#
# spec file for package kernel-kvmsmall
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needssslcertforbuild


%define srcversion 6.10
%define patchversion 6.10.2
%define git_commit 65a34e2b50710364d2085b4c3258b865dc204d62
%define variant %{nil}
%define compress_modules zstd
%define compress_vmlinux xz
%define livepatch livepatch%{nil}
%define livepatch_rt %{nil}
%define sb_efi_only 0
%define split_base 0
%define split_optional 0
%define supported_modules_check 0
%define build_flavor kvmsmall

%include %_sourcedir/kernel-spec-macros

%(chmod +x %_sourcedir/{guards,apply-patches,check-for-config-changes,group-source-files.pl,split-modules,modversions,kabi.pl,mkspec,compute-PATCHVERSION.sh,arch-symbols,log.sh,try-disable-staging-driver,compress-vmlinux.sh,mkspec-dtb,check-module-license,klp-symbols,splitflist,mergedep,moddep,modflist,kernel-subpackage-build})

Name:           kernel-kvmsmall
Version:        6.10.2
%if 0%{?is_kotd}
Release:        1.1.g65a34e2
%else
Release:        1.1
%endif
Summary:        The Small Developer Kernel for KVM
License:        GPL-2.0-only
Group:          System/Kernel
URL:            https://www.kernel.org/
%if 0%{?suse_version} > 1500 || 0%{?sle_version} > 150300
BuildRequires:  bash-sh
%endif
BuildRequires:  bc
BuildRequires:  bison
BuildRequires:  coreutils
BuildRequires:  fdupes
BuildRequires:  flex
# Cannot test %%CONFIG_GCC_PLUGINS here because the buildservice parser
# does not expand %%(...)
%if "%build_flavor" == "syzkaller"
# Needed by scripts/gcc-plugin.sh
BuildRequires:  gcc-c++
BuildRequires:  gcc-devel
%endif
BuildRequires:  hmaccalc
BuildRequires:  libopenssl-devel
BuildRequires:  modutils
BuildRequires:  python3-base
# Used to sign the kernel in the buildservice
BuildRequires:  openssl
BuildRequires:  pesign-obs-integration
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
# pahole for CONFIG_DEBUG_INFO_BTF
BuildRequires:  dwarves >= 1.22
%endif
# for objtool
BuildRequires:  libelf-devel
# required for 50-check-kernel-build-id rpm check
BuildRequires:  elfutils
%ifarch %arm
BuildRequires:  u-boot-tools
%endif
# Do not install p-b and dracut for the install check, the %post script is
# able to handle this
#!BuildIgnore: perl-Bootloader dracut distribution-release suse-kernel-rpm-scriptlets
# Remove some packages that are installed automatically by the build system,
# but are not needed to build the kernel
#!BuildIgnore: autoconf automake gettext-runtime libtool cvs gettext-tools udev insserv
%if ! 0%{?is_kotd} || ! %{?is_kotd_qa}%{!?is_kotd_qa:0}
ExclusiveArch:  aarch64 ppc64le x86_64
%else
ExclusiveArch:  do_not_build
%endif

%ifarch %ix86 x86_64
%define image vmlinuz
%endif
%ifarch ppc ppc64 ppc64le
%define image vmlinux
%endif
%ifarch s390 s390x
%define image image
%endif
%ifarch %arm
%define image zImage
%endif
%ifarch aarch64 riscv64
%define image Image
%endif

%ifarch %ix86 x86_64
%define install_vdso 1
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150500
%define separate_vdso 1
%endif
%else
%define install_vdso 0
%endif

%define build_default	("%build_flavor" == "default")
%define build_vanilla	("%build_flavor" == "vanilla")
%define vanilla_only    %{lua: if (rpm.expand("%variant") == "-vanilla") then print(1) else print(0) end}

%if ! %build_vanilla
%define src_install_dir /usr/src/linux-%kernelrelease%variant
%else
%define src_install_dir /usr/src/linux-%kernelrelease-vanilla
%endif
%define obj_install_dir /usr/src/linux-%kernelrelease%variant-obj
%define rpm_install_dir %buildroot%obj_install_dir
%define kernel_build_dir %my_builddir/linux-%srcversion/linux-obj
%define modules_dir %kernel_module_directory/%kernelrelease-%build_flavor

%global cpu_arch %(%_sourcedir/arch-symbols %_target_cpu)
%define cpu_arch_flavor %cpu_arch/%build_flavor

%if 0%{?_project:1} && ( %(echo %_project | grep -Ex -f %_sourcedir/release-projects | grep -v ^PTF | grep -vc openSUSE) || %(echo %_project | grep -Ec "^(Devel:)?Kernel:") )
	%define klp_symbols 1
%endif

# Define some CONFIG variables as rpm macros as well. (rpm cannot handle
# defining them all at once.)
%define config_vars CONFIG_MODULES CONFIG_MODULE_SIG CONFIG_MODULE_SIG_HASH CONFIG_KMSG_IDS CONFIG_SUSE_KERNEL_SUPPORTED CONFIG_EFI_STUB CONFIG_LIVEPATCH_IPA_CLONES CONFIG_DEBUG_INFO_BTF_MODULES CONFIG_PREEMPT_DYNAMIC
%{expand:%(eval "$(test -n "%cpu_arch_flavor" && tar -xjf %_sourcedir/config.tar.bz2 --to-stdout config/%cpu_arch_flavor)"; for config in %config_vars; do echo "%%global $config ${!config:-n}"; done)}
%define split_extra ("%CONFIG_MODULES" == "y" && "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y")

%if "%CONFIG_MODULES" != "y"
	%define klp_symbols 0
%endif

%global certs %( space="" ; for f in %_sourcedir/*.crt; do                                              \
    if ! test -e "$f"; then                                                                             \
        continue                                                                                        \
    fi                                                                                                  \
    h=$(openssl x509 -inform PEM -fingerprint -noout -in "$f")                                          \
    if [ -z "$h" ] ; then                                                                               \
        echo Cannot parse "$f" >&2                                                                      \
        confinue                                                                                        \
    fi                                                                                                  \
    cert=$(echo "$h" | sed -rn 's/^SHA1 Fingerprint=//; T; s/://g; s/(.{8}).*/\\1/p')                   \
    echo Found signing certificate "$f" "($cert)" >&2                                                   \
    cat "$f" >>%_sourcedir/.kernel_signing_key.pem                                                      \
    mkdir -p %_sourcedir/.kernel_signing_certs                                                          \
    openssl x509 -inform PEM -in "$f" -outform DER -out %_sourcedir/.kernel_signing_certs/"$cert".crt   \
    echo -n "$space$cert" ; space=" "                                                                   \
done )

Source0:        https://www.kernel.org/pub/linux/kernel/v6.x/linux-%srcversion.tar.xz
Source3:        kernel-source.rpmlintrc
Source14:       series.conf
Source16:       guards
Source17:       apply-patches
Source19:       kernel-binary-conflicts
Source20:       obsolete-kmps
Source21:       config.conf
Source23:       supported.conf
Source33:       check-for-config-changes
Source35:       group-source-files.pl
Source36:       README.PATCH-POLICY.SUSE
Source37:       README.SUSE
Source38:       README.KSYMS
Source40:       source-timestamp
Source46:       split-modules
Source47:       modversions
Source48:       macros.kernel-source
Source49:       kernel-module-subpackage
Source50:       kabi.pl
Source51:       mkspec
Source52:       kernel-source%variant.changes
Source53:       kernel-source.spec.in
Source54:       kernel-binary.spec.in
Source55:       kernel-syms.spec.in
Source56:       kernel-docs.spec.in
Source57:       kernel-cert-subpackage
Source58:       constraints.in
Source60:       config.sh
Source61:       compute-PATCHVERSION.sh
Source62:       old-flavors
Source63:       arch-symbols
Source64:       package-descriptions
Source65:       kernel-spec-macros
Source67:       log.sh
Source68:       host-memcpy-hack.h
Source69:       try-disable-staging-driver
Source70:       kernel-obs-build.spec.in
Source71:       kernel-obs-qa.spec.in
Source72:       compress-vmlinux.sh
Source73:       dtb.spec.in.in
Source74:       mkspec-dtb
Source75:       release-projects
Source76:       check-module-license
Source77:       klp-symbols
Source78:       modules.fips
Source79:       splitflist
Source80:       mergedep
Source81:       moddep
Source82:       modflist
Source83:       kernel-subpackage-build
Source84:       kernel-subpackage-spec
Source85:       kernel-default-base.spec.txt
Source86:       old_changelog.txt
Source100:      config.tar.bz2
Source101:      config.addon.tar.bz2
Source102:      patches.arch.tar.bz2
Source103:      patches.drivers.tar.bz2
Source104:      patches.fixes.tar.bz2
Source105:      patches.rpmify.tar.bz2
Source106:      patches.suse.tar.bz2
Source108:      patches.addon.tar.bz2
Source109:      patches.kernel.org.tar.bz2
Source110:      patches.apparmor.tar.bz2
Source111:      patches.rt.tar.bz2
Source113:      patches.kabi.tar.bz2
Source114:      patches.drm.tar.bz2
Source120:      kabi.tar.bz2
Source121:      sysctl.tar.bz2
# These files are found in the kernel-source package:
NoSource:       0
NoSource:       3
NoSource:       14
NoSource:       16
NoSource:       17
NoSource:       19
NoSource:       20
NoSource:       21
NoSource:       23
NoSource:       33
NoSource:       35
NoSource:       36
NoSource:       37
NoSource:       38
NoSource:       40
NoSource:       46
NoSource:       47
NoSource:       48
NoSource:       49
NoSource:       50
NoSource:       51
NoSource:       52
NoSource:       53
NoSource:       54
NoSource:       55
NoSource:       56
NoSource:       57
NoSource:       58
NoSource:       60
NoSource:       61
NoSource:       62
NoSource:       63
NoSource:       64
NoSource:       65
NoSource:       67
NoSource:       68
NoSource:       69
NoSource:       70
NoSource:       71
NoSource:       72
NoSource:       73
NoSource:       74
NoSource:       75
NoSource:       76
NoSource:       77
NoSource:       78
NoSource:       79
NoSource:       80
NoSource:       81
NoSource:       82
NoSource:       83
NoSource:       84
NoSource:       85
NoSource:       86
NoSource:       100
NoSource:       101
NoSource:       102
NoSource:       103
NoSource:       104
NoSource:       105
NoSource:       106
NoSource:       108
NoSource:       109
NoSource:       110
NoSource:       111
NoSource:       113
NoSource:       114
NoSource:       120
NoSource:       121

%ifarch %ix86
# Only i386/default supports i586, mark other flavors' packages as i686
%if ! %build_default
BuildArch:      i686
%endif
%endif
# Force bzip2 instead of lzma compression to
# 1) allow install on older dist versions, and
# 2) decrease build times (bsc#962356 boo#1175882)
%define _binary_payload w9.bzdio
# Do not recompute the build-id of vmlinux in find-debuginfo.sh (bsc#964063)
%undefine _unique_build_ids
%define _no_recompute_build_ids 1
# prevent usr/lib/debug/boot/vmlinux-4.12.14-11.10-default-4.12.14-11.10.ppc64le.debug
%undefine _unique_debug_names

%if "%{compress_modules}" == "zstd"
BuildRequires:  zstd
# Make sure kmod supports zstd compressed modules
Requires(post): kmod-zstd
%endif
Provides:       %name = %version-%source_rel
# bnc#901925
Provides:       %name-%version-%source_rel
Provides:       %{name}_%_target_cpu = %version-%source_rel
Provides:       kernel-base = %version-%source_rel
Provides:       multiversion(kernel)
# In SLE11, kernel-$flavor complemented kernel-$flavor-base. With SLE12,
# kernel-$flavor itself contains all the needed files and kernel-$flavor-base
# is a subset that can replace kernel-$flavor in some scenarios. We need to
# obsolete the -base subpackage from SLE11, so that the base files are not
# owned by multiple packages now. The dependency is not correct wrt openSUSE
# 11.2 - 11.4, but we primarily care about the supported upgrade path.
Obsoletes:      %name-base < 3.1
%if ("%build_flavor" != "kvmsmall") && ("%build_flavor" != "azure")
Recommends: kernel-firmware
%endif
# The following is copied to the -base subpackage as well
# BEGIN COMMON DEPS
Requires(pre):  suse-kernel-rpm-scriptlets
Requires(post): suse-kernel-rpm-scriptlets
Requires:       suse-kernel-rpm-scriptlets
Requires(preun): suse-kernel-rpm-scriptlets
Requires(postun): suse-kernel-rpm-scriptlets
Requires(pre):  coreutils awk
# For /usr/lib/module-init-tools/weak-modules2 and /usr/lib/modprobe.d/*.conf
Requires(post): suse-module-tools
Requires:       suse-module-tools
# For depmod (modutils is a dependency provided by both module-init-tools and
# kmod-compat)
Requires(post): modutils
# This Requires is wrong, because the post/postun scripts have a
# test -x update-bootloader, having perl-Bootloader is not a hard requirement.
# But, there is no way to tell rpm or yast to schedule the installation
# of perl-Bootloader before kernel-binary.rpm if both are in the list of
# packages to install/update. Likewise, this is true for dracut.
# Need a perl-Bootloader with /usr/lib/bootloader/bootloader_entry
Requires(post): perl-Bootloader >= 0.4.15
Requires(post): dracut
# Install the package providing /etc/SuSE-release early enough, so that
# the grub entry has correct title (bnc#757565)
Requires(post): distribution-release

%if %{usrmerged}
# make sure we have a post-usrmerge system
Conflicts:      filesystem < 16
%endif

Obsoletes:      microcode_ctl < 1.18

%{lua:	fd, err = io.open(rpm.expand('%_sourcedir') .. '/kernel-binary-conflicts')
	if not fd then io.stderr:write(err) end
	unpack = table.unpack or unpack
	for l in fd:lines() do
		if #l > 0 and l:sub(1,1) ~= '#' then
			words = {} ; for w in l:gmatch("([^%s]+)%s*") do table.insert(words, w) end
			package, version = unpack(words)
			print('Conflicts: ' .. package .. ' < '.. version .. '\n')
		end
	end
	fd:close()
}

%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
Provides:       kernel = %version-%source_rel
Provides:       kernel-%build_flavor-base-srchash-%git_commit
Provides:       kernel-srchash-%git_commit
# END COMMON DEPS
Provides:       %name-srchash-%git_commit
%obsolete_rebuilds %name

%define kmp_target_cpu %_target_cpu
%ifarch %ix86
# KMPs are always built as i586, because rpm does not allow to build
# subpackages for different architectures. Therefore, we change the
# /usr/src/linux-obj/<arch> symlink to i586.
%define kmp_target_cpu i586
%endif

%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kernel-preempt = %version-%release
Provides:       kernel-preempt_%_target_cpu = %version-%source_rel
%endif
%endif

%{lua:	fd, err = io.open(rpm.expand('%_sourcedir') .. '/obsolete-kmps')
	if not fd then io.stderr:write(err) end
	unpack = table.unpack or unpack
	for l in fd:lines() do
		if #l > 0 and l:sub(1,1) ~= '#' then
			words = {} ; for w in l:gmatch("([^%s]+)%s*") do table.insert(words, w) end
			package, version = unpack(words)
			print('Obsoletes: ' .. package .. '-kmp-' .. rpm.expand('%build_flavor') .. ' <= '.. version .. '\n')
			print('Provides: ' .. package .. '-kmp = ' .. version .. '.1\n')
			print('Provides: ' .. package .. '-kmp-' .. rpm.expand('%build_flavor') .. ' = '.. version .. '.1\n')
		end
	end
	fd:close()
}

%description
This kernel is intended for kernel developers to use in simple virtual
machines.  It contains only the device drivers necessary to use a
KVM virtual machine *without* device passthrough enabled.  Common
local and network file systems are enabled.  All device mapper targets
are enabled.  Only the network and graphics drivers for devices that qemu
emulates are enabled.  Many subsystems enabled in the default kernel
are entirely disabled.  This kernel is meant to be small and to build
very quickly.  The configuration may change arbitrarily between builds.


%source_timestamp

%pre
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-pre --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%post
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-post --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%preun
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-preun --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%postun
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-postun --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%posttrans
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-posttrans --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%files -f kernel-main.files

%if "%CONFIG_MODULES" == "y" && %split_base
%package base
Summary:        The Small Developer Kernel for KVM - base modules
Group:          System/Kernel
Url:            http://www.kernel.org/
Provides:       kernel-base = %version-%source_rel
Provides:       multiversion(kernel)
Conflicts:      %name = %version-%source_rel
Requires(pre):  suse-kernel-rpm-scriptlets
Requires(post): suse-kernel-rpm-scriptlets
Requires:       suse-kernel-rpm-scriptlets
Requires(preun): suse-kernel-rpm-scriptlets
Requires(postun): suse-kernel-rpm-scriptlets
Requires(pre):  coreutils awk
# For /usr/lib/module-init-tools/weak-modules2 and /usr/lib/modprobe.d/*.conf
Requires(post): suse-module-tools
Requires:       suse-module-tools
# For depmod (modutils is a dependency provided by both module-init-tools and
# kmod-compat)
Requires(post): modutils
# This Requires is wrong, because the post/postun scripts have a
# test -x update-bootloader, having perl-Bootloader is not a hard requirement.
# But, there is no way to tell rpm or yast to schedule the installation
# of perl-Bootloader before kernel-binary.rpm if both are in the list of
# packages to install/update. Likewise, this is true for dracut.
# Need a perl-Bootloader with /usr/lib/bootloader/bootloader_entry
Requires(post): perl-Bootloader >= 0.4.15
Requires(post): dracut
# Install the package providing /etc/SuSE-release early enough, so that
# the grub entry has correct title (bnc#757565)
Requires(post): distribution-release

%if %{usrmerged}
# make sure we have a post-usrmerge system
Conflicts:      filesystem < 16
%endif

Obsoletes:      microcode_ctl < 1.18

%{lua:	fd, err = io.open(rpm.expand('%_sourcedir') .. '/kernel-binary-conflicts')
	if not fd then io.stderr:write(err) end
	unpack = table.unpack or unpack
	for l in fd:lines() do
		if #l > 0 and l:sub(1,1) ~= '#' then
			words = {} ; for w in l:gmatch("([^%s]+)%s*") do table.insert(words, w) end
			package, version = unpack(words)
			print('Conflicts: ' .. package .. ' < '.. version .. '\n')
		end
	end
	fd:close()
}

%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
Provides:       kernel = %version-%source_rel
Provides:       kernel-%build_flavor-base-srchash-%git_commit
Provides:       kernel-srchash-%git_commit

%obsolete_rebuilds %name-base
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif

%description base
This kernel is intended for kernel developers to use in simple virtual
machines.  It contains only the device drivers necessary to use a
KVM virtual machine *without* device passthrough enabled.  Common
local and network file systems are enabled.  All device mapper targets
are enabled.  Only the network and graphics drivers for devices that qemu
emulates are enabled.  Many subsystems enabled in the default kernel
are entirely disabled.  This kernel is meant to be small and to build
very quickly.  The configuration may change arbitrarily between builds.

This package contains only the base modules, required in all installs.


%source_timestamp
%pre base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-pre --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-post --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-preun --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-postun --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-posttrans --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files base -f kernel-base.files
%endif

%package extra
Summary:        The Small Developer Kernel for KVM - Unsupported kernel modules
Group:          System/Kernel
URL:            https://www.kernel.org/
Provides:       %name-extra_%_target_cpu = %version-%source_rel
Provides:       kernel-extra = %version-%source_rel
Provides:       multiversion(kernel)
Requires:       %{name}_%_target_cpu = %version-%source_rel
Requires(pre):  coreutils awk
Requires(post): modutils
Requires(post): perl-Bootloader
Requires(post): dracut
%obsolete_rebuilds %name-extra
Supplements:    packageand(product(SLED):%{name}_%_target_cpu)
Supplements:    packageand(product(sle-we):%{name}_%_target_cpu)
Supplements:    packageand(product(Leap):%{name}_%_target_cpu)
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kernel-preempt-extra = %version-%release
Provides:       kernel-preempt-extra_%_target_cpu = %version-%source_rel
%endif
%endif

%description extra
This kernel is intended for kernel developers to use in simple virtual
machines.  It contains only the device drivers necessary to use a
KVM virtual machine *without* device passthrough enabled.  Common
local and network file systems are enabled.  All device mapper targets
are enabled.  Only the network and graphics drivers for devices that qemu
emulates are enabled.  Many subsystems enabled in the default kernel
are entirely disabled.  This kernel is meant to be small and to build
very quickly.  The configuration may change arbitrarily between builds.

This package contains additional modules not supported by SUSE.


%source_timestamp

%pre extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%if %split_extra

%files extra -f kernel-extra.files
%endif

%if %split_extra && %split_optional
%package optional
Summary:        The Small Developer Kernel for KVM - Optional kernel modules
Group:          System/Kernel
URL:            https://www.kernel.org/
Provides:       %name-optional_%_target_cpu = %version-%source_rel
Provides:       kernel-optional = %version-%source_rel
Provides:       multiversion(kernel)
Requires:       %name-extra_%_target_cpu = %version-%source_rel
Requires(pre):  coreutils awk
Requires(post): modutils
Requires(post): perl-Bootloader
Requires(post): dracut
%obsolete_rebuilds %name-optional
Supplements:    packageand(product(Leap):%{name}_%_target_cpu)
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kernel-preempt-optional = %version-%release
Provides:       kernel-preempt-optional_%_target_cpu = %version-%source_rel
%endif
%endif

%description optional
This kernel is intended for kernel developers to use in simple virtual
machines.  It contains only the device drivers necessary to use a
KVM virtual machine *without* device passthrough enabled.  Common
local and network file systems are enabled.  All device mapper targets
are enabled.  Only the network and graphics drivers for devices that qemu
emulates are enabled.  Many subsystems enabled in the default kernel
are entirely disabled.  This kernel is meant to be small and to build
very quickly.  The configuration may change arbitrarily between builds.

This package contains optional modules only for openSUSE Leap.


%source_timestamp

%pre optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files optional -f kernel-optional.files
%endif

%if "%CONFIG_KMSG_IDS" == "y"

%package man
Summary:        The collection of man pages generated by the kmsg script
Group:          System/Kernel

%description man
This package includes the man pages that have been generated from the
kmsg message documentation comments.


%source_timestamp
%files man
/usr/share/man/man9/*
%endif

%if 0%{?separate_vdso}
%package vdso
Summary:        vdso binaries for debugging purposes
Group:          System/Kernel

%description vdso
This package includes the vdso binaries. They can be used for debugging. The
actual binary linked to the programs is loaded from the in-memory image, not
from this package.


%source_timestamp
%files vdso
%dir %modules_dir
%modules_dir/vdso/
%endif

%package devel
Summary:        Development files necessary for building kernel modules
Group:          Development/Sources
Provides:       %name-devel = %version-%source_rel
Provides:       multiversion(kernel)
%if ! %build_vanilla && ! %vanilla_only
Requires:       kernel-devel%variant = %version-%source_rel
Recommends:     make
Recommends:     gcc
Recommends:     perl
# for objtool
Requires:	libelf-devel
Supplements:    packageand(%name:kernel-devel%variant)
%else
Requires:       kernel-source-vanilla = %version-%source_rel
Supplements:    packageand(%name:kernel-source-vanilla)
%endif
%if "%CONFIG_DEBUG_INFO_BTF_MODULES" == "y"
Requires:       dwarves >= 1.22
%endif
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kernel-preempt-devel = %version-%release
%endif
%endif
%obsolete_rebuilds %name-devel
PreReq:         coreutils

%description devel
This package contains files necessary for building kernel modules (and
kernel module packages) against the %build_flavor flavor of the kernel.


%source_timestamp

%if "%CONFIG_MODULES" == "y"

%pre devel

# handle update from an older kernel-source with linux-obj as symlink
if [ -h /usr/src/linux-obj ]; then
    rm -vf /usr/src/linux-obj
fi

%post devel
%relink_function

relink ../../linux-%{kernelrelease}%{variant}-obj/"%cpu_arch_flavor" /usr/src/linux-obj/"%cpu_arch_flavor"

%files devel -f kernel-devel.files
%dir /usr/src/linux-obj
%dir /usr/src/linux-obj/%cpu_arch
%ghost /usr/src/linux-obj/%cpu_arch_flavor
%exclude %obj_install_dir/%cpu_arch_flavor/Symbols.list
%if "%kmp_target_cpu" != "%cpu_arch"
%obj_install_dir/%kmp_target_cpu
/usr/src/linux-obj/%kmp_target_cpu
%endif

%if "%livepatch" != "" && "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y" && (("%variant" == "" && %build_default) || ("%variant" == "-rt" && 0%livepatch_rt))
%if "%livepatch" == "kgraft"
%define patch_package %{livepatch}-patch
%else
%define patch_package kernel-%{livepatch}
%endif
%package %{livepatch}
Summary:        Metapackage to pull in matching %patch_package package
Group:          System/Kernel
Requires:       %{patch_package}-%(echo %{version}-%{source_rel} | sed 'y/\./_/')-%{build_flavor}
Provides:       multiversion(kernel)
%if "%variant" != "-rt"
Provides:	kernel-default-kgraft = %version
Provides:	kernel-xen-kgraft = %version
%if "%livepatch" != "kgraft"
Obsoletes:	kernel-default-kgraft < %version
Obsoletes:	kernel-xen-kgraft < %version
%endif
%endif

%description %{livepatch}
This is a metapackage that pulls in the matching %patch_package package for a
given kernel version. The advantage of the metapackage is that its name is
static, unlike the %{patch_package}-<kernel-version>-flavor package names.

%files %{livepatch}
# rpmlint complains about empty packages, so lets own something
%dir %modules_dir
%endif

%if 0%{?klp_symbols} && "%livepatch" != ""
%package %{livepatch}-devel
Summary:	Kernel symbols file used during kGraft patch development
Group:		System/Kernel
Provides:	klp-symbols = %version

%description %{livepatch}-devel
This package brings a file named Symbols.list, which contains a list of all
kernel symbols and its respective kernel object . This list is to be used by
the klp-convert tool, which helps livepatch developers by enabling automatic
symbol resolution.

%files %{livepatch}-devel -f livepatch-files
%endif

%if "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y"
%package -n cluster-md-kmp-%build_flavor
Summary:        Clustering support for MD devices
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       cluster-md-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       cluster-md-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:cluster-md-kmp-%build_flavor)
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n cluster-md-kmp-%build_flavor
Clustering support for MD devices. This enables locking and
synchronization across multiple systems on the cluster, so all
nodes in the cluster can access the MD devices simultaneously.

%pre -n cluster-md-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "cluster-md-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n cluster-md-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "cluster-md-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n cluster-md-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "cluster-md-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n cluster-md-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "cluster-md-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n cluster-md-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "cluster-md-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n cluster-md-kmp-%build_flavor -f cluster-md-kmp.files

%package -n dlm-kmp-%build_flavor
Summary:        DLM kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       dlm-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       dlm-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:dlm-kmp-%build_flavor)

%description -n dlm-kmp-%build_flavor
DLM stands for Distributed Lock Manager, a means to synchronize access to
shared resources over the cluster.

%pre -n dlm-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "dlm-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n dlm-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "dlm-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n dlm-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "dlm-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n dlm-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "dlm-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n dlm-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "dlm-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n dlm-kmp-%build_flavor -f dlm-kmp.files

%package -n gfs2-kmp-%build_flavor
Summary:        GFS2 kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       gfs2-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       gfs2-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:gfs2-kmp-%build_flavor)
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n gfs2-kmp-%build_flavor
GFS2 is Global Filesystem, a shared device filesystem.

%pre -n gfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "gfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n gfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "gfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n gfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "gfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n gfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "gfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n gfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "gfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n gfs2-kmp-%build_flavor -f gfs2-kmp.files

%package -n kselftests-kmp-%build_flavor
Summary:        Kernel sefltests
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       kselftests-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kselftests-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:kselftests-kmp-%build_flavor)

%description -n kselftests-kmp-%build_flavor
This package contains kernel modules which are part of the upstream kernel
selftest effort. kselftest is the name of the upstream kernel target to build
and run all selftests. You can also run each test individually from the
respective upstream tools/testing/selftests/ directory, this package is
intended to be used using individial upstream selftest scripts given only
select supported selftest drivers are enabled.

It should always be possible to always run the latest linux-next version of the
selftest scripts and tests against any older kernel selftest driver.  Certain
tests facilities may be backported onto older kernels to enable further
testing.

Selftests also provide for a vehicle or proof of concept issues to be
reproduced, verified and corrected.

Selftest drivers are intended to be supported only in testing and QA
environments, they are not intended to be run on production systems.

%pre -n kselftests-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "kselftests-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n kselftests-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "kselftests-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n kselftests-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "kselftests-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n kselftests-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "kselftests-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n kselftests-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "kselftests-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n kselftests-kmp-%build_flavor -f kselftests-kmp.files

%package -n ocfs2-kmp-%build_flavor
Summary:        OCFS2 kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       ocfs2-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       ocfs2-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:ocfs2-kmp-%build_flavor)
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n ocfs2-kmp-%build_flavor
OCFS2 is the Oracle Cluster Filesystem, a filesystem for shared devices
accessible simultaneously from multiple nodes of a cluster.

%pre -n ocfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "ocfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n ocfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "ocfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n ocfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "ocfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n ocfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "ocfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n ocfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "ocfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n ocfs2-kmp-%build_flavor -f ocfs2-kmp.files

%package -n reiserfs-kmp-%build_flavor
Summary:        Reiserfs kernel module
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       reiserfs-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       reiserfs-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:reiserfs-kmp-%build_flavor)

%description -n reiserfs-kmp-%build_flavor
The reiserfs file system is no longer supported in SLE15.  This package
provides the reiserfs module for the installation system.

%pre -n reiserfs-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "reiserfs-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n reiserfs-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "reiserfs-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n reiserfs-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "reiserfs-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n reiserfs-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "reiserfs-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n reiserfs-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "reiserfs-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n reiserfs-kmp-%build_flavor -f reiserfs-kmp.files

%endif # %CONFIG_SUSE_KERNEL_SUPPORTED
%endif # %CONFIG_MODULES

%prep
if ! [ -e %{S:0} ]; then
    echo "The %name-%version.nosrc.rpm package does not contain the" \
	 "complete sources. Please install kernel-source-%version.src.rpm."
    exit 1
fi

SYMBOLS=
if test -e %_sourcedir/extra-symbols; then
	SYMBOLS=$(cat %_sourcedir/extra-symbols)
	echo "extra symbol(s):" $SYMBOLS
fi

# Unpack all sources and patches
%setup -q -c -T -a 0 -a 100 -a 101 -a 102 -a 103 -a 104 -a 105 -a 106 -a 108 -a 109 -a 110 -a 111 -a 113 -a 114 -a 120 -a 121

mkdir -p %kernel_build_dir

# Generate a list of modules with their support status marking
# The first marker is supposed to be either "+external", "-" or "-!optional",
# where "+external" is for an externally supported module, "-" is for an
# unsuppored module, "-!optional" is for Leap-only unsupported module.
# There can be an optional arch-specific second marker with "+arch" (e.g.
# +arm64), which enforces the module to be supported on the specific arch.
%_sourcedir/guards --list --with-guards <%_sourcedir/supported.conf | \
awk '{
    t = "";
    for (i = 1; i < NF; i++) {
	if ($i == "+external") {
		t = " external";
	} else if ($i == "+'%cpu_arch'") {
		t = "";
	} else if ($i ~ "^-") {
		t = " no";
	}
    }
    print $(NF) t;
}' >%kernel_build_dir/Module.supported
subpackages=(
	base
%if "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y"
	cluster-md-kmp dlm-kmp gfs2-kmp kselftests-kmp ocfs2-kmp reiserfs-kmp
%endif
)
for package in "${subpackages[@]}"; do
	%_sourcedir/guards --default=0 "$package" \
		<%_sourcedir/supported.conf | sed 's,.*/,,; s,\.ko$,,' | \
		sort -u >%kernel_build_dir/Module."$package"
done
%if %split_extra && %split_optional
# Module.optional is in a special form, containing guard markers for
# both extra and optional modules, which is processed by split-modules
%_sourcedir/guards --list --with-guards <%_sourcedir/supported.conf | \
awk '{
    t = "";
    for (i = 1; i < NF; i++) {
	if ($i == "+'%cpu_arch'") {
		t = "";
	} else if ($i ~ "^-") {
		t = $i
	}
    }
    if (t != "") {print t,$(NF);}
}' >%kernel_build_dir/Module.optional
%endif

cd linux-%srcversion

%_sourcedir/apply-patches \
%if %{build_vanilla} && ! %vanilla_only
	--vanilla \
%endif
	%_sourcedir/series.conf .. $SYMBOLS

cd %kernel_build_dir

# Override the timestamp 'uname -v' reports with the source timestamp and
# the commit hash.
date=$(head -n 1 %_sourcedir/source-timestamp)
commit=$(sed -n 's/GIT Revision: //p' %_sourcedir/source-timestamp)
cat > .kernel-binary.spec.buildenv <<EOF
export KBUILD_BUILD_TIMESTAMP="$(LANG=C date -d "$date") (${commit:0:7})"
export KBUILD_VERBOSE=0
export KBUILD_SYMTYPES=1
export KBUILD_BUILD_USER=geeko
export KBUILD_BUILD_HOST=buildhost
export HOST_EXTRACFLAGS="-include %_sourcedir/host-memcpy-hack.h"
EOF
source .kernel-binary.spec.buildenv

if [ -f %_sourcedir/localversion ] ; then
    cat %_sourcedir/localversion > localversion
fi

config_base="default"
%ifarch %ix86
config_base="pae"
%endif
if ! [ -f %my_builddir/config/%cpu_arch/$config_base ] ; then
    config_base=%variant
    config_base=${config_base#-}
fi
if ! grep -q CONFIG_MMU= "%my_builddir/config/%cpu_arch_flavor"; then
cp "%my_builddir/config/%cpu_arch/$config_base" .config
../scripts/kconfig/merge_config.sh -m .config \
                                   %my_builddir/config/%cpu_arch_flavor
else
cp %my_builddir/config/%cpu_arch_flavor .config
fi
if test -e %my_builddir/config.addon/%cpu_arch_flavor; then
	# FIXME: config.addon doesn't affect the %CONFIG_ macros defined at
	# the top of the specfile
	../scripts/kconfig/merge_config.sh -m .config %my_builddir/config.addon/%cpu_arch_flavor
fi

CONFIG_SUSE_KERNEL_RELEASED="--disable CONFIG_SUSE_KERNEL_RELEASED"
%if 0%{?_project:1}
if echo %_project | grep -Eqx -f %_sourcedir/release-projects; then
	CONFIG_SUSE_KERNEL_RELEASED="--enable CONFIG_SUSE_KERNEL_RELEASED"
fi
%endif

DEBUG_INFO_TYPE="$(grep "CONFIG_DEBUG_INFO_DWARF.*=y" .config)"
DEBUG_INFO_TYPE="${DEBUG_INFO_TYPE%%=y}"
DEBUG_INFO_TYPE="${DEBUG_INFO_TYPE##CONFIG_DEBUG_INFO_}"
echo "Kernel debuginfo type: ${DEBUG_INFO_TYPE}"

../scripts/config \
	--set-str CONFIG_LOCALVERSION -%source_rel-%build_flavor \
	--enable  CONFIG_SUSE_KERNEL \
	$CONFIG_SUSE_KERNEL_RELEASED \
%if 0%{?__debug_package:1}
	--enable  CONFIG_DEBUG_INFO
%else
	--disable CONFIG_DEBUG_INFO \
	--disable CONFIG_DEBUG_INFO_"${DEBUG_INFO_TYPE}" \
	--enable  CONFIG_DEBUG_INFO_NONE
%endif

if [ %CONFIG_MODULE_SIG = "y" ]; then
	if [ -n "%certs" ] ; then
		ln -s %_sourcedir/.kernel_signing_key.pem .
	else
		if ! [ -f .kernel.genkey ] ; then
			cat > .kernel.genkey <<EOF
[ req ]
default_bits = 4096
distinguished_name = req_distinguished_name
prompt = no
string_mask = utf8only
x509_extensions = myexts

[ req_distinguished_name ]
CN = Build time autogenerated kernel key

[ myexts ]
basicConstraints=critical,CA:FALSE
keyUsage=digitalSignature
subjectKeyIdentifier=hash
authorityKeyIdentifier=keyid
extendedKeyUsage=codeSigning
EOF
		fi
		openssl req -new -nodes -utf8 -%CONFIG_MODULE_SIG_HASH -days 36500 \
			-batch -x509 -config .kernel.genkey \
			-outform PEM -out .kernel_signing_key.pem \
			-keyout .kernel_signing_key.pem
	fi
	../scripts/config --set-str CONFIG_MODULE_SIG_KEY ".kernel_signing_key.pem"
fi

case %cpu_arch in
    x86_64 | i386)
        MAKE_ARGS="$MAKE_ARGS ARCH=x86"
        ;;
    ppc*)
        MAKE_ARGS="$MAKE_ARGS ARCH=powerpc"
        ;;
    s390x)
        MAKE_ARGS="$MAKE_ARGS ARCH=s390"
        ;;
    arm64)
        MAKE_ARGS="$MAKE_ARGS ARCH=arm64"
        ;;
    armv*)
        MAKE_ARGS="$MAKE_ARGS ARCH=arm"
        ;;
    riscv*)
        MAKE_ARGS="$MAKE_ARGS ARCH=riscv"
        ;;
    *)
        MAKE_ARGS="$MAKE_ARGS ARCH=%cpu_arch"
        ;;
esac

makeoutputsync=
if make --output-sync --help >/dev/null 2>&1 ; then
        makeoutputsync=--output-sync
else
        echo make does not support --output-sync flag. Build messages may be mangled. 1>&2
fi
MAKE_ARGS="$MAKE_ARGS $makeoutputsync %{?_smp_mflags}"
echo export MAKE_ARGS=\""$MAKE_ARGS"\" >> .kernel-binary.spec.buildenv

KERN_DIRS="-C .. O=$PWD"
if test -e %_sourcedir/TOLERATE-UNKNOWN-NEW-CONFIG-OPTIONS; then
    yes '' | make oldconfig $MAKE_ARGS $KERN_DIRS
else
    cp .config .config.orig
    if test -f ../scripts/kconfig/Makefile && \
       grep -q syncconfig ../scripts/kconfig/Makefile; then
        syncconfig="syncconfig"
    else
        syncconfig="silentoldconfig"
    fi
    make $syncconfig $MAKE_ARGS $KERN_DIRS < /dev/null
    %_sourcedir/check-for-config-changes .config.orig .config
    rm .config.orig
fi

make prepare $MAKE_ARGS
make scripts $MAKE_ARGS
krel=$(make -s kernelrelease $MAKE_ARGS)

if [ "$krel" != "%kernelrelease-%build_flavor" ]; then
    echo "Kernel release mismatch: $krel != %kernelrelease-%build_flavor" >&2
    exit 1
fi

make clean $MAKE_ARGS

rm -f source
find . ! -type d ! -name 'Module.base' ! -name 'Module.*-kmp' ! -name 'Module.optional' -printf '%%P\n' \
	> %my_builddir/obj-files

%build
cd %kernel_build_dir
source .kernel-binary.spec.buildenv

# create *.symref files in the tree
if test -e %my_builddir/kabi/%cpu_arch/symtypes-%build_flavor; then
    %_sourcedir/modversions --unpack . < $_
fi

%if "%CONFIG_KMSG_IDS" == "y"
    chmod +x ../scripts/kmsg-doc
    MAKE_ARGS="$MAKE_ARGS D=2"
%endif

mkdir -p %_topdir/OTHER
log=%_topdir/OTHER/make-stderr.log
while true; do
    make all $MAKE_ARGS 2> >(tee "$log")
    if test "${PIPESTATUS[0]}" -eq 0; then
        break
    fi
    # In the linux-next and vanilla branches, we try harder to build a
    # package.
    if test 0%vanilla_only -gt 0 &&
			%_sourcedir/try-disable-staging-driver "$log"; then
        echo "Retrying make"
    else
        exit 1
    fi
done

# Generate list of symbols that are used to create kernel livepatches
%if 0%{?klp_symbols}
	%_sourcedir/klp-symbols . Symbols.list
%endif

%install

# get rid of /usr/lib/rpm/brp-strip-debug
# strip removes too much from the vmlinux ELF binary
export NO_BRP_STRIP_DEBUG=true
export STRIP_KEEP_SYMTAB='*/vmlinux*'

# %kernel_module_directory/%kernelrelease-%build_flavor/source points to the source
# directory installed by kernel-devel. The kernel-%build_flavor-devel package
# has a correct dependency on kernel-devel, but the brp check does not see
# kernel-devel during build.
export NO_BRP_STALE_LINK_ERROR=yes

cd %kernel_build_dir
source .kernel-binary.spec.buildenv

mkdir -p %buildroot/boot
# (Could strip out non-public symbols.)
cp -p System.map %buildroot/boot/System.map-%kernelrelease-%build_flavor

add_vmlinux()
{
    local vmlinux=boot/vmlinux-%kernelrelease-%build_flavor

    cp vmlinux %buildroot/$vmlinux
    # make sure that find-debuginfo.sh picks it up. In the filelist, we
    # mark the file 0644 again
    chmod +x %buildroot/$vmlinux
    if test $1 == "--compressed"; then
        # avoid using the gzip -n option to make kdump happy (bnc#880848#c20)
        ts="$(head -n1 %_sourcedir/source-timestamp)"
        touch -d "$ts" %buildroot/$vmlinux
        touch %buildroot/$vmlinux.%{compress_vmlinux}
%if 0%{?__debug_package:1}
        # compress the vmlinux image after find-debuginfo.sh has processed it
%global __debug_install_post %__debug_install_post \
%_sourcedir/compress-vmlinux.sh %buildroot/boot/vmlinux-%kernelrelease-%build_flavor
%else
        %_sourcedir/compress-vmlinux.sh %buildroot/$vmlinux
%endif
        ghost_vmlinux=true
    else
        ghost_vmlinux=false
    fi
}

# architecture specifics
%ifarch %ix86 x86_64
    add_vmlinux --compressed
    cp -p arch/x86/boot/bzImage %buildroot/boot/%image-%kernelrelease-%build_flavor
%endif
%ifarch ppc ppc64 ppc64le
    add_vmlinux
%endif
%ifarch s390 s390x
    add_vmlinux --compressed
    image=image
    if test ! -f arch/s390/boot/$image; then
        image=bzImage
    fi
    cp -p arch/s390/boot/$image %buildroot/boot/%image-%kernelrelease-%build_flavor
%if "%CONFIG_KMSG_IDS" == "y"
    mkdir -p %buildroot/usr/share/man/man9
    find man -name '*.9' -exec install -m 644 -D '{}' %buildroot/usr/share/man/man9/ ';'
%endif
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
    s390x_vmlinux=arch/s390/boot/compressed/vmlinux
    if [ ! -f "$s390x_vmlinux" ]; then
        s390x_vmlinux=arch/s390/boot/vmlinux
    fi
    objcopy -R .rodata.compressed "$s390x_vmlinux" %buildroot/boot/zdebug-%kernelrelease-%build_flavor
%endif
%endif
%ifarch %arm
    add_vmlinux --compressed
    cp -p arch/arm/boot/%image %buildroot/boot/%image-%kernelrelease-%build_flavor
%endif
%ifarch aarch64
    add_vmlinux --compressed
    cp -p arch/arm64/boot/%image %buildroot/boot/%image-%kernelrelease-%build_flavor
%endif
%ifarch riscv64
    add_vmlinux --compressed
    cp -p arch/riscv/boot/%image %buildroot/boot/%image-%kernelrelease-%build_flavor
%endif

# sign the modules, firmware and possibly the kernel in the buildservice
BRP_PESIGN_FILES=""
%if "%CONFIG_EFI_STUB" == "y"
%if %{usrmerged}
BRP_PESIGN_FILES="%modules_dir/%image"
%else
BRP_PESIGN_FILES="/boot/%image-%kernelrelease-%build_flavor"
%endif
%endif
%if ! %sb_efi_only
%ifarch s390x ppc64 ppc64le
%if %{usrmerged}
BRP_PESIGN_FILES="%modules_dir/%image"
%else
BRP_PESIGN_FILES="/boot/%image-%kernelrelease-%build_flavor"
%endif
%endif
%endif
%if "%CONFIG_MODULE_SIG" == "y"
BRP_PESIGN_FILES="$BRP_PESIGN_FILES *.ko"
%endif
%ifarch %ix86
# XXX: do not sign on x86, as the repackaging changes kernel-pae
# from i686 to i586
BRP_PESIGN_FILES=""
%endif
export BRP_PESIGN_FILES
%if "%{compress_modules}" != "none"
export BRP_PESIGN_COMPRESS_MODULE=%{compress_modules}
%endif
# Do not sign vanilla kernels released in official projects
%if %build_vanilla && ! %vanilla_only
BRP_PESIGN_FILES=""
%endif

if test -x /usr/lib/rpm/pesign/gen-hmac; then
	$_ -r %buildroot /boot/%image-%kernelrelease-%build_flavor
fi

# Package the compiled-in certificates as DER files in /etc/uefi/certs
# and have mokutil enroll them when the kernel is installed
echo Signing certificates "%certs"
if test %CONFIG_MODULE_SIG = "y" -a -d %_sourcedir/.kernel_signing_certs ; then
    for f in %_sourcedir/.kernel_signing_certs/*.crt; do
            mkdir -p %buildroot/etc/uefi/certs
            cp -v $f %buildroot/etc/uefi/certs
    done
fi

cp -p .config %buildroot/boot/config-%kernelrelease-%build_flavor
sysctl_file=%buildroot/boot/sysctl.conf-%kernelrelease-%build_flavor
for file in %my_builddir/sysctl/{defaults,%cpu_arch/arch-defaults,%cpu_arch_flavor}; do
	if [ -f "$file" ]; then
		cat "$file"
	fi
done | sed '1i # Generated file - do not edit.' >$sysctl_file
if [ ! -s $sysctl_file ]; then
	rm $sysctl_file
fi

%if %install_vdso
# Install the unstripped vdso's that are linked in the kernel image
make vdso_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot
rm -rf %buildroot%kernel_module_directory/%kernelrelease-%build_flavor/vdso/.build-id
%endif

# Create a dummy initrd with roughly the size the real one will have.
# That way, YaST will know that this package requires some additional
# space in /boot.
dd if=/dev/zero of=%buildroot/boot/initrd-%kernelrelease-%build_flavor \
	bs=1024 seek=2047 count=1
# Also reserve some space for the kdump initrd
cp %buildroot/boot/initrd-%kernelrelease-%build_flavor{,-kdump}
%if 0%{?suse_version} >= 1500
# Use same permissions as dracut
chmod 0600 %buildroot/boot/initrd-%kernelrelease-%build_flavor{,-kdump}
%endif

if [ %CONFIG_MODULES = y ]; then
    mkdir -p %rpm_install_dir/%cpu_arch_flavor
    mkdir -p %buildroot/usr/src/linux-obj/%cpu_arch
    install -m 755 -D -t %rpm_install_dir/%cpu_arch_flavor/scripts/mod/ scripts/mod/ksym-provides

    gzip -n -c9 < Module.symvers > %buildroot/boot/symvers-%kernelrelease-%build_flavor.gz

    make modules_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot

%ifarch s390 s390x
    expoline=arch/s390/lib/expoline/expoline.o
    if test -f arch/s390/lib/expoline/expoline.o ; then
	install -m 644 -D -t %rpm_install_dir/%cpu_arch_flavor/$(dirname $expoline) $expoline
    fi
%endif

    # Also put the resulting file in %rpm_install_dir/%cpu_arch/%build_flavor
    # so that kernel-devel + kernel-%build_flavor is sufficient for building
    # modules that have modversions as well.
    mkdir -p %rpm_install_dir/%cpu_arch/%build_flavor
    cp Module.symvers %rpm_install_dir/%cpu_arch/%build_flavor

    # List of symbols that are used to generate kernel livepatches
    %if 0%{?klp_symbols}
        cp Symbols.list %rpm_install_dir/%cpu_arch/%build_flavor
        echo %obj_install_dir/%cpu_arch/%build_flavor/Symbols.list > %my_builddir/livepatch-files.no_dir

        %if "%CONFIG_LIVEPATCH_IPA_CLONES" == "y"
            find %kernel_build_dir -name "*.ipa-clones" ! -size 0 | sed -e 's|^%kernel_build_dir/||' | sort > ipa-clones.list
            cp ipa-clones.list %rpm_install_dir/%cpu_arch/%build_flavor
            echo %obj_install_dir/%cpu_arch/%build_flavor/ipa-clones.list >> %my_builddir/livepatch-files.no_dir
            tar -C %kernel_build_dir \
%if ! 0%{?suse_version} || 0%{?suse_version} >= 1500
		    --verbatim-files-from \
%endif
		    -T ipa-clones.list -cf- | tar -C %rpm_install_dir/%cpu_arch/%build_flavor -xvf-
            cat ipa-clones.list | sed -e 's|^|%obj_install_dir/%cpu_arch/%build_flavor/|' >> %my_builddir/livepatch-files.no_dir
        %endif
    %endif

    # Table of types used in exported symbols (for modversion debugging).
    %_sourcedir/modversions --pack . > %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    if [ -s %buildroot/boot/symtypes-%kernelrelease-%build_flavor ]; then
	gzip -n -9 %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    else
	rm -f %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    fi

    # Some architecture's $(uname -m) output is different from the ARCH
    # parameter that needs to be passed to kbuild. Create symlinks from
    # $(uname -m) to the ARCH directory.
    if [ ! -e %rpm_install_dir/%kmp_target_cpu ]; then
        ln -sf %cpu_arch %rpm_install_dir/%kmp_target_cpu
        ln -sf %cpu_arch %buildroot/usr/src/linux-obj/%kmp_target_cpu
    fi

    # We were building in %my_builddir/linux-%srcversion, but the sources will
    # later be installed in /usr/src/linux-%srcversion-%source_rel. Fix up the
    # build symlink.
    rm -f %buildroot%kernel_module_directory/%kernelrelease-%build_flavor/{source,build}
    ln -s %src_install_dir \
	%buildroot%kernel_module_directory/%kernelrelease-%build_flavor/source
    ln -s %obj_install_dir/%cpu_arch/%build_flavor \
	%buildroot%kernel_module_directory/%kernelrelease-%build_flavor/build

    # Abort if there are any undefined symbols
    msg="$(/sbin/depmod -F %buildroot/boot/System.map-%kernelrelease-%build_flavor \
			-b %buildroot -ae %kernelrelease-%build_flavor 2>&1)"
    if [ $? -ne 0 ] || echo "$msg" | grep  'needs unknown symbol'; then
	exit 1
    fi

    %_sourcedir/split-modules -d %buildroot \
	-o %my_builddir \
	-b %kernel_build_dir \
%if "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y"
	-e \
%endif
%if ! %supported_modules_check
	-i \
%endif
	%nil
%if ! %split_extra
    cat %my_builddir/unsupported-modules >>%my_builddir/main-modules
%endif

    # The modules.dep file is sorted randomly which produces strange file
    # checksums. As the file is not included in the resulting RPM, it's
    # pointless to rely on its contents. Replacing by zeros to make the
    # checksums always the same for several builds of the same package.
    test -s %buildroot%kernel_module_directory/%kernelrelease-%build_flavor/modules.dep && \
    dd if=/dev/zero of=%buildroot%kernel_module_directory/%kernelrelease-%build_flavor/modules.dep ibs=$(stat -c%s %buildroot%kernel_module_directory/%kernelrelease-%build_flavor/modules.dep) count=1

    res=0
    if test -e %my_builddir/kabi/%cpu_arch/symvers-%build_flavor; then
        # check for kabi changes
        %_sourcedir/kabi.pl --rules %my_builddir/kabi/severities \
            %my_builddir/kabi/%cpu_arch/symvers-%build_flavor \
            Module.symvers || res=$?
    fi
    if [ $res -ne 0 ]; then
	# %ignore_kabi_badness is defined in the Kernel:* projects in the
	# OBS to be able to build the KOTD in spite of kabi errors
	if [ 0%{?ignore_kabi_badness} -eq 0 -a \
	     ! -e %my_builddir/kabi/%cpu_arch/ignore-%build_flavor -a \
	     ! -e %_sourcedir/IGNORE-KABI-BADNESS ]; then
	    echo "Create a file IGNORE-KABI-BADNESS in the kernel-source" \
		 "directory to build this kernel even though its badness is" \
		 "higher than allowed for an official kernel."
	   exit 1
	fi
    fi

    # Check the license in each module
    if ! sh %_sourcedir/check-module-license %buildroot; then
	echo "Please fix the missing licenses!"
%if "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y"
	exit 1
%endif
    fi

    # These files are required for building external modules
    for FILE in arch/powerpc/lib/crtsavres.o arch/arm64/kernel/ftrace-mod.o \
		arch/*/kernel/macros.s scripts/module.lds
    do
	    if [ -f %kernel_build_dir/$FILE ]; then
		echo $FILE >> %my_builddir/obj-files
	    fi
    done

    tar --exclude=\*.ipa-clones --exclude=.config.old --exclude=.kernel-binary.spec.buildenv \
        --exclude=.kernel_signing_key.pem --exclude=.kernel.genkey \
        -cf - -T %my_builddir/obj-files | \
	tar -xf - -C %rpm_install_dir/%cpu_arch_flavor
    # bnc#507084
    find %rpm_install_dir/%cpu_arch_flavor/scripts -type f -perm -111 | \
        while read f; do
            case "$(file -b "$f")" in
            ELF\ *\ executable*)
                strip "$f"
            esac
        done

    # Recreate the generated Makefile with correct path
    #
    # Linux 5.13 no longer has mkmakefile
    if [ -f ../scripts/mkmakefile ] ; then
        sh ../scripts/mkmakefile ../../../%{basename:%src_install_dir} \
            %rpm_install_dir/%cpu_arch_flavor \
            $(echo %srcversion | sed -r 's/^([0-9]+)\.([0-9]+).*/\1 \2/')
    else
       echo include ../../../%{basename:%src_install_dir}/Makefile > %rpm_install_dir/%cpu_arch_flavor/Makefile
    fi
fi

# CONFIG_GDB_SCRIPTS
if [ -e vmlinux-gdb.py ]; then
    DEST=%rpm_install_dir/%cpu_arch_flavor/
    install -m 755 -d "$DEST"
    # set sys.path to our devel.rpm scripts
    sed 's@\(sys\.path\.insert(0, \).*@\1"%obj_install_dir/%cpu_arch_flavor/scripts/gdb/")@' vmlinux-gdb.py > "$DEST/vmlinux-gdb.py"

    DEST=%rpm_install_dir/%cpu_arch_flavor/scripts/gdb/linux
    install -m 755 -d "$DEST"
    pushd scripts/gdb/linux/
    for file in *.py; do
	if test -L "$file"; then
	    # relink against our devel.rpm sources, not of buildroot's
	    ln -s "%src_install_dir/scripts/gdb/linux/$file" "$DEST/$file"
	else
	    cp -p "$file" "$DEST"
	fi
    done
    popd

    DEST=%{buildroot}%{_datadir}/gdb/auto-load%modules_dir
    install -m 755 -d "$DEST"
    ln -s %obj_install_dir/%cpu_arch_flavor/vmlinux-gdb.py "$DEST/vmlinux-gdb.py"
fi

rm -rf %{buildroot}/lib/firmware

add_dirs_to_filelist() {
    sed -rn '
        # print file name
        p
        # remove filelist macros
        s:%%[a-z]+(\([^)]+\))? ?::g
        # add %%dir prefix
        s:^:%%dir :
        # print all parents
        :a
            # skip directories owned by other packages
            s:^%%dir (/boot|/etc|(/usr)?/lib/(modules|firmware)|/usr/share|/usr/src)/[^/]+$::
            s:/[^/]+$::p
        ta
    ' "$@" | sort -u
}

# Collect the file lists.
if [ -f %my_builddir/livepatch-files.no_dir ] ; then
    cat %my_builddir/livepatch-files.no_dir | add_dirs_to_filelist > %my_builddir/livepatch-files
fi

# does not exist for non-modularized kernels
%if %{usrmerged}
        mkdir -p %{buildroot}%modules_dir
%endif
shopt -s nullglob dotglob
> %my_builddir/kernel-devel.files
{
    echo "%modules_dir/build"
    echo "%modules_dir/source"
    cd %buildroot
    for file in boot/symtypes*; do
%if %{usrmerged}
        l="${file##*/}"
        l="%modules_dir/${l//-%kernelrelease-%build_flavor}"
        mv "$file" "%{buildroot}$l"
        ln -s "..$l" $file
        echo "$l"
        echo "%%ghost /$file"
%else
        echo "/$file"
%endif
    done
    if test -d .%{_datadir}/gdb/; then
	find .%obj_install_dir/%cpu_arch_flavor/scripts/gdb/linux/ -name '*.py' -type l | sed -e 's/^[.]//'
	echo "%{_datadir}/gdb/auto-load%modules_dir/vmlinux-gdb.py"
    fi
} | add_dirs_to_filelist >%my_builddir/kernel-devel.files
( cd %buildroot ; find .%obj_install_dir/%cpu_arch_flavor -type f ; ) | \
sed -e 's/^[.]//' | grep -v -e '[.]ipa-clones$' -e '/Symbols[.]list$' -e '/ipa-clones[.]list$'| \
add_dirs_to_filelist >> %my_builddir/kernel-devel.files

{   echo %ghost /boot/%image
    echo %ghost /boot/initrd
    cd %buildroot
    for f in boot/*; do
        l="${f##*/}"
        l="%modules_dir/${l//-%kernelrelease-%build_flavor}"
        if test -L "$f"; then
            echo "%%ghost /$f"
            continue
        elif test ! -f "$f"; then
            continue
        fi
        case "$f" in
        boot/initrd-*)
            echo "%%ghost /$f"
            continue
            ;;
        boot/vmlinux-*.%{compress_vmlinux})
            ;;
        boot/vmlinux-*)
            if $ghost_vmlinux; then
                # fall through to mark next echo as %ghost
                echo -n "%%ghost "
            fi
            ;;
%if %{usrmerged}
        boot/vmlinuz-*)
            echo -n "%%attr(0644, root, root) "
            ;;
%endif
        boot/symtypes*)
%if %{usrmerged}
            echo "%exclude $l"
%endif
            continue
            ;;
        esac
%if %{usrmerged}
        mv "$f" "./$l"
        ln -s "..$l" $f
        # the find in the CONFIG_MODULES condition below also finds the files
        # but there's sort -u later, so this is ok
        echo "$l" # note: must be first after case statement above
        echo "%%ghost /$f"
%else
        echo "%%attr(0644, root, root) /$f"
%endif
    done

    if [ %CONFIG_MODULES = y ]; then
	MODULES=%{lua: print(rpm.expand('%kernel_module_directory'):sub(2))}/%kernelrelease-%build_flavor
	find "$MODULES" \
%if 0%{?separate_vdso}
	    -path "$MODULES/vdso" -prune -o \
%endif
	    -type d -o \
	    \( -path '*/modules.*' ! -path '*/modules.order' \
	     ! -path '*/modules.builtin' \
	     ! -path '*/modules.builtin.modinfo' \) -printf '%%%%ghost /%%p\n' \
	       -o -name '*.ko' -prune \
	       -o \( -type f \
%if %{usrmerged}
		! -path '*/symtypes*' ! -path '*/vmlinu*' \
%endif
		\) -printf '/%%p\n'
	cat %my_builddir/base-modules
    fi
    if test %CONFIG_MODULE_SIG = "y" -a -d etc/uefi/certs; then
        find etc/uefi/certs -type f -printf '/%%p\n'
    fi
    if test -d lib/firmware/%kernelrelease-%build_flavor; then
        echo "%%dir /lib/firmware/%kernelrelease-%build_flavor"
        cat %my_builddir/base-firmware
    fi
    if [ -e .%_docdir/%name ]; then
	echo "%%doc %_docdir/%name"
    fi
} | sort -u | add_dirs_to_filelist >%my_builddir/kernel-base.files

{
    add_dirs_to_filelist %my_builddir/kernel-base.files
    if [ %CONFIG_MODULES = y ]; then
        add_dirs_to_filelist %my_builddir/main-modules
    fi
    if test -d %buildroot/lib/firmware/%kernelrelease-%build_flavor; then
	echo "/lib/firmware/%kernelrelease-%build_flavor"
    fi
} > %my_builddir/kernel-main.files

%if %split_extra
    add_dirs_to_filelist %my_builddir/unsupported-modules > %my_builddir/kernel-extra.files
%if %split_extra && %split_optional
    add_dirs_to_filelist %my_builddir/optional-modules > %my_builddir/kernel-optional.files
%endif

%if 0%{?sle_version} >= 150000
    # By default, loading unsupported modules is disabled on SLE through
    # /etc/modprobe.d/10-unsupported-modules.conf from the suse-module-tools
    # package.
    # modules in kernel-$flavor-extra don't have the supported flag set,
    # yet loading them should be possible if the package is installed.
    # CAUTION PACKAGERS: The file content below must not change between
    # kernel versions, otherwise file conflicts might arise with
    # multiversion(kernel).

    modprobe_d_dir=/etc/modprobe.d
    %if 0%{?sle_version} > 150300
    modprobe_d_dir=/lib/modprobe.d
    %endif
    %if %{usrmerged}
    modprobe_d_dir=/usr/lib/modprobe.d
    %endif

    mkdir -p %buildroot$modprobe_d_dir
    cat >%buildroot$modprobe_d_dir/20-kernel-%{build_flavor}-extra.conf <<EOF
# This file overrides the default from 10-unsupported-modules.conf.
# This is necessary to load kernel modules from the
# kernel-%{build_flavor}-extra package.
#
# WARNING: loading unsupported modules may compromise SLE support.
# Please read the comments in 10-unsupported-modules.conf.
allow_unsupported_modules 1
EOF
    echo "%%dir $modprobe_d_dir" >> %my_builddir/kernel-extra.files
    echo "%%config(noreplace) $modprobe_d_dir/20-kernel-%{build_flavor}-extra.conf" >> %my_builddir/kernel-extra.files
%endif
%endif
for f in %my_builddir/*-kmp-modules; do
	f2=${f%%-modules}.files
	add_dirs_to_filelist "$f" >"$f2"
done

if [ %CONFIG_MODULES = y ]; then
  install -m 644 %_sourcedir/modules.fips %{buildroot}%modules_dir/modules.fips
  echo %modules_dir/modules.fips >> %my_builddir/kernel-base.files
  echo %modules_dir/modules.fips >> %my_builddir/kernel-main.files
fi

# Hardlink duplicate files automatically (from package fdupes): It doesn't save
# much, but it keeps rpmlint from breaking the package build. Note that we skip
# /usr/src/linux-obj intentionally, to not accidentally break timestamps there
%fdupes %buildroot%modules_dir

%changelog
* Mon Jul 29 2024 jslaby@suse.cz
- Update
  patches.suse/drm-qxl-Pin-buffer-objects-for-internal-mappings.patch
  (bsc#1228387).
  Fix the bsc #.
- commit 65a34e2
* Mon Jul 29 2024 jslaby@suse.cz
- drm/qxl: Pin buffer objects for internal mappings (bsc#1228388).
- commit 691f036
* Sun Jul 28 2024 jslaby@suse.cz
- Linux 6.10.2 (bsc#1012628).
- tap: add missing verification for short frame (bsc#1012628).
- tun: add missing verification for short frame (bsc#1012628).
- filelock: Fix fcntl/close race recovery compat path
  (bsc#1012628).
- ALSA: seq: ump: Skip useless ports for static blocks
  (bsc#1012628).
- ALSA: pcm_dmaengine: Don't synchronize DMA channel when DMA
  is paused (bsc#1012628).
- arm64: dts: qcom: sm6115: Disable SS instance in Parkmode for
  USB (bsc#1012628).
- arm64: dts: qcom: sdm845: Disable SS instance in Parkmode for
  USB (bsc#1012628).
- arm64: dts: qcom: ipq8074: Disable SS instance in Parkmode
  for USB (bsc#1012628).
- arm64: dts: qcom: sdm630: Disable SS instance in Parkmode for
  USB (bsc#1012628).
- arm64: dts: qcom: ipq6018: Disable SS instance in Parkmode
  for USB (bsc#1012628).
- arm64: dts: qcom: msm8998: Disable SS instance in Parkmode
  for USB (bsc#1012628).
- arm64: dts: qcom: sm6350: Disable SS instance in Parkmode for
  USB (bsc#1012628).
- arm64: dts: qcom: msm8996: Disable SS instance in Parkmode
  for USB (bsc#1012628).
- arm64: dts: qcom: x1e80100-crd: Fix USB PHYs regulators
  (bsc#1012628).
- arm64: dts: qcom: x1e80100-qcp: Fix the PHY regulator for PCIe
  6a (bsc#1012628).
- arm64: dts: qcom: x1e80100-crd: Fix the PHY regulator for PCIe
  6a (bsc#1012628).
- arm64: dts: qcom: qrb4210-rb2: switch I2C2 to i2c-gpio
  (bsc#1012628).
- arm64: dts: qcom: qrb2210-rb1: switch I2C2 to i2c-gpio
  (bsc#1012628).
- arm64: dts: qcom: x1e80100-qcp: Fix USB PHYs regulators
  (bsc#1012628).
- arm64: dts: qcom: sc7280: Disable SuperSpeed instances in park
  mode (bsc#1012628).
- arm64: dts: qcom: sc7180: Disable SuperSpeed instances in park
  mode (bsc#1012628).
- ALSA: hda/realtek: Fix the speaker output on Samsung Galaxy
  Book Pro 360 (bsc#1012628).
- ALSA: hda/realtek: Enable headset mic on Positivo SU C1400
  (bsc#1012628).
- ALSA: hda/tas2781: Add new quirk for Lenovo Hera2 Laptop
  (bsc#1012628).
- usb: gadget: midi2: Fix incorrect default MIDI2 protocol setup
  (bsc#1012628).
- fs/ntfs3: Validate ff offset (bsc#1012628).
- fs/ntfs3: Add a check for attr_names and oatbl (bsc#1012628).
- jfs: don't walk off the end of ealist (bsc#1012628).
- ocfs2: add bounds checking to ocfs2_check_dir_entry()
  (bsc#1012628).
- s390/mm: Fix VM_FAULT_HWPOISON handling in do_exception()
  (bsc#1012628).
- drm/amdgpu: Fix signedness bug in sdma_v4_0_process_trap_irq()
  (bsc#1012628).
- commit d3b5079
* Thu Jul 25 2024 jslaby@suse.cz
- Revert "rpm/kernel-obs-build.spec.in: drop algif_hash from KERNEL_MODULES (bsc#1226463)"
  This reverts commit c9c2e244cf9031882276be043b882ccf33835a4f. Openssl
  was fixed:
  https://build.opensuse.org/request/show/1189541
- commit 178f0b6
* Thu Jul 25 2024 jslaby@suse.cz
- drm/amd/display: Take Synaptics Cascaded Topology into Account
  (bsc#1228093 #3495).
- commit a4c3703
* Thu Jul 25 2024 jslaby@suse.cz
- Linux 6.10.1 (bsc#1012628).
- thermal: core: Allow thermal zones to tell the core to ignore
  them (bsc#1012628).
- io_uring: fix error pbuf checking (bsc#1012628).
- ASoC: cs35l56: Limit Speaker Volume to +12dB maximum
  (bsc#1012628).
- ASoC: cs35l56: Use header defines for Speaker Volume control
  definition (bsc#1012628).
- tpm: Use auth only after NULL check in
  tpm_buf_check_hmac_response() (bsc#1012628).
- cifs: Fix setting of zero_point after DIO write (bsc#1012628).
- cifs: Fix server re-repick on subrequest retry (bsc#1012628).
- cifs: fix noisy message on copy_file_range (bsc#1012628).
- cifs: Fix missing fscache invalidation (bsc#1012628).
- cifs: Fix missing error code set (bsc#1012628).
- ext4: use memtostr_pad() for s_volume_name (bsc#1012628).
- commit a57275a
* Thu Jul 18 2024 jslaby@suse.cz
- Revert "drm/amd/display: FEC overhead should be checked once
  for mst slot nums" (bsc#1228093 #3495).
- commit cee765e
* Mon Jul 15 2024 mkubecek@suse.cz
- update to 6.10 final
- refresh configs (headers only)
- commit b8b0277
* Thu Jul 11 2024 jslaby@suse.cz
- Linux 6.9.9 (bsc#1012628).
- selftests/resctrl: Fix non-contiguous CBM for AMD (bsc#1012628).
- locking/mutex: Introduce devm_mutex_init() (bsc#1012628).
- leds: mlxreg: Use devm_mutex_init() for mutex initialization
  (bsc#1012628).
- leds: an30259a: Use devm_mutex_init() for mutex initialization
  (bsc#1012628).
- crypto: hisilicon/debugfs - Fix debugfs uninit process issue
  (bsc#1012628).
- drm/lima: fix shared irq handling on driver remove
  (bsc#1012628).
- powerpc: Avoid nmi_enter/nmi_exit in real mode interrupt
  (bsc#1012628).
- media: dvb: as102-fe: Fix as10x_register_addr packing
  (bsc#1012628).
- media: dvb-usb: dib0700_devices: Add missing release_firmware()
  (bsc#1012628).
- net: dql: Avoid calling BUG() when WARN() is enough
  (bsc#1012628).
- wifi: rtw89: fw: scan offload prohibit all 6 GHz channel if
  no 6 GHz sband (bsc#1012628).
- drm/xe: Add outer runtime_pm protection to
  xe_live_ktest@xe_dma_buf (bsc#1012628).
- IB/core: Implement a limit on UMAD receive List (bsc#1012628).
- scsi: qedf: Make qedf_execute_tmf() non-preemptible
  (bsc#1012628).
- bpf: mark bpf_dummy_struct_ops.test_1 parameter as nullable
  (bsc#1012628).
- selftests/bpf: adjust dummy_st_ops_success to detect additional
  error (bsc#1012628).
- selftests/bpf: do not pass NULL for non-nullable params in
  dummy_st_ops (bsc#1012628).
- bpf: check bpf_dummy_struct_ops program params for test runs
  (bsc#1012628).
- selftests/bpf: dummy_st_ops should reject 0 for non-nullable
  params (bsc#1012628).
- RISC-V: KVM: Fix the initial sample period value (bsc#1012628).
- crypto: aead,cipher - zeroize key buffer after use
  (bsc#1012628).
- media: mediatek: vcodec: Only free buffer VA that is not NULL
  (bsc#1012628).
- drm/amdgpu: Fix uninitialized variable warnings (bsc#1012628).
- drm/amdgpu: Using uninitialized value *size when calling
  amdgpu_vce_cs_reloc (bsc#1012628).
- drm/amdgpu: Initialize timestamp for some legacy SOCs
  (bsc#1012628).
- drm/amdgpu: fix double free err_addr pointer warnings
  (bsc#1012628).
- drm/amd/display: Add NULL pointer check for kzalloc
  (bsc#1012628).
- drm/amd/display: Check index msg_id before read or write
  (bsc#1012628).
- drm/amd/display: Check pipe offset before setting vblank
  (bsc#1012628).
- drm/amd/display: Skip finding free audio for unknown engine_id
  (bsc#1012628).
- drm/amd/display: Fix overlapping copy within
  dml_core_mode_programming (bsc#1012628).
- drm/amd/display: update pipe topology log to support subvp
  (bsc#1012628).
- drm/amd/display: Do not return negative stream id for array
  (bsc#1012628).
- drm/amd/display: ASSERT when failing to find index by
  plane/stream id (bsc#1012628).
- drm/amd/display: Fix uninitialized variables in DM
  (bsc#1012628).
- drm/amdgpu: fix uninitialized scalar variable warning
  (bsc#1012628).
- drm/amdgpu: fix the warning about the expression (int)size -
  len (bsc#1012628).
- media: dw2102: Don't translate i2c read into write
  (bsc#1012628).
- riscv: Apply SiFive CIP-1200 workaround to single-ASID
  sfence.vma (bsc#1012628).
- media: dw2102: fix a potential buffer overflow (bsc#1012628).
- sctp: prefer struct_size over open coded arithmetic
  (bsc#1012628).
- firmware: dmi: Stop decoding on broken entry (bsc#1012628).
- kunit/fortify: Do not spam logs with fortify WARNs
  (bsc#1012628).
- Input: ff-core - prefer struct_size over open coded arithmetic
  (bsc#1012628).
- usb: xhci: prevent potential failure in handle_tx_event()
  for Transfer events without TRB (bsc#1012628).
- wifi: mt76: replace skb_put with skb_put_zero (bsc#1012628).
- wifi: mt76: mt7996: add sanity checks for background radar
  trigger (bsc#1012628).
- thermal/drivers/mediatek/lvts_thermal: Check NULL ptr on
  lvts_data (bsc#1012628).
- net: dsa: mv88e6xxx: Correct check for empty list (bsc#1012628).
- media: dvb-frontends: tda18271c2dd: Remove casting during div
  (bsc#1012628).
- media: s2255: Use refcount_t instead of atomic_t for
  num_channels (bsc#1012628).
- media: i2c: st-mipid02: Use the correct div function
  (bsc#1012628).
- media: tc358746: Use the correct div_ function (bsc#1012628).
- media: dvb-frontends: tda10048: Fix integer overflow
  (bsc#1012628).
- crypto: hisilicon/sec2 - fix for register offset (bsc#1012628).
- gve: Account for stopped queues when reading NIC stats
  (bsc#1012628).
- i2c: i801: Annotate apanel_addr as __ro_after_init
  (bsc#1012628).
- powerpc/64: Set _IO_BASE to POISON_POINTER_DELTA not 0 for
  CONFIG_PCI=n (bsc#1012628).
- orangefs: fix out-of-bounds fsid access (bsc#1012628).
- kunit: Fix timeout message (bsc#1012628).
- powerpc/xmon: Check cpu id in commands "c#", "dp#" and "dx#"
  (bsc#1012628).
- selftests/net: fix uninitialized variables (bsc#1012628).
- igc: fix a log entry using uninitialized netdev (bsc#1012628).
- bpf: Avoid uninitialized value in BPF_CORE_READ_BITFIELD
  (bsc#1012628).
- f2fs: check validation of fault attrs in f2fs_build_fault_attr()
  (bsc#1012628).
- scsi: mpi3mr: Sanitise num_phys (bsc#1012628).
- serial: imx: Raise TX trigger level to 8 (bsc#1012628).
- jffs2: Fix potential illegal address access in jffs2_free_inode
  (bsc#1012628).
- s390: Mark psw in __load_psw_mask() as __unitialized
  (bsc#1012628).
- s390/pkey: Use kfree_sensitive() to fix Coccinelle warnings
  (bsc#1012628).
- s390/pkey: Wipe sensitive data on failure (bsc#1012628).
- s390/pkey: Wipe copies of clear-key structures on failure
  (bsc#1012628).
- s390/pkey: Wipe copies of protected- and secure-keys
  (bsc#1012628).
- btrfs: scrub: initialize ret in scrub_simple_mirror() to fix
  compilation warning (bsc#1012628).
- cdrom: rearrange last_media_change check to avoid unintentional
  overflow (bsc#1012628).
- tools/power turbostat: Remember global max_die_id (bsc#1012628).
- tools/power turbostat: Avoid possible memory corruption due
  to sparse topology IDs (bsc#1012628).
- vhost: Use virtqueue mutex for swapping worker (bsc#1012628).
- vhost: Release worker mutex during flushes (bsc#1012628).
- vhost_task: Handle SIGKILL by flushing work and exiting
  (bsc#1012628).
- virtio-pci: Check if is_avq is NULL (bsc#1012628).
- mac802154: fix time calculation in
  ieee802154_configure_durations() (bsc#1012628).
- wifi: cfg80211: restrict NL80211_ATTR_TXQ_QUANTUM values
  (bsc#1012628).
- net: phy: phy_device: Fix PHY LED blinking code comment
  (bsc#1012628).
- wifi: mac80211: fix BSS_CHANGED_UNSOL_BCAST_PROBE_RESP
  (bsc#1012628).
- UPSTREAM: tcp: fix DSACK undo in fast recovery to call
  tcp_try_to_open() (bsc#1012628).
- net/mlx5: E-switch, Create ingress ACL when needed
  (bsc#1012628).
- net/mlx5e: Add mqprio_rl cleanup and free in
  mlx5e_priv_cleanup() (bsc#1012628).
- net/mlx5e: Present succeeded IPsec SA bytes and packet
  (bsc#1012628).
- net/mlx5e: Approximate IPsec per-SA payload data bytes count
  (bsc#1012628).
- Bluetooth: hci_event: Fix setting of unicast qos interval
  (bsc#1012628).
- Bluetooth: Ignore too large handle values in BIG (bsc#1012628).
- Bluetooth: ISO: Check socket flag instead of hcon (bsc#1012628).
- bluetooth/hci: disallow setting handle bigger than
  HCI_CONN_HANDLE_MAX (bsc#1012628).
- tcp_metrics: validate source addr length (bsc#1012628).
- KVM: s390: fix LPSWEY handling (bsc#1012628).
- e1000e: Fix S0ix residency on corporate systems (bsc#1012628).
- gpiolib: of: fix lookup quirk for MIPS Lantiq (bsc#1012628).
- net: allow skb_datagram_iter to be called from any context
  (bsc#1012628).
- net: txgbe: initialize num_q_vectors for MSI/INTx interrupts
  (bsc#1012628).
- net: txgbe: remove separate irq request for MSI and INTx
  (bsc#1012628).
- net: txgbe: add extra handle for MSI/INTx into thread irq handle
  (bsc#1012628).
- net: txgbe: free isb resources at the right time (bsc#1012628).
- btrfs: always do the basic checks for btrfs_qgroup_inherit
  structure (bsc#1012628).
- net: phy: aquantia: add missing include guards (bsc#1012628).
- net: ntb_netdev: Move ntb_netdev_rx_handler() to call netif_rx()
  from __netif_rx() (bsc#1012628).
- drm/fbdev-generic: Fix framebuffer on big endian devices
  (bsc#1012628).
- net: stmmac: enable HW-accelerated VLAN stripping for gmac4 only
  (bsc#1012628).
- s390/vfio_ccw: Fix target addresses of TIC CCWs (bsc#1012628).
- gpio: mmio: do not calculate bgpio_bits via "ngpios"
  (bsc#1012628).
- wifi: wilc1000: fix ies_len type in connect path (bsc#1012628).
- riscv: kexec: Avoid deadlock in kexec crash path (bsc#1012628).
- netfilter: nf_tables: unconditionally flush pending work before
  notifier (bsc#1012628).
- net: rswitch: Avoid use-after-free in rswitch_poll()
  (bsc#1012628).
- bonding: Fix out-of-bounds read in
  bond_option_arp_ip_targets_set() (bsc#1012628).
- ice: Fix improper extts handling (bsc#1012628).
- ice: Don't process extts if PTP is disabled (bsc#1012628).
- ice: Reject pin requests with unsupported flags (bsc#1012628).
- ice: use proper macro for testing bit (bsc#1012628).
- selftests: fix OOM in msg_zerocopy selftest (bsc#1012628).
- selftests: make order checking verbose in msg_zerocopy selftest
  (bsc#1012628).
- drm/xe/mcr: Avoid clobbering DSS steering (bsc#1012628).
- tcp: Don't flag tcp_sk(sk)->rx_opt.saw_unknown for TCP AO
  (bsc#1012628).
- inet_diag: Initialize pad field in struct inet_diag_req_v2
  (bsc#1012628).
- mlxsw: core_linecards: Fix double memory deallocation in case
  of invalid INI file (bsc#1012628).
- bnxt_en: Fix the resource check condition for RSS contexts
  (bsc#1012628).
- gpiolib: of: add polarity quirk for TSC2005 (bsc#1012628).
- platform/x86: toshiba_acpi: Fix quickstart quirk handling
  (bsc#1012628).
- Revert "igc: fix a log entry using uninitialized netdev"
  (bsc#1012628).
- nilfs2: fix inode number range checks (bsc#1012628).
- nilfs2: add missing check for inode numbers on directory entries
  (bsc#1012628).
- nilfs2: fix incorrect inode allocation from reserved inodes
  (bsc#1012628).
- mm: optimize the redundant loop of mm_update_owner_next()
  (bsc#1012628).
- mm: avoid overflows in dirty throttling logic (bsc#1012628).
- btrfs: zoned: fix calc_available_free_space() for zoned mode
  (bsc#1012628).
- btrfs: fix adding block group to a reclaim list and the unused
  list during reclaim (bsc#1012628).
- btrfs: fix folio refcount in __alloc_dummy_extent_buffer()
  (bsc#1012628).
- f2fs: Add inline to f2fs_build_fault_attr() stub (bsc#1012628).
- scsi: mpi3mr: Use proper format specifier in
  mpi3mr_sas_port_add() (bsc#1012628).
- Bluetooth: hci_bcm4377: Fix msgid release (bsc#1012628).
- Bluetooth: Add quirk to ignore reserved PHY bits in LE Extended
  Adv Report (bsc#1012628).
- Bluetooth: qca: Fix BT enable failure again for QCA6390 after
  warm reboot (bsc#1012628).
- can: kvaser_usb: Explicitly initialize family in leafimx
  driver_info struct (bsc#1012628).
- fsnotify: Do not generate events for O_PATH file descriptors
  (bsc#1012628).
- Revert "mm/writeback: fix possible divide-by-zero in
  wb_dirty_limits(), again" (bsc#1012628).
- drm/xe: fix error handling in xe_migrate_update_pgtables
  (bsc#1012628).
- drm/ttm: Always take the bo delayed cleanup path for imported
  bos (bsc#1012628).
- drm/nouveau: fix null pointer dereference in
  nouveau_connector_get_modes (bsc#1012628).
- drm/amdgpu/atomfirmware: silence UBSAN warning (bsc#1012628).
- drm: panel-orientation-quirks: Add quirk for Valve Galileo
  (bsc#1012628).
- clk: qcom: gcc-ipq9574: Add BRANCH_HALT_VOTED flag
  (bsc#1012628).
- clk: sunxi-ng: common: Don't call hw_to_ccu_common on hw
  without common (bsc#1012628).
- powerpc/pseries: Fix scv instruction crash with kexec
  (bsc#1012628).
- powerpc/64s: Fix unnecessary copy to 0 when kernel is booted
  at address 0 (bsc#1012628).
- firmware: sysfb: Fix reference count of sysfb parent device
  (bsc#1012628).
- filelock: Remove locks reliably when fcntl/close race is
  detected (bsc#1012628).
- mtd: rawnand: Ensure ECC configuration is propagated to upper
  layers (bsc#1012628).
- mtd: rawnand: Fix the nand_read_data_op() early check
  (bsc#1012628).
- mtd: rawnand: Bypass a couple of sanity checks during NAND
  identification (bsc#1012628).
- mtd: rawnand: rockchip: ensure NVDDR timings are rejected
  (bsc#1012628).
- fs: don't misleadingly warn during thaw operations
  (bsc#1012628).
- net: stmmac: dwmac-qcom-ethqos: fix error array size
  (bsc#1012628).
- bnx2x: Fix multiple UBSAN array-index-out-of-bounds
  (bsc#1012628).
- s390/dasd: Fix invalid dereferencing of indirect CCW data
  pointer (bsc#1012628).
- selftests/harness: Fix tests timeout and race condition
  (bsc#1012628).
- arm64: dts: rockchip: Fix the DCDC_REG2 minimum voltage on
  Quartz64 Model B (bsc#1012628).
- clk: qcom: gcc-sm6350: Fix gpll6* & gpll7 parents (bsc#1012628).
- clk: qcom: clk-alpha-pll: set ALPHA_EN bit for Stromer Plus PLLs
  (bsc#1012628).
- clk: mediatek: mt8183: Only enable runtime PM on mt8183-mfgcfg
  (bsc#1012628).
- i2c: pnx: Fix potential deadlock warning from del_timer_sync()
  call in isr (bsc#1012628).
- fs/ntfs3: Mark volume as dirty if xattr is broken (bsc#1012628).
- drm/amdkfd: Let VRAM allocations go to GTT domain on small APUs
  (bsc#1012628).
- ALSA: hda/realtek: Enable headset mic of JP-IK LEAP W502 with
  ALC897 (bsc#1012628).
- vhost-scsi: Handle vhost_vq_work_queue failures for events
  (bsc#1012628).
- nvme-multipath: find NUMA path only for online numa-node
  (bsc#1012628).
- dma-mapping: benchmark: avoid needless copy_to_user if benchmark
  fails (bsc#1012628).
- drm/amdgpu: correct hbm field in boot status (bsc#1012628).
- connector: Fix invalid conversion in cn_proc.h (bsc#1012628).
- swap: yield device immediately (bsc#1012628).
- nvme: adjust multiples of NVME_CTRL_PAGE_SIZE in offset
  (bsc#1012628).
- libbpf: detect broken PID filtering logic for multi-uprobe
  (bsc#1012628).
- regmap-i2c: Subtract reg size from max_write (bsc#1012628).
- platform/x86: touchscreen_dmi: Add info for GlobalSpace SolT
  IVW 11.6" tablet (bsc#1012628).
- platform/x86: touchscreen_dmi: Add info for the EZpad 6s Pro
  (bsc#1012628).
- block: check for max_hw_sectors underflow (bsc#1012628).
- nvmet: fix a possible leak when destroy a ctrl during qp
  establishment (bsc#1012628).
- kbuild: fix short log for AS in link-vmlinux.sh (bsc#1012628).
- nfc/nci: Add the inconsistency check between the input data
  length and count (bsc#1012628).
- spi: cadence: Ensure data lines set to low during dummy-cycle
  period (bsc#1012628).
- ALSA: ump: Set default protocol when not given explicitly
  (bsc#1012628).
- drm/amdgpu: silence UBSAN warning (bsc#1012628).
- hwmon: (dell-smm) Add Dell G15 5511 to fan control whitelist
  (bsc#1012628).
- null_blk: Do not allow runt zone with zone capacity smaller
  then zone size (bsc#1012628).
- libbpf: don't close(-1) in multi-uprobe feature detector
  (bsc#1012628).
- Refresh
  patches.suse/drivers-firmware-skip-simpledrm-if-nvidia-drm.modese.patch.
- commit 8c0f797
* Wed Jul 10 2024 mkubecek@suse.cz
- config: update arm configs
- arm64 and armv7hl
  - DRM_MSM_VALIDATE_XML=n ("unsure")
- commit 92abc10
* Tue Jul  9 2024 msuchanek@suse.de
- kernel-binary: vdso: Own module_dir
- commit ff69986
* Tue Jul  9 2024 svarbanov@suse.de
- config: update and reenable armv6hl configs
  Option values mirrored from armv7hl
- commit c5191d9
* Tue Jul  9 2024 svarbanov@suse.de
- config: update and reenable armv7hl configs
  Option values from arm64 and x86.
- commit 3e8ca13
* Mon Jul  8 2024 svarbanov@suse.de
- config: update and reenable arm64 configs
  Options mirrored from x86_64, except:
  +CONFIG_SCHED_HW_PRESSURE=y
  +CONFIG_ARCH_AIROHA=y
  +CONFIG_ARM64_WORKAROUND_SPECULATIVE_SSBS=y
  +CONFIG_ARM64_ERRATUM_3194386=y
  +CONFIG_ARM64_ERRATUM_3312417=y
  +CONFIG_ARCH_WANTS_EXECMEM_LATE=y
  +CONFIG_STM32_FIREWALL=y
  +CONFIG_SPI_AIROHA_SNFI=m
  +CONFIG_PINCTRL_SCMI=m
  +CONFIG_GPIO_SWNODE_UNDEFINED=y
  +CONFIG_GPIO_EN7523=m
  +CONFIG_REGULATOR_SUN20I=m
  +CONFIG_VIDEO_BCM2835_UNICAM=m
  +CONFIG_DRM_DISPLAY_DP_AUX_BUS=m
  +CONFIG_DRM_PANEL_LG_SW43408=m
  +CONFIG_DRM_PANEL_RAYDIUM_RM69380=m
  +CONFIG_DRM_PANEL_SAMSUNG_S6E3FA7=m
  +CONFIG_DRM_PANTHOR=m
  +CONFIG_SND_SOC_MT8186_MT6366=m
  +CONFIG_SND_SOC_RK3308=m
  +CONFIG_USB_ONBOARD_DEV=m
  +CONFIG_ARM64_PLATFORM_DEVICES=y
  +CONFIG_EC_ACER_ASPIRE1=m
  +CONFIG_COMMON_CLK_EN7523=y
  +CONFIG_CLK_IMX95_BLK_CTL=m
  +CONFIG_COMMON_CLK_MESON_VCLK=y
  +CONFIG_COMMON_CLK_STM32MP257=y
  +CONFIG_ARM_MHU_V3=m
  +CONFIG_ARCH_R9A09G057=y
  +CONFIG_AD7173=m
  +CONFIG_AD7944=m
  +CONFIG_AD9739A=m
  +CONFIG_ADI_AXI_DAC=m
  +CONFIG_APDS9306=m
  +CONFIG_STM32_EXTI=y
  +CONFIG_PHY_FSL_SAMSUNG_HDMI_PHY=m
  +CONFIG_PHY_ROCKCHIP_USBDP=m
  +CONFIG_ARM_TSTEE=m
  +CONFIG_TRUSTED_KEYS_DCP=y
  +CONFIG_CRYPTO_DEV_TEGRA=m
- commit aacb786
* Mon Jul  8 2024 mkubecek@suse.cz
- update to 6.10-rc7
- refresh
  - patches.suse/drivers-firmware-skip-simpledrm-if-nvidia-drm.modese.patch
- commit 45f4681
* Sun Jul  7 2024 jslaby@suse.cz
- Linux 6.9.8 (bsc#1012628).
- usb: typec: ucsi: Never send a lone connector change ack
  (bsc#1012628).
- usb: typec: ucsi: Ack also failed Get Error commands
  (bsc#1012628).
- pinctrl: renesas: rzg2l: Use
  spin_{lock,unlock}_irq{save,restore} (bsc#1012628).
- Input: ili210x - fix ili251x_read_touch_data() return value
  (bsc#1012628).
- pinctrl: fix deadlock in create_pinctrl() when handling
  - EPROBE_DEFER (bsc#1012628).
- pinctrl: rockchip: fix pinmux bits for RK3328 GPIO2-B pins
  (bsc#1012628).
- pinctrl: rockchip: fix pinmux bits for RK3328 GPIO3-B pins
  (bsc#1012628).
- pinctrl: rockchip: use dedicated pinctrl type for RK3328
  (bsc#1012628).
- pinctrl: rockchip: fix pinmux reset in rockchip_pmx_set
  (bsc#1012628).
- MIPS: pci: lantiq: restore reset gpio polarity (bsc#1012628).
- pwm: stm32: Improve precision of calculation in .apply()
  (bsc#1012628).
- pwm: stm32: Fix for settings using period > UINT32_MAX
  (bsc#1012628).
- pwm: stm32: Calculate prescaler with a division instead of a
  loop (bsc#1012628).
- pwm: stm32: Refuse too small period requests (bsc#1012628).
- ASoC: cs42l43: Increase default type detect time and button
  delay (bsc#1012628).
- ASoC: rockchip: i2s-tdm: Fix trcm mode by setting clock on
  right mclk (bsc#1012628).
- ASoC: mediatek: mt8183-da7219-max98357: Fix kcontrol name
  collision (bsc#1012628).
- ASoC: atmel: atmel-classd: Re-add dai_link->platform to fix
  card init (bsc#1012628).
- workqueue: Increase worker desc's length to 32 (bsc#1012628).
- ASoC: q6apm-lpass-dai: close graph on prepare errors
  (bsc#1012628).
- bpf: Add missed var_off setting in set_sext32_default_val()
  (bsc#1012628).
- bpf: Add missed var_off setting in coerce_subreg_to_size_sx()
  (bsc#1012628).
- s390/pci: Add missing virt_to_phys() for directed DIBV
  (bsc#1012628).
- s390/virtio_ccw: Fix config change notifications (bsc#1012628).
- bpf: Fix remap of arena (bsc#1012628).
- ASoC: amd: acp: add a null check for chip_pdev structure
  (bsc#1012628).
- ASoC: amd: acp: remove i2s configuration check in
  acp_i2s_probe() (bsc#1012628).
- ASoC: amd: acp: move chip->flag variable assignment
  (bsc#1012628).
- ASoC: fsl-asoc-card: set priv->pdev before using it
  (bsc#1012628).
- net: dsa: microchip: fix initial port flush problem
  (bsc#1012628).
- openvswitch: get related ct labels from its master if it is
  not confirmed (bsc#1012628).
- bonding: fix incorrect software timestamping report
  (bsc#1012628).
- ionic: fix kernel panic due to multi-buffer handling
  (bsc#1012628).
- mlxsw: pci: Fix driver initialization with Spectrum-4
  (bsc#1012628).
- mlxsw: spectrum_buffers: Fix memory corruptions on Spectrum-4
  systems (bsc#1012628).
- bpf: Fix the corner case with may_goto and jump to the 1st insn
  (bsc#1012628).
- bpf: Fix overrunning reservations in ringbuf (bsc#1012628).
- vxlan: Pull inner IP header in vxlan_xmit_one() (bsc#1012628).
- ibmvnic: Free any outstanding tx skbs during scrq reset
  (bsc#1012628).
- net: phy: micrel: add Microchip KSZ 9477 to the device table
  (bsc#1012628).
- net: dsa: microchip: use collision based back pressure mode
  (bsc#1012628).
- ice: Rebuild TC queues on VSI queue reconfiguration
  (bsc#1012628).
- bpf: Fix may_goto with negative offset (bsc#1012628).
- xdp: Remove WARN() from __xdp_reg_mem_model() (bsc#1012628).
- ASoC: mediatek: mt8195: Add platform entry for ETDM1_OUT_BE
  dai link (bsc#1012628).
- btrfs: use NOFS context when getting inodes during logging
  and log replay (bsc#1012628).
- Fix race for duplicate reqsk on identical SYN (bsc#1012628).
- ALSA: seq: Fix missing channel at encoding RPN/NRPN MIDI2
  messages (bsc#1012628).
- net: dsa: microchip: fix wrong register write when masking
  interrupt (bsc#1012628).
- sparc: fix old compat_sys_select() (bsc#1012628).
- sparc: fix compat recv/recvfrom syscalls (bsc#1012628).
- parisc: use correct compat recv/recvfrom syscalls (bsc#1012628).
- powerpc: restore some missing spu syscalls (bsc#1012628).
- ionic: use dev_consume_skb_any outside of napi (bsc#1012628).
- ALSA: seq: Fix missing MSB in MIDI2 SPP conversion
  (bsc#1012628).
- netfilter: nf_tables: fully validate NFT_DATA_VALUE on store
  to data registers (bsc#1012628).
- af_unix: Stop recv(MSG_PEEK) at consumed OOB skb (bsc#1012628).
- af_unix: Don't stop recv(MSG_DONTWAIT) if consumed OOB skb is
  at the head (bsc#1012628).
- af_unix: Don't stop recv() at consumed ex-OOB skb (bsc#1012628).
- af_unix: Fix wrong ioctl(SIOCATMARK) when consumed OOB skb is
  at the head (bsc#1012628).
- net: mana: Fix possible double free in error handling path
  (bsc#1012628).
- bpf: Take return from set_memory_ro() into account with
  bpf_prog_lock_ro() (bsc#1012628).
- bpf: Take return from set_memory_rox() into account with
  bpf_jit_binary_lock_ro() (bsc#1012628).
- drm/panel: ilitek-ili9881c: Fix warning with GPIO controllers
  that sleep (bsc#1012628).
- drm/xe: Fix potential integer overflow in page size calculation
  (bsc#1012628).
- vduse: validate block features only with block devices
  (bsc#1012628).
- vduse: Temporarily fail if control queue feature requested
  (bsc#1012628).
- x86/fpu: Fix AMD X86_BUG_FXSAVE_LEAK fixup (bsc#1012628).
- drm/xe: Add a NULL check in xe_ttm_stolen_mgr_init
  (bsc#1012628).
- drm/amd/display: correct hostvm flag (bsc#1012628).
- mtd: partitions: redboot: Added conversion of operands to a
  larger type (bsc#1012628).
- wifi: ieee80211: check for NULL in ieee80211_mle_size_ok()
  (bsc#1012628).
- drm/amd/display: Skip pipe if the pipe idx not set properly
  (bsc#1012628).
- bpf: Add a check for struct bpf_fib_lookup size (bsc#1012628).
- bpf: Mark bpf prog stack with kmsan_unposion_memory in
  interpreter mode (bsc#1012628).
- drm/xe/xe_devcoredump: Check NULL before assignments
  (bsc#1012628).
- RDMA/restrack: Fix potential invalid address access
  (bsc#1012628).
- net/iucv: Avoid explicit cpumask var allocation on stack
  (bsc#1012628).
- net/dpaa2: Avoid explicit cpumask var allocation on stack
  (bsc#1012628).
- wifi: rtw89: download firmware with five times retry
  (bsc#1012628).
- crypto: ecdh - explicitly zeroize private_key (bsc#1012628).
- ALSA: emux: improve patch ioctl data validation (bsc#1012628).
- media: dvbdev: Initialize sbuf (bsc#1012628).
- irqchip/loongson: Select GENERIC_IRQ_EFFECTIVE_AFF_MASK if
  SMP for IRQ_LOONGARCH_CPU (bsc#1012628).
- iommu/arm-smmu-v3: Do not allow a SVA domain to be set on the
  wrong PASID (bsc#1012628).
- soc: ti: wkup_m3_ipc: Send NULL dummy message instead of
  pointer message (bsc#1012628).
- gfs2: Fix NULL pointer dereference in gfs2_log_flush
  (bsc#1012628).
- evm: Enforce signatures on unsupported filesystem for
  EVM_INIT_X509 (bsc#1012628).
- drm/radeon/radeon_display: Decrease the size of allocated memory
  (bsc#1012628).
- drm/xe: Check pat.ops before dumping PAT settings (bsc#1012628).
- nvmet: do not return 'reserved' for empty TSAS values
  (bsc#1012628).
- nvme: fixup comment for nvme RDMA Provider Type (bsc#1012628).
- nvmet: make 'tsas' attribute idempotent for RDMA (bsc#1012628).
- drm/panel: simple: Add missing display timing flags for KOE
  TX26D202VM0BWA (bsc#1012628).
- gpio: davinci: Validate the obtained number of IRQs
  (bsc#1012628).
- arm64: Clear the initial ID map correctly before remapping
  (bsc#1012628).
- nfsd: initialise nfsd_info.mutex early (bsc#1012628).
- RISC-V: fix vector insn load/store width mask (bsc#1012628).
- drm/amdgpu: Fix pci state save during mode-1 reset
  (bsc#1012628).
- riscv: stacktrace: convert arch_stack_walk() to noinstr
  (bsc#1012628).
- iommu/amd: Introduce per device DTE update function
  (bsc#1012628).
- iommu/amd: Invalidate cache before removing device from domain
  list (bsc#1012628).
- iommu/amd: Fix GT feature enablement again (bsc#1012628).
- gpiolib: cdev: Disallow reconfiguration without direction
  (uAPI v1) (bsc#1012628).
- gpiolib: cdev: Ignore reconfiguration without direction
  (bsc#1012628).
- tools/power turbostat: option '-n' is ambiguous (bsc#1012628).
- randomize_kstack: Remove non-functional per-arch entropy
  filtering (bsc#1012628).
- x86: stop playing stack games in profile_pc() (bsc#1012628).
- parisc: use generic sys_fanotify_mark implementation
  (bsc#1012628).
- Revert "MIPS: pci: lantiq: restore reset gpio polarity"
  (bsc#1012628).
- pinctrl: qcom: spmi-gpio: drop broken pm8008 support
  (bsc#1012628).
- ocfs2: fix DIO failure due to insufficient transaction credits
  (bsc#1012628).
- nfs: drop the incorrect assertion in nfs_swap_rw()
  (bsc#1012628).
- kasan: fix bad call to unpoison_slab_object (bsc#1012628).
- mm: fix incorrect vbq reference in purge_fragmented_block
  (bsc#1012628).
- mm/memory: don't require head page for do_set_pmd()
  (bsc#1012628).
- Revert "mmc: moxart-mmc: Use sg_miter for PIO" (bsc#1012628).
- mmc: sdhci-pci-o2micro: Convert PCIBIOS_* return codes to errnos
  (bsc#1012628).
- mmc: sdhci-brcmstb: check R1_STATUS for erase/trim/discard
  (bsc#1012628).
- mmc: sdhci-pci: Convert PCIBIOS_* return codes to errnos
  (bsc#1012628).
- mmc: sdhci: Do not invert write-protect twice (bsc#1012628).
- mmc: sdhci: Do not lock spinlock around mmc_gpio_get_ro()
  (bsc#1012628).
- iio: xilinx-ams: Don't include ams_ctrl_channels in scan_mask
  (bsc#1012628).
- SUNRPC: Fix backchannel reply, again (bsc#1012628).
- counter: ti-eqep: enable clock at probe (bsc#1012628).
- kbuild: doc: Update default INSTALL_MOD_DIR from extra to
  updates (bsc#1012628).
- kbuild: Fix build target deb-pkg: ln: failed to create hard link
  (bsc#1012628).
- kbuild: rpm-pkg: fix build error with CONFIG_MODULES=n
  (bsc#1012628).
- i2c: testunit: don't erase registers after STOP (bsc#1012628).
- i2c: testunit: discard write requests while old command is
  running (bsc#1012628).
- ata: libata-core: Fix null pointer dereference on error
  (bsc#1012628).
- ata,scsi: libata-core: Do not leak memory for ata_port struct
  members (bsc#1012628).
- iio: humidity: hdc3020: fix hysteresis representation
  (bsc#1012628).
- iio: adc: ad7266: Fix variable checking bug (bsc#1012628).
- iio: accel: fxls8962af: select IIO_BUFFER & IIO_KFIFO_BUF
  (bsc#1012628).
- iio: chemical: bme680: Fix pressure value output (bsc#1012628).
- iio: chemical: bme680: Fix calibration data variable
  (bsc#1012628).
- iio: chemical: bme680: Fix overflows in compensate() functions
  (bsc#1012628).
- iio: chemical: bme680: Fix sensor data read operation
  (bsc#1012628).
- net: usb: ax88179_178a: improve link status logs (bsc#1012628).
- usb: gadget: printer: SS+ support (bsc#1012628).
- usb: gadget: printer: fix races against disable (bsc#1012628).
- usb: musb: da8xx: fix a resource leak in probe() (bsc#1012628).
- usb: atm: cxacru: fix endpoint checking in cxacru_bind()
  (bsc#1012628).
- usb: dwc3: core: remove lock of otg mode during gadget
  suspend/resume to avoid deadlock (bsc#1012628).
- usb: gadget: aspeed_udc: fix device address configuration
  (bsc#1012628).
- usb: typec: ucsi: glink: fix child node release in probe
  function (bsc#1012628).
- Revert "usb: gadget: u_ether: Re-attach netif device to mirror
  detachment" (bsc#1012628).
- Revert "usb: gadget: u_ether: Replace netif_stop_queue with
  netif_device_detach" (bsc#1012628).
- usb: ucsi: stm32: fix command completion handling (bsc#1012628).
- usb: dwc3: core: Workaround for CSR read timeout (bsc#1012628).
- Revert "serial: core: only stop transmit when HW fifo is empty"
  (bsc#1012628).
- tty: serial: 8250: Fix port count mismatch with the device
  (bsc#1012628).
- serial: 8250_omap: Implementation of Errata i2310 (bsc#1012628).
- serial: imx: set receiver level before starting uart
  (bsc#1012628).
- serial: core: introduce uart_port_tx_limited_flags()
  (bsc#1012628).
- serial: bcm63xx-uart: fix tx after conversion to
  uart_port_tx_limited() (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs don't work for
  EliteBook 645/665 G11 (bsc#1012628).
- tty: mxser: Remove __counted_by from mxser_board.ports[]
  (bsc#1012628).
- tty: mcf: MCF54418 has 10 UARTS (bsc#1012628).
- net: can: j1939: Initialize unused data in j1939_send_one()
  (bsc#1012628).
- net: can: j1939: recover socket queue on CAN bus error during
  BAM transmission (bsc#1012628).
- net: can: j1939: enhanced error handling for tightly received
  RTS messages in xtp_rx_rts_session_new (bsc#1012628).
- PCI/MSI: Fix UAF in msi_capability_init (bsc#1012628).
- nvmet-fc: Remove __counted_by from nvmet_fc_tgt_queue.fod[]
  (bsc#1012628).
- cpufreq: intel_pstate: Use HWP to initialize ITMT if CPPC is
  missing (bsc#1012628).
- irqchip/loongson-eiointc: Use early_cpu_to_node() instead of
  cpu_to_node() (bsc#1012628).
- cpu: Fix broken cmdline "nosmp" and "maxcpus=0" (bsc#1012628).
- cpu/hotplug: Fix dynstate assignment in
  __cpuhp_setup_state_cpuslocked() (bsc#1012628).
- irqchip/loongson-liointc: Set different ISRs for different cores
  (bsc#1012628).
- kbuild: Install dtb files as 0644 in Makefile.dtbinst
  (bsc#1012628).
- sh: rework sync_file_range ABI (bsc#1012628).
- btrfs: zoned: fix initial free space detection (bsc#1012628).
- csky, hexagon: fix broken sys_sync_file_range (bsc#1012628).
- hexagon: fix fadvise64_64 calling conventions (bsc#1012628).
- drm/drm_file: Fix pid refcounting race (bsc#1012628).
- drm/nouveau/dispnv04: fix null pointer dereference in
  nv17_tv_get_ld_modes (bsc#1012628).
- drm/fbdev-dma: Only set smem_start is enable per module option
  (bsc#1012628).
- drm/amdgpu: avoid using null object of framebuffer
  (bsc#1012628).
- drm/i915/gt: Fix potential UAF by revoke of fence registers
  (bsc#1012628).
- drm/nouveau/dispnv04: fix null pointer dereference in
  nv17_tv_get_hd_modes (bsc#1012628).
- drm/amd/display: Send DP_TOTAL_LTTPR_CNT during detection if
  LTTPR is present (bsc#1012628).
- drm/amdgpu/atomfirmware: fix parsing of vram_info (bsc#1012628).
- io_uring: signal SQPOLL task_work with TWA_SIGNAL_NO_IPI
  (bsc#1012628).
- batman-adv: Don't accept TT entries for out-of-spec VIDs
  (bsc#1012628).
- can: mcp251xfd: fix infinite loop when xmit fails (bsc#1012628).
- ata: ahci: Clean up sysfs file on error (bsc#1012628).
- ata: libata-core: Add ATA_HORKAGE_NOLPM for all Crucial BX
  SSD1 models (bsc#1012628).
- ata: libata-core: Fix double free on error (bsc#1012628).
- ftruncate: pass a signed offset (bsc#1012628).
- syscalls: fix compat_sys_io_pgetevents_time64 usage
  (bsc#1012628).
- syscalls: fix sys_fanotify_mark prototype (bsc#1012628).
- bcachefs: Fix sb_field_downgrade validation (bsc#1012628).
- bcachefs: Fix sb-downgrade validation (bsc#1012628).
- bcachefs: Fix bch2_sb_downgrade_update() (bsc#1012628).
- bcachefs: Fix setting of downgrade recovery passes/errors
  (bsc#1012628).
- bcachefs: btree_gc can now handle unknown btrees (bsc#1012628).
- Revert "net: sfp: enhance quirk for Fibrestore 2.5G copper
  SFP module" (bsc#1012628).
- mm/page_alloc: Separate THP PCP into movable and non-movable
  categories (bsc#1012628).
- pwm: stm32: Fix calculation of prescaler (bsc#1012628).
- pwm: stm32: Fix error message to not describe the previous
  error path (bsc#1012628).
- arm64: dts: rockchip: Fix SD NAND and eMMC init on
  rk3308-rock-pi-s (bsc#1012628).
- arm64: dts: rockchip: Rename LED related pinctrl nodes on
  rk3308-rock-pi-s (bsc#1012628).
- arm64: dts: rockchip: set correct pwm0 pinctrl on rk3588-tiger
  (bsc#1012628).
- arm64: dts: rockchip: Fix the value of `dlg,jack-det-rate`
  mismatch on rk3399-gru (bsc#1012628).
- ARM: dts: rockchip: rk3066a: add #sound-dai-cells to hdmi node
  (bsc#1012628).
- Revert "arm64: dts: rockchip: remove redundant cd-gpios from
  rk3588 sdmmc nodes" (bsc#1012628).
- arm64: dts: rockchip: make poweroff(8) work on Radxa ROCK 5A
  (bsc#1012628).
- cxl/region: Convert cxl_pmem_region_alloc to scope-based
  resource management (bsc#1012628).
- cxl/mem: Fix no cxl_nvd during pmem region auto-assembling
  (bsc#1012628).
- arm64: dts: rockchip: fix PMIC interrupt pin on ROCK Pi E
  (bsc#1012628).
- reset: gpio: Fix missing gpiolib dependency for GPIO reset
  controller (bsc#1012628).
- arm64: dts: rockchip: Fix the i2c address of es8316 on Cool
  Pi 4B (bsc#1012628).
- arm64: dts: rockchip: Add sound-dai-cells for RK3368
  (bsc#1012628).
- cxl/region: Move cxl_dpa_to_region() work to the region driver
  (bsc#1012628).
- cxl/region: Avoid null pointer dereference in region lookup
  (bsc#1012628).
- cxl/region: check interleave capability (bsc#1012628).
- netfs: Fix netfs_page_mkwrite() to check folio->mapping is valid
  (bsc#1012628).
- netfs: Fix netfs_page_mkwrite() to flush conflicting data,
  not wait (bsc#1012628).
- serial: imx: only set receiver level if it is zero
  (bsc#1012628).
- serial: 8250_omap: Fix Errata i2310 with RX FIFO level check
  (bsc#1012628).
- tracing/net_sched: NULL pointer dereference in
  perf_trace_qdisc_reset() (bsc#1012628).
- Rename to
  patches.kernel.org/6.9.8-046-netfilter-fix-undefined-reference-to-netfilter_.patch.
- Rename to
  patches.kernel.org/6.9.8-056-tcp-fix-tcp_rcv_fastopen_synack-to-enter-TCP_CA.patch.
- commit 3cf5121
* Mon Jul  1 2024 mkubecek@suse.cz
- update to 6.10-rc6
- commit 3c2a141
* Fri Jun 28 2024 jslaby@suse.cz
- netfilter: fix undefined reference to 'netfilter_lwtunnel_*'
  when CONFIG_SYSCTL=n (git-fixes).
- tcp: fix tcp_rcv_fastopen_synack() to enter TCP_CA_Loss for
  failed TFO (git-fixes).
- ALSA: hda/realtek: Fix conflicting quirk for PCI SSID 17aa:3820
  (git-fixes).
- commit a5efffa
* Fri Jun 28 2024 jslaby@suse.cz
- Linux 6.9.7 (bsc#1012628).
- fs/writeback: bail out if there is no more inodes for IO and
  queued once (bsc#1012628).
- padata: Disable BH when taking works lock on MT path
  (bsc#1012628).
- crypto: hisilicon/sec - Fix memory leak for sec resource release
  (bsc#1012628).
- crypto: hisilicon/qm - Add the err memory release process to
  qm uninit (bsc#1012628).
- io_uring/sqpoll: work around a potential audit memory leak
  (bsc#1012628).
- rcutorture: Fix rcu_torture_one_read() pipe_count overflow
  comment (bsc#1012628).
- rcutorture: Make stall-tasks directly exit when rcutorture
  tests end (bsc#1012628).
- rcutorture: Fix invalid context warning when enable srcu
  barrier testing (bsc#1012628).
- platform/chrome: cros_usbpd_logger: provide ID table for
  avoiding fallback match (bsc#1012628).
- platform/chrome: cros_usbpd_notify: provide ID table for
  avoiding fallback match (bsc#1012628).
- ubsan: Avoid i386 UBSAN handler crashes with Clang
  (bsc#1012628).
- arm64: defconfig: select INTERCONNECT_QCOM_SM6115 as built-in
  (bsc#1012628).
- block/ioctl: prefer different overflow check (bsc#1012628).
- ssb: Fix potential NULL pointer dereference in
  ssb_device_uevent() (bsc#1012628).
- selftests/bpf: Prevent client connect before server bind in
  test_tc_tunnel.sh (bsc#1012628).
- selftests/bpf: Fix flaky test btf_map_in_map/lookup_update
  (bsc#1012628).
- bpf: Avoid kfree_rcu() under lock in bpf_lpm_trie (bsc#1012628).
- devlink: use kvzalloc() to allocate devlink instance resources
  (bsc#1012628).
- batman-adv: bypass empty buckets in batadv_purge_orig_ref()
  (bsc#1012628).
- wifi: rtw89: 8852c: add quirk to set PCI BER for certain
  platforms (bsc#1012628).
- wifi: ath9k: work around memset overflow warning (bsc#1012628).
- af_packet: avoid a false positive warning in packet_setsockopt()
  (bsc#1012628).
- clocksource: Make watchdog and suspend-timing multiplication
  overflow safe (bsc#1012628).
- ACPI: x86: Add PNP_UART1_SKIP quirk for Lenovo Blade2 tablets
  (bsc#1012628).
- drop_monitor: replace spin_lock by raw_spin_lock (bsc#1012628).
- ACPI: resource: Do IRQ override on GMxBGxx (XMG APEX 17 M23)
  (bsc#1012628).
- wifi: ath12k: fix kernel crash during resume (bsc#1012628).
- scsi: qedi: Fix crash while reading debugfs attribute
  (bsc#1012628).
- net: sfp: enhance quirk for Fibrestore 2.5G copper SFP module
  (bsc#1012628).
- net: sfp: add quirk for ATS SFP-GE-T 1000Base-TX module
  (bsc#1012628).
- net/sched: fix false lockdep warning on qdisc root lock
  (bsc#1012628).
- arm64/sysreg: Update PIE permission encodings (bsc#1012628).
- kselftest: arm64: Add a null pointer check (bsc#1012628).
- net: dsa: realtek: keep default LED state in rtl8366rb
  (bsc#1012628).
- net: dsa: realtek: do not assert reset on remove (bsc#1012628).
- ACPI: resource: Skip IRQ override on Asus Vivobook Pro N6506MV
  (bsc#1012628).
- netpoll: Fix race condition in netpoll_owner_active
  (bsc#1012628).
- wifi: ath12k: fix the problem that down grade phy mode operation
  (bsc#1012628).
- wifi: mt76: mt7921s: fix potential hung tasks during chip
  recovery (bsc#1012628).
- HID: Add quirk for Logitech Casa touchpad (bsc#1012628).
- HID: asus: fix more n-key report descriptors if n-key quirked
  (bsc#1012628).
- bpf: avoid uninitialized warnings in verifier_global_subprogs.c
  (bsc#1012628).
- selftests: net: fix timestamp not arriving in cmsg_time.sh
  (bsc#1012628).
- net: ena: Add validation for completion descriptors consistency
  (bsc#1012628).
- Bluetooth: ath3k: Fix multiple issues reported by checkpatch.pl
  (bsc#1012628).
- drm/amd/display: Exit idle optimizations before HDCP execution
  (bsc#1012628).
- drm/amd/display: Workaround register access in idle race with
  cursor (bsc#1012628).
- platform/x86: toshiba_acpi: Add quirk for buttons on Z830
  (bsc#1012628).
- cgroup/cpuset: Make cpuset hotplug processing synchronous
  (bsc#1012628).
- ASoC: Intel: sof_sdw: add JD2 quirk for HP Omen 14
  (bsc#1012628).
- ASoC: Intel: sof_sdw: add quirk for Dell SKU 0C0F (bsc#1012628).
- drm/lima: add mask irq callback to gp and pp (bsc#1012628).
- drm/lima: include pp bcast irq in timeout handler check
  (bsc#1012628).
- drm/lima: mask irqs in timeout path before hard reset
  (bsc#1012628).
- platform/x86: x86-android-tablets: Unregister devices in
  reverse order (bsc#1012628).
- platform/x86: x86-android-tablets: Add Lenovo Yoga Tablet 2
  Pro 1380F/L data (bsc#1012628).
- ALSA: hda/realtek: Add quirks for HP Omen models using CS35L41
  (bsc#1012628).
- ALSA: hda/realtek: Add quirks for Lenovo 13X (bsc#1012628).
- powerpc/pseries: Enforce hcall result buffer validity and size
  (bsc#1012628).
- media: intel/ipu6: Fix build with !ACPI (bsc#1012628).
- media: mtk-vcodec: potential null pointer deference in SCP
  (bsc#1012628).
- powerpc/io: Avoid clang null pointer arithmetic warnings
  (bsc#1012628).
- platform/x86: p2sb: Don't init until unassigned resources have
  been assigned (bsc#1012628).
- power: supply: cros_usbpd: provide ID table for avoiding
  fallback match (bsc#1012628).
- iommu/arm-smmu-v3: Free MSIs in case of ENOMEM (bsc#1012628).
- ext4: do not create EA inode under buffer lock (bsc#1012628).
- ext4: fix uninitialized ratelimit_state->lock access in
  __ext4_fill_super() (bsc#1012628).
- kprobe/ftrace: bail out if ftrace was killed (bsc#1012628).
- usb: gadget: uvc: configfs: ensure guid to be valid before set
  (bsc#1012628).
- f2fs: fix to detect inconsistent nat entry during truncation
  (bsc#1012628).
- f2fs: remove clear SB_INLINECRYPT flag in default_options
  (bsc#1012628).
- usb: typec: ucsi_glink: rework quirks implementation
  (bsc#1012628).
- usb: misc: uss720: check for incompatible versions of the
  Belkin F5U002 (bsc#1012628).
- Avoid hw_desc array overrun in dw-axi-dmac (bsc#1012628).
- usb: dwc3: pci: Don't set "linux,phy_charger_detect" property
  on Lenovo Yoga Tab2 1380 (bsc#1012628).
- usb: typec: ucsi_glink: drop special handling for CCI_BUSY
  (bsc#1012628).
- udf: udftime: prevent overflow in udf_disk_stamp_to_time()
  (bsc#1012628).
- PCI/PM: Avoid D3cold for HP Pavilion 17 PC/1972 PCIe Ports
  (bsc#1012628).
- f2fs: don't set RO when shutting down f2fs (bsc#1012628).
- MIPS: Octeon: Add PCIe link status check (bsc#1012628).
- serial: imx: Introduce timeout when waiting on transmitter empty
  (bsc#1012628).
- serial: exar: adding missing CTI and Exar PCI ids (bsc#1012628).
- usb: gadget: function: Remove usage of the deprecated
  ida_simple_xx() API (bsc#1012628).
- xhci: remove XHCI_TRUST_TX_LENGTH quirk (bsc#1012628).
- tty: add the option to have a tty reject a new ldisc
  (bsc#1012628).
- i2c: lpi2c: Avoid calling clk_get_rate during transfer
  (bsc#1012628).
- cxl: Add post-reset warning if reset results in loss of
  previously committed HDM decoders (bsc#1012628).
- vfio/pci: Collect hot-reset devices to local buffer
  (bsc#1012628).
- usb: typec: qcom-pmic-typec: split HPD bridge alloc and
  registration (bsc#1012628).
- cpufreq: amd-pstate: fix memory leak on CPU EPP exit
  (bsc#1012628).
- ACPI: EC: Install address space handler at the namespace root
  (bsc#1012628).
- PCI: Do not wait for disconnected devices when resuming
  (bsc#1012628).
- OPP: Fix required_opp_tables for multiple genpds using same
  table (bsc#1012628).
- ALSA: hda: cs35l41: Possible null pointer dereference in
  cs35l41_hda_unbind() (bsc#1012628).
- ALSA: seq: ump: Fix missing System Reset message handling
  (bsc#1012628).
- MIPS: Routerboard 532: Fix vendor retry check code
  (bsc#1012628).
- mips: bmips: BCM6358: make sure CBR is correctly set
  (bsc#1012628).
- tracing: Build event generation tests only as modules
  (bsc#1012628).
- wifi: iwlwifi: mvm: fix ROC version check (bsc#1012628).
- wifi: mac80211: Recalc offload when monitor stop (bsc#1012628).
- ALSA: hda/realtek: Remove Framework Laptop 16 from quirks
  (bsc#1012628).
- ALSA/hda: intel-dsp-config: Document AVS as dsp_driver option
  (bsc#1012628).
- ice: avoid IRQ collision to fix init failure on ACPI S3 resume
  (bsc#1012628).
- ice: fix 200G link speed message log (bsc#1012628).
- ice: implement AQ download pkg retry (bsc#1012628).
- bpf: Fix reg_set_min_max corruption of fake_reg (bsc#1012628).
- btrfs: zoned: allocate dummy checksums for zoned NODATASUM
  writes (bsc#1012628).
- net: mvpp2: use slab_build_skb for oversized frames
  (bsc#1012628).
- cipso: fix total option length computation (bsc#1012628).
- ALSA: hda: cs35l56: Component should be unbound before
  deconstruction (bsc#1012628).
- ALSA: hda: cs35l41: Component should be unbound before
  deconstruction (bsc#1012628).
- ALSA: hda: tas2781: Component should be unbound before
  deconstruction (bsc#1012628).
- bpf: Avoid splat in pskb_pull_reason (bsc#1012628).
- netdev-genl: fix error codes when outputting XDP features
  (bsc#1012628).
- ALSA: hda/realtek: Enable headset mic on IdeaPad 330-17IKB 81DM
  (bsc#1012628).
- netrom: Fix a memory leak in nr_heartbeat_expiry()
  (bsc#1012628).
- ipv6: prevent possible NULL deref in fib6_nh_init()
  (bsc#1012628).
- ipv6: prevent possible NULL dereference in rt6_probe()
  (bsc#1012628).
- xfrm6: check ip6_dst_idev() return value in xfrm6_get_saddr()
  (bsc#1012628).
- netns: Make get_net_ns() handle zero refcount net (bsc#1012628).
- qca_spi: Make interrupt remembering atomic (bsc#1012628).
- net: lan743x: disable WOL upon resume to restore full data
  path operation (bsc#1012628).
- net: lan743x: Support WOL at both the PHY and MAC appropriately
  (bsc#1012628).
- net: phy: mxl-gpy: Remove interrupt mask clearing from
  config_init (bsc#1012628).
- net/sched: act_api: fix possible infinite loop in
  tcf_idr_check_alloc() (bsc#1012628).
- tipc: force a dst refcount before doing decryption
  (bsc#1012628).
- sched: act_ct: add netns into the key of tcf_ct_flow_table
  (bsc#1012628).
- ptp: fix integer overflow in max_vclocks_store (bsc#1012628).
- selftests: openvswitch: Use bash as interpreter (bsc#1012628).
- virtio_net: checksum offloading handling fix (bsc#1012628).
- virtio_net: fixing XDP for fully checksummed packets handling
  (bsc#1012628).
- octeontx2-pf: Add error handling to VLAN unoffload handling
  (bsc#1012628).
- octeontx2-pf: Fix linking objects into multiple modules
  (bsc#1012628).
- seg6: fix parameter passing when calling NF_HOOK() in End.DX4
  and End.DX6 behaviors (bsc#1012628).
- netfilter: move the sysctl nf_hooks_lwtunnel into the netfilter
  core (bsc#1012628).
- ice: Fix VSI list rule with ICE_SW_LKUP_LAST type (bsc#1012628).
- bnxt_en: Restore PTP tx_avail count in case of skb_pad() error
  (bsc#1012628).
- net: usb: rtl8150 fix unintiatilzed variables in
  rtl8150_get_link_ksettings (bsc#1012628).
- RDMA/bnxt_re: Fix the max msix vectors macro (bsc#1012628).
- arm64: dts: freescale: imx8mm-verdin: Fix GPU speed
  (bsc#1012628).
- phy: qcom-qmp: qserdes-txrx: Add missing registers offsets
  (bsc#1012628).
- phy: qcom-qmp: pcs: Add missing v6 N4 register offsets
  (bsc#1012628).
- phy: qcom: qmp-combo: Switch from V6 to V6 N4 register offsets
  (bsc#1012628).
- powerpc/crypto: Add generated P8 asm to .gitignore
  (bsc#1012628).
- spi: cs42l43: Correct SPI root clock speed (bsc#1012628).
- RDMA/rxe: Fix responder length checking for UD request packets
  (bsc#1012628).
- regulator: core: Fix modpost error "regulator_get_regmap"
  undefined (bsc#1012628).
- dmaengine: idxd: Fix possible Use-After-Free in
  irq_process_work_list (bsc#1012628).
- dmaengine: ti: k3-udma-glue: Fix
  of_k3_udma_glue_parse_chn_by_id() (bsc#1012628).
- dmaengine: ioatdma: Fix leaking on version mismatch
  (bsc#1012628).
- dmaengine: ioatdma: Fix error path in ioat3_dma_probe()
  (bsc#1012628).
- dmaengine: ioatdma: Fix kmemleak in ioat_pci_probe()
  (bsc#1012628).
- dmaengine: fsl-edma: avoid linking both modules (bsc#1012628).
- dmaengine: ioatdma: Fix missing kmem_cache_destroy()
  (bsc#1012628).
- regulator: bd71815: fix ramp values (bsc#1012628).
- thermal/drivers/mediatek/lvts_thermal: Return error in case
  of invalid efuse data (bsc#1012628).
- arm64: dts: imx8mp: Fix TC9595 input clock on DH i.MX8M Plus
  DHCOM SoM (bsc#1012628).
- arm: dts: imx53-qsb-hdmi: Disable panel instead of deleting node
  (bsc#1012628).
- arm64: dts: freescale: imx8mp-venice-gw73xx-2x: fix BT shutdown
  GPIO (bsc#1012628).
- arm64: dts: imx93-11x11-evk: Remove the 'no-sdio' property
  (bsc#1012628).
- arm64: dts: freescale: imx8mm-verdin: enable hysteresis on
  slow input pin (bsc#1012628).
- ACPICA: Revert "ACPICA: avoid Info: mapping multiple BARs. Your
  kernel is fine." (bsc#1012628).
- ACPI: scan: Ignore camera graph port nodes on all Dell Tiger,
  Alder and Raptor Lake models (bsc#1012628).
- spi: Fix SPI slave probe failure (bsc#1012628).
- x86/resctrl: Don't try to free nonexistent RMIDs (bsc#1012628).
- spi: spi-imx: imx51: revert burst length calculation back to
  bits_per_word (bsc#1012628).
- drm/xe/vf: Don't touch GuC irq registers if using memory irqs
  (bsc#1012628).
- io_uring/rsrc: fix incorrect assignment of iter->nr_segs in
  io_import_fixed (bsc#1012628).
- firmware: psci: Fix return value from psci_system_suspend()
  (bsc#1012628).
- LoongArch: Only allow OBJTOOL & ORC unwinder if toolchain
  supports -mthin-add-sub (bsc#1012628).
- RDMA/mlx5: Fix unwind flow as part of mlx5_ib_stage_init_init
  (bsc#1012628).
- RDMA/mlx5: Add check for srq max_sge attribute (bsc#1012628).
- RDMA/mana_ib: Ignore optional access flags for MRs
  (bsc#1012628).
- ACPI: EC: Evaluate orphan _REG under EC device (bsc#1012628).
- ext4: avoid overflow when setting values via sysfs
  (bsc#1012628).
- ext4: fix slab-out-of-bounds in
  ext4_mb_find_good_group_avg_frag_lists() (bsc#1012628).
- net: phy: dp83tg720: wake up PHYs in managed mode (bsc#1012628).
- net: stmmac: Assign configured channel value to EXTTS event
  (bsc#1012628).
- net: usb: ax88179_178a: improve reset check (bsc#1012628).
- net: phy: dp83tg720: get master/slave configuration in link
  down state (bsc#1012628).
- net: do not leave a dangling sk pointer, when socket creation
  fails (bsc#1012628).
- btrfs: retry block group reclaim without infinite loop
  (bsc#1012628).
- scsi: ufs: core: Free memory allocated for model before reinit
  (bsc#1012628).
- cifs: fix typo in module parameter enable_gcm_256 (bsc#1012628).
- LoongArch: Fix watchpoint setting error (bsc#1012628).
- LoongArch: Trigger user-space watchpoints correctly
  (bsc#1012628).
- LoongArch: Fix multiple hardware watchpoint issues
  (bsc#1012628).
- KVM: Fix a data race on last_boosted_vcpu in kvm_vcpu_on_spin()
  (bsc#1012628).
- KVM: arm64: Disassociate vcpus from redistributor region on
  teardown (bsc#1012628).
- KVM: x86: Always sync PIR to IRR prior to scanning I/O APIC
  routes (bsc#1012628).
- RDMA/rxe: Fix data copy for IB_SEND_INLINE (bsc#1012628).
- RDMA/mlx5: Remove extra unlock on error path (bsc#1012628).
- RDMA/mlx5: Follow rb_key.ats when creating new mkeys
  (bsc#1012628).
- RDMA/mlx5: Ensure created mkeys always have a populated rb_key
  (bsc#1012628).
- ovl: fix encoding fid for lower only root (bsc#1012628).
- wifi: mac80211: fix monitor channel with chanctx emulation
  (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs don't work for ProBook
  445/465 G11 (bsc#1012628).
- ALSA: hda/realtek: Limit mic boost on N14AP7 (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Lenovo Yoga Pro 7 14AHP9
  (bsc#1012628).
- drm/i915/mso: using joiner is not possible with eDP MSO
  (bsc#1012628).
- drm/radeon: fix UBSAN warning in kv_dpm.c (bsc#1012628).
- drm/amdgpu: fix UBSAN warning in kv_dpm.c (bsc#1012628).
- drm/amdgpu: fix locking scope when flushing tlb (bsc#1012628).
- drm/amd/display: Remove redundant idle optimization check
  (bsc#1012628).
- drm/amd/display: Attempt to avoid empty TUs when endpoint is
  DPIA (bsc#1012628).
- dt-bindings: dma: fsl-edma: fix dma-channels constraints
  (bsc#1012628).
- ocfs2: fix NULL pointer dereference in ocfs2_journal_dirty()
  (bsc#1012628).
- ocfs2: fix NULL pointer dereference in ocfs2_abort_trigger()
  (bsc#1012628).
- scsi: core: Introduce the BLIST_SKIP_IO_HINTS flag
  (bsc#1012628).
- scsi: usb: uas: Do not query the IO Advice Hints Grouping mode
  page for USB/UAS devices (bsc#1012628).
- ata: ahci: Do not enable LPM if no LPM states are supported
  by the HBA (bsc#1012628).
- dmaengine: xilinx: xdma: Fix data synchronisation in
  xdma_channel_isr() (bsc#1012628).
- net/tcp_ao: Don't leak ao_info on error-path (bsc#1012628).
- gcov: add support for GCC 14 (bsc#1012628).
- kcov: don't lose track of remote references during softirqs
  (bsc#1012628).
- efi/x86: Free EFI memory map only when installing a new one
  (bsc#1012628).
- serial: 8250_dw: Revert "Move definitions to the shared header"
  (bsc#1012628).
- MIPS: mipsmtregs: Fix target register for MFTC0 (bsc#1012628).
- mm: mmap: allow for the maximum number of bits for randomizing
  mmap_base by default (bsc#1012628).
- mm: huge_memory: fix misused mapping_large_folio_support()
  for anon folios (bsc#1012628).
- mm: shmem: fix getting incorrect lruvec when replacing a shmem
  folio (bsc#1012628).
- selftests: mptcp: userspace_pm: fixed subtest names
  (bsc#1012628).
- tcp: clear tp->retrans_stamp in tcp_rcv_fastopen_synack()
  (bsc#1012628).
- mm/page_table_check: fix crash on ZONE_DEVICE (bsc#1012628).
- ima: Avoid blocking in RCU read-side critical section
  (bsc#1012628).
- i2c: ocores: set IACK bit after core is enabled (bsc#1012628).
- dt-bindings: i2c: atmel,at91sam: correct path to i2c-controller
  schema (bsc#1012628).
- virt: guest_memfd: fix reference leak on hwpoisoned page
  (bsc#1012628).
- dt-bindings: i2c: google,cros-ec-i2c-tunnel: correct path to
  i2c-controller schema (bsc#1012628).
- thermal: int340x: processor_thermal: Support shared interrupts
  (bsc#1012628).
- spi: stm32: qspi: Fix dual flash mode sanity test in
  stm32_qspi_setup() (bsc#1012628).
- arm64: dts: imx8qm-mek: fix gpio number for reg_usdhc2_vmmc
  (bsc#1012628).
- spi: stm32: qspi: Clamp stm32_qspi_get_mode() output to
  CCR_BUSWIDTH_4 (bsc#1012628).
- nbd: Improve the documentation of the locking assumptions
  (bsc#1012628).
- nbd: Fix signal handling (bsc#1012628).
- tracing: Add MODULE_DESCRIPTION() to preemptirq_delay_test
  (bsc#1012628).
- x86/cpu/vfm: Add new macros to work with (vendor/family/model)
  values (bsc#1012628).
- x86/cpu: Fix x86_match_cpu() to match just X86_VENDOR_INTEL
  (bsc#1012628).
- drm/amd/display: revert Exit idle optimizations before HDCP
  execution (bsc#1012628).
- wifi: ath12k: check M3 buffer size as well whey trying to
  reuse it (bsc#1012628).
- ASoC: Intel: sof-sdw: really remove FOUR_SPEAKER quirk
  (bsc#1012628).
- net/sched: unregister lockdep keys in qdisc_create/qdisc_alloc
  error path (bsc#1012628).
- kprobe/ftrace: fix build error due to bad function definition
  (bsc#1012628).
- hid: asus: asus_report_fixup: fix potential read out of bounds
  (bsc#1012628).
- Revert "mm: mmap: allow for the maximum number of bits for
  randomizing mmap_base by default" (bsc#1012628).
- Rename to
  patches.kernel.org/6.9.7-042-ACPI-video-Add-backlight-native-quirk-for-Lenov.patch.
- Rename to
  patches.kernel.org/6.9.7-131-net-stmmac-No-need-to-calculate-speed-divider-w.patch.
- Rename to
  patches.kernel.org/6.9.7-136-netfilter-ipset-Fix-suspicious-rcu_dereference_.patch.
- Rename to
  patches.kernel.org/6.9.7-236-thermal-core-Change-PM-notifier-priority-to-the.patch.
- commit 2eea3a0
* Tue Jun 25 2024 jslaby@suse.cz
- Refresh
  patches.suse/thermal-core-Change-PM-notifier-priority-to-the-mini.patch.
  Update upstream status and move to sorted section.
- commit d344d3a
* Sun Jun 23 2024 mkubecek@suse.cz
- update to 6.10-rc5
- refresh configs
- commit 0c5f39a
* Sat Jun 22 2024 jslaby@suse.cz
- netfilter: ipset: Fix suspicious rcu_dereference_protected()
  (git-fixes).
- net: stmmac: No need to calculate speed divider when offload
  is disabled (git-fixes).
- commit e256f5c
* Sat Jun 22 2024 jslaby@suse.cz
- Linux 6.9.6 (bsc#1012628).
- wifi: ath11k: fix WCN6750 firmware crash caused by 17 num_vdevs
  (bsc#1012628).
- wifi: ath11k: move power type check to ASSOC stage when
  connecting to 6 GHz AP (bsc#1012628).
- cpufreq: amd-pstate: Unify computation of
  {max,min,nominal,lowest_nonlinear}_freq (bsc#1012628).
- cpufreq: amd-pstate: Add quirk for the pstate CPPC capabilities
  missing (bsc#1012628).
- cpufreq: amd-pstate: remove global header file (bsc#1012628).
- wifi: mac80211: mesh: Fix leak of mesh_preq_queue objects
  (bsc#1012628).
- wifi: mac80211: Fix deadlock in
  ieee80211_sta_ps_deliver_wakeup() (bsc#1012628).
- wifi: cfg80211: fully move wiphy work to unbound workqueue
  (bsc#1012628).
- wifi: cfg80211: Lock wiphy in cfg80211_get_station
  (bsc#1012628).
- wifi: cfg80211: pmsr: use correct nla_get_uX functions
  (bsc#1012628).
- wifi: mac80211: pass proper link id for channel switch started
  notification (bsc#1012628).
- wifi: iwlwifi: mvm: don't initialize csa_work twice
  (bsc#1012628).
- wifi: iwlwifi: mvm: revert gen2 TX A-MPDU size to 64
  (bsc#1012628).
- wifi: iwlwifi: mvm: set properly mac header (bsc#1012628).
- wifi: iwlwifi: dbg_ini: move iwl_dbg_tlv_free outside of
  debugfs ifdef (bsc#1012628).
- wifi: iwlwifi: mvm: check n_ssids before accessing the ssids
  (bsc#1012628).
- wifi: iwlwifi: mvm: don't read past the mfuart notifcation
  (bsc#1012628).
- wifi: mac80211: fix Spatial Reuse element size check
  (bsc#1012628).
- wifi: mac80211: correctly parse Spatial Reuse Parameter Set
  element (bsc#1012628).
- scsi: ufs: mcq: Fix error output and clean up ufshcd_mcq_abort()
  (bsc#1012628).
- RISC-V: KVM: No need to use mask when hart-index-bit is 0
  (bsc#1012628).
- RISC-V: KVM: Fix incorrect reg_subtype labels in
  kvm_riscv_vcpu_set_reg_isa_ext function (bsc#1012628).
- virtio_net: fix possible dim status unrecoverable (bsc#1012628).
- ax25: Fix refcount imbalance on inbound connections
  (bsc#1012628).
- ax25: Replace kfree() in ax25_dev_free() with ax25_dev_put()
  (bsc#1012628).
- net/ncsi: Fix the multi thread manner of NCSI driver
  (bsc#1012628).
- net: phy: micrel: fix KSZ9477 PHY issues after suspend/resume
  (bsc#1012628).
- bpf: Fix a potential use-after-free in bpf_link_free()
  (bsc#1012628).
- KVM: SEV-ES: Disallow SEV-ES guests when X86_FEATURE_LBRV is
  absent (bsc#1012628).
- KVM: SEV-ES: Delegate LBR virtualization to the processor
  (bsc#1012628).
- vmxnet3: disable rx data ring on dma allocation failure
  (bsc#1012628).
- ipv6: ioam: block BH from ioam6_output() (bsc#1012628).
- ipv6: sr: block BH in seg6_output_core() and seg6_input_core()
  (bsc#1012628).
- net: tls: fix marking packets as decrypted (bsc#1012628).
- bpf: Set run context for rawtp test_run callback (bsc#1012628).
- octeontx2-af: Always allocate PF entries from low prioriy zone
  (bsc#1012628).
- net/smc: avoid overwriting when adjusting sock bufsizes
  (bsc#1012628).
- net: phy: Micrel KSZ8061: fix errata solution not taking effect
  problem (bsc#1012628).
- ionic: fix kernel panic in XDP_TX action (bsc#1012628).
- net: sched: sch_multiq: fix possible OOB write in multiq_tune()
  (bsc#1012628).
- tcp: count CLOSE-WAIT sockets for TCP_MIB_CURRESTAB
  (bsc#1012628).
- mptcp: count CLOSE-WAIT sockets for MPTCP_MIB_CURRESTAB
  (bsc#1012628).
- rtnetlink: make the "split" NLM_DONE handling generic
  (bsc#1012628).
- net: ethernet: mtk_eth_soc: handle dma buffer size soc specific
  (bsc#1012628).
- net/mlx5: Stop waiting for PCI if pci channel is offline
  (bsc#1012628).
- net/mlx5: Always stop health timer during driver removal
  (bsc#1012628).
- net/mlx5: Fix tainted pointer delete is case of flow rules
  creation fail (bsc#1012628).
- net/sched: taprio: always validate TCA_TAPRIO_ATTR_PRIOMAP
  (bsc#1012628).
- ptp: Fix error message on failed pin verification (bsc#1012628).
- ice: fix iteration of TLVs in Preserved Fields Area
  (bsc#1012628).
- ice: fix reads from NVM Shadow RAM on E830 and E825-C devices
  (bsc#1012628).
- ice: remove af_xdp_zc_qps bitmap (bsc#1012628).
- ice: add flag to distinguish reset from .ndo_bpf in XDP rings
  config (bsc#1012628).
- ice: map XDP queues to vectors in ice_vsi_map_rings_to_vectors()
  (bsc#1012628).
- igc: Fix Energy Efficient Ethernet support declaration
  (bsc#1012628).
- net: wwan: iosm: Fix tainted pointer delete is case of region
  creation fail (bsc#1012628).
- af_unix: Set sk->sk_state under unix_state_lock() for truly
  disconencted peer (bsc#1012628).
- af_unix: Annodate data-races around sk->sk_state for writers
  (bsc#1012628).
- af_unix: Annotate data-race of sk->sk_state in unix_inq_len()
  (bsc#1012628).
- af_unix: Annotate data-races around sk->sk_state in
  unix_write_space() and poll() (bsc#1012628).
- af_unix: Annotate data-race of sk->sk_state in
  unix_stream_connect() (bsc#1012628).
- af_unix: Annotate data-races around sk->sk_state in sendmsg()
  and recvmsg() (bsc#1012628).
- af_unix: Annotate data-race of sk->sk_state in
  unix_stream_read_skb() (bsc#1012628).
- af_unix: Annotate data-races around sk->sk_state in UNIX_DIAG
  (bsc#1012628).
- af_unix: Annotate data-races around sk->sk_sndbuf (bsc#1012628).
- af_unix: Annotate data-race of net->unx.sysctl_max_dgram_qlen
  (bsc#1012628).
- af_unix: Use unix_recvq_full_lockless() in unix_stream_connect()
  (bsc#1012628).
- af_unix: Use skb_queue_empty_lockless() in unix_release_sock()
  (bsc#1012628).
- af_unix: Use skb_queue_len_lockless() in sk_diag_show_rqlen()
  (bsc#1012628).
- af_unix: Annotate data-race of sk->sk_shutdown in sk_diag_fill()
  (bsc#1012628).
- ipv6: fix possible race in __fib6_drop_pcpu_from()
  (bsc#1012628).
- net: ethtool: fix the error condition in
  ethtool_get_phy_stats_ethtool() (bsc#1012628).
- x86/cpu: Get rid of an unnecessary local variable in
  get_cpu_address_sizes() (bsc#1012628).
- x86/cpu: Provide default cache line size if not enumerated
  (bsc#1012628).
- selftests/mm: ksft_exit functions do not return (bsc#1012628).
- selftests/mm: compaction_test: fix bogus test success and
  reduce probability of OOM-killer invocation (bsc#1012628).
- eventfs: Update all the eventfs_inodes from the events
  descriptor (bsc#1012628).
- .editorconfig: remove trim_trailing_whitespace option
  (bsc#1012628).
- io_uring/rsrc: don't lock while !TASK_RUNNING (bsc#1012628).
- io_uring: fix cancellation overwriting req->flags (bsc#1012628).
- USB: class: cdc-wdm: Fix CPU lockup caused by excessive log
  messages (bsc#1012628).
- kcov, usb: disable interrupts in kcov_remote_start_usb_softirq
  (bsc#1012628).
- USB: xen-hcd: Traverse host/ when CONFIG_USB_XEN_HCD is selected
  (bsc#1012628).
- usb: typec: tcpm: fix use-after-free case in
  tcpm_register_source_caps (bsc#1012628).
- usb: typec: tcpm: Ignore received Hard Reset in TOGGLING state
  (bsc#1012628).
- mei: me: release irq in mei_me_pci_resume error path
  (bsc#1012628).
- mei: vsc: Don't stop/restart mei device during system
  suspend/resume (bsc#1012628).
- tty: n_tty: Fix buffer offsets when lookahead is used
  (bsc#1012628).
- serial: 8250_pxa: Configure tx_loadsz to match FIFO IRQ level
  (bsc#1012628).
- serial: port: Don't block system suspend even if bytes are
  left to xmit (bsc#1012628).
- landlock: Fix d_parent walk (bsc#1012628).
- jfs: xattr: fix buffer overflow for invalid xattr (bsc#1012628).
- xhci: Set correct transferred length for cancelled bulk
  transfers (bsc#1012628).
- xhci: Apply reset resume quirk to Etron EJ188 xHCI host
  (bsc#1012628).
- xhci: Handle TD clearing for multiple streams case
  (bsc#1012628).
- xhci: Apply broken streams quirk to Etron EJ188 xHCI host
  (bsc#1012628).
- thunderbolt: debugfs: Fix margin debugfs node creation condition
  (bsc#1012628).
- scsi: core: Disable CDL by default (bsc#1012628).
- scsi: mpi3mr: Fix ATA NCQ priority support (bsc#1012628).
- scsi: mpt3sas: Avoid test/set_bit() operating in non-allocated
  memory (bsc#1012628).
- scsi: sd: Use READ(16) when reading block zero on large capacity
  disks (bsc#1012628).
- gve: Clear napi->skb before dev_kfree_skb_any() (bsc#1012628).
- powerpc/85xx: fix compile error without CONFIG_CRASH_DUMP
  (bsc#1012628).
- powerpc/uaccess: Fix build errors seen with GCC 13/14
  (bsc#1012628).
- HID: nvidia-shield: Add missing check for
  input_ff_create_memless (bsc#1012628).
- cxl/test: Add missing vmalloc.h for tools/testing/cxl/test/mem.c
  (bsc#1012628).
- cxl/region: Fix memregion leaks in devm_cxl_add_region()
  (bsc#1012628).
- cachefiles: add output string to
  cachefiles_obj_[get|put]_ondemand_fd (bsc#1012628).
- cachefiles: remove requests from xarray during flushing requests
  (bsc#1012628).
- cachefiles: fix slab-use-after-free in
  cachefiles_ondemand_get_fd() (bsc#1012628).
- cachefiles: fix slab-use-after-free in
  cachefiles_ondemand_daemon_read() (bsc#1012628).
- cachefiles: add spin_lock for cachefiles_ondemand_info
  (bsc#1012628).
- cachefiles: remove err_put_fd label in
  cachefiles_ondemand_daemon_read() (bsc#1012628).
- cachefiles: never get a new anonymous fd if ondemand_id is valid
  (bsc#1012628).
- cachefiles: defer exposing anon_fd until after copy_to_user()
  succeeds (bsc#1012628).
- cachefiles: flush all requests after setting CACHEFILES_DEAD
  (bsc#1012628).
- kselftest/alsa: Ensure _GNU_SOURCE is defined (bsc#1012628).
- selftests/ftrace: Fix to check required event file
  (bsc#1012628).
- clk: sifive: Do not register clkdevs for PRCI clocks
  (bsc#1012628).
- NFSv4.1 enforce rootpath check in fs_location query
  (bsc#1012628).
- SUNRPC: return proper error from gss_wrap_req_priv
  (bsc#1012628).
- NFS: add barriers when testing for NFS_FSDATA_BLOCKED
  (bsc#1012628).
- selftests/tracing: Fix event filter test to retry up to 10 times
  (bsc#1012628).
- selftests/futex: don't pass a const char* to asprintf(3)
  (bsc#1012628).
- nvme: fix nvme_pr_* status code parsing (bsc#1012628).
- drm/panel: sitronix-st7789v: Add check for
  of_drm_get_panel_orientation (bsc#1012628).
- platform/x86: dell-smbios: Fix wrong token data in sysfs
  (bsc#1012628).
- gpio: tqmx86: fix typo in Kconfig label (bsc#1012628).
- gpio: tqmx86: introduce shadow register for GPIO output value
  (bsc#1012628).
- gpio: tqmx86: store IRQ trigger type and unmask status
  separately (bsc#1012628).
- gpio: tqmx86: fix broken IRQ_TYPE_EDGE_BOTH interrupt type
  (bsc#1012628).
- HID: core: remove unnecessary WARN_ON() in implement()
  (bsc#1012628).
- iommu/amd: Fix sysfs leak in iommu init (bsc#1012628).
- iommu: Return right value in iommu_sva_bind_device()
  (bsc#1012628).
- io_uring/io-wq: Use set_bit() and test_bit() at worker->flags
  (bsc#1012628).
- io_uring/io-wq: avoid garbage value of 'match' in
  io_wq_enqueue() (bsc#1012628).
- HID: logitech-dj: Fix memory leak in
  logi_dj_recv_switch_to_dj_mode() (bsc#1012628).
- drm/vmwgfx: Filter modes which exceed graphics memory
  (bsc#1012628).
- drm/vmwgfx: 3D disabled should not effect STDU memory limits
  (bsc#1012628).
- drm/vmwgfx: Remove STDU logic from generic mode_valid function
  (bsc#1012628).
- drm/vmwgfx: Don't memcmp equivalent pointers (bsc#1012628).
- af_unix: Annotate data-race of sk->sk_state in unix_accept()
  (bsc#1012628).
- modpost: do not warn about missing MODULE_DESCRIPTION() for
  vmlinux.o (bsc#1012628).
- net: sfp: Always call `sfp_sm_mod_remove()` on remove
  (bsc#1012628).
- net: hns3: fix kernel crash problem in concurrent scenario
  (bsc#1012628).
- net: hns3: add cond_resched() to hns3 ring buffer init process
  (bsc#1012628).
- thermal: core: Do not fail cdev registration because of invalid
  initial state (bsc#1012628).
- liquidio: Adjust a NULL pointer handling path in
  lio_vf_rep_copy_packet (bsc#1012628).
- net: stmmac: dwmac-qcom-ethqos: Configure host DMA width
  (bsc#1012628).
- netdevsim: fix backwards compatibility in nsim_get_iflink()
  (bsc#1012628).
- drm/komeda: check for error-valued pointer (bsc#1012628).
- drm/bridge/panel: Fix runtime warning on panel bridge release
  (bsc#1012628).
- tcp: fix race in tcp_v6_syn_recv_sock() (bsc#1012628).
- net dsa: qca8k: fix usages of device_get_named_child_node()
  (bsc#1012628).
- geneve: Fix incorrect inner network header offset when
  innerprotoinherit is set (bsc#1012628).
- net/mlx5e: Fix features validation check for tunneled UDP
  (non-VXLAN) packets (bsc#1012628).
- Bluetooth: hci_sync: Fix not using correct handle (bsc#1012628).
- Bluetooth: L2CAP: Fix rejecting L2CAP_CONN_PARAM_UPDATE_REQ
  (bsc#1012628).
- net/sched: initialize noop_qdisc owner (bsc#1012628).
- tcp: use signed arithmetic in tcp_rtx_probe0_timed_out()
  (bsc#1012628).
- drm/nouveau: don't attempt to schedule hpd_work on headless
  cards (bsc#1012628).
- netfilter: nft_inner: validate mandatory meta and payload
  (bsc#1012628).
- netfilter: ipset: Fix race between namespace cleanup and gc
  in the list:set type (bsc#1012628).
- x86/asm: Use %%c/%%n instead of %%P operand modifier in asm
  templates (bsc#1012628).
- x86/uaccess: Fix missed zeroing of ia32 u64 get_user() range
  checking (bsc#1012628).
- scsi: ufs: core: Quiesce request queues before checking pending
  cmds (bsc#1012628).
- net: pse-pd: Use EOPNOTSUPP error code instead of ENOTSUPP
  (bsc#1012628).
- gve: ignore nonrelevant GSO type bits when processing TSO
  headers (bsc#1012628).
- net: stmmac: replace priv->speed with the portTransmitRate
  from the tc-cbs parameters (bsc#1012628).
- block: sed-opal: avoid possible wrong address reference in
  read_sed_opal_key() (bsc#1012628).
- block: fix request.queuelist usage in flush (bsc#1012628).
- nvmet-passthru: propagate status from id override functions
  (bsc#1012628).
- net/ipv6: Fix the RT cache flush via sysctl using a previous
  delay (bsc#1012628).
- net: bridge: mst: pass vlan group directly to
  br_mst_vlan_set_state (bsc#1012628).
- net: bridge: mst: fix suspicious rcu usage in br_mst_set_state
  (bsc#1012628).
- drm/xe/xe_gt_idle: use GT forcewake domain assertion
  (bsc#1012628).
- drm/xe: flush engine buffers before signalling user fence on
  all engines (bsc#1012628).
- drm/xe: Remove mem_access from guc_pc calls (bsc#1012628).
- drm/xe: move disable_c6 call (bsc#1012628).
- ionic: fix use after netif_napi_del() (bsc#1012628).
- bnxt_en: Cap the size of HWRM_PORT_PHY_QCFG forwarded response
  (bsc#1012628).
- af_unix: Read with MSG_PEEK loops if the first unread byte is
  OOB (bsc#1012628).
- bnxt_en: Adjust logging of firmware messages in case of released
  token in __hwrm_send() (bsc#1012628).
- misc: microchip: pci1xxxx: fix double free in the error handling
  of gp_aux_bus_probe() (bsc#1012628).
- ksmbd: move leading slash check to smb2_get_name()
  (bsc#1012628).
- ksmbd: fix missing use of get_write in in smb2_set_ea()
  (bsc#1012628).
- tick/nohz_full: Don't abuse smp_call_function_single() in
  tick_setup_device() (bsc#1012628).
- leds: class: Revert: "If no default trigger is given, make
  hw_control trigger the default trigger" (bsc#1012628).
- x86/boot: Don't add the EFI stub to targets, again
  (bsc#1012628).
- iio: adc: ad9467: fix scan type sign (bsc#1012628).
- iio: dac: ad5592r: fix temperature channel scaling value
  (bsc#1012628).
- iio: imu: bmi323: Fix trigger notification in case of error
  (bsc#1012628).
- iio: invensense: fix odr switching to same value (bsc#1012628).
- iio: pressure: bmp280: Fix BMP580 temperature reading
  (bsc#1012628).
- iio: temperature: mlx90635: Fix ERR_PTR dereference in
  mlx90635_probe() (bsc#1012628).
- iio: imu: inv_icm42600: delete unneeded update watermark call
  (bsc#1012628).
- drivers: core: synchronize really_probe() and dev_uevent()
  (bsc#1012628).
- parisc: Try to fix random segmentation faults in package builds
  (bsc#1012628).
- RAS/AMD/ATL: Fix MI300 bank hash (bsc#1012628).
- RAS/AMD/ATL: Use system settings for MI300 DRAM to normalized
  address translation (bsc#1012628).
- ACPI: x86: Force StorageD3Enable on more products (bsc#1012628).
- thermal: ACPI: Invalidate trip points with temperature of 0
  or below (bsc#1012628).
- x86/mm/numa: Use NUMA_NO_NODE when calling memblock_set_node()
  (bsc#1012628).
- memblock: make memblock_set_node() also warn about use of
  MAX_NUMNODES (bsc#1012628).
- drm/exynos/vidi: fix memory leak in .get_modes() (bsc#1012628).
- drm/exynos: hdmi: report safe 640x480 mode as a fallback when
  no EDID found (bsc#1012628).
- mptcp: ensure snd_una is properly initialized on connect
  (bsc#1012628).
- mptcp: pm: inc RmAddr MIB counter once per RM_ADDR ID
  (bsc#1012628).
- mptcp: pm: update add_addr counters after connect (bsc#1012628).
- irqchip/sifive-plic: Chain to parent IRQ after handlers are
  ready (bsc#1012628).
- irqchip/gic-v3-its: Fix potential race condition in
  its_vlpi_prop_update() (bsc#1012628).
- x86/kexec: Fix bug with call depth tracking (bsc#1012628).
- x86/amd_nb: Check for invalid SMN reads (bsc#1012628).
- perf/core: Fix missing wakeup when waiting for context reference
  (bsc#1012628).
- perf auxtrace: Fix multiple use of --itrace option
  (bsc#1012628).
- perf script: Show also errors for --insn-trace option
  (bsc#1012628).
- wifi: cfg80211: validate HE operation element parsing
  (bsc#1012628).
- wifi: rtlwifi: Ignore IEEE80211_CONF_CHANGE_RETRY_LIMITS
  (bsc#1012628).
- wifi: mt76: mt7615: add missing chanctx ops (bsc#1012628).
- locking/atomic: scripts: fix ${atomic}_sub_and_test() kerneldoc
  (bsc#1012628).
- riscv: fix overlap of allocated page and PTR_ERR (bsc#1012628).
- tracing/selftests: Fix kprobe event name test for
  .isra. functions (bsc#1012628).
- kheaders: explicitly define file modes for archived headers
  (bsc#1012628).
- null_blk: Print correct max open zones limit in
  null_init_zoned_dev() (bsc#1012628).
- ata: ahci: Do not apply Intel PCS quirk on Intel Alder Lake
  (bsc#1012628).
- ata: libata-core: Add ATA_HORKAGE_NOLPM for Apacer AS340
  (bsc#1012628).
- ata: libata-core: Add ATA_HORKAGE_NOLPM for Crucial
  CT240BX500SSD1 (bsc#1012628).
- ata: libata-core: Add ATA_HORKAGE_NOLPM for AMD Radeon S3 SSD
  (bsc#1012628).
- sock_map: avoid race between sock_map_close and sk_psock_put
  (bsc#1012628).
- dma-buf: handle testing kthreads creation failure (bsc#1012628).
- vmci: prevent speculation leaks by sanitizing event in
  event_deliver() (bsc#1012628).
- spmi: hisi-spmi-controller: Do not override device identifier
  (bsc#1012628).
- knfsd: LOOKUP can return an illegal error value (bsc#1012628).
- fs/proc: fix softlockup in __read_vmcore (bsc#1012628).
- kexec: fix the unexpected kexec_dprintk() macro (bsc#1012628).
- ocfs2: update inode fsync transaction id in ocfs2_unlink and
  ocfs2_link (bsc#1012628).
- ocfs2: use coarse time for new created files (bsc#1012628).
- ocfs2: fix races between hole punching and AIO+DIO
  (bsc#1012628).
- dm-integrity: set discard_granularity to logical block size
  (bsc#1012628).
- PCI: rockchip-ep: Remove wrong mask on subsys_vendor_id
  (bsc#1012628).
- dmaengine: axi-dmac: fix possible race in remove()
  (bsc#1012628).
- drm/bridge: aux-hpd-bridge: correct devm_drm_dp_hpd_bridge_add()
  stub (bsc#1012628).
- remoteproc: k3-r5: Wait for core0 power-up before powering up
  core1 (bsc#1012628).
- remoteproc: k3-r5: Do not allow core1 to power up before core0
  via sysfs (bsc#1012628).
- iio: adc: axi-adc: make sure AXI clock is enabled (bsc#1012628).
- iio: temperature: mcp9600: Fix temperature reading for negative
  values (bsc#1012628).
- iio: invensense: fix interrupt timestamp alignment
  (bsc#1012628).
- drm/mst: Fix NULL pointer dereference at
  drm_dp_add_payload_part2 (bsc#1012628).
- riscv: rewrite __kernel_map_pages() to fix sleeping in invalid
  context (bsc#1012628).
- riscv: force PAGE_SIZE linear mapping if debug_pagealloc is
  enabled (bsc#1012628).
- rtla/timerlat: Simplify "no value" printing on top
  (bsc#1012628).
- rtla/auto-analysis: Replace \t with spaces (bsc#1012628).
- drm/i915/gt: Disarm breadcrumbs if engines are already idle
  (bsc#1012628).
- drm/shmem-helper: Fix BUG_ON() on mmap(PROT_WRITE, MAP_PRIVATE)
  (bsc#1012628).
- drm/xe: Properly handle alloc_guc_id() failure (bsc#1012628).
- drm/i915/dpt: Make DPT object unshrinkable (bsc#1012628).
- drm/i915: Fix audio component initialization (bsc#1012628).
- intel_th: pci: Add Granite Rapids support (bsc#1012628).
- intel_th: pci: Add Granite Rapids SOC support (bsc#1012628).
- intel_th: pci: Add Sapphire Rapids SOC support (bsc#1012628).
- intel_th: pci: Add Meteor Lake-S support (bsc#1012628).
- intel_th: pci: Add Lunar Lake support (bsc#1012628).
- pmdomain: ti-sci: Fix duplicate PD referrals (bsc#1012628).
- btrfs: zoned: fix use-after-free due to race with dev replace
  (bsc#1012628).
- mm/huge_memory: don't unpoison huge_zero_folio (bsc#1012628).
- remoteproc: k3-r5: Jump to error handling labels in start/stop
  errors (bsc#1012628).
- greybus: Fix use-after-free bug in gb_interface_release due
  to race condition (bsc#1012628).
- ima: Fix use-after-free on a dentry's dname.name (bsc#1012628).
- serial: 8250_dw: Don't use struct dw8250_data outside of 8250_dw
  (bsc#1012628).
- dt-bindings: usb: realtek,rts5411: Add missing
  "additionalProperties" on child nodes (bsc#1012628).
- usb-storage: alauda: Check whether the media is initialized
  (bsc#1012628).
- mei: vsc: Fix wrong invocation of ACPI SID method (bsc#1012628).
- misc: microchip: pci1xxxx: Fix a memory leak in the error
  handling of gp_aux_bus_probe() (bsc#1012628).
- i2c: at91: Fix the functionality flags of the slave-only
  interface (bsc#1012628).
- i2c: designware: Fix the functionality flags of the slave-only
  interface (bsc#1012628).
- zap_pid_ns_processes: clear TIF_NOTIFY_SIGNAL along with
  TIF_SIGPENDING (bsc#1012628).
- Rename to
  patches.kernel.org/6.9.6-098-ata-libata-scsi-Set-the-RMB-bit-only-for-remova.patch.
- Rename to
  patches.kernel.org/6.9.6-160-Bluetooth-fix-connection-setup-in-l2cap_connect.patch.
- Rename to
  patches.kernel.org/6.9.6-267-wifi-iwlwifi-mvm-support-iwl_dev_tx_power_cmd_v.patch.
- Rename to
  patches.kernel.org/6.9.6-268-wifi-iwlwifi-mvm-fix-a-crash-on-7265.patch.
- commit 6156266
* Fri Jun 21 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: fix a crash on 7265 (bsc#1226544).
- wifi: iwlwifi: mvm: support iwl_dev_tx_power_cmd_v8
  (bsc#1226544).
- commit b32a843
* Tue Jun 18 2024 jslaby@suse.cz
- Refresh
  patches.suse/Bluetooth-fix-connection-setup-in-l2cap_connect.patch.
- Refresh
  patches.suse/scsi-core-alua-I-O-errors-for-ALUA-state-transitions.patch.
  Update upstream statuses.
- commit ee54ae4
* Tue Jun 18 2024 jslaby@suse.cz
- rpm/kernel-obs-build.spec.in: drop algif_hash from KERNEL_MODULES (bsc#1226463)
  algif_hash was added as a part of commit bfd7db420f29
  (rpm/kernel-obs-build.spec.in: Include algif_hash, aegis128 and xts
  modules). But it causes issues with an openssl-1_1 test. See the bug.
  Therefore, temporarily drop the module from KERNEL_MODULES.
- commit c9c2e24
* Mon Jun 17 2024 tiwai@suse.de
- ata: libata-scsi: Set the RMB bit only for removable media
  devices (bsc#1226214).
- commit e43cb70
* Mon Jun 17 2024 jslaby@suse.cz
- Linux 6.9.5 (bsc#1012628).
- drm/amdkfd: handle duplicate BOs in reserve_bo_and_cond_vms
  (bsc#1012628).
- drm/i915/hwmon: Get rid of devm (bsc#1012628).
- afs: Don't cross .backup mountpoint from backup volume
  (bsc#1012628).
- erofs: avoid allocating DEFLATE streams before mounting
  (bsc#1012628).
- x86/topology/amd: Evaluate SMT in CPUID leaf 0x8000001e only
  on family 0x17 and greater (bsc#1012628).
- vxlan: Fix regression when dropping packets due to invalid
  src addresses (bsc#1012628).
- f2fs: fix to do sanity check on i_xattr_nid in
  sanity_check_inode() (bsc#1012628).
- media: lgdt3306a: Add a check against null-pointer-def
  (bsc#1012628).
- drm/amdgpu: add error handle to avoid out-of-bounds
  (bsc#1012628).
- drm/xe/bb: assert width in xe_bb_create_job() (bsc#1012628).
- bcache: fix variable length array abuse in btree_iter
  (bsc#1012628).
- crypto: starfive - Do not free stack buffer (bsc#1012628).
- btrfs: qgroup: fix initialization of auto inherit array
  (bsc#1012628).
- wifi: rtw89: correct aSIFSTime for 6GHz band (bsc#1012628).
- ata: pata_legacy: make legacy_exit() work again (bsc#1012628).
- fsverity: use register_sysctl_init() to avoid kmemleak warning
  (bsc#1012628).
- proc: Move fdinfo PTRACE_MODE_READ check into the inode
  .permission operation (bsc#1012628).
- platform/chrome: cros_ec: Handle events during suspend after
  resume completion (bsc#1012628).
- thermal/drivers/qcom/lmh: Check for SCM availability at probe
  (bsc#1012628).
- soc: qcom: rpmh-rsc: Enhance check for VRM in-flight request
  (bsc#1012628).
- ACPI: resource: Do IRQ override on TongFang GXxHRXx and GMxHGxx
  (bsc#1012628).
- arm64: tegra: Correct Tegra132 I2C alias (bsc#1012628).
- arm64: dts: qcom: qcs404: fix bluetooth device address
  (bsc#1012628).
- md/raid5: fix deadlock that raid5d() wait for itself to clear
  MD_SB_CHANGE_PENDING (bsc#1012628).
- wifi: rtw89: pci: correct TX resource checking for PCI DMA
  channel of firmware command (bsc#1012628).
- wifi: rtl8xxxu: Fix the TX power of RTL8192CU, RTL8723AU
  (bsc#1012628).
- wifi: rtl8xxxu: enable MFP support with security flag of RX
  descriptor (bsc#1012628).
- wifi: rtlwifi: rtl8192de: Fix 5 GHz TX power (bsc#1012628).
- wifi: rtlwifi: rtl8192de: Fix low speed with WPA3-SAE
  (bsc#1012628).
- wifi: rtlwifi: rtl8192de: Fix endianness issue in RX path
  (bsc#1012628).
- arm64: dts: qcom: sc8280xp: add missing PCIe minimum OPP
  (bsc#1012628).
- arm64: dts: hi3798cv200: fix the size of GICR (bsc#1012628).
- arm64: dts: ti: verdin-am62: Set memory size to 2gb
  (bsc#1012628).
- media: mgb4: Fix double debugfs remove (bsc#1012628).
- media: mc: Fix graph walk in media_pipeline_start (bsc#1012628).
- media: mc: mark the media devnode as registered from the,
  start (bsc#1012628).
- media: mxl5xx: Move xpt structures off stack (bsc#1012628).
- media: v4l2-core: hold videodev_lock until dev reg, finishes
  (bsc#1012628).
- media: ov2740: Fix LINK_FREQ and PIXEL_RATE control value
  reporting (bsc#1012628).
- media: v4l: async: Properly re-initialise notifier entry in
  unregister (bsc#1012628).
- media: v4l: async: Don't set notifier's V4L2 device if
  registering fails (bsc#1012628).
- media: v4l: async: Fix notifier list entry init (bsc#1012628).
- mmc: davinci: Don't strip remove function when driver is builtin
  (bsc#1012628).
- mmc: core: Add mmc_gpiod_set_cd_config() function (bsc#1012628).
- mmc: sdhci: Add support for "Tuning Error" interrupts
  (bsc#1012628).
- mmc: sdhci-acpi: Sort DMI quirks alphabetically (bsc#1012628).
- mmc: sdhci-acpi: Fix Lenovo Yoga Tablet 2 Pro 1380 sdcard slot
  not working (bsc#1012628).
- mmc: sdhci-acpi: Disable write protect detection on Toshiba
  WT10-A (bsc#1012628).
- mmc: sdhci-acpi: Add quirk to enable pull-up on the card-detect
  GPIO on Asus T100TA (bsc#1012628).
- drm/fbdev-generic: Do not set physical framebuffer address
  (bsc#1012628).
- fbdev: savage: Handle err return when savagefb_check_var failed
  (bsc#1012628).
- firmware: qcom_scm: disable clocks if qcom_scm_bw_enable()
  fails (bsc#1012628).
- drm/amdgpu/atomfirmware: add intergrated info v2.3 table
  (bsc#1012628).
- 9p: add missing locking around taking dentry fid list
  (bsc#1012628).
- drm/amd: Fix shutdown (again) on some SMU v13.0.4/11 platforms
  (bsc#1012628).
- Revert "drm/amdkfd: fix gfx_target_version for certain 11.0.3
  devices" (bsc#1012628).
- KVM: SVM: WARN on vNMI + NMI window iff NMIs are outright masked
  (bsc#1012628).
- KVM: arm64: Fix AArch32 register narrowing on userspace write
  (bsc#1012628).
- KVM: arm64: Allow AArch32 PSTATE.M to be restored as System mode
  (bsc#1012628).
- KVM: arm64: AArch32: Fix spurious trapping of conditional
  instructions (bsc#1012628).
- LoongArch: Add all CPUs enabled by fdt to NUMA node 0
  (bsc#1012628).
- LoongArch: Fix built-in DTB detection (bsc#1012628).
- LoongArch: Override higher address bits in JUMP_VIRT_ADDR
  (bsc#1012628).
- LoongArch: Fix entry point in kernel image header (bsc#1012628).
- clk: bcm: dvp: Assign ->num before accessing ->hws
  (bsc#1012628).
- clk: bcm: rpi: Assign ->num before accessing ->hws
  (bsc#1012628).
- clk: qcom: clk-alpha-pll: fix rate setting for Stromer PLLs
  (bsc#1012628).
- clk: qcom: apss-ipq-pll: use stromer ops for IPQ5018 to fix
  boot failure (bsc#1012628).
- crypto: ecdsa - Fix module auto-load on add-key (bsc#1012628).
- crypto: ecrdsa - Fix module auto-load on add_key (bsc#1012628).
- crypto: qat - Fix ADF_DEV_RESET_SYNC memory leak (bsc#1012628).
- kbuild: Remove support for Clang's ThinLTO caching
  (bsc#1012628).
- mm: fix race between __split_huge_pmd_locked() and GUP-fast
  (bsc#1012628).
- io_uring/napi: fix timeout calculation (bsc#1012628).
- io_uring: check for non-NULL file pointer in io_file_can_poll()
  (bsc#1012628).
- filemap: add helper mapping_max_folio_size() (bsc#1012628).
- iomap: fault in smaller chunks for non-large folio mappings
  (bsc#1012628).
- ACPI: APEI: EINJ: Fix einj_dev release leak (bsc#1012628).
- i2c: acpi: Unbind mux adapters before delete (bsc#1012628).
- HID: i2c-hid: elan: fix reset suspend current leakage
  (bsc#1012628).
- scsi: core: Handle devices which return an unusually large
  VPD page count (bsc#1012628).
- net/ipv6: Fix route deleting failure when metric equals 0
  (bsc#1012628).
- net/9p: fix uninit-value in p9_client_rpc() (bsc#1012628).
- net/tcp: Don't consider TCP_CLOSE in TCP_AO_ESTABLISHED
  (bsc#1012628).
- selftests: net: lib: support errexit with busywait
  (bsc#1012628).
- selftests: net: lib: avoid error removing empty netns name
  (bsc#1012628).
- mm/ksm: fix ksm_pages_scanned accounting (bsc#1012628).
- mm/ksm: fix ksm_zero_pages accounting (bsc#1012628).
- kmsan: do not wipe out origin when doing partial unpoisoning
  (bsc#1012628).
- tpm_tis: Do *not* flush uninitialized work (bsc#1012628).
- cpufreq: amd-pstate: Fix the inconsistency in max frequency
  units (bsc#1012628).
- intel_th: pci: Add Meteor Lake-S CPU support (bsc#1012628).
- rtla/timerlat: Fix histogram report when a cpu count is 0
  (bsc#1012628).
- sparc64: Fix number of online CPUs (bsc#1012628).
- mm/hugetlb: do not call vma_add_reservation upon ENOMEM
  (bsc#1012628).
- mm/cma: drop incorrect alignment check in cma_init_reserved_mem
  (bsc#1012628).
- mm/hugetlb: pass correct order_per_bit to
  cma_declare_contiguous_nid (bsc#1012628).
- mm: /proc/pid/smaps_rollup: avoid skipping vma after getting
  mmap_lock again (bsc#1012628).
- mm/memory-failure: fix handling of dissolved but not taken
  off from buddy pages (bsc#1012628).
- mm/vmalloc: fix vmalloc which may return null if called with
  __GFP_NOFAIL (bsc#1012628).
- selftests/mm: compaction_test: fix incorrect write of zero to
  nr_hugepages (bsc#1012628).
- selftests/mm: fix build warnings on ppc64 (bsc#1012628).
- selftests/mm: compaction_test: fix bogus test success on Aarch64
  (bsc#1012628).
- watchdog: rti_wdt: Set min_hw_heartbeat_ms to accommodate a
  safety margin (bsc#1012628).
- bonding: fix oops during rmmod (bsc#1012628).
- irqchip/riscv-intc: Prevent memory leak when
  riscv_intc_init_common() fails (bsc#1012628).
- wifi: ath10k: fix QCOM_RPROC_COMMON dependency (bsc#1012628).
- kdb: Fix buffer overflow during tab-complete (bsc#1012628).
- kdb: Use format-strings rather than '\0' injection in kdb_read()
  (bsc#1012628).
- kdb: Fix console handling when editing and tab-completing
  commands (bsc#1012628).
- kdb: Merge identical case statements in kdb_read()
  (bsc#1012628).
- kdb: Use format-specifiers rather than memset() for padding
  in kdb_read() (bsc#1012628).
- Revert "xsk: Support redirect to any socket bound to the same
  umem" (bsc#1012628).
- Revert "xsk: Document ability to redirect to any socket bound
  to the same umem" (bsc#1012628).
- Revert "perf record: Reduce memory for recording
  PERF_RECORD_LOST_SAMPLES event" (bsc#1012628).
- sparc: move struct termio to asm/termios.h (bsc#1012628).
- ext4: Fixes len calculation in mpage_journal_page_buffers
  (bsc#1012628).
- ext4: set type of ac_groups_linear_remaining to __u32 to avoid
  overflow (bsc#1012628).
- ext4: fix mb_cache_entry's e_refcnt leak in
  ext4_xattr_block_cache_find() (bsc#1012628).
- riscv: dts: starfive: Remove PMIC interrupt info for Visionfive
  2 board (bsc#1012628).
- ARM: dts: samsung: smdkv310: fix keypad no-autorepeat
  (bsc#1012628).
- ARM: dts: samsung: smdk4412: fix keypad no-autorepeat
  (bsc#1012628).
- ARM: dts: samsung: exynos4412-origen: fix keypad no-autorepeat
  (bsc#1012628).
- parisc: Define HAVE_ARCH_HUGETLB_UNMAPPED_AREA (bsc#1012628).
- parisc: Define sigset_t in parisc uapi header (bsc#1012628).
- s390/ap: Fix crash in AP internal function modify_bitmap()
  (bsc#1012628).
- s390/cpacf: Split and rework cpacf query functions
  (bsc#1012628).
- s390/cpacf: Make use of invalid opcode produce a link error
  (bsc#1012628).
- i3c: master: svc: fix invalidate IBI type and miss call client
  IBI handler (bsc#1012628).
- genirq/irqdesc: Prevent use-after-free in irq_find_at_or_after()
  (bsc#1012628).
- hwmon: (ltc2992) Fix memory leak in ltc2992_parse_dt()
  (bsc#1012628).
- riscv: enable HAVE_ARCH_HUGE_VMAP for XIP kernel (bsc#1012628).
- ASoC: SOF: ipc4-topology: Fix input format query of process
  modules without base extension (bsc#1012628).
- ALSA: ump: Don't clear bank selection after sending a program
  change (bsc#1012628).
- ALSA: ump: Don't accept an invalid UMP protocol number
  (bsc#1012628).
- EDAC/amd64: Convert PCIBIOS_* return codes to errnos
  (bsc#1012628).
- EDAC/igen6: Convert PCIBIOS_* return codes to errnos
  (bsc#1012628).
- cifs: fix creating sockets when using sfu mount options
  (bsc#1012628).
- nfs: fix undefined behavior in nfs_block_bits() (bsc#1012628).
- NFS: Fix READ_PLUS when server doesn't support OP_READ_PLUS
  (bsc#1012628).
- eventfs: Fix a possible null pointer dereference in
  eventfs_find_events() (bsc#1012628).
- eventfs: Keep the directories from having the same inode number
  as files (bsc#1012628).
- tracefs: Clear EVENT_INODE flag in tracefs_drop_inode()
  (bsc#1012628).
- btrfs: qgroup: update rescan message levels and error codes
  (bsc#1012628).
- btrfs: qgroup: fix qgroup id collision across mounts
  (bsc#1012628).
- btrfs: protect folio::private when attaching extent buffer
  folios (bsc#1012628).
- btrfs: fix crash on racing fsync and size-extending write into
  prealloc (bsc#1012628).
- btrfs: fix leak of qgroup extent records after transaction abort
  (bsc#1012628).
- ALSA: seq: Fix incorrect UMP type for system messages
  (bsc#1012628).
- bpf: fix multi-uprobe PID filtering logic (bsc#1012628).
- powerpc/64/bpf: fix tail calls for PCREL addressing
  (bsc#1012628).
- powerpc/bpf: enforce full ordering for ATOMIC operations with
  BPF_FETCH (bsc#1012628).
- nilfs2: fix potential kernel bug due to lack of writeback flag
  waiting (bsc#1012628).
- nilfs2: fix nilfs_empty_dir() misjudgment and long loop on
  I/O errors (bsc#1012628).
- smb: client: fix deadlock in smb2_find_smb_tcon() (bsc#1012628).
- Rename to
  patches.kernel.org/6.9.5-149-btrfs-re-introduce-norecovery-mount-option.patch.
- commit 5288e50
* Sun Jun 16 2024 mkubecek@suse.cz
- update to 6.10-rc4
- update configs
  - SERIAL_SC16IS7XX_CORE renamed to SERIAL_SC16IS7XX
- commit 3306b36
* Sat Jun 15 2024 tiwai@suse.de
- thermal: core: Change PM notifier priority to the minimum
  (bsc#1223194).
- commit 58c58d8
* Fri Jun 14 2024 jslaby@suse.cz
- Revert "e1000e: move force SMBUS near the end of enable_ulp function"
  This reverts commit 5d33711db052b7c9a1f49eff54bc13dd696f7385, it causes
  another regression. See:
  https://lore.kernel.org/all/20240611062416.16440-1-hui.wang@canonical.com/
- commit dc37293
* Fri Jun 14 2024 jslaby@suse.cz
- e1000e: move force SMBUS near the end of enable_ulp function
  (<ZmfcJsyCB6M3wr84@pirotess>).
- commit 5d33711
* Thu Jun 13 2024 fvogt@suse.de
- rpm/kernel-obs-build.spec.in: Add iso9660 (bsc#1226212)
  Some builds don't just create an iso9660 image, but also mount it during
  build.
- commit aaee141
* Wed Jun 12 2024 jslaby@suse.cz
- Linux 6.9.4 (bsc#1012628).
- platform/x86/intel-uncore-freq: Don't present root domain on
  error (bsc#1012628).
- platform/x86/intel/tpmi: Handle error from tpmi_process_info()
  (bsc#1012628).
- genirq/cpuhotplug, x86/vector: Prevent vector leak during CPU
  offline (bsc#1012628).
- x86/topology/intel: Unlock CPUID before evaluating anything
  (bsc#1012628).
- KVM: x86: Don't advertise guest.MAXPHYADDR as host.MAXPHYADDR
  in CPUID (bsc#1012628).
- x86/pci: Skip early E820 check for ECAM region (bsc#1012628).
- x86/topology: Handle bogus ACPI tables correctly (bsc#1012628).
- efi: libstub: only free priv.runtime_map when allocated
  (bsc#1012628).
- x86/efistub: Omit physical KASLR when memory reservations exist
  (bsc#1012628).
- Revert "drm: Make drivers depends on DRM_DW_HDMI" (bsc#1012628).
- ALSA: seq: ump: Fix swapped song position pointer data
  (bsc#1012628).
- riscv: prevent pt_regs corruption for secondary idle threads
  (bsc#1012628).
- hwmon: (shtc1) Fix property misspelling (bsc#1012628).
- hwmon: (intel-m10-bmc-hwmon) Fix multiplier for N6000 board
  power sensor (bsc#1012628).
- drm/panel: sitronix-st7789v: fix display size for
  jt240mhqs_hwt_ek_e3 panel (bsc#1012628).
- drm/panel: sitronix-st7789v: tweak timing for
  jt240mhqs_hwt_ek_e3 panel (bsc#1012628).
- drm/panel: sitronix-st7789v: fix timing for jt240mhqs_hwt_ek_e3
  panel (bsc#1012628).
- powerpc/pseries/lparcfg: drop error message from guest name
  lookup (bsc#1012628).
- ALSA: seq: Fix yet another spot for system message conversion
  (bsc#1012628).
- ipvlan: Dont Use skb->sk in ipvlan_process_v{4,6}_outbound
  (bsc#1012628).
- net: ena: Fix redundant device NUMA node override (bsc#1012628).
- ice: fix 200G PHY types to link speed mapping (bsc#1012628).
- net: dsa: microchip: fix RGMII error in KSZ DSA driver
  (bsc#1012628).
- ipv4: correctly iterate over the target netns in
  inet_dump_ifaddr() (bsc#1012628).
- net: fix __dst_negative_advice() race (bsc#1012628).
- inet: introduce dst_rtable() helper (bsc#1012628).
- ipv6: introduce dst_rt6_info() helper (bsc#1012628).
- drm/amdgpu: Adjust logic in amdgpu_device_partner_bandwidth()
  (bsc#1012628).
- spi: stm32: Don't warn about spurious interrupts (bsc#1012628).
- kheaders: use `command -v` to test for existence of `cpio`
  (bsc#1012628).
- drm/i915/gt: Fix CCS id's calculation for CCS mode setting
  (bsc#1012628).
- drm/i915/guc: avoid FIELD_PREP warning (bsc#1012628).
- kconfig: fix comparison to constant symbols, 'm', 'n'
  (bsc#1012628).
- net/sched: taprio: extend minimum interval restriction to
  entire cycle too (bsc#1012628).
- net/sched: taprio: make q->picos_per_byte available to
  fill_sched_entry() (bsc#1012628).
- netfilter: nft_fib: allow from forward/input without iif
  selector (bsc#1012628).
- netfilter: tproxy: bail out if IP has been disabled on the
  device (bsc#1012628).
- netfilter: nft_payload: skbuff vlan metadata mangle support
  (bsc#1012628).
- net: ti: icssg-prueth: Fix start counter for ft1 filter
  (bsc#1012628).
- block: stack max_user_sectors (bsc#1012628).
- sd: also set max_user_sectors when setting max_sectors
  (bsc#1012628).
- ALSA: seq: Don't clear bank selection at event -> UMP MIDI2
  conversion (bsc#1012628).
- ALSA: seq: Fix missing bank setup between MIDI1/MIDI2 UMP
  conversion (bsc#1012628).
- drm/xe: Only use reserved BCS instances for usm migrate exec
  queue (bsc#1012628).
- drm/xe: Change pcode timeout to 50msec while polling again
  (bsc#1012628).
- drm/xe: check pcode init status only on root gt of root tile
  (bsc#1012628).
- drm/xe: Add dbg messages on the suspend resume functions
  (bsc#1012628).
- selftests: mptcp: join: mark 'fail' tests as flaky
  (bsc#1012628).
- selftests: mptcp: add ms units for tc-netem delay (bsc#1012628).
- selftests: mptcp: join: mark 'fastclose' tests as flaky
  (bsc#1012628).
- selftests: mptcp: simult flows: mark 'unbalanced' tests as flaky
  (bsc#1012628).
- ice: fix accounting if a VLAN already exists (bsc#1012628).
- idpf: don't enable NAPI and interrupts prior to allocating Rx
  buffers (bsc#1012628).
- net: micrel: Fix lan8841_config_intr after getting out of
  sleep mode (bsc#1012628).
- net:fec: Add fec_enet_deinit() (bsc#1012628).
- ipv4: Fix address dump when IPv4 is disabled on an interface
  (bsc#1012628).
- null_blk: Fix return value of nullb_device_power_store()
  (bsc#1012628).
- bpf: Allow delete from sockmap/sockhash only if update is
  allowed (bsc#1012628).
- ASoC: cs42l43: Only restrict 44.1kHz for the ASP (bsc#1012628).
- net: usb: smsc95xx: fix changing LED_SEL bit value updated
  from EEPROM (bsc#1012628).
- Octeontx2-pf: Free send queue buffers incase of leaf to inner
  (bsc#1012628).
- af_unix: Read sk->sk_hash under bindlock during bind()
  (bsc#1012628).
- af_unix: Annotate data-race around unix_sk(sk)->addr
  (bsc#1012628).
- enic: Validate length of nl attributes in enic_set_vf_port
  (bsc#1012628).
- ALSA: hda/realtek: Adjust G814JZR to use SPI init for amp
  (bsc#1012628).
- ALSA: core: Remove debugfs at disconnection (bsc#1012628).
- netkit: Fix pkt_type override upon netkit pass verdict
  (bsc#1012628).
- netkit: Fix setting mac address in l2 mode (bsc#1012628).
- bpf: Fix potential integer overflow in resolve_btfids
  (bsc#1012628).
- dma-buf/sw-sync: don't enable IRQ from sync_print_obj()
  (bsc#1012628).
- net/mlx5e: Fix UDP GSO for encapsulated packets (bsc#1012628).
- net/mlx5e: Use rx_missed_errors instead of rx_dropped for
  reporting buffer exhaustion (bsc#1012628).
- net/mlx5e: Fix IPsec tunnel mode offload feature check
  (bsc#1012628).
- net/mlx5: Use mlx5_ipsec_rx_status_destroy to correctly delete
  status rules (bsc#1012628).
- net/mlx5: Fix MTMP register capability offset in MCAM register
  (bsc#1012628).
- net/mlx5: Do not query MPIR on embedded CPU function
  (bsc#1012628).
- net/mlx5: Lag, do bond only if slaves agree on roce state
  (bsc#1012628).
- net: phy: micrel: set soft_reset callback to genphy_soft_reset
  for KSZ8061 (bsc#1012628).
- drm/amd/display: Enable colorspace property for MST connectors
  (bsc#1012628).
- nvmet: fix ns enable/disable possible hang (bsc#1012628).
- nvme-multipath: fix io accounting on failover (bsc#1012628).
- nvme: fix multipath batched completion accounting (bsc#1012628).
- dma-mapping: benchmark: handle NUMA_NO_NODE correctly
  (bsc#1012628).
- dma-mapping: benchmark: fix node id validation (bsc#1012628).
- dma-mapping: benchmark: fix up kthread-related error handling
  (bsc#1012628).
- spi: stm32: Revert change that enabled controller before
  asserting CS (bsc#1012628).
- spi: Don't mark message DMA mapped when no transfer in it is
  (bsc#1012628).
- netfilter: nft_payload: restore vlan q-in-q match support
  (bsc#1012628).
- netfilter: ipset: Add list flush to cancel_gc (bsc#1012628).
- netfilter: nfnetlink_queue: acquire rcu_read_lock() in
  instance_destroy_rcu() (bsc#1012628).
- selftests: net: lib: set 'i' as local (bsc#1012628).
- SUNRPC: Fix loop termination condition in
  gss_free_in_token_pages() (bsc#1012628).
- tpm_tis_spi: Account for SPI header when allocating TPM SPI
  xfer buffer (bsc#1012628).
- tracing/probes: fix error check in parse_btf_field()
  (bsc#1012628).
- cifs: Fix missing set of remote_i_size (bsc#1012628).
- cifs: Set zero_point in the copy_file_range() and
  remap_file_range() (bsc#1012628).
- kasan, fortify: properly rename memintrinsics (bsc#1012628).
- netfs: Fix setting of BDP_ASYNC from iocb flags (bsc#1012628).
- null_blk: fix null-ptr-dereference while configuring 'power'
  and 'submit_queues' (bsc#1012628).
- idpf: Interpret .set_channels() input differently (bsc#1012628).
- ice: Interpret .set_channels() input differently (bsc#1012628).
- drivers/xen: Improve the late XenStore init protocol
  (bsc#1012628).
- nfc: nci: Fix handling of zero-length payload packets in
  nci_rx_work() (bsc#1012628).
- net: relax socket state check at accept time (bsc#1012628).
- tls: fix missing memory barrier in tls_init (bsc#1012628).
- net: fec: avoid lock evasion when reading pps_enable
  (bsc#1012628).
- Revert "ixgbe: Manual AN-37 for troublesome link partners for
  X550 SFI" (bsc#1012628).
- riscv: selftests: Add hwprobe binaries to .gitignore
  (bsc#1012628).
- riscv: stacktrace: fixed walk_stackframe() (bsc#1012628).
- i3c: master: svc: change ENXIO to EAGAIN when IBI occurs during
  start frame (bsc#1012628).
- riscv: cpufeature: Fix extension subset checking (bsc#1012628).
- riscv: cpufeature: Fix thead vector hwcap removal (bsc#1012628).
- virtio: delete vq in vp_find_vqs_msix() when request_irq()
  fails (bsc#1012628).
- virtio_balloon: Give the balloon its own wakeup source
  (bsc#1012628).
- net: lan966x: Remove ptp traps in case the ptp is not enabled
  (bsc#1012628).
- rv: Update rv_en(dis)able_monitor doc to match kernel-doc
  (bsc#1012628).
- arm64: asm-bug: Add .align 2 to the end of __BUG_ENTRY
  (bsc#1012628).
- openvswitch: Set the skbuff pkt_type for proper pmtud support
  (bsc#1012628).
- pNFS/filelayout: fixup pNfs allocation modes (bsc#1012628).
- tcp: Fix shift-out-of-bounds in dctcp_update_alpha()
  (bsc#1012628).
- regulator: tps6594-regulator: Correct multi-phase configuration
  (bsc#1012628).
- selftests/net: use tc rule to filter the na packet
  (bsc#1012628).
- selftests: net: Unify code of busywait() and slowwait()
  (bsc#1012628).
- selftests: forwarding: Convert log_test() to recognize RET
  values (bsc#1012628).
- selftests: forwarding: Have RET track kselftest framework
  constants (bsc#1012628).
- selftests: forwarding: Change inappropriate log_test_skip()
  calls (bsc#1012628).
- ipv6: sr: fix memleak in seg6_hmac_init_algo (bsc#1012628).
- af_unix: Update unix_sk(sk)->oob_skb under sk_receive_queue lock
  (bsc#1012628).
- regulator: tps6287x: Force writing VSEL bit (bsc#1012628).
- regulator: pickable ranges: don't always cache vsel
  (bsc#1012628).
- rpcrdma: fix handling for RDMA_CM_EVENT_DEVICE_REMOVAL
  (bsc#1012628).
- sunrpc: fix NFSACL RPC retry on soft mount (bsc#1012628).
- nfs: keep server info for remounts (bsc#1012628).
- NFSv4: Fixup smatch warning for ambiguous return (bsc#1012628).
- ASoC: tas2781: Fix wrong loading calibrated data sequence
  (bsc#1012628).
- ASoC: tas2552: Add TX path for capturing AUDIO-OUT data
  (bsc#1012628).
- nfc: nci: Fix uninit-value in nci_rx_work (bsc#1012628).
- selftests: net: kill smcrouted in the cleanup logic in amt.sh
  (bsc#1012628).
- ipv6: sr: fix missing sk_buff release in seg6_input_core
  (bsc#1012628).
- net: Always descend into dsa/ folder with CONFIG_NET_DSA enabled
  (bsc#1012628).
- x86/kconfig: Select ARCH_WANT_FRAME_POINTERS again when
  UNWINDER_FRAME_POINTER=y (bsc#1012628).
- Update config files.
- ubsan: Restore dependency on ARCH_HAS_UBSAN (bsc#1012628).
- perf/arm-dmc620: Fix lockdep assert in ->event_init()
  (bsc#1012628).
- xen/x86: add extra pages to unpopulated-alloc if available
  (bsc#1012628).
- regulator: bd71828: Don't overwrite runtime voltages
  (bsc#1012628).
- blk-cgroup: Properly propagate the iostat update up the
  hierarchy (bsc#1012628).
- blk-cgroup: fix list corruption from reorder of WRITE ->lqueued
  (bsc#1012628).
- blk-cgroup: fix list corruption from resetting io stat
  (bsc#1012628).
- Bluetooth: L2CAP: Fix div-by-zero in l2cap_le_flowctl_init()
  (bsc#1012628).
- Bluetooth: ISO: Handle PA sync when no BIGInfo reports are
  generated (bsc#1012628).
- drm/nouveau: use tile_mode and pte_kind for VM_BIND bo
  allocations (bsc#1012628).
- ALSA: hda/realtek: Drop doubly quirk entry for 103c:8a2e
  (bsc#1012628).
- ASoC: rt715-sdca-sdw: Fix wrong complete waiting in
  rt715_dev_resume() (bsc#1012628).
- ASoC: mediatek: mt8192: fix register configuration for tdm
  (bsc#1012628).
- ALSA: hda: cs35l56: Fix lifetime of cs_dsp instance
  (bsc#1012628).
- ALSA: hda: hda_component: Initialize shared data during bind
  callback (bsc#1012628).
- ALSA: hda/cs_dsp_ctl: Use private_free for control cleanup
  (bsc#1012628).
- KVM: arm64: Destroy mpidr_data for 'late' vCPU creation
  (bsc#1012628).
- KVM: PPC: Book3S HV nestedv2: Fix an error handling path in
  gs_msg_ops_kvmhv_nestedv2_config_fill_info() (bsc#1012628).
- KVM: PPC: Book3S HV nestedv2: Cancel pending DEC exception
  (bsc#1012628).
- powerpc/bpf/32: Fix failing test_bpf tests (bsc#1012628).
- printk: Fix LOG_CPU_MAX_BUF_SHIFT when BASE_SMALL is enabled
  (bsc#1012628).
- null_blk: Fix the WARNING: modpost: missing MODULE_DESCRIPTION()
  (bsc#1012628).
- ASoC: tas2781: Fix a warning reported by robot kernel test
  (bsc#1012628).
- drm/msm/a6xx: Avoid a nullptr dereference when speedbin setting
  fails (bsc#1012628).
- drm/msm/adreno: fix CP cycles stat retrieval on a7xx
  (bsc#1012628).
- selftests/powerpc/dexcr: Add -no-pie to hashchk tests
  (bsc#1012628).
- ASoC: amd: acp: fix for acp platform device creation failure
  (bsc#1012628).
- drm: zynqmp_dpsub: Always register bridge (bsc#1012628).
- Revert "drm/bridge: ti-sn65dsi83: Fix enable error path"
  (bsc#1012628).
- media: cec: core: avoid confusing "transmit timed out" message
  (bsc#1012628).
- media: cec: core: avoid recursive cec_claim_log_addrs
  (bsc#1012628).
- media: cec: cec-api: add locking in cec_release() (bsc#1012628).
- media: cec: cec-adap: always cancel work in cec_transmit_msg_fh
  (bsc#1012628).
- media: sunxi: a83-mips-csi2: also select GENERIC_PHY
  (bsc#1012628).
- cxl/region: Fix cxlr_pmem leaks (bsc#1012628).
- cxl/trace: Correct DPA field masks for general_media & dram
  events (bsc#1012628).
- um: Fix the declaration of kasan_map_memory (bsc#1012628).
- um: Fix the -Wmissing-prototypes warning for get_thread_reg
  (bsc#1012628).
- um: Fix the -Wmissing-prototypes warning for __switch_mm
  (bsc#1012628).
- ASoC: SOF: debug: Handle cases when fw_lib_prefix is not set,
  NULL (bsc#1012628).
- powerpc/pseries: Add failure related checks for h_get_mpp and
  h_get_ppp (bsc#1012628).
- media: flexcop-usb: fix sanity check of bNumEndpoints
  (bsc#1012628).
- platform/x86: thinkpad_acpi: Take hotkey_mutex during
  hotkey_exit() (bsc#1012628).
- tools/arch/x86/intel_sdsi: Fix meter_certificate decoding
  (bsc#1012628).
- tools/arch/x86/intel_sdsi: Fix meter_show display (bsc#1012628).
- tools/arch/x86/intel_sdsi: Fix maximum meter bundle length
  (bsc#1012628).
- media: mediatek: vcodec: fix possible unbalanced PM counter
  (bsc#1012628).
- drm/amdgpu: Fix buffer size in gfx_v9_4_3_init_
  cp_compute_microcode() and rlc_microcode() (bsc#1012628).
- drm/amdgpu: init microcode chip name from ip versions
  (bsc#1012628).
- Input: cyapa - add missing input core locking to suspend/resume
  functions (bsc#1012628).
- string: Prepare to merge strcat KUnit tests into string_kunit.c
  (bsc#1012628).
- string: Prepare to merge strscpy_kunit.c into string_kunit.c
  (bsc#1012628).
- string_kunit: Add test cases for str*cmp functions
  (bsc#1012628).
- drm/bridge: imx: Fix unmet depenency for
  PHY_FSL_SAMSUNG_HDMI_PHY (bsc#1012628).
- drm: Make drivers depends on DRM_DW_HDMI (bsc#1012628).
- media: stk1160: fix bounds checking in stk1160_copy_video()
  (bsc#1012628).
- drm/bridge: tc358775: fix support for jeida-18 and jeida-24
  (bsc#1012628).
- drm/msm/dpu: Add callback function pointer check before its call
  (bsc#1012628).
- fs/ntfs3: Use variable length array instead of fixed size
  (bsc#1012628).
- fs/ntfs3: Use 64 bit variable to avoid 32 bit overflow
  (bsc#1012628).
- fs/ntfs3: Check 'folio' pointer for NULL (bsc#1012628).
- um: vector: fix bpfflash parameter evaluation (bsc#1012628).
- um: Add winch to winch_handlers before registering winch IRQ
  (bsc#1012628).
- um: Fix return value in ubd_init() (bsc#1012628).
- drm/meson: gate px_clk when setting rate (bsc#1012628).
- drm/mediatek: dp: Fix mtk_dp_aux_transfer return value
  (bsc#1012628).
- drm/msm/dpu: Allow configuring multiple active DSC blocks
  (bsc#1012628).
- drm/msm/dpu: Always flush the slave INTF on the CTL
  (bsc#1012628).
- drm/msm/dsi: Print dual-DSI-adjusted pclk instead of original
  mode pclk (bsc#1012628).
- media: ov2680: Do not fail if data-lanes property is absent
  (bsc#1012628).
- media: ov2680: Allow probing if link-frequencies is absent
  (bsc#1012628).
- media: ov2680: Clear the 'ret' variable on success
  (bsc#1012628).
- media: v4l: Don't turn on privacy LED if streamon fails
  (bsc#1012628).
- media: ti: j721e-csi2rx: Fix races while restarting DMA
  (bsc#1012628).
- Input: pm8xxx-vibrator - correct VIB_MAX_LEVELS calculation
  (bsc#1012628).
- phy: qcom: qmp-combo: fix sm8650 voltage swing table
  (bsc#1012628).
- x86/percpu: Use __force to cast from __percpu address space
  (bsc#1012628).
- x86/percpu: Unify arch_raw_cpu_ptr() defines (bsc#1012628).
- mmc: sdhci_am654: Fix ITAPDLY for HS400 timing (bsc#1012628).
- mmc: sdhci_am654: Add ITAPDLYSEL in sdhci_j721e_4bit_set_clock
  (bsc#1012628).
- mmc: sdhci_am654: Add OTAP/ITAP delay enable (bsc#1012628).
- mmc: sdhci_am654: Write ITAPDLY for DDR52 timing (bsc#1012628).
- mmc: sdhci_am654: Add tuning algorithm for delay chain
  (bsc#1012628).
- Input: ioc3kbd - add device table (bsc#1012628).
- Input: ims-pcu - fix printf string overflow (bsc#1012628).
- gpiolib: acpi: Fix failed in acpi_gpiochip_find() by adding
  parent node match (bsc#1012628).
- mailbox: mtk-cmdq: Fix pm_runtime_get_sync() warning in mbox
  shutdown (bsc#1012628).
- selftests/harness: use 1024 in place of LINE_MAX (bsc#1012628).
- ocfs2: correctly use ocfs2_find_next_zero_bit() (bsc#1012628).
- Revert "selftests/harness: remove use of LINE_MAX"
  (bsc#1012628).
- dt-bindings: PCI: rockchip,rk3399-pcie: Add missing maxItems
  to ep-gpios (bsc#1012628).
- s390/boot: Remove alt_stfle_fac_list from decompressor
  (bsc#1012628).
- s390/ap: Fix bind complete udev event sent after each AP bus
  scan (bsc#1012628).
- s390/ipl: Fix incorrect initialization of nvme dump block
  (bsc#1012628).
- s390/ipl: Fix incorrect initialization of len fields in nvme
  reipl block (bsc#1012628).
- s390/stackstrace: Detect vdso stack frames (bsc#1012628).
- s390/vdso: Introduce and use struct stack_frame_vdso_wrapper
  (bsc#1012628).
- s390/stacktrace: Improve detection of invalid instruction
  pointers (bsc#1012628).
- s390/stacktrace: Skip first user stack frame (bsc#1012628).
- s390/stacktrace: Merge perf_callchain_user() and
  arch_stack_walk_user() (bsc#1012628).
- s390/ftrace: Use unwinder instead of __builtin_return_address()
  (bsc#1012628).
- s390/vdso: Use standard stack frame layout (bsc#1012628).
- s390/vdso: Create .build-id links for unstripped vdso files
  (bsc#1012628).
- s390/vdso: Generate unwind information for C modules
  (bsc#1012628).
- LoongArch: Fix callchain parse error with kernel tracepoint
  events again (bsc#1012628).
- perf pmu: Count sys and cpuid JSON events separately
  (bsc#1012628).
- perf pmu: Assume sysfs events are always the same case
  (bsc#1012628).
- perf tools: Add/use PMU reverse lookup from config to name
  (bsc#1012628).
- perf tools: Use pmus to describe type from attribute
  (bsc#1012628).
- perf stat: Don't display metric header for non-leader uncore
  events (bsc#1012628).
- perf annotate: Fix segfault on sample histogram (bsc#1012628).
- usb: fotg210: Add missing kernel doc description (bsc#1012628).
- f2fs: fix to add missing iput() in gc_data_segment()
  (bsc#1012628).
- backlight: mp3309c: Fix signedness bug in mp3309c_parse_fwnode()
  (bsc#1012628).
- perf daemon: Fix file leak in daemon_session__control
  (bsc#1012628).
- libsubcmd: Fix parse-options memory leak (bsc#1012628).
- serial: sh-sci: protect invalidating RXDMA on shutdown
  (bsc#1012628).
- fuse: clear FR_SENT when re-adding requests into pending list
  (bsc#1012628).
- fuse: set FR_PENDING atomically in fuse_resend() (bsc#1012628).
- f2fs: compress: don't allow unaligned truncation on released
  compress inode (bsc#1012628).
- f2fs: fix to release node block count in error path of
  f2fs_new_node_page() (bsc#1012628).
- f2fs: compress: fix to cover {reserve,release}_compress_blocks()
  w/ cp_rwsem lock (bsc#1012628).
- f2fs: compress: fix error path of inc_valid_block_count()
  (bsc#1012628).
- f2fs: compress: fix to update i_compr_blocks correctly
  (bsc#1012628).
- perf symbols: Fix ownership of string in dso__load_vmlinux()
  (bsc#1012628).
- perf symbols: Update kcore map before merging in remaining
  symbols (bsc#1012628).
- perf symbols: Remove map from list before updating addresses
  (bsc#1012628).
- perf dwarf-aux: Fix build with HAVE_DWARF_CFI_SUPPORT
  (bsc#1012628).
- perf dwarf-aux: Add die_collect_vars() (bsc#1012628).
- perf thread: Fixes to thread__new() related to initializing comm
  (bsc#1012628).
- perf report: Avoid SEGV in report__setup_sample_type()
  (bsc#1012628).
- perf ui browser: Avoid SEGV on title (bsc#1012628).
- f2fs: fix block migration when section is not aligned to pow2
  (bsc#1012628).
- PCI/EDR: Align EDR_PORT_LOCATE_DSM with PCI Firmware r3.3
  (bsc#1012628).
- PCI/EDR: Align EDR_PORT_DPC_ENABLE_DSM with PCI Firmware r3.3
  (bsc#1012628).
- spmi: pmic-arb: Replace three IS_ERR() calls by null pointer
  checks in spmi_pmic_arb_probe() (bsc#1012628).
- extcon: max8997: select IRQ_DOMAIN instead of depending on it
  (bsc#1012628).
- perf annotate: Fix memory leak in annotated_source
  (bsc#1012628).
- perf ui browser: Don't save pointer to stack memory
  (bsc#1012628).
- perf bench internals inject-build-id: Fix trap divide when
  collecting just one DSO (bsc#1012628).
- i2c: synquacer: Fix an error handling path in
  synquacer_i2c_probe() (bsc#1012628).
- i2c: cadence: Avoid fifo clear after start (bsc#1012628).
- ppdev: Add an error check in register_device (bsc#1012628).
- stm class: Fix a double free in stm_register_device()
  (bsc#1012628).
- usb: gadget: u_audio: Clear uac pointer when freed
  (bsc#1012628).
- usb: gadget: u_audio: Fix race condition use of controls after
  free during gadget unbind (bsc#1012628).
- dmaengine: idxd: Avoid unnecessary destruction of file_ida
  (bsc#1012628).
- dt-bindings: phy: qcom,usb-snps-femto-v2: use correct fallback
  for sc8180x (bsc#1012628).
- dt-bindings: phy: qcom,sc8280xp-qmp-ufs-phy: fix msm899[68]
  power-domains (bsc#1012628).
- dt-bindings: phy: qcom,sc8280xp-qmp-pcie-phy: fix
  x1e80100-gen3x2 schema (bsc#1012628).
- watchdog: sa1100: Fix PTR_ERR_OR_ZERO() vs NULL check in
  sa1100dog_probe() (bsc#1012628).
- watchdog: bd9576: Drop "always-running" property (bsc#1012628).
- watchdog: cpu5wdt.c: Fix use-after-free bug caused by
  cpu5wdt_trigger (bsc#1012628).
- iio: adc: PAC1934: fix accessing out of bounds array index
  (bsc#1012628).
- pinctrl: qcom: pinctrl-sm7150: Fix sdc1 and ufs special pins
  regs (bsc#1012628).
- dt-bindings: pinctrl: mediatek: mt7622: fix array properties
  (bsc#1012628).
- VMCI: Fix an error handling path in vmci_guest_probe_device()
  (bsc#1012628).
- PCI: of_property: Return error for int_map allocation failure
  (bsc#1012628).
- ovl: remove upper umask handling from ovl_create_upper()
  (bsc#1012628).
- leds: pwm: Disable PWM when going to suspend (bsc#1012628).
- usb: xhci: check if 'requested segments' exceeds ERST capacity
  (bsc#1012628).
- docs: iio: adis16475: fix device files tables (bsc#1012628).
- riscv: Flush the instruction cache during SMP bringup
  (bsc#1012628).
- perf intel-pt: Fix unassigned instruction op (discovered by
  MemorySanitizer) (bsc#1012628).
- PCI: Wait for Link Training==0 before starting Link retrain
  (bsc#1012628).
- pinctrl: renesas: rzg2l: Limit 2.5V power supply to Ethernet
  interfaces (bsc#1012628).
- microblaze: Remove early printk call from cpuinfo-static.c
  (bsc#1012628).
- microblaze: Remove gcc flag for non existing early_printk.c file
  (bsc#1012628).
- udf: Convert udf_expand_file_adinicb() to use a folio
  (bsc#1012628).
- pinctrl: renesas: r8a779h0: Fix IRQ suffixes (bsc#1012628).
- fpga: region: add owner module and take its refcount
  (bsc#1012628).
- vfio/pci: fix potential memory leak in vfio_intx_enable()
  (bsc#1012628).
- coresight: etm4x: Fix access to resource selector registers
  (bsc#1012628).
- coresight: etm4x: Safe access for TRCQCLTR (bsc#1012628).
- coresight: etm4x: Do not save/restore Data trace control
  registers (bsc#1012628).
- coresight: etm4x: Do not hardcode IOMEM access for register
  restore (bsc#1012628).
- iio: adc: adi-axi-adc: only error out in major version mismatch
  (bsc#1012628).
- iio: pressure: dps310: support negative temperature values
  (bsc#1012628).
- perf test shell arm_coresight: Increase buffer size for
  Coresight basic tests (bsc#1012628).
- perf docs: Document bpf event modifier (bsc#1012628).
- perf dwarf-aux: Check pointer offset when checking variables
  (bsc#1012628).
- coresight: etm4x: Fix unbalanced pm_runtime_enable()
  (bsc#1012628).
- riscv: dts: starfive: visionfive 2: Remove non-existing I2S
  hardware (bsc#1012628).
- riscv: dts: starfive: visionfive 2: Remove non-existing TDM
  hardware (bsc#1012628).
- iio: adc: stm32: Fixing err code to not indicate success
  (bsc#1012628).
- f2fs: write missing last sum blk of file pinning section
  (bsc#1012628).
- f2fs: fix to check pinfile flag in f2fs_move_file_range()
  (bsc#1012628).
- f2fs: fix to relocate check condition in f2fs_fallocate()
  (bsc#1012628).
- f2fs: compress: fix to relocate check condition in
  f2fs_ioc_{,de}compress_file() (bsc#1012628).
- f2fs: compress: fix to relocate check condition in
  f2fs_{release,reserve}_compress_blocks() (bsc#1012628).
- perf bench uprobe: Remove lib64 from libc.so.6 binary path
  (bsc#1012628).
- dt-bindings: PCI: rcar-pci-host: Add missing IOMMU properties
  (bsc#1012628).
- perf record: Fix debug message placement for test consumption
  (bsc#1012628).
- perf map: Remove kernel map before updating start and end
  addresses (bsc#1012628).
- perf tests: Apply attributes to all events in object code
  reading test (bsc#1012628).
- perf tests: Make "test data symbol" more robust on Neoverse N1
  (bsc#1012628).
- arm64: dts: meson: fix S4 power-controller node (bsc#1012628).
- interconnect: qcom: qcm2290: Fix mas_snoc_bimc QoS port
  assignment (bsc#1012628).
- module: don't ignore sysfs_create_link() failures (bsc#1012628).
- serial: sc16is7xx: add proper sched.h include for
  sched_set_fifo() (bsc#1012628).
- PCI: tegra194: Fix probe path for Endpoint mode (bsc#1012628).
- PCI: dwc: ep: Fix DBI access failure for drivers requiring
  refclk from host (bsc#1012628).
- greybus: arche-ctrl: move device table to its right location
  (bsc#1012628).
- serial: max3100: Fix bitwise types (bsc#1012628).
- serial: max3100: Update uart_driver_registered on driver removal
  (bsc#1012628).
- serial: max3100: Lock port->lock when calling
  uart_handle_cts_change() (bsc#1012628).
- perf annotate: Fix annotation_calc_lines() to pass correct
  address to get_srcline() (bsc#1012628).
- firmware: dmi-id: add a release callback function (bsc#1012628).
- dmaengine: idma64: Add check for dma_set_max_seg_size
  (bsc#1012628).
- soundwire: cadence: fix invalid PDI offset (bsc#1012628).
- perf stat: Do not fail on metrics on s390 z/VM systems
  (bsc#1012628).
- perf report: Fix PAI counter names for s390 virtual machines
  (bsc#1012628).
- usb: typec: ucsi: simplify partner's PD caps registration
  (bsc#1012628).
- usb: typec: ucsi: always register a link to USB PD device
  (bsc#1012628).
- usb: typec: ucsi: allow non-partner GET_PDOS for Qualcomm
  devices (bsc#1012628).
- perf sched timehist: Fix -g/--call-graph option failure
  (bsc#1012628).
- perf annotate: Get rid of duplicate --group option item
  (bsc#1012628).
- counter: linux/counter.h: fix Excess kernel-doc description
  warning (bsc#1012628).
- fpga: bridge: add owner module and take its refcount
  (bsc#1012628).
- fpga: manager: add owner module and take its refcount
  (bsc#1012628).
- f2fs: fix to wait on page writeback in __clone_blkaddrs()
  (bsc#1012628).
- f2fs: multidev: fix to recognize valid zero block address
  (bsc#1012628).
- dt-bindings: pinctrl: qcom: update functions to match with
  driver (bsc#1012628).
- greybus: lights: check return of get_channel_from_mode
  (bsc#1012628).
- iio: core: Leave private pointer NULL when no private data
  supplied (bsc#1012628).
- perf probe: Add missing libgen.h header needed for using
  basename() (bsc#1012628).
- perf test: Use a single fd for the child process out/err
  (bsc#1012628).
- perf record: Delete session after stopping sideband thread
  (bsc#1012628).
- perf build: Fix out of tree build related to installation of
  sysreg-defs (bsc#1012628).
- commit ad8659c
* Wed Jun 12 2024 fvogt@suse.de
- rpm/kernel-obs-build.spec.in: Add networking modules for docker
  (bsc#1226211)
  docker needs more networking modules, even legacy iptable_nat and _filter.
- commit 415e132
* Tue Jun 11 2024 jslaby@suse.cz
- Bluetooth: fix connection setup in l2cap_connect
  (https://github.com/bluez/bluez/issues/865).
- commit f3ff049
* Sun Jun  9 2024 mkubecek@suse.cz
- update to 6.10-rc3
- drop 1 mainline patch
  - patches.suse/scsi-core-alua-I-O-errors-for-ALUA-state-transitions.patch
- commit 751e4fb
* Mon Jun  3 2024 mkubecek@suse.cz
- update to 6.10-rc2
- commit 068a181
* Thu May 30 2024 mkubecek@suse.cz
- update to 6.10-rc1
- drop 11 patches (5 mainline, 6 stable)
  - patches.kernel.org/*
  - patches.suse/ACPI-video-Add-backlight-native-quirk-for-Lenovo-Sli.patch
  - patches.suse/btrfs-re-introduce-norecovery-mount-option.patch
  - patches.suse/bus-mhi-host-add-mhi_power_down_no_destroy.patch
  - patches.suse/net-qrtr-support-suspend-hibernation.patch
  - patches.suse/wifi-ath11k-support-hibernation.patch
- refresh
  - patches.rpmify/Add-ksym-provides-tool.patch
  - patches.suse/btrfs-provide-super_operations-get_inode_dev
- disable ARM architectures (need config update)
- new config options
  - General setup
  - BASE_SMALL=n
  - Processor type and features
  - X86_POSTED_MSI=n
  - Virtualization
  - KVM_INTEL_PROVE_VE=n
  - Networking support
  - SMC_LO=n
  - BT_INTEL_PCIE=m
  - File systems
  - EROFS_FS_ZIP_ZSTD=y
  - Security options
  - INIT_MLOCKED_ON_FREE_DEFAULT_ON=n
  - Kernel hacking
  - FTRACE_VALIDATE_RCU_IS_WATCHING=n
  - Network device support
  - PFCP=m
  - AIR_EN8811H_PHY=m
  - PSE_PD692X0=m
  - PSE_TPS23881=m
  - RTW88_8723CS=m
  - RTW89_8922AE=m
  - Hardware Monitoring support
  - SENSORS_LENOVO_EC=m
  - SENSORS_ADP1050=m
  - SENSORS_XDP710=m
  - SENSORS_PWM_FAN=m
  - Graphics support
  - DRM_DISPLAY_DP_AUX_CEC=y
  - DRM_DISPLAY_DP_AUX_CHARDEV=y
  - DRM_WERROR=n
  - Sound card support
  - SND_SOC_AMD_ACP63_TOPLEVEL=m
  - SND_SOC_PCM6240=n
  - X86 Platform Specific Device Drivers
  - YT2_1380=m
  - AMD_MP2_STB=y
  - DELL_UART_BACKLIGHT=m
  - ACPI_QUICKSTART=m
  - MEEGOPAD_ANX7428=m
  - MSI_WMI_PLATFORM=m
  - LENOVO_WMI_CAMERA=m
  - Industrial I/O support
  - AD7173=n
  - AD7944=n
  - AD9739A=n
  - ADI_AXI_DAC=n
  - APDS9306=n
  - Misc drivers
  - TCG_TPM2_HMAC=y
  - I2C_ZHAOXIN=m
  - GPIO_GRANITERAPIDS=m
  - LENOVO_SE10_WDT=m
  - VIDEO_INTEL_IPU6=m
  - HID_WINWING=m
  - RTC_DRV_RX8111=m
  - QAT_VFIO_PCI=m
  - VIRTIO_DEBUG=n
  - FPGA_MGR_XILINX_SELECTMAP=m
  - OF dependent (i386, ppc64le, riscv64)
  - DRM_PANEL_LG_SW43408=n
  - DRM_PANEL_RAYDIUM_RM69380=n
  - DRM_PANEL_SAMSUNG_S6E3FA7=n
  - USB_ONBOARD_DEV=m
  - i386
  - ARM_MHU_V3=m
  - i386/default
  - NET_SB1000=n
  - CAN_SJA1000_ISA=n
  - ppc64le
  - CRASH_HOTPLUG=y
  - CRASH_MAX_MEMORY_RANGES=8192 (default)
  - SERIAL_SC16IS7XX_CORE=n
  - VMGENID=y
  - SOFTLOCKUP_DETECTOR_INTR_STORM=y
  - TEST_FPU=n
  - s390x
  - KERNEL_IMAGE_BASE=0x3FFE0000000 (default)
  - AP=y
  - AP_DEBUG=n
  - HAMRADIO=n
  - SERIAL_SC16IS7XX_CORE=n
  - VMGENID=y
  - s390x/zfcpdump
  - BPF_JIT=n
  - KPROBES=n
  - MEM_ALLOC_PROFILING=n
  - TEST_BITOPS=n
  - riscv64
  - KERNEL_GZIP=y
  - ARCH_MICROCHIP=y
  - I2C_CADENCE=m
  - REGULATOR_SUN20I=m
  - DRM_AMD_SECURE_DISPLAY=n
  - CLK_SOPHGO_CV1800=m
  - ARM_MHU_V3=m
  - TEST_FPU=n
- commit 6be9abf
* Thu May 30 2024 jslaby@suse.cz
- Linux 6.9.3 (bsc#1012628).
- Revert "selftests/sgx: Include KHDR_INCLUDES in Makefile"
  (bsc#1012628).
- Revert "selftests: Compile kselftest headers with -D_GNU_SOURCE"
  (bsc#1012628).
- l2tp: fix ICMP error handling for UDP-encap sockets
  (bsc#1012628).
- net: txgbe: fix to control VLAN strip (bsc#1012628).
- net: wangxun: match VLAN CTAG and STAG features (bsc#1012628).
- net: wangxun: fix to change Rx features (bsc#1012628).
- sched/core: Fix incorrect initialization of the 'burst'
  parameter in cpu_max_write() (bsc#1012628).
- sched/fair: Allow disabling sched_balance_newidle with
  sched_relax_domain_level (bsc#1012628).
- af_packet: do not call packet_read_pending() from
  tpacket_destruct_skb() (bsc#1012628).
- netrom: fix possible dead-lock in nr_rt_ioctl() (bsc#1012628).
- idpf: don't skip over ethtool tcp-data-split setting
  (bsc#1012628).
- selftests/net/lib: no need to record ns name if it already exist
  (bsc#1012628).
- net: qrtr: ns: Fix module refcnt (bsc#1012628).
- libbpf: fix feature detectors when using token_fd (bsc#1012628).
- net: bridge: mst: fix vlan use-after-free (bsc#1012628).
- selftests: net: bridge: increase IGMP/MLD exclude timeout
  membership interval (bsc#1012628).
- net: bridge: xmit: make sure we have at least eth header len
  bytes (bsc#1012628).
- modules: Drop the .export_symbol section from the final modules
  (bsc#1012628).
- tracing/user_events: Fix non-spaced field matching
  (bsc#1012628).
- samples/landlock: Fix incorrect free in populate_ruleset_net
  (bsc#1012628).
- RDMA/cma: Fix kmemleak in rdma_core observed during blktests
  nvme/rdma use siw (bsc#1012628).
- RDMA/IPoIB: Fix format truncation compilation errors
  (bsc#1012628).
- selftests/kcmp: remove unused open mode (bsc#1012628).
- selftests/damon/_damon_sysfs: check errors from nr_schemes
  file reads (bsc#1012628).
- SUNRPC: Fix gss_free_in_token_pages() (bsc#1012628).
- bnxt_re: avoid shift undefined behavior in
  bnxt_qplib_alloc_init_hwq (bsc#1012628).
- of: module: add buffer overflow check in of_modalias()
  (bsc#1012628).
- clk: qcom: apss-ipq-pll: fix PLL rate for IPQ5018 (bsc#1012628).
- clk: qcom: Fix SM_GPUCC_8650 dependencies (bsc#1012628).
- Update config files.
- clk: qcom: Fix SC_CAMCC_8280XP dependencies (bsc#1012628).
- Update config files.
- ext4: remove the redundant folio_wait_stable() (bsc#1012628).
- ext4: fix potential unnitialized variable (bsc#1012628).
- dax/bus.c: use the right locking mode (read vs write) in
  size_show (bsc#1012628).
- dax/bus.c: don't use down_write_killable for non-user processes
  (bsc#1012628).
- dax/bus.c: fix locking for unregister_dax_dev /
  unregister_dax_mapping paths (bsc#1012628).
- dax/bus.c: replace WARN_ON_ONCE() with lockdep asserts
  (bsc#1012628).
- nfsd: don't create nfsv4recoverydir in nfsdfs when not used
  (bsc#1012628).
- sunrpc: removed redundant procp check (bsc#1012628).
- iommu/amd: Enable Guest Translation after reading IOMMU feature
  register (bsc#1012628).
- iommu/vt-d: Decouple igfx_off from graphic identity mapping
  (bsc#1012628).
- drivers/virt/acrn: fix PFNMAP PTE checks in acrn_vm_ram_map()
  (bsc#1012628).
- virt: acrn: stop using follow_pfn (bsc#1012628).
- RDMA/mana_ib: boundary check before installing cq callbacks
  (bsc#1012628).
- RDMA/mana_ib: Use struct mana_ib_queue for CQs (bsc#1012628).
- RDMA/mana_ib: Introduce helpers to create and destroy mana
  queues (bsc#1012628).
- ext4: avoid excessive credit estimate in ext4_tmpfile()
  (bsc#1012628).
- x86/insn: Add VEX versions of VPDPBUSD, VPDPBUSDS, VPDPWSSD
  and VPDPWSSDS (bsc#1012628).
- x86/insn: Fix PUSH instruction in x86 instruction decoder
  opcode map (bsc#1012628).
- clk: qcom: mmcc-msm8998: fix venus clock issue (bsc#1012628).
- clk: qcom: dispcc-sm8650: fix DisplayPort clocks (bsc#1012628).
- clk: qcom: dispcc-sm8550: fix DisplayPort clocks (bsc#1012628).
- clk: qcom: dispcc-sm6350: fix DisplayPort clocks (bsc#1012628).
- clk: qcom: dispcc-sm8450: fix DisplayPort clocks (bsc#1012628).
- mm/ksm: fix ksm exec support for prctl (bsc#1012628).
- lib/test_hmm.c: handle src_pfns and dst_pfns allocation failure
  (bsc#1012628).
- clk: renesas: r9a07g043: Add clock and reset entry for PLIC
  (bsc#1012628).
- clk: renesas: r8a779a0: Fix CANFD parent clock (bsc#1012628).
- IB/mlx5: Use __iowrite64_copy() for write combining stores
  (bsc#1012628).
- RDMA/rxe: Fix incorrect rxe_put in error path (bsc#1012628).
- RDMA/rxe: Allow good work requests to be executed (bsc#1012628).
- RDMA/rxe: Fix seg fault in rxe_comp_queue_pkt (bsc#1012628).
- clk: samsung: gs101: propagate PERIC1 USI SPI clock rate
  (bsc#1012628).
- clk: samsung: gs101: propagate PERIC0 USI SPI clock rate
  (bsc#1012628).
- clk: qcom: clk-alpha-pll: remove invalid Stromer register offset
  (bsc#1012628).
- clk: rs9: fix wrong default value for clock amplitude
  (bsc#1012628).
- clk: mediatek: mt8365-mm: fix DPI0 parent (bsc#1012628).
- RDMA/hns: Modify the print level of CQE error (bsc#1012628).
- RDMA/hns: Use complete parentheses in macros (bsc#1012628).
- RDMA/hns: Fix GMV table pagesize (bsc#1012628).
- RDMA/hns: Fix mismatch exception rollback (bsc#1012628).
- RDMA/hns: Fix UAF for cq async event (bsc#1012628).
- RDMA/hns: Fix deadlock on SRQ async events (bsc#1012628).
- RDMA/hns: Add max_ah and cq moderation capacities in
  query_device() (bsc#1012628).
- RDMA/hns: Fix return value in hns_roce_map_mr_sg (bsc#1012628).
- iommu: Undo pasid attachment only for the devices that have
  succeeded (bsc#1012628).
- clk: mediatek: pllfh: Don't log error for missing fhctl node
  (bsc#1012628).
- RDMA/mlx5: Adding remote atomic access flag to updatable flags
  (bsc#1012628).
- RDMA/mlx5: Change check for cacheable mkeys (bsc#1012628).
- RDMA/mlx5: Uncacheable mkey has neither rb_key or cache_ent
  (bsc#1012628).
- clk: samsung: exynosautov9: fix wrong pll clock id value
  (bsc#1012628).
- power: supply: core: simplify charge_behaviour formatting
  (bsc#1012628).
- media: cadence: csi2rx: configure DPHY before starting source
  stream (bsc#1012628).
- drm/edid: Parse topology block for all DispID structure v1.x
  (bsc#1012628).
- RISC-V: Fix the typo in Scountovf CSR name (bsc#1012628).
- drm/rockchip: vop2: Do not divide height twice for YUV
  (bsc#1012628).
- media: uvcvideo: Add quirk for Logitech Rally Bar (bsc#1012628).
- drm/mipi-dsi: use correct return type for the DSC functions
  (bsc#1012628).
- ALSA: hda: cs35l41: Remove Speaker ID for Lenovo Legion slim
  7 16ARHA7 (bsc#1012628).
- drm/panel: simple: Add missing Innolux G121X1-L03 format,
  flags, connector (bsc#1012628).
- drm/bridge: anx7625: Update audio status while detecting
  (bsc#1012628).
- drm/panel: novatek-nt35950: Don't log an error when DSI host
  can't be found (bsc#1012628).
- drm/bridge: dpc3433: Don't log an error when DSI host can't
  be found (bsc#1012628).
- drm/bridge: tc358775: Don't log an error when DSI host can't
  be found (bsc#1012628).
- drm/bridge: lt9611uxc: Don't log an error when DSI host can't
  be found (bsc#1012628).
- drm/bridge: lt9611: Don't log an error when DSI host can't be
  found (bsc#1012628).
- drm/bridge: lt8912b: Don't log an error when DSI host can't
  be found (bsc#1012628).
- drm/bridge: icn6211: Don't log an error when DSI host can't
  be found (bsc#1012628).
- drm/bridge: anx7625: Don't log an error when DSI host can't
  be found (bsc#1012628).
- ASoC: tracing: Export SND_SOC_DAPM_DIR_OUT to its value
  (bsc#1012628).
- drm: vc4: Fix possible null pointer dereference (bsc#1012628).
- drm/arm/malidp: fix a possible null pointer dereference
  (bsc#1012628).
- media: atomisp: ssh_css: Fix a null-pointer dereference in
  load_video_binaries (bsc#1012628).
- fbdev: sh7760fb: allow modular build (bsc#1012628).
- media: v4l2-subdev: Fix stream handling for crop API
  (bsc#1012628).
- media: i2c: et8ek8: Don't strip remove function when driver
  is builtin (bsc#1012628).
- media: dt-bindings: ovti,ov2680: Fix the power supply names
  (bsc#1012628).
- media: ipu3-cio2: Request IRQ earlier (bsc#1012628).
- drm/msm/dp: Account for the timeout in wait_hpd_asserted()
  callback (bsc#1012628).
- drm/msm/dp: Avoid a long timeout for AUX transfer if nothing
  connected (bsc#1012628).
- drm/msm/dp: allow voltage swing / pre emphasis of 3
  (bsc#1012628).
- platform/x86: xiaomi-wmi: Fix race condition when reporting
  key events (bsc#1012628).
- drm: bridge: cdns-mhdp8546: Fix possible null pointer
  dereference (bsc#1012628).
- media: radio-shark2: Avoid led_names truncations (bsc#1012628).
- media: rcar-vin: work around -Wenum-compare-conditional warning
  (bsc#1012628).
- staging: media: starfive: Remove links when unregistering
  devices (bsc#1012628).
- media: ngene: Add dvb_ca_en50221_init return value check
  (bsc#1012628).
- ASoC: Intel: avs: Test result of avs_get_module_entry()
  (bsc#1012628).
- ASoC: Intel: avs: Fix potential integer overflow (bsc#1012628).
- ASoC: Intel: avs: Fix ASRC module initialization (bsc#1012628).
- ASoC: Intel: avs: Fix debug-slot offset calculation
  (bsc#1012628).
- ASoC: Intel: avs: Restore stream decoupling on prepare
  (bsc#1012628).
- selftests: cgroup: skip test_cgcore_lesser_ns_open when cgroup2
  mounted without nsdelegate (bsc#1012628).
- fbdev: sisfb: hide unused variables (bsc#1012628).
- ASoC: SOF: Intel: mtl: Implement firmware boot state check
  (bsc#1012628).
- ASoC: SOF: Intel: mtl: Disable interrupts when firmware boot
  failed (bsc#1012628).
- ASoC: SOF: Intel: lnl: Correct rom_status_reg (bsc#1012628).
- ASoC: SOF: Intel: mtl: Correct rom_status_reg (bsc#1012628).
- powerpc/fsl-soc: hide unused const variable (bsc#1012628).
- ASoC: SOF: Intel: hda-dai: fix channel map configuration for
  aggregated dailink (bsc#1012628).
- drm/mediatek: Init `ddp_comp` with devm_kcalloc() (bsc#1012628).
- drm/mediatek: Add 0 size check to mtk_drm_gem_obj (bsc#1012628).
- drm/meson: vclk: fix calculation of 59.94 fractional rates
  (bsc#1012628).
- ASoC: kirkwood: Fix potential NULL dereference (bsc#1012628).
- fbdev: shmobile: fix snprintf truncation (bsc#1012628).
- drm/panel: ltk050h3146w: drop duplicate commands from
  LTK050H3148W init (bsc#1012628).
- drm/panel: ltk050h3146w: add MIPI_DSI_MODE_VIDEO to LTK050H3148W
  flags (bsc#1012628).
- ASoC: mediatek: Assign dummy when codec not specified for a
  DAI link (bsc#1012628).
- drm/imagination: avoid -Woverflow warning (bsc#1012628).
- mtd: rawnand: hynix: fixed typo (bsc#1012628).
- mtd: core: Report error if first mtd_otp_size() call fails in
  mtd_otp_nvmem_add() (bsc#1012628).
- ASoC: Intel: avs: ssm4567: Do not ignore route checks
  (bsc#1012628).
- ASoC: Intel: Disable route checks for Skylake boards
  (bsc#1012628).
- drm/amd/display: Remove redundant condition in
  dcn35_calc_blocks_to_gate() (bsc#1012628).
- drm/amd/display: Fix potential index out of bounds in color
  transformation function (bsc#1012628).
- drm/panel: atna33xc20: Fix unbalanced regulator in the case
  HPD doesn't assert (bsc#1012628).
- drm/lcdif: Do not disable clocks on already suspended hardware
  (bsc#1012628).
- dev_printk: Add and use dev_no_printk() (bsc#1012628).
- printk: Let no_printk() use _printk() (bsc#1012628).
- drm/omapdrm: Fix console with deferred ops (bsc#1012628).
- Update config files.
- drm/omapdrm: Fix console by implementing fb_dirty (bsc#1012628).
- drm/nouveau/dp: Fix incorrect return code in r535_dp_aux_xfer()
  (bsc#1012628).
- drm/ci: update device type for volteer devices (bsc#1012628).
- drm/bridge: Fix improper bridge init order with
  pre_enable_prev_first (bsc#1012628).
- drm/panel-edp: Add prepare_to_enable to 200ms for MNC207QS1-1
  (bsc#1012628).
- Bluetooth: hci_core: Fix not handling hdev->le_num_of_adv_sets=1
  (bsc#1012628).
- Bluetooth: hci_conn, hci_sync: Use __counted_by() to avoid
  - Wfamnae warnings (bsc#1012628).
- Bluetooth: HCI: Remove HCI_AMP support (bsc#1012628).
- Bluetooth: ISO: Make iso_get_sock_listen generic (bsc#1012628).
- Bluetooth: qca: Fix error code in qca_read_fw_build_info()
  (bsc#1012628).
- Bluetooth: compute LE flow credits based on recvbuf space
  (bsc#1012628).
- net: micrel: Fix receiving the timestamp in the frame for
  lan8841 (bsc#1012628).
- net: stmmac: move the EST lock to struct stmmac_priv
  (bsc#1012628).
- mptcp: fix full TCP keep-alive support (bsc#1012628).
- mptcp: SO_KEEPALIVE: fix getsockopt support (bsc#1012628).
- net: fec: remove .ndo_poll_controller to avoid deadlocks
  (bsc#1012628).
- dpll: fix return value check for kmemdup (bsc#1012628).
- ax25: Fix reference count leak issue of net_device
  (bsc#1012628).
- ax25: Fix reference count leak issues of ax25_dev (bsc#1012628).
- ax25: Use kernel universal linked list to implement
  ax25_dev_list (bsc#1012628).
- inet: fix inet_fill_ifaddr() flags truncation (bsc#1012628).
- riscv, bpf: make some atomic operations fully ordered
  (bsc#1012628).
- s390/bpf: Emit a barrier for BPF_FETCH instructions
  (bsc#1012628).
- net/mlx5: Discard command completions in internal error
  (bsc#1012628).
- net/mlx5: Add a timeout to acquire the command queue semaphore
  (bsc#1012628).
- net/mlx5: Reload only IB representors upon lag disable/enable
  (bsc#1012628).
- net/mlx5: Fix peer devlink set for SF representor devlink port
  (bsc#1012628).
- net/mlx5e: Fix netif state handling (bsc#1012628).
- ipv6: sr: fix invalid unregister error path (bsc#1012628).
- ipv6: sr: fix incorrect unregister order (bsc#1012628).
- ipv6: sr: add missing seg6_local_exit (bsc#1012628).
- net: openvswitch: fix overwriting ct original tuple for ICMPv6
  (bsc#1012628).
- net: usb: smsc95xx: stop lying about skb->truesize
  (bsc#1012628).
- af_unix: Fix data races in unix_release_sock/unix_stream_sendmsg
  (bsc#1012628).
- net: ethernet: cortina: Locking fixes (bsc#1012628).
- ice: Fix package download algorithm (bsc#1012628).
- net: ethernet: mediatek: use ADMAv1 instead of ADMAv2.0 on
  MT7981 and MT7986 (bsc#1012628).
- net: ethernet: mediatek: split tx and rx fields in mtk_soc_data
  struct (bsc#1012628).
- selftests: net: move amt to socat for better compatibility
  (bsc#1012628).
- selftests: net: add missing config for amt.sh (bsc#1012628).
- eth: sungem: remove .ndo_poll_controller to avoid deadlocks
  (bsc#1012628).
- net: ipv6: fix wrong start position when receive hop-by-hop
  fragment (bsc#1012628).
- ptp: ocp: fix DPLL functions (bsc#1012628).
- dm-delay: fix max_delay calculations (bsc#1012628).
- dm-delay: fix hung task introduced by kthread mode
  (bsc#1012628).
- dm-delay: fix workqueue delay_timer race (bsc#1012628).
- selftests/sgx: Include KHDR_INCLUDES in Makefile (bsc#1012628).
- selftests: Compile kselftest headers with -D_GNU_SOURCE
  (bsc#1012628).
- m68k: Move ARCH_HAS_CPU_CACHE_ALIASING (bsc#1012628).
- m68k: mac: Fix reboot hang on Mac IIci (bsc#1012628).
- m68k: Fix spinlock race in kernel thread creation (bsc#1012628).
- net: usb: sr9700: stop lying about skb->truesize (bsc#1012628).
- usb: aqc111: stop lying about skb->truesize (bsc#1012628).
- btrfs: set start on clone before calling copy_extent_buffer_full
  (bsc#1012628).
- HID: amd_sfh: Handle "no sensors" in PM operations
  (bsc#1012628).
- wifi: mwl8k: initialize cmd->addr[] properly (bsc#1012628).
- x86/numa: Fix SRAT lookup of CFMWS ranges with
  numa_fill_memblks() (bsc#1012628).
- gpio: nuvoton: Fix sgpio irq handle error (bsc#1012628).
- scsi: qla2xxx: Fix debugfs output for fw_resource_count
  (bsc#1012628).
- scsi: qedf: Ensure the copied buf is NUL terminated
  (bsc#1012628).
- scsi: bfa: Ensure the copied buf is NUL terminated
  (bsc#1012628).
- HID: intel-ish-hid: ipc: Add check for pci_alloc_irq_vectors
  (bsc#1012628).
- selftests/bpf: Fix pointer arithmetic in test_xdp_do_redirect
  (bsc#1012628).
- kunit: bail out early in __kunit_test_suites_init() if there
  are no suites to test (bsc#1012628).
- kunit: unregister the device on error (bsc#1012628).
- kunit: Fix kthread reference (bsc#1012628).
- selftests: default to host arch for LLVM builds (bsc#1012628).
- selftests/resctrl: fix clang build failure: use LOCAL_HDRS
  (bsc#1012628).
- selftests/binderfs: use the Makefile's rules, not Make's
  implicit rules (bsc#1012628).
- selftests: power_supply: Make it POSIX-compliant (bsc#1012628).
- selftests: ktap_helpers: Make it POSIX-compliant (bsc#1012628).
- wifi: rtw89: wow: refine WoWLAN flows of HCI interrupts and
  low power mode (bsc#1012628).
- wifi: nl80211: Avoid address calculations via out of bounds
  array indexing (bsc#1012628).
- libbpf: Fix error message in attach_kprobe_multi (bsc#1012628).
- wifi: mt76: connac: use muar idx 0xe for non-mt799x as well
  (bsc#1012628).
- wifi: mt76: mt7996: fix potential memory leakage when reading
  chip temperature (bsc#1012628).
- wifi: mt76: mt7996: fix uninitialized variable in
  mt7996_irq_tasklet() (bsc#1012628).
- wifi: mt76: mt7925: ensure 4-byte alignment for suspend &
  wow command (bsc#1012628).
- wifi: mt76: mt7996: fix size of txpower MCU command
  (bsc#1012628).
- wifi: mt76: connac: check for null before dereferencing
  (bsc#1012628).
- wifi: mt76: mt7603: add wpdma tx eof flag for PSE client reset
  (bsc#1012628).
- wifi: mt76: mt7603: fix tx queue of loopback packets
  (bsc#1012628).
- Revert "sh: Handle calling csum_partial with misaligned data"
  (bsc#1012628).
- sh: kprobes: Merge arch_copy_kprobe() into arch_prepare_kprobe()
  (bsc#1012628).
- bpf: Add BPF_PROG_TYPE_CGROUP_SKB attach type enforcement in
  BPF_LINK_CREATE (bsc#1012628).
- pwm: meson: Use mul_u64_u64_div_u64() for frequency calculating
  (bsc#1012628).
- pwm: meson: Add check for error from clk_round_rate()
  (bsc#1012628).
- wifi: ar5523: enable proper endpoint verification (bsc#1012628).
- selftests/bpf: Run cgroup1_hierarchy test in own mount namespace
  (bsc#1012628).
- bpf: Fix verifier assumptions about socket->sk (bsc#1012628).
- wifi: carl9170: add a proper sanity check for endpoints
  (bsc#1012628).
- macintosh/via-macii: Fix "BUG: sleeping function called from
  invalid context" (bsc#1012628).
- net: give more chances to rcu in netdev_wait_allrefs_any()
  (bsc#1012628).
- drivers/perf: hisi: hns3: Actually use
  devm_add_action_or_reset() (bsc#1012628).
- drivers/perf: hisi: hns3: Fix out-of-bound access when valid
  event group (bsc#1012628).
- drivers/perf: hisi_pcie: Fix out-of-bound access when valid
  event group (bsc#1012628).
- pwm: sti: Simplify probe function using devm functions
  (bsc#1012628).
- thermal/debugfs: Pass cooling device state to
  thermal_debug_cdev_add() (bsc#1012628).
- thermal/debugfs: Create records for cdev states as they get used
  (bsc#1012628).
- tcp: avoid premature drops in tcp_add_backlog() (bsc#1012628).
- net: dsa: mv88e6xxx: Avoid EEPROM timeout without EEPROM on
  88E6250-family switches (bsc#1012628).
- net: dsa: mv88e6xxx: Add support for model-specific pre-
  and post-reset handlers (bsc#1012628).
- wifi: ath10k: populate board data for WCN3990 (bsc#1012628).
- cpufreq: brcmstb-avs-cpufreq: ISO C90 forbids mixed declarations
  (bsc#1012628).
- scsi: ufs: core: mcq: Fix ufshcd_mcq_sqe_search() (bsc#1012628).
- selftests/bpf: Fix a fd leak in error paths in open_netns
  (bsc#1012628).
- thermal/debugfs: Avoid excessive updates of trip point
  statistics (bsc#1012628).
- gfs2: do_xmote fixes (bsc#1012628).
- gfs2: finish_xmote cleanup (bsc#1012628).
- gfs2: Fix potential glock use-after-free on unmount
  (bsc#1012628).
- gfs2: Remove ill-placed consistency check (bsc#1012628).
- wifi: ath10k: Fix an error code problem in
  ath10k_dbg_sta_write_peer_debug_trigger() (bsc#1012628).
- dt-bindings: thermal: loongson,ls2k-thermal: Fix incorrect
  compatible definition (bsc#1012628).
- dt-bindings: thermal: loongson,ls2k-thermal: Add Loongson-2K0500
  compatible (bsc#1012628).
- thermal/drivers/tsens: Fix null pointer dereference
  (bsc#1012628).
- thermal/drivers/mediatek/lvts_thermal: Add coeff for mt8192
  (bsc#1012628).
- wifi: ath12k: fix out-of-bound access of qmi_invoke_handler()
  (bsc#1012628).
- x86/purgatory: Switch to the position-independent small code
  model (bsc#1012628).
- scsi: hpsa: Fix allocation size for Scsi_Host private data
  (bsc#1012628).
- scsi: libsas: Fix the failure of adding phy with zero-address
  to port (bsc#1012628).
- wifi: iwlwifi: mvm: init vif works only once (bsc#1012628).
- wifi: iwlwifi: mvm: don't always disable EMLSR due to BT coex
  (bsc#1012628).
- wifi: iwlwifi: mvm: calculate EMLSR mode after connection
  (bsc#1012628).
- wifi: iwlwifi: mvm: introduce esr_disable_reason (bsc#1012628).
- wifi: mac80211: transmit deauth only if link is available
  (bsc#1012628).
- cppc_cpufreq: Fix possible null pointer dereference
  (bsc#1012628).
- openrisc: traps: Don't send signals to kernel mode threads
  (bsc#1012628).
- openrisc: Use do_kernel_power_off() (bsc#1012628).
- udp: Avoid call to compute_score on multiple sites
  (bsc#1012628).
- x86/pat: Fix W^X violation false-positives when running as
  Xen PV guest (bsc#1012628).
- x86/pat: Restructure _lookup_address_cpa() (bsc#1012628).
- x86/pat: Introduce lookup_address_in_pgd_attr() (bsc#1012628).
- cpufreq: exit() callback is optional (bsc#1012628).
- tcp: increase the default TCP scaling ratio (bsc#1012628).
- selftests/bpf: Fix umount cgroup2 error in test_sockmap
  (bsc#1012628).
- x86/boot/64: Clear most of CR4 in startup_64(), except PAE,
  MCE and LA57 (bsc#1012628).
- arm64: Remove unnecessary irqflags alternative.h include
  (bsc#1012628).
- gfs2: Fix "ignore unlock failures after withdraw" (bsc#1012628).
- gfs2: Don't forget to complete delayed withdraw (bsc#1012628).
- ACPI: disable -Wstringop-truncation (bsc#1012628).
- irqchip/loongson-pch-msi: Fix off-by-one on allocation error
  path (bsc#1012628).
- irqchip/alpine-msi: Fix off-by-one in allocation error path
  (bsc#1012628).
- locking/atomic/x86: Correct the definition of
  __arch_try_cmpxchg128() (bsc#1012628).
- EDAC/skx_common: Allow decoding of SGX addresses (bsc#1012628).
- ACPI: LPSS: Advertise number of chip selects via property
  (bsc#1012628).
- scsi: ufs: core: Perform read back after disabling
  UIC_COMMAND_COMPL (bsc#1012628).
- scsi: ufs: core: Perform read back after disabling interrupts
  (bsc#1012628).
- scsi: ufs: core: Perform read back after writing
  UTP_TASK_REQ_LIST_BASE_H (bsc#1012628).
- scsi: ufs: cdns-pltfrm: Perform read back after writing HCLKDIV
  (bsc#1012628).
- scsi: ufs: qcom: Perform read back after writing CGC enable
  (bsc#1012628).
- scsi: ufs: qcom: Perform read back after writing unipro mode
  (bsc#1012628).
- scsi: ufs: qcom: Perform read back after writing
  REG_UFS_SYS1CLK_1US (bsc#1012628).
- scsi: ufs: qcom: Perform read back after writing reset bit
  (bsc#1012628).
- x86/microcode/AMD: Avoid -Wformat warning with clang-15
  (bsc#1012628).
- bpf: prevent r10 register from being marked as precise
  (bsc#1012628).
- bpf: Pack struct bpf_fib_lookup (bsc#1012628).
- bpftool: Mount bpffs on provided dir instead of parent dir
  (bsc#1012628).
- wifi: carl9170: re-fix fortified-memset warning (bsc#1012628).
- dlm: fix user space lock decision to copy lvb (bsc#1012628).
- bitops: add missing prototype check (bsc#1012628).
- mlx5: stop warning for 64KB pages (bsc#1012628).
- mlx5: avoid truncating error message (bsc#1012628).
- qed: avoid truncating work queue length (bsc#1012628).
- enetc: avoid truncating error message (bsc#1012628).
- ACPI: bus: Indicate support for IRQ ResourceSource thru _OSC
  (bsc#1012628).
- ACPI: Fix Generic Initiator Affinity _OSC bit (bsc#1012628).
- ACPI: bus: Indicate support for the Generic Event Device thru
  _OSC (bsc#1012628).
- ACPI: bus: Indicate support for more than 16 p-states thru _OSC
  (bsc#1012628).
- ACPI: bus: Indicate support for _TFP thru _OSC (bsc#1012628).
- sched/fair: Add EAS checks before updating
  root_domain::overutilized (bsc#1012628).
- wifi: iwlwifi: mvm: fix check in iwl_mvm_sta_fw_id_mask
  (bsc#1012628).
- wifi: iwlwifi: reconfigure TLC during HW restart (bsc#1012628).
- wifi: iwlwifi: mvm: select STA mask only for active links
  (bsc#1012628).
- wifi: iwlwifi: mvm: set wider BW OFDMA ignore correctly
  (bsc#1012628).
- wifi: iwlwifi: mvm: fix active link counting during recovery
  (bsc#1012628).
- wifi: mac80211: don't select link ID if not provided in scan
  request (bsc#1012628).
- wifi: iwlwifi: mvm: allocate STA links only for active links
  (bsc#1012628).
- wifi: iwlwifi: mvm: Do not warn on invalid link on scan complete
  (bsc#1012628).
- wifi: cfg80211: ignore non-TX BSSs in per-STA profile
  (bsc#1012628).
- wifi: ieee80211: fix ieee80211_mle_basic_sta_prof_size_ok()
  (bsc#1012628).
- x86/fred: Fix typo in Kconfig description (bsc#1012628).
- x86/boot: Ignore relocations in .notes sections in walk_relocs()
  too (bsc#1012628).
- wifi: mt76: mt7915: workaround too long expansion sparse
  warnings (bsc#1012628).
- wifi: ath12k: use correct flag field for 320 MHz channels
  (bsc#1012628).
- libbpf: Prevent null-pointer dereference when prog to load
  has no BTF (bsc#1012628).
- bpftool: Fix missing pids during link show (bsc#1012628).
- wifi: ath11k: don't force enable power save on non-running vdevs
  (bsc#1012628).
- wifi: brcmfmac: pcie: handle randbuf allocation failure
  (bsc#1012628).
- wifi: ath10k: poll service ready message before failing
  (bsc#1012628).
- block: support to account io_ticks precisely (bsc#1012628).
- block: fix and simplify blkdevparts= cmdline parsing
  (bsc#1012628).
- block: refine the EOF check in blkdev_iomap_begin (bsc#1012628).
- crypto: qat - specify firmware files for 402xx (bsc#1012628).
- md: fix resync softlockup when bitmap size is less than array
  size (bsc#1012628).
- kunit/fortify: Fix replaced failure path to unbreak __alloc_size
  (bsc#1012628).
- lkdtm: Disable CFI checking for perms functions (bsc#1012628).
- soc: qcom: pmic_glink: Make client-lock non-sleeping
  (bsc#1012628).
- io_uring/net: fix sendzc lazy wake polling (bsc#1012628).
- s390: vmlinux.lds.S: Drop .hash and .gnu.hash for
  !CONFIG_PIE_BUILD (bsc#1012628).
- kunit/fortify: Fix mismatched kvalloc()/vfree() usage
  (bsc#1012628).
- hwrng: stm32 - repair clock handling (bsc#1012628).
- hwrng: stm32 - put IP into RPM suspend on failure (bsc#1012628).
- hwrng: stm32 - use logical OR in conditional (bsc#1012628).
- crypto: qat - validate slices count returned by FW
  (bsc#1012628).
- null_blk: Fix missing mutex_destroy() at module removal
  (bsc#1012628).
- soc: mediatek: cmdq: Fix typo of CMDQ_JUMP_RELATIVE
  (bsc#1012628).
- firmware: qcom: scm: Fix __scm and waitq completion variable
  initialization (bsc#1012628).
- soc: qcom: pmic_glink: notify clients about the current state
  (bsc#1012628).
- soc: qcom: pmic_glink: don't traverse clients list without a
  lock (bsc#1012628).
- crypto: qat - improve error logging to be consistent across
  features (bsc#1012628).
- crypto: qat - improve error message in adf_get_arbiter_mapping()
  (bsc#1012628).
- crypto: octeontx2 - add missing check for dma_map_single
  (bsc#1012628).
- s390/mm: Re-enable the shared zeropage for !PV and !skeys KVM
  guests (bsc#1012628).
- mm/userfaultfd: Do not place zeropages when zeropages are
  disallowed (bsc#1012628).
- io-wq: write next_work before dropping acct_lock (bsc#1012628).
- shmem: Fix shmem_rename2() (bsc#1012628).
- libfs: Add simple_offset_rename() API (bsc#1012628).
- libfs: Fix simple_offset_rename_exchange() (bsc#1012628).
- jffs2: prevent xattr node from overflowing the eraseblock
  (bsc#1012628).
- ARM: configs: sunxi: Enable DRM_DW_HDMI (bsc#1012628).
- rcu: Fix buffer overflow in print_cpu_stall_info()
  (bsc#1012628).
- rcu-tasks: Fix show_rcu_tasks_trace_gp_kthread buffer overflow
  (bsc#1012628).
- io_uring: use the right type for work_llist empty check
  (bsc#1012628).
- s390/cio: fix tracepoint subchannel type field (bsc#1012628).
- crypto: x86/sha512-avx2 - add missing vzeroupper (bsc#1012628).
- crypto: x86/sha256-avx2 - add missing vzeroupper (bsc#1012628).
- crypto: x86/nh-avx2 - add missing vzeroupper (bsc#1012628).
- crypto: ccp - drop platform ifdef checks (bsc#1012628).
- parisc: add missing export of __cmpxchg_u8() (bsc#1012628).
- nilfs2: fix out-of-range warning (bsc#1012628).
- ecryptfs: Fix buffer size for tag 66 packet (bsc#1012628).
- firmware: raspberrypi: Use correct device for DMA mappings
  (bsc#1012628).
- mm/slub, kunit: Use inverted data to corrupt kmem cache
  (bsc#1012628).
- firmware: qcom: qcm: fix unused qcom_scm_qseecom_allowlist
  (bsc#1012628).
- crypto: bcm - Fix pointer arithmetic (bsc#1012628).
- openpromfs: finish conversion to the new mount API
  (bsc#1012628).
- KEYS: asymmetric: Add missing dependencies of
  FIPS_SIGNATURE_SELFTEST (bsc#1012628).
- KEYS: asymmetric: Add missing dependency on CRYPTO_SIG
  (bsc#1012628).
- Update config files.
- ALSA: Fix deadlocks with kctl removals at disconnection
  (bsc#1012628).
- ALSA: timer: Set lower bound of start tick time (bsc#1012628).
- ALSA: core: Fix NULL module pointer assignment at card init
  (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs don't work for ProBook
  440/460 G11 (bsc#1012628).
- ksmbd: ignore trailing slashes in share paths (bsc#1012628).
- ksmbd: avoid to send duplicate oplock break notifications
  (bsc#1012628).
- fs/ntfs3: Break dir enumeration if directory contents error
  (bsc#1012628).
- fs/ntfs3: Fix case when index is reused during tree
  transformation (bsc#1012628).
- fs/ntfs3: Taking DOS names into account during link counting
  (bsc#1012628).
- fs/ntfs3: Remove max link count info display during driver init
  (bsc#1012628).
- nilfs2: fix potential hang in nilfs_detach_log_writer()
  (bsc#1012628).
- nilfs2: fix unexpected freezing of nilfs_segctor_sync()
  (bsc#1012628).
- nilfs2: fix use-after-free of timer for log writer thread
  (bsc#1012628).
- dt-bindings: adc: axi-adc: add clocks property (bsc#1012628).
- f2fs: fix false alarm on invalid block address (bsc#1012628).
- net: smc91x: Fix m68k kernel compilation for ColdFire CPU
  (bsc#1012628).
- net: lan966x: remove debugfs directory in probe() error path
  (bsc#1012628).
- net: ti: icssg_prueth: Fix NULL pointer dereference in
  prueth_probe() (bsc#1012628).
- tools/nolibc/stdlib: fix memory error in realloc()
  (bsc#1012628).
- tools/latency-collector: Fix -Wformat-security compile warns
  (bsc#1012628).
- net: mana: Fix the extra HZ in mana_hwc_send_request
  (bsc#1012628).
- ring-buffer: Fix a race between readers and resize checks
  (bsc#1012628).
- r8169: Fix possible ring buffer corruption on fragmented Tx
  packets (bsc#1012628).
- Revert "r8169: don't try to disable interrupts if NAPI is,
  scheduled already" (bsc#1012628).
- io_uring/sqpoll: ensure that normal task_work is also run timely
  (bsc#1012628).
- io_uring: fail NOP if non-zero op flags is passed in
  (bsc#1012628).
- Input: try trimming too long modalias strings (bsc#1012628).
- serial: 8520_mtk: Set RTS on shutdown for Rx in-band wakeup
  (bsc#1012628).
- serial: 8250_bcm7271: use default_mux_rate if possible
  (bsc#1012628).
- serial: sc16is7xx: fix bug in sc16is7xx_set_baud() when using
  prescaler (bsc#1012628).
- speakup: Fix sizeof() vs ARRAY_SIZE() bug (bsc#1012628).
- tty: n_gsm: fix missing receive state reset after mode switch
  (bsc#1012628).
- tty: n_gsm: fix possible out-of-bounds in gsm0_receive()
  (bsc#1012628).
- Reapply "arm64: fpsimd: Implement lazy restore for kernel mode
  FPSIMD" (bsc#1012628).
- arm64/fpsimd: Avoid erroneous elide of user state reload
  (bsc#1012628).
- Revert "arm64: fpsimd: Implement lazy restore for kernel mode
  FPSIMD" (bsc#1012628).
- ftrace: Fix possible use-after-free issue in ftrace_location()
  (bsc#1012628).
- selftests/ftrace: Fix checkbashisms errors (bsc#1012628).
- selftests/ftrace: Fix BTFARG testcase to check fprobe is
  enabled correctly (bsc#1012628).
- x86/tsc: Trust initial offset in architectural TSC-adjust MSRs
  (bsc#1012628).
- commit 279162a
* Wed May 29 2024 colyli@suse.de
- Update config files to enable CONFIG_DM_VERITY_VERIFY_ROOTHASH_SIG (bsc#1223544)
- commit d84e6ec
* Wed May 29 2024 colyli@suse.de
- Update config files to enable CONFIG_DM_VERITY_VERIFY_ROOTHASH_SIG (bsc#1223544)
- commit 1b34643
* Mon May 27 2024 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and move into sorted section:
  - patches.suse/btrfs-re-introduce-norecovery-mount-option.patch
- commit a9b6c1b
* Sun May 26 2024 tiwai@suse.de
- Workaround for amdgpu hard freeze (bsc#1225147).
- commit b14bc87
* Sun May 26 2024 jslaby@suse.cz
- Linux 6.9.2 (bsc#1012628).
- wifi: iwlwifi: Use request_module_nowait (bsc#1012628).
- cpufreq: amd-pstate: fix the highest frequency issue which
  limits performance (bsc#1012628).
- drm/amd/display: Fix division by zero in setup_dsc_config
  (bsc#1012628).
- net: ks8851: Fix another TX stall caused by wrong ISR flag
  handling (bsc#1012628).
- x86/percpu: Use __force to cast from __percpu address space
  (bsc#1012628).
- Bluetooth: L2CAP: Fix div-by-zero in l2cap_le_flowctl_init()
  (bsc#1012628).
- KEYS: trusted: Fix memory leak in tpm2_key_encode()
  (bsc#1012628).
- ASoC: Intel: sof_sdw: use generic rtd_init function for Realtek
  SDW DMICs (bsc#1012628).
- binder: fix max_thread type inconsistency (bsc#1012628).
- usb: dwc3: Wait unconditionally after issuing EndXfer command
  (bsc#1012628).
- net: usb: ax88179_178a: fix link status when link is set to
  down/up (bsc#1012628).
- usb: typec: ucsi: displayport: Fix potential deadlock
  (bsc#1012628).
- usb: typec: tipd: fix event checking for tps25750 (bsc#1012628).
- usb: typec: tipd: fix event checking for tps6598x (bsc#1012628).
- serial: kgdboc: Fix NMI-safety problems from keyboard reset code
  (bsc#1012628).
- remoteproc: mediatek: Make sure IPI buffer fits in L2TCM
  (bsc#1012628).
- Revert "media: v4l2-ctrls: show all owned controls in
  log_status" (bsc#1012628).
- KEYS: trusted: Do not use WARN when encode fails (bsc#1012628).
- admin-guide/hw-vuln/core-scheduling: fix return type of
  PR_SCHED_CORE_GET (bsc#1012628).
- docs: kernel_include.py: Cope with docutils 0.21 (bsc#1012628).
- Docs/admin-guide/mm/damon/usage: fix wrong example of DAMOS
  filter matching sysfs file (bsc#1012628).
- Docs/admin-guide/mm/damon/usage: fix wrong schemes effective
  quota update command (bsc#1012628).
- block: add a disk_has_partscan helper (bsc#1012628).
- block: add a partscan sysfs attribute for disks (bsc#1012628).
- Rename to
  patches.kernel.org/6.9.2-001-Bluetooth-btusb-Fix-the-patch-for-MT7920-the-af.patch.
- commit 2759db4
* Thu May 23 2024 mwilck@suse.com
- scsi: core: alua: I/O errors for ALUA state transitions
  (bsc#1189970).
- commit 030909a
* Thu May 23 2024 mwilck@suse.com
- Delete patches.suse/scsi-retry-alua-transition-in-progress. (bsc#1189970)
- commit ead9897
* Thu May 23 2024 tiwai@suse.de
- Bluetooth: btusb: Fix the patch for MT7920 the affected to
  MT7921 (bsc#1225068).
- commit a0089e6
* Thu May 23 2024 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  - patches.suse/ACPI-video-Add-backlight-native-quirk-for-Lenovo-Sli.patch
  - patches.suse/bus-mhi-host-add-mhi_power_down_no_destroy.patch
  - patches.suse/net-qrtr-support-suspend-hibernation.patch
  - patches.suse/wifi-ath11k-support-hibernation.patch
- commit c7821e3
* Tue May 21 2024 tiwai@suse.de
- drm/nouveau/disp: Fix missing backlight control on Macbook 5,1 (bsc#1223838).
- drm/nouveau/disp: Fix missing backlight control on Macbook 5,
  1 (bsc#1223838).
- commit db10868
* Tue May 21 2024 jslaby@suse.cz
- btrfs: re-introduce 'norecovery' mount option (bsc#1222429).
- commit e5b30a1
* Tue May 21 2024 jslaby@suse.cz
- rpm/kernel-obs-build.spec.in: remove reiserfs from OBS initrd
  We disabled the FS in bug 1202309. And we actively blacklist it in:
  /usr/lib/modprobe.d/60-blacklist_fs-reiserfs.conf
  This, as a side-effect, fixes obs-build's warning:
  dracut-pre-udev[1463]: sh: line 1: /usr/lib/module-init-tools/unblacklist: No such file or directory
  Exactly due to the above 60-blacklist_fs-reiserfs.conf trying to call the
  above unblacklist.
  We should likely drop ext2+ext3 from the list too, as we don't build
  them at all. But that's a different story.
- commit 9e1a078
* Tue May 21 2024 jslaby@suse.cz
- Linux 6.9.1 (bsc#1012628).
- wifi: mt76: mt7915: add missing chanctx ops (bsc#1012628).
- keys: Fix overwrite of key expiration on instantiation
  (bsc#1012628).
- dmaengine: idxd: add a write() method for applications to
  submit work (bsc#1012628).
- dmaengine: idxd: add a new security check to deal with a
  hardware erratum (bsc#1012628).
- VFIO: Add the SPR_DSA and SPR_IAX devices to the denylist
  (bsc#1012628).
- commit 6d0f67e
* Fri May 17 2024 jslaby@suse.cz
- Linux 6.9.1 (bsc#1012628).
- wifi: mt76: mt7915: add missing chanctx ops (bsc#1012628).
- keys: Fix overwrite of key expiration on instantiation
  (bsc#1012628).
- dmaengine: idxd: add a write() method for applications to
  submit work (bsc#1012628).
- dmaengine: idxd: add a new security check to deal with a
  hardware erratum (bsc#1012628).
- VFIO: Add the SPR_DSA and SPR_IAX devices to the denylist
  (bsc#1012628).
- commit 0c0b0b5
* Tue May 14 2024 jslaby@suse.cz
- Revert "Update config files (boo#1224053)."
  This reverts commit 59423a933cb917b60a84fa090a2804997c95e450.
  See boo#1224053:
  Michal, please revert this patch. You've just disabled the kernel
  console entirely.
- commit 553f7b7
* Tue May 14 2024 jslaby@suse.cz
- ACPI: video: Add backlight=native quirk for Lenovo Slim 7 16ARH7
  (bsc#1217750).
- commit 760002e
* Tue May 14 2024 jslaby@suse.cz
- scripts/git_sort/git_sort.py: add rafael/linux-pm.git#linux-next to remotes
- commit f265c28
* Tue May 14 2024 jslaby@suse.cz
- Refresh
  patches.suse/Workaround-broken-chacha-crypto-fallback.patch.
- Refresh
  patches.suse/e1000e-change-usleep_range-to-udelay-in-PHY-mdic-acc.patch.
- Refresh
  patches.suse/ACPI-video-Add-backlight-native-quirk-for-Lenovo-Sli.patch.
- Refresh
  patches.suse/ALSA-hda-realtek-Fix-conflicting-PCI-SSID-17aa-386f-.patch.
- Refresh
  patches.suse/usb-Fix-regression-caused-by-invalid-ep0-maxpacket-i.patch.
  Update upstream status and move to sorted section.
- commit dfc068d
* Tue May 14 2024 jslaby@suse.cz
- bus: mhi: host: Add mhi_power_down_keep_dev() API to support
  system suspend/hibernation (bsc#1207948).
- Refresh patches.suse/net-qrtr-support-suspend-hibernation.patch.
- Refresh patches.suse/wifi-ath11k-support-hibernation.patch.
  Update to upstream versions (v7):
  https://lore.kernel.org/all/20240305021320.3367-1-quic_bqiang@quicinc.com/
  And move to sorted section.
- commit 9e598bf
* Mon May 13 2024 msuchanek@suse.de
- Update config files (boo#1224053).
  DRM_FBDEV_EMULATION=n
- commit 59423a9
* Sun May 12 2024 mkubecek@suse.cz
- update to 6.9 final
- refresh configs
- commit e4714c6
* Fri May 10 2024 msuchanek@suse.de
- Update ppc64le config files (bsc#1223982).
  drop support for agpgart, there is no driver enabled
  drop extcon support, it is not used
  drop support for pinctrl drivers, these are not used
  drop support for i2c leds, timers, multiplexors, watchdogs, sensors, displays, HID - these are not used
  drop support for platform-specific DMA found on other platforms
  drop support for Freescale USB controller, it's not used
  drop support for DSA, it's not used
  drop regulater support, there are no regulators exposed
  drop support for random SoC bits, we do not support SoCs
  drop support for Intel QAT
  drop support for PATA
- commit 92e64cf
* Thu May  9 2024 schwab@suse.de
- config: riscv64: SERIAL_DEV_BUS=y
  This is needed for BT_HCIUART_BCM.
- commit 25b9325
* Tue May  7 2024 tiwai@suse.de
- ACPI: video: Add backlight=native quirk for Lenovo Slim 7 16ARH7
  (bsc#1217750).
- commit dca0b95
* Tue May  7 2024 mkubecek@suse.cz
- Update
  patches.kernel.org/6.8.2-636-rds-tcp-Fix-use-after-free-of-net-in-reqsk_time.patch
  references (add CVE-2024-26865 bsc#1223062).
- commit eadd052
* Mon May  6 2024 mkubecek@suse.cz
- Update
  patches.kernel.org/6.8.2-662-packet-annotate-data-races-around-ignore_outgoi.patch
  references (add CVE-2024-26862 bsc#1223111).
- commit dc3978a
* Mon May  6 2024 jslaby@suse.cz
- drm/amdgpu: fix doorbell regression (git-fixes).
- commit aa245c7
* Mon May  6 2024 jslaby@suse.cz
- Linux 6.8.9 (bsc#1012628).
- Bluetooth: hci_sync: Fix UAF on hci_abort_conn_sync
  (bsc#1012628).
- Bluetooth: hci_sync: Fix UAF on create_le_conn_complete
  (bsc#1012628).
- Bluetooth: hci_sync: Fix UAF in hci_acl_create_conn_sync
  (bsc#1012628).
- bounds: Use the right number of bits for power-of-two
  CONFIG_NR_CPUS (bsc#1012628).
- phy: qcom: qmp-combo: fix VCO div offset on v5_5nm and v6
  (bsc#1012628).
- i2c: smbus: fix NULL function pointer dereference (bsc#1012628).
- RISC-V: selftests: cbo: Ensure asm operands match constraints,
  take 2 (bsc#1012628).
- riscv: hwprobe: fix invalid sign extension for
  RISCV_HWPROBE_EXT_ZVFHMIN (bsc#1012628).
- sched/eevdf: Prevent vlag from going out of bounds in
  reweight_eevdf() (bsc#1012628).
- sched/eevdf: Fix miscalculation in reweight_entity() when se
  is not curr (bsc#1012628).
- sched/eevdf: Always update V if se->on_rq when reweighting
  (bsc#1012628).
- dt-bindings: eeprom: at24: Fix ST M24C64-D compatible schema
  (bsc#1012628).
- phy: ti: tusb1210: Resolve charger-det crash if charger psy
  is unregistered (bsc#1012628).
- riscv: Fix loading 64-bit NOMMU kernels past the start of RAM
  (bsc#1012628).
- riscv: Fix TASK_SIZE on 64-bit NOMMU (bsc#1012628).
- dmaengine: idxd: Fix oops during rmmod on single-CPU platforms
  (bsc#1012628).
- dma: xilinx_dpdma: Fix locking (bsc#1012628).
- dmaengine: idxd: Convert spinlock to mutex to lock evl workqueue
  (bsc#1012628).
- phy: qcom: m31: match requested regulator name with dt schema
  (bsc#1012628).
- phy: rockchip: naneng-combphy: Fix mux on rk3588 (bsc#1012628).
- phy: rockchip-snps-pcie3: fix clearing PHP_GRF_PCIESEL_CON bits
  (bsc#1012628).
- phy: rockchip-snps-pcie3: fix bifurcation on rk3588
  (bsc#1012628).
- phy: freescale: imx8m-pcie: fix pcie link-up instability
  (bsc#1012628).
- phy: marvell: a3700-comphy: Fix hardcoded array size
  (bsc#1012628).
- phy: marvell: a3700-comphy: Fix out of bounds read
  (bsc#1012628).
- soundwire: amd: fix for wake interrupt handling for clockstop
  mode (bsc#1012628).
- idma64: Don't try to serve interrupts when device is powered
  off (bsc#1012628).
- dmaengine: tegra186: Fix residual calculation (bsc#1012628).
- dmaengine: owl: fix register access functions (bsc#1012628).
- mm: zswap: fix shrinker NULL crash with cgroup_disable=memory
  (bsc#1012628).
- mm: turn folio_test_hugetlb into a PageType (bsc#1012628).
- phy: qcom: qmp-combo: Fix VCO div offset on v3 (bsc#1012628).
- phy: qcom: qmp-combo: Fix register base for QSERDES_DP_PHY_MODE
  (bsc#1012628).
- firmware: qcom: uefisecapp: Fix memory related IO errors and
  crashes (bsc#1012628).
- mtd: diskonchip: work around ubsan link failure (bsc#1012628).
- mtd: limit OTP NVMEM cell parse to non-NAND devices
  (bsc#1012628).
- udp: preserve the connected status if only UDP cmsg
  (bsc#1012628).
- fbdev: fix incorrect address computation in deferred IO
  (bsc#1012628).
- stackdepot: respect __GFP_NOLOCKDEP allocation flag
  (bsc#1012628).
- macsec: Detect if Rx skb is macsec-related for offloading
  devices that update md_dst (bsc#1012628).
- macsec: Enable devices to advertise whether they update sk_buff
  md_dst during offloads (bsc#1012628).
- net: b44: set pause params only when interface is up
  (bsc#1012628).
- ethernet: Add helper for assigning packet type when dest
  address does not match device address (bsc#1012628).
- net/mlx5e: Advertise mlx5 ethernet driver updates sk_buff
  md_dst for MACsec (bsc#1012628).
- ACPI: CPPC: Fix access width used for PCC registers
  (bsc#1012628).
- ACPI: CPPC: Fix bit_offset shift in MASK_VAL() macro
  (bsc#1012628).
- ACPI: CPPC: Use access_width over bit_width for system memory
  accesses (bsc#1012628).
- irqchip/gic-v3-its: Prevent double free on error (bsc#1012628).
- drm/amdkfd: Fix eviction fence handling (bsc#1012628).
- drm/amdkfd: Fix rescheduling of restore worker (bsc#1012628).
- drm/amdgpu: Fix leak when GPU memory allocation fails
  (bsc#1012628).
- drm/amdgpu/umsch: don't execute umsch test when GPU is in
  reset/suspend (bsc#1012628).
- drm/amdgpu/pm: Remove gpu_od if it's an empty directory
  (bsc#1012628).
- drm/atomic-helper: fix parameter order in
  drm_format_conv_state_copy() call (bsc#1012628).
- drm/amdgpu: Assign correct bits for SDMA HDP flush
  (bsc#1012628).
- drm/amdgpu/sdma5.2: use legacy HDP flush for SDMA2/3
  (bsc#1012628).
- dmaengine: xilinx: xdma: Fix synchronization issue
  (bsc#1012628).
- dmaengine: xilinx: xdma: Fix wrong offsets in the buffers
  addresses in dma descriptor (bsc#1012628).
- dmaengine: Revert "dmaengine: pl330: issue_pending waits until
  WFP state" (bsc#1012628).
- arm64: dts: rockchip: enable internal pull-up for Q7_THRM#
  on RK3399 Puma (bsc#1012628).
- arm64: dts: qcom: sm8450: Fix the msi-map entries (bsc#1012628).
- arm64: dts: qcom: sc8280xp: add missing PCIe minimum OPP
  (bsc#1012628).
- LoongArch: Fix access error when read fault on a write-only VMA
  (bsc#1012628).
- LoongArch: Fix callchain parse error with kernel tracepoint
  events (bsc#1012628).
- eeprom: at24: fix memory corruption race condition
  (bsc#1012628).
- cpu: Re-enable CPU mitigations by default for !X86 architectures
  (bsc#1012628).
- Update config files.
- x86/tdx: Preserve shared bit on mprotect() (bsc#1012628).
- btrfs: fix information leak in btrfs_ioctl_logical_to_ino()
  (bsc#1012628).
- btrfs: scrub: run relocation repair when/only needed
  (bsc#1012628).
- btrfs: fix wrong block_start calculation for
  btrfs_drop_extent_map_range() (bsc#1012628).
- btrfs: fallback if compressed IO fails for ENOSPC (bsc#1012628).
- HID: i2c-hid: Revert to await reset ACK before reading report
  descriptor (bsc#1012628).
- HID: i2c-hid: remove I2C_HID_READ_PENDING flag to prevent
  lock-up (bsc#1012628).
- smb3: fix lock ordering potential deadlock in
  cifs_sync_mid_result (bsc#1012628).
- smb3: missing lock when picking channel (bsc#1012628).
- smb: client: Fix struct_group() usage in __packed structs
  (bsc#1012628).
- mm/hugetlb: fix DEBUG_LOCKS_WARN_ON(1) when
  dissolve_free_hugetlb_folio() (bsc#1012628).
- mm: support page_mapcount() on page_has_type() pages
  (bsc#1012628).
- mm: create FOLIO_FLAG_FALSE and FOLIO_TYPE_OPS macros
  (bsc#1012628).
- mmc: sdhci-of-dwcmshc: th1520: Increase tuning loop count to
  128 (bsc#1012628).
- mmc: sdhci-msm: pervent access to suspended controller
  (bsc#1012628).
- mm/hugetlb: fix missing hugetlb_lock for resv uncharge
  (bsc#1012628).
- mtd: rawnand: qcom: Fix broken OP_RESET_DEVICE command in
  qcom_misc_cmd_type_exec() (bsc#1012628).
- Bluetooth: qca: fix NULL-deref on non-serdev setup
  (bsc#1012628).
- Bluetooth: qca: fix NULL-deref on non-serdev suspend
  (bsc#1012628).
- Bluetooth: btusb: Add Realtek RTL8852BE support ID 0x0bda:0x4853
  (bsc#1012628).
- Bluetooth: Fix type of len in {l2cap,sco}_sock_getsockopt_old()
  (bsc#1012628).
- rust: remove `params` from `module` macro example (bsc#1012628).
- kbuild: rust: force `alloc` extern to allow "empty" Rust files
  (bsc#1012628).
- kbuild: rust: remove unneeded `@rustc_cfg` to avoid ICE
  (bsc#1012628).
- rust: make mutually exclusive with CFI_CLANG (bsc#1012628).
- rust: init: remove impl Zeroable for Infallible (bsc#1012628).
- rust: don't select CONSTRUCTORS (bsc#1012628).
- rust: kernel: require `Send` for `Module` implementations
  (bsc#1012628).
- rust: phy: implement `Send` for `Registration` (bsc#1012628).
- x86/cpu: Fix check for RDPKRU in __show_regs() (bsc#1012628).
- x86/CPU/AMD: Add models 0x10-0x1f to the Zen5 range
  (bsc#1012628).
- selftests/seccomp: Handle EINVAL on unshare(CLONE_NEWPID)
  (bsc#1012628).
- selftests/seccomp: Change the syscall used in KILL_THREAD test
  (bsc#1012628).
- selftests/seccomp: user_notification_addfd check nextfd is
  available (bsc#1012628).
- drm/amdgpu: fix visible VRAM handling during faults
  (bsc#1012628).
- drm/amdgpu: add shared fdinfo stats (bsc#1012628).
- drm: add drm_gem_object_is_shared_for_memory_stats() helper
  (bsc#1012628).
- KVM: x86/pmu: Set enable bits for GP counters in
  PERF_GLOBAL_CTRL at "RESET" (bsc#1012628).
- KVM: x86/pmu: Zero out PMU metadata on AMD if PMU is disabled
  (bsc#1012628).
- usb: xhci: correct return value in case of STS_HCE
  (bsc#1012628).
- xhci: move event processing for one interrupter to a separate
  function (bsc#1012628).
- Revert "drm/amd/display: fix USB-C flag update after enc10
  feature init" (bsc#1012628).
- drm/amd/display: Check DP Alt mode DPCS state via DMUB
  (bsc#1012628).
- netfs: Fix the pre-flush when appending to a file in
  writethrough mode (bsc#1012628).
- af_unix: Suppress false-positive lockdep splat for spin_lock()
  in __unix_gc() (bsc#1012628).
- tls: fix lockless read of strp->msg_ready in ->poll
  (bsc#1012628).
- dpll: fix dpll_pin_on_pin_register() for multiple parent pins
  (bsc#1012628).
- dpll: check that pin is registered in __dpll_pin_unregister()
  (bsc#1012628).
- octeontx2-af: fix the double free in rvu_npc_freemem()
  (bsc#1012628).
- net: ethernet: ti: am65-cpts: Fix PTPv1 message type on TX
  packets (bsc#1012628).
- ice: fix LAG and VF lock dependency in ice_reset_vf()
  (bsc#1012628).
- iavf: Fix TC config comparison with existing adapter TC config
  (bsc#1012628).
- i40e: Report MFS in decimal base instead of hex (bsc#1012628).
- i40e: Do not use WQ_MEM_RECLAIM flag for workqueue
  (bsc#1012628).
- net: ti: icssg-prueth: Fix signedness bug in
  prueth_init_rx_chns() (bsc#1012628).
- net: phy: dp83869: Fix MII mode failure (bsc#1012628).
- netfilter: nf_tables: honor table dormant flag from netdev
  release event path (bsc#1012628).
- ARM: dts: imx6ull-tarragon: fix USB over-current polarity
  (bsc#1012628).
- eth: bnxt: fix counting packets discarded due to OOM and netpoll
  (bsc#1012628).
- mlxsw: spectrum_acl_tcam: Fix memory leak when canceling rehash
  work (bsc#1012628).
- mlxsw: spectrum_acl_tcam: Fix incorrect list API usage
  (bsc#1012628).
- mlxsw: spectrum_acl_tcam: Fix warning during rehash
  (bsc#1012628).
- mlxsw: spectrum_acl_tcam: Fix memory leak during rehash
  (bsc#1012628).
- mlxsw: spectrum_acl_tcam: Rate limit error message
  (bsc#1012628).
- mlxsw: spectrum_acl_tcam: Fix possible use-after-free during
  rehash (bsc#1012628).
- mlxsw: spectrum_acl_tcam: Fix possible use-after-free during
  activity update (bsc#1012628).
- mlxsw: spectrum_acl_tcam: Fix race during rehash delayed work
  (bsc#1012628).
- mlxsw: spectrum_acl_tcam: Fix race in region ID allocation
  (bsc#1012628).
- mlxsw: Use refcount_t for reference counting (bsc#1012628).
- net: openvswitch: Fix Use-After-Free in ovs_ct_exit
  (bsc#1012628).
- ipvs: Fix checksumming on GSO of SCTP packets (bsc#1012628).
- Bluetooth: qca: set power_ctrl_enabled on NULL returned by
  gpiod_get_optional() (bsc#1012628).
- Bluetooth: hci_sync: Using hci_cmd_sync_submit when removing
  Adv Monitor (bsc#1012628).
- Bluetooth: btusb: mediatek: Fix double free of skb in coredump
  (bsc#1012628).
- Bluetooth: MGMT: Fix failing to
  MGMT_OP_ADD_UUID/MGMT_OP_REMOVE_UUID (bsc#1012628).
- Bluetooth: hci_event: Fix sending HCI_OP_READ_ENC_KEY_SIZE
  (bsc#1012628).
- Bluetooth: btusb: Fix triggering coredump implementation for
  QCA (bsc#1012628).
- Bluetooth: hci_sync: Use advertised PHYs on
  hci_le_ext_create_conn_sync (bsc#1012628).
- Bluetooth: ISO: Reassemble PA data for bcast sink (bsc#1012628).
- Bluetooth: hci_sync: Attempt to dequeue connection attempt
  (bsc#1012628).
- Bluetooth: hci_sync: Add helper functions to manipulate cmd_sync
  queue (bsc#1012628).
- Bluetooth: hci_conn: Fix UAF Write in
  __hci_acl_create_connection_sync (bsc#1012628).
- Bluetooth: hci_conn: Always use sk_timeo as conn_timeout
  (bsc#1012628).
- Bluetooth: Remove pending ACL connection attempts (bsc#1012628).
- Bluetooth: hci_conn: Only do ACL connections sequentially
  (bsc#1012628).
- Bluetooth: hci_event: Use HCI error defines instead of magic
  values (bsc#1012628).
- drm/xe: call free_gsc_pkt only once on action add failure
  (bsc#1012628).
- drm/xe: Remove sysfs only once on action add failure
  (bsc#1012628).
- gpio: tegra186: Fix tegra186_gpio_is_accessible() check
  (bsc#1012628).
- net: phy: mediatek-ge-soc: follow netdev LED trigger semantics
  (bsc#1012628).
- net: gtp: Fix Use-After-Free in gtp_dellink (bsc#1012628).
- tcp: Fix Use-After-Free in tcp_ao_connect_init (bsc#1012628).
- net: usb: ax88179_178a: stop lying about skb->truesize
  (bsc#1012628).
- ipv4: check for NULL idev in ip_route_use_hint() (bsc#1012628).
- net: fix sk_memory_allocated_{add|sub} vs softirqs
  (bsc#1012628).
- net: make SK_MEMORY_PCPU_RESERV tunable (bsc#1012628).
- tools: ynl: don't ignore errors in NLMSG_DONE messages
  (bsc#1012628).
- soc: mediatek: mtk-svs: Append "-thermal" to thermal zone names
  (bsc#1012628).
- ax25: Fix netdev refcount issue (bsc#1012628).
- netfs: Fix writethrough-mode error handling (bsc#1012628).
- NFC: trf7970a: disable all regulators on removal (bsc#1012628).
- net: dsa: mv88e6xx: fix supported_interfaces setup in
  mv88e6250_phylink_get_caps() (bsc#1012628).
- cxl/core: Fix potential payload size confusion in
  cxl_mem_get_poison() (bsc#1012628).
- bnxt_en: Fix error recovery for 5760X (P7) chips (bsc#1012628).
- bnxt_en: Fix the PCI-AER routines (bsc#1012628).
- bnxt_en: refactor reset close code (bsc#1012628).
- bridge/br_netlink.c: no need to return void function
  (bsc#1012628).
- icmp: prevent possible NULL dereferences from icmp_build_probe()
  (bsc#1012628).
- ARM: dts: microchip: at91-sama7g5ek: Replace
  regulator-suspend-voltage with the valid property (bsc#1012628).
- mlxsw: pci: Fix driver initialization with old firmware
  (bsc#1012628).
- mlxsw: core_env: Fix driver initialization with old firmware
  (bsc#1012628).
- mlxsw: core: Unregister EMAD trap using FORWARD action
  (bsc#1012628).
- net: bcmasp: fix memory leak when bringing down interface
  (bsc#1012628).
- vxlan: drop packets from invalid src-address (bsc#1012628).
- net: libwx: fix alloc msix vectors failed (bsc#1012628).
- wifi: mac80211: fix unaligned le16 access (bsc#1012628).
- wifi: mac80211: remove link before AP (bsc#1012628).
- wifi: mac80211_hwsim: init peer measurement result
  (bsc#1012628).
- drm/gma500: Remove lid code (bsc#1012628).
- wifi: iwlwifi: mvm: return uid from iwl_mvm_build_scan_cmd
  (bsc#1012628).
- wifi: iwlwifi: mvm: remove old PASN station when adding a new
  one (bsc#1012628).
- wifi: mac80211: split mesh fast tx cache into
  local/proxied/forwarded (bsc#1012628).
- wifi: mac80211: clean up assignments to pointer cache
  (bsc#1012628).
- ARC: [plat-hsdk]: Remove misplaced interrupt-cells property
  (bsc#1012628).
- gpio: tangier: Use correct type for the IRQ chip data
  (bsc#1012628).
- arm64: dts: qcom: sc8180x: Fix ss_phy_irq for secondary USB
  controller (bsc#1012628).
- arm64: dts: qcom: x1e80100: Fix the compatible for cluster
  idle states (bsc#1012628).
- arm64: dts: qcom: Fix type of "wdog" IRQs for remoteprocs
  (bsc#1012628).
- block: fix module reference leakage from bdev_open_by_dev
  error path (bsc#1012628).
- arm64: dts: rockchip: regulator for sd needs to be always on
  for BPI-R2Pro (bsc#1012628).
- arm64: dts: rockchip: mark system power controller and fix
  typo on orangepi-5-plus (bsc#1012628).
- arm64: dts: mediatek: mt2712: fix validation errors
  (bsc#1012628).
- arm64: dts: mediatek: mt7986: prefix BPI-R3 cooling maps with
  "map-" (bsc#1012628).
- arm64: dts: mediatek: mt7986: drop invalid thermal block clock
  (bsc#1012628).
- arm64: dts: mediatek: mt7986: reorder nodes (bsc#1012628).
- arm64: dts: mediatek: mt7986: drop "#reset-cells" from Ethernet
  controller (bsc#1012628).
- arm64: dts: mediatek: mt7986: drop invalid properties from
  ethsys (bsc#1012628).
- arm64: dts: mediatek: mt7986: reorder properties (bsc#1012628).
- arm64: dts: mediatek: mt7622: drop "reset-names" from thermal
  block (bsc#1012628).
- arm64: dts: mediatek: mt7622: fix ethernet controller
  "compatible" (bsc#1012628).
- arm64: dts: mediatek: mt7622: fix IR nodename (bsc#1012628).
- arm64: dts: mediatek: mt7622: fix clock controllers
  (bsc#1012628).
- arm64: dts: mediatek: mt8183-kukui: Use default min voltage
  for MT6358 (bsc#1012628).
- arm64: dts: mediatek: mt8195-cherry: Update min voltage
  constraint for MT6315 (bsc#1012628).
- arm64: dts: mediatek: mt8192-asurada: Update min voltage
  constraint for MT6315 (bsc#1012628).
- arm64: dts: mediatek: cherry: Describe CPU supplies
  (bsc#1012628).
- arm64: dts: mediatek: mt8195: Add missing gce-client-reg to
  mutex1 (bsc#1012628).
- arm64: dts: mediatek: mt8195: Add missing gce-client-reg to
  mutex (bsc#1012628).
- arm64: dts: mediatek: mt8195: Add missing gce-client-reg to
  vpp/vdosys (bsc#1012628).
- arm64: dts: mediatek: mt8192: Add missing gce-client-reg to
  mutex (bsc#1012628).
- arm64: dts: mediatek: mt8183: Add power-domains properity to
  mfgcfg (bsc#1012628).
- arm64: dts: rockchip: Remove unsupported node from the Pinebook
  Pro dts (bsc#1012628).
- arm64: dts: rockchip: Fix the i2c address of es8316 on Cool
  Pi CM5 (bsc#1012628).
- arm64: dts: rockchip: enable internal pull-up on PCIE_WAKE#
  for RK3399 Puma (bsc#1012628).
- arm64: dts: rockchip: fix alphabetical ordering RK3399 puma
  (bsc#1012628).
- arm64: dts: rockchip: enable internal pull-up on Q7_USB_ID
  for RK3399 Puma (bsc#1012628).
- arm64: dts: rockchip: set PHY address of MT7531 switch to 0x1f
  (bsc#1012628).
- HID: logitech-dj: allow mice to use all types of reports
  (bsc#1012628).
- HID: intel-ish-hid: ipc: Fix dev_err usage with uninitialized
  dev->devc (bsc#1012628).
- cifs: reinstate original behavior again for forceuid/forcegid
  (bsc#1012628).
- smb: client: fix rename(2) regression against samba
  (bsc#1012628).
- cifs: Fix reacquisition of volume cookie on still-live
  connection (bsc#1012628).
- commit 4bb6fc6
* Sun May  5 2024 mkubecek@suse.cz
- update to 6.9-rc7
- update configs
  - DRM_PANEL_ILITEK_ILI9341=n (x86_64)
- commit df64d6f
* Tue Apr 30 2024 tiwai@suse.de
- ALSA: hda/realtek: Fix conflicting PCI SSID 17aa:386f for
  Lenovo Legion models (bsc#1223462).
- commit 12d1ee1
* Tue Apr 30 2024 tiwai@suse.de
- usb: Fix regression caused by invalid ep0 maxpacket in virtual
  SuperSpeed device (bsc#1220569).
- commit b2a1bf4
* Tue Apr 30 2024 jslaby@suse.cz
- e1000e: change usleep_range to udelay in PHY mdic access
  (bsc#1223109).
- commit e7fcfd8
* Mon Apr 29 2024 jslaby@suse.cz
- Linux 6.8.8 (bsc#1012628).
- thunderbolt: Reset only non-USB4 host routers in resume
  (bsc#1012628).
- ksmbd: common: use struct_group_attr instead of struct_group
  for network_open_info (bsc#1012628).
- ksmbd: clear RENAME_NOREPLACE before calling vfs_rename
  (bsc#1012628).
- ksmbd: validate request buffer size in smb2_allocate_rsp_buf()
  (bsc#1012628).
- ksmbd: fix slab-out-of-bounds in smb2_allocate_rsp_buf
  (bsc#1012628).
- net: dsa: mt7530: fix enabling EEE on MT7531 switch on all
  boards (bsc#1012628).
- net: dsa: mt7530: fix improper frames on all 25MHz and 40MHz
  XTAL MT7530 (bsc#1012628).
- fork: defer linking file vma until vma is fully initialized
  (bsc#1012628).
- nilfs2: fix OOB in nilfs_set_de_type (bsc#1012628).
- Squashfs: check the inode number is not the invalid value of
  zero (bsc#1012628).
- bootconfig: use memblock_free_late to free xbc memory to buddy
  (bsc#1012628).
- nouveau: fix instmem race condition around ptr stores
  (bsc#1012628).
- drm/vmwgfx: Fix crtc's atomic check conditional (bsc#1012628).
- drm/vmwgfx: Sort primary plane formats by order of preference
  (bsc#1012628).
- drm/vmwgfx: Fix prime import/export (bsc#1012628).
- drm/xe: Fix bo leak in intel_fb_bo_framebuffer_init
  (bsc#1012628).
- drm/ttm: stop pooling cached NUMA pages v2 (bsc#1012628).
- drm/amdgpu: remove invalid resource->start check v2
  (bsc#1012628).
- drm/amdkfd: Fix memory leak in create_process failure
  (bsc#1012628).
- drm/amdgpu: validate the parameters of bo mapping operations
  more clearly (bsc#1012628).
- fuse: fix leaked ENOSYS error on first statx call (bsc#1012628).
- mm/shmem: inline shmem_is_huge() for disabled transparent
  hugepages (bsc#1012628).
- mm/memory-failure: fix deadlock when hugetlb_optimize_vmemmap
  is enabled (bsc#1012628).
- mm,swapops: update check in is_pfn_swap_entry for hwpoison
  entries (bsc#1012628).
- mm/userfaultfd: allow hugetlb change protection upon poison
  entry (bsc#1012628).
- mm/madvise: make MADV_POPULATE_(READ|WRITE) handle
  VM_FAULT_RETRY properly (bsc#1012628).
- init/main.c: Fix potential static_command_line memory overflow
  (bsc#1012628).
- arm64: hibernate: Fix level3 translation fault in swsusp_save()
  (bsc#1012628).
- arm64/head: Disable MMU at EL2 before clearing HCR_EL2.E2H
  (bsc#1012628).
- KVM: x86/mmu: Write-protect L2 SPTEs in TDP MMU when clearing
  dirty status (bsc#1012628).
- KVM: x86/mmu: x86: Don't overflow lpage_info when checking
  attributes (bsc#1012628).
- KVM: x86/pmu: Do not mask LVTPC when handling a PMI on AMD
  platforms (bsc#1012628).
- KVM: x86/pmu: Disable support for adaptive PEBS (bsc#1012628).
- KVM: x86: Snapshot if a vCPU's vendor model is AMD vs. Intel
  compatible (bsc#1012628).
- sched: Add missing memory barrier in switch_mm_cid
  (bsc#1012628).
- fs: sysfs: Fix reference leak in sysfs_break_active_protection()
  (bsc#1012628).
- speakup: Avoid crash on very long word (bsc#1012628).
- mei: me: disable RPL-S on SPS and IGN firmwares (bsc#1012628).
- mei: vsc: Unregister interrupt handler for system suspend
  (bsc#1012628).
- usb: typec: tcpm: Correct the PDO counting in pd_set
  (bsc#1012628).
- usb: gadget: f_ncm: Fix UAF ncm object at re-bind after usb
  ep transport error (bsc#1012628).
- usb: Disable USB3 LPM at shutdown (bsc#1012628).
- usb: dwc2: host: Fix dereference issue in DDMA completion flow
  (bsc#1012628).
- Revert "mei: vsc: Call wake_up() in the threaded IRQ handler"
  (bsc#1012628).
- Revert "usb: cdc-wdm: close race between read and workqueue"
  (bsc#1012628).
- USB: serial: option: add Telit FN920C04 rmnet compositions
  (bsc#1012628).
- USB: serial: option: add Rolling RW101-GL and RW135-GL support
  (bsc#1012628).
- USB: serial: option: support Quectel EM060K sub-models
  (bsc#1012628).
- USB: serial: option: add Lonsung U8300/U9300 product
  (bsc#1012628).
- USB: serial: option: add support for Fibocom FM650/FG650
  (bsc#1012628).
- USB: serial: option: add Fibocom FM135-GL variants
  (bsc#1012628).
- serial: core: Fix missing shutdown and startup for serial base
  port (bsc#1012628).
- serial: core: Clearing the circular buffer before NULLifying it
  (bsc#1012628).
- serial: core: Fix regression when runtime PM is not enabled
  (bsc#1012628).
- serial: stm32: Reset .throttled state in .startup()
  (bsc#1012628).
- serial: stm32: Return IRQ_NONE in the ISR if no handling happend
  (bsc#1012628).
- serial: 8250_dw: Revert: Do not reclock if already at correct
  rate (bsc#1012628).
- serial/pmac_zilog: Remove flawed mitigation for rx irq flood
  (bsc#1012628).
- serial: mxs-auart: add spinlock around changing cts state
  (bsc#1012628).
- comedi: vmk80xx: fix incomplete endpoint checking (bsc#1012628).
- thunderbolt: Do not create DisplayPort tunnels on adapters of
  the same router (bsc#1012628).
- thunderbolt: Fix wake configurations after device unplug
  (bsc#1012628).
- thunderbolt: Avoid notify PM core about runtime PM resume
  (bsc#1012628).
- binder: check offset alignment in binder_get_object()
  (bsc#1012628).
- misc: rtsx: Fix rts5264 driver status incorrect when card
  removed (bsc#1012628).
- usb: misc: onboard_usb_hub: Disable the USB hub clock on failure
  (bsc#1012628).
- ALSA: hda/realtek - Enable audio jacks of Haier Boyue G42 with
  ALC269VC (bsc#1012628).
- ALSA: hda/realtek: Add quirks for Huawei Matebook D14 NBLB-WAX9N
  (bsc#1012628).
- ALSA: hda/tas2781: Add new vendor_id and subsystem_id to
  support ThinkPad ICE-1 (bsc#1012628).
- ALSA: hda/tas2781: correct the register for pow calibrated data
  (bsc#1012628).
- ALSA: seq: ump: Fix conversion from MIDI2 to MIDI1 UMP messages
  (bsc#1012628).
- net/mlx5: E-switch, store eswitch pointer before registering
  devlink_param (bsc#1012628).
- block: propagate partition scanning errors to the BLKRRPART
  ioctl (bsc#1012628).
- x86/cpufeatures: Fix dependencies for GFNI, VAES, and VPCLMULQDQ
  (bsc#1012628).
- x86/bugs: Fix BHI retpoline check (bsc#1012628).
- selftests/powerpc/papr-vpd: Fix missing variable initialization
  (bsc#1012628).
- clk: mediatek: mt7988-infracfg: fix clocks for 2nd PCIe port
  (bsc#1012628).
- clk: mediatek: Do a runtime PM get on controllers during probe
  (bsc#1012628).
- clk: Get runtime PM before walking tree for clk_summary
  (bsc#1012628).
- clk: Get runtime PM before walking tree during disable_unused
  (bsc#1012628).
- clk: Initialize struct clk_core kref earlier (bsc#1012628).
- clk: Remove prepare_lock hold assertion in __clk_release()
  (bsc#1012628).
- interconnect: Don't access req_list while it's being manipulated
  (bsc#1012628).
- interconnect: qcom: x1e80100: Remove inexistent ACV_PERF BCM
  (bsc#1012628).
- platform/x86/amd/pmc: Extend Framework 13 quirk to more BIOSes
  (bsc#1012628).
- thermal/debugfs: Add missing count increment to
  thermal_debug_tz_trip_up() (bsc#1012628).
- ALSA: hda/realtek: Fix volumn control of ThinkBook 16P Gen4
  (bsc#1012628).
- drm/radeon: make -fstrict-flex-arrays=3 happy (bsc#1012628).
- drm/panel: visionox-rm69299: don't unregister DSI device
  (bsc#1012628).
- thunderbolt: Reset topology created by the boot firmware
  (bsc#1012628).
- thunderbolt: Make tb_switch_reset() support Thunderbolt 2,
  3 and USB4 routers (bsc#1012628).
- thunderbolt: Introduce tb_path_deactivate_hop() (bsc#1012628).
- thunderbolt: Introduce tb_port_reset() (bsc#1012628).
- userfaultfd: change src_folio after ensuring it's unpinned in
  UFFDIO_MOVE (bsc#1012628).
- drm/v3d: Don't increment `enabled_ns` twice (bsc#1012628).
- drm: nv04: Fix out of bounds access (bsc#1012628).
- iommufd: Add config needed for iommufd_fail_nth (bsc#1012628).
- iommufd: Add missing IOMMUFD_DRIVER kconfig for the selftest
  (bsc#1012628).
- s390/cio: fix race condition during online processing
  (bsc#1012628).
- s390/qdio: handle deferred cc1 (bsc#1012628).
- perf lock contention: Add a missing NULL check (bsc#1012628).
- perf annotate: Make sure to call symbol__annotate2() in TUI
  (bsc#1012628).
- RDMA/mlx5: Fix port number for counter query in multi-port
  configuration (bsc#1012628).
- RDMA/cm: Print the old state when cm_destroy_id gets timeout
  (bsc#1012628).
- RDMA/rxe: Fix the problem "mutex_destroy missing" (bsc#1012628).
- NFSD: fix endianness issue in nfsd4_encode_fattr4 (bsc#1012628).
- net: ethernet: ti: am65-cpsw-nuss: cleanup DMA Channels before
  using them (bsc#1012628).
- net: ravb: Allow RX loop to move past DMA mapping errors
  (bsc#1012628).
- net: ravb: Count packets instead of descriptors in R-Car RX path
  (bsc#1012628).
- ravb: Group descriptor types used in Rx ring (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix WED + wifi reset (bsc#1012628).
- net/sched: Fix mirred deadlock on device recursion
  (bsc#1012628).
- netfilter: nf_tables: fix memleak in map from abort path
  (bsc#1012628).
- gpiolib: swnode: Remove wrong header inclusion (bsc#1012628).
- netfilter: nf_tables: restore set elements when delete set fails
  (bsc#1012628).
- netfilter: nf_tables: missing iterator type in lookup walk
  (bsc#1012628).
- s390/ism: Properly fix receive message buffer allocation
  (bsc#1012628).
- net: dsa: mt7530: fix port mirroring for MT7988 SoC switch
  (bsc#1012628).
- net: dsa: mt7530: fix mirroring frames received on local port
  (bsc#1012628).
- tun: limit printing rate when illegal packet received by tun
  dev (bsc#1012628).
- ice: Fix checking for unsupported keys on non-tunnel device
  (bsc#1012628).
- ice: tc: allow zero flags in parsing tc flower (bsc#1012628).
- ice: tc: check src_vsi in case of traffic from VF (bsc#1012628).
- net: stmmac: Fix IP-cores specific MAC capabilities
  (bsc#1012628).
- net: stmmac: Fix max-speed being ignored on queue re-init
  (bsc#1012628).
- net: stmmac: Apply half-duplex-less constraint for DW QoS Eth
  only (bsc#1012628).
- selftests/tcp_ao: Printing fixes to confirm with format-security
  (bsc#1012628).
- selftests/tcp_ao: Fix fscanf() call for format-security
  (bsc#1012628).
- selftests/tcp_ao: Zero-init tcp_ao_info_opt (bsc#1012628).
- selftests/tcp_ao: Make RST tests less flaky (bsc#1012628).
- octeontx2-pf: fix FLOW_DIS_IS_FRAGMENT implementation
  (bsc#1012628).
- net: change maximum number of UDP segments to 128 (bsc#1012628).
- net/mlx5e: Prevent deadlock while disabling aRFS (bsc#1012628).
- net/mlx5: Restore mistakenly dropped parts in register devlink
  flow (bsc#1012628).
- net/mlx5: Lag, restore buckets number to default after hash
  LAG deactivation (bsc#1012628).
- net: sparx5: flower: fix fragment flags handling (bsc#1012628).
- af_unix: Don't peek OOB data without MSG_OOB (bsc#1012628).
- af_unix: Call manage_oob() for every skb in
  unix_stream_read_generic() (bsc#1012628).
- netfilter: flowtable: incorrect pppoe tuple (bsc#1012628).
- netfilter: flowtable: validate pppoe header (bsc#1012628).
- netfilter: nft_set_pipapo: do not free live element
  (bsc#1012628).
- netfilter: nft_set_pipapo: walk over current view on netlink
  dump (bsc#1012628).
- netfilter: nft_set_pipapo: constify lookup fn args where
  possible (bsc#1012628).
- netfilter: br_netfilter: skip conntrack input hook for promisc
  packets (bsc#1012628).
- netfilter: nf_tables: Fix potential data-race in
  __nft_obj_type_get() (bsc#1012628).
- netfilter: nf_tables: Fix potential data-race in
  __nft_expr_type_get() (bsc#1012628).
- scsi: ufs: qcom: Add missing interconnect bandwidth values
  for Gear 5 (bsc#1012628).
- r8169: add missing conditional compiling for call to
  r8169_remove_leds (bsc#1012628).
- r8169: fix LED-related deadlock on module removal (bsc#1012628).
- btrfs: zoned: do not flag ZEROOUT on non-dirty extent buffer
  (bsc#1012628).
- btrfs: do not wait for short bulk allocation (bsc#1012628).
- net: usb: ax88179_178a: avoid writing the mac address before
  first reading (bsc#1012628).
- scsi: core: Fix handling of SCMD_FAIL_IF_RECOVERING
  (bsc#1012628).
- random: handle creditable entropy from atomic process context
  (bsc#1012628).
- selftests/ftrace: Limit length in subsystem-enable tests
  (bsc#1012628).
- SUNRPC: Fix rpcgss_context trace event acceptor field
  (bsc#1012628).
- Revert "vmgenid: emit uevent when VMGENID updates"
  (bsc#1012628).
- drm/i915/cdclk: Fix voltage_level programming edge case
  (bsc#1012628).
- io_uring: Fix io_cqring_wait() not restoring sigmask on
  get_timespec64() failure (bsc#1012628).
- commit 9d04f0e
* Sun Apr 28 2024 mkubecek@suse.cz
- update to 6.9-rc6
- update configs
  - CPU_MITIGATIONS=y (x86)
  - NTFS_FS=m (except s390x/zfcpdump)
  - ERRATA_THEAD_MAE=y (riscv64)
- commit 5967f99
* Thu Apr 25 2024 jslaby@suse.cz
- bootconfig: Fix the kerneldoc of _xbc_exit() (git-fixes).
- commit 5cd3298
* Sun Apr 21 2024 mkubecek@suse.cz
- update to 6.9-rc5
- eliminate 1 patch
  - patches.suse/Workaround-broken-chacha-crypto-fallback.patch (69630926011c)
- commit 7ee1174
* Fri Apr 19 2024 jslaby@suse.cz
- Update config files. Disable N_GSM (bsc#1223134).
- commit bbf9614
* Wed Apr 17 2024 jslaby@suse.cz
- Linux 6.8.7 (bsc#1012628).
- drm/amd/display: fix disable otg wa logic in DCN316
  (bsc#1012628).
- drm/amd/display: always reset ODM mode in context when adding
  first plane (bsc#1012628).
- drm/amd/display: Return max resolution supported by DWB
  (bsc#1012628).
- drm/amd/display: Do not recursively call manual trigger
  programming (bsc#1012628).
- drm/amd/display: Set VSC SDP Colorimetry same way for MST and
  SST (bsc#1012628).
- drm/amd/display: Program VSC SDP colorimetry for all DP sinks >=
  1.4 (bsc#1012628).
- drm/amdgpu: differentiate external rev id for gfx 11.5.0
  (bsc#1012628).
- drm/amdgpu: fix incorrect number of active RBs for gfx11
  (bsc#1012628).
- drm/amdgpu: always force full reset for SOC21 (bsc#1012628).
- drm/amdgpu: Reset dGPU if suspend got aborted (bsc#1012628).
- drm/i915: Disable live M/N updates when using bigjoiner
  (bsc#1012628).
- drm/i915: Disable port sync when bigjoiner is used
  (bsc#1012628).
- drm/i915/psr: Disable PSR when bigjoiner is used (bsc#1012628).
- drm/i915/cdclk: Fix CDCLK programming order when pipes are
  active (bsc#1012628).
- commit a2ed3b5
* Wed Apr 17 2024 jslaby@suse.cz
-  x86/bugs: Replace CONFIG_SPECTRE_BHI_{ON,OFF} with
  CONFIG_MITIGATION_SPECTRE_BHI (bsc#1012628 bsc#1217339
  CVE-2024-2201).
- Update config files.
- x86/bugs: Remove CONFIG_BHI_MITIGATION_AUTO and spectre_bhi=auto
  (bsc#1012628).
- x86/bugs: Clarify that syscall hardening isn't a BHI mitigation
  (bsc#1012628).
- x86/bugs: Fix BHI handling of RRSBA (bsc#1012628).
- x86/bugs: Rename various 'ia32_cap' variables to
  'x86_arch_cap_msr' (bsc#1012628).
- x86/bugs: Cache the value of MSR_IA32_ARCH_CAPABILITIES
  (bsc#1012628).
- x86/bugs: Fix BHI documentation (bsc#1012628).
- x86/bugs: Fix return type of spectre_bhi_state() (bsc#1012628).
- kernfs: annotate different lockdep class for of->mutex of
  writable files (bsc#1012628).
- selftests: kselftest: Fix build failure with NOLIBC
  (bsc#1012628).
- irqflags: Explicitly ignore lockdep_hrtimer_exit() argument
  (bsc#1012628).
- x86/apic: Force native_apic_mem_read() to use the MOV
  instruction (bsc#1012628).
- selftests: kselftest: Mark functions that unconditionally call
  exit() as __noreturn (bsc#1012628).
- selftests: timers: Fix abs() warning in posix_timers test
  (bsc#1012628).
- selftests: timers: Fix posix_timers ksft_print_msg() warning
  (bsc#1012628).
- selftests/timers/posix_timers: Reimplement
  check_timer_distribution() (bsc#1012628).
- x86/cpu: Actually turn off mitigations by default for
  SPECULATION_MITIGATIONS=n (bsc#1012628).
- perf/x86: Fix out of range data (bsc#1012628).
- vhost: Add smp_rmb() in vhost_enable_notify() (bsc#1012628).
- vhost: Add smp_rmb() in vhost_vq_avail_empty() (bsc#1012628).
- arm64: dts: imx8-ss-dma: fix spi lpcg indices (bsc#1012628).
- arm64: dts: imx8-ss-lsio: fix pwm lpcg indices (bsc#1012628).
- arm64: dts: imx8-ss-dma: fix pwm lpcg indices (bsc#1012628).
- arm64: dts: imx8-ss-conn: fix usb lpcg indices (bsc#1012628).
- arm64: dts: imx8-ss-dma: fix adc lpcg indices (bsc#1012628).
- arm64: dts: imx8-ss-dma: fix can lpcg indices (bsc#1012628).
- arm64: dts: imx8qm-ss-dma: fix can lpcg indices (bsc#1012628).
- drm/amdgpu/umsch: reinitialize write pointer in hw init
  (bsc#1012628).
- drm/msm/dp: fix runtime PM leak on connect failure
  (bsc#1012628).
- drm/msm/dp: fix runtime PM leak on disconnect (bsc#1012628).
- drm/client: Fully protect modes[] with dev->mode_config.mutex
  (bsc#1012628).
- drm/panfrost: Fix the error path in
  panfrost_mmu_map_fault_addr() (bsc#1012628).
- drm/ast: Fix soft lockup (bsc#1012628).
- drm/amdkfd: Reset GPU on queue preemption failure (bsc#1012628).
- drm/i915/vrr: Disable VRR when using bigjoiner (bsc#1012628).
- drm/vmwgfx: Enable DMA mappings with SEV (bsc#1012628).
- accel/ivpu: Fix deadlock in context_xa (bsc#1012628).
- accel/ivpu: Return max freq for DRM_IVPU_PARAM_CORE_CLOCK_RATE
  (bsc#1012628).
- accel/ivpu: Put NPU back to D3hot after failed resume
  (bsc#1012628).
- accel/ivpu: Fix PCI D0 state entry in resume (bsc#1012628).
- accel/ivpu: Check return code of ipc->lock init (bsc#1012628).
- scsi: sg: Avoid race in error handling & drop bogus warn
  (bsc#1012628).
- scsi: sg: Avoid sg device teardown race (bsc#1012628).
- fs/proc: Skip bootloader comment if no embedded kernel
  parameters (bsc#1012628).
- fs/proc: remove redundant comments from /proc/bootconfig
  (bsc#1012628).
- kprobes: Fix possible use-after-free issue on kprobe
  registration (bsc#1012628).
- io_uring/net: restore msg_control on sendzc retry (bsc#1012628).
- btrfs: qgroup: convert PREALLOC to PERTRANS after
  record_root_in_trans (bsc#1012628).
- btrfs: record delayed inode root in transaction (bsc#1012628).
- btrfs: qgroup: fix qgroup prealloc rsv leak in subvolume
  operations (bsc#1012628).
- btrfs: qgroup: correctly model root qgroup rsv in convert
  (bsc#1012628).
- io_uring: disable io-wq execution of multishot NOWAIT requests
  (bsc#1012628).
- io_uring: refactor DEFER_TASKRUN multishot checks (bsc#1012628).
- iommu/vt-d: Fix WARN_ON in iommu probe path (bsc#1012628).
- iommu/vt-d: Allocate local memory for page request queue
  (bsc#1012628).
- iommu/vt-d: Fix wrong use of pasid config (bsc#1012628).
- tracing: hide unused ftrace_event_id_fops (bsc#1012628).
- drm/xe/hwmon: Cast result to output precision on left shift
  of operand (bsc#1012628).
- drm/xe/display: Fix double mutex initialization (bsc#1012628).
- net: ena: Set tx_info->xdpf value to NULL (bsc#1012628).
- net: ena: Fix incorrect descriptor free behavior (bsc#1012628).
- net: ena: Wrong missing IO completions check order
  (bsc#1012628).
- net: ena: Fix potential sign extension issue (bsc#1012628).
- af_unix: Fix garbage collector racing against connect()
  (bsc#1012628).
- af_unix: Do not use atomic ops for unix_sk(sk)->inflight
  (bsc#1012628).
- net: dsa: mt7530: trap link-local frames regardless of ST Port
  State (bsc#1012628).
- Revert "s390/ism: fix receive message buffer allocation"
  (bsc#1012628).
- net: sparx5: fix wrong config being used when reconfiguring PCS
  (bsc#1012628).
- net/mlx5e: Do not produce metadata freelist entries in Tx port
  ts WQE xmit (bsc#1012628).
- net/mlx5e: HTB, Fix inconsistencies with QoS SQs number
  (bsc#1012628).
- net/mlx5e: Fix mlx5e_priv_init() cleanup flow (bsc#1012628).
- net/mlx5e: RSS, Block changing channels number when RXFH is
  configured (bsc#1012628).
- net/mlx5: Correctly compare pkt reformat ids (bsc#1012628).
- net/mlx5: Properly link new fs rules into the tree
  (bsc#1012628).
- net/mlx5: offset comp irq index in name by one (bsc#1012628).
- net/mlx5: Register devlink first under devlink lock
  (bsc#1012628).
- net/mlx5: SF, Stop waiting for FW as teardown was called
  (bsc#1012628).
- netfilter: complete validation of user input (bsc#1012628).
- Bluetooth: l2cap: Don't double set the HCI_CONN_MGMT_CONNECTED
  bit (bsc#1012628).
- Bluetooth: hci_sock: Fix not validating setsockopt user input
  (bsc#1012628).
- Bluetooth: ISO: Fix not validating setsockopt user input
  (bsc#1012628).
- Bluetooth: L2CAP: Fix not validating setsockopt user input
  (bsc#1012628).
- Bluetooth: RFCOMM: Fix not validating setsockopt user input
  (bsc#1012628).
- Bluetooth: SCO: Fix not validating setsockopt user input
  (bsc#1012628).
- Bluetooth: hci_sync: Fix using the same interval and window
  for Coded PHY (bsc#1012628).
- Bluetooth: hci_sync: Use QoS to determine which PHY to scan
  (bsc#1012628).
- Bluetooth: ISO: Don't reject BT_ISO_QOS if parameters are unset
  (bsc#1012628).
- Bluetooth: ISO: Align broadcast sync_timeout with connection
  timeout (bsc#1012628).
- pds_core: Fix pdsc_check_pci_health function to use work thread
  (bsc#1012628).
- pds_core: use pci_reset_function for health reset (bsc#1012628).
- ipv6: fix race condition between ipv6_get_ifaddr and
  ipv6_del_addr (bsc#1012628).
- ipv4/route: avoid unused-but-set-variable warning (bsc#1012628).
- ipv6: fib: hide unused 'pn' variable (bsc#1012628).
- octeontx2-af: Fix NIX SQ mode and BP config (bsc#1012628).
- af_unix: Clear stale u->oob_skb (bsc#1012628).
- net: ks8851: Handle softirqs at the end of IRQ thread to fix
  hang (bsc#1012628).
- net: ks8851: Inline ks8851_rx_skb() (bsc#1012628).
- cxl: Fix retrieving of access_coordinates in PCIe path
  (bsc#1012628).
- cxl: Remove checking of iter in
  cxl_endpoint_get_perf_coordinates() (bsc#1012628).
- cxl: Split out host bridge access coordinates (bsc#1012628).
- cxl: Split out combine_coordinates() for common shared usage
  (bsc#1012628).
- ACPI: HMAT / cxl: Add retrieval of generic port coordinates
  for both access classes (bsc#1012628).
- ACPI: HMAT: Introduce 2 levels of generic port access class
  (bsc#1012628).
- base/node / ACPI: Enumerate node access class for 'struct
  access_coordinate' (bsc#1012628).
- ACPI: bus: allow _UID matching for integer zero (bsc#1012628).
- bnxt_en: Reset PTP tx_avail after possible firmware reset
  (bsc#1012628).
- bnxt_en: Fix error recovery for RoCE ulp client (bsc#1012628).
- bnxt_en: Fix possible memory leak in bnxt_rdma_aux_device_init()
  (bsc#1012628).
- s390/ism: fix receive message buffer allocation (bsc#1012628).
- geneve: fix header validation in geneve[6]_xmit_skb
  (bsc#1012628).
- lib: checksum: hide unused expected_csum_ipv6_magic[]
  (bsc#1012628).
- block: fix q->blkg_list corruption during disk rebind
  (bsc#1012628).
- octeontx2-pf: Fix transmit scheduler resource leak
  (bsc#1012628).
- xsk: validate user input for XDP_{UMEM|COMPLETION}_FILL_RING
  (bsc#1012628).
- u64_stats: fix u64_stats_init() for lockdep when used repeatedly
  in one file (bsc#1012628).
- net: openvswitch: fix unwanted error log on timeout policy
  probing (bsc#1012628).
- scsi: qla2xxx: Fix off by one in qla_edif_app_getstats()
  (bsc#1012628).
- scsi: hisi_sas: Modify the deadline for ata_wait_after_reset()
  (bsc#1012628).
- drm/msm/adreno: Set highest_bank_bit for A619 (bsc#1012628).
- nouveau: fix function cast warning (bsc#1012628).
- Revert "drm/qxl: simplify qxl_fence_wait" (bsc#1012628).
- cxl/core: Fix initialization of mbox_cmd.size_out in get event
  (bsc#1012628).
- arm64: dts: imx8-ss-conn: fix usdhc wrong lpcg clock order
  (bsc#1012628).
- dt-bindings: display/msm: sm8150-mdss: add DP node
  (bsc#1012628).
- drm/msm/dpu: make error messages at
  dpu_core_irq_register_callback() more sensible (bsc#1012628).
- drm/msm/dpu: don't allow overriding data from catalog
  (bsc#1012628).
- drm/msm: Add newlines to some debug prints (bsc#1012628).
- arm64: dts: freescale: imx8mp-venice-gw73xx-2x: fix USB vbus
  regulator (bsc#1012628).
- arm64: dts: freescale: imx8mp-venice-gw72xx-2x: fix USB vbus
  regulator (bsc#1012628).
- cxl/core/regs: Fix usage of map->reg_type in
  cxl_decode_regblock() before assigned (bsc#1012628).
- cxl/mem: Fix for the index of Clear Event Record Handle
  (bsc#1012628).
- firmware: arm_scmi: Make raw debugfs entries non-seekable
  (bsc#1012628).
- firmware: arm_ffa: Fix the partition ID check in
  ffa_notification_info_get() (bsc#1012628).
- ARM: OMAP2+: fix USB regression on Nokia N8x0 (bsc#1012628).
- mmc: omap: restore original power up/down steps (bsc#1012628).
- mmc: omap: fix deferred probe (bsc#1012628).
- mmc: omap: fix broken slot switch lookup (bsc#1012628).
- ARM: OMAP2+: fix N810 MMC gpiod table (bsc#1012628).
- ARM: OMAP2+: fix bogus MMC GPIO labels on Nokia N8x0
  (bsc#1012628).
- btrfs: tests: allocate dummy fs_info and root in
  test_find_delalloc() (bsc#1012628).
- media: cec: core: remove length check of Timer Status
  (bsc#1012628).
- PM: s2idle: Make sure CPUs will wakeup directly on resume
  (bsc#1012628).
- ACPI: scan: Do not increase dep_unmet for already met
  dependencies (bsc#1012628).
- platform/chrome: cros_ec_uart: properly fix race condition
  (bsc#1012628).
- drm/amd/pm: fixes a random hang in S4 for SMU v13.0.4/11
  (bsc#1012628).
- Bluetooth: Fix memory leak in hci_req_sync_complete()
  (bsc#1012628).
- ring-buffer: Only update pages_touched when a new page is
  touched (bsc#1012628).
- raid1: fix use-after-free for original bio in
  raid1_write_request() (bsc#1012628).
- ARM: dts: imx7s-warp: Pass OV2680 link-frequencies
  (bsc#1012628).
- arm64: tlb: Fix TLBI RANGE operand (bsc#1012628).
- virtio_net: Do not send RSS key if it is not supported
  (bsc#1012628).
- ceph: switch to use cap_delay_lock for the unlink delay list
  (bsc#1012628).
- ceph: redirty page before returning AOP_WRITEPAGE_ACTIVATE
  (bsc#1012628).
- batman-adv: Avoid infinite loop trying to resize local TT
  (bsc#1012628).
- drm/amdgpu/vpe: power on vpe when hw_init (bsc#1012628).
- ata: libata-scsi: Fix ata_scsi_dev_rescan() error path
  (bsc#1012628).
- ata: libata-core: Allow command duration limits detection for
  ACS-4 drives (bsc#1012628).
- smb3: fix Open files on server counter going negative
  (bsc#1012628).
- commit 9e7200f
* Wed Apr 17 2024 macpaul.lin@mediatek.com
- Update config files: re-enable arm64 regulator modules for MediaTek boards (bsc#1222818).
  This re-enable some regulator modules, pinctrl and RTC drivers for
  MediaTek boards which has been disabled when merging config file from
  master to stable (kernel 6.5.9->6.6) branch.
  This re-applies commit b197b3604a7b (Update config files: enable arm64
  regulator modules for MediaTek boards.)
  [js] set also KEYBOARD_MTK_PMIC=m, POWER_RESET_MT6323=n, LEDS_MT6323=n,
    and MFD_MT6397=m -- the same as commit b197b3604a7b.
- commit d11a210
* Mon Apr 15 2024 duwe@suse.de
- Update arm* configs to 6.9-rc4. Mostly new SoC and component support enabled as modules.
- Re-enable arm in config.conf
- commit 4804f5c
* Mon Apr 15 2024 jslaby@suse.cz
- bus: mhi: host: Add mhi_power_down_keep_dev() API to support
  system suspend/hibernation (bsc#1207948).
  Update upstream status and move to soon-upstream section.
- commit 114e4b9
* Mon Apr 15 2024 jslaby@suse.cz
- Refresh
  patches.suse/Workaround-broken-chacha-crypto-fallback.patch.
  Update upstream status.
- commit 85a400d
* Mon Apr 15 2024 jslaby@suse.cz
- Linux 6.8.6 (bsc#1012628).
- amdkfd: use calloc instead of kzalloc to avoid integer overflow
  (bsc#1012628).
- wifi: ath9k: fix LNA selection in ath_ant_try_scan()
  (bsc#1012628).
- wifi: rtw89: fix null pointer access when abort scan
  (bsc#1012628).
- bnx2x: Fix firmware version string character counts
  (bsc#1012628).
- net: stmmac: dwmac-starfive: Add support for JH7100 SoC
  (bsc#1012628).
- net: phy: phy_device: Prevent nullptr exceptions on ISR
  (bsc#1012628).
- wifi: rtw89: pci: validate RX tag for RXQ and RPQ (bsc#1012628).
- wifi: rtw89: pci: enlarge RX DMA buffer to consider size of
  RX descriptor (bsc#1012628).
- VMCI: Fix memcpy() run-time warning in dg_dispatch_as_host()
  (bsc#1012628).
- wifi: iwlwifi: pcie: Add the PCI device id for new hardware
  (bsc#1012628).
- arm64: dts: qcom: qcm6490-idp: Add definition for three LEDs
  (bsc#1012628).
- net: dsa: qca8k: put MDIO controller OF node if unavailable
  (bsc#1012628).
- arm64: dts: qcom: qrb2210-rb1: disable cluster power domains
  (bsc#1012628).
- printk: For @suppress_panic_printk check for other CPU in panic
  (bsc#1012628).
- panic: Flush kernel log buffer at the end (bsc#1012628).
- dump_stack: Do not get cpu_sync for panic CPU (bsc#1012628).
- wifi: iwlwifi: pcie: Add new PCI device id and CNVI
  (bsc#1012628).
- cpuidle: Avoid potential overflow in integer multiplication
  (bsc#1012628).
- ARM: dts: rockchip: fix rk3288 hdmi ports node (bsc#1012628).
- ARM: dts: rockchip: fix rk322x hdmi ports node (bsc#1012628).
- arm64: dts: rockchip: fix rk3328 hdmi ports node (bsc#1012628).
- arm64: dts: rockchip: fix rk3399 hdmi ports node (bsc#1012628).
- net: add netdev_lockdep_set_classes() to virtual drivers
  (bsc#1012628).
- arm64: dts: qcom: qcs6490-rb3gen2: Declare GCC clocks protected
  (bsc#1012628).
- pmdomain: ti: Add a null pointer check to the
  omap_prm_domain_init (bsc#1012628).
- pmdomain: imx8mp-blk-ctrl: imx8mp_blk: Add fdcc clock to
  hdmimix domain (bsc#1012628).
- ACPI: resource: Add IRQ override quirk for ASUS ExpertBook
  B2502FBA (bsc#1012628).
- ionic: set adminq irq affinity (bsc#1012628).
- net: skbuff: add overflow debug check to pull/push helpers
  (bsc#1012628).
- firmware: tegra: bpmp: Return directly after a failed kzalloc()
  in get_filename() (bsc#1012628).
- wifi: brcmfmac: Add DMI nvram filename quirk for ACEPC W5 Pro
  (bsc#1012628).
- wifi: mt76: mt7915: add locking for accessing mapped registers
  (bsc#1012628).
- wifi: mt76: mt7996: disable AMSDU for non-data frames
  (bsc#1012628).
- wifi: mt76: mt7996: add locking for accessing mapped registers
  (bsc#1012628).
- ACPI: x86: Move acpi_quirk_skip_serdev_enumeration() out of
  CONFIG_X86_ANDROID_TABLETS (bsc#1012628).
- ACPI: x86: Add DELL0501 handling to
  acpi_quirk_skip_serdev_enumeration() (bsc#1012628).
- pstore/zone: Add a null pointer check to the psz_kmsg_read
  (bsc#1012628).
- tools/power x86_energy_perf_policy: Fix file leak in
  get_pkg_num() (bsc#1012628).
- net: pcs: xpcs: Return EINVAL in the internal methods
  (bsc#1012628).
- dma-direct: Leak pages on dma_set_decrypted() failure
  (bsc#1012628).
- iommu/arm-smmu-v3: Hold arm_smmu_asid_lock during all of
  attach_dev (bsc#1012628).
- cpufreq: Don't unregister cpufreq cooling on CPU hotplug
  (bsc#1012628).
- overflow: Allow non-type arg to type_max() and type_min()
  (bsc#1012628).
- wifi: cfg80211: check A-MSDU format more carefully
  (bsc#1012628).
- btrfs: handle chunk tree lookup error in
  btrfs_relocate_sys_chunks() (bsc#1012628).
- btrfs: export: handle invalid inode or root reference in
  btrfs_get_parent() (bsc#1012628).
- btrfs: send: handle path ref underflow in header
  iterate_inode_ref() (bsc#1012628).
- ice: use relative VSI index for VFs instead of PF VSI number
  (bsc#1012628).
- net/smc: reduce rtnl pressure in smc_pnet_create_pnetids_list()
  (bsc#1012628).
- netdev: let netlink core handle -EMSGSIZE errors (bsc#1012628).
- Bluetooth: btintel: Fix null ptr deref in btintel_read_version
  (bsc#1012628).
- Bluetooth: Add new quirk for broken read key length on ATS2851
  (bsc#1012628).
- drm/vc4: don't check if plane->state->fb == state->fb
  (bsc#1012628).
- drm/ci: uprev mesa version: fix kdl commit fetch (bsc#1012628).
- drm/amdgpu: Skip do PCI error slot reset during RAS recovery
  (bsc#1012628).
- Input: synaptics-rmi4 - fail probing if memory allocation for
  "phys" fails (bsc#1012628).
- drm: panel-orientation-quirks: Add quirk for GPD Win Mini
  (bsc#1012628).
- ASoC: SOF: amd: Optimize quirk for Valve Galileo (bsc#1012628).
- drm/ttm: return ENOSPC from ttm_bo_mem_space v3 (bsc#1012628).
- scsi: ufs: qcom: Avoid re-init quirk when gears match
  (bsc#1012628).
- drm/amd/display: increased min_dcfclk_mhz and min_fclk_mhz
  (bsc#1012628).
- pinctrl: renesas: checker: Limit cfg reg enum checks to provided
  IDs (bsc#1012628).
- sysv: don't call sb_bread() with pointers_lock held
  (bsc#1012628).
- scsi: lpfc: Fix possible memory leak in lpfc_rcv_padisc()
  (bsc#1012628).
- drm/amd/display: Disable idle reallow as part of command/gpint
  execution (bsc#1012628).
- isofs: handle CDs with bad root inode but good Joliet root
  directory (bsc#1012628).
- ASoC: Intel: sof_rt5682: dmi quirk cleanup for mtl boards
  (bsc#1012628).
- ASoC: Intel: common: DMI remap for rebranded Intel NUC M15
  (LAPRC710) laptops (bsc#1012628).
- rcu/nocb: Fix WARN_ON_ONCE() in the rcu_nocb_bypass_lock()
  (bsc#1012628).
- rcu-tasks: Repair RCU Tasks Trace quiescence check
  (bsc#1012628).
- Julia Lawall reported this null pointer dereference, this
  should fix it (bsc#1012628).
- media: sta2x11: fix irq handler cast (bsc#1012628).
- ALSA: firewire-lib: handle quirk to calculate payload quadlets
  as data block counter (bsc#1012628).
- drm/panel: simple: Add BOE BP082WX1-100 8.2" panel
  (bsc#1012628).
- x86/vdso: Fix rethunk patching for vdso-image-{32,64}.o
  (bsc#1012628).
- ASoC: Intel: avs: Populate board selection with new I2S entries
  (bsc#1012628).
- ext4: add a hint for block bitmap corrupt state in mb_groups
  (bsc#1012628).
- ext4: forbid commit inconsistent quota data when
  errors=remount-ro (bsc#1012628).
- drm/amd/display: Fix nanosec stat overflow (bsc#1012628).
- accel/habanalabs: increase HL_MAX_STR to 64 bytes to avoid
  warnings (bsc#1012628).
- i2c: designware: Fix RX FIFO depth define on Wangxun 10Gb NIC
  (bsc#1012628).
- HID: input: avoid polling stylus battery on Chromebook Pompom
  (bsc#1012628).
- drm/amd/amdgpu: Fix potential ioremap() memory leaks in
  amdgpu_device_init() (bsc#1012628).
- drm: Check output polling initialized before disabling
  (bsc#1012628).
- drm: Check polling initialized before enabling in
  drm_helper_probe_single_connector_modes (bsc#1012628).
- SUNRPC: increase size of rpc_wait_queue.qlen from unsigned
  short to unsigned int (bsc#1012628).
- PCI: Disable D3cold on Asus B1400 PCI-NVMe bridge (bsc#1012628).
- Revert "ACPI: PM: Block ASUS B1400CEAE from suspend to idle
  by default" (bsc#1012628).
- libperf evlist: Avoid out-of-bounds access (bsc#1012628).
- crypto: iaa - Fix async_disable descriptor leak (bsc#1012628).
- input/touchscreen: imagis: Correct the maximum touch area value
  (bsc#1012628).
- drivers/perf: hisi: Enable HiSilicon Erratum 162700402 quirk
  for HIP09 (bsc#1012628).
- block: prevent division by zero in blk_rq_stat_sum()
  (bsc#1012628).
- RDMA/cm: add timeout to cm_destroy_id wait (bsc#1012628).
- Input: imagis - use FIELD_GET where applicable (bsc#1012628).
- Input: allocate keycode for Display refresh rate toggle
  (bsc#1012628).
- platform/x86: acer-wmi: Add support for Acer PH16-71
  (bsc#1012628).
- platform/x86: acer-wmi: Add predator_v4 module parameter
  (bsc#1012628).
- platform/x86: touchscreen_dmi: Add an extra entry for a variant
  of the Chuwi Vi8 tablet (bsc#1012628).
- perf/x86/amd/lbr: Discard erroneous branch entries
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Lenovo Yoga 9 14IMH9
  (bsc#1012628).
- ktest: force $buildonly = 1 for 'make_warnings_file' test type
  (bsc#1012628).
- Input: xpad - add support for Snakebyte GAMEPADs (bsc#1012628).
- ring-buffer: use READ_ONCE() to read cpu_buffer->commit_page
  in concurrent environment (bsc#1012628).
- tools: iio: replace seekdir() in iio_generic_buffer
  (bsc#1012628).
- bus: mhi: host: Add MHI_PM_SYS_ERR_FAIL state (bsc#1012628).
- kernfs: RCU protect kernfs_nodes and avoid kernfs_idr_lock in
  kernfs_find_and_get_node_by_id() (bsc#1012628).
- usb: typec: ucsi: Add qcm6490-pmic-glink as needing PDOS quirk
  (bsc#1012628).
- thunderbolt: Calculate DisplayPort tunnel bandwidth after DPRX
  capabilities read (bsc#1012628).
- usb: gadget: uvc: refactor the check for a valid buffer in
  the pump worker (bsc#1012628).
- usb: gadget: uvc: mark incomplete frames with UVC_STREAM_ERR
  (bsc#1012628).
- usb: typec: ucsi: Limit read size on v1.2 (bsc#1012628).
- serial: 8250_of: Drop quirk fot NPCM from 8250_port
  (bsc#1012628).
- thunderbolt: Keep the domain powered when USB4 port is in
  redrive mode (bsc#1012628).
- usb: typec: tcpci: add generic tcpci fallback compatible
  (bsc#1012628).
- usb: sl811-hcd: only defined function checkdone if QUIRK2 is
  defined (bsc#1012628).
- ASoC: amd: yc: Fix non-functional mic on ASUS M7600RE
  (bsc#1012628).
- thermal/of: Assume polling-delay(-passive) 0 when absent
  (bsc#1012628).
- ASoC: soc-core.c: Skip dummy codec when adding platforms
  (bsc#1012628).
- x86/xen: attempt to inflate the memory balloon on PVH
  (bsc#1012628).
- fbdev: viafb: fix typo in hw_bitblt_1 and hw_bitblt_2
  (bsc#1012628).
- io_uring: clear opcode specific data for an early failure
  (bsc#1012628).
- modpost: fix null pointer dereference (bsc#1012628).
- drivers/nvme: Add quirks for device 126f:2262 (bsc#1012628).
- fbmon: prevent division by zero in fb_videomode_from_videomode()
  (bsc#1012628).
- ALSA: hda/realtek: Add quirks for some Clevo laptops
  (bsc#1012628).
- drm/amdgpu: Init zone device and drm client after mode-1 reset
  on reload (bsc#1012628).
- media: mediatek: vcodec: Fix oops when HEVC init fails
  (bsc#1012628).
- media: mediatek: vcodec: adding lock to protect decoder context
  list (bsc#1012628).
- media: mediatek: vcodec: adding lock to protect encoder context
  list (bsc#1012628).
- randomize_kstack: Improve entropy diffusion (bsc#1012628).
- platform/x86/intel/hid: Don't wake on 5-button releases
  (bsc#1012628).
- platform/x86: intel-vbtn: Update tablet mode switch at end of
  probe (bsc#1012628).
- nouveau: fix devinit paths to only handle display on GSP
  (bsc#1012628).
- Bluetooth: btintel: Fixe build regression (bsc#1012628).
- net: mpls: error out if inner headers are not set (bsc#1012628).
- VMCI: Fix possible memcpy() run-time warning in
  vmci_datagram_invoke_guest_handler() (bsc#1012628).
- x86/vdso: Fix rethunk patching for vdso-image-x32.o too
  (bsc#1012628).
- Revert "drm/amd/amdgpu: Fix potential ioremap() memory leaks
  in amdgpu_device_init()" (bsc#1012628).
- Rename to
  patches.kernel.org/6.8.6-041-wifi-ath11k-decrease-MHI-channel-buffer-length-.patch.
- Rename to
  patches.kernel.org/6.8.6-045-wifi-iwlwifi-Add-missing-MODULE_FIRMWARE-for-.p.patch.
- Rename to
  patches.kernel.org/6.8.6-054-Bluetooth-btmtk-Add-MODULE_FIRMWARE-for-MT7922.patch.
- Rename to
  patches.kernel.org/6.8.6-131-gcc-plugins-stackleak-Avoid-.head.text-section.patch.
- commit 15f7a16
* Sun Apr 14 2024 mkubecek@suse.cz
- update to 6.9-rc4
- update configs
  - MITIGATION_SPECTRE_BHI=y (x86 only)
- commit 750564f
* Thu Apr 11 2024 jslaby@suse.cz
- gcc-plugins/stackleak: Avoid .head.text section (git-fixes).
- commit 542f698
* Thu Apr 11 2024 jslaby@suse.cz
- Linux 6.8.5 (bsc#1012628).
- x86: set SPECTRE_BHI_ON as default (bsc#1012628).
- KVM: x86: Add BHI_NO (bsc#1012628).
- x86/bhi: Mitigate KVM by default (bsc#1012628).
- x86/bhi: Add BHI mitigation knob (bsc#1012628 bsc#1217339 CVE-2024-2201).
- Update config files (set SPECTRE_BHI_ON=y which is the default later).
- x86/bhi: Enumerate Branch History Injection (BHI) bug
  (bsc#1012628).
- x86/bhi: Define SPEC_CTRL_BHI_DIS_S (bsc#1012628).
- x86/bhi: Add support for clearing branch history at syscall
  entry (bsc#1012628).
- x86/syscall: Don't force use of indirect calls for system calls
  (bsc#1012628).
- x86/bugs: Change commas to semicolons in 'spectre_v2' sysfs file
  (bsc#1012628).
- x86/efistub: Remap kernel text read-only before dropping NX
  attribute (bsc#1012628).
- x86/sev: Move early startup code into .head.text section
  (bsc#1012628).
- x86/sme: Move early SME kernel encryption handling into
  .head.text (bsc#1012628).
- x86/boot: Move mem_encrypt= parsing to the decompressor
  (bsc#1012628).
- efi/libstub: Add generic support for parsing mem_encrypt=
  (bsc#1012628).
- bpf: support deferring bpf_link dealloc to after RCU grace
  period (bsc#1012628).
- bpf: put uprobe link's path and task in release callback
  (bsc#1012628).
- Revert "x86/mpparse: Register APIC address only once"
  (bsc#1012628).
- drm/xe: Rework rebinding (bsc#1012628).
- drm/xe: Use ring ops TLB invalidation for rebinds (bsc#1012628).
- drm/i915/gt: Enable only one CCS for compute workload
  (bsc#1012628).
- drm/i915/gt: Do not generate the command streamer for all the
  CCS (bsc#1012628).
- drm/i915/gt: Disable HW load balancing for CCS (bsc#1012628).
- drm/i915/dp: Fix the computation for compressed_bpp for DISPLAY
  < 13 (bsc#1012628).
- drm/i915/mst: Reject FEC+MST on ICL (bsc#1012628).
- drm/i915/mst: Limit MST+DSC to TGL+ (bsc#1012628).
- smb: client: fix potential UAF in
  cifs_signal_cifsd_for_reconnect() (bsc#1012628).
- smb: client: fix potential UAF in smb2_is_network_name_deleted()
  (bsc#1012628).
- smb: client: fix potential UAF in is_valid_oplock_break()
  (bsc#1012628).
- smb: client: fix potential UAF in smb2_is_valid_lease_break()
  (bsc#1012628).
- smb: client: fix potential UAF in smb2_is_valid_oplock_break()
  (bsc#1012628).
- smb: client: fix potential UAF in cifs_dump_full_key()
  (bsc#1012628).
- smb: client: fix potential UAF in cifs_stats_proc_show()
  (bsc#1012628).
- smb: client: fix potential UAF in cifs_stats_proc_write()
  (bsc#1012628).
- smb: client: fix potential UAF in cifs_debug_files_proc_show()
  (bsc#1012628).
- smb3: retrying on failed server close (bsc#1012628).
- smb: client: serialise cifs_construct_tcon() with
  cifs_mount_mutex (bsc#1012628).
- smb: client: handle DFS tcons in cifs_construct_tcon()
  (bsc#1012628).
- smb: client: refresh referral without acquiring refpath_lock
  (bsc#1012628).
- smb: client: guarantee refcounted children from parent session
  (bsc#1012628).
- smb: client: fix UAF in smb2_reconnect_server() (bsc#1012628).
- riscv: process: Fix kernel gp leakage (bsc#1012628).
- riscv: Fix spurious errors from __get/put_kernel_nofault
  (bsc#1012628).
- s390/entry: align system call table on 8 bytes (bsc#1012628).
- selftests/mm: include strings.h for ffsl (bsc#1012628).
- mm/secretmem: fix GUP-fast succeeding on secretmem folios
  (bsc#1012628).
- arm64/ptrace: Use saved floating point state type to determine
  SVE layout (bsc#1012628).
- riscv: Fix vector state restore in rt_sigreturn() (bsc#1012628).
- aio: Fix null ptr deref in aio_complete() wakeup (bsc#1012628).
- perf/x86/intel/ds: Don't clear ->pebs_data_cfg for the last
  PEBS event (bsc#1012628).
- x86/coco: Require seeding RNG with RDRAND on CoCo systems
  (bsc#1012628).
- x86/mce: Make sure to grab mce_sysfs_mutex in set_bank()
  (bsc#1012628).
- x86/mm/pat: fix VM_PAT handling in COW mappings (bsc#1012628).
- of: module: prevent NULL pointer dereference in vsnprintf()
  (bsc#1012628).
- of: dynamic: Synchronize of_changeset_destroy() with the
  devlink removals (bsc#1012628).
- driver core: Introduce device_link_wait_removal() (bsc#1012628).
- ASoC: SOF: Intel: hda: Compensate LLP in case it is not reset
  (bsc#1012628).
- ASoC: SOF: ipc4-pcm: Correct the delay calculation
  (bsc#1012628).
- ASoC: SOF: sof-pcm: Add pointer callback to sof_ipc_pcm_ops
  (bsc#1012628).
- ASoC: SOF: ipc4-pcm: Invalidate the stream_start_offset in
  PAUSED state (bsc#1012628).
- ASoC: SOF: ipc4-pcm: Combine the SOF_IPC4_PIPE_PAUSED cases
  in pcm_trigger (bsc#1012628).
- ASoC: SOF: ipc4-pcm: Move struct sof_ipc4_timestamp_info
  definition locally (bsc#1012628).
- ASoC: SOF: Remove the get_stream_position callback
  (bsc#1012628).
- ASoC: SOF: ipc4-pcm: Use the snd_sof_pcm_get_dai_frame_counter()
  for pcm_delay (bsc#1012628).
- ASoC: SOF: Intel: hda-common-ops: Do not set the
  get_stream_position callback (bsc#1012628).
- ASoC: SOF: Intel: Set the dai/host get frame/byte counter
  callbacks (bsc#1012628).
- ASoC: SOF: Introduce a new callback pair to be used for PCM
  delay reporting (bsc#1012628).
- ASoC: SOF: Intel: mtl/lnl: Use the generic get_stream_position
  callback (bsc#1012628).
- ASoC: SOF: Intel: hda: Implement get_stream_position (Linear
  Link Position) (bsc#1012628).
- ASoC: SOF: Intel: hda-pcm: Use dsp_max_burst_size_in_ms to
  place constraint (bsc#1012628).
- ASoC: SOF: ipc4-topology: Save the DMA maximum burst size for
  PCMs (bsc#1012628).
- ASoC: SOF: Add dsp_max_burst_size_in_ms member to
  snd_sof_pcm_stream (bsc#1012628).
- io_uring/kbuf: hold io_buffer_list reference over mmap
  (bsc#1012628).
- io_uring: use private workqueue for exit work (bsc#1012628).
- io_uring/rw: don't allow multishot reads without NOWAIT support
  (bsc#1012628).
- io_uring/kbuf: protect io_buffer_list teardown with a reference
  (bsc#1012628).
- io_uring/kbuf: get rid of bl->is_ready (bsc#1012628).
- io_uring/kbuf: get rid of lower BGID lists (bsc#1012628).
- ALSA: hda/realtek: Update Panasonic CF-SZ6 quirk to support
  headset with microphone (bsc#1012628).
- ALSA: hda/realtek: cs35l41: Support ASUS ROG G634JYR
  (bsc#1012628).
- ALSA: hda/realtek: Add sound quirks for Lenovo Legion slim 7
  16ARHA7 models (bsc#1012628).
- ALSA: hda/realtek - Fix inactive headset mic jack (bsc#1012628).
- ALSA: hda: Add pplcllpl/u members to hdac_ext_stream
  (bsc#1012628).
- ksmbd: do not set SMB2_GLOBAL_CAP_ENCRYPTION for SMB 3.1.1
  (bsc#1012628).
- ksmbd: validate payload size in ipc response (bsc#1012628).
- ksmbd: don't send oplock break if rename fails (bsc#1012628).
- gpio: cdev: fix missed label sanitizing in debounce_setup()
  (bsc#1012628).
- gpio: cdev: check for NULL labels when sanitizing them for irqs
  (bsc#1012628).
- Revert "drm/amd/display: Send DTBCLK disable message on first
  commit" (bsc#1012628).
- x86/retpoline: Add NOENDBR annotation to the SRSO dummy return
  thunk (bsc#1012628).
- stackdepot: rename pool_index to pool_index_plus_1
  (bsc#1012628).
- lib/stackdepot: move stack_record struct definition into the
  header (bsc#1012628).
- nfsd: hold a lighter-weight client reference over CB_RECALL_ANY
  (bsc#1012628).
- riscv: Disable preemption when using patch_map() (bsc#1012628).
- riscv: Fix warning by declaring arch_cpu_idle() as noinstr
  (bsc#1012628).
- riscv: use KERN_INFO in do_trap (bsc#1012628).
- SUNRPC: Fix a slow server-side memory leak with RPC-over-TCP
  (bsc#1012628).
- ASoC: SOF: amd: fix for false dsp interrupts (bsc#1012628).
- ata: sata_mv: Fix PCI device ID table declaration compilation
  warning (bsc#1012628).
- drm/i915/gt: Limit the reserved VM space to only the platforms
  that need it (bsc#1012628).
- thermal: gov_power_allocator: Allow binding without trip points
  (bsc#1012628).
- thermal: gov_power_allocator: Allow binding without cooling
  devices (bsc#1012628).
- s390/pai: fix sampling event removal for PMU device driver
  (bsc#1012628).
- spi: mchp-pci1xxx: Fix a possible null pointer dereference in
  pci1xxx_spi_probe (bsc#1012628).
- cifs: Fix caching to try to do open O_WRONLY as rdwr on server
  (bsc#1012628).
- drm/i915/dp: Fix DSC state HW readout for SST connectors
  (bsc#1012628).
- Revert "ALSA: emu10k1: fix synthesizer sample playback position
  and caching" (bsc#1012628).
- scsi: sd: Unregister device if device_add_disk() failed in
  sd_probe() (bsc#1012628).
- scsi: mylex: Fix sysfs buffer lengths (bsc#1012628).
- ata: sata_sx4: fix pdc20621_get_from_dimm() on 64-bit
  (bsc#1012628).
- regmap: maple: Fix uninitialized symbol 'ret' warnings
  (bsc#1012628).
- ASoC: amd: acp: fix for acp_init function error handling
  (bsc#1012628).
- spi: s3c64xx: Use DMA mode from fifo size (bsc#1012628).
- spi: s3c64xx: determine the fifo depth only once (bsc#1012628).
- spi: s3c64xx: allow full FIFO masks (bsc#1012628).
- spi: s3c64xx: define a magic value (bsc#1012628).
- spi: s3c64xx: remove else after return (bsc#1012628).
- spi: s3c64xx: explicitly include <linux/bits.h> (bsc#1012628).
- spi: s3c64xx: sort headers alphabetically (bsc#1012628).
- spi: s3c64xx: Extract FIFO depth calculation to a dedicated
  macro (bsc#1012628).
- ASoC: ops: Fix wraparound for mask in snd_soc_get_volsw
  (bsc#1012628).
- ASoC: rt722-sdca-sdw: fix locking sequence (bsc#1012628).
- ASoC: rt712-sdca-sdw: fix locking sequence (bsc#1012628).
- ASoC: rt711-sdw: fix locking sequence (bsc#1012628).
- ASoC: rt711-sdca: fix locking sequence (bsc#1012628).
- ASoC: rt5682-sdw: fix locking sequence (bsc#1012628).
- drm/prime: Unbreak virtgpu dma-buf export (bsc#1012628).
- nouveau/uvmm: fix addr/range calcs for remap operations
  (bsc#1012628).
- drm/panfrost: fix power transition timeout warnings
  (bsc#1012628).
- ALSA: hda: cs35l56: Add ACPI device match tables (bsc#1012628).
- regmap: maple: Fix cache corruption in regcache_maple_drop()
  (bsc#1012628).
- ASoC: amd: acp: fix for acp pdm configuration check
  (bsc#1012628).
- RISC-V: Update AT_VECTOR_SIZE_ARCH for new AT_MINSIGSTKSZ
  (bsc#1012628).
- block: count BLK_OPEN_RESTRICT_WRITES openers (bsc#1012628).
- drivers/perf: riscv: Disable PERF_SAMPLE_BRANCH_* while not
  supported (bsc#1012628).
- riscv: hwprobe: do not produce frtace relocation (bsc#1012628).
- riscv: mm: Fix prototype to avoid discarding const
  (bsc#1012628).
- ASoC: cs42l43: Correct extraction of data pointer in
  suspend/resume (bsc#1012628).
- ASoC: wm_adsp: Fix missing mutex_lock in wm_adsp_write_ctl()
  (bsc#1012628).
- 9p: Fix read/write debug statements to report server reply
  (bsc#1012628).
- mptcp: don't account accept() of non-MPC client as fallback
  to TCP (bsc#1012628).
- selftests: mptcp: use += operator to append strings
  (bsc#1012628).
- selftests: mptcp: connect: fix shellcheck warnings
  (bsc#1012628).
- KVM: SVM: Add support for allowing zero SEV ASIDs (bsc#1012628).
- KVM: SVM: Use unsigned integers when dealing with ASIDs
  (bsc#1012628).
- net: ravb: Always update error counters (bsc#1012628).
- net: ravb: Always process TX descriptor ring (bsc#1012628).
- net: ravb: Let IP-specific receive function to interrogate
  descriptors (bsc#1012628).
- mean_and_variance: Drop always failing tests (bsc#1012628).
- e1000e: move force SMBUS from enable ulp function to avoid
  PHY loss issue (bsc#1012628).
- e1000e: Minor flow correction in e1000_shutdown function
  (bsc#1012628).
- drm/amd: Flush GFXOFF requests in prepare stage (bsc#1012628).
- i40e: Enforce software interrupt during busy-poll exit
  (bsc#1012628).
- i40e: fix vf may be used uninitialized in this function warning
  (bsc#1012628).
- i40e: fix i40e_count_filters() to count only active/new filters
  (bsc#1012628).
- octeontx2-af: Add array index check (bsc#1012628).
- octeontx2-pf: check negative error code in otx2_open()
  (bsc#1012628).
- octeontx2-af: Fix issue with loading coalesced KPU profiles
  (bsc#1012628).
- udp: prevent local UDP tunnel packets from being GROed
  (bsc#1012628).
- udp: do not transition UDP GRO fraglist partial checksums to
  unnecessary (bsc#1012628).
- udp: do not accept non-tunnel GSO skbs landing in a tunnel
  (bsc#1012628).
- r8169: skip DASH fw status checks when DASH is disabled
  (bsc#1012628).
- mlxbf_gige: stop interface during shutdown (bsc#1012628).
- ipv6: Fix infinite recursion in fib6_dump_done() (bsc#1012628).
- e1000e: Workaround for sporadic MDI error on Meteor Lake systems
  (bsc#1012628).
- ax25: fix use-after-free bugs caused by ax25_ds_del_timer
  (bsc#1012628).
- tcp: Fix bind() regression for v6-only wildcard and
  v4(-mapped-v6) non-wildcard addresses (bsc#1012628).
- selftests: reuseaddr_conflict: add missing new line at the
  end of the output (bsc#1012628).
- erspan: make sure erspan_base_hdr is present in skb->head
  (bsc#1012628).
- tcp: Fix bind() regression for v6-only wildcard and v4-mapped-v6
  non-wildcard addresses (bsc#1012628).
- i40e: Fix VF MAC filter removal (bsc#1012628).
- ice: fix enabling RX VLAN filtering (bsc#1012628).
- idpf: fix kernel panic on unknown packet types (bsc#1012628).
- gro: fix ownership transfer (bsc#1012628).
- selftests: net: gro fwd: update vxlan GRO test expectations
  (bsc#1012628).
- net: dsa: mv88e6xxx: fix usable ports on 88e6020 (bsc#1012628).
- net: phy: micrel: Fix potential null pointer dereference
  (bsc#1012628).
- net: fec: Set mac_managed_pm during probe (bsc#1012628).
- net: txgbe: fix i2c dev name cannot match clkdev (bsc#1012628).
- net: phy: micrel: lan8814: Fix when enabling/disabling 1-step
  timestamping (bsc#1012628).
- net: stmmac: fix rx queue priority assignment (bsc#1012628).
- net/sched: fix lockdep splat in qdisc_tree_reduce_backlog()
  (bsc#1012628).
- net: dsa: sja1105: Fix parameters order in
  sja1110_pcs_mdio_write_c45() (bsc#1012628).
- net/sched: act_skbmod: prevent kernel-infoleak (bsc#1012628).
- KVM: arm64: Ensure target address is granule-aligned for range
  TLBI (bsc#1012628).
- KVM: arm64: Use TLBI_TTL_UNKNOWN in __kvm_tlb_flush_vmid_range()
  (bsc#1012628).
- x86/retpoline: Do the necessary fixup to the Zen3/4 srso return
  thunk for !SRSO (bsc#1012628).
- mptcp: prevent BPF accessing lowat from a subflow socket
  (bsc#1012628).
- bpf, sockmap: Prevent lock inversion deadlock in map delete elem
  (bsc#1012628).
- vboxsf: Avoid an spurious warning if load_nls_xxx() fails
  (bsc#1012628).
- netfilter: validate user input for expected length
  (bsc#1012628).
- netfilter: nf_tables: discard table flag update with pending
  basechain deletion (bsc#1012628).
- netfilter: nf_tables: Fix potential data-race in
  __nft_flowtable_type_get() (bsc#1012628).
- netfilter: nf_tables: flush pending destroy work before exit_net
  release (bsc#1012628).
- netfilter: nf_tables: reject new basechain after table flag
  update (bsc#1012628).
- vsock/virtio: fix packet delivery to tap device (bsc#1012628).
- net: mana: Fix Rx DMA datasize and skb_over_panic (bsc#1012628).
- net: usb: ax88179_178a: avoid the interface always configured
  as random address (bsc#1012628).
- net/rds: fix possible cp null dereference (bsc#1012628).
- xen-netfront: Add missing skb_mark_for_recycle (bsc#1012628).
- selftests: mptcp: join: fix dev in check_endpoint (bsc#1012628).
- netfilter: nf_tables: release mutex after nft_gc_seq_end from
  abort path (bsc#1012628).
- netfilter: nf_tables: release batch on table validation from
  abort path (bsc#1012628).
- Bluetooth: Fix TOCTOU in HCI debugfs implementation
  (bsc#1012628).
- Bluetooth: hci_event: set the conn encrypted before conn
  establishes (bsc#1012628).
- Bluetooth: add quirk for broken address properties
  (bsc#1012628).
- Bluetooth: qca: fix device-address endianness (bsc#1012628).
- arm64: dts: qcom: sc7180-trogdor: mark bluetooth address as
  broken (bsc#1012628).
- Revert "Bluetooth: hci_qca: Set BDA quirk bit if fwnode exists
  in DT" (bsc#1012628).
- x86/bpf: Fix IP after emitting call depth accounting
  (bsc#1012628).
- x86/cpufeatures: Add CPUID_LNX_5 to track recently added
  Linux-defined word (bsc#1012628).
- x86/cpufeatures: Add new word for scattered features
  (bsc#1012628).
- r8169: fix issue caused by buggy BIOS on certain boards with
  RTL8168d (bsc#1012628).
- selinux: avoid dereference of garbage after mount failure
  (bsc#1012628).
- KVM: arm64: Fix out-of-IPA space translation fault handling
  (bsc#1012628).
- KVM: arm64: Fix host-programmed guest events in nVHE
  (bsc#1012628).
- RISC-V: KVM: Fix APLIC in_clrip[x] read emulation (bsc#1012628).
- RISC-V: KVM: Fix APLIC setipnum_le/be write emulation
  (bsc#1012628).
- gpio: cdev: sanitize the label before requesting the interrupt
  (bsc#1012628).
- Revert "x86/mm/ident_map: Use gbpages only where full GB page
  should be mapped." (bsc#1012628).
- mm/treewide: replace pud_large() with pud_leaf() (bsc#1012628).
- kbuild: make -Woverride-init warnings more consistent
  (bsc#1012628).
- modpost: do not make find_tosym() return NULL (bsc#1012628).
- dm integrity: fix out-of-range warning (bsc#1012628).
- drm/i915: Do not print 'pxp init failed with 0' when it succeed
  (bsc#1012628).
- drm/i915/mtl: Update workaround 14018575942 (bsc#1012628).
- drm/i915/xelpg: Extend some workarounds/tuning to gfx version
  12.74 (bsc#1012628).
- drm/i915/display: Disable AuxCCS framebuffers if built for Xe
  (bsc#1012628).
- drm/i915: Stop doing double audio enable/disable on SDVO and
  g4x+ DP (bsc#1012628).
- inet: inet_defrag: prevent sk release while still in use
  (bsc#1012628).
- Octeontx2-af: fix pause frame configuration in GMP mode
  (bsc#1012628).
- net: lan743x: Add set RFE read fifo threshold for PCI1x1x chips
  (bsc#1012628).
- net: bcmasp: Bring up unimac after PHY link up (bsc#1012628).
- iommu: Validate the PASID in iommu_attach_device_pasid()
  (bsc#1012628).
- netfilter: nf_tables: skip netdev hook unregistration if table
  is dormant (bsc#1012628).
- netfilter: nf_tables: reject table flag and netdev basechain
  updates (bsc#1012628).
- netfilter: nf_tables: reject destroy command to remove basechain
  hooks (bsc#1012628).
- cifs: Fix duplicate fscache cookie warnings (bsc#1012628).
- bpf: Protect against int overflow for stack access size
  (bsc#1012628).
- drm/amd/display: Send DTBCLK disable message on first commit
  (bsc#1012628).
- drm/amd/display: Update P010 scaling cap (bsc#1012628).
- mlxbf_gige: call request_irq() after NAPI initialized
  (bsc#1012628).
- tls: get psock ref after taking rxlock to avoid leak
  (bsc#1012628).
- tls: adjust recv return with async crypto and failed copy to
  userspace (bsc#1012628).
- tls: recv: process_rx_list shouldn't use an offset with kvec
  (bsc#1012628).
- net: hns3: mark unexcuted loopback test result as UNEXECUTED
  (bsc#1012628).
- net: hns3: fix kernel crash when devlink reload during pf
  initialization (bsc#1012628).
- net: hns3: fix index limit to support all queue stats
  (bsc#1012628).
- ACPICA: debugger: check status of acpi_evaluate_object()
  in acpi_db_walk_for_fields() (bsc#1012628).
- gpiolib: Fix debug messaging in gpiod_find_and_request()
  (bsc#1012628).
- selftests: vxlan_mdb: Fix failures with old libnet
  (bsc#1012628).
- drm/rockchip: vop2: Remove AR30 and AB30 format support
  (bsc#1012628).
- net: wwan: t7xx: Split 64bit accesses to fix alignment issues
  (bsc#1012628).
- tcp: properly terminate timers for kernel sockets (bsc#1012628).
- net: hsr: hsr_slave: Fix the promiscuous mode in offload mode
  (bsc#1012628).
- s390/qeth: handle deferred cc1 (bsc#1012628).
- dpll: indent DPLL option type by a tab (bsc#1012628).
- drm/xe/device: fix XE_MAX_TILES_PER_DEVICE check (bsc#1012628).
- drm/xe/device: fix XE_MAX_GT_PER_TILE check (bsc#1012628).
- drm/xe/queue: fix engine_class bounds check (bsc#1012628).
- drm/xe/guc_submit: use jiffies for job timeout (bsc#1012628).
- drm/xe: Add exec_queue.sched_props.job_timeout_ms (bsc#1012628).
- drm/xe: Remove unused xe_bo->props struct (bsc#1012628).
- igc: Remove stale comment about Tx timestamping (bsc#1012628).
- ixgbe: avoid sleeping allocation in ixgbe_ipsec_vf_add_sa()
  (bsc#1012628).
- ice: fix memory corruption bug with suspend and rebuild
  (bsc#1012628).
- ice: Refactor FW data type and fix bitmap casting issue
  (bsc#1012628).
- ALSA: hda: cs35l56: Set the init_done flag before
  component_add() (bsc#1012628).
- wifi: iwlwifi: mvm: include link ID when releasing frames
  (bsc#1012628).
- wifi: iwlwifi: mvm: rfi: fix potential response leaks
  (bsc#1012628).
- wifi: iwlwifi: mvm: pick the version of SESSION_PROTECTION_NOTIF
  (bsc#1012628).
- mlxbf_gige: stop PHY during open() error paths (bsc#1012628).
- tools: ynl: fix setting presence bits in simple nests
  (bsc#1012628).
- nfsd: Fix error cleanup path in nfsd_rename() (bsc#1012628).
- nfc: nci: Fix uninit-value in nci_dev_up and nci_ntf_packet
  (bsc#1012628).
- arm64: bpf: fix 32bit unconditional bswap (bsc#1012628).
- dma-buf: Fix NULL pointer dereference in sanitycheck()
  (bsc#1012628).
- bpf, arm64: fix bug in BPF_LDX_MEMSX (bsc#1012628).
- s390/bpf: Fix bpf_plt pointer arithmetic (bsc#1012628).
- xsk: Don't assume metadata is always requested in TX completion
  (bsc#1012628).
- scripts/bpf_doc: Use silent mode when exec make cmd
  (bsc#1012628).
- commit 0ff7778
* Sun Apr  7 2024 mkubecek@suse.cz
- update to 6.9-rc3
- commit 761535f
* Fri Apr  5 2024 tiwai@suse.de
- Input: psmouse: add NULL check to psmouse_from_serio()
  (bsc#1219522).
- commit 2e2b394
* Fri Apr  5 2024 jslaby@suse.cz
- Linux 6.8.4 (bsc#1012628).
- Refresh
  patches.kernel.org/6.8.4-002-Revert-workqueue-Don-t-call-cpumask_test_cpu-wi.patch.
- Refresh
  patches.kernel.org/6.8.4-003-Revert-workqueue-Implement-system-wide-nr_activ.patch.
- Refresh
  patches.kernel.org/6.8.4-005-Revert-workqueue-RCU-protect-wq-dfl_pwq-and-imp.patch.
- Refresh
  patches.kernel.org/6.8.4-008-Revert-workqueue-Replace-pwq_activate_inactive_.patch.
- Refresh
  patches.kernel.org/6.8.4-009-Revert-workqueue-Factor-out-pwq_is_empty.patch.
- Refresh
  patches.kernel.org/6.8.4-010-Revert-workqueue-Move-pwq-max_active-to-wq-max_.patch.
- Refresh
  patches.kernel.org/6.8.4-011-Revert-workqueue.c-Increase-workqueue-name-leng.patch.
- Delete patches.kernel.org/6.8.4-012-Linux-6.8.4-rc1.patch.
  Update patches to 6.8.4-final.
- commit f362b5c
* Thu Apr  4 2024 jslaby@suse.cz
- Linux 6.8.4-rc1 (bsc#1012628).
- Revert "workqueue.c: Increase workqueue name length"
  (bsc#1012628).
- Revert "workqueue: Move pwq->max_active to wq->max_active"
  (bsc#1012628).
- Revert "workqueue: Factor out pwq_is_empty()" (bsc#1012628).
- Revert "workqueue: Replace pwq_activate_inactive_work() with
  [__]pwq_activate_work()" (bsc#1012628).
- Revert "workqueue: Move nr_active handling into helpers"
  (bsc#1012628).
- Revert "workqueue: Make wq_adjust_max_active() round-robin
  pwqs while activating" (bsc#1012628).
- Revert "workqueue: RCU protect wq->dfl_pwq and implement
  accessors for it" (bsc#1012628).
- Revert "workqueue: Introduce struct wq_node_nr_active"
  (bsc#1012628).
- Revert "workqueue: Implement system-wide nr_active enforcement
  for unbound workqueues" (bsc#1012628).
- Revert "workqueue: Don't call cpumask_test_cpu() with -1 CPU
  in wq_update_node_max_active()" (bsc#1012628).
- Revert "workqueue: Shorten events_freezable_power_efficient
  name" (bsc#1012628).
- commit 1089550
* Wed Apr  3 2024 jslaby@suse.cz
- Linux 6.8.3 (bsc#1012628).
- drm/vmwgfx: Unmap the surface before resetting it on a plane
  state (bsc#1012628).
- wifi: brcmfmac: avoid invalid list operation when vendor attach
  fails (bsc#1012628).
- media: staging: ipu3-imgu: Set fields before
  media_entity_pads_init() (bsc#1012628).
- arm64: dts: qcom: sc7280: Add additional MSI interrupts
  (bsc#1012628).
- remoteproc: virtio: Fix wdg cannot recovery remote processor
  (bsc#1012628).
- clk: qcom: gcc-sdm845: Add soft dependency on rpmhpd
  (bsc#1012628).
- smack: Set SMACK64TRANSMUTE only for dirs in
  smack_inode_setxattr() (bsc#1012628).
- smack: Handle SMACK64TRANSMUTE in smack_inode_setsecurity()
  (bsc#1012628).
- arm: dts: marvell: Fix maxium->maxim typo in brownstone dts
  (bsc#1012628).
- drm/vmwgfx: Fix possible null pointer derefence with invalid
  contexts (bsc#1012628).
- arm64: dts: qcom: sm8450-hdk: correct AMIC4 and AMIC5
  microphones (bsc#1012628).
- serial: max310x: fix NULL pointer dereference in I2C
  instantiation (bsc#1012628).
- drm/vmwgfx: Fix the lifetime of the bo cursor memory
  (bsc#1012628).
- pci_iounmap(): Fix MMIO mapping leak (bsc#1012628).
- media: xc4000: Fix atomicity violation in xc4000_get_frequency
  (bsc#1012628).
- media: mc: Add local pad to pipeline regardless of the link
  state (bsc#1012628).
- media: mc: Fix flags handling when creating pad links
  (bsc#1012628).
- media: nxp: imx8-isi: Check whether crossbar pad is non-NULL
  before access (bsc#1012628).
- media: mc: Add num_links flag to media_pad (bsc#1012628).
- media: mc: Rename pad variable to clarify intent (bsc#1012628).
- media: mc: Expand MUST_CONNECT flag to always require an
  enabled link (bsc#1012628).
- media: nxp: imx8-isi: Mark all crossbar sink pads as
  MUST_CONNECT (bsc#1012628).
- md: use RCU lock to protect traversal in md_spares_need_change()
  (bsc#1012628).
- KVM: Always flush async #PF workqueue when vCPU is being
  destroyed (bsc#1012628).
- arm64: dts: qcom: sm8550-qrd: correct WCD9385 TX port mapping
  (bsc#1012628).
- arm64: dts: qcom: sm8550-mtp: correct WCD9385 TX port mapping
  (bsc#1012628).
- cpufreq: amd-pstate: Fix min_perf assignment in
  amd_pstate_adjust_perf() (bsc#1012628).
- thermal/intel: Fix intel_tcc_get_temp() to support negative
  CPU temperature (bsc#1012628).
- powercap: intel_rapl: Fix a NULL pointer dereference
  (bsc#1012628).
- powercap: intel_rapl: Fix locking in TPMI RAPL (bsc#1012628).
- powercap: intel_rapl_tpmi: Fix a register bug (bsc#1012628).
- powercap: intel_rapl_tpmi: Fix System Domain probing
  (bsc#1012628).
- powerpc/smp: Adjust nr_cpu_ids to cover all threads of a core
  (bsc#1012628).
- powerpc/smp: Increase nr_cpu_ids to include the boot CPU
  (bsc#1012628).
- sparc64: NMI watchdog: fix return value of __setup handler
  (bsc#1012628).
- sparc: vDSO: fix return value of __setup handler (bsc#1012628).
- crypto: qat - change SLAs cleanup flow at shutdown
  (bsc#1012628).
- crypto: qat - resolve race condition during AER recovery
  (bsc#1012628).
- selftests/mqueue: Set timeout to 180 seconds (bsc#1012628).
- pinctrl: qcom: sm8650-lpass-lpi: correct Kconfig name
  (bsc#1012628).
- ext4: correct best extent lstart adjustment logic (bsc#1012628).
- drm/amdgpu/display: Address kdoc for 'is_psr_su' in
  'fill_dc_dirty_rects' (bsc#1012628).
- block: Clear zone limits for a non-zoned stacked queue
  (bsc#1012628).
- kasan/test: avoid gcc warning for intentional overflow
  (bsc#1012628).
- bounds: support non-power-of-two CONFIG_NR_CPUS (bsc#1012628).
- fat: fix uninitialized field in nostale filehandles
  (bsc#1012628).
- fuse: fix VM_MAYSHARE and direct_io_allow_mmap (bsc#1012628).
- mfd: twl: Select MFD_CORE (bsc#1012628).
- ubifs: Set page uptodate in the correct place (bsc#1012628).
- ubi: Check for too small LEB size in VTBL code (bsc#1012628).
- ubi: correct the calculation of fastmap size (bsc#1012628).
- ubifs: ubifs_symlink: Fix memleak of inode->i_link in error path
  (bsc#1012628).
- mtd: rawnand: meson: fix scrambling mode value in command macro
  (bsc#1012628).
- md/md-bitmap: fix incorrect usage for sb_index (bsc#1012628).
- x86/nmi: Fix the inverse "in NMI handler" check (bsc#1012628).
- parisc/unaligned: Rewrite 64-bit inline assembly of
  emulate_ldd() (bsc#1012628).
- parisc: Avoid clobbering the C/B bits in the PSW with tophys
  and tovirt macros (bsc#1012628).
- parisc: Fix ip_fast_csum (bsc#1012628).
- parisc: Fix csum_ipv6_magic on 32-bit systems (bsc#1012628).
- parisc: Fix csum_ipv6_magic on 64-bit systems (bsc#1012628).
- parisc: Strip upper 32 bit of sum in csum_ipv6_magic for 64-bit
  builds (bsc#1012628).
- iio: adc: rockchip_saradc: fix bitmask for channels on SARADCv2
  (bsc#1012628).
- iio: adc: rockchip_saradc: use mask for write_enable bitfield
  (bsc#1012628).
- docs: Restore "smart quotes" for quotes (bsc#1012628).
- cpufreq: Limit resolving a frequency to policy min/max
  (bsc#1012628).
- PM: suspend: Set mem_sleep_current during kernel command line
  setup (bsc#1012628).
- vfio/pds: Always clear the save/restore FDs on reset
  (bsc#1012628).
- clk: qcom: gcc-ipq5018: fix terminating of frequency table
  arrays (bsc#1012628).
- clk: qcom: gcc-ipq6018: fix terminating of frequency table
  arrays (bsc#1012628).
- clk: qcom: gcc-ipq8074: fix terminating of frequency table
  arrays (bsc#1012628).
- clk: qcom: gcc-ipq9574: fix terminating of frequency table
  arrays (bsc#1012628).
- clk: qcom: camcc-sc8280xp: fix terminating of frequency table
  arrays (bsc#1012628).
- clk: qcom: mmcc-apq8084: fix terminating of frequency table
  arrays (bsc#1012628).
- clk: qcom: mmcc-msm8974: fix terminating of frequency table
  arrays (bsc#1012628).
- usb: xhci: Add error handling in xhci_map_urb_for_dma
  (bsc#1012628).
- powerpc/fsl: Fix mfpmr build errors with newer binutils
  (bsc#1012628).
- USB: serial: ftdi_sio: add support for GMC Z216C Adapter IR-USB
  (bsc#1012628).
- USB: serial: add device ID for VeriFone adapter (bsc#1012628).
- USB: serial: cp210x: add ID for MGP Instruments PDS100
  (bsc#1012628).
- wifi: mac80211: track capability/opmode NSS separately
  (bsc#1012628).
- USB: serial: option: add MeiG Smart SLM320 product
  (bsc#1012628).
- KVM: x86/xen: inject vCPU upcall vector when local APIC is
  enabled (bsc#1012628).
- USB: serial: cp210x: add pid/vid for TDK NC0110013M and
  MM0110113M (bsc#1012628).
- PM: sleep: wakeirq: fix wake irq warning in system suspend
  (bsc#1012628).
- mmc: tmio: avoid concurrent runs of mmc_request_done()
  (bsc#1012628).
- fuse: replace remaining make_bad_inode() with fuse_make_bad()
  (bsc#1012628).
- fuse: fix root lookup with nonzero generation (bsc#1012628).
- fuse: don't unhash root (bsc#1012628).
- usb: typec: ucsi: Clean up UCSI_CABLE_PROP macros (bsc#1012628).
- usb: dwc3-am62: fix module unload/reload behavior (bsc#1012628).
- usb: dwc3-am62: Disable wakeup at remove (bsc#1012628).
- serial: core: only stop transmit when HW fifo is empty
  (bsc#1012628).
- serial: Lock console when calling into driver before
  registration (bsc#1012628).
- btrfs: qgroup: always free reserved space for extent records
  (bsc#1012628).
- btrfs: fix off-by-one chunk length calculation at
  contains_pending_extent() (bsc#1012628).
- wifi: rtw88: Add missing VID/PIDs for 8811CU and 8821CU
  (bsc#1012628).
- docs: Makefile: Add dependency to $(YNL_INDEX) for targets
  other than htmldocs (bsc#1012628).
- PCI/PM: Drain runtime-idle callbacks before driver removal
  (bsc#1012628).
- PCI/DPC: Quirk PIO log size for Intel Raptor Lake Root Ports
  (bsc#1012628).
- Revert "Revert "md/raid5: Wait for MD_SB_CHANGE_PENDING in
  raid5d"" (bsc#1012628).
- md: don't clear MD_RECOVERY_FROZEN for new dm-raid until resume
  (bsc#1012628).
- md: export helpers to stop sync_thread (bsc#1012628).
- md: export helper md_is_rdwr() (bsc#1012628).
- md: add a new helper reshape_interrupted() (bsc#1012628).
- dm-raid: really frozen sync_thread during suspend (bsc#1012628).
- md/dm-raid: don't call md_reap_sync_thread() directly
  (bsc#1012628).
- dm-raid: add a new helper prepare_suspend() in md_personality
  (bsc#1012628).
- dm-raid456, md/raid456: fix a deadlock for dm-raid456 while
  io concurrent with reshape (bsc#1012628).
- dm-raid: fix lockdep waring in "pers->hot_add_disk"
  (bsc#1012628).
- powerpc: xor_vmx: Add '-mhard-float' to CFLAGS (bsc#1012628).
- block: Fix page refcounts for unaligned buffers in
  __bio_release_pages() (bsc#1012628).
- mac802154: fix llsec key resources release in
  mac802154_llsec_key_del (bsc#1012628).
- mm: swap: fix race between free_swap_and_cache() and swapoff()
  (bsc#1012628).
- mmc: core: Fix switch on gp3 partition (bsc#1012628).
- Bluetooth: btnxpuart: Fix btnxpuart_close (bsc#1012628).
- leds: trigger: netdev: Fix kernel panic on interface rename
  trig notify (bsc#1012628).
- drm/etnaviv: Restore some id values (bsc#1012628).
- landlock: Warn once if a Landlock action is requested while
  disabled (bsc#1012628).
- io_uring: fix mshot read defer taskrun cqe posting
  (bsc#1012628).
- hwmon: (amc6821) add of_match table (bsc#1012628).
- io_uring: fix io_queue_proc modifying req->flags (bsc#1012628).
- ext4: fix corruption during on-line resize (bsc#1012628).
- nvmem: meson-efuse: fix function pointer type mismatch
  (bsc#1012628).
- slimbus: core: Remove usage of the deprecated ida_simple_xx()
  API (bsc#1012628).
- phy: tegra: xusb: Add API to retrieve the port number of phy
  (bsc#1012628).
- usb: gadget: tegra-xudc: Fix USB3 PHY retrieval logic
  (bsc#1012628).
- speakup: Fix 8bit characters from direct synth (bsc#1012628).
- debugfs: fix wait/cancellation handling during remove
  (bsc#1012628).
- PCI/AER: Block runtime suspend when handling errors
  (bsc#1012628).
- io_uring/net: correctly handle multishot recvmsg retry setup
  (bsc#1012628).
- io_uring: fix mshot io-wq checks (bsc#1012628).
- PCI: qcom: Disable ASPM L0s for sc8280xp, sa8540p and sa8295p
  (bsc#1012628).
- sparc32: Fix parport build with sparc32 (bsc#1012628).
- nfs: fix UAF in direct writes (bsc#1012628).
- NFS: Read unlock folio on nfs_page_create_from_folio() error
  (bsc#1012628).
- kbuild: Move -Wenum-{compare-conditional,enum-conversion}
  into W=1 (bsc#1012628).
- PCI: qcom: Enable BDF to SID translation properly (bsc#1012628).
- PCI: dwc: endpoint: Fix advertised resizable BAR size
  (bsc#1012628).
- PCI: hv: Fix ring buffer size calculation (bsc#1012628).
- cifs: prevent updating file size from server if we have a
  read/write lease (bsc#1012628).
- cifs: allow changing password during remount (bsc#1012628).
- thermal/drivers/mediatek: Fix control buffer enablement on
  MT7896 (bsc#1012628).
- vfio/pci: Disable auto-enable of exclusive INTx IRQ
  (bsc#1012628).
- vfio/pci: Lock external INTx masking ops (bsc#1012628).
- vfio/platform: Disable virqfds on cleanup (bsc#1012628).
- vfio/platform: Create persistent IRQ handlers (bsc#1012628).
- vfio/fsl-mc: Block calling interrupt handler without trigger
  (bsc#1012628).
- tpm,tpm_tis: Avoid warning splat at shutdown (bsc#1012628).
- ksmbd: replace generic_fillattr with vfs_getattr (bsc#1012628).
- ksmbd: retrieve number of blocks using vfs_getattr in
  set_file_allocation_info (bsc#1012628).
- platform/x86/intel/tpmi: Change vsec offset to u64
  (bsc#1012628).
- io_uring/rw: return IOU_ISSUE_SKIP_COMPLETE for multishot retry
  (bsc#1012628).
- io_uring: clean rings on NO_MMAP alloc fail (bsc#1012628).
- ring-buffer: Do not set shortest_full when full target is hit
  (bsc#1012628).
- ring-buffer: Fix full_waiters_pending in poll (bsc#1012628).
- ring-buffer: Use wait_event_interruptible() in
  ring_buffer_wait() (bsc#1012628).
- tracing/ring-buffer: Fix wait_on_pipe() race (bsc#1012628).
- dlm: fix user space lkb refcounting (bsc#1012628).
- soc: fsl: qbman: Always disable interrupts when taking cgr_lock
  (bsc#1012628).
- soc: fsl: qbman: Use raw spinlock for cgr_lock (bsc#1012628).
- s390/zcrypt: fix reference counting on zcrypt card objects
  (bsc#1012628).
- drm/probe-helper: warn about negative .get_modes()
  (bsc#1012628).
- drm/panel: do not return negative error codes from
  drm_panel_get_modes() (bsc#1012628).
- drm/exynos: do not return negative values from .get_modes()
  (bsc#1012628).
- drm/imx/ipuv3: do not return negative values from .get_modes()
  (bsc#1012628).
- drm/vc4: hdmi: do not return negative values from .get_modes()
  (bsc#1012628).
- clocksource/drivers/timer-riscv: Clear timer interrupt on
  timer initialization (bsc#1012628).
- memtest: use {READ,WRITE}_ONCE in memory scanning (bsc#1012628).
- Revert "block/mq-deadline: use correct way to throttling write
  requests" (bsc#1012628).
- lsm: use 32-bit compatible data types in LSM syscalls
  (bsc#1012628).
- lsm: handle the NULL buffer case in lsm_fill_user_ctx()
  (bsc#1012628).
- f2fs: mark inode dirty for FI_ATOMIC_COMMITTED flag
  (bsc#1012628).
- f2fs: truncate page cache before clearing flags when aborting
  atomic write (bsc#1012628).
- nilfs2: fix failure to detect DAT corruption in btree and
  direct mappings (bsc#1012628).
- nilfs2: prevent kernel bug at submit_bh_wbc() (bsc#1012628).
- cifs: make sure server interfaces are requested only for SMB3+
  (bsc#1012628).
- cifs: reduce warning log level for server not advertising
  interfaces (bsc#1012628).
- cifs: open_cached_dir(): add FILE_READ_EA to desired access
  (bsc#1012628).
- mtd: rawnand: Fix and simplify again the continuous read
  derivations (bsc#1012628).
- mtd: rawnand: Add a helper for calculating a page index
  (bsc#1012628).
- mtd: rawnand: Ensure all continuous terms are always in sync
  (bsc#1012628).
- mtd: rawnand: Constrain even more when continuous reads are
  enabled (bsc#1012628).
- cpufreq: dt: always allocate zeroed cpumask (bsc#1012628).
- io_uring/futex: always remove futex entry for cancel all
  (bsc#1012628).
- io_uring/waitid: always remove waitid entry for cancel all
  (bsc#1012628).
- x86/CPU/AMD: Update the Zenbleed microcode revisions
  (bsc#1012628).
- ksmbd: fix slab-out-of-bounds in smb_strndup_from_utf16()
  (bsc#1012628).
- net: esp: fix bad handling of pages from page_pool
  (bsc#1012628).
- NFSD: Fix nfsd_clid_class use of __string_len() macro
  (bsc#1012628).
- drm/i915: Add missing ; to __assign_str() macros in tracepoint
  code (bsc#1012628).
- net: hns3: tracing: fix hclgevf trace event strings
  (bsc#1012628).
- cxl/trace: Properly initialize cxl_poison region name
  (bsc#1012628).
- ksmbd: fix potencial out-of-bounds when buffer offset is invalid
  (bsc#1012628).
- virtio: reenable config if freezing device failed (bsc#1012628).
- LoongArch: Change __my_cpu_offset definition to avoid
  mis-optimization (bsc#1012628).
- LoongArch: Define the __io_aw() hook as mmiowb() (bsc#1012628).
- LoongArch/crypto: Clean up useless assignment operations
  (bsc#1012628).
- wireguard: netlink: check for dangling peer via is_dead instead
  of empty list (bsc#1012628).
- wireguard: netlink: access device through ctx instead of peer
  (bsc#1012628).
- wireguard: selftests: set RISCV_ISA_FALLBACK on riscv{32,64}
  (bsc#1012628).
- ahci: asm1064: asm1166: don't limit reported ports
  (bsc#1012628).
- drm/amd/display: Change default size for dummy plane in DML2
  (bsc#1012628).
- drm/amdgpu: amdgpu_ttm_gart_bind set gtt bound flag
  (bsc#1012628).
- drm/amdgpu/pm: Fix NULL pointer dereference when get power limit
  (bsc#1012628).
- drm/amdgpu/pm: Check the validity of overdiver power limit
  (bsc#1012628).
- drm/amd/display: Override min required DCFCLK in dml1_validate
  (bsc#1012628).
- drm/amd/display: Allow dirty rects to be sent to dmub when
  abm is active (bsc#1012628).
- drm/amd/display: Init DPPCLK from SMU on dcn32 (bsc#1012628).
- drm/amd/display: Update odm when ODM combine is changed on an
  otg master pipe with no plane (bsc#1012628).
- drm/amd/display: Fix idle check for shared firmware state
  (bsc#1012628).
- drm/amd/display: Amend coasting vtotal for replay low hz
  (bsc#1012628).
- drm/amd/display: Lock all enabled otg pipes even with no planes
  (bsc#1012628).
- drm/amd/display: Implement wait_for_odm_update_pending_complete
  (bsc#1012628).
- drm/amd/display: Return the correct HDCP error code
  (bsc#1012628).
- drm/amd/display: Add a dc_state NULL check in dc_state_release
  (bsc#1012628).
- drm/amd/display: Fix noise issue on HDMI AV mute (bsc#1012628).
- dm snapshot: fix lockup in dm_exception_table_exit
  (bsc#1012628).
- x86/pm: Work around false positive kmemleak report in
  msr_build_context() (bsc#1012628).
- wifi: brcmfmac: add per-vendor feature detection callback
  (bsc#1012628).
- wifi: brcmfmac: cfg80211: Use WSEC to set SAE password
  (bsc#1012628).
- wifi: brcmfmac: Demote vendor-specific attach/detach messages
  to info (bsc#1012628).
- drm/ttm: Make sure the mapped tt pages are decrypted when needed
  (bsc#1012628).
- drm/amd/display: Unify optimize_required flags and VRR
  adjustments (bsc#1012628).
- drm/amd/display: Add more checks for exiting idle in DC
  (bsc#1012628).
- btrfs: add set_folio_extent_mapped() helper (bsc#1012628).
- btrfs: replace sb::s_blocksize by fs_info::sectorsize
  (bsc#1012628).
- btrfs: add helpers to get inode from page/folio pointers
  (bsc#1012628).
- btrfs: add helpers to get fs_info from page/folio pointers
  (bsc#1012628).
- btrfs: add helper to get fs_info from struct inode pointer
  (bsc#1012628).
- btrfs: qgroup: validate btrfs_qgroup_inherit parameter
  (bsc#1012628).
- vfio: Introduce interface to flush virqfd inject workqueue
  (bsc#1012628).
- vfio/pci: Create persistent INTx handler (bsc#1012628).
- drm/bridge: add ->edid_read hook and drm_bridge_edid_read()
  (bsc#1012628).
- drm/bridge: lt8912b: use drm_bridge_edid_read() (bsc#1012628).
- drm/bridge: lt8912b: clear the EDID property on failures
  (bsc#1012628).
- drm/bridge: lt8912b: do not return negative values from
  .get_modes() (bsc#1012628).
- drm/amd/display: Remove pixle rate limit for subvp
  (bsc#1012628).
- drm/amd/display: Revert Remove pixle rate limit for subvp
  (bsc#1012628).
- workqueue: Shorten events_freezable_power_efficient name
  (bsc#1012628).
- drm/amd/display: Use freesync when
  `DRM_EDID_FEATURE_CONTINUOUS_FREQ` found (bsc#1012628).
- netfilter: nf_tables: reject constant set with timeout
  (bsc#1012628).
- Revert "crypto: pkcs7 - remove sha1 support" (bsc#1012628).
- x86/efistub: Call mixed mode boot services on the firmware's
  stack (bsc#1012628).
- ASoC: amd: yc: Revert "Fix non-functional mic on Lenovo 21J2"
  (bsc#1012628).
- ASoC: amd: yc: Revert "add new YC platform variant (0x63)
  support" (bsc#1012628).
- Fix memory leak in posix_clock_open() (bsc#1012628).
- wifi: rtw88: 8821cu: Fix connection failure (bsc#1012628).
- x86/Kconfig: Remove CONFIG_AMD_MEM_ENCRYPT_ACTIVE_BY_DEFAULT
  (bsc#1012628).
- x86/sev: Fix position dependent variable references in startup
  code (bsc#1012628).
- clocksource/drivers/arm_global_timer: Fix maximum prescaler
  value (bsc#1012628).
- ARM: 9352/1: iwmmxt: Remove support for PJ4/PJ4B cores
  (bsc#1012628).
- ARM: 9359/1: flush: check if the folio is reserved for
  no-mapping addresses (bsc#1012628).
- entry: Respect changes to system call number by
  trace_sys_enter() (bsc#1012628).
- swiotlb: Fix double-allocation of slots due to broken alignment
  handling (bsc#1012628).
- swiotlb: Honour dma_alloc_coherent() alignment in
  swiotlb_alloc() (bsc#1012628).
- swiotlb: Fix alignment checks when both allocation and DMA
  masks are present (bsc#1012628).
- iommu/dma: Force swiotlb_max_mapping_size on an untrusted device
  (bsc#1012628).
- printk: Update @console_may_schedule in
  console_trylock_spinning() (bsc#1012628).
- irqchip/renesas-rzg2l: Flush posted write in irq_eoi()
  (bsc#1012628).
- irqchip/renesas-rzg2l: Rename rzg2l_tint_eoi() (bsc#1012628).
- irqchip/renesas-rzg2l: Rename rzg2l_irq_eoi() (bsc#1012628).
- irqchip/renesas-rzg2l: Prevent spurious interrupts when setting
  trigger type (bsc#1012628).
- kprobes/x86: Use copy_from_kernel_nofault() to read from unsafe
  address (bsc#1012628).
- efi/libstub: fix efi_random_alloc() to allocate memory at
  alloc_min or higher address (bsc#1012628).
- x86/mpparse: Register APIC address only once (bsc#1012628).
- x86/fpu: Keep xfd_state in sync with MSR_IA32_XFD (bsc#1012628).
- efi: fix panic in kdump kernel (bsc#1012628).
- pwm: img: fix pwm clock lookup (bsc#1012628).
- selftests/mm: Fix build with _FORTIFY_SOURCE (bsc#1012628).
- btrfs: handle errors returned from unpin_extent_cache()
  (bsc#1012628).
- btrfs: fix warning messages not printing interval at
  unpin_extent_range() (bsc#1012628).
- btrfs: do not skip re-registration for the mounted device
  (bsc#1012628).
- mfd: intel-lpss: Switch to generalized quirk table
  (bsc#1012628).
- mfd: intel-lpss: Introduce QUIRK_CLOCK_DIVIDER_UNITY for XPS
  9530 (bsc#1012628).
- drm/i915: Replace a memset() with zero initialization
  (bsc#1012628).
- drm/i915: Try to preserve the current shared_dpll for fastset
  on type-c ports (bsc#1012628).
- drm/i915: Include the PLL name in the debug messages
  (bsc#1012628).
- drm/i915: Suppress old PLL pipe_mask checks for MG/TC/TBT PLLs
  (bsc#1012628).
- crypto: iaa - Fix nr_cpus < nr_iaa case (bsc#1012628).
- drm/amd/display: Prevent crash when disable stream
  (bsc#1012628).
- ALSA: hda/tas2781: remove digital gain kcontrol (bsc#1012628).
- ALSA: hda/tas2781: add locks to kcontrols (bsc#1012628).
- mm: zswap: fix writeback shinker GFP_NOIO/GFP_NOFS recursion
  (bsc#1012628).
- init: open /initrd.image with O_LARGEFILE (bsc#1012628).
- x86/efistub: Add missing boot_params for mixed mode compat entry
  (bsc#1012628).
- efi/libstub: Cast away type warning in use of max()
  (bsc#1012628).
- x86/efistub: Reinstate soft limit for initrd loading
  (bsc#1012628).
- prctl: generalize PR_SET_MDWE support check to be per-arch
  (bsc#1012628).
- ARM: prctl: reject PR_SET_MDWE on pre-ARMv6 (bsc#1012628).
- tmpfs: fix race on handling dquot rbtree (bsc#1012628).
- btrfs: validate device maj:min during open (bsc#1012628).
- btrfs: fix race in read_extent_buffer_pages() (bsc#1012628).
- btrfs: zoned: don't skip block groups with 100%% zone unusable
  (bsc#1012628).
- btrfs: zoned: use zone aware sb location for scrub
  (bsc#1012628).
- btrfs: zoned: fix use-after-free in do_zone_finish()
  (bsc#1012628).
- wifi: mac80211: check/clear fast rx for non-4addr sta VLAN
  changes (bsc#1012628).
- wifi: cfg80211: add a flag to disable wireless extensions
  (bsc#1012628).
- wifi: iwlwifi: mvm: disable MLO for the time being
  (bsc#1012628).
- wifi: iwlwifi: fw: don't always use FW dump trig (bsc#1012628).
- wifi: iwlwifi: mvm: handle debugfs names more carefully
  (bsc#1012628).
- Revert "drm/amd/display: Fix sending VSC (+ colorimetry)
  packets for DP/eDP displays without PSR" (bsc#1012628).
- fbdev: Select I/O-memory framebuffer ops for SBus (bsc#1012628).
- exec: Fix NOMMU linux_binprm::exec in transfer_args_to_stack()
  (bsc#1012628).
- hexagon: vmlinux.lds.S: handle attributes section (bsc#1012628).
- mm: cachestat: fix two shmem bugs (bsc#1012628).
- selftests/mm: sigbus-wp test requires
  UFFD_FEATURE_WP_HUGETLBFS_SHMEM (bsc#1012628).
- selftests/mm: fix ARM related issue with fork after
  pthread_create (bsc#1012628).
- mmc: sdhci-omap: re-tuning is needed after a pm transition to
  support emmc HS200 mode (bsc#1012628).
- mmc: core: Initialize mmc_blk_ioc_data (bsc#1012628).
- mmc: core: Avoid negative index with array access (bsc#1012628).
- sdhci-of-dwcmshc: disable PM runtime in dwcmshc_remove()
  (bsc#1012628).
- block: Do not force full zone append completion in
  req_bio_endio() (bsc#1012628).
- thermal: devfreq_cooling: Fix perf state when calculate dfc
  res_util (bsc#1012628).
- Revert "thermal: core: Don't update trip points inside the
  hysteresis range" (bsc#1012628).
- nouveau/dmem: handle kcalloc() allocation failure (bsc#1012628).
- net: ll_temac: platform_get_resource replaced by wrong function
  (bsc#1012628).
- net: wan: framer: Add missing static inline qualifiers
  (bsc#1012628).
- net: phy: qcom: at803x: fix kernel panic with at8031_probe
  (bsc#1012628).
- drm/xe/query: fix gt_id bounds check (bsc#1012628).
- drm/dp: Fix divide-by-zero regression on DP MST unplug with
  nouveau (bsc#1012628).
- drm/vmwgfx: Create debugfs ttm_resource_manager entry only if
  needed (bsc#1012628).
- drm/amdkfd: fix TLB flush after unmap for GFX9.4.2
  (bsc#1012628).
- drm/amdgpu: fix deadlock while reading mqd from debugfs
  (bsc#1012628).
- drm/amd/display: Remove MPC rate control logic from DCN30 and
  above (bsc#1012628).
- drm/amd/display: Set DCN351 BB and IP the same as DCN35
  (bsc#1012628).
- drm/i915/hwmon: Fix locking inversion in sysfs getter
  (bsc#1012628).
- drm/i915/vma: Fix UAF on destroy against retire race
  (bsc#1012628).
- drm/i915/bios: Tolerate devdata==NULL in
  intel_bios_encoder_supports_dp_dual_mode() (bsc#1012628).
- drm/i915/vrr: Generate VRR "safe window" for DSB (bsc#1012628).
- drm/i915/dsi: Go back to the previous INIT_OTP/DISPLAY_ON order,
  mostly (bsc#1012628).
- drm/i915/dsb: Fix DSB vblank waits when using VRR (bsc#1012628).
- drm/i915: Do not match JSL in ehl_combo_pll_div_frac_wa_needed()
  (bsc#1012628).
- drm/i915: Pre-populate the cursor physical dma address
  (bsc#1012628).
- drm/i915/gt: Reset queue_priority_hint on parking (bsc#1012628).
- drm/amd/display: Fix bounds check for dcn35 DcfClocks
  (bsc#1012628).
- mtd: spinand: Add support for 5-byte IDs (bsc#1012628).
- Revert "usb: phy: generic: Get the vbus supply" (bsc#1012628).
- usb: cdc-wdm: close race between read and workqueue
  (bsc#1012628).
- usb: misc: ljca: Fix double free in error handling path
  (bsc#1012628).
- USB: UAS: return ENODEV when submit urbs fail with device not
  attached (bsc#1012628).
- vfio/pds: Make sure migration file isn't accessed after reset
  (bsc#1012628).
- ring-buffer: Make wake once of ring_buffer_wait() more robust
  (bsc#1012628).
- btrfs: fix extent map leak in unexpected scenario at
  unpin_extent_cache() (bsc#1012628).
- ALSA: sh: aica: reorder cleanup operations to avoid UAF bugs
  (bsc#1012628).
- scsi: ufs: qcom: Provide default cycles_in_1us value
  (bsc#1012628).
- scsi: sd: Fix TCG OPAL unlock on system resume (bsc#1012628).
- scsi: core: Fix unremoved procfs host directory regression
  (bsc#1012628).
- staging: vc04_services: changen strncpy() to strscpy_pad()
  (bsc#1012628).
- staging: vc04_services: fix information leak in
  create_component() (bsc#1012628).
- genirq: Introduce IRQF_COND_ONESHOT and use it in pinctrl-amd
  (bsc#1012628).
- usb: dwc3: Properly set system wakeup (bsc#1012628).
- USB: core: Fix deadlock in usb_deauthorize_interface()
  (bsc#1012628).
- USB: core: Add hub_get() and hub_put() routines (bsc#1012628).
- USB: core: Fix deadlock in port "disable" sysfs attribute
  (bsc#1012628).
- usb: dwc2: host: Fix remote wakeup from hibernation
  (bsc#1012628).
- usb: dwc2: host: Fix hibernation flow (bsc#1012628).
- usb: dwc2: host: Fix ISOC flow in DDMA mode (bsc#1012628).
- usb: dwc2: gadget: Fix exiting from clock gating (bsc#1012628).
- usb: dwc2: gadget: LPM flow fix (bsc#1012628).
- usb: udc: remove warning when queue disabled ep (bsc#1012628).
- usb: typec: ucsi: Fix race between typec_switch and role_switch
  (bsc#1012628).
- usb: typec: tcpm: fix double-free issue in
  tcpm_port_unregister_pd() (bsc#1012628).
- usb: typec: tcpm: Correct port source pdo array in pd_set
  callback (bsc#1012628).
- usb: typec: tcpm: Update PD of Type-C port upon pd_set
  (bsc#1012628).
- usb: typec: Return size of buffer if pd_set operation succeeds
  (bsc#1012628).
- usb: typec: ucsi: Clear EVENT_PENDING under PPM lock
  (bsc#1012628).
- usb: typec: ucsi: Ack unsupported commands (bsc#1012628).
- usb: typec: ucsi_acpi: Refactor and fix DELL quirk
  (bsc#1012628).
- usb: typec: ucsi: Clear UCSI_CCI_RESET_COMPLETE before reset
  (bsc#1012628).
- scsi: qla2xxx: Prevent command send on chip reset (bsc#1012628).
- scsi: qla2xxx: Fix N2N stuck connection (bsc#1012628).
- scsi: qla2xxx: Split FCE|EFT trace control (bsc#1012628).
- scsi: qla2xxx: Update manufacturer detail (bsc#1012628).
- scsi: qla2xxx: NVME|FCP prefer flag not being honored
  (bsc#1012628).
- scsi: qla2xxx: Fix command flush on cable pull (bsc#1012628).
- scsi: qla2xxx: Fix double free of the ha->vp_map pointer
  (bsc#1012628).
- scsi: qla2xxx: Fix double free of fcport (bsc#1012628).
- scsi: qla2xxx: Change debug message during driver unload
  (bsc#1012628).
- scsi: qla2xxx: Delay I/O Abort on PCI error (bsc#1012628).
- x86/bugs: Fix the SRSO mitigation on Zen3/4 (bsc#1012628).
- crash: use macro to add crashk_res into iomem early for specific
  arch (bsc#1012628).
- drm/amd/display: fix IPX enablement (bsc#1012628).
- x86/bugs: Use fixed addressing for VERW operand (bsc#1012628).
- Revert "x86/bugs: Use fixed addressing for VERW operand"
  (bsc#1012628).
- usb: dwc3: pci: Drop duplicate ID (bsc#1012628).
- scsi: lpfc: Correct size for cmdwqe/rspwqe for memset()
  (bsc#1012628).
- scsi: lpfc: Correct size for wqe for memset() (bsc#1012628).
- scsi: libsas: Add a helper sas_get_sas_addr_and_dev_type()
  (bsc#1012628).
- scsi: libsas: Fix disk not being scanned in after being removed
  (bsc#1012628).
- perf/x86/amd/core: Update and fix stalled-cycles-* events for
  Zen 2 and later (bsc#1012628).
- x86/sev: Skip ROM range scans and validation for SEV-SNP guests
  (bsc#1012628).
- tools/resolve_btfids: fix build with musl libc (bsc#1012628).
- drm/amdgpu: fix use-after-free bug (bsc#1012628).
- drm/sched: fix null-ptr-deref in init entity (bsc#1012628).
- Update config files.
- Refresh
  patches.suse/0001-security-lockdown-expose-a-hook-to-lock-the-kernel-down.patch.
- Refresh
  patches.suse/0003-efi-Lock-down-the-kernel-if-booted-in-secure-boot-mode.patch.
- Rename to
  patches.kernel.org/6.8.3-002-wifi-brcmfmac-Fix-use-after-free-bug-in-brcmf_c.patch.
- Rename to
  patches.kernel.org/6.8.3-063-md-raid5-fix-atomicity-violation-in-raid5_cache.patch.
- Rename to
  patches.kernel.org/6.8.3-338-Bluetooth-hci_sync-Fix-not-checking-error-on-hc.patch.
- commit b5e6a9b
* Wed Apr  3 2024 jslaby@suse.cz
- Reapply "io_uring: remove unconditional looping in local
  This reverts commit 5b857cbdea3a310ec703341b4586e4f4f7748b04, liburing
  was fixed.
- commit 27b1222
* Tue Apr  2 2024 jslaby@suse.cz
- Bluetooth: hci_sync: Fix not checking error on
  hci_cmd_sync_cancel_sync (bluetooth-fix).
- commit 2eb0f0f
* Tue Apr  2 2024 jslaby@suse.cz
- Revert "io_uring: remove unconditional looping in local
  task_work handling" (liburing_failure).
- commit 5b857cb
* Mon Apr  1 2024 mkubecek@suse.cz
- update to 6.9-rc2
- refresh
  - patches.suse/0003-efi-Lock-down-the-kernel-if-booted-in-secure-boot-mode.patch
- update configs
- commit 0788112
* Thu Mar 28 2024 msuchanek@suse.de
- powerpc/crypto/chacha-p10: Fix failure on non Power10
  (boo#1218114).
- commit 47aaf44
* Thu Mar 28 2024 jslaby@suse.cz
- Linux 6.8.2 (bsc#1012628).
- do_sys_name_to_handle(): use kzalloc() to fix kernel-infoleak
  (bsc#1012628).
- workqueue.c: Increase workqueue name length (bsc#1012628).
- workqueue: Move pwq->max_active to wq->max_active (bsc#1012628).
- workqueue: Factor out pwq_is_empty() (bsc#1012628).
- workqueue: Replace pwq_activate_inactive_work() with
  [__]pwq_activate_work() (bsc#1012628).
- workqueue: Move nr_active handling into helpers (bsc#1012628).
- workqueue: Make wq_adjust_max_active() round-robin pwqs while
  activating (bsc#1012628).
- workqueue: RCU protect wq->dfl_pwq and implement accessors
  for it (bsc#1012628).
- workqueue: Introduce struct wq_node_nr_active (bsc#1012628).
- workqueue: Implement system-wide nr_active enforcement for
  unbound workqueues (bsc#1012628).
- workqueue: Don't call cpumask_test_cpu() with -1 CPU in
  wq_update_node_max_active() (bsc#1012628).
- iomap: clear the per-folio dirty bits on all writeback failures
  (bsc#1012628).
- fs: Fix rw_hint validation (bsc#1012628).
- io_uring: remove looping around handling traditional task_work
  (bsc#1012628).
- io_uring: remove unconditional looping in local task_work
  handling (bsc#1012628).
- s390/dasd: Use dev_*() for device log messages (bsc#1012628).
- s390/dasd: fix double module refcount decrement (bsc#1012628).
- fs/hfsplus: use better @opf description (bsc#1012628).
- md: fix kmemleak of rdev->serial (bsc#1012628).
- rcu/exp: Fix RCU expedited parallel grace period kworker
  allocation failure recovery (bsc#1012628).
- rcu/exp: Handle RCU expedited grace period kworker allocation
  failure (bsc#1012628).
- nbd: null check for nla_nest_start (bsc#1012628).
- fs/select: rework stack allocation hack for clang (bsc#1012628).
- block: fix deadlock between bd_link_disk_holder and partition
  scan (bsc#1012628).
- md: Don't clear MD_CLOSING when the raid is about to stop
  (bsc#1012628).
- kunit: Setup DMA masks on the kunit device (bsc#1012628).
- ovl: Always reject mounting over case-insensitive directories
  (bsc#1012628).
- kunit: test: Log the correct filter string in executor_test
  (bsc#1012628).
- lib/cmdline: Fix an invalid format specifier in an assertion
  msg (bsc#1012628).
- lib: memcpy_kunit: Fix an invalid format specifier in an
  assertion msg (bsc#1012628).
- time: test: Fix incorrect format specifier (bsc#1012628).
- rtc: test: Fix invalid format specifier (bsc#1012628).
- net: test: Fix printf format specifier in skb_segment kunit test
  (bsc#1012628).
- drm/xe/tests: Fix printf format specifiers in xe_migrate test
  (bsc#1012628).
- drm: tests: Fix invalid printf format specifiers in KUnit tests
  (bsc#1012628).
- md/raid1: factor out helpers to add rdev to conf (bsc#1012628).
- md/raid1: record nonrot rdevs while adding/removing rdevs to
  conf (bsc#1012628).
- md/raid1: fix choose next idle in read_balance() (bsc#1012628).
- io_uring/net: unify how recvmsg and sendmsg copy in the msghdr
  (bsc#1012628).
- io_uring/net: move receive multishot out of the generic msghdr
  path (bsc#1012628).
- io_uring/net: fix overflow check in io_recvmsg_mshot_prep()
  (bsc#1012628).
- nvme: host: fix double-free of struct nvme_id_ns in
  ns_update_nuse() (bsc#1012628).
- x86/mm: Ensure input to pfn_to_kaddr() is treated as a 64-bit
  type (bsc#1012628).
- x86/resctrl: Remove hard-coded memory bandwidth limit
  (bsc#1012628).
- x86/resctrl: Read supported bandwidth sources from CPUID
  (bsc#1012628).
- x86/resctrl: Implement new mba_MBps throttling heuristic
  (bsc#1012628).
- x86/sme: Fix memory encryption setting if enabled by default
  and not overridden (bsc#1012628).
- timekeeping: Fix cross-timestamp interpolation on counter wrap
  (bsc#1012628).
- timekeeping: Fix cross-timestamp interpolation corner case
  decision (bsc#1012628).
- timekeeping: Fix cross-timestamp interpolation for non-x86
  (bsc#1012628).
- x86/asm: Remove the __iomem annotation of movdir64b()'s dst
  argument (bsc#1012628).
- sched/fair: Take the scheduling domain into account in
  select_idle_smt() (bsc#1012628).
- sched/fair: Take the scheduling domain into account in
  select_idle_core() (bsc#1012628).
- wifi: b43: Stop/wake correct queue in DMA Tx path when QoS is
  disabled (bsc#1012628).
- wifi: b43: Stop/wake correct queue in PIO Tx path when QoS is
  disabled (bsc#1012628).
- wifi: b43: Stop correct queue in DMA worker when QoS is disabled
  (bsc#1012628).
- wifi: b43: Disable QoS for bcm4331 (bsc#1012628).
- wifi: wilc1000: fix declarations ordering (bsc#1012628).
- wifi: wilc1000: fix RCU usage in connect path (bsc#1012628).
- wifi: ath11k: add support to select 6 GHz regulatory type
  (bsc#1012628).
- wifi: ath11k: store cur_regulatory_info for each radio
  (bsc#1012628).
- wifi: ath11k: fix a possible dead lock caused by ab->base_lock
  (bsc#1012628).
- wifi: rtl8xxxu: add cancel_work_sync() for c2hcmd_work
  (bsc#1012628).
- wifi: wilc1000: do not realloc workqueue everytime an interface
  is added (bsc#1012628).
- wifi: wilc1000: fix multi-vif management when deleting a vif
  (bsc#1012628).
- wifi: mwifiex: debugfs: Drop unnecessary error check for
  debugfs_create_dir() (bsc#1012628).
- ARM: dts: renesas: r8a73a4: Fix external clocks and clock rate
  (bsc#1012628).
- arm64: dts: qcom: x1e80100: drop qcom,drv-count (bsc#1012628).
- arm64: dts: qcom: sc8180x: Hook up VDD_CX as GCC parent domain
  (bsc#1012628).
- arm64: dts: qcom: sc8180x: Fix up big CPU idle state entry
  latency (bsc#1012628).
- arm64: dts: qcom: sc8180x: Add missing CPU off state
  (bsc#1012628).
- arm64: dts: qcom: sc8180x: Fix eDP PHY power-domains
  (bsc#1012628).
- arm64: dts: qcom: sc8180x: Don't hold MDP core clock at FMAX
  (bsc#1012628).
- arm64: dts: qcom: sc8180x: Require LOW_SVS vote for MMCX if
  DISPCC is on (bsc#1012628).
- arm64: dts: qcom: sc8180x: Add missing CPU<->MDP_CFG path
  (bsc#1012628).
- arm64: dts: qcom: sc8180x: Shrink aoss_qmp register space size
  (bsc#1012628).
- cpufreq: brcmstb-avs-cpufreq: add check for cpufreq_cpu_get's
  return value (bsc#1012628).
- cpufreq: mediatek-hw: Wait for CPU supplies before probing
  (bsc#1012628).
- sock_diag: annotate data-races around sock_diag_handlers[family]
  (bsc#1012628).
- inet_diag: annotate data-races around inet_diag_table[]
  (bsc#1012628).
- bpftool: Silence build warning about calloc() (bsc#1012628).
- selftests/bpf: Fix potential premature unload in bpf_testmod
  (bsc#1012628).
- libbpf: Apply map_set_def_max_entries() for inner_maps on
  creation (bsc#1012628).
- selftest/bpf: Add map_in_maps with BPF_MAP_TYPE_PERF_EVENT_ARRAY
  values (bsc#1012628).
- bpftool: Fix wrong free call in do_show_link (bsc#1012628).
- wifi: ath12k: Fix issues in channel list update (bsc#1012628).
- selftests/bpf: Fix the flaky tc_redirect_dtime test
  (bsc#1012628).
- selftests/bpf: Wait for the netstamp_needed_key static key to
  be turned on (bsc#1012628).
- wifi: cfg80211: add RNR with reporting AP information
  (bsc#1012628).
- wifi: mac80211: use deflink and fix typo in link ID check
  (bsc#1012628).
- wifi: iwlwifi: change link id in time event to s8 (bsc#1012628).
- af_unix: Annotate data-race of gc_in_progress in
  wait_for_unix_gc() (bsc#1012628).
- arm64: dts: qcom: sm8450: Add missing interconnects to serial
  (bsc#1012628).
- soc: qcom: socinfo: rename PM2250 to PM4125 (bsc#1012628).
- arm64: dts: qcom: sc7280: Add static properties to cryptobam
  (bsc#1012628).
- arm64: dts: qcom: qcm6490-fairphone-fp5: Add missing
  reserved-memory (bsc#1012628).
- arm64: dts: qcom: sdm845-oneplus-common: improve DAI node naming
  (bsc#1012628).
- arm64: dts: qcom: rename PM2250 to PM4125 (bsc#1012628).
- cpufreq: mediatek-hw: Don't error out if supply is not found
  (bsc#1012628).
- libbpf: Fix faccessat() usage on Android (bsc#1012628).
- libbpf: fix __arg_ctx type enforcement for perf_event programs
  (bsc#1012628).
- pmdomain: qcom: rpmhpd: Drop SA8540P gfx.lvl (bsc#1012628).
- arm64: dts: qcom: sa8540p: Drop gfx.lvl as power-domain for
  gpucc (bsc#1012628).
- arm64: dts: renesas: r8a779g0: Restore sort order (bsc#1012628).
- arm64: dts: renesas: r8a779g0: Add missing SCIF_CLK2
  (bsc#1012628).
- selftests/bpf: Disable IPv6 for lwt_redirect test (bsc#1012628).
- arm64: dts: imx8mm-kontron: Disable pullups for I2C signals
  on OSM-S i.MX8MM (bsc#1012628).
- arm64: dts: imx8mm-kontron: Disable pullups for I2C signals
  on SL/BL i.MX8MM (bsc#1012628).
- arm64: dts: imx8mm-kontron: Disable pullups for onboard UART
  signals on BL OSM-S board (bsc#1012628).
- arm64: dts: imx8mm-kontron: Disable pullups for onboard UART
  signals on BL board (bsc#1012628).
- arm64: dts: imx8mm-kontron: Disable pull resistors for SD card
  signals on BL OSM-S board (bsc#1012628).
- arm64: dts: imx8mm-kontron: Disable pull resistors for SD card
  signals on BL board (bsc#1012628).
- arm64: dts: imx8mm-kontron: Fix interrupt for RTC on OSM-S
  i.MX8MM module (bsc#1012628).
- arm64: dts: imx8qm: Align edma3 power-domains resources
  indentation (bsc#1012628).
- arm64: dts: imx8qm: Correct edma3 power-domains and interrupt
  numbers (bsc#1012628).
- libbpf: Add missing LIBBPF_API annotation to
  libbpf_set_memlock_rlim API (bsc#1012628).
- wifi: ath9k: delay all of ath9k_wmi_event_tasklet() until init
  is complete (bsc#1012628).
- wifi: ath11k: change to move WMI_VDEV_PARAM_SET_HEMU_MODE
  before WMI_PEER_ASSOC_CMDID (bsc#1012628).
- wifi: ath12k: fix fetching MCBC flag for QCN9274 (bsc#1012628).
- wifi: iwlwifi: mvm: report beacon protection failures
  (bsc#1012628).
- wifi: iwlwifi: dbg-tlv: ensure NUL termination (bsc#1012628).
- wifi: iwlwifi: acpi: fix WPFC reading (bsc#1012628).
- wifi: iwlwifi: mvm: initialize rates in FW earlier
  (bsc#1012628).
- wifi: iwlwifi: fix EWRD table validity check (bsc#1012628).
- wifi: iwlwifi: mvm: d3: fix IPN byte order (bsc#1012628).
- wifi: iwlwifi: always have 'uats_enabled' (bsc#1012628).
- wifi: iwlwifi: mvm: fix the TLC command after ADD_STA
  (bsc#1012628).
- wifi: iwlwifi: read BIOS PNVM only for non-Intel SKU
  (bsc#1012628).
- gpio: vf610: allow disabling the vf610 driver (bsc#1012628).
- selftests/bpf: trace_helpers.c: do not use poisoned type
  (bsc#1012628).
- bpf: make sure scalar args don't accept __arg_nonnull tag
  (bsc#1012628).
- bpf: don't emit warnings intended for global subprogs for
  static subprogs (bsc#1012628).
- arm64: dts: imx8mm-venice-gw71xx: fix USB OTG VBUS
  (bsc#1012628).
- pwm: atmel-hlcdc: Fix clock imbalance related to suspend support
  (bsc#1012628).
- net: blackhole_dev: fix build warning for ethh set but not used
  (bsc#1012628).
- spi: consolidate setting message->spi (bsc#1012628).
- spi: move split xfers for CS_WORD emulation (bsc#1012628).
- arm64: dts: ti: k3-am62p5-sk: Enable CPSW MDIO node
  (bsc#1012628).
- arm64: dts: ti: k3-j721s2: Fix power domain for VTM node
  (bsc#1012628).
- arm64: dts: ti: k3-j784s4: Fix power domain for VTM node
  (bsc#1012628).
- wifi: ath11k: initialize rx_mcs_80 and rx_mcs_160 before use
  (bsc#1012628).
- wifi: libertas: fix some memleaks in lbs_allocate_cmd_buffer()
  (bsc#1012628).
- arm64: dts: ti: k3-am69-sk: remove assigned-clock-parents for
  unused VP (bsc#1012628).
- libbpf: fix return value for PERF_EVENT __arg_ctx type fix up
  check (bsc#1012628).
- arm64: dts: ti: k3-am62p-mcu/wakeup: Disable MCU and wakeup
  R5FSS nodes (bsc#1012628).
- arm64: dts: qcom: x1e80100-qcp: Fix supplies for LDOs 3E and 2J
  (bsc#1012628).
- libbpf: Use OPTS_SET() macro in bpf_xdp_query() (bsc#1012628).
- wifi: wfx: fix memory leak when starting AP (bsc#1012628).
- arm64: dts: qcom: qcm2290: declare VLS CLAMP register for USB3
  PHY (bsc#1012628).
- arm64: dts: qcom: sm6115: declare VLS CLAMP register for USB3
  PHY (bsc#1012628).
- arm64: dts: qcom: sm8650: Fix UFS PHY clocks (bsc#1012628).
- wifi: ath12k: fix incorrect logic of calculating vdev_stats_id
  (bsc#1012628).
- printk: nbcon: Relocate 32bit seq macros (bsc#1012628).
- printk: ringbuffer: Do not skip non-finalized records with
  prb_next_seq() (bsc#1012628).
- printk: Wait for all reserved records with pr_flush()
  (bsc#1012628).
- printk: Add this_cpu_in_panic() (bsc#1012628).
- printk: ringbuffer: Cleanup reader terminology (bsc#1012628).
- printk: ringbuffer: Skip non-finalized records in panic
  (bsc#1012628).
- printk: Disable passing console lock owner completely during
  panic() (bsc#1012628).
- pwm: sti: Fix capture for st,pwm-num-chan < st,capture-num-chan
  (bsc#1012628).
- tools/resolve_btfids: Refactor set sorting with types from
  btf_ids.h (bsc#1012628).
- tools/resolve_btfids: Fix cross-compilation to non-host
  endianness (bsc#1012628).
- wifi: iwlwifi: support EHT for WH (bsc#1012628).
- wifi: iwlwifi: properly check if link is active (bsc#1012628).
- wifi: iwlwifi: mvm: fix erroneous queue index mask
  (bsc#1012628).
- wifi: iwlwifi: mvm: don't set the MFP flag for the GTK
  (bsc#1012628).
- wifi: iwlwifi: mvm: don't set replay counters to 0xff
  (bsc#1012628).
- s390/pai: fix attr_event_free upper limit for pai device drivers
  (bsc#1012628).
- s390/vdso: drop '-fPIC' from LDFLAGS (bsc#1012628).
- arm64: dts: qcom: qcm6490-idp: Correct the voltage setting
  for vph_pwr (bsc#1012628).
- arm64: dts: qcom: qcs6490-rb3gen2: Correct the voltage setting
  for vph_pwr (bsc#1012628).
- selftests: forwarding: Add missing config entries (bsc#1012628).
- selftests: forwarding: Add missing multicast routing config
  entries (bsc#1012628).
- arm64: dts: qcom: sm6115: drop pipe clock selection
  (bsc#1012628).
- ipv6: mcast: remove one synchronize_net() barrier in
  ipv6_mc_down() (bsc#1012628).
- arm64: dts: mt8183: Move CrosEC base detection node to
  kukui-based DTs (bsc#1012628).
- arm64: dts: mediatek: mt7986: fix reference to PWM in fan node
  (bsc#1012628).
- arm64: dts: mediatek: mt7986: drop crypto's unneeded/invalid
  clock name (bsc#1012628).
- arm64: dts: mediatek: mt7986: fix SPI bus width properties
  (bsc#1012628).
- arm64: dts: mediatek: mt7986: fix SPI nodename (bsc#1012628).
- arm64: dts: mediatek: mt7986: drop "#clock-cells" from PWM
  (bsc#1012628).
- arm64: dts: mediatek: mt7986: add "#reset-cells" to infracfg
  (bsc#1012628).
- arm64: dts: mediatek: mt8192-asurada: Remove CrosEC base
  detection node (bsc#1012628).
- arm64: dts: mediatek: mt8192: fix vencoder clock name
  (bsc#1012628).
- arm64: dts: mediatek: mt8186: fix VENC power domain clocks
  (bsc#1012628).
- arm64: dts: mediatek: mt7622: add missing "device_type" to
  memory nodes (bsc#1012628).
- can: m_can: Start/Cancel polling timer together with interrupts
  (bsc#1012628).
- wifi: iwlwifi: mvm: Fix the listener MAC filter flags
  (bsc#1012628).
- bpf: Mark bpf_spin_{lock,unlock}() helpers with notrace
  correctly (bsc#1012628).
- arm64: dts: qcom: sdm845: Use the Low Power Island CX/MX for
  SLPI (bsc#1012628).
- soc: qcom: llcc: Check return value on Broadcast_OR reg read
  (bsc#1012628).
- ARM: dts: qcom: msm8974: correct qfprom node size (bsc#1012628).
- arm64: dts: mediatek: mt8186: Add missing clocks to ssusb
  power domains (bsc#1012628).
- arm64: dts: mediatek: mt8186: Add missing xhci clock to usb
  controllers (bsc#1012628).
- arm64: dts: ti: am65x: Fix dtbs_install for Rocktech OLDI
  overlay (bsc#1012628).
- cpufreq: qcom-hw: add CONFIG_COMMON_CLK dependency
  (bsc#1012628).
- wifi: wilc1000: prevent use-after-free on vif when cleaning
  up all interfaces (bsc#1012628).
- pwm: dwc: use pm_sleep_ptr() macro (bsc#1012628).
- arm64: dts: ti: k3-am69-sk: fix PMIC interrupt number
  (bsc#1012628).
- arm64: dts: ti: k3-j721e-sk: fix PMIC interrupt number
  (bsc#1012628).
- arm64: dts: ti: k3-am62-main: disable usb lpm (bsc#1012628).
- ACPI: processor_idle: Fix memory leak in
  acpi_processor_power_exit() (bsc#1012628).
- bus: tegra-aconnect: Update dependency to ARCH_TEGRA
  (bsc#1012628).
- iommu/amd: Mark interrupt as managed (bsc#1012628).
- wifi: brcmsmac: avoid function pointer casts (bsc#1012628).
- arm64: dts: qcom: sdm845-db845c: correct PCIe wake-gpios
  (bsc#1012628).
- arm64: dts: qcom: sm8150: correct PCIe wake-gpios (bsc#1012628).
- powercap: dtpm_cpu: Fix error check against
  freq_qos_add_request() (bsc#1012628).
- net: ena: Remove ena_select_queue (bsc#1012628).
- arm64: dts: ti: k3-j7200-common-proc-board: Modify Pinmux for
  wkup_uart0 and mcu_uart0 (bsc#1012628).
- arm64: dts: ti: k3-j7200-common-proc-board: Remove
  clock-frequency from mcu_uart0 (bsc#1012628).
- arm64: dts: ti: k3-j721s2-common-proc-board: Remove Pinmux
  for CTS and RTS in wkup_uart0 (bsc#1012628).
- arm64: dts: ti: k3-j784s4-evm: Remove Pinmux for CTS and RTS
  in wkup_uart0 (bsc#1012628).
- arm64: dts: ti: k3-am64-main: Fix ITAP/OTAP values for MMC
  (bsc#1012628).
- arm64: dts: mt8195-cherry-tomato: change watchdog reset boot
  flow (bsc#1012628).
- arm64: dts: ti: Add common1 register space for AM65x SoC
  (bsc#1012628).
- arm64: dts: ti: Add common1 register space for AM62x SoC
  (bsc#1012628).
- firmware: arm_scmi: Fix double free in SMC transport cleanup
  path (bsc#1012628).
- wifi: cfg80211: set correct param change count in ML element
  (bsc#1012628).
- arm64: dts: ti: k3-j721e: Fix mux-reg-masks in hbmc_mux
  (bsc#1012628).
- arm64: dts: ti: k3-j784s4-main: Fix mux-reg-masks in
  serdes_ln_ctrl (bsc#1012628).
- arm64: dts: ti: k3-am62p: Fix memory ranges for DMSS
  (bsc#1012628).
- wifi: wilc1000: revert reset line logic flip (bsc#1012628).
- ARM: dts: arm: realview: Fix development chip ROM compatible
  value (bsc#1012628).
- memory: tegra: Correct DLA client names (bsc#1012628).
- wifi: mt76: mt7996: fix fw loading timeout (bsc#1012628).
- wifi: mt76: mt7925: fix connect to 80211b mode fail in 2Ghz band
  (bsc#1012628).
- wifi: mt76: mt7925: fix SAP no beacon issue in 5Ghz and 6Ghz
  band (bsc#1012628).
- wifi: mt76: mt7925: fix mcu query command fail (bsc#1012628).
- wifi: mt76: mt7925: fix wmm queue mapping (bsc#1012628).
- wifi: mt76: mt7925: fix fw download fail (bsc#1012628).
- wifi: mt76: mt7925: fix WoW failed in encrypted mode
  (bsc#1012628).
- wifi: mt76: mt7925: fix the wrong header translation config
  (bsc#1012628).
- wifi: mt76: mt7925: add flow to avoid chip bt function fail
  (bsc#1012628).
- wifi: mt76: mt7925: add support to set ifs time by mcu command
  (bsc#1012628).
- wifi: mt76: mt7925: update PCIe DMA settings (bsc#1012628).
- wifi: mt76: mt7996: check txs format before getting skb by pid
  (bsc#1012628).
- wifi: mt76: mt7996: fix TWT issues (bsc#1012628).
- wifi: mt76: mt7996: fix incorrect interpretation of EHT MCS caps
  (bsc#1012628).
- wifi: mt76: mt7996: fix HE beamformer phy cap for station vif
  (bsc#1012628).
- wifi: mt76: mt7996: fix efuse reading issue (bsc#1012628).
- wifi: mt76: mt7996: fix HIF_TXD_V2_1 value (bsc#1012628).
- wifi: mt76: mt792x: fix ethtool warning (bsc#1012628).
- wifi: mt76: mt7921e: fix use-after-free in free_irq()
  (bsc#1012628).
- wifi: mt76: mt7925e: fix use-after-free in free_irq()
  (bsc#1012628).
- wifi: mt76: mt7921: fix incorrect type conversion for CLC
  command (bsc#1012628).
- wifi: mt76: mt792x: fix a potential loading failure of the
  6Ghz channel config from ACPI (bsc#1012628).
- wifi: mt76: fix the issue of missing txpwr settings from ch153
  to ch177 (bsc#1012628).
- arm64: dts: renesas: rzg2l: Add missing interrupts to IRQC nodes
  (bsc#1012628).
- arm64: dts: renesas: r9a08g045: Add missing interrupts to IRQC
  node (bsc#1012628).
- arm64: dts: renesas: rzg3s-smarc-som: Guard Ethernet IRQ GPIO
  hogs (bsc#1012628).
- arm64: dts: renesas: r8a779a0: Correct avb[01] reg sizes
  (bsc#1012628).
- arm64: dts: renesas: r8a779g0: Correct avb[01] reg sizes
  (bsc#1012628).
- net: mctp: copy skb ext data when fragmenting (bsc#1012628).
- pstore: inode: Only d_invalidate() is needed (bsc#1012628).
- arm64: dts: allwinner: h6: Add RX DMA channel for SPDIF
  (bsc#1012628).
- ARM: dts: imx6dl-yapp4: Fix typo in the QCA switch register
  address (bsc#1012628).
- ARM: dts: imx6dl-yapp4: Move the internal switch PHYs under
  the switch node (bsc#1012628).
- arm64: dts: imx8mp: Set SPI NOR to max 40 MHz on Data Modul
  i.MX8M Plus eDM SBC (bsc#1012628).
- arm64: dts: imx8mp-evk: Fix hdmi@3d node (bsc#1012628).
- regulator: userspace-consumer: add module device table
  (bsc#1012628).
- gpiolib: Pass consumer device through to core in
  devm_fwnode_gpiod_get_index() (bsc#1012628).
- arm64: dts: marvell: reorder crypto interrupts on Armada SoCs
  (bsc#1012628).
- ACPI: resource: Do IRQ override on Lunnen Ground laptops
  (bsc#1012628).
- ACPI: resource: Add MAIBENBEN X577 to
  irq1_edge_low_force_override (bsc#1012628).
- ACPI: scan: Fix device check notification handling
  (bsc#1012628).
- arm64: dts: rockchip: add missing interrupt-names for rk356x
  vdpu (bsc#1012628).
- arm64: dts: rockchip: fix reset-names for rk356x i2s2 controller
  (bsc#1012628).
- arm64: dts: rockchip: drop rockchip,trcm-sync-tx-only from
  rk3588 i2s (bsc#1012628).
- objtool: Fix UNWIND_HINT_{SAVE,RESTORE} across basic blocks
  (bsc#1012628).
- x86, relocs: Ignore relocations in .notes section (bsc#1012628).
- SUNRPC: fix a memleak in gss_import_v2_context (bsc#1012628).
- SUNRPC: fix some memleaks in gssx_dec_option_array
  (bsc#1012628).
- arm64: dts: qcom: sm8550: Fix SPMI channels size (bsc#1012628).
- arm64: dts: qcom: sm8650: Fix SPMI channels size (bsc#1012628).
- mmc: wmt-sdmmc: remove an incorrect release_mem_region()
  call in the .remove function (bsc#1012628).
- ACPI: CPPC: enable AMD CPPC V2 support for family 17h processors
  (bsc#1012628).
- wifi: rtw88: 8821cu: Fix firmware upload fail (bsc#1012628).
- wifi: rtw88: 8821c: Fix beacon loss and disconnect
  (bsc#1012628).
- wifi: rtw88: 8821c: Fix false alarm count (bsc#1012628).
- wifi: brcm80211: handle pmk_op allocation failure (bsc#1012628).
- riscv: dts: starfive: jh7100: fix root clock names
  (bsc#1012628).
- PCI: Make pci_dev_is_disconnected() helper public for other
  drivers (bsc#1012628).
- iommu/vt-d: Don't issue ATS Invalidation request when device
  is disconnected (bsc#1012628).
- iommu/vt-d: Use rbtree to track iommu probed devices
  (bsc#1012628).
- iommu/vt-d: Improve ITE fault handling if target device isn't
  present (bsc#1012628).
- iommu/vt-d: Use device rbtree in iopf reporting path
  (bsc#1012628).
- iommu: Add static iommu_ops->release_domain (bsc#1012628).
- iommu/vt-d: Fix NULL domain on device release (bsc#1012628).
- igc: Fix missing time sync events (bsc#1012628).
- igb: Fix missing time sync events (bsc#1012628).
- ice: fix stats being updated by way too large values
  (bsc#1012628).
- Bluetooth: Remove HCI_POWER_OFF_TIMEOUT (bsc#1012628).
- Bluetooth: mgmt: Remove leftover queuing of power_off work
  (bsc#1012628).
- Bluetooth: Remove superfluous call to hci_conn_check_pending()
  (bsc#1012628).
- Bluetooth: Remove BT_HS (bsc#1012628).
- Bluetooth: hci_event: Fix not indicating new connection for
  BIG Sync (bsc#1012628).
- Bluetooth: hci_qca: don't use IS_ERR_OR_NULL() with
  gpiod_get_optional() (bsc#1012628).
- Bluetooth: hci_core: Cancel request on command timeout
  (bsc#1012628).
- Bluetooth: hci_sync: Fix overwriting request callback
  (bsc#1012628).
- Bluetooth: hci_h5: Add ability to allocate memory for private
  data (bsc#1012628).
- Bluetooth: btrtl: fix out of bounds memory access (bsc#1012628).
- Bluetooth: hci_core: Fix possible buffer overflow (bsc#1012628).
- Bluetooth: msft: Fix memory leak (bsc#1012628).
- Bluetooth: btusb: Fix memory leak (bsc#1012628).
- Bluetooth: af_bluetooth: Fix deadlock (bsc#1012628).
- Bluetooth: fix use-after-free in accessing skb after sending it
  (bsc#1012628).
- sr9800: Add check for usbnet_get_endpoints (bsc#1012628).
- s390/cache: prevent rebuild of shared_cpu_list (bsc#1012628).
- bpf: Fix DEVMAP_HASH overflow check on 32-bit arches
  (bsc#1012628).
- bpf: Fix hashtab overflow check on 32-bit arches (bsc#1012628).
- bpf: Fix stackmap overflow check on 32-bit arches (bsc#1012628).
- net: dsa: microchip: make sure drive strength configuration
  is not lost by soft reset (bsc#1012628).
- dpll: spec: use proper enum for pin capabilities attribute
  (bsc#1012628).
- iommu: Fix compilation without CONFIG_IOMMU_INTEL (bsc#1012628).
- ipv6: fib6_rules: flush route cache when rule is changed
  (bsc#1012628).
- net: ip_tunnel: make sure to pull inner header in
  ip_tunnel_rcv() (bsc#1012628).
- octeontx2-af: Fix devlink params (bsc#1012628).
- net: phy: fix phy_get_internal_delay accessing an empty array
  (bsc#1012628).
- dpll: fix dpll_xa_ref_*_del() for multiple registrations
  (bsc#1012628).
- net: hns3: fix wrong judgment condition issue (bsc#1012628).
- net: hns3: fix kernel crash when 1588 is received on HIP08
  devices (bsc#1012628).
- net: hns3: fix port duplex configure error in IMP reset
  (bsc#1012628).
- Bluetooth: Fix eir name length (bsc#1012628).
- net: phy: dp83822: Fix RGMII TX delay configuration
  (bsc#1012628).
- erofs: fix lockdep false positives on initializing
  erofs_pseudo_mnt (bsc#1012628).
- OPP: debugfs: Fix warning around icc_get_name() (bsc#1012628).
- tcp: fix incorrect parameter validation in the
  do_tcp_getsockopt() function (bsc#1012628).
- ipmr: fix incorrect parameter validation in the
  ip_mroute_getsockopt() function (bsc#1012628).
- l2tp: fix incorrect parameter validation in the
  pppol2tp_getsockopt() function (bsc#1012628).
- udp: fix incorrect parameter validation in the
  udp_lib_getsockopt() function (bsc#1012628).
- net: kcm: fix incorrect parameter validation in the
  kcm_getsockopt) function (bsc#1012628).
- net/x25: fix incorrect parameter validation in the
  x25_getsockopt() function (bsc#1012628).
- devlink: Fix length of eswitch inline-mode (bsc#1012628).
- r8152: fix unknown device for choose_configuration
  (bsc#1012628).
- nfp: flower: handle acti_netdevs allocation failure
  (bsc#1012628).
- bpf: hardcode BPF_PROG_PACK_SIZE to 2MB * num_possible_nodes()
  (bsc#1012628).
- dm raid: fix false positive for requeue needed during reshape
  (bsc#1012628).
- dm: call the resume method on internal suspend (bsc#1012628).
- fbdev/simplefb: change loglevel when the power domains cannot
  be parsed (bsc#1012628).
- drm/tegra: dsi: Add missing check for of_find_device_by_node
  (bsc#1012628).
- drm/tegra: dpaux: Fix PM disable depth imbalance in
  tegra_dpaux_probe (bsc#1012628).
- drm/tegra: dsi: Fix some error handling paths in
  tegra_dsi_probe() (bsc#1012628).
- drm/tegra: dsi: Fix missing pm_runtime_disable() in the error
  handling path of tegra_dsi_probe() (bsc#1012628).
- drm/tegra: hdmi: Fix some error handling paths in
  tegra_hdmi_probe() (bsc#1012628).
- drm/tegra: rgb: Fix some error handling paths in
  tegra_dc_rgb_probe() (bsc#1012628).
- drm/tegra: rgb: Fix missing clk_put() in the error handling
  paths of tegra_dc_rgb_probe() (bsc#1012628).
- drm/tegra: output: Fix missing i2c_put_adapter() in the error
  handling paths of tegra_output_probe() (bsc#1012628).
- drm/rockchip: inno_hdmi: Fix video timing (bsc#1012628).
- drm: Don't treat 0 as -1 in drm_fixp2int_ceil (bsc#1012628).
- drm/vkms: Avoid reading beyond LUT array (bsc#1012628).
- drm/vmwgfx: fix a memleak in vmw_gmrid_man_get_node
  (bsc#1012628).
- drm/rockchip: lvds: do not overwrite error code (bsc#1012628).
- drm/rockchip: lvds: do not print scary message when probing
  defer (bsc#1012628).
- drm/panel-edp: use put_sync in unprepare (bsc#1012628).
- drm/lima: fix a memleak in lima_heap_alloc (bsc#1012628).
- ASoC: amd: acp: Add missing error handling in sof-mach
  (bsc#1012628).
- ASoC: SOF: amd: Fix memory leak in amd_sof_acp_probe()
  (bsc#1012628).
- ASoC: SOF: core: Skip firmware test for custom loaders
  (bsc#1012628).
- ASoC: SOF: amd: Compute file paths on firmware load
  (bsc#1012628).
- soundwire: stream: add missing const to Documentation
  (bsc#1012628).
- dmaengine: tegra210-adma: Update dependency to ARCH_TEGRA
  (bsc#1012628).
- media: tc358743: register v4l2 async device only after
  successful setup (bsc#1012628).
- media: cadence: csi2rx: use match fwnode for media link
  (bsc#1012628).
- PCI/DPC: Print all TLP Prefixes, not just the first
  (bsc#1012628).
- perf record: Fix possible incorrect free in
  record__switch_output() (bsc#1012628).
- perf record: Check conflict between '--timestamp-filename'
  option and pipe mode before recording (bsc#1012628).
- HID: lenovo: Add middleclick_workaround sysfs knob for cptkbd
  (bsc#1012628).
- drm/amd/display: Fix a potential buffer overflow in
  'dp_dsc_clock_en_read()' (bsc#1012628).
- perf pmu: Treat the msr pmu as software (bsc#1012628).
- crypto: qat - avoid memcpy() overflow warning (bsc#1012628).
- ALSA: hda: cs35l41: Set Channel Index correctly when system
  is missing _DSD (bsc#1012628).
- drm/amd/display: Fix potential NULL pointer dereferences in
  'dcn10_set_output_transfer_func()' (bsc#1012628).
- ASoC: sh: rz-ssi: Fix error message print (bsc#1012628).
- drm/vmwgfx: Fix vmw_du_get_cursor_mob fencing of newly-created
  MOBs (bsc#1012628).
- clk: renesas: r8a779g0: Fix PCIe clock name (bsc#1012628).
- pinctrl: renesas: rzg2l: Fix locking in
  rzg2l_dt_subnode_to_map() (bsc#1012628).
- pinctrl: renesas: r8a779g0: Add missing SCIF_CLK2 pin
  group/function (bsc#1012628).
- clk: samsung: exynos850: Propagate SPI IPCLK rate change
  (bsc#1012628).
- media: v4l2: cci: print leading 0 on error (bsc#1012628).
- perf evsel: Fix duplicate initialization of data->id in
  evsel__parse_sample() (bsc#1012628).
- perf bpf: Clean up the generated/copied vmlinux.h (bsc#1012628).
- clk: meson: Add missing clocks to axg_clk_regmaps (bsc#1012628).
- media: em28xx: annotate unchecked call to
  media_device_register() (bsc#1012628).
- media: v4l2-tpg: fix some memleaks in tpg_alloc (bsc#1012628).
- media: v4l2-mem2mem: fix a memleak in v4l2_m2m_register_entity
  (bsc#1012628).
- media: dt-bindings: techwell,tw9900: Fix port schema ref
  (bsc#1012628).
- mtd: spinand: esmt: Extend IDs to 5 bytes (bsc#1012628).
- media: edia: dvbdev: fix a use-after-free (bsc#1012628).
- pinctrl: mediatek: Drop bogus slew rate register range for
  MT8186 (bsc#1012628).
- pinctrl: mediatek: Drop bogus slew rate register range for
  MT8192 (bsc#1012628).
- drm/amdgpu: Fix potential out-of-bounds access in
  'amdgpu_discovery_reg_base_init()' (bsc#1012628).
- clk: qcom: reset: Commonize the de/assert functions
  (bsc#1012628).
- clk: qcom: reset: Ensure write completion on reset de/assertion
  (bsc#1012628).
- quota: Fix potential NULL pointer dereference (bsc#1012628).
- quota: Fix rcu annotations of inode dquot pointers
  (bsc#1012628).
- quota: Properly annotate i_dquot arrays with __rcu
  (bsc#1012628).
- ASoC: Intel: ssp-common: Add stub for sof_ssp_get_codec_name
  (bsc#1012628).
- PCI/P2PDMA: Fix a sleeping issue in a RCU read section
  (bsc#1012628).
- PCI: switchtec: Fix an error handling path in
  switchtec_pci_probe() (bsc#1012628).
- crypto: xilinx - call finalize with bh disabled (bsc#1012628).
- drivers/ps3: select VIDEO to provide cmdline functions
  (bsc#1012628).
- perf thread_map: Free strlist on normal path in
  thread_map__new_by_tid_str() (bsc#1012628).
- perf srcline: Add missed addr2line closes (bsc#1012628).
- dt-bindings: msm: qcom, mdss: Include ommited fam-b compatible
  (bsc#1012628).
- drm/msm/dpu: fix the programming of INTF_CFG2_DATA_HCTL_EN
  (bsc#1012628).
- drm/msm/dpu: Only enable DSC_MODE_MULTIPLEX if dsc_merge is
  enabled (bsc#1012628).
- drm/radeon/ni: Fix wrong firmware size logging in
  ni_init_microcode() (bsc#1012628).
- drm/amd/display: fix NULL checks for adev->dm.dc in
  amdgpu_dm_fini() (bsc#1012628).
- clk: renesas: r8a779g0: Correct PFC/GPIO parent clocks
  (bsc#1012628).
- clk: renesas: r8a779f0: Correct PFC/GPIO parent clock
  (bsc#1012628).
- clk: renesas: r9a07g04[34]: Use SEL_SDHI1_STS status
  configuration for SD1 mux (bsc#1012628).
- ALSA: seq: fix function cast warnings (bsc#1012628).
- perf expr: Fix "has_event" function for metric style events
  (bsc#1012628).
- perf stat: Avoid metric-only segv (bsc#1012628).
- perf metric: Don't remove scale from counts (bsc#1012628).
- ASoC: meson: aiu: fix function pointer type mismatch
  (bsc#1012628).
- ASoC: meson: t9015: fix function pointer type mismatch
  (bsc#1012628).
- powerpc: Force inlining of arch_vmap_p{u/m}d_supported()
  (bsc#1012628).
- ASoC: SOF: Add some bounds checking to firmware data
  (bsc#1012628).
- drm: ci: use clk_ignore_unused for apq8016 (bsc#1012628).
- NTB: fix possible name leak in ntb_register_device()
  (bsc#1012628).
- media: cedrus: h265: Fix configuring bitstream size
  (bsc#1012628).
- media: sun8i-di: Fix coefficient writes (bsc#1012628).
- media: sun8i-di: Fix power on/off sequences (bsc#1012628).
- media: sun8i-di: Fix chroma difference threshold (bsc#1012628).
- staging: media: starfive: Set 16 bpp for capture_raw device
  (bsc#1012628).
- media: imx: csc/scaler: fix v4l2_ctrl_handler memory leak
  (bsc#1012628).
- media: go7007: add check of return value of go7007_read_addr()
  (bsc#1012628).
- media: pvrusb2: remove redundant NULL check (bsc#1012628).
- media: videobuf2: Add missing doc comment for waiting_in_dqbuf
  (bsc#1012628).
- media: pvrusb2: fix pvr2_stream_callback casts (bsc#1012628).
- clk: qcom: dispcc-sdm845: Adjust internal GDSC wait times
  (bsc#1012628).
- drm/amd/display: Add 'replay' NULL check in
  'edp_set_replay_allow_active()' (bsc#1012628).
- drm/panel: boe-tv101wum-nl6: make use of prepare_prev_first
  (bsc#1012628).
- drm/msm/dpu: finalise global state object (bsc#1012628).
- drm/mediatek: dsi: Fix DSI RGB666 formats and definitions
  (bsc#1012628).
- PCI: Mark 3ware-9650SE Root Port Extended Tags as broken
  (bsc#1012628).
- drm/bridge: adv7511: fix crash on irq during probe
  (bsc#1012628).
- pinctrl: renesas: Allow the compiler to optimize away sh_pfc_pm
  (bsc#1012628).
- clk: hisilicon: hi3519: Release the correct number of gates
  in hi3519_clk_unregister() (bsc#1012628).
- clk: hisilicon: hi3559a: Fix an erroneous devm_kfree()
  (bsc#1012628).
- clk: mediatek: mt8135: Fix an error handling path in
  clk_mt8135_apmixed_probe() (bsc#1012628).
- clk: mediatek: mt7622-apmixedsys: Fix an error handling path
  in clk_mt8135_apmixed_probe() (bsc#1012628).
- clk: mediatek: mt8183: Correct parent of CLK_INFRA_SSPM_32K_SELF
  (bsc#1012628).
- clk: mediatek: mt7981-topckgen: flag SGM_REG_SEL as critical
  (bsc#1012628).
- drm/tegra: put drm_gem_object ref on error in tegra_fb_create
  (bsc#1012628).
- tty: mips_ejtag_fdc: Fix passing incompatible pointer type
  warning (bsc#1012628).
- media: ivsc: csi: Swap SINK and SOURCE pads (bsc#1012628).
- media: i2c: imx290: Fix IMX920 typo (bsc#1012628).
- mfd: syscon: Call of_node_put() only when of_parse_phandle()
  takes a ref (bsc#1012628).
- mfd: altera-sysmgr: Call of_node_put() only when
  of_parse_phandle() takes a ref (bsc#1012628).
- perf print-events: make is_event_supported() more robust
  (bsc#1012628).
- crypto: arm/sha - fix function cast warnings (bsc#1012628).
- crypto: ccp - Avoid discarding errors in
  psp_send_platform_access_msg() (bsc#1012628).
- crypto: qat - remove unused macros in qat_comp_alg.c
  (bsc#1012628).
- crypto: qat - removed unused macro in adf_cnv_dbgfs.c
  (bsc#1012628).
- crypto: qat - avoid division by zero (bsc#1012628).
- crypto: qat - remove double initialization of value
  (bsc#1012628).
- crypto: qat - fix ring to service map for dcc in 4xxx
  (bsc#1012628).
- crypto: qat - fix ring to service map for dcc in 420xx
  (bsc#1012628).
- crypto: jitter - fix CRYPTO_JITTERENTROPY help text
  (bsc#1012628).
- drm/tidss: Fix initial plane zpos values (bsc#1012628).
- drm/tidss: Fix sync-lost issue with two displays (bsc#1012628).
- clk: imx: imx8mp: Fix SAI_MCLK_SEL definition (bsc#1012628).
- mtd: maps: physmap-core: fix flash size larger than 32-bit
  (bsc#1012628).
- mtd: rawnand: lpc32xx_mlc: fix irq handler prototype
  (bsc#1012628).
- mtd: rawnand: brcmnand: exec_op helper functions return type
  fixes (bsc#1012628).
- ASoC: meson: axg-tdm-interface: fix mclk setup without mclk-fs
  (bsc#1012628).
- ASoC: meson: axg-tdm-interface: add frame rate constraint
  (bsc#1012628).
- drm/msm/a6xx: specify UBWC config for sc7180 (bsc#1012628).
- drm/msm/a7xx: Fix LLC typo (bsc#1012628).
- dt-bindings: arm-smmu: fix SM8[45]50 GPU SMMU if condition
  (bsc#1012628).
- perf pmu: Fix a potential memory leak in perf_pmu__lookup()
  (bsc#1012628).
- HID: amd_sfh: Update HPD sensor structure elements
  (bsc#1012628).
- HID: amd_sfh: Avoid disabling the interrupt (bsc#1012628).
- drm/amdgpu: Fix missing break in ATOM_ARG_IMM Case of
  atom_get_src_int() (bsc#1012628).
- media: pvrusb2: fix uaf in pvr2_context_set_notify
  (bsc#1012628).
- media: dvb-frontends: avoid stack overflow warnings with clang
  (bsc#1012628).
- media: go7007: fix a memleak in go7007_load_encoder
  (bsc#1012628).
- media: ttpci: fix two memleaks in budget_av_attach
  (bsc#1012628).
- media: mediatek: vcodec: avoid -Wcast-function-type-strict
  warning (bsc#1012628).
- arm64: ftrace: Don't forbid CALL_OPS+CC_OPTIMIZE_FOR_SIZE with
  Clang (bsc#1012628).
- drm/tests: helpers: Include missing drm_drv header
  (bsc#1012628).
- drm/amd/pm: Fix esm reg mask use to get pcie speed
  (bsc#1012628).
- gpio: nomadik: fix offset bug in nmk_pmx_set() (bsc#1012628).
- drm/mediatek: Fix a null pointer crash in
  mtk_drm_crtc_finish_page_flip (bsc#1012628).
- mfd: cs42l43: Fix wrong register defaults (bsc#1012628).
- powerpc/32: fix ADB_CUDA kconfig warning (bsc#1012628).
- powerpc/pseries: Fix potential memleak in papr_get_attr()
  (bsc#1012628).
- powerpc/hv-gpci: Fix the H_GET_PERF_COUNTER_INFO hcall return
  value checks (bsc#1012628).
- clk: qcom: gcc-ipq5018: fix 'enable_reg' offset of
  'gcc_gmac0_sys_clk' (bsc#1012628).
- clk: qcom: gcc-ipq5018: fix 'halt_reg' offset of
  'gcc_pcie1_pipe_clk' (bsc#1012628).
- clk: qcom: gcc-ipq5018: fix register offset for
  GCC_UBI0_AXI_ARES reset (bsc#1012628).
- perf vendor events amd: Fix Zen 4 cache latency events
  (bsc#1012628).
- drm/msm/dpu: allow certain formats for CDM for DP (bsc#1012628).
- drm/msm/dpu: add division of drm_display_mode's hskew parameter
  (bsc#1012628).
- media: usbtv: Remove useless locks in usbtv_video_free()
  (bsc#1012628).
- drm/xe: Fix ref counting leak on page fault (bsc#1012628).
- drm/xe: Replace 'grouped target' in Makefile with pattern rule
  (bsc#1012628).
- lib/stackdepot: fix first entry having a 0-handle (bsc#1012628).
- lib/stackdepot: off by one in depot_fetch_stack() (bsc#1012628).
- modules: wait do_free_init correctly (bsc#1012628).
- mfd: cs42l43: Fix wrong GPIO_FN_SEL and SPI_CLK_CONFIG1 defaults
  (bsc#1012628).
- power: supply: mm8013: fix "not charging" detection
  (bsc#1012628).
- powerpc/embedded6xx: Fix no previous prototype for
  avr_uart_send() etc (bsc#1012628).
- powerpc/4xx: Fix warp_gpio_leds build failure (bsc#1012628).
- RISC-V: KVM: Forward SEED CSR access to user space
  (bsc#1012628).
- leds: aw2013: Unlock mutex before destroying it (bsc#1012628).
- leds: sgm3140: Add missing timer cleanup and flash gpio control
  (bsc#1012628).
- backlight: hx8357: Fix potential NULL pointer dereference
  (bsc#1012628).
- backlight: ktz8866: Correct the check for of_property_read_u32
  (bsc#1012628).
- backlight: lm3630a: Initialize backlight_properties on init
  (bsc#1012628).
- backlight: lm3630a: Don't set bl->props.brightness in
  get_brightness (bsc#1012628).
- backlight: da9052: Fully initialize backlight_properties during
  probe (bsc#1012628).
- backlight: lm3639: Fully initialize backlight_properties during
  probe (bsc#1012628).
- backlight: lp8788: Fully initialize backlight_properties during
  probe (bsc#1012628).
- sparc32: Use generic cmpdi2/ucmpdi2 variants (bsc#1012628).
- mtd: maps: sun_uflash: Declare uflash_devinit static
  (bsc#1012628).
- sparc32: Do not select GENERIC_ISA_DMA (bsc#1012628).
- sparc32: Fix section mismatch in leon_pci_grpci (bsc#1012628).
- clk: Fix clk_core_get NULL dereference (bsc#1012628).
- clk: zynq: Prevent null pointer dereference caused by kmalloc
  failure (bsc#1012628).
- PCI: brcmstb: Fix broken brcm_pcie_mdio_write() polling
  (bsc#1012628).
- cifs: Fix writeback data corruption (bsc#1012628).
- ALSA: hda/realtek: fix ALC285 issues on HP Envy x360 laptops
  (bsc#1012628).
- ALSA: hda/tas2781: use dev_dbg in system_resume (bsc#1012628).
- ALSA: hda/tas2781: add lock to system_suspend (bsc#1012628).
- ALSA: hda/tas2781: do not reset cur_* values in runtime_suspend
  (bsc#1012628).
- ALSA: hda/tas2781: do not call pm_runtime_force_* in
  system_resume/suspend (bsc#1012628).
- ALSA: hda/tas2781: restore power state after system_resume
  (bsc#1012628).
- ALSA: scarlett2: Fix Scarlett 4th Gen 4i4 low-voltage detection
  (bsc#1012628).
- ALSA: scarlett2: Fix Scarlett 4th Gen autogain status values
  (bsc#1012628).
- ALSA: scarlett2: Fix Scarlett 4th Gen input gain range
  (bsc#1012628).
- ALSA: scarlett2: Fix Scarlett 4th Gen input gain range again
  (bsc#1012628).
- mips: cm: Convert __mips_cm_l2sync_phys_base() to weak function
  (bsc#1012628).
- platform/x86/intel/pmc/lnl: Remove SSRAM support (bsc#1012628).
- platform/x86/intel/pmc/arl: Put GNA device in D3 (bsc#1012628).
- platform/x86/amd/pmf: Do not use readl() for policy buffer
  access (bsc#1012628).
- ALSA: usb-audio: Stop parsing channels bits when all channels
  are found (bsc#1012628).
- phy: qcom: qmp-usb: split USB-C PHY driver (bsc#1012628).
- phy: qcom: qmp-usbc: add support for the Type-C handling
  (bsc#1012628).
- phy: qcom: qmp-usbc: handle CLAMP register in a correct way
  (bsc#1012628).
- scsi: hisi_sas: Fix a deadlock issue related to automatic dump
  (bsc#1012628).
- RDMA/irdma: Remove duplicate assignment (bsc#1012628).
- RDMA/srpt: Do not register event handler until srpt device is
  fully setup (bsc#1012628).
- f2fs: compress: fix to guarantee persisting compressed blocks
  by CP (bsc#1012628).
- f2fs: compress: fix to cover normal cluster write with cp_rwsem
  (bsc#1012628).
- f2fs: compress: fix to check unreleased compressed cluster
  (bsc#1012628).
- f2fs: compress: fix to avoid inconsistence bewteen i_blocks
  and dnode (bsc#1012628).
- f2fs: fix to remove unnecessary f2fs_bug_on() to avoid panic
  (bsc#1012628).
- f2fs: zone: fix to wait completion of last bio in zone correctly
  (bsc#1012628).
- f2fs: fix NULL pointer dereference in f2fs_submit_page_write()
  (bsc#1012628).
- f2fs: compress: fix to cover f2fs_disable_compressed_file()
  w/ i_sem (bsc#1012628).
- f2fs: fix to avoid potential panic during recovery
  (bsc#1012628).
- scsi: csiostor: Avoid function pointer casts (bsc#1012628).
- i3c: dw: Disable IBI IRQ depends on hot-join and SIR enabling
  (bsc#1012628).
- RDMA/hns: Fix mis-modifying default congestion control algorithm
  (bsc#1012628).
- RDMA/device: Fix a race between mad_client and cm_client init
  (bsc#1012628).
- RDMA/rtrs-clt: Check strnlen return len in sysfs
  mpath_policy_store() (bsc#1012628).
- scsi: bfa: Fix function pointer type mismatch for hcb_qe->cbfn
  (bsc#1012628).
- f2fs: fix to create selinux label during whiteout initialization
  (bsc#1012628).
- f2fs: compress: fix to check zstd compress level correctly in
  mount option (bsc#1012628).
- net: sunrpc: Fix an off by one in rpc_sockaddr2uaddr()
  (bsc#1012628).
- NFSv4.2: fix nfs4_listxattr kernel BUG at mm/usercopy.c:102
  (bsc#1012628).
- NFSv4.2: fix listxattr maximum XDR buffer size (bsc#1012628).
- f2fs: compress: fix to check compress flag w/ .i_sem lock
  (bsc#1012628).
- f2fs: check number of blocks in a current section (bsc#1012628).
- watchdog: starfive: Check pm_runtime_enabled() before
  decrementing usage counter (bsc#1012628).
- watchdog: stm32_iwdg: initialize default timeout (bsc#1012628).
- f2fs: fix to use correct segment type in
  f2fs_allocate_data_block() (bsc#1012628).
- f2fs: ro: compress: fix to avoid caching unaligned extent
  (bsc#1012628).
- RDMA/mana_ib: Fix bug in creation of dma regions (bsc#1012628).
- RDMA/mana_ib: Introduce mdev_to_gc helper function
  (bsc#1012628).
- RDMA/mana_ib: Introduce mana_ib_get_netdev helper function
  (bsc#1012628).
- RDMA/mana_ib: Introduce mana_ib_install_cq_cb helper function
  (bsc#1012628).
- RDMA/mana_ib: Use virtual address in dma regions for MRs
  (bsc#1012628).
- Input: iqs7222 - add support for IQS7222D v1.1 and v1.2
  (bsc#1012628).
- NFS: Fix nfs_netfs_issue_read() xarray locking for writeback
  interrupt (bsc#1012628).
- NFS: Fix an off by one in root_nfs_cat() (bsc#1012628).
- NFSv4.1/pnfs: fix NFS with TLS in pnfs (bsc#1012628).
- ACPI: HMAT: Remove register of memory node for generic target
  (bsc#1012628).
- f2fs: compress: relocate some judgments in
  f2fs_reserve_compress_blocks (bsc#1012628).
- f2fs: compress: fix reserve_cblocks counting error when out
  of space (bsc#1012628).
- f2fs: fix to truncate meta inode pages forcely (bsc#1012628).
- f2fs: zone: fix to remove pow2 check condition for zoned block
  device (bsc#1012628).
- cxl: Fix the incorrect assignment of SSLBIS entry pointer
  initial location (bsc#1012628).
- perf/x86/amd/core: Avoid register reset when CPU is dead
  (bsc#1012628).
- afs: Revert "afs: Hide silly-rename files from userspace"
  (bsc#1012628).
- afs: Don't cache preferred address (bsc#1012628).
- afs: Fix occasional rmdir-then-VNOVNODE with generic/011
  (bsc#1012628).
- f2fs: fix to avoid use-after-free issue in f2fs_filemap_fault
  (bsc#1012628).
- nfs: fix panic when nfs4_ff_layout_prepare_ds() fails
  (bsc#1012628).
- ovl: relax WARN_ON in ovl_verify_area() (bsc#1012628).
- io_uring/net: correct the type of variable (bsc#1012628).
- remoteproc: stm32: Fix incorrect type in assignment for va
  (bsc#1012628).
- remoteproc: stm32: Fix incorrect type assignment returned by
  stm32_rproc_get_loaded_rsc_tablef (bsc#1012628).
- iio: pressure: mprls0025pa fix off-by-one enum (bsc#1012628).
- usb: phy: generic: Get the vbus supply (bsc#1012628).
- tty: vt: fix 20 vs 0x20 typo in EScsiignore (bsc#1012628).
- serial: max310x: fix syntax error in IRQ error message
  (bsc#1012628).
- tty: serial: samsung: fix tx_empty() to return TIOCSER_TEMT
  (bsc#1012628).
- arm64: dts: broadcom: bcmbca: bcm4908: drop invalid switch cells
  (bsc#1012628).
- coresight: Fix issue where a source device's helpers aren't
  disabled (bsc#1012628).
- coresight: etm4x: Set skip_power_up in etm4_init_arch_data
  function (bsc#1012628).
- xhci: Add interrupt pending autoclear flag to each interrupter
  (bsc#1012628).
- xhci: make isoc_bei_interval variable interrupter specific
  (bsc#1012628).
- xhci: remove unnecessary event_ring_deq parameter from
  xhci_handle_event() (bsc#1012628).
- xhci: update event ring dequeue pointer position to controller
  correctly (bsc#1012628).
- coccinelle: device_attr_show: Remove useless expression STR
  (bsc#1012628).
- kconfig: fix infinite loop when expanding a macro at the end
  of file (bsc#1012628).
- iio: gts-helper: Fix division loop (bsc#1012628).
- bus: mhi: ep: check the correct variable in
  mhi_ep_register_controller() (bsc#1012628).
- hwtracing: hisi_ptt: Move type check to the beginning of
  hisi_ptt_pmu_event_init() (bsc#1012628).
- rtc: mt6397: select IRQ_DOMAIN instead of depending on it
  (bsc#1012628).
- rtc: max31335: fix interrupt status reg (bsc#1012628).
- serial: 8250_exar: Don't remove GPIO device on suspend
  (bsc#1012628).
- staging: greybus: fix get_channel_from_mode() failure path
  (bsc#1012628).
- mei: vsc: Call wake_up() in the threaded IRQ handler
  (bsc#1012628).
- mei: vsc: Don't use sleeping condition in wait_event_timeout()
  (bsc#1012628).
- usb: gadget: net2272: Use irqflags in the call to
  net2272_probe_fin (bsc#1012628).
- char: xilinx_hwicap: Fix NULL vs IS_ERR() bug (bsc#1012628).
- x86/hyperv: Use per cpu initial stack for vtl context
  (bsc#1012628).
- ASoC: tlv320adc3xxx: Don't strip remove function when driver
  is builtin (bsc#1012628).
- thermal/drivers/mediatek/lvts_thermal: Fix a memory leak in
  an error handling path (bsc#1012628).
- thermal/drivers/qoriq: Fix getting tmu range (bsc#1012628).
- io_uring: don't save/restore iowait state (bsc#1012628).
- spi: lpspi: Avoid potential use-after-free in probe()
  (bsc#1012628).
- spi: Restore delays for non-GPIO chip select (bsc#1012628).
- ASoC: rockchip: i2s-tdm: Fix inaccurate sampling rates
  (bsc#1012628).
- nouveau: reset the bo resource bus info after an eviction
  (bsc#1012628).
- tcp: Fix NEW_SYN_RECV handling in inet_twsk_purge()
  (bsc#1012628).
- rds: tcp: Fix use-after-free of net in reqsk_timer_handler()
  (bsc#1012628).
- octeontx2-af: Use matching wake_up API variant in CGX command
  interface (bsc#1012628).
- s390/vtime: fix average steal time calculation (bsc#1012628).
- net/sched: taprio: proper TCA_TAPRIO_TC_ENTRY_INDEX check
  (bsc#1012628).
- devlink: Fix devlink parallel commands processing (bsc#1012628).
- riscv: Only check online cpus for emulated accesses
  (bsc#1012628).
- soc: fsl: dpio: fix kcalloc() argument order (bsc#1012628).
- cpufreq: Fix per-policy boost behavior on SoCs using
  cpufreq_boost_set_sw() (bsc#1012628).
- io_uring: Fix release of pinned pages when __io_uaddr_map fails
  (bsc#1012628).
- tcp: Fix refcnt handling in __inet_hash_connect() (bsc#1012628).
- vmxnet3: Fix missing reserved tailroom (bsc#1012628).
- hsr: Fix uninit-value access in hsr_get_node() (bsc#1012628).
- net: txgbe: fix clk_name exceed MAX_DEV_ID limits (bsc#1012628).
- spi: spi-mem: add statistics support to ->exec_op() calls
  (bsc#1012628).
- spi: Fix error code checking in spi_mem_exec_op() (bsc#1012628).
- nvme: fix reconnection fail due to reserved tag allocation
  (bsc#1012628).
- drm/xe: Invalidate userptr VMA on page pin fault (bsc#1012628).
- drm/xe: Skip VMAs pin when requesting signal to the last XE_EXEC
  (bsc#1012628).
- net: mediatek: mtk_eth_soc: clear MAC_MCR_FORCE_LINK only when
  MAC is up (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix PPE hanging issue (bsc#1012628).
- io_uring: fix poll_remove stalled req completion (bsc#1012628).
- ASoC: SOF: amd: Move signed_fw_image to struct acp_quirk_entry
  (bsc#1012628).
- ASoC: SOF: amd: Skip IRAM/DRAM size modification for Steam
  Deck OLED (bsc#1012628).
- riscv: Fix compilation error with FAST_GUP and rv32
  (bsc#1012628).
- xen/evtchn: avoid WARN() when unbinding an event channel
  (bsc#1012628).
- xen/events: increment refcnt only if event channel is refcounted
  (bsc#1012628).
- packet: annotate data-races around ignore_outgoing
  (bsc#1012628).
- xfrm: Allow UDP encapsulation only in offload modes
  (bsc#1012628).
- net: veth: do not manipulate GRO when using XDP (bsc#1012628).
- net: dsa: mt7530: prevent possible incorrect XTAL frequency
  selection (bsc#1012628).
- spi: spi-imx: fix off-by-one in mx51 CPU mode burst length
  (bsc#1012628).
- drm: Fix drm_fixp2int_round() making it add 0.5 (bsc#1012628).
- virtio: uapi: Drop __packed attribute in linux/virtio_pci.h
  (bsc#1012628).
- vdpa_sim: reset must not run (bsc#1012628).
- vdpa/mlx5: Allow CVQ size changes (bsc#1012628).
- virtio: packed: fix unmap leak for indirect desc table
  (bsc#1012628).
- net: move dev->state into net_device_read_txrx group
  (bsc#1012628).
- wireguard: receive: annotate data-race around
  receiving_counter.counter (bsc#1012628).
- rds: introduce acquire/release ordering in
  acquire/release_in_xmit() (bsc#1012628).
- hsr: Handle failures in module init (bsc#1012628).
- ipv4: raw: Fix sending packets from raw sockets via IPsec
  tunnels (bsc#1012628).
- nouveau/gsp: don't check devinit disable on GSP (bsc#1012628).
- ceph: stop copying to iter at EOF on sync reads (bsc#1012628).
- net: phy: fix phy_read_poll_timeout argument type in
  genphy_loopback (bsc#1012628).
- dm-integrity: fix a memory leak when rechecking the data
  (bsc#1012628).
- net/bnx2x: Prevent access to a freed page in page_pool
  (bsc#1012628).
- devlink: fix port new reply cmd type (bsc#1012628).
- octeontx2: Detect the mbox up or down message via register
  (bsc#1012628).
- octeontx2-pf: Wait till detach_resources msg is complete
  (bsc#1012628).
- octeontx2-pf: Use default max_active works instead of one
  (bsc#1012628).
- octeontx2-pf: Send UP messages to VF only when VF is up
  (bsc#1012628).
- octeontx2-af: Use separate handlers for interrupts
  (bsc#1012628).
- drm/amdgpu: add MMHUB 3.3.1 support (bsc#1012628).
- drm/amdgpu: fix mmhub client id out-of-bounds access
  (bsc#1012628).
- drm/amdgpu: drop setting buffer funcs in sdma442 (bsc#1012628).
- netfilter: nft_set_pipapo: release elements in clone only from
  destroy path (bsc#1012628).
- netfilter: nf_tables: do not compare internal table flags on
  updates (bsc#1012628).
- rcu: add a helper to report consolidated flavor QS
  (bsc#1012628).
- net: report RCU QS on threaded NAPI repolling (bsc#1012628).
- bpf: report RCU QS in cpumap kthread (bsc#1012628).
- net: dsa: mt7530: fix link-local frames that ingress vlan
  filtering ports (bsc#1012628).
- net: dsa: mt7530: fix handling of all link-local frames
  (bsc#1012628).
- netfilter: nf_tables: Fix a memory leak in nf_tables_updchain
  (bsc#1012628).
- spi: spi-mt65xx: Fix NULL pointer access in interrupt handler
  (bsc#1012628).
- selftests: forwarding: Fix ping failure due to short timeout
  (bsc#1012628).
- dm io: Support IO priority (bsc#1012628).
- dm-integrity: align the outgoing bio in integrity_recheck
  (bsc#1012628).
- x86/efistub: Clear decompressor BSS in native EFI entrypoint
  (bsc#1012628).
- x86/efistub: Don't clear BSS twice in mixed mode (bsc#1012628).
- printk: Adjust mapping for 32bit seq macros (bsc#1012628).
- printk: Use prb_first_seq() as base for 32bit seq macros
  (bsc#1012628).
- Update config files.
- Rename to
  patches.kernel.org/6.8.2-043-aoe-fix-the-potential-use-after-free-problem-in.patch.
- Rename to
  patches.kernel.org/6.8.2-055-wifi-ath10k-fix-NULL-pointer-dereference-in-ath.patch.
- Rename to
  patches.kernel.org/6.8.2-280-btrfs-fix-race-when-detecting-delalloc-ranges-d.patch.
- commit f53ef05
* Tue Mar 26 2024 colyli@suse.de
- md/raid5: fix atomicity violation in raid5_cache_count
  (bsc#1219169, CVE-2024-23307).
- commit c5176b2
* Tue Mar 26 2024 jlee@suse.com
- wifi: ath10k: fix NULL pointer dereference in
  ath10k_wmi_tlv_op_pull_mgmt_tx_compl_ev() (bsc#1218336
  CVE-2023-7042).
- commit 7ab0c97
* Mon Mar 25 2024 mkubecek@suse.cz
- update to 6.9-rc1
- drop 19 patches (14 mainline, 5 stable)
  - patches.kernel.org/*
  - patches.suse/Bluetooth-btmtk-Add-MODULE_FIRMWARE-for-MT7922.patch
  - patches.suse/btrfs-fix-race-when-detecting-delalloc-ranges-during.patch
  - patches.suse/iwlwifi-cfg-Add-missing-MODULE_FIRMWARE-for-pnvm.patch
  - patches.suse/net-mdio-add-2.5g-and-5g-related-PMA-speed-constants.patch
  - patches.suse/net-phy-realtek-add-5Gbps-support-to-rtl822x_config_.patch
  - patches.suse/net-phy-realtek-add-support-for-RTL8126A-integrated-.patch
  - patches.suse/net-phy-realtek-use-generic-MDIO-constants.patch
  - patches.suse/r8169-add-support-for-RTL8126A.patch
  - patches.suse/wifi-ath11k-do-not-dump-SRNG-statistics-during-resum.patch
  - patches.suse/wifi-ath11k-fix-warning-on-DMA-ring-capabilities-eve.patch
  - patches.suse/wifi-ath11k-rearrange-IRQ-enable-disable-in-reset-pa.patch
  - patches.suse/wifi-ath11k-remove-MHI-LOOPBACK-channels.patch
  - patches.suse/wifi-ath11k-thermal-don-t-try-to-register-multiple-t.patch
  - patches.suse/wifi-brcmfmac-Fix-use-after-free-bug-in-brcmf_cfg802.patch
- refresh
  - patches.suse/0001-security-lockdown-expose-a-hook-to-lock-the-kernel-down.patch
  - patches.suse/Restore-kABI-for-NVidia-vGPU-driver.patch
  - patches.suse/add-product-identifying-information-to-vmcoreinfo.patch
  - patches.suse/bus-mhi-host-add-mhi_power_down_no_destroy.patch
  - patches.suse/drivers-firmware-skip-simpledrm-if-nvidia-drm.modese.patch
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/vfs-add-super_operations-get_inode_dev
- disable ARM architectures (need config update)
- new config options
  - Processor type and features
  - X86_FRED=y
  - Mitigations for speculative execution vulnerabilities
  - MITIGATION_PAGE_TABLE_ISOLATION=y
  - MITIGATION_RETPOLINE=y
  - MITIGATION_RETHUNK=y
  - MITIGATION_UNRET_ENTRY=y
  - MITIGATION_CALL_DEPTH_TRACKING=y
  - MITIGATION_IBPB_ENTRY=y
  - MITIGATION_IBRS_ENTRY=y
  - MITIGATION_SRSO=y
  - MITIGATION_SLS=y
  - MITIGATION_GDS_FORCE=n
  - Power management and ACPI options
  - HIBERNATION_COMP_LZO=y
  - HIBERNATION_COMP_LZ4=n
  - General architecture-dependent options
  - PAGE_SIZE_4KB=y
  - File systems
  - FUSE_PASSTHROUGH=y
  - Cryptographic API
  - CRYPTO_DEV_QAT_ERROR_INJECTION=n
  - Network device support
  - OCTEON_EP_VF=m
  - QCA83XX_PHY=m
  - QCA808X_PHY=m
  - CAN_ESD_402_PCI=m
  - Input device support
  - TOUCHSCREEN_GOODIX_BERLIN_I2C=m
  - TOUCHSCREEN_GOODIX_BERLIN_SPI=m
  - Hardware Monitoring support
  - SENSORS_ASUS_ROG_RYUJIN=m
  - SENSORS_CHIPCAP2=m
  - SENSORS_LTC4282=m
  - SENSORS_NZXT_KRAKEN3=m
  - SENSORS_MPQ8785=m
  - SENSORS_PT5161L=m
  - SENSORS_SURFACE_FAN=m
  - Graphics support
  - MAX6959=n
  - SEG_LED_GPIO=n
  - DRM_I915_DP_TUNNEL=y
  - BACKLIGHT_KTD2801=m
  - Sound card support
  - SND_SOC_AMD_SOUNDWIRE=m
  - SND_SOC_SOF_AMD_SOUNDWIRE=m
  - SND_SOC_WCD939X_SDW=n
  - USB support
  - USB_DEFAULT_AUTHORIZATION_MODE=1
  - TYPEC_MUX_IT5205=m
  - Industrial I/O support
  - AD9467=n
  - ADI_AXI_ADC=n
  - PAC1934=n
  - TI_ADS1298=n
  - ADMFM2000=n
  - Reliability, Availability and Serviceability (RAS) features
  - AMD_ATL=m
  - RAS_FMPM=m
  - Misc drivers
  - MTD_UBI_NVMEM=m
  - DM_VDO=m
  - PTP_1588_CLOCK_FC3W=m
  - GPIO_CROS_EC=m
  - W1_MASTER_UART=m
  - CROS_EC_WATCHDOG=m
  - QCOM_PBS=m
  - RESET_GPIO=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - DRM_PANEL_BOE_TH101MB31UIG002_28A=n
  - DRM_PANEL_HIMAX_HX83112A=n
  - DRM_PANEL_NOVATEK_NT36672E=n
  - LEDS_NCP5623=m
  - i386
  - QCA807X_PHY=m
  - PINCTRL_AW9523=m
  - DRM_XE=m
  - DRM_XE_* copied from x86_64
  - SND_SOC_FRAMER=m
  - AF8133J=n
  - ppc64le
  - NET_DSA_REALTEK_MDIO=y
  - NET_DSA_REALTEK_SMI=y
  - QCA807X_PHY=m
  - PINCTRL_AW9523=m
  - s390x
  - DRM_DEBUG_MM=n
  - DEBUG_VIRTUAL=n
  - riscv64
  - RISCV_PROBE_UNALIGNED_ACCESS=y
  - HIBERNATION=y
  - HIBERNATION_SNAPSHOT_DEV=y
  - PM_STD_PARTITION=""
  - ACPI_CPPC_CPUFREQ=m
  - ACPI_CPPC_CPUFREQ_FIE=y
  - ACPI_PROCESSOR=y
  - ACPI_THERMAL=m
  - RANDOMIZE_KSTACK_OFFSET=y
  - RANDOMIZE_KSTACK_OFFSET_DEFAULT=y
  - NET_DSA_REALTEK_MDIO=y
  - NET_DSA_REALTEK_SMI=y
  - SND_SOC_FRAMER=m
  - MMC_DW_HI3798MV200=m
  - AF8133J=n
  - STARFIVE_JH8100_INTC=y
  - STARFIVE_STARLINK_PMU=y
  - ANDES_CUSTOM_PMU=y
  - CRYPTO_*_RISCV64=m
- commit ffd2471
* Mon Mar 25 2024 tiwai@suse.de
- wifi: ath11k: decrease MHI channel buffer length to 8KB
  (bsc#1207948).
- commit 6ca52f8
* Thu Mar 21 2024 jlee@suse.com
- aoe: fix the potential use-after-free problem in aoecmd_cfg_pkts
  (bsc#1218562 CVE-2023-6270).
- commit 525e9e7
* Thu Mar 21 2024 msuchanek@suse.de
- Workaround broken chacha crypto fallback (boo#1218114).
- commit 6a29422
* Tue Mar 19 2024 jslaby@suse.cz
- Revert "btrfs: remove code for inode_cache and recovery mount
  options" (https://github.com/yast/yast-update/issues/197).
- commit d922afa
* Mon Mar 18 2024 jslaby@suse.cz
- Linux 6.8.1 (bsc#1012628).
- Rename to
  patches.kernel.org/6.8.1-001-x86-mmio-Disable-KVM-mitigation-when-X86_FEATUR.patch.
- Rename to
  patches.kernel.org/6.8.1-002-Documentation-hw-vuln-Add-documentation-for-RFD.patch.
- Rename to
  patches.kernel.org/6.8.1-003-x86-rfds-Mitigate-Register-File-Data-Sampling-R.patch.
- Rename to
  patches.kernel.org/6.8.1-004-KVM-x86-Export-RFDS_NO-and-RFDS_CLEAR-to-guests.patch.
- commit 74a8025
* Thu Mar 14 2024 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  - patches.suse/iwlwifi-cfg-Add-missing-MODULE_FIRMWARE-for-pnvm.patch
  - patches.suse/wifi-ath11k-do-not-dump-SRNG-statistics-during-resum.patch
  - patches.suse/wifi-ath11k-fix-warning-on-DMA-ring-capabilities-eve.patch
  - patches.suse/wifi-ath11k-rearrange-IRQ-enable-disable-in-reset-pa.patch
  - patches.suse/wifi-ath11k-remove-MHI-LOOPBACK-channels.patch
  - patches.suse/wifi-ath11k-thermal-don-t-try-to-register-multiple-t.patch
- commit 96ac51b
* Thu Mar 14 2024 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  - patches.suse/Bluetooth-btmtk-Add-MODULE_FIRMWARE-for-MT7922.patch
  - patches.suse/net-mdio-add-2.5g-and-5g-related-PMA-speed-constants.patch
  - patches.suse/net-phy-realtek-add-5Gbps-support-to-rtl822x_config_.patch
  - patches.suse/net-phy-realtek-add-support-for-RTL8126A-integrated-.patch
  - patches.suse/net-phy-realtek-use-generic-MDIO-constants.patch
  - patches.suse/r8169-add-support-for-RTL8126A.patch
  - patches.suse/wifi-brcmfmac-Fix-use-after-free-bug-in-brcmf_cfg802.patch
- commit 63b2803
* Wed Mar 13 2024 mkubecek@suse.cz
- series.conf: cleanup
- update upstream status and move to sorted section:
  - patches.suse/btrfs-fix-race-when-detecting-delalloc-ranges-during.patch
- commit e863123
* Wed Mar 13 2024 jslaby@suse.cz
- KVM/x86: Export RFDS_NO and RFDS_CLEAR to guests (bsc#1213456
  CVE-2023-28746).
- x86/rfds: Mitigate Register File Data Sampling (RFDS)
  (bsc#1213456 CVE-2023-28746).
- Update config files. Set MITIGATION_RFDS=y.
- Documentation/hw-vuln: Add documentation for RFDS (bsc#1213456
  CVE-2023-28746).
- x86/mmio: Disable KVM mitigation when X86_FEATURE_CLEAR_CPU_BUF
  is set (bsc#1213456 CVE-2023-28746).
- commit d8d0d20
* Tue Mar 12 2024 jslaby@suse.cz
- btrfs: fix race when detecting delalloc ranges during fiemap
  (btrfs-fix).
- commit 5e23030
* Mon Mar 11 2024 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  - patches.suse/wifi-brcmfmac-Fix-use-after-free-bug-in-brcmf_cfg802.patch
  - patches.suse/net-phy-realtek-add-support-for-RTL8126A-integrated-.patch
  - patches.suse/r8169-add-support-for-RTL8126A.patch
  - patches.suse/net-mdio-add-2.5g-and-5g-related-PMA-speed-constants.patch
  - patches.suse/net-phy-realtek-use-generic-MDIO-constants.patch
  - patches.suse/net-phy-realtek-add-5Gbps-support-to-rtl822x_config_.patch
  - patches.suse/Bluetooth-btmtk-Add-MODULE_FIRMWARE-for-MT7922.patch
- commit 002260c
* Mon Mar 11 2024 jslaby@suse.cz
- rpm/mkspec-dtb: resolve packaging conflicts better
  The merge commit ad1679b2612f left both %%ifs in place. Remove the one
  which d26c540d7eed was removing originally.
  This fixes errors like:
  dtb-armv7l.spec : error: line 1442: Unclosed %%if
  The commit also removed SUBPKG_CASE. Reintroduce it, otherwise we see
  shell garbage in the description
- commit e4b3d06
* Mon Mar 11 2024 jslaby@suse.cz
- Refresh
  patches.suse/mm-mmap-fix-vma_merge-case-7-with-vma_ops-close.patch.
  Update upstream status and move to sorted section.
- commit c6dad0c
* Sun Mar 10 2024 mkubecek@suse.cz
- Update to 6.8 final
- update configs
- commit a551d7b
* Sun Mar 10 2024 mkubecek@suse.cz
- config: update and reenable armv6hl configs
- option values mirrored from armv7hl
- commit be3b67b
* Sun Mar 10 2024 mkubecek@suse.cz
- config: update and reenable armv7hl configs
- option values mirrored from arm64 or other architectures
- commit 336405e
* Sun Mar 10 2024 mkubecek@suse.cz
- config: update and reenable arm64 configs
- most options mirrored from other architectures except
  - ARM64_ERRATUM_3117295=y
  - TEE_STMM_EFI=m
  - PINCTRL_SM4450=m
  - PINCTRL_SM8650=m
  - PINCTRL_X1E80100=m
  - PINCTRL_SM8650_LPASS_LPI=m
  - GPIO_NPCM_SGPIO=y
  - GPIO_RTD=m
  - VIDEO_STM32_DCMIPP=m
  - DRM_POWERVR=m
  - SND_SOC_X1E80100=m
  - RTC_DRV_MA35D1=m
  - COMMON_CLK_MT7988=m
  - CLK_X1E80100_GCC=m
  - SC_CAMCC_8280XP=m
  - QDU_ECPRICC_1000=m
  - SM_DISPCC_8650=m
  - SM_GCC_8650=m
  - SM_GPUCC_8650=m
  - SM_TCSRCC_8650=m
  - COMMON_CLK_STM32MP=y
  - INTERCONNECT_QCOM_SM6115=m
  - INTERCONNECT_QCOM_SM8650=m
  - INTERCONNECT_QCOM_X1E80100=m
  - KASAN_EXTRA_INFO=n (arm64/debug only)
- commit 99c97ec
* Thu Mar  7 2024 msuchanek@suse.de
- group-source-files.pl: Quote filenames (boo#1221077).
  The kernel source now contains a file with a space in the name.
  Add quotes in group-source-files.pl to avoid splitting the filename.
  Also use -print0 / -0 when updating timestamps.
- commit a005e42
* Thu Mar  7 2024 jslaby@suse.cz
- Linux 6.7.9 (bsc#1012628).
- mtd: spinand: gigadevice: Fix the get ecc status issue
  (bsc#1012628).
- ice: fix connection state of DPLL and out pin (bsc#1012628).
- ice: fix dpll input pin phase_adjust value updates
  (bsc#1012628).
- ice: fix dpll and dpll_pin data access on PF reset
  (bsc#1012628).
- ice: fix dpll periodic work data updates on PF reset
  (bsc#1012628).
- ice: fix pin phase adjust updates on PF reset (bsc#1012628).
- spi: cadence-qspi: fix pointer reference in runtime PM hooks
  (bsc#1012628).
- spi: cadence-qspi: remove system-wide suspend helper calls
  from runtime PM hooks (bsc#1012628).
- netlink: Fix kernel-infoleak-after-free in __skb_datagram_iter
  (bsc#1012628).
- netlink: add nla be16/32 types to minlen array (bsc#1012628).
- net: ip_tunnel: prevent perpetual headroom growth (bsc#1012628).
- net: mctp: take ownership of skb in mctp_local_output
  (bsc#1012628).
- net: dpaa: fman_memac: accept phy-interface-type = "10gbase-r"
  in the device tree (bsc#1012628).
- tun: Fix xdp_rxq_info's queue_index when detaching
  (bsc#1012628).
- cpufreq: intel_pstate: fix pstate limits enforcement for
  adjust_perf call back (bsc#1012628).
- net: veth: clear GRO when clearing XDP even when down
  (bsc#1012628).
- ipv6: fix potential "struct net" leak in inet6_rtm_getaddr()
  (bsc#1012628).
- lan78xx: enable auto speed configuration for LAN7850 if no
  EEPROM is detected (bsc#1012628).
- veth: try harder when allocating queue memory (bsc#1012628).
- net: usb: dm9601: fix wrong return value in dm9601_mdio_read
  (bsc#1012628).
- net: lan78xx: fix "softirq work is pending" error (bsc#1012628).
- uapi: in6: replace temporary label with rfc9486 (bsc#1012628).
- stmmac: Clear variable when destroying workqueue (bsc#1012628).
- Bluetooth: hci_sync: Check the correct flag before starting
  a scan (bsc#1012628).
- Bluetooth: Avoid potential use-after-free in hci_error_reset
  (bsc#1012628).
- Bluetooth: hci_sync: Fix accept_list when attempting to suspend
  (bsc#1012628).
- Bluetooth: hci_event: Fix wrongly recorded wakeup BD_ADDR
  (bsc#1012628).
- Bluetooth: hci_event: Fix handling of HCI_EV_IO_CAPA_REQUEST
  (bsc#1012628).
- Bluetooth: Enforce validation on max value of connection
  interval (bsc#1012628).
- Bluetooth: qca: Fix wrong event type for patch config command
  (bsc#1012628).
- Bluetooth: hci_qca: Set BDA quirk bit if fwnode exists in DT
  (bsc#1012628).
- Bluetooth: qca: Fix triggering coredump implementation
  (bsc#1012628).
- netfilter: nf_tables: allow NFPROTO_INET in
  nft_(match/target)_validate() (bsc#1012628).
- netfilter: bridge: confirm multicast packets before passing
  them up the stack (bsc#1012628).
- tools: ynl: fix handling of multiple mcast groups (bsc#1012628).
- rtnetlink: fix error logic of IFLA_BRIDGE_FLAGS writing back
  (bsc#1012628).
- igb: extend PTP timestamp adjustments to i211 (bsc#1012628).
- net: hsr: Use correct offset for HSR TLV values in supervisory
  HSR frames (bsc#1012628).
- tls: decrement decrypt_pending if no async completion will be
  called (bsc#1012628).
- tls: fix peeking with sync+async decryption (bsc#1012628).
- tls: separate no-async decryption request handling from async
  (bsc#1012628).
- tls: fix use-after-free on failed backlog decryption
  (bsc#1012628).
- riscv: tlb: fix __p*d_free_tlb() (bsc#1012628).
- efi/capsule-loader: fix incorrect allocation size (bsc#1012628).
- power: supply: bq27xxx-i2c: Do not free non existing IRQ
  (bsc#1012628).
- ASoC: cs35l56: Must clear HALO_STATE before issuing SYSTEM_RESET
  (bsc#1012628).
- ALSA: Drop leftover snd-rtctimer stuff from Makefile
  (bsc#1012628).
- ASoC: qcom: Fix uninitialized pointer dmactl (bsc#1012628).
- gpu: host1x: Skip reset assert on Tegra186 (bsc#1012628).
- riscv: mm: fix NOCACHE_THEAD does not set bit[61] correctly
  (bsc#1012628).
- riscv: Fix build error if !CONFIG_ARCH_ENABLE_HUGEPAGE_MIGRATION
  (bsc#1012628).
- ASoC: cs35l56: cs35l56_component_remove() must clear
  cs35l56->component (bsc#1012628).
- ASoC: cs35l56: cs35l56_component_remove() must clean up wm_adsp
  (bsc#1012628).
- ASoC: cs35l56: Don't add the same register patch multiple times
  (bsc#1012628).
- ASoC: cs35l56: Fix for initializing ASP1 mixer registers
  (bsc#1012628).
- ASoC: cs35l56: Fix misuse of wm_adsp 'part' string for silicon
  revision (bsc#1012628).
- ASoC: cs35l56: Fix deadlock in ASP1 mixer register
  initialization (bsc#1012628).
- ASoC: soc-card: Fix missing locking in
  snd_soc_card_get_kcontrol() (bsc#1012628).
- RISC-V: Ignore V from the riscv,isa DT property on older T-Head
  CPUs (bsc#1012628).
- drm/tegra: Remove existing framebuffer only if we support
  display (bsc#1012628).
- fbcon: always restore the old font data in fbcon_do_set_font()
  (bsc#1012628).
- afs: Fix endless loop in directory parsing (bsc#1012628).
- drm/amd/display: Prevent potential buffer overflow in
  map_hw_resources (bsc#1012628).
- drivers: perf: added capabilities for legacy PMU (bsc#1012628).
- drivers: perf: ctr_get_width function for legacy is not defined
  (bsc#1012628).
- Revert "riscv: mm: support Svnapot in huge vmap" (bsc#1012628).
- riscv: Fix pte_leaf_size() for NAPOT (bsc#1012628).
- riscv: Sparse-Memory/vmemmap out-of-bounds fix (bsc#1012628).
- btrfs: fix race between ordered extent completion and fiemap
  (bsc#1012628).
- drm/nouveau: keep DMA buffers required for suspend/resume
  (bsc#1012628).
- of: property: fw_devlink: Fix stupid bug in remote-endpoint
  parsing (bsc#1012628).
- tomoyo: fix UAF write bug in tomoyo_write_control()
  (bsc#1012628).
- ALSA: firewire-lib: fix to check cycle continuity (bsc#1012628).
- ALSA: ump: Fix the discard error code from snd_ump_legacy_open()
  (bsc#1012628).
- ALSA: hda/realtek: Fix top speaker connection on Dell Inspiron
  16 Plus 7630 (bsc#1012628).
- ALSA: hda/realtek: tas2781: enable subwoofer volume control
  (bsc#1012628).
- ALSA: hda/realtek: Enable Mute LED on HP 840 G8 (MB 8AB8)
  (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LED For HP mt440
  (bsc#1012628).
- ALSA: hda/realtek: Add special fixup for Lenovo 14IRP8
  (bsc#1012628).
- Bluetooth: hci_bcm4377: do not mark valid bd_addr as invalid
  (bsc#1012628).
- landlock: Fix asymmetric private inodes referring (bsc#1012628).
- gtp: fix use-after-free and null-ptr-deref in gtp_newlink()
  (bsc#1012628).
- mm: cachestat: fix folio read-after-free in cache walk
  (bsc#1012628).
- mtd: rawnand: marvell: fix layouts (bsc#1012628).
- wifi: nl80211: reject iftype change with mesh ID change
  (bsc#1012628).
- btrfs: fix double free of anonymous device after snapshot
  creation failure (bsc#1012628).
- btrfs: dev-replace: properly validate device names
  (bsc#1012628).
- btrfs: send: don't issue unnecessary zero writes for trailing
  hole (bsc#1012628).
- Revert "drm/amd/pm: resolve reboot exception for si oland"
  (bsc#1012628).
- drm/buddy: fix range bias (bsc#1012628).
- drm/amdgpu/pm: Fix the power1_min_cap value (bsc#1012628).
- drm/amd/display: Add monitor patch for specific eDP
  (bsc#1012628).
- soc: qcom: pmic_glink: Fix boot when QRTR=m (bsc#1012628).
- dmaengine: fsl-qdma: fix SoC may hang on 16 byte unaligned read
  (bsc#1012628).
- crypto: arm64/neonbs - fix out-of-bounds access on short input
  (bsc#1012628).
- dmaengine: ptdma: use consistent DMA masks (bsc#1012628).
- dmaengine: fsl-edma: correct calculation of 'nbytes' in
  multi-fifo scenario (bsc#1012628).
- dmaengine: fsl-qdma: init irq after reg initialization
  (bsc#1012628).
- mmc: mmci: stm32: fix DMA API overlapping mappings warning
  (bsc#1012628).
- mmc: core: Fix eMMC initialization with 1-bit bus connection
  (bsc#1012628).
- mmc: sdhci-xenon: add timeout for PHY init complete
  (bsc#1012628).
- mmc: sdhci-xenon: fix PHY init clock stability (bsc#1012628).
- ceph: switch to corrected encoding of max_xattr_size in mdsmap
  (bsc#1012628).
- RISC-V: Drop invalid test from CONFIG_AS_HAS_OPTION_ARCH
  (bsc#1012628).
- riscv: add CALLER_ADDRx support (bsc#1012628).
- riscv: Fix enabling cbo.zero when running in M-mode
  (bsc#1012628).
- power: supply: mm8013: select REGMAP_I2C (bsc#1012628).
- kbuild: Add -Wa,--fatal-warnings to as-instr invocation
  (bsc#1012628).
- iommufd: Fix iopt_access_list_id overwrite bug (bsc#1012628).
- iommufd: Fix protection fault in iommufd_test_syz_conv_iova
  (bsc#1012628).
- efivarfs: Request at most 512 bytes for variable names
  (bsc#1012628).
- pmdomain: arm: Fix NULL dereference on scmi_perf_domain removal
  (bsc#1012628).
- pmdomain: qcom: rpmhpd: Fix enabled_corner aggregation
  (bsc#1012628).
- fprobe: Fix to allocate entry_data_size buffer with rethook
  instances (bsc#1012628).
- mm/debug_vm_pgtable: fix BUG_ON with pud advanced test
  (bsc#1012628).
- mm/vmscan: fix a bug calling wakeup_kswapd() with a wrong zone
  index (bsc#1012628).
- x86/e820: Don't reserve SETUP_RNG_SEED in e820 (bsc#1012628).
- x86/cpu: Allow reducing x86_phys_bits during
  early_identify_cpu() (bsc#1012628).
- x86/cpu/intel: Detect TME keyid bits before setting MTRR mask
  registers (bsc#1012628).
- mptcp: map v4 address to v6 when destroying subflow
  (bsc#1012628).
- mptcp: push at DSS boundaries (bsc#1012628).
- selftests: mptcp: join: add ss mptcp support check
  (bsc#1012628).
- mptcp: fix snd_wnd initialization for passive socket
  (bsc#1012628).
- mptcp: fix potential wake-up event loss (bsc#1012628).
- mptcp: fix double-free on socket dismantle (bsc#1012628).
- mfd: twl6030-irq: Revert to use of_match_device() (bsc#1012628).
- NFS: Fix data corruption caused by congestion (bsc#1012628).
- af_unix: Drop oob_skb ref before purging queue in GC
  (bsc#1012628).
- ASoC: cs35l56: fix reversed if statement in
  cs35l56_dspwait_asp1tx_put() (bsc#1012628).
- dmaengine: dw-edma: Fix the ch_count hdma callback
  (bsc#1012628).
- dmaengine: dw-edma: Fix wrong interrupt bit set for HDMA
  (bsc#1012628).
- dmaengine: dw-edma: HDMA_V0_REMOTEL_STOP_INT_EN typo fix
  (bsc#1012628).
- dmaengine: dw-edma: Add HDMA remote interrupt configuration
  (bsc#1012628).
- dmaengine: dw-edma: HDMA: Add sync read before starting the
  DMA transfer in remote setup (bsc#1012628).
- dmaengine: dw-edma: eDMA: Add sync read before starting the
  DMA transfer in remote setup (bsc#1012628).
- phy: freescale: phy-fsl-imx8-mipi-dphy: Fix alias name to use
  dashes (bsc#1012628).
- phy: qcom: phy-qcom-m31: fix wrong pointer pass to PTR_ERR()
  (bsc#1012628).
- phy: qcom-qmp-usb: fix v3 offsets data (bsc#1012628).
- dmaengine: idxd: Remove shadow Event Log head stored in idxd
  (bsc#1012628).
- dmaengine: idxd: Ensure safe user copy of completion record
  (bsc#1012628).
- powerpc/pseries/iommu: IOMMU table is not initialized for
  kdump over SR-IOV (bsc#1012628).
- powerpc/rtas: use correct function name for resetting TCE tables
  (bsc#1012628).
- gpio: 74x164: Enable output pins after registers are reset
  (bsc#1012628).
- gpiolib: Fix the error path order in
  gpiochip_add_data_with_key() (bsc#1012628).
- gpio: fix resource unwinding order in error path (bsc#1012628).
- block: define bvec_iter as __packed __aligned(4) (bsc#1012628).
- selftests: mptcp: add evts_get_info helper (bsc#1012628).
- selftests: mptcp: add chk_subflows_total helper (bsc#1012628).
- selftests: mptcp: update userspace pm test helpers
  (bsc#1012628).
- selftests: mptcp: add mptcp_lib_is_v6 (bsc#1012628).
- selftests: mptcp: rm subflow with v4/v4mapped addr
  (bsc#1012628).
- drm/nouveau: don't fini scheduler before entity flush
  (bsc#1012628).
- Rename to
  patches.kernel.org/6.7.9-121-mptcp-avoid-printing-warning-once-on-client-sid.patch.
- Rename to
  patches.kernel.org/6.7.9-127-mptcp-fix-possible-deadlock-in-subflow-diag.patch.
- Rename to
  patches.kernel.org/6.7.9-130-af_unix-Fix-task-hung-while-purging-oob_skb-in-.patch.
- Rename to
  patches.kernel.org/6.7.9-150-x86-entry_64-Add-VERW-just-before-userspace-tra.patch.
- Rename to
  patches.kernel.org/6.7.9-151-x86-entry_32-Add-VERW-just-before-userspace-tra.patch.
- Rename to
  patches.kernel.org/6.7.9-152-x86-bugs-Use-ALTERNATIVE-instead-of-mds_user_cl.patch.
- Rename to
  patches.kernel.org/6.7.9-153-KVM-VMX-Use-BT-JNC-i.e.-EFLAGS.CF-to-select-VMR.patch.
- Rename to
  patches.kernel.org/6.7.9-154-KVM-VMX-Move-VERW-closer-to-VMentry-for-MDS-mit.patch.
- commit 752a7bc
* Wed Mar  6 2024 msuchanek@suse.de
- kernel-binary: Fix i386 build
  Fixes: 89eaf4cdce05 ("rpm templates: Move macro definitions below buildrequires")
- commit f7c6351
* Wed Mar  6 2024 msuchanek@suse.de
- kernel-binary: vdso: fix filelist for non-usrmerged kernel
  Fixes: a6ad8af207e6 ("rpm templates: Always define usrmerged")
- commit fb3f221
* Mon Mar  4 2024 vkarasulli@suse.de
- Update
  patches.kernel.org/6.7.2-260-drm-sched-Fix-bounds-limiting-when-given-a-malf.patch
  (bsc#1012628 bsc#1220322 CVE-2023-52461).
- commit c6c85cb
* Mon Mar  4 2024 vkarasulli@suse.de
- Update
  patches.kernel.org/6.7.2-283-media-v4l-async-Fix-duplicated-list-deletion.patch
  (bsc#1012628 bsc#1220318 CVE-2023-52459).
- commit 57771fb
* Mon Mar  4 2024 petr.pavlu@suse.com
- doc/README.SUSE: Update information about module support status
  (jsc#PED-5759)
  Following the code change in SLE15-SP6 to have externally supported
  modules no longer taint the kernel, update the respective documentation
  in README.SUSE:
  * Describe that support status can be obtained at runtime for each
  module from /sys/module/$MODULE/supported and for the entire system
  from /sys/kernel/supported. This provides a way how to now check that
  the kernel has any externally supported modules loaded.
  * Remove a mention that externally supported modules taint the kernel,
  but keep the information about bit 16 (X) and add a note that it is
  still tracked per module and can be read from
  /sys/module/$MODULE/taint. This per-module information also appears in
  Oopses.
- commit 9ed8107
* Mon Mar  4 2024 tiwai@suse.de
- Bluetooth: btmtk: Add MODULE_FIRMWARE() for MT7922
  (bsc#1214133).
- commit 8b861a8
* Mon Mar  4 2024 jslaby@suse.cz
- Update
  patches.kernel.org/6.7.2-504-serial-8250-omap-Don-t-skip-resource-freeing-if.patch
  (bsc#1012628 bsc#1220350 CVE-2023-52457).
- Update
  patches.kernel.org/6.7.2-520-serial-imx-fix-tx-statemachine-deadlock.patch
  (bsc#1012628 bsc#1220364 CVE-2023-52456).
- Update
  patches.kernel.org/6.7.5-109-PCI-ASPM-Fix-deadlock-when-enabling-ASPM.patch
  (bsc#1012628 bsc#1220336 CVE-2024-26605).
  Add CVE references.
- commit 08a1e2c
* Mon Mar  4 2024 jslaby@suse.cz
- Linux 6.7.8 (bsc#1012628).
- Rename to
  patches.kernel.org/6.7.8-001-fs-ntfs3-fix-build-without-CONFIG_NTFS3_LZX_XPR.patch.
- commit 81068ab
* Sun Mar  3 2024 mkubecek@suse.cz
- Update to 6.8-rc7
- eliminate 1 mainline patch
  - patches.rpmify/net-ethernet-adi-move-PHYLIB-from-vendor-to-driver-s.patch (943d4bd67950)
- update riscv64 configs
  - RISCV_ISA_V=y
  - RISCV_ISA_V_DEFAULT_ENABLE=y
  - RISCV_ISA_V_UCOPY_THRESHOLD=768
  - RISCV_ISA_V_PREEMPTIVE=y
  - RISCV_ISA_ZBB=y
- commit ed0a227
* Fri Mar  1 2024 jslaby@suse.cz
- mptcp: fix possible deadlock in subflow diag (git-fixes).
- mptcp: avoid printing warning once on client side (git-fixes).
- commit 1ff84c5
* Fri Mar  1 2024 jslaby@suse.cz
- Linux 6.7.7 (bsc#1012628).
- dmaengine: apple-admac: Keep upper bits of REG_BUS_WIDTH
  (bsc#1012628).
- scsi: smartpqi: Add new controller PCI IDs (bsc#1012628).
- scsi: smartpqi: Fix logical volume rescan race condition
  (bsc#1012628).
- tools: selftests: riscv: Fix compile warnings in hwprobe
  (bsc#1012628).
- tools: selftests: riscv: Fix compile warnings in cbo
  (bsc#1012628).
- tools: selftests: riscv: Fix compile warnings in vector tests
  (bsc#1012628).
- tools: selftests: riscv: Fix compile warnings in mm tests
  (bsc#1012628).
- scsi: target: core: Add TMF to tmr_list handling (bsc#1012628).
- cifs: open_cached_dir should not rely on primary channel
  (bsc#1012628).
- dmaengine: shdma: increase size of 'dev_id' (bsc#1012628).
- dmaengine: fsl-qdma: increase size of 'irq_name' (bsc#1012628).
- dmaengine: dw-edma: increase size of 'name' in debugfs code
  (bsc#1012628).
- wifi: cfg80211: fix missing interfaces when dumping
  (bsc#1012628).
- wifi: mac80211: fix race condition on enabling fast-xmit
  (bsc#1012628).
- fbdev: savage: Error out if pixclock equals zero (bsc#1012628).
- fbdev: sis: Error out if pixclock equals zero (bsc#1012628).
- platform/mellanox: mlxbf-tmfifo: Drop Tx network packet when
  Tx TmFIFO is full (bsc#1012628).
- spi: intel-pci: Add support for Arrow Lake SPI serial flash
  (bsc#1012628).
- spi: hisi-sfc-v3xx: Return IRQ_NONE if no interrupts were
  detected (bsc#1012628).
- block: Fix WARNING in _copy_from_iter (bsc#1012628).
- smb: Work around Clang __bdos() type confusion (bsc#1012628).
- cifs: cifs_pick_channel should try selecting active channels
  (bsc#1012628).
- cifs: translate network errors on send to -ECONNABORTED
  (bsc#1012628).
- cifs: helper function to check replayable error codes
  (bsc#1012628).
- ahci: asm1166: correct count of reported ports (bsc#1012628).
- aoe: avoid potential deadlock at set_capacity (bsc#1012628).
- spi: cs42l43: Handle error from devm_pm_runtime_enable
  (bsc#1012628).
- ahci: add 43-bit DMA address quirk for ASMedia ASM1061
  controllers (bsc#1012628).
- ARM: dts: Fix TPM schema violations (bsc#1012628).
- drm/amd/display: Disable ips before dc interrupt setting
  (bsc#1012628).
- MIPS: reserve exception vector space ONLY ONCE (bsc#1012628).
- platform/x86: touchscreen_dmi: Add info for the TECLAST X16
  Plus tablet (bsc#1012628).
- ext4: avoid dividing by 0 in mb_update_avg_fragment_size()
  when block bitmap corrupt (bsc#1012628).
- ext4: avoid allocating blocks from corrupted group in
  ext4_mb_try_best_found() (bsc#1012628).
- ext4: avoid allocating blocks from corrupted group in
  ext4_mb_find_by_goal() (bsc#1012628).
- Input: goodix - accept ACPI resources with gpio_count == 3 &&
  gpio_int_idx == 0 (bsc#1012628).
- dmaengine: ti: edma: Add some null pointer checks to the
  edma_probe (bsc#1012628).
- ASoC: amd: acp: Add check for cpu dai link initialization
  (bsc#1012628).
- regulator: pwm-regulator: Add validity checks in continuous
  .get_voltage (bsc#1012628).
- HID: logitech-hidpp: add support for Logitech G Pro X Superlight
  2 (bsc#1012628).
- ALSA: hda: Replace numeric device IDs with constant values
  (bsc#1012628).
- ALSA: hda: Increase default bdl_pos_adj for Apollo Lake
  (bsc#1012628).
- HID: nvidia-shield: Add missing null pointer checks to LED
  initialization (bsc#1012628).
- nvmet-tcp: fix nvme tcp ida memory leak (bsc#1012628).
- usb: ucsi_acpi: Quirk to ack a connector change ack cmd
  (bsc#1012628).
- ALSA: usb-audio: Check presence of valid altsetting control
  (bsc#1012628).
- ASoC: sunxi: sun4i-spdif: Add support for Allwinner H616
  (bsc#1012628).
- ALSA: hda: cs35l41: Support additional ASUS Zenbook UX3402VA
  (bsc#1012628).
- ALSA: hda: cs35l41: Support ASUS Zenbook UM3402YAR
  (bsc#1012628).
- regulator (max5970): Fix IRQ handler (bsc#1012628).
- spi: sh-msiof: avoid integer overflow in constants
  (bsc#1012628).
- Input: xpad - add Lenovo Legion Go controllers (bsc#1012628).
- misc: open-dice: Fix spurious lockdep warning (bsc#1012628).
- netfilter: conntrack: check SCTP_CID_SHUTDOWN_ACK for vtag
  setting in sctp_new (bsc#1012628).
- drm/amdkfd: Use correct drm device for cgroup permission check
  (bsc#1012628).
- drm/amd/display: increased min_dcfclk_mhz and min_fclk_mhz
  (bsc#1012628).
- drm/amd/display: fix USB-C flag update after enc10 feature init
  (bsc#1012628).
- drm/amd/display: Fix DPSTREAM CLK on and off sequence
  (bsc#1012628).
- cifs: make sure that channel scaling is done only once
  (bsc#1012628).
- ASoC: wm_adsp: Don't overwrite fwf_name with the default
  (bsc#1012628).
- ALSA: usb-audio: Ignore clock selector errors for single
  connection (bsc#1012628).
- nvme-fc: do not wait in vain when unloading module
  (bsc#1012628).
- nvmet-fcloop: swap the list_add_tail arguments (bsc#1012628).
- nvmet-fc: release reference on target port (bsc#1012628).
- nvmet-fc: defer cleanup using RCU properly (bsc#1012628).
- nvmet-fc: free queue and assoc directly (bsc#1012628).
- nvmet-fc: hold reference on hostport match (bsc#1012628).
- nvmet-fc: abort command when there is no binding (bsc#1012628).
- nvmet-fc: avoid deadlock on delete association path
  (bsc#1012628).
- nvmet-fc: take ref count on tgtport before delete assoc
  (bsc#1012628).
- cifs: do not search for channel if server is terminating
  (bsc#1012628).
- smb: client: increase number of PDUs allowed in a compound
  request (bsc#1012628).
- ext4: correct the hole length returned by ext4_map_blocks()
  (bsc#1012628).
- Input: i8042 - add Fujitsu Lifebook U728 to i8042 quirk table
  (bsc#1012628).
- fs/ntfs3: Improve alternative boot processing (bsc#1012628).
- fs/ntfs3: Modified fix directory element type detection
  (bsc#1012628).
- fs/ntfs3: Improve ntfs_dir_count (bsc#1012628).
- fs/ntfs3: Correct hard links updating when dealing with DOS
  names (bsc#1012628).
- fs/ntfs3: Print warning while fixing hard links count
  (bsc#1012628).
- fs/ntfs3: Reduce stack usage (bsc#1012628).
- fs/ntfs3: Fix multithreaded stress test (bsc#1012628).
- fs/ntfs3: Fix detected field-spanning write (size 8) of single
  field "le->name" (bsc#1012628).
- fs/ntfs3: Correct use bh_read (bsc#1012628).
- fs/ntfs3: Add file_modified (bsc#1012628).
- fs/ntfs3: Drop suid and sgid bits as a part of fpunch
  (bsc#1012628).
- fs/ntfs3: Implement super_operations::shutdown (bsc#1012628).
- fs/ntfs3: ntfs3_forced_shutdown use int instead of bool
  (bsc#1012628).
- fs/ntfs3: Add and fix comments (bsc#1012628).
- fs/ntfs3: Add NULL ptr dereference checking at the end of
  attr_allocate_frame() (bsc#1012628).
- fs/ntfs3: Fix c/mtime typo (bsc#1012628).
- fs/ntfs3: Disable ATTR_LIST_ENTRY size check (bsc#1012628).
- fs/ntfs3: Use kvfree to free memory allocated by kvmalloc
  (bsc#1012628).
- fs/ntfs3: use non-movable memory for ntfs3 MFT buffer cache
  (bsc#1012628).
- fs/ntfs3: Prevent generic message "attempt to access beyond
  end of device" (bsc#1012628).
- fs/ntfs3: Use i_size_read and i_size_write (bsc#1012628).
- fs/ntfs3: Correct function is_rst_area_valid (bsc#1012628).
- fs/ntfs3: Fixed overflow check in mi_enum_attr() (bsc#1012628).
- fs/ntfs3: Update inode->i_size after success write into
  compressed file (bsc#1012628).
- fs/ntfs3: Fix oob in ntfs_listxattr (bsc#1012628).
- wifi: mac80211: set station RX-NSS on reconfig (bsc#1012628).
- wifi: mac80211: fix driver debugfs for vif type change
  (bsc#1012628).
- wifi: mac80211: initialize SMPS mode correctly (bsc#1012628).
- wifi: mac80211: adding missing drv_mgd_complete_tx() call
  (bsc#1012628).
- wifi: mac80211: accept broadcast probe responses on 6 GHz
  (bsc#1012628).
- wifi: iwlwifi: do not announce EPCS support (bsc#1012628).
- efi: runtime: Fix potential overflow of soft-reserved region
  size (bsc#1012628).
- efi: Don't add memblocks for soft-reserved memory (bsc#1012628).
- hwmon: (coretemp) Enlarge per package core count limit
  (bsc#1012628).
- drm/nouveau: nvkm_gsp_radix3_sg() should use nvkm_gsp_mem_ctor()
  (bsc#1012628).
- scsi: lpfc: Use unsigned type for num_sge (bsc#1012628).
- scsi: ufs: core: Fix shift issue in ufshcd_clear_cmd()
  (bsc#1012628).
- scsi: ufs: core: Remove the ufshcd_release() in
  ufshcd_err_handling_prepare() (bsc#1012628).
- LoongArch: Select ARCH_ENABLE_THP_MIGRATION instead of
  redefining it (bsc#1012628).
- LoongArch: Select HAVE_ARCH_SECCOMP to use the common SECCOMP
  menu (bsc#1012628).
- LoongArch: Change acpi_core_pic[NR_CPUS] to
  acpi_core_pic[MAX_CORE_PIC] (bsc#1012628).
- LoongArch: vDSO: Disable UBSAN instrumentation (bsc#1012628).
- accel/ivpu: Force snooping for MMU writes (bsc#1012628).
- accel/ivpu: Disable d3hot_delay on all NPU generations
  (bsc#1012628).
- accel/ivpu/40xx: Stop passing SKU boot parameters to FW
  (bsc#1012628).
- firewire: core: send bus reset promptly on gap count error
  (bsc#1012628).
- libceph: fail sparse-read if the data length doesn't match
  (bsc#1012628).
- ceph: always check dir caps asynchronously (bsc#1012628).
- drm/amdgpu: skip to program GFXDEC registers for suspend abort
  (bsc#1012628).
- drm/amdgpu: reset gpu for s3 suspend abort case (bsc#1012628).
- drm/amdgpu: Fix shared buff copy to user (bsc#1012628).
- drm/amdgpu: Fix HDP flush for VFs on nbio v7.9 (bsc#1012628).
- smb: client: set correct d_type for reparse points under DFS
  mounts (bsc#1012628).
- virtio-blk: Ensure no requests in virtqueues before deleting
  vqs (bsc#1012628).
- cifs: change tcon status when need_reconnect is set on it
  (bsc#1012628).
- cifs: handle cases where multiple sessions share connection
  (bsc#1012628).
- smb3: clarify mount warning (bsc#1012628).
- mptcp: add CurrEstab MIB counter support (bsc#1012628).
- mptcp: use mptcp_set_state (bsc#1012628).
- mptcp: fix more tx path fields initialization (bsc#1012628).
- mptcp: corner case locking for rx path fields initialization
  (bsc#1012628).
- drm/amd/display: Add dpia display mode validation logic
  (bsc#1012628).
- drm/amd/display: Request usb4 bw for mst streams (bsc#1012628).
- drm/amd/display: fixed integer types and null check locations
  (bsc#1012628).
- IB/hfi1: Fix sdma.h tx->num_descs off-by-one error
  (bsc#1012628).
- kunit: Add a macro to wrap a deferred action function
  (bsc#1012628).
- docs: Instruct LaTeX to cope with deeper nesting (bsc#1012628).
- LoongArch: Call early_init_fdt_scan_reserved_mem() earlier
  (bsc#1012628).
- LoongArch: Disable IRQ before init_fn() for nonboot CPUs
  (bsc#1012628).
- LoongArch: Update cpu_sibling_map when disabling nonboot CPUs
  (bsc#1012628).
- btrfs: defrag: avoid unnecessary defrag caused by incorrect
  extent size (bsc#1012628).
- drm/ttm: Fix an invalid freeing on already freed page in error
  path (bsc#1012628).
- drm/meson: Don't remove bridges which are created by other
  drivers (bsc#1012628).
- drm/buddy: Modify duplicate list_splice_tail call (bsc#1012628).
- drm/amd/display: Only allow dig mapping to pwrseq in new asic
  (bsc#1012628).
- drm/amd/display: adjust few initialization order in dm
  (bsc#1012628).
- s390/cio: fix invalid -EBUSY on ccw_device_start (bsc#1012628).
- ata: libata-core: Do not try to set sleeping devices to standby
  (bsc#1012628).
- ata: libata-core: Do not call ata_dev_power_set_standby()
  twice (bsc#1012628).
- fs/aio: Restrict kiocb_set_cancel_fn() to I/O submitted via
  libaio (bsc#1012628).
- lib/Kconfig.debug: TEST_IOV_ITER depends on MMU (bsc#1012628).
- dm-crypt: recheck the integrity tag after a failure
  (bsc#1012628).
- Revert "parisc: Only list existing CPUs in cpu_possible_mask"
  (bsc#1012628).
- dm-integrity: recheck the integrity tag after a failure
  (bsc#1012628).
- dm-crypt: don't modify the data when using authenticated
  encryption (bsc#1012628).
- dm-verity: recheck the hash after a failure (bsc#1012628).
- cxl/acpi: Fix load failures due to single window creation
  failure (bsc#1012628).
- cxl/pci: Skip to handle RAS errors if CXL.mem device is detached
  (bsc#1012628).
- cxl/pci: Fix disabling memory if DVSEC CXL Range does not
  match a CFMWS window (bsc#1012628).
- scsi: sd: usb_storage: uas: Access media prior to querying
  device properties (bsc#1012628).
- scsi: target: pscsi: Fix bio_put() for error case (bsc#1012628).
- scsi: core: Consult supported VPD page list prior to fetching
  page (bsc#1012628).
- selftests/mm: uffd-unit-test check if huge page size is 0
  (bsc#1012628).
- mm/swap: fix race when skipping swapcache (bsc#1012628).
- mm/damon/lru_sort: fix quota status loss due to online tunings
  (bsc#1012628).
- mm: memcontrol: clarify swapaccount=0 deprecation warning
  (bsc#1012628).
- mm/damon/core: check apply interval in damon_do_apply_schemes()
  (bsc#1012628).
- mm/damon/reclaim: fix quota stauts loss due to online tunings
  (bsc#1012628).
- mm/memblock: add MEMBLOCK_RSRV_NOINIT into flagname[] array
  (bsc#1012628).
- platform/x86: x86-android-tablets: Fix keyboard touchscreen
  on Lenovo Yogabook1 X90 (bsc#1012628).
- platform/x86: intel-vbtn: Stop calling "VBDL" from
  notify_handler (bsc#1012628).
- platform/x86: touchscreen_dmi: Allow partial (prefix) matches
  for ACPI names (bsc#1012628).
- cachefiles: fix memory leak in cachefiles_add_cache()
  (bsc#1012628).
- sparc: Fix undefined reference to fb_is_primary_device
  (bsc#1012628).
- md: Don't ignore suspended array in md_check_recovery()
  (bsc#1012628).
- md: Don't ignore read-only array in md_check_recovery()
  (bsc#1012628).
- md: Make sure md_do_sync() will set MD_RECOVERY_DONE
  (bsc#1012628).
- md: Don't register sync_thread for reshape directly
  (bsc#1012628).
- md: Don't suspend the array for interrupted reshape
  (bsc#1012628).
- md: Fix missing release of 'active_io' for flush (bsc#1012628).
- KVM: arm64: vgic-its: Test for valid IRQ in MOVALL handler
  (bsc#1012628).
- KVM: arm64: vgic-its: Test for valid IRQ in
  its_sync_lpi_pending_table() (bsc#1012628).
- accel/ivpu: Don't enable any tiles by default on VPU40xx
  (bsc#1012628).
- gtp: fix use-after-free and null-ptr-deref in
  gtp_genl_dump_pdp() (bsc#1012628).
- crypto: virtio/akcipher - Fix stack overflow on memcpy
  (bsc#1012628).
- irqchip/mbigen: Don't use bus_get_dev_root() to find the parent
  (bsc#1012628).
- irqchip/gic-v3-its: Do not assume vPE tables are preallocated
  (bsc#1012628).
- irqchip/sifive-plic: Enable interrupt if needed before EOI
  (bsc#1012628).
- PCI/MSI: Prevent MSI hardware interrupt number truncation
  (bsc#1012628).
- l2tp: pass correct message length to ip6_append_data
  (bsc#1012628).
- ARM: ep93xx: Add terminator to gpiod_lookup_table (bsc#1012628).
- dm-integrity, dm-verity: reduce stack usage for recheck
  (bsc#1012628).
- erofs: fix refcount on the metabuf used for inode lookup
  (bsc#1012628).
- Revert "usb: typec: tcpm: reset counter when enter into
  unattached state after try role" (bsc#1012628).
- serial: stm32: do not always set SER_RS485_RX_DURING_TX if
  RS485 is enabled (bsc#1012628).
- serial: amba-pl011: Fix DMA transmission in RS485 mode
  (bsc#1012628).
- usb: dwc3: gadget: Don't disconnect if not started
  (bsc#1012628).
- usb: cdnsp: blocked some cdns3 specific code (bsc#1012628).
- usb: cdnsp: fixed issue with incorrect detecting CDNSP family
  controllers (bsc#1012628).
- usb: cdns3: fixed memory use after free at
  cdns3_gadget_ep_disable() (bsc#1012628).
- usb: cdns3: fix memory double free when handle zero packet
  (bsc#1012628).
- usb: gadget: ncm: Avoid dropping datagrams of properly parsed
  NTBs (bsc#1012628).
- usb: gadget: omap_udc: fix USB gadget regression on Palm TE
  (bsc#1012628).
- usb: roles: fix NULL pointer issue when put module's reference
  (bsc#1012628).
- usb: roles: don't get/set_role() when usb_role_switch is
  unregistered (bsc#1012628).
- mptcp: add needs_id for userspace appending addr (bsc#1012628).
- mptcp: add needs_id for netlink appending addr (bsc#1012628).
- mptcp: fix lockless access in subflow ULP diag (bsc#1012628).
- mptcp: fix data races on local_id (bsc#1012628).
- mptcp: fix data races on remote_id (bsc#1012628).
- mptcp: fix duplicate subflow creation (bsc#1012628).
- selftests: mptcp: userspace_pm: unique subtest names
  (bsc#1012628).
- selftests: mptcp: simult flows: fix some subtest names
  (bsc#1012628).
- selftests: mptcp: pm nl: also list skipped tests (bsc#1012628).
- selftests: mptcp: pm nl: avoid error msg on older kernels
  (bsc#1012628).
- selftests: mptcp: diag: check CURRESTAB counters (bsc#1012628).
- selftests: mptcp: diag: fix bash warnings on older kernels
  (bsc#1012628).
- selftests: mptcp: diag: unique 'in use' subtest names
  (bsc#1012628).
- selftests: mptcp: diag: unique 'cestab' subtest names
  (bsc#1012628).
- ahci: Extend ASM1061 43-bit DMA address quirk to other ASM106x
  parts (bsc#1012628).
- smb3: add missing null server pointer check (bsc#1012628).
- drm/amd/display: Avoid enum conversion warning (bsc#1012628).
- drm/amd/display: Fix buffer overflow in
  'get_host_router_total_dp_tunnel_bw()' (bsc#1012628).
- Revert "drm/amd/display: increased min_dcfclk_mhz and
  min_fclk_mhz" (bsc#1012628).
- IB/hfi1: Fix a memleak in init_credit_return (bsc#1012628).
- RDMA/bnxt_re: Return error for SRQ resize (bsc#1012628).
- RDMA/bnxt_re: Add a missing check in bnxt_qplib_query_srq
  (bsc#1012628).
- IB/mlx5: Don't expose debugfs entries for RRoCE general
  parameters if not supported (bsc#1012628).
- arm64: dts: imx8mp: Disable UART4 by default on Data Modul
  i.MX8M Plus eDM SBC (bsc#1012628).
- RDMA/irdma: Fix KASAN issue with tasklet (bsc#1012628).
- RDMA/irdma: Validate max_send_wr and max_recv_wr (bsc#1012628).
- RDMA/irdma: Set the CQ read threshold for GEN 1 (bsc#1012628).
- RDMA/irdma: Add AE for too many RNRS (bsc#1012628).
- RDMA/srpt: Support specifying the srpt_service_guid parameter
  (bsc#1012628).
- arm64: dts: tqma8mpql: fix audio codec iov-supply (bsc#1012628).
- bus: imx-weim: fix valid range check (bsc#1012628).
- iommufd/iova_bitmap: Bounds check mapped::pages access
  (bsc#1012628).
- iommufd/iova_bitmap: Switch iova_bitmap::bitmap to an u8 array
  (bsc#1012628).
- iommufd/iova_bitmap: Handle recording beyond the mapped pages
  (bsc#1012628).
- iommufd/iova_bitmap: Consider page offset for the pages to be
  pinned (bsc#1012628).
- RDMA/qedr: Fix qedr_create_user_qp error flow (bsc#1012628).
- arm64: dts: rockchip: set num-cs property for spi on px30
  (bsc#1012628).
- arm64: dts: rockchip: Correct Indiedroid Nova GPIO Names
  (bsc#1012628).
- xsk: Add truesize to skb_add_rx_frag() (bsc#1012628).
- RDMA/srpt: fix function pointer cast warnings (bsc#1012628).
- bpf, scripts: Correct GPL license name (bsc#1012628).
- scsi: ufs: Uninitialized variable in ufshcd_devfreq_target()
  (bsc#1012628).
- scsi: smartpqi: Fix disable_managed_interrupts (bsc#1012628).
- scsi: jazz_esp: Only build if SCSI core is builtin
  (bsc#1012628).
- net: bridge: switchdev: Skip MDB replays of deferred events
  on offload (bsc#1012628).
- net: bridge: switchdev: Ensure deferred event delivery on
  unoffload (bsc#1012628).
- dccp/tcp: Unhash sk from ehash for tb2 alloc failure after
  check_estalblished() (bsc#1012628).
- net/sched: act_mirred: Create function tcf_mirred_to_dev and
  improve readability (bsc#1012628).
- net/sched: act_mirred: use the backlog for mirred ingress
  (bsc#1012628).
- net/sched: act_mirred: don't override retval if we already
  lost the skb (bsc#1012628).
- nouveau: fix function cast warnings (bsc#1012628).
- drm/nouveau/mmu/r535: uninitialized variable in r535_bar_new_()
  (bsc#1012628).
- x86/numa: Fix the address overlap check in numa_fill_memblks()
  (bsc#1012628).
- x86/numa: Fix the sort compare func used in numa_fill_memblks()
  (bsc#1012628).
- net: stmmac: Fix incorrect dereference in interrupt handlers
  (bsc#1012628).
- ipv4: properly combine dev_base_seq and ipv4.dev_addr_genid
  (bsc#1012628).
- ipv6: properly combine dev_base_seq and ipv6.dev_addr_genid
  (bsc#1012628).
- net: bcmasp: Indicate MAC is in charge of PHY PM (bsc#1012628).
- net: bcmasp: Sanity check is off by one (bsc#1012628).
- powerpc/pseries/iommu: DLPAR add doesn't completely initialize
  pci_controller (bsc#1012628).
- selftests: bonding: set active slave to primary eth1
  specifically (bsc#1012628).
- ata: ahci_ceva: fix error handling for Xilinx GT PHY support
  (bsc#1012628).
- bpf: Fix racing between bpf_timer_cancel_and_free and
  bpf_timer_cancel (bsc#1012628).
- platform/x86: think-lmi: Fix password opcode ordering for
  workstations (bsc#1012628).
- parisc: Fix stack unwinder (bsc#1012628).
- afs: Increase buffer size in afs_update_volume_status()
  (bsc#1012628).
- ipv6: sr: fix possible use-after-free and null-ptr-deref
  (bsc#1012628).
- devlink: fix possible use-after-free and memory leaks in
  devlink_init() (bsc#1012628).
- arp: Prevent overflow in arp_req_get() (bsc#1012628).
- KVM: PPC: Book3S HV: Fix L2 guest reboot failure due to empty
  'arch_compat' (bsc#1012628).
- gpiolib: Handle no pin_ranges in gpiochip_generic_config()
  (bsc#1012628).
- arm64/sme: Restore SME registers on exit from suspend
  (bsc#1012628).
- arm64/sme: Restore SMCR_EL1.EZT0 on exit from suspend
  (bsc#1012628).
- platform/x86: thinkpad_acpi: Only update profile if successfully
  converted (bsc#1012628).
- drm/i915/tv: Fix TV mode (bsc#1012628).
- iommu/vt-d: Update iotlb in nested domain attach (bsc#1012628).
- iommu/vt-d: Track nested domains in parent (bsc#1012628).
- iommu/vt-d: Remove domain parameter for
  intel_pasid_setup_dirty_tracking() (bsc#1012628).
- iommu/vt-d: Wrap the dirty tracking loop to be a helper
  (bsc#1012628).
- iommu/vt-d: Add missing dirty tracking set for parent domain
  (bsc#1012628).
- iommu/vt-d: Set SSADE when attaching to a parent with dirty
  tracking (bsc#1012628).
- octeontx2-af: Consider the action set by PF (bsc#1012628).
- net: implement lockless setsockopt(SO_PEEK_OFF) (bsc#1012628).
- net: ipa: don't overrun IPA suspend interrupt registers
  (bsc#1012628).
- iommufd: Reject non-zero data_type if no data_len is provided
  (bsc#1012628).
- s390: use the correct count for __iowrite64_copy()
  (bsc#1012628).
- bpf, sockmap: Fix NULL pointer dereference in
  sk_psock_verdict_data_ready() (bsc#1012628).
- cache: ax45mp_cache: Align end size to cache boundary in
  ax45mp_dma_cache_wback() (bsc#1012628).
- hwmon: (nct6775) Fix access to temperature configuration
  registers (bsc#1012628).
- tls: break out of main loop when PEEK gets a non-data record
  (bsc#1012628).
- tls: stop recv() if initial process_rx_list gave us non-DATA
  (bsc#1012628).
- tls: don't skip over different type records from the rx_list
  (bsc#1012628).
- netfilter: nf_tables: set dormant flag on hook register failure
  (bsc#1012628).
- netfilter: nft_flow_offload: reset dst in route object after
  setting up flow (bsc#1012628).
- netfilter: nft_flow_offload: release dst in case direct xmit
  path is used (bsc#1012628).
- netfilter: nf_tables: register hooks last when adding new
  chain/flowtable (bsc#1012628).
- netfilter: nf_tables: use kzalloc for hook allocation
  (bsc#1012628).
- net: mctp: put sock on tag allocation failure (bsc#1012628).
- tools: ynl: make sure we always pass yarg to mnl_cb_run
  (bsc#1012628).
- tools: ynl: don't leak mcast_groups on init error (bsc#1012628).
- devlink: fix port dump cmd type (bsc#1012628).
- net/sched: flower: Add lock protection when remove filter handle
  (bsc#1012628).
- net: sparx5: Add spinlock for frame transmission from CPU
  (bsc#1012628).
- phonet: take correct lock to peek at the RX queue (bsc#1012628).
- phonet/pep: fix racy skb_queue_empty() use (bsc#1012628).
- Fix write to cloned skb in ipv6_hop_ioam() (bsc#1012628).
- net: phy: realtek: Fix rtl8211f_config_init() for
  RTL8211F(D)(I)-VD-CG PHY (bsc#1012628).
- drm/syncobj: call drm_syncobj_fence_add_wait when WAIT_AVAILABLE
  flag is set (bsc#1012628).
- iommu: Add mm_get_enqcmd_pasid() helper function (bsc#1012628).
- iommu/arm-smmu-v3: Do not use GFP_KERNEL under as spinlock
  (bsc#1012628).
- drm/syncobj: handle NULL fence in syncobj_eventfd_entry_func
  (bsc#1012628).
- selftests/iommu: fix the config fragment (bsc#1012628).
- drm/amd/display: Fix potential null pointer dereference in
  dc_dmub_srv (bsc#1012628).
- drm/amd/display: Fix memory leak in dm_sw_fini() (bsc#1012628).
- drm/amd/display: fix null-pointer dereference on edid reading
  (bsc#1012628).
- i2c: imx: when being a target, mark the last read as processed
  (bsc#1012628).
- mm: zswap: fix missing folio cleanup in writeback race path
  (bsc#1012628).
- selftests: mptcp: join: stop transfer when check is done
  (part 1) (bsc#1012628).
- mm/zswap: invalidate duplicate entry when !zswap_enabled
  (bsc#1012628).
- selftests: mptcp: join: stop transfer when check is done
  (part 2) (bsc#1012628).
- selftests: mptcp: add mptcp_lib_get_counter (bsc#1012628).
- Rename to
  patches.kernel.org/6.7.7-001-drm-amd-Stop-evicting-resources-on-APUs-in-susp.patch.
- Rename to
  patches.kernel.org/6.7.7-142-x86-bugs-Add-asm-helpers-for-executing-VERW.patch.
- Rename to
  patches.kernel.org/6.7.7-153-drm-amdgpu-Fix-the-runtime-resume-failure-issue.patch.
- commit e08e1d2
* Wed Feb 28 2024 jslaby@suse.cz
- fs/ntfs3: fix build without CONFIG_NTFS3_LZX_XPRESS (git-fixes).
- commit fab87b1
* Wed Feb 28 2024 jslaby@suse.cz
- series.conf: move patches.suse/nvmet-tcp-remove-boilerplate-code.patch to sorted section
- commit a47b18d
* Tue Feb 27 2024 tiwai@suse.de
- Update ath11k hibernation patches for v2 series (bsc#1207948)
- commit a6d02cf
* Tue Feb 27 2024 tiwai@suse.de
- Update ath11k hibernation patches for v2 series (bsc#1207948)
- commit 6668923
* Tue Feb 27 2024 jslaby@suse.cz
- KVM/VMX: Move VERW closer to VMentry for MDS mitigation
  (git-fixes).
- KVM/VMX: Use BT+JNC, i.e. EFLAGS.CF to select VMRESUME
  vs. VMLAUNCH (git-fixes).
- x86/bugs: Use ALTERNATIVE() instead of mds_user_clear static
  key (git-fixes).
- x86/entry_32: Add VERW just before userspace transition
  (git-fixes).
- x86/entry_64: Add VERW just before userspace transition
  (git-fixes).
- x86/bugs: Add asm helpers for executing VERW (git-fixes).
- commit ac736e5
* Mon Feb 26 2024 tiwai@suse.de
- wifi: ath11k: support hibernation (bsc#1207948).
- net: qrtr: support suspend/hibernation (bsc#1207948).
- bus: mhi: host: add mhi_power_down_no_destroy() (bsc#1207948).
- commit 4021880
* Mon Feb 26 2024 tiwai@suse.de
- wifi: ath11k: thermal: don't try to register multiple times
  (bsc#1207948).
- wifi: ath11k: fix warning on DMA ring capabilities event
  (bsc#1207948).
- wifi: ath11k: do not dump SRNG statistics during resume
  (bsc#1207948).
- wifi: ath11k: remove MHI LOOPBACK channels (bsc#1207948).
- wifi: ath11k: rearrange IRQ enable/disable in reset path
  (bsc#1207948).
- commit 14ad705
* Mon Feb 26 2024 tiwai@suse.de
- wifi: ath11k: support hibernation (bsc#1207948).
- net: qrtr: support suspend/hibernation (bsc#1207948).
- bus: mhi: host: add mhi_power_down_no_destroy() (bsc#1207948).
- commit 1c8bab3
* Mon Feb 26 2024 tiwai@suse.de
- wifi: ath11k: thermal: don't try to register multiple times
  (bsc#1207948).
- wifi: ath11k: fix warning on DMA ring capabilities event
  (bsc#1207948).
- wifi: ath11k: do not dump SRNG statistics during resume
  (bsc#1207948).
- wifi: ath11k: remove MHI LOOPBACK channels (bsc#1207948).
- wifi: ath11k: rearrange IRQ enable/disable in reset path
  (bsc#1207948).
- commit 1ef5076
* Mon Feb 26 2024 tiwai@suse.de
- Drop ath11k hibernation patches for refreshing to the new patch set (bsc#1207948)
- commit 6620772
* Mon Feb 26 2024 jslaby@suse.cz
- Update
  patches.suse/mm-mmap-fix-vma_merge-case-7-with-vma_ops-close.patch
  (bsc#1217313).
  Fix reference.
- commit d8ba004
* Mon Feb 26 2024 mkubecek@suse.cz
- net: ethernet: adi: move PHYLIB from vendor to driver symbol.
  Fix config dependencies.
- restore config options from before 6.8-rc6:
  - NET_VENDOR_ADI=y
  - ADIN1110=m
- commit 2aa849d
* Mon Feb 26 2024 jslaby@suse.cz
- drm/amdgpu: Fix the runtime resume failure issue
  (https://gitlab.freedesktop.org/drm/amd/-/issues/3132).
- commit d6edcef
* Mon Feb 26 2024 jslaby@suse.cz
- drm/amd: Stop evicting resources on APUs in suspend
  (https://gitlab.freedesktop.org/drm/amd/-/issues/3132).
- commit ce46963
* Mon Feb 26 2024 mkubecek@suse.cz
- Update to 6.8-rc6
- update configs
  - DRM_NOUVEAU_GSP_DEFAULT=n
  - disable NET_VENDOR_ADI (mainline commit a9f80df4f514 would force many
    other config options to "Y")
- commit 0883557
* Fri Feb 23 2024 jslaby@suse.cz
- Linux 6.7.6 (bsc#1012628).
- work around gcc bugs with 'asm goto' with outputs (bsc#1012628).
- update workarounds for gcc "asm goto" issue (bsc#1012628).
- mm: mmap: map MAP_STACK to VM_NOHUGEPAGE (bsc#1012628).
- btrfs: forbid creating subvol qgroups (bsc#1012628).
- btrfs: do not ASSERT() if the newly created subvolume already
  got read (bsc#1012628).
- btrfs: forbid deleting live subvol qgroup (bsc#1012628).
- btrfs: send: return EOPNOTSUPP on unknown flags (bsc#1012628).
- btrfs: don't reserve space for checksums when writing to nocow
  files (bsc#1012628).
- btrfs: reject encoded write if inode has nodatasum flag set
  (bsc#1012628).
- btrfs: don't drop extent_map for free space inode on write error
  (bsc#1012628).
- driver core: Fix device_link_flag_is_sync_state_only()
  (bsc#1012628).
- kselftest: dt: Stop relying on dirname to improve performance
  (bsc#1012628).
- selftests/landlock: Fix net_test build with old libc
  (bsc#1012628).
- selftests/landlock: Fix fs_test build with old libc
  (bsc#1012628).
- of: unittest: Fix compile in the non-dynamic case (bsc#1012628).
- drm/msm/gem: Fix double resv lock aquire (bsc#1012628).
- selftests/landlock: Fix capability for net_test (bsc#1012628).
- ASoC: Intel: avs: Fix pci_probe() error path (bsc#1012628).
- spi: imx: fix the burst length at DMA mode and CPU mode
  (bsc#1012628).
- ASoC: Intel: avs: Fix dynamic port assignment when TDM is set
  (bsc#1012628).
- wifi: iwlwifi: clear link_id in time_event (bsc#1012628).
- wifi: iwlwifi: Fix some error codes (bsc#1012628).
- wifi: iwlwifi: uninitialized variable in
  iwl_acpi_get_ppag_table() (bsc#1012628).
- ASoC: SOF: ipc3-topology: Fix pipeline tear down logic
  (bsc#1012628).
- dpll: fix possible deadlock during netlink dump operation
  (bsc#1012628).
- net/mlx5: DPLL, Fix possible use after free after delayed work
  timer triggers (bsc#1012628).
- net/handshake: Fix handshake_req_destroy_test1 (bsc#1012628).
- bonding: do not report NETDEV_XDP_ACT_XSK_ZEROCOPY
  (bsc#1012628).
- devlink: Fix command annotation documentation (bsc#1012628).
- of: property: Improve finding the consumer of a remote-endpoint
  property (bsc#1012628).
- of: property: Improve finding the supplier of a remote-endpoint
  property (bsc#1012628).
- ALSA: hda/cs35l56: select intended config FW_CS_DSP
  (bsc#1012628).
- perf: CXL: fix mismatched cpmu event opcode (bsc#1012628).
- selftests/net: convert test_bridge_backup_port.sh to run it
  in unique namespace (bsc#1012628).
- selftests: net: Fix bridge backup port test flakiness
  (bsc#1012628).
- selftests: forwarding: Fix layer 2 miss test flakiness
  (bsc#1012628).
- selftests: forwarding: Fix bridge MDB test flakiness
  (bsc#1012628).
- selftests: forwarding: Suppress grep warnings (bsc#1012628).
- selftests: forwarding: Fix bridge locked port test flakiness
  (bsc#1012628).
- net: openvswitch: limit the number of recursions from action
  sets (bsc#1012628).
- lan966x: Fix crash when adding interface under a lag
  (bsc#1012628).
- net: tls: factor out tls_*crypt_async_wait() (bsc#1012628).
- tls: fix race between async notify and socket close
  (bsc#1012628).
- tls: fix race between tx work scheduling and socket close
  (bsc#1012628).
- net: tls: handle backlogging of crypto requests (bsc#1012628).
- net: tls: fix use-after-free with partial reads and async
  decrypt (bsc#1012628).
- net: tls: fix returned read length with async decrypt
  (bsc#1012628).
- spi: ppc4xx: Drop write-only variable (bsc#1012628).
- ASoC: rt5645: Fix deadlock in rt5645_jack_detect_work()
  (bsc#1012628).
- drm/i915/dsc: Fix the macro that calculates DSCC_/DSCA_ PPS
  reg address (bsc#1012628).
- net: sysfs: Fix /sys/class/net/<iface> path for statistics
  (bsc#1012628).
- nouveau/svm: fix kvcalloc() argument order (bsc#1012628).
- MIPS: Add 'memory' clobber to csum_ipv6_magic() inline assembler
  (bsc#1012628).
- ptrace: Introduce exception_ip arch hook (bsc#1012628).
- mm/memory: Use exception ip to search exception tables
  (bsc#1012628).
- i40e: Do not allow untrusted VF to remove administratively
  set MAC (bsc#1012628).
- i40e: Fix waiting for queues of all VSIs to be disabled
  (bsc#1012628).
- mm: thp_get_unmapped_area must honour topdown preference
  (bsc#1012628).
- userfaultfd: fix mmap_changing checking in mfill_atomic_hugetlb
  (bsc#1012628).
- selftests/mm: ksm_tests should only MADV_HUGEPAGE valid memory
  (bsc#1012628).
- scs: add CONFIG_MMU dependency for vfree_atomic() (bsc#1012628).
- tracing/trigger: Fix to return error if failed to alloc snapshot
  (bsc#1012628).
- fs/hugetlbfs/inode.c: mm/memory-failure.c: fix hugetlbfs
  hwpoison handling (bsc#1012628).
- selftests/mm: switch to bash from sh (bsc#1012628).
- mm/writeback: fix possible divide-by-zero in wb_dirty_limits(),
  again (bsc#1012628).
- selftests/mm: Update va_high_addr_switch.sh to check CPU for
  la57 flag (bsc#1012628).
- selftests: mm: fix map_hugetlb failure on 64K page size systems
  (bsc#1012628).
- scsi: storvsc: Fix ring buffer size calculation (bsc#1012628).
- nouveau: offload fence uevents work to workqueue (bsc#1012628).
- dm-crypt, dm-verity: disable tasklets (bsc#1012628).
- ASoC: amd: yc: Add DMI quirk for MSI Bravo 15 C7VF
  (bsc#1012628).
- parisc: Prevent hung tasks when printing inventory on serial
  console (bsc#1012628).
- ALSA: hda/realtek: Fix the external mic not being recognised
  for Acer Swift 1 SF114-32 (bsc#1012628).
- ALSA: hda/realtek: Enable Mute LED on HP Laptop 14-fq0xxx
  (bsc#1012628).
- HID: bpf: remove double fdget() (bsc#1012628).
- HID: bpf: actually free hdev memory after attaching a HID-BPF
  program (bsc#1012628).
- HID: i2c-hid-of: fix NULL-deref on failed power up
  (bsc#1012628).
- HID: wacom: generic: Avoid reporting a serial of '0' to
  userspace (bsc#1012628).
- HID: wacom: Do not register input devices until after
  hid_hw_start (bsc#1012628).
- iio: hid-sensor-als: Return 0 for
  HID_USAGE_SENSOR_TIME_TIMESTAMP (bsc#1012628).
- usb: ucsi: Add missing ppm_lock (bsc#1012628).
- usb: ulpi: Fix debugfs directory leak (bsc#1012628).
- usb: ucsi_acpi: Fix command completion handling (bsc#1012628).
- USB: hub: check for alternate port before enabling
  A_ALT_HNP_SUPPORT (bsc#1012628).
- usb: f_mass_storage: forbid async queue when shutdown happen
  (bsc#1012628).
- usb: chipidea: core: handle power lost in workqueue
  (bsc#1012628).
- usb: core: Prevent null pointer dereference in
  update_port_device_state (bsc#1012628).
- usb: dwc3: gadget: Fix NULL pointer dereference in
  dwc3_gadget_suspend (bsc#1012628).
- interconnect: qcom: sc8180x: Mark CO0 BCM keepalive
  (bsc#1012628).
- interconnect: qcom: sm8550: Enable sync_state (bsc#1012628).
- media: ir_toy: fix a memleak in irtoy_tx (bsc#1012628).
- driver core: fw_devlink: Improve detection of overlapping cycles
  (bsc#1012628).
- powerpc/pseries/iommu: Fix iommu initialisation during DLPAR
  add (bsc#1012628).
- powerpc/6xx: set High BAT Enable flag on G2_LE cores
  (bsc#1012628).
- powerpc/kasan: Fix addr error caused by page alignment
  (bsc#1012628).
- Revert "kobject: Remove redundant checks for whether ktype is
  NULL" (bsc#1012628).
- PCI: Fix active state requirement in PME polling (bsc#1012628).
- iio: adc: ad4130: zero-initialize clock init data (bsc#1012628).
- iio: adc: ad4130: only set GPIO_CTRL if pin is unused
  (bsc#1012628).
- cifs: fix underflow in parse_server_interfaces() (bsc#1012628).
- i2c: qcom-geni: Correct I2C TRE sequence (bsc#1012628).
- irqchip/loongson-eiointc: Use correct struct type in
  eiointc_domain_alloc() (bsc#1012628).
- irqchip/gic-v3-its: Handle non-coherent GICv4 redistributors
  (bsc#1012628).
- powerpc/kasan: Limit KASAN thread size increase to 32KB
  (bsc#1012628).
- powerpc/iommu: Fix the missing iommu_group_put() during platform
  domain attach (bsc#1012628).
- i2c: pasemi: split driver into two separate modules
  (bsc#1012628).
- i2c: i801: Fix block process call transactions (bsc#1012628).
- modpost: trim leading spaces when processing source files list
  (bsc#1012628).
- kallsyms: ignore ARMv4 thunks along with others (bsc#1012628).
- mptcp: fix data re-injection from stale subflow (bsc#1012628).
- selftests: mptcp: add missing kconfig for NF Filter
  (bsc#1012628).
- selftests: mptcp: add missing kconfig for NF Filter in v6
  (bsc#1012628).
- selftests: mptcp: add missing kconfig for NF Mangle
  (bsc#1012628).
- selftests: mptcp: increase timeout to 30 min (bsc#1012628).
- selftests: mptcp: allow changing subtests prefix (bsc#1012628).
- selftests: mptcp: add mptcp_lib_kill_wait (bsc#1012628).
- mptcp: drop the push_pending field (bsc#1012628).
- mptcp: fix rcv space initialization (bsc#1012628).
- mptcp: check addrs list in userspace_pm_get_local_id
  (bsc#1012628).
- mptcp: really cope with fastopen race (bsc#1012628).
- Revert "powerpc/pseries/iommu: Fix iommu initialisation during
  DLPAR add" (bsc#1012628).
- media: Revert "media: rkisp1: Drop IRQF_SHARED" (bsc#1012628).
- scsi: Revert "scsi: fcoe: Fix potential deadlock on
  &fip->ctlr_lock" (bsc#1012628).
- Revert "drm/amd: flush any delayed gfxoff on suspend entry"
  (bsc#1012628).
- Revert "drm/msm/gpu: Push gpu lock down past runpm"
  (bsc#1012628).
- connector/cn_proc: revert "connector: Fix
  proc_event_num_listeners count not cleared" (bsc#1012628).
- spi: omap2-mcspi: Revert FIFO support without DMA (bsc#1012628).
- drm/virtio: Set segment size for virtio_gpu device
  (bsc#1012628).
- drm/amdgpu: Reset IH OVERFLOW_CLEAR bit (bsc#1012628).
- drm/amd: Don't init MEC2 firmware when it fails to load
  (bsc#1012628).
- drm/amd/display: fix incorrect mpc_combine array size
  (bsc#1012628).
- drm/amd/display: Fix dcn35 8k30 Underflow/Corruption Issue
  (bsc#1012628).
- lsm: fix default return value of the socket_getpeersec_*()
  hooks (bsc#1012628).
- lsm: fix the logic in security_inode_getsecctx() (bsc#1012628).
- firewire: core: correct documentation of fw_csr_string()
  kernel API (bsc#1012628).
- ALSA: hda/realtek: Apply headset jack quirk for non-bass alc287
  thinkpads (bsc#1012628).
- kbuild: Fix changing ELF file type for output of gen_btf for
  big endian (bsc#1012628).
- nfc: nci: free rx_data_reassembly skb on NCI device cleanup
  (bsc#1012628).
- net: hsr: remove WARN_ONCE() in send_hsr_supervision_frame()
  (bsc#1012628).
- net: stmmac: do not clear TBS enable bit on link up/down
  (bsc#1012628).
- parisc: Fix random data corruption from exception handler
  (bsc#1012628).
- parisc: BTLB: Fix crash when setting up BTLB at CPU bringup
  (bsc#1012628).
- xen-netback: properly sync TX responses (bsc#1012628).
- um: Fix adding '-no-pie' for clang (bsc#1012628).
- modpost: Add '.ltext' and '.ltext.*' to TEXT_SECTIONS
  (bsc#1012628).
- ALSA: hda/realtek: Enable headset mic on Vaio VJFE-ADL
  (bsc#1012628).
- ALSA: hda/realtek - Add speaker pin verbtable for Dell dual
  speaker platform (bsc#1012628).
- ASoC: codecs: wcd938x: handle deferred probe (bsc#1012628).
- ALSA: hda/cs8409: Suppress vmaster control for Dolphin models
  (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP ZBook Power
  (bsc#1012628).
- binder: signal epoll threads of self-work (bsc#1012628).
- misc: fastrpc: Mark all sessions as invalid in cb_remove
  (bsc#1012628).
- ext4: fix double-free of blocks due to wrong extents moved_len
  (bsc#1012628).
- ext4: avoid bb_free and bb_fragments inconsistency in
  mb_free_blocks() (bsc#1012628).
- tracing/timerlat: Move hrtimer_init to timerlat_fd open()
  (bsc#1012628).
- tracing: Fix wasted memory in saved_cmdlines logic
  (bsc#1012628).
- tracing/synthetic: Fix trace_string() return value
  (bsc#1012628).
- tracing/probes: Fix to show a parse error for bad type for $comm
  (bsc#1012628).
- tracing/probes: Fix to set arg size and fmt after setting type
  from BTF (bsc#1012628).
- tracing/probes: Fix to search structure fields correctly
  (bsc#1012628).
- Revert "workqueue: Override implicit ordered attribute in
  workqueue_apply_unbound_cpumask()" (bsc#1012628).
- staging: iio: ad5933: fix type mismatch regression
  (bsc#1012628).
- iio: magnetometer: rm3100: add boundary check for the value
  read from RM3100_REG_TMRC (bsc#1012628).
- iio: core: fix memleak in iio_device_register_sysfs
  (bsc#1012628).
- iio: commom: st_sensors: ensure proper DMA alignment
  (bsc#1012628).
- iio: accel: bma400: Fix a compilation problem (bsc#1012628).
- iio: adc: ad_sigma_delta: ensure proper DMA alignment
  (bsc#1012628).
- iio: imu: adis: ensure proper DMA alignment (bsc#1012628).
- iio: imu: bno055: serdev requires REGMAP (bsc#1012628).
- iio: pressure: bmp280: Add missing bmp085 to SPI id table
  (bsc#1012628).
- pmdomain: mediatek: fix race conditions with genpd
  (bsc#1012628).
- media: rc: bpf attach/detach requires write permission
  (bsc#1012628).
- eventfs: Remove "lookup" parameter from create_dir/file_dentry()
  (bsc#1012628).
- eventfs: Stop using dcache_readdir() for getdents()
  (bsc#1012628).
- eventfs: Have eventfs_iterate() stop immediately if ei->is_freed
  is set (bsc#1012628).
- eventfs: Do ctx->pos update for all iterations in
  eventfs_iterate() (bsc#1012628).
- eventfs: Read ei->entries before ei->children in
  eventfs_iterate() (bsc#1012628).
- eventfs: Shortcut eventfs_iterate() by skipping entries already
  read (bsc#1012628).
- eventfs: Have the inodes all for files and directories all be
  the same (bsc#1012628).
- eventfs: Do not create dentries nor inodes in iterate_shared
  (bsc#1012628).
- eventfs: Use kcalloc() instead of kzalloc() (bsc#1012628).
- eventfs: Save directory inodes in the eventfs_inode structure
  (bsc#1012628).
- tracefs: Zero out the tracefs_inode when allocating it
  (bsc#1012628).
- eventfs: Initialize the tracefs inode properly (bsc#1012628).
- tracefs: Avoid using the ei->dentry pointer unnecessarily
  (bsc#1012628).
- tracefs: dentry lookup crapectomy (bsc#1012628).
- eventfs: Remove unused d_parent pointer field (bsc#1012628).
- eventfs: Clean up dentry ops and add revalidate function
  (bsc#1012628).
- eventfs: Get rid of dentry pointers without refcounts
  (bsc#1012628).
- eventfs: Warn if an eventfs_inode is freed without is_freed
  being set (bsc#1012628).
- eventfs: Restructure eventfs_inode structure to be more
  condensed (bsc#1012628).
- eventfs: Remove fsnotify*() functions from lookup()
  (bsc#1012628).
- eventfs: Keep all directory links at 1 (bsc#1012628).
- getrusage: move thread_group_cputime_adjusted() outside of
  lock_task_sighand() (bsc#1012628).
- getrusage: use sig->stats_lock rather than lock_task_sighand()
  (bsc#1012628).
- ksmbd: free aux buffer if ksmbd_iov_pin_rsp_read fails
  (bsc#1012628).
- drm/nouveau: fix several DMA buffer leaks (bsc#1012628).
- drm/buddy: Fix alloc_range() error handling code (bsc#1012628).
- drm/msm: Wire up tlb ops (bsc#1012628).
- drm/amd/display: Add align done check (bsc#1012628).
- drm/i915/dp: Limit SST link rate to <=8.1Gbps (bsc#1012628).
- drm/prime: Support page array >= 4GB (bsc#1012628).
- drm/amdgpu/soc21: update VCN 4 max HEVC encoding resolution
  (bsc#1012628).
- drm/amd/display: Fix MST Null Ptr for RV (bsc#1012628).
- drm/amd/display: Increase frame-larger-than for all
  display_mode_vba files (bsc#1012628).
- drm/amd/display: Fix array-index-out-of-bounds in dcn35_clkmgr
  (bsc#1012628).
- drm/amd/display: Preserve original aspect ratio in create stream
  (bsc#1012628).
- drm/amdgpu: Avoid fetching VRAM vendor info (bsc#1012628).
- hv_netvsc: Fix race condition between netvsc_probe and
  netvsc_remove (bsc#1012628).
- ring-buffer: Clean ring_buffer_poll_wait() error return
  (bsc#1012628).
- net: dsa: mv88e6xxx: Fix failed probe due to unsupported C45
  reads (bsc#1012628).
- nfp: flower: add hardware offload check for post ct entry
  (bsc#1012628).
- nfp: flower: fix hardware offload for the transfer layer port
  (bsc#1012628).
- serial: core: Fix atomicity violation in uart_tiocmget
  (bsc#1012628).
- serial: max310x: set default value when reading clock ready bit
  (bsc#1012628).
- serial: max310x: improve crystal stable clock detection
  (bsc#1012628).
- serial: max310x: fail probe if clock crystal is unstable
  (bsc#1012628).
- serial: max310x: prevent infinite while() loop in port startup
  (bsc#1012628).
- ftrace: Fix DIRECT_CALLS to use SAVE_REGS by default
  (bsc#1012628).
- powerpc/64: Set task pt_regs->link to the LR value on scv entry
  (bsc#1012628).
- powerpc/cputable: Add missing PPC_FEATURE_BOOKE on PPC64 Book-E
  (bsc#1012628).
- powerpc/pseries: fix accuracy of stolen time (bsc#1012628).
- serial: core: introduce uart_port_tx_flags() (bsc#1012628).
- serial: mxs-auart: fix tx (bsc#1012628).
- x86/Kconfig: Transmeta Crusoe is CPU family 5, not 6
  (bsc#1012628).
- x86/fpu: Stop relying on userspace for info to fault in xsave
  buffer (bsc#1012628).
- KVM: x86: make KVM_REQ_NMI request iff NMI pending for vcpu
  (bsc#1012628).
- KVM: x86/pmu: Fix type length error when reading
  pmu->fixed_ctr_ctrl (bsc#1012628).
- x86/mm/ident_map: Use gbpages only where full GB page should
  be mapped (bsc#1012628).
- io_uring/net: fix multishot accept overflow handling
  (bsc#1012628).
- mmc: slot-gpio: Allow non-sleeping GPIO ro (bsc#1012628).
- gpiolib: add gpio_device_get_base() stub for !GPIOLIB
  (bsc#1012628).
- gpiolib: add gpiod_to_gpio_device() stub for !GPIOLIB
  (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LED For HP mt645
  (bsc#1012628).
- ALSA: hda/conexant: Add quirk for SWS JS201D (bsc#1012628).
- ALSA: hda/realtek: add IDs for Dell dual spk platform
  (bsc#1012628).
- nilfs2: fix data corruption in dsync block recovery for small
  block sizes (bsc#1012628).
- nilfs2: fix hang in nilfs_lookup_dirty_data_buffers()
  (bsc#1012628).
- crypto: ccp - Fix null pointer dereference in
  __sev_platform_shutdown_locked (bsc#1012628).
- crypto: algif_hash - Remove bogus SGL free on zero-length
  error path (bsc#1012628).
- nfp: use correct macro for LengthSelect in BAR config
  (bsc#1012628).
- nfp: enable NETDEV_XDP_ACT_REDIRECT feature flag (bsc#1012628).
- nfp: flower: prevent re-adding mac index for bonded port
  (bsc#1012628).
- wifi: iwlwifi: fix double-free bug (bsc#1012628).
- wifi: cfg80211: fix wiphy delayed work queueing (bsc#1012628).
- wifi: mac80211: reload info pointer in ieee80211_tx_dequeue()
  (bsc#1012628).
- wifi: iwlwifi: mvm: fix a crash when we run out of stations
  (bsc#1012628).
- PCI: dwc: Fix a 64bit bug in dw_pcie_ep_raise_msix_irq()
  (bsc#1012628).
- irqchip/irq-brcmstb-l2: Add write memory barrier before exit
  (bsc#1012628).
- irqchip/gic-v3-its: Restore quirk probing for ACPI-based systems
  (bsc#1012628).
- irqchip/gic-v3-its: Fix GICv4.1 VPE affinity update
  (bsc#1012628).
- thunderbolt: Fix setting the CNS bit in ROUTER_CS_5
  (bsc#1012628).
- smb: client: set correct id, uid and cruid for multiuser
  automounts (bsc#1012628).
- smb: Fix regression in writes when non-standard maximum write
  size negotiated (bsc#1012628).
- KVM: s390: vsie: fix race during shadow creation (bsc#1012628).
- KVM: arm64: Fix circular locking dependency (bsc#1012628).
- zonefs: Improve error handling (bsc#1012628).
- mmc: sdhci-pci-o2micro: Fix a warm reboot issue that disk
  can't be detected by BIOS (bsc#1012628).
- arm64/signal: Don't assume that TIF_SVE means we saved SVE state
  (bsc#1012628).
- arm64: Subscribe Microsoft Azure Cobalt 100 to ARM Neoverse
  N2 errata (bsc#1012628).
- ASoC: SOF: IPC3: fix message bounds on ipc ops (bsc#1012628).
- ASoC: tas2781: add module parameter to tascodec_init()
  (bsc#1012628).
- ASoC: amd: yc: Add DMI quirk for Lenovo Ideapad Pro 5 16ARP8
  (bsc#1012628).
- tools/rv: Fix curr_reactor uninitialized variable (bsc#1012628).
- tools/rv: Fix Makefile compiler options for clang (bsc#1012628).
- tools/rtla: Remove unused sched_getattr() function
  (bsc#1012628).
- tools/rtla: Replace setting prio with nice for SCHED_OTHER
  (bsc#1012628).
- tools/rtla: Fix clang warning about mount_point var size
  (bsc#1012628).
- tools/rtla: Exit with EXIT_SUCCESS when help is invoked
  (bsc#1012628).
- tools/rtla: Fix uninitialized bucket/data->bucket_size warning
  (bsc#1012628).
- tools/rtla: Fix Makefile compiler options for clang
  (bsc#1012628).
- fs: relax mount_setattr() permission checks (bsc#1012628).
- net: ethernet: ti: cpsw: enable mac_managed_pm to fix mdio
  (bsc#1012628).
- s390/qeth: Fix potential loss of L3-IP@ in case of network
  issues (bsc#1012628).
- mm/damon/sysfs-schemes: fix wrong DAMOS tried regions update
  timeout setup (bsc#1012628).
- net: ethernet: ti: cpsw_new: enable mac_managed_pm to fix mdio
  (bsc#1012628).
- pmdomain: renesas: r8a77980-sysc: CR7 must be always on
  (bsc#1012628).
- riscv/efistub: Ensure GP-relative addressing is not used
  (bsc#1012628).
- net: stmmac: protect updates of 64-bit statistics counters
  (bsc#1012628).
- hv_netvsc: Register VF in netvsc_probe if NET_DEVICE_REGISTER
  missed (bsc#1012628).
- ceph: prevent use-after-free in encode_cap_msg() (bsc#1012628).
- nouveau/gsp: use correct size for registry rpc (bsc#1012628).
- fs,hugetlb: fix NULL pointer dereference in hugetlbs_fill_super
  (bsc#1012628).
- mm: hugetlb pages should not be reserved by shmat() if
  SHM_NORESERVE (bsc#1012628).
- LoongArch: Fix earlycon parameter if KASAN enabled
  (bsc#1012628).
- blk-wbt: Fix detection of dirty-throttled tasks (bsc#1012628).
- docs: kernel_feat.py: fix build error for missing files
  (bsc#1012628).
- of: property: fix typo in io-channels (bsc#1012628).
- xen/events: close evtchn after mapping cleanup (bsc#1012628).
- can: netlink: Fix TDCO calculation using the old data bittiming
  (bsc#1012628).
- can: j1939: prevent deadlock by changing j1939_socks_lock to
  rwlock (bsc#1012628).
- can: j1939: Fix UAF in j1939_sk_match_filter during
  setsockopt(SO_J1939_FILTER) (bsc#1012628).
- pmdomain: core: Move the unused cleanup to a _sync initcall
  (bsc#1012628).
- fs/proc: do_task_stat: move thread_group_cputime_adjusted()
  outside of lock_task_sighand() (bsc#1012628).
- fs/proc: do_task_stat: use sig->stats_lock to gather the
  threads/children stats (bsc#1012628).
- tracing: Fix HAVE_DYNAMIC_FTRACE_WITH_REGS ifdef (bsc#1012628).
- tracing: Inform kmemleak of saved_cmdlines allocation
  (bsc#1012628).
- md: bypass block throttle for superblock update (bsc#1012628).
- block: fix partial zone append completion handling in
  req_bio_endio() (bsc#1012628).
- usb: typec: tpcm: Fix issues with power being removed during
  reset (bsc#1012628).
- netfilter: ipset: fix performance regression in swap operation
  (bsc#1012628).
- netfilter: ipset: Missing gc cancellations fixed (bsc#1012628).
- nfsd: don't take fi_lock in nfsd_break_deleg_cb() (bsc#1012628).
- of: property: Add in-ports/out-ports support to
  of_graph_get_port_parent() (bsc#1012628).
- nilfs2: fix potential bug in end_buffer_async_write
  (bsc#1012628).
- x86/barrier: Do not serialize MSR accesses on AMD (bsc#1012628).
- Rename to
  patches.kernel.org/6.7.6-003-mm-huge_memory-don-t-force-huge-page-alignment-.patch.
- Rename to
  patches.kernel.org/6.7.6-005-btrfs-add-and-use-helper-to-check-if-block-grou.patch.
- Rename to
  patches.kernel.org/6.7.6-006-btrfs-do-not-delete-unused-block-group-if-it-ma.patch.
- Rename to
  patches.kernel.org/6.7.6-007-btrfs-add-new-unused-block-groups-to-the-list-o.patch.
- Rename to
  patches.kernel.org/6.7.6-008-btrfs-don-t-refill-whole-delayed-refs-block-res.patch.
- Rename to
  patches.kernel.org/6.7.6-309-sched-membarrier-reduce-the-ability-to-hammer-o.patch.
- Rename to
  patches.kernel.org/6.7.6-312-dm-limit-the-number-of-targets-and-parameter-si.patch.
- commit b9dc7c6
* Fri Feb 23 2024 jslaby@suse.cz
- mm, mmap: fix vma_merge() case 7 with vma_ops->close
  (git-fixes).
- commit 0067aac
* Thu Feb 22 2024 msuchanek@suse.de
- rpm templates: Always define usrmerged
  usrmerged is now defined in kernel-spec-macros and not the distribution.
  Only check if it's defined in kernel-spec-macros, not everywhere where
  it's used.
- commit a6ad8af
* Wed Feb 21 2024 msuchanek@suse.de
- rpm templates: Move macro definitions below buildrequires
  Many of the rpm macros defined in the kernel packages depend directly or
  indirectly on script execution. OBS cannot execute scripts which means
  values of these macros cannot be used in tags that are required for OBS
  to see such as package name, buildrequires or buildarch.
  Accumulate macro definitions that are not directly expanded by mkspec
  below buildrequires and buildarch to make this distinction clear.
- commit 89eaf4c
* Wed Feb 21 2024 jslaby@suse.cz
- sched/membarrier: reduce the ability to hammer on sys_membarrier
  (git-fixes).
- commit edf6bd4
* Wed Feb 21 2024 jslaby@suse.cz
- rpm/check-for-config-changes: add GCC_ASM_GOTO_OUTPUT_WORKAROUND to IGNORED_CONFIGS_RE
  Introduced by commit 68fb3ca0e408 ("update workarounds for gcc "asm
  goto" issue").
- commit be1bdab
* Tue Feb 20 2024 mkubecek@suse.cz
- Update to 6.8-rc5
- update configs
  - HDC3020=n
- commit 9b37ede
* Mon Feb 19 2024 mkoutny@suse.com
- Update config files.
  Disable CONFIG_RT_GROUP_SCHED on all archs (bsc#950955 bsc#1153228).
- commit 4821c9f
* Mon Feb 19 2024 msuchanek@suse.de
- compute-PATCHVERSION: Do not produce output when awk fails
  compute-PATCHVERSION uses awk to produce a shell script that is
  subsequently executed to update shell variables which are then printed
  as the patchversion.
  Some versions of awk, most notably bysybox-gawk do not understand the
  awk program and fail to run. This results in no script generated as
  output, and printing the initial values of the shell variables as
  the patchversion.
  When the awk program fails to run produce 'exit 1' as the shell script
  to run instead. That prevents printing the stale values, generates no
  output, and generates invalid rpm spec file down the line. Then the
  problem is flagged early and should be easier to diagnose.
- commit 8ef8383
* Sat Feb 17 2024 jslaby@suse.cz
- Linux 6.7.5 (bsc#1012628).
- ext4: regenerate buddy after block freeing failed if under fc
  replay (bsc#1012628).
- dmaengine: fsl-dpaa2-qdma: Fix the size of dma pools
  (bsc#1012628).
- dmaengine: ti: k3-udma: Report short packet errors
  (bsc#1012628).
- dmaengine: fsl-qdma: Fix a memory leak related to the status
  queue DMA (bsc#1012628).
- dmaengine: fsl-qdma: Fix a memory leak related to the queue
  command DMA (bsc#1012628).
- phy: qcom-qmp-usb: fix register offsets for ipq8074/ipq6018
  (bsc#1012628).
- phy: qcom-qmp-usb: fix serdes init sequence for IPQ6018
  (bsc#1012628).
- phy: renesas: rcar-gen3-usb2: Fix returning wrong error code
  (bsc#1012628).
- perf tests: Add perf script test (bsc#1012628).
- perf test: Fix 'perf script' tests on s390 (bsc#1012628).
- perf evlist: Fix evlist__new_default() for > 1 core PMU
  (bsc#1012628).
- dmaengine: fix is_slave_direction() return false when
  DMA_DEV_TO_DEV (bsc#1012628).
- phy: ti: phy-omap-usb2: Fix NULL pointer dereference for SRP
  (bsc#1012628).
- cifs: avoid redundant calls to disable multichannel
  (bsc#1012628).
- cifs: failure to add channel on iface should bump up weight
  (bsc#1012628).
- drm/msms/dp: fixed link clock divider bits be over written in
  BPC unknown case (bsc#1012628).
- drm/msm/dp: return correct Colorimetry for
  DP_TEST_DYNAMIC_RANGE_CEA case (bsc#1012628).
- drm/msm/dpu: check for valid hw_pp in
  dpu_encoder_helper_phys_cleanup (bsc#1012628).
- wifi: iwlwifi: mvm: skip adding debugfs symlink for reconfig
  (bsc#1012628).
- x86/efistub: Give up if memory attribute protocol returns an
  error (bsc#1012628).
- x86/efistub: Avoid placing the kernel below LOAD_PHYSICAL_ADDR
  (bsc#1012628).
- net: stmmac: xgmac: fix handling of DPP safety error for DMA
  channels (bsc#1012628).
- wifi: cfg80211: consume both probe response and beacon IEs
  (bsc#1012628).
- wifi: mac80211: fix RCU use in TDLS fast-xmit (bsc#1012628).
- wifi: mac80211: fix unsolicited broadcast probe config
  (bsc#1012628).
- wifi: mac80211: fix waiting for beacons logic (bsc#1012628).
- wifi: iwlwifi: exit eSR only after the FW does (bsc#1012628).
- wifi: brcmfmac: Adjust n_channels usage for __counted_by
  (bsc#1012628).
- netdevsim: avoid potential loop in nsim_dev_trap_report_work()
  (bsc#1012628).
- net: atlantic: Fix DMA mapping for PTP hwts ring (bsc#1012628).
- selftests: net: cut more slack for gro fwd tests (bsc#1012628).
- selftests/net: convert unicast_extensions.sh to run it in
  unique namespace (bsc#1012628).
- selftests/net: convert pmtu.sh to run it in unique namespace
  (bsc#1012628).
- selftests/net: change shebang to bash to support "source"
  (bsc#1012628).
- selftests: net: fix tcp listener handling in pmtu.sh
  (bsc#1012628).
- selftests: net: avoid just another constant wait (bsc#1012628).
- tsnep: Fix mapping for zero copy XDP_TX action (bsc#1012628).
- tunnels: fix out of bounds access when building IPv6 PMTU error
  (bsc#1012628).
- atm: idt77252: fix a memleak in open_card_ubr0 (bsc#1012628).
- octeontx2-pf: Fix a memleak otx2_sq_init (bsc#1012628).
- hwmon: (aspeed-pwm-tacho) mutex for tach reading (bsc#1012628).
- hwmon: (coretemp) Fix out-of-bounds memory access (bsc#1012628).
- hwmon: (coretemp) Fix bogus core_id to attr name mapping
  (bsc#1012628).
- inet: read sk->sk_family once in inet_recv_error()
  (bsc#1012628).
- drm/i915/gvt: Fix uninitialized variable in handle_mmio()
  (bsc#1012628).
- x86/efistub: Use 1:1 file:memory mapping for PE/COFF .compat
  section (bsc#1012628).
- rxrpc: Fix generation of serial numbers to skip zero
  (bsc#1012628).
- rxrpc: Fix delayed ACKs to not set the reference serial number
  (bsc#1012628).
- rxrpc: Fix response to PING RESPONSE ACKs to a dead call
  (bsc#1012628).
- rxrpc: Fix counting of new acks and nacks (bsc#1012628).
- selftests: net: let big_tcp test cope with slow env
  (bsc#1012628).
- tipc: Check the bearer type before calling
  tipc_udp_nl_bearer_add() (bsc#1012628).
- af_unix: Call kfree_skb() for dead unix_(sk)->oob_skb in GC
  (bsc#1012628).
- devlink: avoid potential loop in
  devlink_rel_nested_in_notify_work() (bsc#1012628).
- ppp_async: limit MRU to 64K (bsc#1012628).
- selftests: cmsg_ipv6: repeat the exact packet (bsc#1012628).
- netfilter: nft_compat: narrow down revision to unsigned 8-bits
  (bsc#1012628).
- netfilter: nft_compat: reject unused compat flag (bsc#1012628).
- netfilter: nft_compat: restrict match/target protocol to u16
  (bsc#1012628).
- drm/amd/display: Fix 'panel_cntl' could be null in
  'dcn21_set_backlight_level()' (bsc#1012628).
- drm/amd/display: Add NULL test for 'timing generator' in
  'dcn21_set_pipe()' (bsc#1012628).
- drm/amd/display: Implement bounds check for stream encoder
  creation in DCN301 (bsc#1012628).
- netfilter: nft_set_pipapo: remove static in nft_pipapo_get()
  (bsc#1012628).
- netfilter: nft_ct: reject direction for ct id (bsc#1012628).
- netfilter: nf_tables: use timestamp to check for set element
  timeout (bsc#1012628).
- netfilter: nfnetlink_queue: un-break NF_REPEAT (bsc#1012628).
- netfilter: nft_set_pipapo: store index in scratch maps
  (bsc#1012628).
- netfilter: nft_set_pipapo: add helper to release pcpu scratch
  area (bsc#1012628).
- netfilter: nft_set_pipapo: remove scratch_aligned pointer
  (bsc#1012628).
- fs/ntfs3: Fix an NULL dereference bug (bsc#1012628).
- mm: Introduce flush_cache_vmap_early() (bsc#1012628).
- riscv: mm: execute local TLB flush after populating vmemmap
  (bsc#1012628).
- riscv: Fix set_huge_pte_at() for NAPOT mapping (bsc#1012628).
- riscv: Fix hugetlb_mask_last_page() when NAPOT is enabled
  (bsc#1012628).
- scsi: core: Move scsi_host_busy() out of host lock if it is
  for per-command (bsc#1012628).
- riscv: Flush the tlb when a page directory is freed
  (bsc#1012628).
- libceph: rename read_sparse_msg_*() to
  read_partial_sparse_msg_*() (bsc#1012628).
- libceph: just wait for more data to be available on the socket
  (bsc#1012628).
- ceph: always set initial i_blkbits to CEPH_FSCRYPT_BLOCK_SHIFT
  (bsc#1012628).
- riscv: Fix arch_hugetlb_migration_supported() for NAPOT
  (bsc#1012628).
- riscv: declare overflow_stack as exported from traps.c
  (bsc#1012628).
- nvme-host: fix the updating of the firmware version
  (bsc#1012628).
- selftests: core: include linux/close_range.h for CLOSE_RANGE_*
  macros (bsc#1012628).
- blk-iocost: Fix an UBSAN shift-out-of-bounds warning
  (bsc#1012628).
- ALSA: usb-audio: Add delay quirk for MOTU M Series 2nd revision
  (bsc#1012628).
- ALSA: usb-audio: Add a quirk for Yamaha YIT-W12TX transmitter
  (bsc#1012628).
- ALSA: usb-audio: add quirk for RODE NT-USB+ (bsc#1012628).
- USB: serial: qcserial: add new usb-id for Dell Wireless DW5826e
  (bsc#1012628).
- USB: serial: option: add Fibocom FM101-GL variant (bsc#1012628).
- USB: serial: cp210x: add ID for IMST iM871A-USB (bsc#1012628).
- Revert "usb: typec: tcpm: fix cc role at port reset"
  (bsc#1012628).
- Revert "drm/amd/pm: fix the high voltage and temperature issue"
  (bsc#1012628).
- x86/lib: Revert to _ASM_EXTABLE_UA() for {get,put}_user()
  fixups (bsc#1012628).
- usb: dwc3: host: Set XHCI_SG_TRB_CACHE_SIZE_QUIRK (bsc#1012628).
- usb: host: xhci-plat: Add support for
  XHCI_SG_TRB_CACHE_SIZE_QUIRK (bsc#1012628).
- xhci: process isoc TD properly when there was a transaction
  error mid TD (bsc#1012628).
- xhci: handle isoc Babble and Buffer Overrun events properly
  (bsc#1012628).
- usb: dwc3: pci: add support for the Intel Arrow Lake-H
  (bsc#1012628).
- hrtimer: Report offline hrtimer enqueue (bsc#1012628).
- Input: i8042 - fix strange behavior of touchpad on Clevo NS70PU
  (bsc#1012628).
- Input: atkbd - skip ATKBD_CMD_SETLEDS when skipping
  ATKBD_CMD_GETID (bsc#1012628).
- wifi: iwlwifi: mvm: fix a battery life regression (bsc#1012628).
- io_uring/net: fix sr->len for IORING_OP_RECV with MSG_WAITALL
  and buffers (bsc#1012628).
- io_uring/poll: move poll execution helpers higher up
  (bsc#1012628).
- io_uring/net: un-indent mshot retry path in io_recv_finish()
  (bsc#1012628).
- io_uring/rw: ensure poll based multishot read retries
  appropriately (bsc#1012628).
- PCI/ASPM: Fix deadlock when enabling ASPM (bsc#1012628).
- new helper: user_path_locked_at() (bsc#1012628).
- bch2_ioctl_subvolume_destroy(): fix locking (bsc#1012628).
- bcachefs: Don't pass memcmp() as a pointer (bsc#1012628).
- bcachefs: rebalance should wakeup on shutdown if disabled
  (bsc#1012628).
- bcachefs: Add missing bch2_moving_ctxt_flush_all()
  (bsc#1012628).
- bcachefs: bch2_kthread_io_clock_wait() no longer sleeps until
  full amount (bsc#1012628).
- bcachefs: kvfree bch_fs::snapshots in bch2_fs_snapshots_exit
  (bsc#1012628).
- bcachefs: grab s_umount only if snapshotting (bsc#1012628).
- bcachefs: unlock parent dir if entry is not found in subvolume
  deletion (bsc#1012628).
- bcachefs: time_stats: Check for last_event == 0 when updating
  freq stats (bsc#1012628).
- Revert "ASoC: amd: Add new dmi entries for acp5x platform"
  (bsc#1012628).
- io_uring/poll: add requeue return code from poll multishot
  handling (bsc#1012628).
- io_uring/net: limit inline multishot retries (bsc#1012628).
- net: Fix from address in memcpy_to_iter_csum() (bsc#1012628).
- net: stmmac: xgmac: use #define for string constants
  (bsc#1012628).
- ALSA: usb-audio: Sort quirk table entries (bsc#1012628).
- net: stmmac: xgmac: fix a typo of register name in DPP safety
  handling (bsc#1012628).
- netfilter: nft_set_rbtree: skip end interval element from gc
  (bsc#1012628).
- Rename to
  patches.kernel.org/6.7.5-024-wifi-cfg80211-detect-stuck-ECSA-element-in-prob.patch.
- Rename to
  patches.kernel.org/6.7.5-025-wifi-mac80211-improve-CSA-ECSA-connection-refus.patch.
- Rename to
  patches.kernel.org/6.7.5-118-bcachefs-fix-incorrect-usage-of-REQ_OP_FLUSH.patch.
- commit 3d6e6db
* Fri Feb 16 2024 jslaby@suse.cz
- af_unix: Fix task hung while purging oob_skb in GC (git-fixes).
- commit bf7a7ae
* Fri Feb 16 2024 jslaby@suse.cz
- btrfs: don't refill whole delayed refs block reserve when
  starting transaction (bsc#1219930).
- btrfs: add new unused block groups to the list of unused block
  groups (bsc#1219930).
- btrfs: do not delete unused block group if it may be used soon
  (bsc#1219930).
- btrfs: add and use helper to check if block group is used
  (bsc#1219930).
- commit f790b2f
* Wed Feb 14 2024 msuchanek@suse.de
- kernel-binary: Move build script to the end
  All other spec templates have the build script at the end, only
  kernel-binary has it in the middle. Align with the other templates.
- commit 98cbdd0
* Wed Feb 14 2024 msuchanek@suse.de
- rpm templates: Aggregate subpackage descriptions
  While in some cases the package tags, description, scriptlets and
  filelist are located together in other cases they are all across the
  spec file. Aggregate the information related to a subpackage in one
  place.
- commit 8eeb08c
* Wed Feb 14 2024 msuchanek@suse.de
- rpm templates: sort rpm tags
  The rpm tags in kernel spec files are sorted at random.
  Make the order of rpm tags somewhat more consistent across rpm spec
  templates.
- commit 8875c35
* Wed Feb 14 2024 jslaby@suse.cz
- blacklist.conf: add one riscv entry
- commit a3bab56
* Wed Feb 14 2024 jslaby@suse.cz
- Update config files.
  Only oldconfig.
- commit f4f3bac
* Tue Feb 13 2024 colyli@suse.de
- Update to add CVE-2024-23851 tag,
  patches.suse/dm-limit-the-number-of-targets-and-parameter-size-ar.patch
  (bsc#1219827, bsc#1219146, CVE-2023-52429, CVE-2024-23851).
- commit f7319be
* Mon Feb 12 2024 colyli@suse.de
- dm: limit the number of targets and parameter size area
  (bsc#1219827, bsc#1219146, CVE-2023-52429).
- commit 3dc0a6c
* Mon Feb 12 2024 tiwai@suse.de
- Update config files: disable broken ATOMISP drivers (bsc#1210639)
  It's been broken over a year, better to disable it before hitting another victim
- commit aa68e1a
* Mon Feb 12 2024 vbabka@suse.cz
- Update config files. Enable CONFIG_READ_ONLY_THP_FOR_FS (bsc#1219593).
- commit 8f5ed7a
* Sun Feb 11 2024 mkubecek@suse.cz
- Update to 6.8-rc4
- commit 9b23bf2
* Sat Feb 10 2024 tiwai@suse.de
- net: phy: realtek: add 5Gbps support to rtl822x_config_aneg()
  (bsc#1217417).
- net: phy: realtek: use generic MDIO constants (bsc#1217417).
- net: mdio: add 2.5g and 5g related PMA speed constants
  (bsc#1217417).
- net: phy: realtek: add 5Gbps support to rtl822x_config_aneg()
  (bsc#1217417).
- net: phy: realtek: use generic MDIO constants (bsc#1217417).
- net: mdio: add 2.5g and 5g related PMA speed constants
  (bsc#1217417).
- commit 5c78291
* Thu Feb  8 2024 msuchanek@suse.de
- kernel-binary: certs: Avoid trailing space
- commit bc7dc31
* Thu Feb  8 2024 vkarasulli@suse.de
- Update
  patches.kernel.org/6.7.2-448-Bluetooth-Fix-atomicity-violation-in-min-max-_k.patch
  (bsc#1012628 bsc#1219608 CVE-2024-24860).
- commit dff65cf
* Wed Feb  7 2024 jslaby@suse.cz
- rpm/kernel-binary.spec.in: install scripts/gdb when enabled in config
  (bsc#1219653)
  They are put into -devel subpackage. And a proper link to
  /usr/share/gdb/auto-load/ is created.
- commit 1dccf2a
* Tue Feb  6 2024 jslaby@suse.cz
- rpm/mkspec: sort entries in _multibuild
  Otherwise it creates unnecessary diffs when tar-up-ing. It's of course
  due to readdir() using "random" order as served by the underlying
  filesystem.
  See for example:
  https://build.opensuse.org/request/show/1144457/changes
- commit d1155de
* Tue Feb  6 2024 jslaby@suse.cz
- Linux 6.7.4 (bsc#1012628).
- asm-generic: make sparse happy with odd-sized put_unaligned_*()
  (bsc#1012628).
- powerpc/mm: Fix null-pointer dereference in pgtable_cache_add
  (bsc#1012628).
- arm64: irq: set the correct node for VMAP stack (bsc#1012628).
- drivers/perf: pmuv3: don't expose SW_INCR event in sysfs
  (bsc#1012628).
- powerpc: Fix build error due to is_valid_bugaddr()
  (bsc#1012628).
- powerpc/mm: Fix build failures due to
  arch_reserved_kernel_pages() (bsc#1012628).
- powerpc/64s: Fix CONFIG_NUMA=n build due to
  create_section_mapping() (bsc#1012628).
- x86/boot: Ignore NMIs during very early boot (bsc#1012628).
- powerpc: pmd_move_must_withdraw() is only needed for
  CONFIG_TRANSPARENT_HUGEPAGE (bsc#1012628).
- powerpc/lib: Validate size for vector operations (bsc#1012628).
- x86/mce: Mark fatal MCE's page as poison to avoid panic in
  the kdump kernel (bsc#1012628).
- sched/numa: Fix mm numa_scan_seq based unconditional scan
  (bsc#1012628).
- perf/core: Fix narrow startup race when creating the perf
  nr_addr_filters sysfs file (bsc#1012628).
- debugobjects: Stop accessing objects after releasing hash
  bucket lock (bsc#1012628).
- sched/fair: Fix tg->load when offlining a CPU (bsc#1012628).
- regulator: core: Only increment use_count when enable_count
  changes (bsc#1012628).
- audit: Send netlink ACK before setting connection in auditd_set
  (bsc#1012628).
- ACPI: tables: Correct and clean up the logic of
  acpi_parse_entries_array() (bsc#1012628).
- ACPI: video: Add quirk for the Colorful X15 AT 23 Laptop
  (bsc#1012628).
- PNP: ACPI: fix fortify warning (bsc#1012628).
- ACPI: extlog: fix NULL pointer dereference check (bsc#1012628).
- selftests/nolibc: fix testcase status alignment (bsc#1012628).
- ACPI: NUMA: Fix the logic of getting the fake_pxm value
  (bsc#1012628).
- kunit: tool: fix parsing of test attributes (bsc#1012628).
- kunit: Reset test->priv after each param iteration
  (bsc#1012628).
- PM / devfreq: Synchronize devfreq_monitor_[start/stop]
  (bsc#1012628).
- ACPI: APEI: set memory failure flags as MF_ACTION_REQUIRED on
  synchronous events (bsc#1012628).
- OPP: The level field is always of unsigned int type
  (bsc#1012628).
- thermal: core: Fix thermal zone suspend-resume synchronization
  (bsc#1012628).
- FS:JFS:UBSAN:array-index-out-of-bounds in dbAdjTree
  (bsc#1012628).
- UBSAN: array-index-out-of-bounds in dtSplitRoot (bsc#1012628).
- jfs: fix slab-out-of-bounds Read in dtSearch (bsc#1012628).
- jfs: fix array-index-out-of-bounds in dbAdjTree (bsc#1012628).
- jfs: fix uaf in jfs_evict_inode (bsc#1012628).
- hwrng: starfive - Fix dev_err_probe return error (bsc#1012628).
- crypto: p10-aes-gcm - Avoid -Wstringop-overflow warnings
  (bsc#1012628).
- pstore/ram: Fix crash when setting number of cpus to an odd
  number (bsc#1012628).
- erofs: fix up compacted indexes for block size < 4096
  (bsc#1012628).
- crypto: starfive - Fix dev_err_probe return error (bsc#1012628).
- crypto: octeontx2 - Fix cptvf driver cleanup (bsc#1012628).
- erofs: fix ztailpacking for subpage compressed blocks
  (bsc#1012628).
- crypto: stm32/crc32 - fix parsing list of devices (bsc#1012628).
- afs: fix the usage of read_seqbegin_or_lock() in
  afs_lookup_volume_rcu() (bsc#1012628).
- rxrpc_find_service_conn_rcu: fix the usage of
  read_seqbegin_or_lock() (bsc#1012628).
- jfs: fix array-index-out-of-bounds in diNewExt (bsc#1012628).
- s390/boot: always align vmalloc area on segment boundary
  (bsc#1012628).
- arch: consolidate arch_irq_work_raise prototypes (bsc#1012628).
- arch: fix asm-offsets.c building with -Wmissing-prototypes
  (bsc#1012628).
- s390/vfio-ap: fix sysfs status attribute for AP queue devices
  (bsc#1012628).
- s390/ptrace: handle setting of fpc register correctly
  (bsc#1012628).
- KVM: s390: fix setting of fpc register (bsc#1012628).
- sysctl: Fix out of bounds access for empty sysctl registers
  (bsc#1012628).
- SUNRPC: Fix a suspicious RCU usage warning (bsc#1012628).
- ext4: treat end of range as exclusive in ext4_zero_range()
  (bsc#1012628).
- smb: client: fix renaming of reparse points (bsc#1012628).
- smb: client: fix hardlinking of reparse points (bsc#1012628).
- cifs: fix in logging in cifs_chan_update_iface (bsc#1012628).
- ecryptfs: Reject casefold directory inodes (bsc#1012628).
- ext4: fix inconsistent between segment fstrim and full fstrim
  (bsc#1012628).
- ext4: unify the type of flexbg_size to unsigned int
  (bsc#1012628).
- ext4: remove unnecessary check from alloc_flex_gd()
  (bsc#1012628).
- ext4: avoid online resizing failures due to oversized flex bg
  (bsc#1012628).
- wifi: rtw89: fix timeout calculation in rtw89_roc_end()
  (bsc#1012628).
- wifi: rt2x00: restart beacon queue when hardware reset
  (bsc#1012628).
- selftests/bpf: fix RELEASE=1 build for tc_opts (bsc#1012628).
- selftests/bpf: satisfy compiler by having explicit return in
  btf test (bsc#1012628).
- libbpf: Fix potential uninitialized tail padding with
  LIBBPF_OPTS_RESET (bsc#1012628).
- selftests/bpf: Fix pyperf180 compilation failure with clang18
  (bsc#1012628).
- wifi: rt2x00: correct wrong BBP register in RxDCOC calibration
  (bsc#1012628).
- selftests/bpf: Fix issues in setup_classid_environment()
  (bsc#1012628).
- ARM: dts: qcom: strip prefix from PMIC files (bsc#1012628).
- ARM: dts: qcom: mdm9615: fix PMIC node labels (bsc#1012628).
- ARM: dts: qcom: msm8660: fix PMIC node labels (bsc#1012628).
- soc: xilinx: Fix for call trace due to the usage of
  smp_processor_id() (bsc#1012628).
- soc: xilinx: fix unhandled SGI warning message (bsc#1012628).
- scsi: lpfc: Fix possible file string name overflow when updating
  firmware (bsc#1012628).
- ARM: dts: samsung: exynos4: fix camera unit addresses/ranges
  (bsc#1012628).
- ARM: dts: samsung: s5pv210: fix camera unit addresses/ranges
  (bsc#1012628).
- net: phy: micrel: fix ts_info value in case of no phc
  (bsc#1012628).
- PCI: Add no PM reset quirk for NVIDIA Spectrum devices
  (bsc#1012628).
- bonding: return -ENOMEM instead of BUG in alb_upper_dev_walk
  (bsc#1012628).
- net: usb: ax88179_178a: avoid two consecutive device resets
  (bsc#1012628).
- scsi: mpi3mr: Add support for SAS5116 PCI IDs (bsc#1012628).
- scsi: mpi3mr: Add PCI checks where SAS5116 diverges from SAS4116
  (bsc#1012628).
- scsi: arcmsr: Support new PCI device IDs 1883 and 1886
  (bsc#1012628).
- ARM: dts: imx7d: Fix coresight funnel ports (bsc#1012628).
- ARM: dts: imx7s: Fix lcdif compatible (bsc#1012628).
- ARM: dts: imx7s: Fix nand-controller #size-cells (bsc#1012628).
- bpf: Fix a few selftest failures due to llvm18 change
  (bsc#1012628).
- wifi: ath9k: Fix potential array-index-out-of-bounds read in
  ath9k_htc_txstatus() (bsc#1012628).
- wifi: ath11k: fix race due to setting
  ATH11K_FLAG_EXT_IRQ_ENABLED too early (bsc#1012628).
- wifi: rtw89: fix not entering PS mode after AP stops
  (bsc#1012628).
- wifi: rtw89: fix misbehavior of TX beacon in concurrent mode
  (bsc#1012628).
- bpf: Check rcu_read_lock_trace_held() before calling bpf map
  helpers (bsc#1012628).
- bpf: Set need_defer as false when clearing fd array during
  map free (bsc#1012628).
- wifi: ath12k: fix and enable AP mode for WCN7850 (bsc#1012628).
- scsi: libfc: Don't schedule abort twice (bsc#1012628).
- scsi: libfc: Fix up timeout error in fc_fcp_rec_error()
  (bsc#1012628).
- net: mvmdio: Avoid excessive sleeps in polled mode
  (bsc#1012628).
- arm64: dts: qcom: sm8550: fix soundwire controllers node name
  (bsc#1012628).
- arm64: dts: qcom: sm8450: fix soundwire controllers node name
  (bsc#1012628).
- arm64: dts: qcom: sm8350: Fix remoteproc interrupt type
  (bsc#1012628).
- wifi: mt76: connac: fix EHT phy mode check (bsc#1012628).
- wifi: mt76: mt7996: add PCI IDs for mt7992 (bsc#1012628).
- bpf: Set uattr->batch.count as zero before batched update or
  deletion (bsc#1012628).
- wifi: wfx: fix possible NULL pointer dereference in
  wfx_set_mfp_ap() (bsc#1012628).
- wifi: ath12k: fix the issue that the multicast/broadcast
  indicator is not read correctly for WCN7850 (bsc#1012628).
- ARM: dts: rockchip: fix rk3036 hdmi ports node (bsc#1012628).
- ARM: dts: imx25/27-eukrea: Fix RTC node name (bsc#1012628).
- ARM: dts: imx: Use flash@0,0 pattern (bsc#1012628).
- ARM: dts: imx27: Fix sram node (bsc#1012628).
- ARM: dts: imx1: Fix sram node (bsc#1012628).
- net: phy: at803x: fix passing the wrong reference for
  config_intr (bsc#1012628).
- ionic: pass opcode to devcmd_wait (bsc#1012628).
- ionic: bypass firmware cmds when stuck in reset (bsc#1012628).
- block/rnbd-srv: Check for unlikely string overflow
  (bsc#1012628).
- arm64: zynqmp: Move fixed clock to / for kv260 (bsc#1012628).
- arm64: zynqmp: Fix clock node name in kv260 cards (bsc#1012628).
- selftests/bpf: fix compiler warnings in RELEASE=1 mode
  (bsc#1012628).
- ARM: dts: imx25: Fix the iim compatible string (bsc#1012628).
- ARM: dts: imx25/27: Pass timing0 (bsc#1012628).
- ARM: dts: imx27-apf27dev: Fix LED name (bsc#1012628).
- ARM: dts: imx23-sansa: Use preferred i2c-gpios properties
  (bsc#1012628).
- ARM: dts: imx23/28: Fix the DMA controller node name
  (bsc#1012628).
- scsi: lpfc: Reinitialize an NPIV's VMID data structures after
  FDISC (bsc#1012628).
- scsi: lpfc: Move determination of vmid_flag after VMID
  reinitialization completes (bsc#1012628).
- scsi: hisi_sas: Set .phy_attached before notifing phyup event
  HISI_PHYE_PHY_UP_PM (bsc#1012628).
- ice: fix ICE_AQ_VSI_Q_OPT_RSS_* register values (bsc#1012628).
- net: atlantic: eliminate double free in error handling logic
  (bsc#1012628).
- net: dsa: mv88e6xxx: Fix mv88e6352_serdes_get_stats error path
  (bsc#1012628).
- ARM: dts: marvell: Fix some common switch mistakes
  (bsc#1012628).
- ARM64: dts: marvell: Fix some common switch mistakes
  (bsc#1012628).
- block: prevent an integer overflow in bvec_try_merge_hw_page
  (bsc#1012628).
- md: Whenassemble the array, consult the superblock of the
  freshest device (bsc#1012628).
- x86/cfi,bpf: Fix bpf_exception_cb() signature (bsc#1012628).
- arm64: dts: qcom: msm8996: Fix 'in-ports' is a required property
  (bsc#1012628).
- arm64: dts: qcom: msm8998: Fix 'out-ports' is a required
  property (bsc#1012628).
- arm64: dts: qcom: Fix coresight warnings in in-ports and
  out-ports (bsc#1012628).
- intel: add bit macro includes where needed (bsc#1012628).
- ice: fix pre-shifted bit usage (bsc#1012628).
- arm64: dts: amlogic: fix format for s4 uart node (bsc#1012628).
- wifi: rtl8xxxu: Add additional USB IDs for RTL8192EU devices
  (bsc#1012628).
- wifi: rtw89: coex: Fix wrong Wi-Fi role info and FDDT parameter
  members (bsc#1012628).
- libbpf: Fix NULL pointer dereference in
  bpf_object__collect_prog_relos (bsc#1012628).
- wifi: rtlwifi: rtl8723{be,ae}: using calculate_bit_shift()
  (bsc#1012628).
- wifi: cfg80211: free beacon_ies when overridden from hidden BSS
  (bsc#1012628).
- Bluetooth: qca: Set both WIDEBAND_SPEECH and LE_STATES quirks
  for QCA2066 (bsc#1012628).
- Bluetooth: ISO: Avoid creating child socket if PA sync is
  terminating (bsc#1012628).
- Bluetooth: hci_sync: fix BR/EDR wakeup bug (bsc#1012628).
- Bluetooth: L2CAP: Fix possible multiple reject send
  (bsc#1012628).
- net/smc: disable SEID on non-s390 archs where virtual ISM may
  be used (bsc#1012628).
- bridge: cfm: fix enum typo in br_cc_ccm_tx_parse (bsc#1012628).
- arm64: dts: sprd: Add clock reference for pll2 on UMS512
  (bsc#1012628).
- arm64: dts: sprd: Change UMS512 idle-state nodename to match
  bindings (bsc#1012628).
- i40e: Fix VF disable behavior to block all traffic
  (bsc#1012628).
- octeontx2-af: Fix max NPC MCAM entry check while validating
  ref_entry (bsc#1012628).
- net: kcm: fix direct access to bv_len (bsc#1012628).
- net: dsa: qca8k: put MDIO bus OF node on qca8k_mdio_register()
  failure (bsc#1012628).
- ARM: dts: usr8200: Fix phy registers (bsc#1012628).
- f2fs: fix to check return value of f2fs_reserve_new_block()
  (bsc#1012628).
- ALSA: hda: Refer to correct stream index at loops (bsc#1012628).
- ASoC: doc: Fix undefined SND_SOC_DAPM_NOPM argument
  (bsc#1012628).
- fast_dput(): handle underflows gracefully (bsc#1012628).
- reiserfs: Avoid touching renamed directory if parent does not
  change (bsc#1012628).
- ocfs2: Avoid touching renamed directory if parent does not
  change (bsc#1012628).
- drm/msm/a690: Fix reg values for a690 (bsc#1012628).
- RDMA/IPoIB: Fix error code return in ipoib_mcast_join
  (bsc#1012628).
- drm/panel-edp: Add override_edid_mode quirk for generic edp
  (bsc#1012628).
- drm/bridge: anx7625: Fix Set HPD irq detect window to 2ms
  (bsc#1012628).
- drm/amd/display: Fix tiled display misalignment (bsc#1012628).
- f2fs: fix write pointers on zoned device after roll forward
  (bsc#1012628).
- ASoC: amd: Add new dmi entries for acp5x platform (bsc#1012628).
- drm/amd/display: Fix MST PBN/X.Y value calculations
  (bsc#1012628).
- drm/amd/display: Fix disable_otg_wa logic (bsc#1012628).
- drm/amd/display: Fix Replay Desync Error IRQ handler
  (bsc#1012628).
- drm/amd/display: add support for DTO genarated dscclk
  (bsc#1012628).
- drm/drm_file: fix use of uninitialized variable (bsc#1012628).
- drm/framebuffer: Fix use of uninitialized variable
  (bsc#1012628).
- drm/mipi-dsi: Fix detach call without attach (bsc#1012628).
- media: stk1160: Fixed high volume of stk1160_dbg messages
  (bsc#1012628).
- media: rockchip: rga: fix swizzling for RGB formats
  (bsc#1012628).
- PCI: add INTEL_HDA_ARL to pci_ids.h (bsc#1012628).
- ALSA: hda: Intel: add HDA_ARL PCI ID support (bsc#1012628).
- ALSA: hda: intel-dspcfg: add filters for ARL-S and ARL
  (bsc#1012628).
- drm/msm/dp: Add DisplayPort controller for SM8650 (bsc#1012628).
- media: uvcvideo: Fix power line control for a Chicony camera
  (bsc#1012628).
- media: uvcvideo: Fix power line control for SunplusIT camera
  (bsc#1012628).
- media: rkisp1: Drop IRQF_SHARED (bsc#1012628).
- media: rkisp1: Fix IRQ handler return values (bsc#1012628).
- media: rkisp1: Store IRQ lines (bsc#1012628).
- media: rkisp1: Fix IRQ disable race issue (bsc#1012628).
- media: rkisp1: resizer: Stop manual allocation of
  v4l2_subdev_state (bsc#1012628).
- hwmon: (nct6775) Fix fan speed set failure in automatic mode
  (bsc#1012628).
- hwmon: (hp-wmi-sensors) Fix failure to load on EliteDesk 800 G6
  (bsc#1012628).
- f2fs: fix to tag gcing flag on page during block migration
  (bsc#1012628).
- drm/exynos: Call drm_atomic_helper_shutdown() at shutdown/unbind
  time (bsc#1012628).
- IB/ipoib: Fix mcast list locking (bsc#1012628).
- media: amphion: remove mutext lock in condition of wait_event
  (bsc#1012628).
- media: ddbridge: fix an error code problem in ddb_probe
  (bsc#1012628).
- media: ov2740: Fix hts value (bsc#1012628).
- media: i2c: imx335: Fix hblank min/max values (bsc#1012628).
- drm/amd/display: For prefetch mode > 0, extend prefetch if
  possible (bsc#1012628).
- drm/amd/display: Force p-state disallow if leaving no plane
  config (bsc#1012628).
- drm/amdkfd: fix mes set shader debugger process management
  (bsc#1012628).
- drm/msm/dpu: enable writeback on SM8350 (bsc#1012628).
- drm/msm/dpu: enable writeback on SM8450 (bsc#1012628).
- drm/msm/dpu: Ratelimit framedone timeout msgs (bsc#1012628).
- drm/msm/dpu: fix writeback programming for YUV cases
  (bsc#1012628).
- drm/msm/dpu: Add mutex lock in control vblank irq (bsc#1012628).
- drm/amdgpu: fix ftrace event amdgpu_bo_move always move on
  same heap (bsc#1012628).
- clk: hi3620: Fix memory leak in hi3620_mmc_clk_init()
  (bsc#1012628).
- clk: mmp: pxa168: Fix memory leak in pxa168_clk_init()
  (bsc#1012628).
- watchdog: starfive: add lock annotations to fix context
  imbalances (bsc#1012628).
- watchdog: it87_wdt: Keep WDTCTRL bit 3 unmodified for
  IT8784/IT8786 (bsc#1012628).
- accel/habanalabs: add support for Gaudi2C device (bsc#1012628).
- accel/habanalabs: fix EQ heartbeat mechanism (bsc#1012628).
- accel/habanalabs/gaudi2: fix undef opcode reporting
  (bsc#1012628).
- drm/amd/display: make flip_timestamp_in_us a 64-bit variable
  (bsc#1012628).
- drm/amd/display: fix usb-c connector_type (bsc#1012628).
- drm/amd/display: Fix lightup regression with DP2 single display
  configs (bsc#1012628).
- drm/amd/display: Only clear symclk otg flag for HDMI
  (bsc#1012628).
- clk: imx: scu: Fix memory leak in __imx_clk_gpr_scu()
  (bsc#1012628).
- clk: imx: clk-imx8qxp: fix LVDS bypass, pixel and phy clocks
  (bsc#1012628).
- drm/amdgpu: Fix ecc irq enable/disable unpaired (bsc#1012628).
- drm/amd/display: Fix minor issues in BW Allocation Phase2
  (bsc#1012628).
- drm/amdgpu: Let KFD sync with VM fences (bsc#1012628).
- Re-revert "drm/amd/display: Enable Replay for static screen
  use cases" (bsc#1012628).
- drm/amdgpu: Fix possible NULL dereference in
  amdgpu_ras_query_error_status_helper() (bsc#1012628).
- drm/amdgpu: Fix variable 'mca_funcs' dereferenced before NULL
  check in 'amdgpu_mca_smu_get_mca_entry()' (bsc#1012628).
- drm/amdgpu: Fix '*fw' from request_firmware() not released in
  'amdgpu_ucode_request()' (bsc#1012628).
- drm/amdgpu: Drop 'fence' check in 'to_amdgpu_amdkfd_fence()'
  (bsc#1012628).
- drm/amdkfd: Fix iterator used outside loop in
  'kfd_add_peer_prop()' (bsc#1012628).
- drm/amdgpu: apply the RV2 system aperture fix to RN/CZN as well
  (bsc#1012628).
- ALSA: hda/conexant: Fix headset auto detect fail in cx8070
  and SN6140 (bsc#1012628).
- pinctrl: baytrail: Fix types of config value in
  byt_pin_config_set() (bsc#1012628).
- leds: trigger: panic: Don't register panic notifier if creating
  the trigger failed (bsc#1012628).
- um: Fix naming clash between UML and scheduler (bsc#1012628).
- um: Don't use vfprintf() for os_info() (bsc#1012628).
- um: net: Fix return type of uml_net_start_xmit() (bsc#1012628).
- um: time-travel: fix time corruption (bsc#1012628).
- i3c: master: cdns: Update maximum prescaler value for i2c clock
  (bsc#1012628).
- ACPI: resource: Add DMI quirks for ASUS Vivobook E1504GA and
  E1504GAB (bsc#1012628).
- ACPI: resource: Skip IRQ override on ASUS ExpertBook B1502CGA
  (bsc#1012628).
- riscv: Make XIP bootable again (bsc#1012628).
- xen/gntdev: Fix the abuse of underlying struct page in DMA-buf
  import (bsc#1012628).
- mfd: ti_am335x_tscadc: Fix TI SoC dependencies (bsc#1012628).
- mailbox: arm_mhuv2: Fix a bug for mhuv2_sender_interrupt
  (bsc#1012628).
- PCI: Only override AMD USB controller if required (bsc#1012628).
- PCI: switchtec: Fix stdev_release() crash after surprise hot
  remove (bsc#1012628).
- perf cs-etm: Bump minimum OpenCSD version to ensure a bugfix
  is present (bsc#1012628).
- extcon: fix possible name leak in extcon_dev_register()
  (bsc#1012628).
- usb: hub: Replace hardcoded quirk value with BIT() macro
  (bsc#1012628).
- usb: hub: Add quirk to decrease IN-ep poll interval for
  Microchip USB491x hub (bsc#1012628).
- selftests/sgx: Fix linker script asserts (bsc#1012628).
- tty: allow TIOCSLCKTRMIOS with CAP_CHECKPOINT_RESTORE
  (bsc#1012628).
- tty: serial: 8250: Set RS422 interface by default to fix Moxa
  RS422/RS485 PCIe boards (bsc#1012628).
- fs/kernfs/dir: obey S_ISGID (bsc#1012628).
- spmi: mediatek: Fix UAF on device remove (bsc#1012628).
- staging: vme_user: Fix the issue of return the wrong error code
  (bsc#1012628).
- PCI: Fix 64GT/s effective data rate calculation (bsc#1012628).
- PCI/AER: Decode Requester ID when no error info found
  (bsc#1012628).
- 9p: Fix initialisation of netfs_inode for 9p (bsc#1012628).
- tracefs/eventfs: Use root and instance inodes as default
  ownership (bsc#1012628).
- usb: xhci-plat: fix usb disconnect issue after s4 (bsc#1012628).
- misc: lis3lv02d_i2c: Add missing setting of the reg_ctrl
  callback (bsc#1012628).
- libsubcmd: Fix memory leak in uniq() (bsc#1012628).
- ASoC: codecs: rtq9128: Fix PM_RUNTIME usage (bsc#1012628).
- ASoC: codecs: rtq9128: Fix TDM enable and DAI format control
  flow (bsc#1012628).
- drm/amdkfd: Fix lock dependency warning (bsc#1012628).
- drm/amd/display: To adjust dprefclk by down spread percentage
  (bsc#1012628).
- Revert "drm/amd/display: Fix conversions between bytes and KB"
  (bsc#1012628).
- drm/amdkfd: Fix lock dependency warning with srcu (bsc#1012628).
- =?UTF-8?q?virtio=5Fnet:=20Fix=20"=E2=80=98%%d=E2=80=99=20d?=
  =?UTF-8?q?irective=20writing=20between=201=20and=2011=20bytes=20into=20a?=
  =?UTF-8?q?=20region=20of=20size=2010"=20warnings?=
  (bsc#1012628).
- blk-mq: fix IO hang from sbitmap wakeup race (bsc#1012628).
- ceph: reinitialize mds feature bit even when session in open
  (bsc#1012628).
- ceph: fix deadlock or deadcode of misusing dget() (bsc#1012628).
- ceph: fix invalid pointer access if get_quota_realm return
  ERR_PTR (bsc#1012628).
- drm/amdgpu: fix avg vs input power reporting on smu7
  (bsc#1012628).
- drm/amd/powerplay: Fix kzalloc parameter 'ATOM_Tonga_PPM_Table'
  in 'get_platform_power_management_table()' (bsc#1012628).
- drm/amdgpu: Fix with right return code '-EIO' in
  'amdgpu_gmc_vram_checking()' (bsc#1012628).
- drm/amdgpu: Release 'adev->pm.fw' before return in
  'amdgpu_device_need_post()' (bsc#1012628).
- drm/amdkfd: Fix 'node' NULL check in
  'svm_range_get_range_boundaries()' (bsc#1012628).
- i2c: rk3x: Adjust mask/value offset for i2c2 on rv1126
  (bsc#1012628).
- perf: Fix the nr_addr_filters fix (bsc#1012628).
- wifi: cfg80211: fix RCU dereference in __cfg80211_bss_update
  (bsc#1012628).
- drm: using mul_u32_u32() requires linux/math64.h (bsc#1012628).
- drm/msm/dpu: Correct UBWC settings for sc8280xp (bsc#1012628).
- drm/amdkfd: only flush mes process context if mes support is
  there (bsc#1012628).
- riscv: Fix build error on rv32 + XIP (bsc#1012628).
- scsi: isci: Fix an error code problem in isci_io_request_build()
  (bsc#1012628).
- kunit: run test suites only after module initialization
  completes (bsc#1012628).
- regulator: ti-abb: don't use
  devm_platform_ioremap_resource_byname for shared interrupt
  register (bsc#1012628).
- scsi: core: Move scsi_host_busy() out of host lock for waking
  up EH handler (bsc#1012628).
- HID: hidraw: fix a problem of memory leak in hidraw_release()
  (bsc#1012628).
- selftests: net: remove dependency on ebpf tests (bsc#1012628).
- selftests: net: explicitly wait for listener ready
  (bsc#1012628).
- gve: Fix skb truesize underestimation (bsc#1012628).
- net: ethernet: mtk_eth_soc: set DMA coherent mask to get PPE
  working (bsc#1012628).
- net: phy: mediatek-ge-soc: sync driver with MediaTek SDK
  (bsc#1012628).
- crypto: caam - fix asynchronous hash (bsc#1012628).
- selftests: net: add missing config for big tcp tests
  (bsc#1012628).
- selftests: net: add missing required classifier (bsc#1012628).
- selftests: net: give more time for GRO aggregation
  (bsc#1012628).
- ip6_tunnel: make sure to pull inner header in __ip6_tnl_rcv()
  (bsc#1012628).
- net: dsa: mt7530: fix 10M/100M speed on MT7988 switch
  (bsc#1012628).
- ipmr: fix kernel panic when forwarding mcast packets
  (bsc#1012628).
- net: lan966x: Fix port configuration when using SGMII interface
  (bsc#1012628).
- tracefs: remove stale 'update_gid' code (bsc#1012628).
- tcp: add sanity checks to rx zerocopy (bsc#1012628).
- e1000e: correct maximum frequency adjustment values
  (bsc#1012628).
- ixgbe: Refactor returning internal error codes (bsc#1012628).
- ixgbe: Refactor overtemp event handling (bsc#1012628).
- ixgbe: Fix an error handling path in
  ixgbe_read_iosf_sb_reg_x550() (bsc#1012628).
- net: dsa: qca8k: fix illegal usage of GPIO (bsc#1012628).
- ipv6: Ensure natural alignment of const ipv6 loopback and
  router addresses (bsc#1012628).
- llc: call sock_orphan() at release time (bsc#1012628).
- selftests: net: Add missing matchall classifier (bsc#1012628).
- bridge: mcast: fix disabled snooping after long uptime
  (bsc#1012628).
- devlink: Fix referring to hw_addr attribute during state
  validation (bsc#1012628).
- selftests: net: add missing config for GENEVE (bsc#1012628).
- netfilter: conntrack: correct window scaling with retransmitted
  SYN (bsc#1012628).
- netfilter: nf_tables: restrict tunnel object to NFPROTO_NETDEV
  (bsc#1012628).
- netfilter: nf_log: replace BUG_ON by WARN_ON_ONCE when putting
  logger (bsc#1012628).
- netfilter: nft_ct: sanitize layer 3 and 4 protocol number in
  custom expectations (bsc#1012628).
- net: ipv4: fix a memleak in ip_setup_cork (bsc#1012628).
- af_unix: fix lockdep positive in sk_diag_dump_icons()
  (bsc#1012628).
- pds_core: Prevent health thread from running during reset/remove
  (bsc#1012628).
- pds_core: Cancel AQ work on teardown (bsc#1012628).
- pds_core: Use struct pdsc for the pdsc_adminq_isr private data
  (bsc#1012628).
- pds_core: Prevent race issues involving the adminq
  (bsc#1012628).
- pds_core: Clear BARs on reset (bsc#1012628).
- pds_core: Rework teardown/setup flow to be more common
  (bsc#1012628).
- selftests: net: add missing config for nftables-backed iptables
  (bsc#1012628).
- selftests: net: add missing config for pmtu.sh tests
  (bsc#1012628).
- selftests: net: fix available tunnels detection (bsc#1012628).
- selftests: net: don't access /dev/stdout in pmtu.sh
  (bsc#1012628).
- octeontx2-pf: Remove xdp queues on program detach (bsc#1012628).
- net: sysfs: Fix /sys/class/net/<iface> path (bsc#1012628).
- selftests: team: Add missing config options (bsc#1012628).
- selftests: bonding: Check initial state (bsc#1012628).
- selftests: net: add missing config for NF_TARGET_TTL
  (bsc#1012628).
- selftests: net: enable some more knobs (bsc#1012628).
- idpf: avoid compiler padding in virtchnl2_ptype struct
  (bsc#1012628).
- arm64: irq: set the correct node for shadow call stack
  (bsc#1012628).
- Revert "drm/amd/display: Disable PSR-SU on Parade 0803 TCON
  again" (bsc#1012628).
- drm/msm/dsi: Enable runtime PM (bsc#1012628).
- selftests/bpf: Remove flaky test_btf_id test (bsc#1012628).
- bonding: remove print in bond_verify_device_path (bsc#1012628).
- ASoC: qcom: sc8280xp: limit speaker volumes (bsc#1012628).
- ASoC: codecs: wcd938x: fix headphones volume controls
  (bsc#1012628).
- ASoC: codecs: lpass-wsa-macro: fix compander volume hack
  (bsc#1012628).
- ASoC: codecs: wsa883x: fix PA volume control (bsc#1012628).
- drm/amdgpu: Fix missing error code in 'gmc_v6/7/8/9_0_hw_init()'
  (bsc#1012628).
- Rename to
  patches.kernel.org/6.7.4-345-mm-kmsan-fix-infinite-recursion-due-to-RCU-crit.patch.
- commit 01735a3
* Mon Feb  5 2024 jslaby@suse.cz
- Refresh
  patches.suse/net-phy-realtek-add-support-for-RTL8126A-integrated-.patch.
- Refresh patches.suse/r8169-add-support-for-RTL8126A.patch.
- Refresh
  patches.suse/Bluetooth-btmtk-Add-MODULE_FIRMWARE-for-MT7922.patch.
  Update upstream statuses (all in maintainers repo now).
- Refresh
  patches.suse/net-phy-realtek-add-support-for-RTL8126A-integrated-.patch.
- Refresh patches.suse/r8169-add-support-for-RTL8126A.patch.
- Refresh
  patches.suse/wifi-cfg80211-detect-stuck-ECSA-element-in-probe-resp.patch.
- Refresh
  patches.suse/wifi-mac80211-improve-CSA-ECSA-connection-refusal.patch.
  Update upstream statuses (all in maintainers repo now).
- commit 2dfb213
* Sun Feb  4 2024 mkubecek@suse.cz
- Update to 6.8-rc3
- eliminate 1 patch
  - patches.suse/mm-huge_memory-don-t-force-huge-page-alignment-on-32.patch
- refresh configs
- commit ae4495f
* Fri Feb  2 2024 mkubecek@suse.cz
- config: add missing USELIB=n to arm configs
  ARM configs were not refreshed properly after commit 077d05a10ddb ("Update
  config files: disable CONFIG_USELIB (bsc#1219222)") because they are
  disabled at the moment. Add missing lines for (now disabled) CONFIG_USELIB
  option.
- commit 3d7309c
* Fri Feb  2 2024 tiwai@suse.de
- net: phy: realtek: add support for RTL8126A-integrated 5Gbps
  PHY (bsc#1217417).
- r8169: add support for RTL8126A (bsc#1217417).
- net: phy: realtek: add support for RTL8126A-integrated 5Gbps
  PHY (bsc#1217417).
- r8169: add support for RTL8126A (bsc#1217417).
- commit 12eff81
* Fri Feb  2 2024 tiwai@suse.de
- Update config files: disable CONFIG_USELIB (bsc#1219222)
  It's only for the old libc5. Let's reduce the possible attack surfaces.
- commit 4a42d0e
* Fri Feb  2 2024 tiwai@suse.de
- Update config files: disable CONFIG_USELIB (bsc#1219222)
  It's only for the old libc5. Let's reduce the possible attack surfaces.
- commit 077d05a
* Thu Feb  1 2024 ddiss@suse.de
- bcachefs: fix incorrect usage of REQ_OP_FLUSH (bsc#1219346).
- commit 6f58d8d
* Thu Feb  1 2024 jslaby@suse.cz
- mm, kmsan: fix infinite recursion due to RCU critical section
  (git-fixes).
- commit 0fa3c9e
* Thu Feb  1 2024 jslaby@suse.cz
- Linux 6.7.3 (bsc#1012628).
- soundwire: bus: introduce controller_id (bsc#1012628).
- soundwire: fix initializing sysfs for same devices on different
  buses (bsc#1012628).
- iio: adc: ad7091r: Set alert bit in config register
  (bsc#1012628).
- iio: adc: ad7091r: Allow users to configure device events
  (bsc#1012628).
- pipe: wakeup wr_wait after setting max_usage (bsc#1012628).
- powerpc/ps3_defconfig: Disable PPC64_BIG_ENDIAN_ELF_ABI_V2
  (bsc#1012628).
- ext4: allow for the last group to be marked as trimmed
  (bsc#1012628).
- async: Split async_schedule_node_domain() (bsc#1012628).
- async: Introduce async_schedule_dev_nocall() (bsc#1012628).
- PM: sleep: Fix possible deadlocks in core system-wide PM code
  (bsc#1012628).
- arm64: properly install vmlinuz.efi (bsc#1012628).
- OPP: Pass rounded rate to _set_opp() (bsc#1012628).
- btrfs: sysfs: validate scrub_speed_max value (bsc#1012628).
- crypto: lib/mpi - Fix unexpected pointer access in mpi_ec_init
  (bsc#1012628).
- erofs: fix lz4 inplace decompression (bsc#1012628).
- crypto: api - Disallow identical driver names (bsc#1012628).
- PM: hibernate: Enforce ordering during image
  compression/decompression (bsc#1012628).
- hwrng: core - Fix page fault dead lock on mmap-ed hwrng
  (bsc#1012628).
- crypto: s390/aes - Fix buffer overread in CTR mode
  (bsc#1012628).
- s390/vfio-ap: unpin pages on gisc registration failure
  (bsc#1012628).
- PM / devfreq: Fix buffer overflow in trans_stat_show
  (bsc#1012628).
- mtd: maps: vmu-flash: Fix the (mtd core) switch to ref counters
  (bsc#1012628).
- mtd: rawnand: Prevent crossing LUN boundaries during sequential
  reads (bsc#1012628).
- mtd: rawnand: Fix core interference with sequential reads
  (bsc#1012628).
- mtd: rawnand: Prevent sequential reads with on-die ECC engines
  (bsc#1012628).
- mtd: rawnand: Clarify conditions to enable continuous reads
  (bsc#1012628).
- soc: qcom: pmic_glink_altmode: fix port sanity check
  (bsc#1012628).
- media: imx355: Enable runtime PM before registering async
  sub-device (bsc#1012628).
- rpmsg: virtio: Free driver_override when rpmsg_remove()
  (bsc#1012628).
- media: ov9734: Enable runtime PM before registering async
  sub-device (bsc#1012628).
- media: ov13b10: Enable runtime PM before registering async
  sub-device (bsc#1012628).
- media: ov01a10: Enable runtime PM before registering async
  sub-device (bsc#1012628).
- soc: fsl: cpm1: tsa: Fix __iomem addresses declaration
  (bsc#1012628).
- soc: fsl: cpm1: qmc: Fix __iomem addresses declaration
  (bsc#1012628).
- soc: fsl: cpm1: qmc: Fix rx channel reset (bsc#1012628).
- s390/vfio-ap: always filter entire AP matrix (bsc#1012628).
- s390/vfio-ap: loop over the shadow APCB when filtering guest's
  AP configuration (bsc#1012628).
- s390/vfio-ap: let on_scan_complete() callback filter matrix
  and update guest's APCB (bsc#1012628).
- s390/vfio-ap: reset queues filtered from the guest's AP config
  (bsc#1012628).
- s390/vfio-ap: reset queues associated with adapter for queue
  unbound from driver (bsc#1012628).
- s390/vfio-ap: do not reset queue removed from host config
  (bsc#1012628).
- seq_buf: Make DECLARE_SEQ_BUF() usable (bsc#1012628).
- nbd: always initialize struct msghdr completely (bsc#1012628).
- mips: Fix max_mapnr being uninitialized on early stages
  (bsc#1012628).
- bus: mhi: host: Add alignment check for event ring read pointer
  (bsc#1012628).
- bus: mhi: host: Drop chan lock before queuing buffers
  (bsc#1012628).
- bus: mhi: host: Add spinlock to protect WP access when queueing
  TREs (bsc#1012628).
- parisc/firmware: Fix F-extend for PDC addresses (bsc#1012628).
- parisc/power: Fix power soft-off button emulation on qemu
  (bsc#1012628).
- iio: adc: ad7091r: Enable internal vref if external vref is
  not supplied (bsc#1012628).
- dmaengine: fsl-edma: fix eDMAv4 channel allocation issue
  (bsc#1012628).
- dmaengine: fix NULL pointer in channel unregistration function
  (bsc#1012628).
- dmaengine: idxd: Move dma_free_coherent() out of spinlocked
  context (bsc#1012628).
- dmaengine: xilinx: xdma: Fix the count of elapsed periods in
  cyclic mode (bsc#1012628).
- scsi: ufs: core: Remove the ufshcd_hba_exit() call from
  ufshcd_async_scan() (bsc#1012628).
- riscv: Fix module loading free order (bsc#1012628).
- riscv: Correctly free relocation hashtable on error
  (bsc#1012628).
- riscv: Fix relocation_hashtable size (bsc#1012628).
- riscv: Fix an off-by-one in get_early_cmdline() (bsc#1012628).
- scsi: core: Kick the requeue list after inserting when flushing
  (bsc#1012628).
- sh: ecovec24: Rename missed backlight field from fbdev to dev
  (bsc#1012628).
- smb: client: fix parsing of SMB3.1.1 POSIX create context
  (bsc#1012628).
- cifs: handle servers that still advertise multichannel after
  disabling (bsc#1012628).
- cifs: update iface_last_update on each query-and-update
  (bsc#1012628).
- ARM: dts: imx6q-apalis: add can power-up delay on ixora board
  (bsc#1012628).
- arm64: dts: qcom: sc8280xp-crd: fix eDP phy compatible
  (bsc#1012628).
- ARM: dts: qcom: sdx55: fix USB wakeup interrupt types
  (bsc#1012628).
- ARM: dts: samsung: exynos4210-i9100: Unconditionally enable
  LDO12 (bsc#1012628).
- ARM: dts: qcom: sdx55: fix pdc '#interrupt-cells' (bsc#1012628).
- arm64: dts: sprd: fix the cpu node for UMS512 (bsc#1012628).
- arm64: dts: rockchip: configure eth pad driver strength for
  orangepi r1 plus lts (bsc#1012628).
- arm64: dts: rockchip: Fix rk3588 USB power-domain clocks
  (bsc#1012628).
- arm64: dts: qcom: msm8916: Make blsp_dma controlled-remotely
  (bsc#1012628).
- arm64: dts: qcom: msm8939: Make blsp_dma controlled-remotely
  (bsc#1012628).
- arm64: dts: qcom: sc7180: fix USB wakeup interrupt types
  (bsc#1012628).
- arm64: dts: qcom: sdm845: fix USB wakeup interrupt types
  (bsc#1012628).
- arm64: dts: qcom: sdm670: fix USB wakeup interrupt types
  (bsc#1012628).
- arm64: dts: qcom: sm8150: fix USB wakeup interrupt types
  (bsc#1012628).
- arm64: dts: qcom: sc8180x: fix USB wakeup interrupt types
  (bsc#1012628).
- arm64: dts: qcom: sc7280: fix usb_1 wakeup interrupt types
  (bsc#1012628).
- arm64: dts: qcom: Add missing vio-supply for AW2013
  (bsc#1012628).
- ARM: dts: qcom: sdx55: fix USB DP/DM HS PHY interrupts
  (bsc#1012628).
- arm64: dts: qcom: sdm845: fix USB DP/DM HS PHY interrupts
  (bsc#1012628).
- arm64: dts: qcom: sdm845: fix USB SS wakeup (bsc#1012628).
- arm64: dts: qcom: sm8150: fix USB DP/DM HS PHY interrupts
  (bsc#1012628).
- arm64: dts: qcom: sm8150: fix USB SS wakeup (bsc#1012628).
- arm64: dts: qcom: sc8180x: fix USB DP/DM HS PHY interrupts
  (bsc#1012628).
- arm64: dts: qcom: sc8180x: fix USB SS wakeup (bsc#1012628).
- arm64: dts: qcom: sdm670: fix USB DP/DM HS PHY interrupts
  (bsc#1012628).
- arm64: dts: qcom: sdm670: fix USB SS wakeup (bsc#1012628).
- ARM: dts: qcom: sdx55: fix USB SS wakeup (bsc#1012628).
- lsm: new security_file_ioctl_compat() hook (bsc#1012628).
- dlm: use kernel_connect() and kernel_bind() (bsc#1012628).
- docs: kernel_abi.py: fix command injection (bsc#1012628).
- scripts/get_abi: fix source path leak (bsc#1012628).
- media: videobuf2-dma-sg: fix vmap callback (bsc#1012628).
- mmc: core: Use mrq.sbc in close-ended ffu (bsc#1012628).
- mmc: mmc_spi: remove custom DMA mapped buffers (bsc#1012628).
- media: i2c: st-mipid02: correct format propagation
  (bsc#1012628).
- media: mtk-jpeg: Fix timeout schedule error in
  mtk_jpegdec_worker (bsc#1012628).
- media: mtk-jpeg: Fix use after free bug due to error path
  handling in mtk_jpeg_dec_device_run (bsc#1012628).
- riscv: mm: Fixup compat arch_get_mmap_end (bsc#1012628).
- riscv: mm: Fixup compat mode boot failure (bsc#1012628).
- RISC-V: selftests: cbo: Ensure asm operands match constraints
  (bsc#1012628).
- arm64: Rename ARM64_WORKAROUND_2966298 (bsc#1012628).
- arm64: errata: Add Cortex-A510 speculative unprivileged load
  workaround (bsc#1012628).
- arm64/sme: Always exit sme_alloc() early with existing storage
  (bsc#1012628).
- arm64: entry: fix ARM64_WORKAROUND_SPECULATIVE_UNPRIV_LOAD
  (bsc#1012628).
- rtc: cmos: Use ACPI alarm for non-Intel x86 systems too
  (bsc#1012628).
- rtc: Adjust failure return code for cmos_set_alarm()
  (bsc#1012628).
- rtc: mc146818-lib: Adjust failure return code for
  mc146818_get_time() (bsc#1012628).
- rtc: Add support for configuring the UIP timeout for RTC reads
  (bsc#1012628).
- rtc: Extend timeout for waiting for UIP to clear to 1s
  (bsc#1012628).
- efi: disable mirror feature during crashkernel (bsc#1012628).
- kdump: defer the insertion of crashkernel resources
  (bsc#1012628).
- ubifs: ubifs_symlink: Fix memleak of inode->i_link in error path
  (bsc#1012628).
- thermal: gov_power_allocator: avoid inability to reset a cdev
  (bsc#1012628).
- fs/proc/task_mmu: move mmu notification mechanism inside mm lock
  (bsc#1012628).
- kexec: do syscore_shutdown() in kernel_kexec (bsc#1012628).
- selftests: mm: hugepage-vmemmap fails on 64K page size systems
  (bsc#1012628).
- mm/rmap: fix misplaced parenthesis of a likely() (bsc#1012628).
- mm: migrate: fix getting incorrect page mapping during page
  migration (bsc#1012628).
- mm/sparsemem: fix race in accessing memory_section->usage
  (bsc#1012628).
- rename(): fix the locking of subdirectories (bsc#1012628).
- serial: sc16is7xx: improve regmap debugfs by using one regmap
  per port (bsc#1012628).
- serial: sc16is7xx: remove wasteful static buffer in
  sc16is7xx_regmap_name() (bsc#1012628).
- serial: sc16is7xx: remove global regmap from struct
  sc16is7xx_port (bsc#1012628).
- serial: sc16is7xx: remove unused line structure member
  (bsc#1012628).
- serial: sc16is7xx: change EFR lock to operate on each channels
  (bsc#1012628).
- serial: sc16is7xx: convert from _raw_ to _noinc_ regmap
  functions for FIFO (bsc#1012628).
- serial: sc16is7xx: fix unconditional activation of THRI
  interrupt (bsc#1012628).
- serial: sc16is7xx: fix invalid sc16is7xx_lines bitfield in
  case of probe error (bsc#1012628).
- serial: sc16is7xx: remove obsolete loop in sc16is7xx_port_irq()
  (bsc#1012628).
- serial: sc16is7xx: improve do/while loop in sc16is7xx_irq()
  (bsc#1012628).
- mm: page_alloc: unreserve highatomic page blocks before oom
  (bsc#1012628).
- ksmbd: set v2 lease version on lease upgrade (bsc#1012628).
- wifi: ath11k: rely on mac80211 debugfs handling for vif
  (bsc#1012628).
- Revert "drm/amd: Enable PCIe PME from D3" (bsc#1012628).
- ksmbd: fix potential circular locking issue in smb2_set_ea()
  (bsc#1012628).
- ksmbd: don't increment epoch if current state and request
  state are same (bsc#1012628).
- ksmbd: send lease break notification on FILE_RENAME_INFORMATION
  (bsc#1012628).
- ksmbd: Add missing set_freezable() for freezable kthread
  (bsc#1012628).
- SUNRPC: use request size to initialize bio_vec in
  svc_udp_sendto() (bsc#1012628).
- wifi: mac80211: fix potential sta-link leak (bsc#1012628).
- btrfs: scrub: avoid use-after-free when chunk length is not
  64K aligned (bsc#1012628).
- net/smc: fix illegal rmb_desc access in SMC-D connection dump
  (bsc#1012628).
- selftests: bonding: Increase timeout to 1200s (bsc#1012628).
- tcp: make sure init the accept_queue's spinlocks once
  (bsc#1012628).
- bnxt_en: Wait for FLR to complete during probe (bsc#1012628).
- bnxt_en: Prevent kernel warning when running offline self test
  (bsc#1012628).
- vlan: skip nested type that is not IFLA_VLAN_QOS_MAPPING
  (bsc#1012628).
- llc: make llc_ui_sendmsg() more robust against bonding changes
  (bsc#1012628).
- llc: Drop support for ETH_P_TR_802_2 (bsc#1012628).
- udp: fix busy polling (bsc#1012628).
- idpf: distinguish vports by the dev_port attribute
  (bsc#1012628).
- net: fix removing a namespace with conflicting altnames
  (bsc#1012628).
- tun: fix missing dropped counter in tun_xdp_act (bsc#1012628).
- tun: add missing rx stats accounting in tun_xdp_act
  (bsc#1012628).
- dpll: fix broken error path in dpll_pin_alloc(..) (bsc#1012628).
- dpll: fix pin dump crash for rebound module (bsc#1012628).
- dpll: fix userspace availability of pins (bsc#1012628).
- dpll: fix register pin with unregistered parent pin
  (bsc#1012628).
- net: micrel: Fix PTP frame parsing for lan8814 (bsc#1012628).
- net/rds: Fix UBSAN: array-index-out-of-bounds in rds_cmsg_recv
  (bsc#1012628).
- netfs, fscache: Prevent Oops in fscache_put_cache()
  (bsc#1012628).
- tracing: Ensure visibility when inserting an element into
  tracing_map (bsc#1012628).
- afs: Hide silly-rename files from userspace (bsc#1012628).
- afs: fix the usage of read_seqbegin_or_lock() in
  afs_find_server*() (bsc#1012628).
- afs: Add comments on abort handling (bsc#1012628).
- afs: Turn the afs_addr_list address array into an array of
  structs (bsc#1012628).
- rxrpc, afs: Allow afs to pin rxrpc_peer objects (bsc#1012628).
- afs: Handle the VIO and UAEIO aborts explicitly (bsc#1012628).
- afs: Use op->nr_iterations=-1 to indicate to begin fileserver
  iteration (bsc#1012628).
- afs: Wrap most op->error accesses with inline funcs
  (bsc#1012628).
- afs: Don't put afs_call in afs_wait_for_call_to_complete()
  (bsc#1012628).
- afs: Simplify error handling (bsc#1012628).
- afs: Fix error handling with lookup via FS.InlineBulkStatus
  (bsc#1012628).
- tcp: Add memory barrier to tcp_push() (bsc#1012628).
- selftest: Don't reuse port for SO_INCOMING_CPU test
  (bsc#1012628).
- netlink: fix potential sleeping issue in mqueue_flush_file
  (bsc#1012628).
- ipv6: init the accept_queue's spinlocks in inet6_create
  (bsc#1012628).
- selftests: fill in some missing configs for net (bsc#1012628).
- net/sched: flower: Fix chain template offload (bsc#1012628).
- net/mlx5e: Fix operation precedence bug in port timestamping
  napi_poll context (bsc#1012628).
- net/mlx5e: Fix inconsistent hairpin RQT sizes (bsc#1012628).
- net/mlx5e: Fix peer flow lists handling (bsc#1012628).
- net/mlx5: Fix a WARN upon a callback command failure
  (bsc#1012628).
- net/mlx5: Bridge, fix multicast packets sent to uplink
  (bsc#1012628).
- net/mlx5: DR, Use the right GVMI number for drop action
  (bsc#1012628).
- net/mlx5: DR, Can't go to uplink vport on RX rule (bsc#1012628).
- net/mlx5: Use mlx5 device constant for selecting CQ period
  mode for ASO (bsc#1012628).
- net/mlx5e: Allow software parsing when IPsec crypto is enabled
  (bsc#1012628).
- net/mlx5e: Ignore IPsec replay window values on sender side
  (bsc#1012628).
- net/mlx5e: fix a double-free in arfs_create_groups
  (bsc#1012628).
- net/mlx5e: fix a potential double-free in fs_any_create_groups
  (bsc#1012628).
- rcu: Defer RCU kthreads wakeup when CPU is dying (bsc#1012628).
- netfilter: nft_limit: reject configurations that cause integer
  overflow (bsc#1012628).
- netfilter: nf_tables: restrict anonymous set and map names to
  16 bytes (bsc#1012628).
- netfilter: nf_tables: validate NFPROTO_* family (bsc#1012628).
- net: stmmac: Wait a bit for the reset to take effect
  (bsc#1012628).
- net: mvpp2: clear BM pool before initialization (bsc#1012628).
- selftests: net: fix rps_default_mask with >32 CPUs
  (bsc#1012628).
- selftests: netdevsim: fix the udp_tunnel_nic test (bsc#1012628).
- xsk: recycle buffer in case Rx queue was full (bsc#1012628).
- xsk: make xsk_buff_pool responsible for clearing xdp_buff::flags
  (bsc#1012628).
- xsk: fix usage of multi-buffer BPF helpers for ZC XDP
  (bsc#1012628).
- ice: work on pre-XDP prog frag count (bsc#1012628).
- i40e: handle multi-buffer packets that are shrunk by xdp prog
  (bsc#1012628).
- ice: remove redundant xdp_rxq_info registration (bsc#1012628).
- intel: xsk: initialize skb_frag_t::bv_offset in ZC drivers
  (bsc#1012628).
- ice: update xdp_rxq_info::frag_size for ZC enabled Rx queue
  (bsc#1012628).
- xdp: reflect tail increase for MEM_TYPE_XSK_BUFF_POOL
  (bsc#1012628).
- i40e: set xdp_rxq_info::frag_size (bsc#1012628).
- i40e: update xdp_rxq_info::frag_size for ZC enabled Rx queue
  (bsc#1012628).
- fjes: fix memleaks in fjes_hw_setup (bsc#1012628).
- selftests: bonding: do not test arp/ns target with mode
  balance-alb/tlb (bsc#1012628).
- net: fec: fix the unhandled context fault from smmu
  (bsc#1012628).
- tsnep: Remove FCS for XDP data path (bsc#1012628).
- tsnep: Fix XDP_RING_NEED_WAKEUP for empty fill ring
  (bsc#1012628).
- btrfs: zoned: fix lock ordering in btrfs_zone_activate()
  (bsc#1012628).
- btrfs: avoid copying BTRFS_ROOT_SUBVOL_DEAD flag to snapshot
  of subvolume being deleted (bsc#1012628).
- btrfs: ref-verify: free ref cache before clearing mount opt
  (bsc#1012628).
- btrfs: tree-checker: fix inline ref size in error messages
  (bsc#1012628).
- btrfs: don't warn if discard range is not aligned to sector
  (bsc#1012628).
- btrfs: defrag: reject unknown flags of
  btrfs_ioctl_defrag_range_args (bsc#1012628).
- btrfs: don't abort filesystem when attempting to snapshot
  deleted subvolume (bsc#1012628).
- rbd: don't move requests to the running list on errors
  (bsc#1012628).
- exec: Fix error handling in begin_new_exec() (bsc#1012628).
- wifi: iwlwifi: fix a memory corruption (bsc#1012628).
- nfsd: fix RELEASE_LOCKOWNER (bsc#1012628).
- ovl: mark xwhiteouts directory with overlay.opaque='x'
  (bsc#1012628).
- hv_netvsc: Calculate correct ring size when PAGE_SIZE is not
  4 Kbytes (bsc#1012628).
- netfilter: nft_chain_filter: handle NETDEV_UNREGISTER for
  inet/ingress basechain (bsc#1012628).
- netfilter: nf_tables: reject QUEUE/DROP verdict parameters
  (bsc#1012628).
- platform/x86: intel-uncore-freq: Fix types in sysfs callbacks
  (bsc#1012628).
- platform/x86: p2sb: Allow p2sb_bar() calls during PCI device
  probe (bsc#1012628).
- ksmbd: fix global oob in ksmbd_nl_policy (bsc#1012628).
- firmware: arm_scmi: Check mailbox/SMT channel for consistency
  (bsc#1012628).
- Revert "drivers/firmware: Move sysfb_init() from device_initcall
  to subsys_initcall_sync" (bsc#1012628).
- drm/amdgpu: Fix the null pointer when load rlc firmware
  (bsc#1012628).
- xfs: read only mounts with fsopen mount API are busted
  (bsc#1012628).
- gpiolib: acpi: Ignore touchpad wakeup on GPD G1619-04
  (bsc#1012628).
- cpufreq: intel_pstate: Refine computation of P-state for given
  frequency (bsc#1012628).
- Revert "drm/i915/dsi: Do display on sequence later on icl+"
  (bsc#1012628).
- drm: Don't unref the same fb many times by mistake due to
  deadlock handling (bsc#1012628).
- drm/i915/psr: Only allow PSR in LPSP mode on HSW non-ULT
  (bsc#1012628).
- drm/bridge: nxp-ptn3460: fix i2c_master_send() error checking
  (bsc#1012628).
- drm: Fix TODO list mentioning non-KMS drivers (bsc#1012628).
- drm/tidss: Fix atomic_flush check (bsc#1012628).
- drm: Disable the cursor plane on atomic contexts with
  virtualized drivers (bsc#1012628).
- drm/virtio: Disable damage clipping if FB changed since last
  page-flip (bsc#1012628).
- drm: Allow drivers to indicate the damage helpers to ignore
  damage clips (bsc#1012628).
- drm/amd/display: fix bandwidth validation failure on DCN 2.1
  (bsc#1012628).
- drm/amd/display: Disable PSR-SU on Parade 0803 TCON again
  (bsc#1012628).
- Revert "drm/amd/display: fix bandwidth validation failure on
  DCN 2.1" (bsc#1012628).
- drm/bridge: nxp-ptn3460: simplify some error checking
  (bsc#1012628).
- drm/amd/display: Fix a debugfs null pointer error (bsc#1012628).
- drm/amdgpu: Enable GFXOFF for Compute on GFX11 (bsc#1012628).
- drm/amdgpu: drop exp hw support check for GC 9.4.3
  (bsc#1012628).
- drm/amdgpu: update regGL2C_CTRL4 value in golden setting
  (bsc#1012628).
- drm/amdgpu: correct the cu count for gfx v11 (bsc#1012628).
- drm/amd/pm: Fix smuv13.0.6 current clock reporting
  (bsc#1012628).
- drm/amd/pm: Add error log for smu v13.0.6 reset (bsc#1012628).
- drm/amd/display: Fix variable deferencing before NULL check
  in edp_setup_replay() (bsc#1012628).
- drm/amd/display: Fix DML2 watermark calculation (bsc#1012628).
- drm/amd/display: Port DENTIST hang and TDR fixes to OTG disable
  W/A (bsc#1012628).
- drm/amd/display: Align the returned error code with legacy DP
  (bsc#1012628).
- drm/amd/display: Fix late derefrence 'dsc' check in
  'link_set_dsc_pps_packet()' (bsc#1012628).
- drm/amd/display: Fix a switch statement in
  populate_dml_output_cfg_from_stream_state() (bsc#1012628).
- drm/amd/amdgpu: Assign GART pages to AMD device mapping
  (bsc#1012628).
- drm/amd/pm: Fetch current power limit from FW (bsc#1012628).
- drm/amdgpu: Avoid fetching vram vendor information
  (bsc#1012628).
- drm/amdgpu: Show vram vendor only if available (bsc#1012628).
- drm/amd/pm: update the power cap setting (bsc#1012628).
- drm/amdgpu/pm: Fix the power source flag error (bsc#1012628).
- drm/amd/display: Fix uninitialized variable usage in core_link_
  'read_dpcd() & write_dpcd()' functions (bsc#1012628).
- thermal: intel: hfi: Refactor enabling code into helper
  functions (bsc#1012628).
- thermal: intel: hfi: Disable an HFI instance when all its CPUs
  go offline (bsc#1012628).
- thermal: intel: hfi: Add syscore callbacks for system-wide PM
  (bsc#1012628).
- media: v4l: cci: Include linux/bits.h (bsc#1012628).
- media: v4l: cci: Add macros to obtain register width and address
  (bsc#1012628).
- media: v4l2-cci: Add support for little-endian encoded registers
  (bsc#1012628).
- media: i2c: imx290: Properly encode registers as little-endian
  (bsc#1012628).
- btrfs: zoned: factor out prepare_allocation_zoned()
  (bsc#1012628).
- btrfs: zoned: optimize hint byte for zoned allocator
  (bsc#1012628).
- drm/amd/display: do not send commands to DMUB if DMUB is
  inactive from S3 (bsc#1012628).
- drm/amd/display: Refactor DMCUB enter/exit idle interface
  (bsc#1012628).
- drm/amd/display: Wake DMCUB before sending a command
  (bsc#1012628).
- drm/amd/display: Wake DMCUB before executing GPINT commands
  (bsc#1012628).
- drm/amd/display: Fix conversions between bytes and KB
  (bsc#1012628).
- drm/panel-edp: Add AUO B116XTN02, BOE NT116WHM-N21,836X2,
  NV116WHM-N49 V8.0 (bsc#1012628).
- drm/panel-edp: drm/panel-edp: Fix AUO B116XAK01 name and timing
  (bsc#1012628).
- drm/panel-edp: drm/panel-edp: Fix AUO B116XTN02 name
  (bsc#1012628).
- drm/amd/display: Fix hang/underflow when transitioning to ODM4:1
  (bsc#1012628).
- drm/amd/display: Disconnect phantom pipe OPP from OPTC being
  disabled (bsc#1012628).
- drm/amd/display: Clear OPTC mem select on disable (bsc#1012628).
- drm/amd/display: Add logging resource checks (bsc#1012628).
- drm/amd/display: update pixel clock params after stream slice
  count change in context (bsc#1012628).
- drm/amd/display: Init link enc resources in dc_state only if
  res_pool presents (bsc#1012628).
- drm/amdgpu: Enable tunneling on high-priority compute queues
  (bsc#1012628).
- drm/amdgpu/gfx10: set UNORD_DISPATCH in compute MQDs
  (bsc#1012628).
- drm/amdgpu/gfx11: set UNORD_DISPATCH in compute MQDs
  (bsc#1012628).
- drm/bridge: parade-ps8640: Wait for HPD when doing an AUX
  transfer (bsc#1012628).
- drm: panel-simple: add missing bus flags for Tianma
  tm070jvhg[30/33] (bsc#1012628).
- drm/panel: samsung-s6d7aa0: drop DRM_BUS_FLAG_DE_HIGH for
  lsl080al02 (bsc#1012628).
- drm/panel/raydium-rm692e5: select CONFIG_DRM_DISPLAY_DP_HELPER
  (bsc#1012628).
- drm/bridge: sii902x: Fix probing race issue (bsc#1012628).
- drm/bridge: sii902x: Fix audio codec unregistration
  (bsc#1012628).
- drm/bridge: parade-ps8640: Ensure bridge is suspended in
  .post_disable() (bsc#1012628).
- drm/bridge: parade-ps8640: Make sure we drop the AUX mutex in
  the error case (bsc#1012628).
- memblock: fix crash when reserved memory is not added to memory
  (bsc#1012628).
- drm/exynos: fix accidental on-stack copy of exynos_drm_plane
  (bsc#1012628).
- drm/exynos: gsc: minor fix for loop iteration in
  gsc_runtime_resume (bsc#1012628).
- firmware: arm_scmi: Use xa_insert() to store opps (bsc#1012628).
- firmware: arm_scmi: Use xa_insert() when saving raw queues
  (bsc#1012628).
- firmware: arm_scmi: Fix the clock protocol version for v3.2
  (bsc#1012628).
- firmware: arm_ffa: Add missing rwlock_init() in
  ffa_setup_partitions() (bsc#1012628).
- firmware: arm_ffa: Add missing rwlock_init() for the driver
  partition (bsc#1012628).
- firmware: arm_ffa: Check xa_load() return value (bsc#1012628).
- platform/x86: wmi: Fix error handling in legacy WMI notify
  handler functions (bsc#1012628).
- gpio: eic-sprd: Clear interrupt after set the interrupt type
  (bsc#1012628).
- ARM: dts: exynos4212-tab3: add samsung,invert-vclk flag to fimd
  (bsc#1012628).
- platform/mellanox: mlxbf-pmc: Fix offset calculation for
  crspace events (bsc#1012628).
- spi: intel-pci: Remove Meteor Lake-S SoC PCI ID from the list
  (bsc#1012628).
- block: Move checking GENHD_FL_NO_PART to bdev_add_partition()
  (bsc#1012628).
- drm/bridge: anx7625: Ensure bridge is suspended in disable()
  (bsc#1012628).
- cpufreq/amd-pstate: Fix setting scaling max/min freq values
  (bsc#1012628).
- spi: bcm-qspi: fix SFDP BFPT read by usig mspi read
  (bsc#1012628).
- spi: spi-cadence: Reverse the order of interleaved write and
  read operations (bsc#1012628).
- cifs: fix stray unlock in cifs_chan_skip_or_disable
  (bsc#1012628).
- spi: fix finalize message on error return (bsc#1012628).
- LoongArch/smp: Call rcutree_report_cpu_starting() at tlb_init()
  (bsc#1012628).
- MIPS: lantiq: register smp_ops on non-smp platforms
  (bsc#1012628).
- riscv: dts: sophgo: separate sg2042 mtime and mtimecmp to fit
  aclint format (bsc#1012628).
- drm: bridge: samsung-dsim: Don't use FORCE_STOP_STATE
  (bsc#1012628).
- platform/x86/intel/ifs: Call release_firmware() when handling
  errors (bsc#1012628).
- =?UTF-8?q?cxl/region=EF=BC=9AFix=20overflow=20issue=20in?=
  =?UTF-8?q?=20alloc=5Fhpa()?= (bsc#1012628).
- mips: Call lose_fpu(0) before initializing fcr31 in
  mips_set_personality_nan (bsc#1012628).
- genirq: Initialize resend_node hlist for all interrupt
  descriptors (bsc#1012628).
- clocksource: Skip watchdog check for large watchdog intervals
  (bsc#1012628).
- tick/sched: Preserve number of idle sleeps across CPU hotplug
  events (bsc#1012628).
- x86/entry/ia32: Ensure s32 is sign extended to s64
  (bsc#1012628).
- Rename to
  patches.kernel.org/6.7.3-114-nouveau-vmm-don-t-set-addr-on-the-fail-path-to-.patch.
- Rename to
  patches.kernel.org/6.7.3-115-nouveau-gsp-handle-engines-in-runl-without-nons.patch.
- Rename to
  patches.kernel.org/6.7.3-246-Revert-nouveau-push-event-block-allowing-out-of.patch.
- Rename to
  patches.kernel.org/6.7.3-315-futex-Prevent-the-reuse-of-stale-pi_state.patch.
- Update config files.
- commit 036d448
* Wed Jan 31 2024 msuchanek@suse.de
- kernel-source: Fix description typo
- commit 8abff35
* Wed Jan 31 2024 dwagner@suse.de
- nvmet-tcp: remove boilerplate code (bsc#1217986 bsc#1217988
  bsc#1217989 CVE-2023-6535 CVE-2023-6536 CVE-2023-6356).
- commit 6125659
* Wed Jan 31 2024 dwagner@suse.de
- Update
  patches.kernel.org/6.7.2-549-nvmet-tcp-Fix-a-kernel-panic-when-host-sends-an.patch
  (bsc#1012628 bsc#1217987 bsc#1217988 bsc#1217989 CVE-2023-6535
  CVE-2023-6536 CVE-2023-6356).
- Update
  patches.kernel.org/6.7.2-550-nvmet-tcp-fix-a-crash-in-nvmet_req_complete.patch
  (bsc#1012628 bsc#1217987 bsc#1217988 bsc#1217989 CVE-2023-6535
  CVE-2023-6536 CVE-2023-6356).
- Update
  patches.kernel.org/6.7.2-571-nvmet-tcp-Fix-the-H2C-expected-PDU-len-calculat.patch
  (bsc#1012628 bsc#1217987 bsc#1217988 bsc#1217989 CVE-2023-6535
  CVE-2023-6536 CVE-2023-6356).
- commit 1340412
* Tue Jan 30 2024 tiwai@suse.de
- Revert "nouveau: push event block/allowing out of the fence
  context" (bsc#1219275).
- nouveau/vmm: don't set addr on the fail path to avoid warning
  (bsc#1219275).
- nouveau/gsp: handle engines in runl without nonstall interrupts
  (bsc#1219275).
- commit f5095eb
* Tue Jan 30 2024 tiwai@suse.de
- wifi: brcmfmac: Fix use-after-free bug in brcmf_cfg80211_detach
  (CVE-2023-47233 bsc#1216702).
- commit b9432ba
* Tue Jan 30 2024 jslaby@suse.cz
- rpm/constraints.in: set jobs for riscv to 8
  The same workers are used for x86 and riscv and the riscv builds take
  ages. So align the riscv jobs count to x86.
- commit b2c82b9
* Tue Jan 30 2024 jslaby@suse.cz
- Refresh
  patches.suse/mm-huge_memory-don-t-force-huge-page-alignment-on-32.patch.
  Update upstream status and move to sorted section.
- commit ab524e9
* Tue Jan 30 2024 jslaby@suse.cz
- Refresh
  patches.suse/mm-huge_memory-don-t-force-huge-page-alignment-on-32.patch.
- Rename to
  patches.suse/futex-Prevent-the-reuse-of-stale-pi_state.patch (bsc#1218801).
  Update upstream status and fix reference.
- commit 73499be
* Tue Jan 30 2024 jslaby@suse.cz
- Update config files. (bsc#1219328)
  Synchronize PSTORE_CONSOLE, PSTORE_PMSG, and PSTORE_FTRACE with
  SLE15-SP6.
- commit 116df61
* Mon Jan 29 2024 tiwai@suse.de
- wifi: mac80211: improve CSA/ECSA connection refusal
  (bsc#1219192).
- wifi: cfg80211: detect stuck ECSA element in probe resp
  (bsc#1219192).
- commit 31edb3f
* Mon Jan 29 2024 tiwai@suse.de
- Re-enable CONFIG_SND_SOC_WSA883X=m for Thinkpad X13s audio (bsc#1217412)
  It was lost during merge from master branch
- commit 4f6ccdc
* Mon Jan 29 2024 jslaby@suse.cz
- Update config files.
  Only run oldconfig.
- commit f71b395
* Mon Jan 29 2024 mkubecek@suse.cz
- Update to 6.8-rc2
- eliminate 1 patch
  - patches.suse/futex-Avoid-reusing-outdated-pi_state.patch (e626cb02ee83)
- refresh configs
- commit 023a12a
* Fri Jan 26 2024 msuchanek@suse.de
- mkspec: Use variant in constraints template
  Constraints are not applied consistently with kernel package variants.
  Add variant to the constraints template as appropriate, and expand it
  in mkspec.
- commit cc68ab9
* Fri Jan 26 2024 jslaby@suse.cz
- rpm/constraints.in: add static multibuild packages
  Commit 841012b049a5 (rpm/mkspec: use kernel-source: prefix for
  constraints on multibuild) added "kernel-source:" prefix to the
  dynamically generated kernels. But there are also static ones like
  kernel-docs. Those fail to build as the constraints are still not
  applied.
  So add the prefix also to the static ones.
  Note kernel-docs-rt is given kernel-source-rt prefix. I am not sure it
  will ever be multibuilt...
- commit c2e0681
* Fri Jan 26 2024 jslaby@suse.cz
- Linux 6.7.2 (bsc#1012628).
- x86/lib: Fix overflow when counting digits (bsc#1012628).
- x86/mce/inject: Clear test status value (bsc#1012628).
- EDAC/thunderx: Fix possible out-of-bounds string access
  (bsc#1012628).
- powerpc: add crtsavres.o to always-y instead of extra-y
  (bsc#1012628).
- fs/pipe: Fix lockdep false-positive in watchqueue pipe_write()
  (bsc#1012628).
- x86: Fix CPUIDLE_FLAG_IRQ_ENABLE leaking timer reprogram
  (bsc#1012628).
- powerpc/44x: select I2C for CURRITUCK (bsc#1012628).
- powerpc/pseries/memhp: Fix access beyond end of drmem array
  (bsc#1012628).
- x86/microcode/intel: Set new revision only after a successful
  update (bsc#1012628).
- perf/arm-cmn: Fix HN-F class_occup_id events (bsc#1012628).
- drivers/perf: hisi: Fix some event id for HiSilicon UC pmu
  (bsc#1012628).
- KVM: PPC: Book3S HV: Handle pending exceptions on guest entry
  with MSR_EE (bsc#1012628).
- selftests/powerpc: Fix error handling in FPU/VMX preemption
  tests (bsc#1012628).
- powerpc/hv-gpci: Add return value check in
  affinity_domain_via_partition_show function (bsc#1012628).
- powerpc/rtas: Avoid warning on invalid token argument to
  sys_rtas() (bsc#1012628).
- powerpc/powernv: Add a null pointer check to
  scom_debug_init_one() (bsc#1012628).
- powerpc/powernv: Add a null pointer check in opal_event_init()
  (bsc#1012628).
- powerpc/powernv: Add a null pointer check in
  opal_powercap_init() (bsc#1012628).
- powerpc/imc-pmu: Add a null pointer check in
  update_events_in_group() (bsc#1012628).
- sched/fair: Update min_vruntime for reweight_entity() correctly
  (bsc#1012628).
- perf/x86/intel/uncore: Fix NULL pointer dereference issue in
  upi_fill_topology() (bsc#1012628).
- spi: spi-zynqmp-gqspi: fix driver kconfig dependencies
  (bsc#1012628).
- mtd: rawnand: Increment IFC_TIMEOUT_MSECS for nand controller
  response (bsc#1012628).
- ACPI: video: check for error while searching for backlight
  device parent (bsc#1012628).
- ACPI: LPIT: Avoid u32 multiplication overflow (bsc#1012628).
- KEYS: encrypted: Add check for strsep (bsc#1012628).
- spi: cadence-quadspi: add missing clk_disable_unprepare()
  in cqspi_probe() (bsc#1012628).
- platform/x86/intel/vsec: Fix xa_alloc memory leak (bsc#1012628).
- cpufreq: scmi: process the result of
  devm_of_clk_add_hw_provider() (bsc#1012628).
- calipso: fix memory leak in netlbl_calipso_add_pass()
  (bsc#1012628).
- efivarfs: force RO when remounting if SetVariable is not
  supported (bsc#1012628).
- efivarfs: Free s_fs_info on unmount (bsc#1012628).
- spi: sh-msiof: Enforce fixed DTDL for R-Car H3 (bsc#1012628).
- ACPI: LPSS: Fix the fractional clock divider flags
  (bsc#1012628).
- ACPI: extlog: Clear Extended Error Log status when RAS_CEC
  handled the error (bsc#1012628).
- thermal: core: Fix NULL pointer dereference in zone registration
  error path (bsc#1012628).
- kunit: debugfs: Fix unchecked dereference in
  debugfs_print_results() (bsc#1012628).
- kunit: debugfs: Handle errors from alloc_string_stream()
  (bsc#1012628).
- mtd: Fix gluebi NULL pointer dereference caused by ftl notifier
  (bsc#1012628).
- cpuidle: haltpoll: Do not enable interrupts when entering idle
  (bsc#1012628).
- drivers/thermal/loongson2_thermal: Fix incorrect PTR_ERR()
  judgment (bsc#1012628).
- selinux: Fix error priority for bind with AF_UNSPEC on PF_INET6
  socket (bsc#1012628).
- crypto: rsa - add a check for allocation failure (bsc#1012628).
- crypto: qat - prevent underflow in rp2srv_store() (bsc#1012628).
- crypto: jh7110 - Correct deferred probe return (bsc#1012628).
- crypto: virtio - Handle dataq logic with tasklet (bsc#1012628).
- crypto: qat - add sysfs_added flag for ras (bsc#1012628).
- crypto: qat - add sysfs_added flag for rate limiting
  (bsc#1012628).
- crypto: sa2ul - Return crypto_aead_setkey to transfer the error
  (bsc#1012628).
- crypto: ccp - fix memleak in ccp_init_dm_workarea (bsc#1012628).
- crypto: af_alg - Disallow multiple in-flight AIO requests
  (bsc#1012628).
- crypto: qat - fix error path in add_update_sla() (bsc#1012628).
- crypto: qat - fix mutex ordering in adf_rl (bsc#1012628).
- crypto: qat - add NULL pointer check (bsc#1012628).
- hwrng: stm32 - add missing clk_disable_unprepare() in
  stm32_rng_init() (bsc#1012628).
- crypto: safexcel - Add error handling for dma_map_sg() calls
  (bsc#1012628).
- crypto: sahara - remove FLAGS_NEW_KEY logic (bsc#1012628).
- crypto: sahara - fix cbc selftest failure (bsc#1012628).
- crypto: sahara - fix ahash selftest failure (bsc#1012628).
- crypto: sahara - fix processing requests with cryptlen <
  sg->length (bsc#1012628).
- crypto: sahara - fix error handling in
  sahara_hw_descriptor_create() (bsc#1012628).
- crypto: hisilicon/qm - save capability registers in qm init
  process (bsc#1012628).
- crypto: hisilicon/zip - add zip comp high perf mode
  configuration (bsc#1012628).
- crypto: hisilicon/qm - add a function to set qm algs
  (bsc#1012628).
- crypto: hisilicon/hpre - save capability registers in probe
  process (bsc#1012628).
- crypto: hisilicon/sec2 - save capability registers in probe
  process (bsc#1012628).
- crypto: hisilicon/zip - save capability registers in probe
  process (bsc#1012628).
- pstore: ram_core: fix possible overflow in
  persistent_ram_init_ecc() (bsc#1012628).
- erofs: fix memory leak on short-lived bounced pages
  (bsc#1012628).
- fs: indicate request originates from old mount API
  (bsc#1012628).
- gfs2: Fix kernel NULL pointer dereference in gfs2_rgrp_dump
  (bsc#1012628).
- gfs2: fix kernel BUG in gfs2_quota_cleanup (bsc#1012628).
- dlm: fix format seq ops type 4 (bsc#1012628).
- crypto: virtio - Wait for tasklet to complete on device remove
  (bsc#1012628).
- crypto: sahara - avoid skcipher fallback code duplication
  (bsc#1012628).
- crypto: sahara - handle zero-length aes requests (bsc#1012628).
- crypto: sahara - fix ahash reqsize (bsc#1012628).
- crypto: sahara - fix wait_for_completion_timeout() error
  handling (bsc#1012628).
- crypto: sahara - improve error handling in sahara_sha_process()
  (bsc#1012628).
- crypto: sahara - fix processing hash requests with req->nbytes <
  sg->length (bsc#1012628).
- crypto: sahara - do not resize req->src when doing hash
  operations (bsc#1012628).
- crypto: scomp - fix req->dst buffer overflow (bsc#1012628).
- csky: fix arch_jump_label_transform_static override
  (bsc#1012628).
- blocklayoutdriver: Fix reference leak of pnfs_device_node
  (bsc#1012628).
- NFS: Use parent's objective cred in nfs_access_login_time()
  (bsc#1012628).
- NFSv4.1/pnfs: Ensure we handle the error NFS4ERR_RETURNCONFLICT
  (bsc#1012628).
- SUNRPC: fix _xprt_switch_find_current_entry logic (bsc#1012628).
- pNFS: Fix the pnfs block driver's calculation of layoutget size
  (bsc#1012628).
- SUNRPC: Fixup v4.1 backchannel request timeouts (bsc#1012628).
- asm-generic: Fix 32 bit __generic_cmpxchg_local (bsc#1012628).
- arm64: dts: qcom: qrb4210-rb2: don't force usb peripheral mode
  (bsc#1012628).
- arm64: dts: qcom: sc8280xp-x13s: Use the correct DP PHY
  compatible (bsc#1012628).
- arm64: dts: qcom: sc8280xp-x13s: add missing camera LED pin
  config (bsc#1012628).
- ARM: dts: qcom: msm8226: provide dsi phy clocks to mmcc
  (bsc#1012628).
- wifi: plfxlc: check for allocation failure in
  plfxlc_usb_wreq_async() (bsc#1012628).
- wifi: rtw88: fix RX filter in FIF_ALLMULTI flag (bsc#1012628).
- bpf, lpm: Fix check prefixlen before walking trie (bsc#1012628).
- bpf: Add KF_RCU flag to bpf_refcount_acquire_impl (bsc#1012628).
- bpf: Add crosstask check to __bpf_get_stack (bsc#1012628).
- wifi: ath11k: Defer on rproc_get failure (bsc#1012628).
- wifi: libertas: stop selecting wext (bsc#1012628).
- ARM: dts: qcom: apq8064: correct XOADC register address
  (bsc#1012628).
- scsi: lpfc: Fix list_entry null check warning in
  lpfc_cmpl_els_plogi() (bsc#1012628).
- net/ncsi: Fix netlink major/minor version numbers (bsc#1012628).
- firmware: ti_sci: Fix an off-by-one in ti_sci_debugfs_create()
  (bsc#1012628).
- scsi: bfa: Use the proper data type for BLIST flags
  (bsc#1012628).
- wifi: ath12k: fix the error handler of rfkill config
  (bsc#1012628).
- wifi: rtlwifi: rtl8821ae: phy: fix an undefined bitwise shift
  behavior (bsc#1012628).
- arm64: dts: ti: k3-am62a-main: Fix GPIO pin count in DT nodes
  (bsc#1012628).
- arm64: dts: ti: k3-am65-main: Fix DSS irq trigger type
  (bsc#1012628).
- arm64: dts: ti: iot2050: Re-add aliases (bsc#1012628).
- wifi: rtw88: sdio: Honor the host max_req_size in the RX path
  (bsc#1012628).
- selftests/bpf: Fix erroneous bitmask operation (bsc#1012628).
- md: synchronize flush io with array reconfiguration
  (bsc#1012628).
- bpf: enforce precision of R0 on callback return (bsc#1012628).
- ARM: dts: qcom: sdx65: correct PCIe EP phy-names (bsc#1012628).
- ARM: dts: qcom: sdx65: correct SPMI node name (bsc#1012628).
- dt-bindings: arm: qcom: Fix html link (bsc#1012628).
- arm64: dts: qcom: sc8180x-primus: Fix HALL_INT polarity
  (bsc#1012628).
- arm64: dts: qcom: sm8450: correct TX Soundwire clock
  (bsc#1012628).
- arm64: dts: qcom: sm8550: correct TX Soundwire clock
  (bsc#1012628).
- arm64: dts: qcom: sc7180: Make watchdog bark interrupt edge
  triggered (bsc#1012628).
- arm64: dts: qcom: sc7280: Make watchdog bark interrupt edge
  triggered (bsc#1012628).
- arm64: dts: qcom: sdm845: Make watchdog bark interrupt edge
  triggered (bsc#1012628).
- arm64: dts: qcom: sm8150: Make watchdog bark interrupt edge
  triggered (bsc#1012628).
- arm64: dts: qcom: sm8250: Make watchdog bark interrupt edge
  triggered (bsc#1012628).
- arm64: dts: qcom: sa8775p: Make watchdog bark interrupt edge
  triggered (bsc#1012628).
- arm64: dts: qcom: sc8280xp: Make watchdog bark interrupt edge
  triggered (bsc#1012628).
- arm64: dts: qcom: sm6350: Make watchdog bark interrupt edge
  triggered (bsc#1012628).
- bpf: Add map and need_defer parameters to .map_fd_put_ptr()
  (bsc#1012628).
- bpf: Defer the free of inner map when necessary (bsc#1012628).
- selftests/net: specify the interface when do arping
  (bsc#1012628).
- bpf: fix check for attempt to corrupt spilled pointer
  (bsc#1012628).
- scsi: fnic: Return error if vmalloc() failed (bsc#1012628).
- arm64: dts: qcom: qrb2210-rb1: use USB host mode (bsc#1012628).
- arm64: dts: qcom: qrb5165-rb5: correct LED panic indicator
  (bsc#1012628).
- arm64: dts: qcom: sdm845-db845c: correct LED panic indicator
  (bsc#1012628).
- arm64: dts: qcom: sm6125: add interrupts to DWC3 USB controller
  (bsc#1012628).
- arm64: dts: qcom: sm8350: Fix DMA0 address (bsc#1012628).
- arm64: dts: qcom: sc7280: Fix up GPU SIDs (bsc#1012628).
- arm64: dts: qcom: sc7280: Mark Adreno SMMU as DMA coherent
  (bsc#1012628).
- arm64: dts: qcom: sa8775p: fix USB wakeup interrupt types
  (bsc#1012628).
- arm64: dts: qcom: sc7280: fix usb_2 wakeup interrupt types
  (bsc#1012628).
- arm64: dts: qcom: sm8550: fix USB wakeup interrupt types
  (bsc#1012628).
- wifi: mt76: mt7996: fix uninitialized variable in parsing txfree
  (bsc#1012628).
- wifi: mt76: fix typo in mt76_get_of_eeprom_from_nvmem function
  (bsc#1012628).
- wifi: mt76: mt7915: fallback to non-wed mode if
  platform_get_resource fails in mt7915_mmio_wed_init()
  (bsc#1012628).
- wifi: mt76: mt7996: fix the size of struct bss_rate_tlv
  (bsc#1012628).
- wifi: mt76: mt7996: fix rate usage of inband discovery frames
  (bsc#1012628).
- wifi: mt76: mt7996: fix alignment of sta info event
  (bsc#1012628).
- wifi: mt76: mt7915: fix EEPROM offset of TSSI flag on MT7981
  (bsc#1012628).
- wifi: mt76: mt7915: also MT7981 is 3T3R but nss2 on 5 GHz band
  (bsc#1012628).
- wifi: mt76: mt7996: fix mt7996_mcu_all_sta_info_event struct
  packing (bsc#1012628).
- wifi: mt76: mt7921s: fix workqueue problem causes STA
  association fail (bsc#1012628).
- bpf: Fix verification of indirect var-off stack access
  (bsc#1012628).
- arm64: dts: hisilicon: hikey970-pmic: fix regulator cells
  properties (bsc#1012628).
- bpf: Guard stack limits against 32bit overflow (bsc#1012628).
- bpf: Fix accesses to uninit stack slots (bsc#1012628).
- test_bpf: Rename second ALU64_SMOD_X to ALU64_SMOD_K
  (bsc#1012628).
- dt-bindings: media: mediatek: mdp3: correct RDMA and WROT node
  with generic names (bsc#1012628).
- arm64: dts: mediatek: mt8183: correct MDP3 DMA-related nodes
  (bsc#1012628).
- arm64: dts: mediatek: mt8195: revise VDOSYS RDMA node name
  (bsc#1012628).
- arm64: dts: mediatek: mt8186: Fix alias prefix for ovl_2l0
  (bsc#1012628).
- arm64: dts: mediatek: mt8186: fix address warning for ADSP
  mailboxes (bsc#1012628).
- wifi: mt76: mt7921: fix country count limitation for CLC
  (bsc#1012628).
- wifi: mt76: mt7921: fix CLC command timeout when suspend/resume
  (bsc#1012628).
- wifi: mt76: mt7921: fix wrong 6Ghz power type (bsc#1012628).
- wifi: iwlwifi: don't support triggered EHT CQI feedback
  (bsc#1012628).
- selftests/bpf: Relax time_tai test for equal timestamps in
  tai_forward (bsc#1012628).
- block: Set memalloc_noio to false on device_add_disk() error
  path (bsc#1012628).
- arm64: dts: xilinx: Apply overlays to base dtbs (bsc#1012628).
- arm64: dts: renesas: white-hawk-cpu: Fix missing serial console
  pin control (bsc#1012628).
- arm64: dts: imx8mm: Reduce GPU to nominal speed (bsc#1012628).
- scsi: ufs: qcom: Fix the return value of
  ufs_qcom_ice_program_key() (bsc#1012628).
- scsi: ufs: qcom: Fix the return value when
  platform_get_resource_byname() fails (bsc#1012628).
- scsi: hisi_sas: Replace with standard error code return value
  (bsc#1012628).
- scsi: hisi_sas: Check before using pointer variables
  (bsc#1012628).
- scsi: hisi_sas: Rollback some operations if FLR failed
  (bsc#1012628).
- scsi: hisi_sas: Correct the number of global debugfs registers
  (bsc#1012628).
- selftests/xsk: Fix for SEND_RECEIVE_UNALIGNED test
  (bsc#1012628).
- ARM: dts: stm32: don't mix SCMI and non-SCMI board compatibles
  (bsc#1012628).
- bpf: Fix a race condition between btf_put() and map_free()
  (bsc#1012628).
- selftests/net: fix grep checking for fib_nexthop_multiprefix
  (bsc#1012628).
- ipmr: support IP_PKTINFO on cache report IGMP msg (bsc#1012628).
- virtio/vsock: fix logic which reduces credit update messages
  (bsc#1012628).
- virtio/vsock: send credit update during setting SO_RCVLOWAT
  (bsc#1012628).
- dma-mapping: clear dev->dma_mem to NULL after freeing it
  (bsc#1012628).
- bpf: Limit the number of uprobes when attaching program to
  multiple uprobes (bsc#1012628).
- bpf: Limit the number of kprobes when attaching program to
  multiple kprobes (bsc#1012628).
- arm64: dts: qcom: acer-aspire1: Correct audio codec definition
  (bsc#1012628).
- soc: qcom: llcc: Fix dis_cap_alloc and retain_on_pc
  configuration (bsc#1012628).
- arm64: dts: qcom: sm6375: fix USB wakeup interrupt types
  (bsc#1012628).
- arm64: dts: qcom: sm6375: Hook up MPM (bsc#1012628).
- arm64: dts: qcom: sm8150: make dispcc cast minimal vote on MMCX
  (bsc#1012628).
- arm64: dts: qcom: sm8150-hdk: fix SS USB regulators
  (bsc#1012628).
- firmware: qcom: qseecom: fix memory leaks in error paths
  (bsc#1012628).
- soc: qcom: llcc: Fix LLCC_TRP_ATTR2_CFGn offset (bsc#1012628).
- block: add check of 'minors' and 'first_minor' in
  device_add_disk() (bsc#1012628).
- arm64: dts: qcom: sc7280: Mark SDHCI hosts as cache-coherent
  (bsc#1012628).
- arm64: dts: qcom: ipq6018: fix clock rates for
  GCC_USB0_MOCK_UTMI_CLK (bsc#1012628).
- arm64: dts: qcom: sm8550: Separate out X3 idle state
  (bsc#1012628).
- arm64: dts: qcom: sm8550: Update idle state time requirements
  (bsc#1012628).
- arm64: dts: qcom: sc8180x: Mark PCIe hosts cache-coherent
  (bsc#1012628).
- arm64: dts: qcom: sc8180x: Fix up PCIe nodes (bsc#1012628).
- bpf: Use c->unit_size to select target cache during free
  (bsc#1012628).
- wifi: rtlwifi: add calculate_bit_shift() (bsc#1012628).
- wifi: rtlwifi: rtl8188ee: phy: using calculate_bit_shift()
  (bsc#1012628).
- wifi: rtlwifi: rtl8192c: using calculate_bit_shift()
  (bsc#1012628).
- wifi: rtlwifi: rtl8192cu: using calculate_bit_shift()
  (bsc#1012628).
- wifi: rtlwifi: rtl8192ce: using calculate_bit_shift()
  (bsc#1012628).
- wifi: rtlwifi: rtl8192de: using calculate_bit_shift()
  (bsc#1012628).
- wifi: rtlwifi: rtl8192ee: using calculate_bit_shift()
  (bsc#1012628).
- wifi: rtlwifi: rtl8192se: using calculate_bit_shift()
  (bsc#1012628).
- wifi: mac80211: fix advertised TTLM scheduling (bsc#1012628).
- wifi: iwlwifi: mvm: set siso/mimo chains to 1 in FW SMPS request
  (bsc#1012628).
- wifi: iwlwifi: mvm: send TX path flush in rfkill (bsc#1012628).
- wifi: iwlwifi: mvm: Do not warn if valid link pair was not found
  (bsc#1012628).
- wifi: iwlwifi: fix out of bound copy_from_user (bsc#1012628).
- wifi: iwlwifi: assign phy_ctxt before eSR activation
  (bsc#1012628).
- netfilter: nf_tables: mark newset as dead on transaction abort
  (bsc#1012628).
- netfilter: nf_tables: validate chain type update if available
  (bsc#1012628).
- Bluetooth: Fix bogus check for re-auth no supported with non-ssp
  (bsc#1012628).
- Bluetooth: btnxpuart: fix recv_buf() return value (bsc#1012628).
- Bluetooth: btmtkuart: fix recv_buf() return value (bsc#1012628).
- null_blk: don't cap max_hw_sectors to BLK_DEF_MAX_SECTORS
  (bsc#1012628).
- arm64: dts: rockchip: Fix led pinctrl of lubancat 1
  (bsc#1012628).
- ice: Fix some null pointer dereference issues in ice_ptp.c
  (bsc#1012628).
- wifi: cfg80211: correct comment about MLD ID (bsc#1012628).
- wifi: cfg80211: parse all ML elements in an ML probe response
  (bsc#1012628).
- bpf: sockmap, fix proto update hook to avoid dup calls
  (bsc#1012628).
- sctp: support MSG_ERRQUEUE flag in recvmsg() (bsc#1012628).
- sctp: fix busy polling (bsc#1012628).
- s390/bpf: Fix gotol with large offsets (bsc#1012628).
- blk-cgroup: fix rcu lockdep warning in blkg_lookup()
  (bsc#1012628).
- net/sched: act_ct: fix skb leak and crash on ooo frags
  (bsc#1012628).
- mlxbf_gige: Fix intermittent no ip issue (bsc#1012628).
- mlxbf_gige: Enable the GigE port in mlxbf_gige_open
  (bsc#1012628).
- rxrpc: Fix skbuff cleanup of call's recvmsg_queue and
  rx_oos_queue (bsc#1012628).
- ip6_tunnel: fix NEXTHDR_FRAGMENT handling in
  ip6_tnl_parse_tlv_enc_lim() (bsc#1012628).
- ARM: davinci: always select CONFIG_CPU_ARM926T (bsc#1012628).
- Revert "drm/tidss: Annotate dma-fence critical section in
  commit path" (bsc#1012628).
- Revert "drm/omapdrm: Annotate dma-fence critical section in
  commit path" (bsc#1012628).
- drm/i915/display: Move releasing gem object away from fb
  tracking (bsc#1012628).
- drm/dp_mst: Fix fractional DSC bpp handling (bsc#1012628).
- drm/panfrost: Really power off GPU cores in
  panfrost_gpu_power_off() (bsc#1012628).
- RDMA/usnic: Silence uninitialized symbol smatch warnings
  (bsc#1012628).
- RDMA/hns: Fix inappropriate err code for unsupported operations
  (bsc#1012628).
- drm/panel: nv3051d: Hold panel in reset for unprepare
  (bsc#1012628).
- drm/panel-elida-kd35t133: hold panel in reset for unprepare
  (bsc#1012628).
- drm/nouveau/fence:: fix warning directly dereferencing a rcu
  pointer (bsc#1012628).
- drm/bridge: tpd12s015: Drop buggy __exit annotation for remove
  function (bsc#1012628).
- drm/tilcdc: Fix irq free on unload (bsc#1012628).
- media: pvrusb2: fix use after free on context disconnection
  (bsc#1012628).
- media: mtk-jpeg: Remove cancel worker in mtk_jpeg_remove to
  avoid the crash of multi-core JPEG devices (bsc#1012628).
- media: visl: Hook the (TRY_)DECODER_CMD stateless ioctls
  (bsc#1012628).
- media: verisilicon: Hook the (TRY_)DECODER_CMD stateless ioctls
  (bsc#1012628).
- media: rkvdec: Hook the (TRY_)DECODER_CMD stateless ioctls
  (bsc#1012628).
- media: amphion: Fix VPU core alias name (bsc#1012628).
- drm/sched: Fix bounds limiting when given a malformed entity
  (bsc#1012628).
- drm/bridge: Fix typo in post_disable() description
  (bsc#1012628).
- drm/bridge: imx93-mipi-dsi: Fix a couple of building warnings
  (bsc#1012628).
- f2fs: fix to avoid dirent corruption (bsc#1012628).
- Revert "drm/bridge: Add 200ms delay to wait FW HPD status
  stable" (bsc#1012628).
- fbdev/sm712fb: Use correct initializer macros for struct fb_ops
  (bsc#1012628).
- ASoC: fsl_rpmsg: update Kconfig dependencies (bsc#1012628).
- drm/radeon/r600_cs: Fix possible int overflows in
  r600_cs_check_reg() (bsc#1012628).
- drm/radeon/r100: Fix integer overflow issues in
  r100_cs_track_check() (bsc#1012628).
- drm/radeon: check return value of radeon_ring_lock()
  (bsc#1012628).
- drm/amd/display: Fix NULL pointer dereference at hibernate
  (bsc#1012628).
- drm/tidss: Move reset to the end of dispc_init() (bsc#1012628).
- drm/tidss: Return error value from from softreset (bsc#1012628).
- drm/tidss: Check for K2G in in dispc_softreset() (bsc#1012628).
- drm/tidss: Fix dss reset (bsc#1012628).
- drm/imx/lcdc: Fix double-free of driver data (bsc#1012628).
- ASoC: cs35l33: Fix GPIO name and drop legacy include
  (bsc#1012628).
- ASoC: cs35l34: Fix GPIO name and drop legacy include
  (bsc#1012628).
- drm/msm/a6xx: add QMP dependency (bsc#1012628).
- drm/msm/mdp4: flush vblank event on disable (bsc#1012628).
- drm/msm/dpu: Add missing safe_lut_tbl in sc8180x catalog
  (bsc#1012628).
- drm/msm/dsi: Use pm_runtime_resume_and_get to prevent refcnt
  leaks (bsc#1012628).
- drm/drv: propagate errors from drm_modeset_register_all()
  (bsc#1012628).
- media: v4l: async: Fix duplicated list deletion (bsc#1012628).
- ASoC: Intel: glk_rt5682_max98357a: fix board id mismatch
  (bsc#1012628).
- ASoC: Intel: sof_sdw_rt_sdca_jack_common: ctx->headset_codec_dev
  = NULL (bsc#1012628).
- ASoC: SOF: topology: Use partial match for disconnecting DAI
  link and DAI widget (bsc#1012628).
- drm/msm/dpu: enable SmartDMA on SM8450 (bsc#1012628).
- drm/msm/dpu: populate SSPP scaler block version (bsc#1012628).
- drm/panfrost: Ignore core_mask for poweroff and disable PWRTRANS
  irq (bsc#1012628).
- drm/msm/dpu: correct clk bit for WB2 block (bsc#1012628).
- drm/amd/display: Return drm_connector from
  find_first_crtc_matching_connector (bsc#1012628).
- drm/amd/display: Use drm_connector in create_stream_for_sink
  (bsc#1012628).
- drm/amd/display: Check writeback connectors in
  create_validate_stream_for_sink (bsc#1012628).
- drm/radeon: check the alloc_workqueue return value in
  radeon_crtc_init() (bsc#1012628).
- drm/radeon/dpm: fix a memleak in sumo_parse_power_table
  (bsc#1012628).
- drm/radeon/trinity_dpm: fix a memleak in
  trinity_parse_power_table (bsc#1012628).
- drm/bridge: cdns-mhdp8546: Fix use of uninitialized variable
  (bsc#1012628).
- drm/bridge: tc358767: Fix return value on error case
  (bsc#1012628).
- media: cx231xx: fix a memleak in cx231xx_init_isoc
  (bsc#1012628).
- ASoC: SOF: Intel: pci-mtl: fix ARL-S definitions (bsc#1012628).
- RDMA/hns: Fix memory leak in free_mr_init() (bsc#1012628).
- clk: qcom: gpucc-sm8150: Update the gpu_cc_pll1 config
  (bsc#1012628).
- f2fs: Restrict max filesize for 16K f2fs (bsc#1012628).
- media: bttv: start_streaming should return a proper error code
  (bsc#1012628).
- media: bttv: add back vbi hack (bsc#1012628).
- media: videobuf2: request more buffers for vb2_read
  (bsc#1012628).
- media: imx-mipi-csis: Fix clock handling in remove()
  (bsc#1012628).
- media: imx-mipi-csis: Drop extra clock enable at probe()
  (bsc#1012628).
- media: dt-bindings: media: rkisp1: Fix the port description
  for the parallel interface (bsc#1012628).
- media: rkisp1: Fix media device memory leak (bsc#1012628).
- media: rkisp1: Fix memory leaks in rkisp1_isp_unregister()
  (bsc#1012628).
- drm/msm/adreno: Fix A680 chip id (bsc#1012628).
- drm/panel: st7701: Fix AVCL calculation (bsc#1012628).
- f2fs: fix to wait on block writeback for post_read case
  (bsc#1012628).
- f2fs: fix to check compress file in f2fs_move_file_range()
  (bsc#1012628).
- f2fs: fix to update iostat correctly in f2fs_filemap_fault()
  (bsc#1012628).
- media: dvbdev: drop refcount on error path in dvb_device_open()
  (bsc#1012628).
- media: dvb-frontends: m88ds3103: Fix a memory leak in an error
  handling path of m88ds3103_probe() (bsc#1012628).
- clk: renesas: rzg2l-cpg: Reuse code in rzg2l_cpg_reset()
  (bsc#1012628).
- clk: renesas: rzg2l: Check reset monitor registers
  (bsc#1012628).
- drm/msm/dpu: Set input_sel bit for INTF (bsc#1012628).
- drm/msm/dpu: Drop enable and frame_count parameters from
  dpu_hw_setup_misr() (bsc#1012628).
- media: i2c: mt9m114: use fsleep() in place of udelay()
  (bsc#1012628).
- drm/mediatek: Return error if MDP RDMA failed to enable the
  clock (bsc#1012628).
- drm/mediatek: Remove the redundant driver data for DPI
  (bsc#1012628).
- drm/mediatek: Fix underrun in VDO1 when switches off the layer
  (bsc#1012628).
- drm/amdgpu/debugfs: fix error code when smc register accessors
  are NULL (bsc#1012628).
- drm/amd/pm: fix a double-free in si_dpm_init (bsc#1012628).
- drivers/amd/pm: fix a use-after-free in kv_parse_power_table
  (bsc#1012628).
- gpu/drm/radeon: fix two memleaks in radeon_vm_init
  (bsc#1012628).
- drm/amd/pm: fix a double-free in
  amdgpu_parse_extended_power_table (bsc#1012628).
- f2fs: fix to check return value of f2fs_recover_xattr_data
  (bsc#1012628).
- clk: qcom: videocc-sm8150: Add missing PLL config property
  (bsc#1012628).
- clk: sp7021: fix return value check in sp7021_clk_probe()
  (bsc#1012628).
- drivers: clk: zynqmp: calculate closest mux rate (bsc#1012628).
- drivers: clk: zynqmp: update divider round rate logic
  (bsc#1012628).
- watchdog: set cdev owner before adding (bsc#1012628).
- watchdog/hpwdt: Only claim UNKNOWN NMI if from iLO
  (bsc#1012628).
- watchdog: bcm2835_wdt: Fix WDIOC_SETTIMEOUT handling
  (bsc#1012628).
- watchdog: rti_wdt: Drop runtime pm reference count when watchdog
  is unused (bsc#1012628).
- clk: rs9: Fix DIF OEn bit placement on 9FGV0241 (bsc#1012628).
- clk: si5341: fix an error code problem in
  si5341_output_clk_set_rate (bsc#1012628).
- ASoC: amd: vangogh: Drop conflicting ACPI-based probing
  (bsc#1012628).
- ASoC: tas2781: add support for FW version 0x0503 (bsc#1012628).
- drm/mediatek: dp: Add phy_mtk_dp module as pre-dependency
  (bsc#1012628).
- accel/habanalabs: fix information leak in sec_attest_info()
  (bsc#1012628).
- clk: qcom: gcc-sm8550: Add the missing RETAIN_FF_ENABLE GDSC
  flag (bsc#1012628).
- clk: qcom: gcc-sm8550: Mark the PCIe GDSCs votable
  (bsc#1012628).
- clk: qcom: gcc-sm8550: use collapse-voting for PCIe GDSCs
  (bsc#1012628).
- clk: qcom: gcc-sm8550: Mark RCGs shared where applicable
  (bsc#1012628).
- clk: qcom: gpucc-sm8550: Update GPU PLL settings (bsc#1012628).
- clk: qcom: dispcc-sm8550: Update disp PLL settings
  (bsc#1012628).
- clk: qcom: dispcc-sm8550: Use the correct PLL configuration
  function (bsc#1012628).
- clk: fixed-rate: fix
  clk_hw_register_fixed_rate_with_accuracy_parent_hw
  (bsc#1012628).
- pwm: stm32: Use hweight32 in stm32_pwm_detect_channels
  (bsc#1012628).
- pwm: stm32: Fix enable count for clk in .probe() (bsc#1012628).
- ASoC: rt5645: Drop double EF20 entry from dmi_platform_data[]
  (bsc#1012628).
- ALSA: scarlett2: Add missing error check to
  scarlett2_config_save() (bsc#1012628).
- ALSA: scarlett2: Add missing error check to
  scarlett2_usb_set_config() (bsc#1012628).
- ALSA: scarlett2: Add missing error checks to *_ctl_get()
  (bsc#1012628).
- ALSA: scarlett2: Add clamp() in scarlett2_mixer_ctl_put()
  (bsc#1012628).
- ALSA: scarlett2: Add missing mutex lock around get meter levels
  (bsc#1012628).
- mmc: sdhci_am654: Fix TI SoC dependencies (bsc#1012628).
- mmc: sdhci_omap: Fix TI SoC dependencies (bsc#1012628).
- drm/amdkfd: Fix type of 'dbg_flags' in 'struct kfd_process'
  (bsc#1012628).
- IB/iser: Prevent invalidating wrong MR (bsc#1012628).
- drm/amdkfd: Confirm list is non-empty before utilizing
  list_first_entry in kfd_topology.c (bsc#1012628).
- drm/amd/pm/smu7: fix a memleak in smu7_hwmgr_backend_init
  (bsc#1012628).
- drm/amd/display: avoid stringop-overflow warnings for
  dp_decide_lane_settings() (bsc#1012628).
- kselftest/alsa - mixer-test: fix the number of parameters to
  ksft_exit_fail_msg() (bsc#1012628).
- kselftest/alsa - mixer-test: Fix the print format specifier
  warning (bsc#1012628).
- kselftest/alsa - conf: Stringify the printed errno in
  sysfs_get() (bsc#1012628).
- ksmbd: validate the zero field of packet header (bsc#1012628).
- of: Fix double free in of_parse_phandle_with_args_map
  (bsc#1012628).
- fbdev: imxfb: fix left margin setting (bsc#1012628).
- of: unittest: Fix of_count_phandle_with_args() expected value
  message (bsc#1012628).
- class: fix use-after-free in class_register() (bsc#1012628).
- kernfs: convert kernfs_idr_lock to an irq safe raw spinlock
  (bsc#1012628).
- Revert "kernfs: convert kernfs_idr_lock to an irq safe raw
  spinlock" (bsc#1012628).
- selftests/bpf: Add assert for user stacks in test_task_stack
  (bsc#1012628).
- binder: fix async space check for 0-sized buffers (bsc#1012628).
- binder: fix unused alloc->free_async_space (bsc#1012628).
- Input: atkbd - use ab83 as id when skipping the getid command
  (bsc#1012628).
- rust: Ignore preserve-most functions (bsc#1012628).
- Revert "drm/amdkfd: Relocate TBA/TMA to opposite side of VM
  hole" (bsc#1012628).
- xen-netback: don't produce zero-size SKB frags (bsc#1012628).
- binder: fix race between mmput() and do_exit() (bsc#1012628).
- clocksource/drivers/timer-ti-dm: Fix make W=n kerneldoc warnings
  (bsc#1012628).
- dt-bindings: timer: thead,c900-aclint-mtimer: separate mtime
  and mtimecmp regs (bsc#1012628).
- clocksource/drivers/ep93xx: Fix error handling during probe
  (bsc#1012628).
- powerpc/64s: Increase default stack size to 32KB (bsc#1012628).
- tick-sched: Fix idle and iowait sleeptime accounting vs CPU
  hotplug (bsc#1012628).
- Revert "usb: gadget: f_uvc: change endpoint allocation in
  uvc_function_bind()" (bsc#1012628).
- usb: gadget: u_ether: Re-attach netif device to mirror
  detachment (bsc#1012628).
- usb: phy: mxs: remove CONFIG_USB_OTG condition for
  mxs_phy_is_otg_host() (bsc#1012628).
- usb: dwc: ep0: Update request status in dwc3_ep0_stall_restart
  (bsc#1012628).
- usb: dwc3: gadget: Handle EP0 request dequeuing properly
  (bsc#1012628).
- usb: dwc3: gadget: Queue PM runtime idle on disconnect event
  (bsc#1012628).
- Revert "usb: dwc3: Soft reset phy on probe for host"
  (bsc#1012628).
- Revert "usb: dwc3: don't reset device side if dwc3 was
  configured as host-only" (bsc#1012628).
- usb: chipidea: wait controller resume finished for wakeup irq
  (bsc#1012628).
- usb: cdns3: fix uvc failure work since sg support enabled
  (bsc#1012628).
- usb: cdns3: fix iso transfer error when mult is not zero
  (bsc#1012628).
- usb: cdns3: Fix uvc fail when DMA cross 4k boundery since sg
  enabled (bsc#1012628).
- Revert "usb: typec: class: fix typec_altmode_put_partner to
  put plugs" (bsc#1012628).
- usb: typec: class: fix typec_altmode_put_partner to put plugs
  (bsc#1012628).
- usb: mon: Fix atomicity violation in mon_bin_vma_fault
  (bsc#1012628).
- dt-bindings: phy: qcom,sc8280xp-qmp-usb43dp-phy: fix path to
  header (bsc#1012628).
- serial: Do not hold the port lock when setting rx-during-tx GPIO
  (bsc#1012628).
- serial: core: fix sanitizing check for RTS settings
  (bsc#1012628).
- serial: core: make sure RS485 cannot be enabled when it is
  not supported (bsc#1012628).
- serial: core: set missing supported flag for RX during TX GPIO
  (bsc#1012628).
- serial: 8250_bcm2835aux: Restore clock error handling
  (bsc#1012628).
- serial: core, imx: do not set RS485 enabled if it is not
  supported (bsc#1012628).
- serial: imx: Ensure that imx_uart_rs485_config() is called
  with enabled clock (bsc#1012628).
- serial: 8250_exar: Set missing rs485_supported flag
  (bsc#1012628).
- serial: omap: do not override settings for RS485 support
  (bsc#1012628).
- ALSA: oxygen: Fix right channel of capture volume mixer
  (bsc#1012628).
- ALSA: hda/relatek: Enable Mute LED on HP Laptop 15s-fq2xxx
  (bsc#1012628).
- ALSA: hda/realtek: Enable mute/micmute LEDs and limit mic
  boost on HP ZBook (bsc#1012628).
- ALSA: hda/realtek: Enable headset mic on Lenovo M70 Gen5
  (bsc#1012628).
- ksmbd: validate mech token in session setup (bsc#1012628).
- ksmbd: fix UAF issue in ksmbd_tcp_new_connection()
  (bsc#1012628).
- ksmbd: only v2 leases handle the directory (bsc#1012628).
- ceph: select FS_ENCRYPTION_ALGS if FS_ENCRYPTION (bsc#1012628).
- LoongArch: Fix and simplify fcsr initialization on execve()
  (bsc#1012628).
- io_uring: don't check iopoll if request completes (bsc#1012628).
- io_uring/rw: ensure io->bytes_done is always initialized
  (bsc#1012628).
- io_uring: ensure local task_work is run on wait timeout
  (bsc#1012628).
- fbdev/acornfb: Fix name of fb_ops initializer macro
  (bsc#1012628).
- fbdev: flush deferred work in fb_deferred_io_fsync()
  (bsc#1012628).
- fbdev: flush deferred IO before closing (bsc#1012628).
- scsi: ufs: core: Simplify power management during async scan
  (bsc#1012628).
- scsi: target: core: add missing file_{start,end}_write()
  (bsc#1012628).
- scsi: mpi3mr: Refresh sdev queue depth after controller reset
  (bsc#1012628).
- scsi: mpi3mr: Clean up block devices post controller reset
  (bsc#1012628).
- scsi: mpi3mr: Block PEL Enable Command on Controller Reset
  and Unrecoverable State (bsc#1012628).
- md: Fix md_seq_ops() regressions (bsc#1012628).
- drm/amd: Enable PCIe PME from D3 (bsc#1012628).
- block: add check that partition length needs to be aligned
  with block size (bsc#1012628).
- block: Remove special-casing of compound pages (bsc#1012628).
- block: Fix iterating over an empty bio with
  bio_for_each_folio_all (bsc#1012628).
- netfilter: nf_tables: check if catch-all set element is active
  in next generation (bsc#1012628).
- pwm: jz4740: Don't use dev_err_probe() in .request()
  (bsc#1012628).
- pwm: Fix out-of-bounds access in of_pwm_single_xlate()
  (bsc#1012628).
- md/raid1: Use blk_opf_t for read and write operations
  (bsc#1012628).
- rootfs: Fix support for rootfstype= when root= is given
  (bsc#1012628).
- Bluetooth: Fix atomicity violation in {min,max}_key_size_set
  (bsc#1012628).
- bpf: Fix re-attachment branch in bpf_tracing_prog_attach
  (bsc#1012628).
- iommu/arm-smmu-qcom: Add missing GMU entry to match table
  (bsc#1012628).
- iommu/dma: Trace bounce buffer usage when mapping buffers
  (bsc#1012628).
- wifi: mt76: fix broken precal loading from MTD for mt7915
  (bsc#1012628).
- wifi: rtlwifi: Remove bogus and dangerous ASPM disable/enable
  code (bsc#1012628).
- wifi: rtlwifi: Convert LNKCTL change to PCIe cap RMW accessors
  (bsc#1012628).
- wifi: mwifiex: add extra delay for firmware ready (bsc#1012628).
- wifi: mwifiex: configure BSSID consistently when starting AP
  (bsc#1012628).
- wifi: mwifiex: fix uninitialized firmware_stat (bsc#1012628).
- net: stmmac: fix ethtool per-queue statistics (bsc#1012628).
- net: stmmac: Prevent DSA tags from breaking COE (bsc#1012628).
- Revert "net: rtnetlink: Enslave device before bringing it up"
  (bsc#1012628).
- Revert "nSVM: Check for reserved encodings of TLB_CONTROL in
  nested VMCB" (bsc#1012628).
- drm/amdgpu: revert "Adjust removal control flow for smu v13_0_2"
  (bsc#1012628).
- cxl/port: Fix decoder initialization when nr_targets >
  interleave_ways (bsc#1012628).
- PCI/P2PDMA: Remove reference to pci_p2pdma_map_sg()
  (bsc#1012628).
- x86/pci: Reserve ECAM if BIOS didn't include it in PNP0C02 _CRS
  (bsc#1012628).
- PCI: dwc: endpoint: Fix dw_pcie_ep_raise_msix_irq() alignment
  support (bsc#1012628).
- PCI: mediatek: Clear interrupt status before dispatching handler
  (bsc#1012628).
- ARM: dts: qcom: sdx55: Fix the base address of PCIe PHY
  (bsc#1012628).
- x86/kvm: Do not try to disable kvmclock if it was not enabled
  (bsc#1012628).
- KVM: arm64: vgic-v4: Restore pending state on host userspace
  write (bsc#1012628).
- KVM: arm64: vgic-its: Avoid potential UAF in LPI translation
  cache (bsc#1012628).
- KVM: x86/pmu: Move PMU reset logic to common x86 code
  (bsc#1012628).
- KVM: x86/pmu: Reset the PMU, i.e. stop counters, before
  refreshing (bsc#1012628).
- iio: adc: ad7091r: Pass iio_dev to event handler (bsc#1012628).
- HID: sensor-hub: Enable hid core report processing for all
  devices (bsc#1012628).
- HID: wacom: Correct behavior when processing some confidence ==
  false touches (bsc#1012628).
- serial: sc16is7xx: add check for unsupported SPI modes during
  probe (bsc#1012628).
- serial: sc16is7xx: set safe default SPI clock frequency
  (bsc#1012628).
- ARM: 9330/1: davinci: also select PINCTRL (bsc#1012628).
- mfd: rk8xx: fixup devices registration with PLATFORM_DEVID_AUTO
  (bsc#1012628).
- mfd: cs42l43: Correct SoundWire port list (bsc#1012628).
- mfd: syscon: Fix null pointer dereference in
  of_syscon_register() (bsc#1012628).
- rcu: Restrict access to RCU CPU stall notifiers (bsc#1012628).
- leds: aw2013: Select missing dependency REGMAP_I2C
  (bsc#1012628).
- leds: aw200xx: Fix write to DIM parameter (bsc#1012628).
- mfd: tps6594: Add null pointer check to tps6594_device_init()
  (bsc#1012628).
- mfd: intel-lpss: Fix the fractional clock divider flags
  (bsc#1012628).
- srcu: Use try-lock lockdep annotation for NMI-safe access
  (bsc#1012628).
- mips: dmi: Fix early remap on MIPS32 (bsc#1012628).
- mips: Fix incorrect max_low_pfn adjustment (bsc#1012628).
- um: virt-pci: fix platform map offset (bsc#1012628).
- riscv: Check if the code to patch lies in the exit section
  (bsc#1012628).
- riscv: Fix wrong usage of lm_alias() when splitting a huge
  linear mapping (bsc#1012628).
- riscv: Fix module_alloc() that did not reset the linear mapping
  permissions (bsc#1012628).
- riscv: Fix set_direct_map_default_noflush() to reset _PAGE_EXEC
  (bsc#1012628).
- riscv: Fixed wrong register in XIP_FIXUP_FLASH_OFFSET macro
  (bsc#1012628).
- drm/i915/dp: Fix the max DSC bpc supported by source
  (bsc#1012628).
- MIPS: Alchemy: Fix an out-of-bound access in db1200_dev_setup()
  (bsc#1012628).
- MIPS: Alchemy: Fix an out-of-bound access in db1550_dev_setup()
  (bsc#1012628).
- power: supply: cw2015: correct time_to_empty units in sysfs
  (bsc#1012628).
- power: supply: bq256xx: fix some problem in bq256xx_hw_init
  (bsc#1012628).
- PCI: Avoid potential out-of-bounds read in
  pci_dev_for_each_resource() (bsc#1012628).
- serial: 8250: omap: Don't skip resource freeing if
  pm_runtime_resume_and_get() failed (bsc#1012628).
- iommu: Map reserved memory as cacheable if device is coherent
  (bsc#1012628).
- perf test: Remove atomics from test_loop to avoid test failures
  (bsc#1012628).
- perf header: Fix segfault on build_mem_topology() error path
  (bsc#1012628).
- libapi: Add missing linux/types.h header to get the __u64 type
  on io.h (bsc#1012628).
- staging: vc04_services: vchiq_core: Log through struct
  vchiq_instance (bsc#1012628).
- staging: vc04_services: Do not pass NULL to vchiq_log_error()
  (bsc#1012628).
- perf test record user-regs: Fix mask for vg register
  (bsc#1012628).
- vfio/pds: Fix calculations in pds_vfio_dirty_sync (bsc#1012628).
- perf vendor events arm64 AmpereOne: Rename BPU_FLUSH_MEM_FAULT
  to GPC_FLUSH_MEM_FAULT (bsc#1012628).
- perf vendor events powerpc: Update datasource event name to
  fix duplicate events (bsc#1012628).
- perf mem: Fix error on hybrid related to availability of mem
  event in a PMU (bsc#1012628).
- perf stat: Exit perf stat if parse groups fails (bsc#1012628).
- base/node.c: initialize the accessor list before registering
  (bsc#1012628).
- acpi: property: Let args be NULL in
  __acpi_node_get_property_reference (bsc#1012628).
- software node: Let args be NULL in
  software_node_get_reference_args (bsc#1012628).
- serial: imx: fix tx statemachine deadlock (bsc#1012628).
- selftests/sgx: Fix uninitialized pointer dereference in error
  path (bsc#1012628).
- selftests/sgx: Fix uninitialized pointer dereferences in
  encl_get_entry (bsc#1012628).
- selftests/sgx: Include memory clobber for inline asm in test
  enclave (bsc#1012628).
- selftests/sgx: Skip non X86_64 platform (bsc#1012628).
- iio: adc: ad9467: fix reset gpio handling (bsc#1012628).
- iio: adc: ad9467: don't ignore error codes (bsc#1012628).
- iio: adc: ad9467: add mutex to struct ad9467_state
  (bsc#1012628).
- iio: adc: ad9467: fix scale setting (bsc#1012628).
- perf header: Fix one memory leakage in
  perf_event__fprintf_event_update() (bsc#1012628).
- perf hisi-ptt: Fix one memory leakage in
  hisi_ptt_process_auxtrace_event() (bsc#1012628).
- perf genelf: Set ELF program header addresses properly
  (bsc#1012628).
- perf unwind-libdw: Handle JIT-generated DSOs properly
  (bsc#1012628).
- perf unwind-libunwind: Fix base address for .eh_frame
  (bsc#1012628).
- bus: mhi: ep: Do not allocate event ring element on stack
  (bsc#1012628).
- bus: mhi: ep: Use slab allocator where applicable (bsc#1012628).
- bus: mhi: ep: Pass mhi_ep_buf_info struct to read/write APIs
  (bsc#1012628).
- PCI: epf-mhi: Fix the DMA data direction of dma_unmap_single()
  (bsc#1012628).
- usb: cdc-acm: return correct error code on unsupported break
  (bsc#1012628).
- arm64: dts: qcom: qrb5165-rb5: use u16 for DP altmode svid
  (bsc#1012628).
- cdx: Explicitly include correct DT includes, again
  (bsc#1012628).
- spmi: mtk-pmif: Serialize PMIF status check and command
  submission (bsc#1012628).
- usb: gadget: webcam: Make g_webcam loadable again (bsc#1012628).
- greybus: gb-beagleplay: Remove use of pad bytes (bsc#1012628).
- iommu: Don't reserve 0-length IOVA region (bsc#1012628).
- perf vendor events: Remove UTF-8 characters from cmn.json
  (bsc#1012628).
- power: supply: Fix null pointer dereference in smb2_probe
  (bsc#1012628).
- vdpa: Fix an error handling path in eni_vdpa_probe()
  (bsc#1012628).
- apparmor: Fix ref count leak in task_kill (bsc#1012628).
- nvmet-tcp: Fix a kernel panic when host sends an invalid H2C
  PDU length (bsc#1012628).
- nvmet-tcp: fix a crash in nvmet_req_complete() (bsc#1012628).
- nvmet-tcp: fix a missing endianess conversion in
  nvmet_tcp_try_peek_pdu (bsc#1012628).
- apparmor: free the allocated pdb objects (bsc#1012628).
- perf env: Avoid recursively taking env->bpf_progs.lock
  (bsc#1012628).
- perf stat: Fix hard coded LL miss units (bsc#1012628).
- cxl/region: fix x9 interleave typo (bsc#1012628).
- apparmor: fix possible memory leak in unpack_trans_table
  (bsc#1012628).
- apparmor: avoid crash when parsed profile name is empty
  (bsc#1012628).
- usb: xhci-mtk: fix a short packet issue of gen1 isoc-in transfer
  (bsc#1012628).
- serial: imx: Correct clock error message in function probe()
  (bsc#1012628).
- serial: apbuart: fix console prompt on qemu (bsc#1012628).
- cdx: call of_node_put() on error path (bsc#1012628).
- cdx: Unlock on error path in rescan_store() (bsc#1012628).
- perf db-export: Fix missing reference count get in
  call_path_from_sample() (bsc#1012628).
- cxl/port: Fix missing target list lock (bsc#1012628).
- spi: coldfire-qspi: Remove an erroneous clk_disable_unprepare()
  from the remove function (bsc#1012628).
- hisi_acc_vfio_pci: Update migration data pointer correctly on
  saving/resume (bsc#1012628).
- nvmet: re-fix tracing strncpy() warning (bsc#1012628).
- nvme: trace: avoid memcpy overflow warning (bsc#1012628).
- PCI: xilinx-xdma: Fix uninitialized symbols in
  xilinx_pl_dma_pcie_setup_irq() (bsc#1012628).
- PCI: xilinx-xdma: Fix error code in
  xilinx_pl_dma_pcie_init_irq_domain() (bsc#1012628).
- nvmet-tcp: Fix the H2C expected PDU len calculation
  (bsc#1012628).
- PCI: keystone: Fix race condition when initializing PHYs
  (bsc#1012628).
- apparmor: Fix memory leak in unpack_profile() (bsc#1012628).
- PCI: mediatek-gen3: Fix translation window size calculation
  (bsc#1012628).
- ASoC: mediatek: sof-common: Add NULL check for normal_link
  string (bsc#1012628).
- s390/pci: fix max size calculation in zpci_memcpy_toio()
  (bsc#1012628).
- net: qualcomm: rmnet: fix global oob in rmnet_policy
  (bsc#1012628).
- net: dsa: fix netdev_priv() dereference before check on non-DSA
  netdevice events (bsc#1012628).
- rxrpc: Fix use of Don't Fragment flag (bsc#1012628).
- octeontx2-af: CN10KB: Fix FIFO length calculation for RPM2
  (bsc#1012628).
- net: ethernet: ti: am65-cpsw: Fix max mtu to fit ethernet frames
  (bsc#1012628).
- amt: do not use overwrapped cb area (bsc#1012628).
- ALSA: aloop: Introduce a function to get if access is
  interleaved mode (bsc#1012628).
- net: micrel: Fix PTP frame parsing for lan8841 (bsc#1012628).
- net: phy: micrel: populate .soft_reset for KSZ9131
  (bsc#1012628).
- ALSA: hda: Properly setup HDMI stream (bsc#1012628).
- mptcp: mptcp_parse_option() fix for MPTCPOPT_MP_JOIN
  (bsc#1012628).
- mptcp: strict validation before using mp_opt->hmac
  (bsc#1012628).
- mptcp: use OPTION_MPTCP_MPJ_SYNACK in subflow_finish_connect()
  (bsc#1012628).
- mptcp: use OPTION_MPTCP_MPJ_SYN in subflow_check_req()
  (bsc#1012628).
- mptcp: refine opt_mp_capable determination (bsc#1012628).
- block: ensure we hold a queue reference when using queue limits
  (bsc#1012628).
- net: stmmac: Fix ethool link settings ops for integrated PCS
  (bsc#1012628).
- udp: annotate data-races around up->pending (bsc#1012628).
- erofs: fix inconsistent per-file compression format
  (bsc#1012628).
- net: add more sanity check in virtio_net_hdr_to_skb()
  (bsc#1012628).
- net: netdev_queue: netdev_txq_completed_mb(): fix wake condition
  (bsc#1012628).
- bpf: iter_udp: Retry with a larger batch size without going
  back to the previous bucket (bsc#1012628).
- bpf: Avoid iter->offset making backward progress in bpf_iter_udp
  (bsc#1012628).
- net: tls, fix WARNIING in __sk_msg_free (bsc#1012628).
- net: ravb: Fix dma_addr_t truncation in error case
  (bsc#1012628).
- dt-bindings: gpio: xilinx: Fix node address in gpio
  (bsc#1012628).
- gpio: mlxbf3: add an error code check in mlxbf3_gpio_probe
  (bsc#1012628).
- ASoC: SOF: ipc4-loader: remove the CPC check warnings
  (bsc#1012628).
- gpiolib: Fix scope-based gpio_device refcounting (bsc#1012628).
- drm/amdkfd: fixes for HMM mem allocation (bsc#1012628).
- drm/amdgpu: fall back to INPUT power for AVG power via INFO
  IOCTL (bsc#1012628).
- selftests: bonding: Change script interpreter (bsc#1012628).
- net: stmmac: ethtool: Fixed calltrace caused by unbalanced
  disable_irq_wake calls (bsc#1012628).
- bpf: Reject variable offset alu on PTR_TO_FLOW_KEYS
  (bsc#1012628).
- net: dsa: vsc73xx: Add null pointer check to vsc73xx_gpio_probe
  (bsc#1012628).
- LoongArch: BPF: Prevent out-of-bounds memory access
  (bsc#1012628).
- mptcp: relax check on MPC passive fallback (bsc#1012628).
- net: netdevsim: don't try to destroy PHC on VFs (bsc#1012628).
- netfilter: nf_tables: reject invalid set policy (bsc#1012628).
- netfilter: nft_limit: do not ignore unsupported flags
  (bsc#1012628).
- netfilter: nfnetlink_log: use proper helper for fetching
  physinif (bsc#1012628).
- netfilter: nf_queue: remove excess nf_bridge variable
  (bsc#1012628).
- netfilter: propagate net to nf_bridge_get_physindev
  (bsc#1012628).
- netfilter: bridge: replace physindev with physinif in
  nf_bridge_info (bsc#1012628).
- netfilter: nf_tables: do not allow mismatch field size and
  set key length (bsc#1012628).
- netfilter: nf_tables: skip dead set elements in netlink dump
  (bsc#1012628).
- netfilter: nf_tables: reject NFT_SET_CONCAT with not field
  length description (bsc#1012628).
- ipvs: avoid stat macros calls from preemptible context
  (bsc#1012628).
- io_uring: adjust defer tw counting (bsc#1012628).
- kdb: Fix a potential buffer overflow in kdb_local()
  (bsc#1012628).
- arm64/ptrace: Don't flush ZA/ZT storage when writing ZA via
  ptrace (bsc#1012628).
- ethtool: netlink: Add missing ethnl_ops_begin/complete
  (bsc#1012628).
- loop: fix the the direct I/O support check when used on top
  of block devices (bsc#1012628).
- mlxsw: spectrum_acl_erp: Fix error flow of pool allocation
  failure (bsc#1012628).
- mlxsw: spectrum_acl_tcam: Fix NULL pointer dereference in
  error path (bsc#1012628).
- mlxsw: spectrum_acl_tcam: Fix stack corruption (bsc#1012628).
- mlxsw: spectrum_router: Register netdevice notifier before
  nexthop (bsc#1012628).
- selftests: mlxsw: qos_pfc: Adjust the test to support 8 lanes
  (bsc#1012628).
- ipv6: mcast: fix data-race in ipv6_mc_down / mld_ifc_work
  (bsc#1012628).
- i2c: s3c24xx: fix read transfers in polling mode (bsc#1012628).
- i2c: s3c24xx: fix transferring more than one message in polling
  mode (bsc#1012628).
- Revert "KEYS: encrypted: Add check for strsep" (bsc#1012628).
- arm64: dts: armada-3720-turris-mox: set irq type for RTC
  (bsc#1012628).
- Revert "Revert "md/raid5: Wait for MD_SB_CHANGE_PENDING in
  raid5d"" (bsc#1012628).
- Rename to
  patches.kernel.org/6.7.2-083-keys-dns-Fix-size-check-of-V1-server-list-heade.patch.
- Rename to
  patches.kernel.org/6.7.2-450-media-solo6x10-replace-max-a-min-b-c-by-clamp-b.patch.
- commit fe3f5d5
* Thu Jan 25 2024 msuchanek@suse.de
- Revert "Limit kernel-source build to architectures for which the kernel binary"
  This reverts commit 08a9e44c00758b5f3f3b641830ab6affff041132.
  The fix for bsc#1108281 directly causes bsc#1218768, revert.
- commit 2943b8a
* Thu Jan 25 2024 msuchanek@suse.de
- mkspec: Include constraints for both multibuild and plain package always
  There is no need to check for multibuild flag, the constraints can be
  always generated for both cases.
- commit 308ea09
* Thu Jan 25 2024 jslaby@suse.cz
- rpm/mkspec: use kernel-source: prefix for constraints on multibuild
  Otherwise the constraints are not applied with multibuild enabled.
- commit 841012b
* Wed Jan 24 2024 jslaby@suse.cz
- rpm/kernel-source.rpmlintrc: add action-ebpf
  Upstream commit a79d8ba734bd (selftests: tc-testing: remove buildebpf
  plugin) added this precompiled binary blob. Adapt rpmlintrc for
  kernel-source.
- commit b5ccb33
* Tue Jan 23 2024 tiwai@suse.de
- scripts/tar-up.sh: don't add spurious entry from kernel-sources.changes.old
  The previous change added the manual entry from kernel-sources.change.old
  to old_changelog.txt unnecessarily.  Let's fix it.
- commit fb033e8
* Tue Jan 23 2024 jslaby@suse.cz
- rpm/kernel-docs.spec.in: fix build with 6.8
  Since upstream commit f061c9f7d058 (Documentation: Document each netlink
  family), the build needs python yaml.
- commit 6a7ece3
* Mon Jan 22 2024 mkubecek@suse.cz
- Update to 6.8-rc1
- drop 3 patches (all mainline)
  - patches.rpmify/media-solo6x10-replace-max-a-min-b-c-by-clamp-b-a-c.patch (31e97d7c9ae3)
  - patches.suse/0001-bsc-1204315-Disable-sysfb-before-creating-simple-fra.patch
  (3310288f6135)
  - patches.suse/keys-dns-Fix-size-check-of-V1-server-list-header.patch
- disable (conflict)
  - patches.suse/btrfs-8447-serialize-subvolume-mounts-with-potentially-mi.patch
- refresh
  - patches.suse/0001-security-lockdown-expose-a-hook-to-lock-the-kernel-down.patch
  - patches.suse/add-product-identifying-information-to-vmcoreinfo.patch
  - patches.suse/btrfs-provide-super_operations-get_inode_dev
  - patches.suse/genksyms-add-override-flag.diff
  - patches.suse/vfs-add-super_operations-get_inode_dev
- fix patch metadata
  - patches.suse/btrfs-provide-super_operations-get_inode_dev
- disable ARM architectures (need config update)
- new config options
  - Virtualization
  - CONFIG_KVM_SW_PROTECTED_VM=y
  - CONFIG_KVM_HYPERV=y
  - Enable the block layer
  - CONFIG_BLK_DEV_WRITE_MOUNTED=y
  - Memory Management options
  - CONFIG_ZSWAP_SHRINKER_DEFAULT_ON=n
  - CONFIG_TRANSPARENT_HUGEPAGE_NEVER=n
  - File systems
  - CONFIG_BCACHEFS_SIX_OPTIMISTIC_SPIN=y
  - CONFIG_EROFS_FS_ONDEMAND=n
  - CONFIG_NFSD_LEGACY_CLIENT_TRACKING=n
  - Cryptographic API
  - CONFIG_CRYPTO_DEV_QAT_420XX=m
  - CONFIG_CRYPTO_DEV_IAA_CRYPTO=m
  - CONFIG_CRYPTO_DEV_IAA_CRYPTO_STATS=n
  - Library routines
  - CONFIG_STACKDEPOT_MAX_FRAMES=64
  - Misc devices
  - CONFIG_NSM=m
  - CONFIG_INTEL_MEI_VSC_HW=m
  - CONFIG_INTEL_MEI_VSC=m
  - Network device support
  - CONFIG_ICE_HWMON=y
  - CONFIG_DP83TG720_PHY=m
  - CONFIG_FRAMER=m
  - Pin controllers
  - CONFIG_PINCTRL_INTEL_PLATFORM=m
  - CONFIG_PINCTRL_METEORPOINT=m
  - Hardware Monitoring support
  - CONFIG_SENSORS_GIGABYTE_WATERFORCE=m
  - CONFIG_SENSORS_LTC4286=n
  - CONFIG_SENSORS_MP2856=m
  - CONFIG_SENSORS_MP5990=m
  - Multimedia support
  - CONFIG_VIDEO_ALVIUM_CSI2=m
  - CONFIG_VIDEO_GC0308=m
  - CONFIG_VIDEO_GC2145=m
  - CONFIG_VIDEO_OV64A40=m
  - CONFIG_VIDEO_THP7312=m
  - CONFIG_VIDEO_TW9900=m
  - Graphics support
  - CONFIG_DRM_I915_DEBUG_WAKEREF=n
  - CONFIG_DRM_XE=m
  - CONFIG_DRM_XE_DISPLAY=y
  - CONFIG_DRM_XE_FORCE_PROBE=""
  - CONFIG_DRM_XE_WERROR=n
  - CONFIG_DRM_XE_DEBUG=n
  - CONFIG_DRM_XE_DEBUG_VM=n
  - CONFIG_DRM_XE_DEBUG_SRIOV=n
  - CONFIG_DRM_XE_DEBUG_MEM=n
  - CONFIG_DRM_XE_SIMPLE_ERROR_CAPTURE=n
  - CONFIG_DRM_XE_LARGE_GUC_BUFFER=n
  - CONFIG_DRM_XE_USERPTR_INVAL_INJECT=n
  - CONFIG_DRM_XE_JOB_TIMEOUT_MAX=10000
  - CONFIG_DRM_XE_JOB_TIMEOUT_MIN=1
  - CONFIG_DRM_XE_TIMESLICE_MAX=10000000
  - CONFIG_DRM_XE_TIMESLICE_MIN=1
  - CONFIG_DRM_XE_PREEMPT_TIMEOUT=640000
  - CONFIG_DRM_XE_PREEMPT_TIMEOUT_MAX=10000000
  - CONFIG_DRM_XE_PREEMPT_TIMEOUT_MIN=1
  - CONFIG_DRM_XE_ENABLE_SCHEDTIMEOUT_LIMIT=y
  - CONFIG_BACKLIGHT_MP3309C=m
  - Real Time Clock
  - CONFIG_RTC_DRV_MAX31335=m
  - CONFIG_RTC_DRV_TPS6594=m
  - VFIO Non-Privileged userspace driver framework
  - CONFIG_VFIO_DEBUGFS=n
  - CONFIG_VIRTIO_VFIO_PCI=m
  - X86 Platform Specific Device Drivers
  - CONFIG_AMD_WBRF=y
  - CONFIG_SILICOM_PLATFORM=m
  - Industrial I/O support
  - CONFIG_AD7091R8=n
  - CONFIG_MAX34408=n
  - CONFIG_AOSONG_AGS02MA=n
  - CONFIG_MCP4821=n
  - CONFIG_BMI323_I2C=m
  - CONFIG_BMI323_SPI=m
  - CONFIG_ISL76682=n
  - CONFIG_LTR390=n
  - CONFIG_VEML6075=n
  - CONFIG_HSC030PA=n
  - CONFIG_MLX90635=m
  - CONFIG_MCP9600=m
  - Misc drivers
  - CONFIG_MTD_UBI_FAULT_INJECTION=n
  - CONFIG_ZRAM_TRACK_ENTRY_ACTIME=n
  - CONFIG_JOYSTICK_SEESAW=m
  - CONFIG_W1_MASTER_AMD_AXI=m
  - CONFIG_THERMAL_DEBUGFS=n
  - CONFIG_REGULATOR_NETLINK_EVENTS=y
  - CONFIG_SND_AMD_ASOC_ACP70=m
  - CONFIG_HID_MCP2200=m
  - CONFIG_TYPEC_MUX_WCD939X_USBSS=m
  - CONFIG_QCOM_PMIC_PDCHARGER_ULOG=m
  - CONFIG_DWC_PCIE_PMU=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - PINCTRL_TPS6594=n
  - DRM_PANEL_ILITEK_ILI9805=n
  - DRM_PANEL_SYNAPTICS_R63353=n
  - LEDS_MAX5970=m
  - i386
  - FRAMER_PEF2256=m
  - PINCTRL_PEF2256=n
  - s390x
  - DRM_DP_AUX_CHARDEV=y
  - DRM_DP_CEC=y
  - DRM_PANEL_RASPBERRYPI_TOUCHSCREEN=n
  - MEDIA_CEC_RC=n
  - s390x/zfcpdump
  - HW_RANDOM_VIRTIO=n
  - HW_RANDOM_S390=y
  - riscv64
  - PARAVIRT=y
  - PARAVIRT_TIME_ACCOUNTING=n
  - POLARFIRE_SOC_AUTO_UPDATE=m
  - FRAMER_PEF2256=m
  - SERIAL_EARLYCON_RISCV_SBI=y
  - HVC_RISCV_SBI=y
  - PINCTRL_PEF2256=n
  - DRM_PANEL_RASPBERRYPI_TOUCHSCREEN=m
  - DRM_PANEL_*=n (except above)
  - LEDS_SUN50I_A100=m
  - VIDEO_STARFIVE_CAMSS=m
- commit c2014a1
* Mon Jan 22 2024 jslaby@suse.cz
- futex: Prevent the reuse of stale pi_state (bsc#1218841).
  Update upstream status (Queued in subsystem maintainer repository).
- commit a3ee207
* Mon Jan 22 2024 jslaby@suse.cz
- Refresh
  patches.rpmify/media-solo6x10-replace-max-a-min-b-c-by-clamp-b-a-c.patch.
  Update usptream status.
- commit 589bdfa
* Sun Jan 21 2024 colyli@suse.de
- Update config files, enable CONFIG_IMA_DISABLE_HTABLE in all archs for
  Tumbleweed as SLE15-SP6 kernel does (bsc#1218400).
- commit 020caa6
* Sat Jan 20 2024 jslaby@suse.cz
- Linux 6.7.1 (bsc#1012628).
- mm/memory_hotplug: fix memmap_on_memory sysfs value retrieval
  (bsc#1012628).
- docs: kernel_feat.py: fix potential command injection
  (bsc#1012628).
- scripts/decode_stacktrace.sh: optionally use LLVM utilities
  (bsc#1012628).
- coresight: etm4x: Fix width of CCITMIN field (bsc#1012628).
- PCI: Add ACS quirk for more Zhaoxin Root Ports (bsc#1012628).
- leds: ledtrig-tty: Free allocated ttyname buffer on deactivate
  (bsc#1012628).
- parport: parport_serial: Add Brainboxes device IDs and geometry
  (bsc#1012628).
- parport: parport_serial: Add Brainboxes BAR details
  (bsc#1012628).
- uio: Fix use-after-free in uio_open (bsc#1012628).
- binder: fix comment on binder_alloc_new_buf() return value
  (bsc#1012628).
- binder: fix trivial typo of binder_free_buf_locked()
  (bsc#1012628).
- binder: fix use-after-free in shinker's callback (bsc#1012628).
- binder: use EPOLLERR from eventpoll.h (bsc#1012628).
- Revert "md/raid5: Wait for MD_SB_CHANGE_PENDING in raid5d"
  (bsc#1012628).
- ksmbd: free ppace array on error in parse_dacl (bsc#1012628).
- ksmbd: don't allow O_TRUNC open on read-only share
  (bsc#1012628).
- drm/amd/display: Pass pwrseq inst for backlight and ABM
  (bsc#1012628).
- bus: moxtet: Add spi device table (bsc#1012628).
- bus: moxtet: Mark the irq as shared (bsc#1012628).
- ACPI: resource: Add another DMI match for the TongFang GMxXGxx
  (bsc#1012628).
- ALSA: hda: cs35l41: Support more HP models without _DSD
  (bsc#1012628).
- ALSA: hda/realtek: Fix mute and mic-mute LEDs for HP Envy X360
  13-ay0xxx (bsc#1012628).
- ALSA: hda/realtek: enable SND_PCI_QUIRK for Lenovo Legion Slim
  7 Gen 8 (2023) serie (bsc#1012628).
- ALSA: hda: Add driver properties for cs35l41 for Lenovo Legion
  Slim 7 Gen 8 serie (bsc#1012628).
- ALSA: hda: cs35l41: Prevent firmware load if SPI speed too low
  (bsc#1012628).
- ALSA: hda: cs35l41: Support additional Dell models without _DSD
  (bsc#1012628).
- ALSA: hda/realtek: Add quirks for Dell models (bsc#1012628).
- f2fs: explicitly null-terminate the xattr list (bsc#1012628).
- commit b2e8ed6
* Fri Jan 19 2024 jslaby@suse.cz
- media: solo6x10: replace max(a, min(b, c)) by clamp(b, a, c)
  (fix build and make it faster).
- Delete
  patches.rpmify/Revert-minmax-allow-comparisons-of-int-against-unsig.patch.
- Delete
  patches.rpmify/Revert-minmax-allow-min-max-clamp-if-the-arguments-h.patch.
- Delete
  patches.rpmify/Revert-minmax-fix-indentation-of-__cmp_once-and-__cl.patch.
- Delete
  patches.rpmify/Revert-minmax-relax-check-to-allow-comparison-betwee.patch.
  Replace the reverts by an upstream workaround.
- commit 9bff21f
* Fri Jan 19 2024 jslaby@suse.cz
- mm: huge_memory: don't force huge page alignment on 32 bit
  (bsc#1218841).
- Delete
  patches.suse/Revert-mm-align-larger-anonymous-mappings-on-THP-bou.patch.
  Replace the revert by an upstream fix.
- commit d54abef
* Fri Jan 19 2024 jslaby@suse.cz
- Update patches.suse/futex-Avoid-reusing-outdated-pi_state.patch
  (bsc#1218801).
  Update to v2.
- commit eeba83a
* Wed Jan 17 2024 jslaby@suse.cz
- Revert "mm: align larger anonymous mappings on THP boundaries"
  (bsc#1218841).
- commit 69537e9
* Tue Jan 16 2024 jslaby@suse.cz
- futex: Avoid reusing outdated pi_state (bsc#1218841).
- commit 9859079
* Thu Jan 11 2024 tiwai@suse.de
- Store the old kernel changelog entries in kernel-docs package (bsc#1218713)
  The old entries are found in kernel-docs/old_changelog.txt in docdir.
  rpm/old_changelog.txt can be an optional file that stores the similar
  info like rpm/kernel-sources.changes.old.  It can specify the commit
  range that have been truncated.  scripts/tar-up.sh expands from the
  git log accordingly.
- commit c9a2566
* Thu Jan 11 2024 jslaby@suse.cz
- keys, dns: Fix size check of V1 server-list header (git-fixes).
- commit 9e5e777
* Thu Jan 11 2024 jslaby@suse.cz
- Linux 6.6.11 (bsc#1012628).
- keys, dns: Fix missing size check of V1 server-list header
  (bsc#1012628).
- ALSA: hda/tas2781: do not use regcache (bsc#1012628).
- ALSA: hda/tas2781: move set_drv_data outside tasdevice_init
  (bsc#1012628).
- ALSA: hda/tas2781: remove sound controls in unbind
  (bsc#1012628).
- ALSA: hda/realtek: enable SND_PCI_QUIRK for hp pavilion
  14-ec1xxx series (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs for a HP ZBook
  (bsc#1012628).
- ALSA: hda/realtek: Fix mute and mic-mute LEDs for HP ProBook
  440 G6 (bsc#1012628).
- drm/amd/display: pbn_div need be updated for hotplug event
  (bsc#1012628).
- mptcp: prevent tcp diag from closing listener subflows
  (bsc#1012628).
- Revert "PCI/ASPM: Remove pcie_aspm_pm_state_change()"
  (bsc#1012628).
- drm/mgag200: Fix gamma lut not initialized for G200ER, G200EV,
  G200SE (bsc#1012628).
- cifs: cifs_chan_is_iface_active should be called with chan_lock
  held (bsc#1012628).
- cifs: do not depend on release_iface for maintaining iface_list
  (bsc#1012628).
- KVM: x86/pmu: fix masking logic for MSR_CORE_PERF_GLOBAL_CTRL
  (bsc#1012628).
- accel/qaic: Fix GEM import path code (bsc#1012628).
- accel/qaic: Implement quirk for SOC_HW_VERSION (bsc#1012628).
- wifi: iwlwifi: pcie: don't synchronize IRQs from IRQ
  (bsc#1012628).
- drm/bridge: parade-ps8640: Never store more than msg->size
  bytes in AUX xfer (bsc#1012628).
- drm/bridge: ti-sn65dsi86: Never store more than msg->size
  bytes in AUX xfer (bsc#1012628).
- drm/bridge: ps8640: Fix size mismatch warning w/ len
  (bsc#1012628).
- netfilter: nf_tables: set transport offset from mac header
  for netdev/egress (bsc#1012628).
- nfc: llcp_core: Hold a ref to llcp_local->dev when holding a
  ref to llcp_local (bsc#1012628).
- octeontx2-af: Fix marking couple of structure as __packed
  (bsc#1012628).
- drm/i915/dp: Fix passing the correct DPCD_REV for
  drm_dp_set_phy_test_pattern (bsc#1012628).
- drm/i915/perf: Update handling of MMIO triggered reports
  (bsc#1012628).
- ice: Fix link_down_on_close message (bsc#1012628).
- ice: Shut down VSI with "link-down-on-close" enabled
  (bsc#1012628).
- i40e: Fix filter input checks to prevent config with invalid
  values (bsc#1012628).
- igc: Report VLAN EtherType matching back to user (bsc#1012628).
- igc: Check VLAN TCI mask (bsc#1012628).
- igc: Check VLAN EtherType mask (bsc#1012628).
- ASoC: fsl_rpmsg: Fix error handler with pm_runtime_enable
  (bsc#1012628).
- ASoC: mediatek: mt8186: fix AUD_PAD_TOP register and offset
  (bsc#1012628).
- mlxbf_gige: fix receive packet race condition (bsc#1012628).
- net: sched: em_text: fix possible memory leak in
  em_text_destroy() (bsc#1012628).
- r8169: Fix PCI error on system resume (bsc#1012628).
- net: Implement missing getsockopt(SO_TIMESTAMPING_NEW)
  (bsc#1012628).
- selftests: bonding: do not set port down when adding to bond
  (bsc#1012628).
- ARM: sun9i: smp: Fix array-index-out-of-bounds read in
  sunxi_mc_smp_init (bsc#1012628).
- sfc: fix a double-free bug in efx_probe_filters (bsc#1012628).
- net: bcmgenet: Fix FCS generation for fragmented skbuffs
  (bsc#1012628).
- netfilter: nf_nat: fix action not being set for all ct states
  (bsc#1012628).
- netfilter: nft_immediate: drop chain reference counter on error
  (bsc#1012628).
- net: Save and restore msg_namelen in sock_sendmsg (bsc#1012628).
- i40e: fix use-after-free in i40e_aqc_add_filters()
  (bsc#1012628).
- ASoC: meson: g12a-toacodec: Validate written enum values
  (bsc#1012628).
- ASoC: meson: g12a-tohdmitx: Validate written enum values
  (bsc#1012628).
- ASoC: meson: g12a-toacodec: Fix event generation (bsc#1012628).
- ASoC: meson: g12a-tohdmitx: Fix event generation for S/PDIF mux
  (bsc#1012628).
- i40e: Restore VF MSI-X state during PCI reset (bsc#1012628).
- igc: Fix hicredit calculation (bsc#1012628).
- apparmor: Fix move_mount mediation by detecting if source is
  detached (bsc#1012628).
- virtio_net: avoid data-races on dev->stats fields (bsc#1012628).
- virtio_net: fix missing dma unmap for resize (bsc#1012628).
- net/qla3xxx: fix potential memleak in ql_alloc_buffer_queues
  (bsc#1012628).
- net/smc: fix invalid link access in dumping SMC-R connections
  (bsc#1012628).
- octeontx2-af: Always configure NIX TX link credits based on
  max frame size (bsc#1012628).
- octeontx2-af: Re-enable MAC TX in otx2_stop processing
  (bsc#1012628).
- asix: Add check for usbnet_get_endpoints (bsc#1012628).
- net: ravb: Wait for operating mode to be applied (bsc#1012628).
- bnxt_en: Remove mis-applied code from bnxt_cfg_ntp_filters()
  (bsc#1012628).
- net: Implement missing SO_TIMESTAMPING_NEW cmsg support
  (bsc#1012628).
- mm: convert DAX lock/unlock page to lock/unlock folio
  (bsc#1012628).
- mm/memory-failure: pass the folio and the page to
  collect_procs() (bsc#1012628).
- xsk: add multi-buffer support for sockets sharing umem
  (bsc#1012628).
- media: qcom: camss: Fix V4L2 async notifier error path
  (bsc#1012628).
- media: qcom: camss: Fix genpd cleanup (bsc#1012628).
- tcp: derive delack_max from rto_min (bsc#1012628).
- bpftool: Fix -Wcast-qual warning (bsc#1012628).
- bpftool: Align output skeleton ELF code (bsc#1012628).
- crypto: xts - use 'spawn' for underlying single-block cipher
  (bsc#1012628).
- crypto: qat - fix double free during reset (bsc#1012628).
- crypto: hisilicon/qm - fix EQ/AEQ interrupt issue (bsc#1012628).
- vfio/mtty: Overhaul mtty interrupt handling (bsc#1012628).
- clk: si521xx: Increase stack based print buffer size in probe
  (bsc#1012628).
- RDMA/mlx5: Fix mkey cache WQ flush (bsc#1012628).
- ACPI: thermal: Fix acpi_thermal_unregister_thermal_zone()
  cleanup (bsc#1012628).
- rcu: Break rcu_node_0 --> &rq->__lock order (bsc#1012628).
- rcu: Introduce rcu_cpu_online() (bsc#1012628).
- rcu/tasks: Handle new PF_IDLE semantics (bsc#1012628).
- rcu/tasks-trace: Handle new PF_IDLE semantics (bsc#1012628).
- riscv: don't probe unaligned access speed if already done
  (bsc#1012628).
- KVM: s390: vsie: fix wrong VIR 37 when MSO is used
  (bsc#1012628).
- phy: ti: gmii-sel: Fix register offset when parent is not a
  syscon node (bsc#1012628).
- dmaengine: ti: k3-psil-am62: Fix SPI PDMA data (bsc#1012628).
- dmaengine: ti: k3-psil-am62a: Fix SPI PDMA data (bsc#1012628).
- dmaengine: fsl-edma: Do not suspend and resume the masked dma
  channel when the system is sleeping (bsc#1012628).
- dmaengine: fsl-edma: Add judgment on enabling round robin
  arbitration (bsc#1012628).
- iio: imu: adis16475: use bit numbers in assign_bit()
  (bsc#1012628).
- iommu/vt-d: Support enforce_cache_coherency only for empty
  domains (bsc#1012628).
- phy: mediatek: mipi: mt8183: fix minimal supported frequency
  (bsc#1012628).
- phy: sunplus: return negative error code in sp_usb_phy_probe
  (bsc#1012628).
- clk: rockchip: rk3128: Fix aclk_peri_src's parent (bsc#1012628).
- clk: rockchip: rk3128: Fix SCLK_SDMMC's clock name
  (bsc#1012628).
- drm/i915: Call intel_pre_plane_updates() also for pipes getting
  enabled (bsc#1012628).
- drm/amd/display: Increase num voltage states to 40
  (bsc#1012628).
- cxl: Add cxl_decoders_committed() helper (bsc#1012628).
- cxl/core: Always hold region_rwsem while reading poison lists
  (bsc#1012628).
- kernel/resource: Increment by align value in
  get_free_mem_region() (bsc#1012628).
- drm/amd/display: Increase frame warning limit with KASAN or
  KCSAN in dml (bsc#1012628).
- dmaengine: idxd: Protect int_handle field in hw descriptor
  (bsc#1012628).
- dmaengine: fsl-edma: fix wrong pointer check in
  fsl_edma3_attach_pd() (bsc#1012628).
- RISCV: KVM: update external interrupt atomically for IMSIC
  swfile (bsc#1012628).
- powerpc/pseries/vas: Migration suspend waits for no in-progress
  open windows (bsc#1012628).
- net: prevent mss overflow in skb_segment() (bsc#1012628).
- cxl/pmu: Ensure put_device on pmu devices (bsc#1012628).
- net: libwx: fix memory leak on free page (bsc#1012628).
- net: constify sk_dst_get() and __sk_dst_get() argument
  (bsc#1012628).
- mm/mglru: skip special VMAs in lru_gen_look_around()
  (bsc#1012628).
- x86/kprobes: fix incorrect return address calculation in
  kprobe_emulate_call_indirect (bsc#1012628).
- i2c: core: Fix atomic xfer check for non-preempt config
  (bsc#1012628).
- mm: fix unmap_mapping_range high bits shift bug (bsc#1012628).
- drm/amdgpu: skip gpu_info fw loading on navi12 (bsc#1012628).
- drm/amd/display: add nv12 bounding box (bsc#1012628).
- drm/amd/display: Fix sending VSC (+ colorimetry) packets for
  DP/eDP displays without PSR (bsc#1012628).
- mmc: meson-mx-sdhc: Fix initialization frozen issue
  (bsc#1012628).
- mmc: rpmb: fixes pause retune on all RPMB partitions
  (bsc#1012628).
- mmc: core: Cancel delayed work before releasing host
  (bsc#1012628).
- mmc: sdhci-sprd: Fix eMMC init failure after hw reset
  (bsc#1012628).
- cxl: Add cxl_num_decoders_committed() usage to cxl_test
  (bsc#1012628).
- cxl/hdm: Fix a benign lockdep splat (bsc#1012628).
- cxl/memdev: Hold region_rwsem during inject and clear poison
  ops (bsc#1012628).
- media: qcom: camss: Comment CSID dt_id field (bsc#1012628).
- Rename to
  patches.kernel.org/6.6.11-110-firewire-ohci-suppress-unexpected-system-reboo.patch.
- commit f421cf4
* Mon Jan  8 2024 palcantara@suse.de
- smb: client: fix potential OOB in smb2_dump_detail()
  (bsc#1217946 CVE-2023-6610).
- commit edb885a
* Mon Jan  8 2024 msuchanek@suse.de
- Limit kernel-source build to architectures for which the kernel binary
  is built (bsc#1108281).
- commit 08a9e44
* Mon Jan  8 2024 jslaby@suse.cz
- Revert "minmax: allow min()/max()/clamp() if the arguments
  have the same signedness." (fix build and make it faster).
- Revert "minmax: fix indentation of __cmp_once() and
  __clamp_once()" (fix build and make it faster).
- commit 7b7f72a
* Mon Jan  8 2024 jslaby@suse.cz
- Revert "minmax: allow comparisons of 'int' against 'unsigned
  char/short'" (fix build and make it faster).
- Revert "minmax: relax check to allow comparison between unsigned
  arguments and signed constants" (fix build and make it faster).
- commit a7cbb4e
* Mon Jan  8 2024 jslaby@suse.cz
- Refresh
  patches.suse/firewire-ohci-suppress-unexpected-system-reboot-in-A.patch.
  Update upstream status and move to sorted section.
- commit 7d3b8d0
* Mon Jan  8 2024 jslaby@suse.cz
- Linux 6.6.10 (bsc#1012628).
- Revert "platform/x86: p2sb: Allow p2sb_bar() calls during PCI
  device probe" (bsc#1012628).
- netfilter: nf_tables: skip set commit for deleted/destroyed sets
  (bsc#1012628).
- wifi: nl80211: fix deadlock in nl80211_set_cqm_rssi (6.6.x)
  (bsc#1012628).
- wifi: cfg80211: fix CQM for non-range use (bsc#1012628).
- tracing: Fix blocked reader of snapshot buffer (bsc#1012628).
- ftrace: Fix modification of direct_function hash while in use
  (bsc#1012628).
- ring-buffer: Fix wake ups when buffer_percent is set to 100
  (bsc#1012628).
- Revert "nvme-fc: fix race between error recovery and creating
  association" (bsc#1012628).
- mm/memory-failure: check the mapcount of the precise page
  (bsc#1012628).
- mm/memory-failure: cast index to loff_t before shifting it
  (bsc#1012628).
- mm: migrate high-order folios in swap cache correctly
  (bsc#1012628).
- mm/filemap: avoid buffered read/write race to read inconsistent
  data (bsc#1012628).
- selftests: secretmem: floor the memory size to the multiple
  of page_size (bsc#1012628).
- maple_tree: do not preallocate nodes for slot stores
  (bsc#1012628).
- platform/x86: p2sb: Allow p2sb_bar() calls during PCI device
  probe (bsc#1012628).
- ksmbd: fix slab-out-of-bounds in smb_strndup_from_utf16()
  (bsc#1012628).
- platform/x86/intel/pmc: Move GBE LTR ignore to suspend callback
  (bsc#1012628).
- platform/x86/intel/pmc: Allow reenabling LTRs (bsc#1012628).
- platform/x86/intel/pmc: Add suspend callback (bsc#1012628).
- block: renumber QUEUE_FLAG_HW_WC (bsc#1012628).
- mptcp: fix inconsistent state on fastopen race (bsc#1012628).
- mptcp: fix possible NULL pointer dereference on close
  (bsc#1012628).
- mptcp: refactor sndbuf auto-tuning (bsc#1012628).
- linux/export: Ensure natural alignment of kcrctab array
  (bsc#1012628).
- linux/export: Fix alignment for 64-bit ksymtab entries
  (bsc#1012628).
- kexec: select CRYPTO from KEXEC_FILE instead of depending on it
  (bsc#1012628).
- kexec: fix KEXEC_FILE dependencies (bsc#1012628).
- Update config files.
  The defaults for s390 taken from the master branch.
- virtio_ring: fix syncs DMA memory with different direction
  (bsc#1012628).
- fs: cifs: Fix atime update check (bsc#1012628).
- client: convert to new timestamp accessors (bsc#1012628).
- fs: new accessor methods for atime and mtime (bsc#1012628).
- ksmbd: avoid duplicate opinfo_put() call on error of
  smb21_lease_break_ack() (bsc#1012628).
- ksmbd: lazy v2 lease break on smb2_write() (bsc#1012628).
- ksmbd: send v2 lease break notification for directory
  (bsc#1012628).
- ksmbd: downgrade RWH lease caching state to RH for directory
  (bsc#1012628).
- ksmbd: set v2 lease capability (bsc#1012628).
- ksmbd: set epoch in create context v2 lease (bsc#1012628).
- ksmbd: don't update ->op_state as OPLOCK_STATE_NONE on error
  (bsc#1012628).
- ksmbd: move setting SMB2_FLAGS_ASYNC_COMMAND and AsyncId
  (bsc#1012628).
- ksmbd: release interim response after sending status pending
  response (bsc#1012628).
- ksmbd: move oplock handling after unlock parent dir
  (bsc#1012628).
- ksmbd: separately allocate ci per dentry (bsc#1012628).
- ksmbd: prevent memory leak on error return (bsc#1012628).
- ksmbd: fix kernel-doc comment of ksmbd_vfs_kern_path_locked()
  (bsc#1012628).
- ksmbd: no need to wait for binded connection termination at
  logoff (bsc#1012628).
- ksmbd: add support for surrogate pair conversion (bsc#1012628).
- ksmbd: fix missing RDMA-capable flag for IPoIB device in
  ksmbd_rdma_capable_netdev() (bsc#1012628).
- ksmbd: fix kernel-doc comment of ksmbd_vfs_setxattr()
  (bsc#1012628).
- ksmbd: reorganize ksmbd_iov_pin_rsp() (bsc#1012628).
- ksmbd: Remove unused field in ksmbd_user struct (bsc#1012628).
- commit b5b393f
* Mon Jan  8 2024 jslaby@suse.cz
- Refresh
  patches.suse/bus-mhi-host-add-mhi_power_down_no_destroy.patch.
- Refresh
  patches.suse/bus-mhi-host-add-new-interfaces-to-handle-MHI-channe.patch.
- Refresh
  patches.suse/wifi-ath11k-do-not-dump-SRNG-statistics-during-resum.patch.
- Refresh
  patches.suse/wifi-ath11k-fix-warning-on-DMA-ring-capabilities-eve.patch.
- Refresh
  patches.suse/wifi-ath11k-handle-irq-enable-disable-in-several-cod.patch.
- Refresh
  patches.suse/wifi-ath11k-remove-MHI-LOOPBACK-channels.patch.
- Refresh patches.suse/wifi-ath11k-support-hibernation.patch.
- Refresh
  patches.suse/wifi-ath11k-thermal-don-t-try-to-register-multiple-t.patch.
  Note the branch name the patches are in.
- commit 9538a8b
* Sun Jan  7 2024 mkubecek@suse.cz
- Update to 6.7
- refresh configs (only headers)
- commit e615918
* Fri Jan  5 2024 petr.pavlu@suse.com
- Delete doc/config-options.changes (jsc#PED-5021)
  Following on adedbd2a5c6 ("kernel-source: Remove config-options.changes
  (jsc#PED-5021)"), remove the now unused file from the tree.
- commit e04388e
* Fri Jan  5 2024 jslaby@suse.cz
- Refresh
  patches.suse/firewire-ohci-suppress-unexpected-system-reboot-in-A.patch.
  Update upstream status.
- commit 6da42fc
* Thu Jan  4 2024 msuchanek@suse.de
- config: ppc64le: CONFIG_MEM_SOFT_DIRTY=y (bsc#1218286 ltc#204519).
- commit c8c5229
* Thu Jan  4 2024 jslaby@suse.cz
- Update config files.
  Only run oldconfig to keep up with the lost configs.
- commit 473d8d7
* Thu Jan  4 2024 jslaby@suse.cz
- firewire: ohci: suppress unexpected system reboot in AMD Ryzen
  machines and ASM108x/VT630x PCIe cards (bsc#1215436).
- commit 139a7b3
* Wed Jan  3 2024 msuchanek@suse.de
- mkspec: Add multibuild support (JSC-SLE#5501, boo#1211226, bsc#1218184)
  When MULTIBUILD option in config.sh is enabled generate a _multibuild
  file listing all spec files.
- commit f734347
* Wed Jan  3 2024 msuchanek@suse.de
- Build in the correct KOTD repository with multibuild
  (JSC-SLE#5501, boo#1211226, bsc#1218184)
  With multibuild setting repository flags is no longer supported for
  individual spec files - see
  https://github.com/openSUSE/open-build-service/issues/3574
  Add ExclusiveArch conditional that depends on a macro set up by
  bs-upload-kernel instead. With that each package should build only in
  one repository - either standard or QA.
  Note: bs-upload-kernel does not interpret rpm conditionals, and only
  uses the first ExclusiveArch line to determine the architectures to
  enable.
- commit aa5424d
* Wed Jan  3 2024 msuchanek@suse.de
- rpm/config.sh: Enable multibuild.
- commit 7b72f91
* Tue Jan  2 2024 jslaby@suse.cz
- Linux 6.6.9 (bsc#1012628).
- bpf: Fix prog_array_map_poke_run map poke update (bsc#1012628).
- mm/damon/core: use number of passed access sampling as a timer
  (bsc#1012628).
- mm/damon/core: make damon_start() waits until kdamond_fn()
  starts (bsc#1012628).
- btrfs: qgroup: iterate qgroups without memory allocation for
  qgroup_reserve() (bsc#1012628).
- btrfs: qgroup: use qgroup_iterator in qgroup_convert_meta()
  (bsc#1012628).
- btrfs: free qgroup pertrans reserve on transaction abort
  (bsc#1012628).
- drm/amd/display: fix hw rotated modes when PSR-SU is enabled
  (bsc#1012628).
- drm/i915: Fix FEC state dump (bsc#1012628).
- drm/i915: Introduce crtc_state->enhanced_framing (bsc#1012628).
- drm/i915/edp: don't write to DP_LINK_BW_SET when using rate
  select (bsc#1012628).
- drm: Update file owner during use (bsc#1012628).
- drm: Fix FD ownership check in drm_master_check_perm()
  (bsc#1012628).
- spi: spi-imx: correctly configure burst length when using dma
  (bsc#1012628).
- arm64: dts: allwinner: h616: update emac for Orange Pi Zero 3
  (bsc#1012628).
- ARM: dts: dra7: Fix DRA7 L3 NoC node register size
  (bsc#1012628).
- ARM: OMAP2+: Fix null pointer dereference and memory leak in
  omap_soc_device_init (bsc#1012628).
- reset: Fix crash when freeing non-existent optional resets
  (bsc#1012628).
- s390/vx: fix save/restore of fpu kernel context (bsc#1012628).
- platform/x86/intel/pmc: Fix hang in pmc_core_send_ltr_ignore()
  (bsc#1012628).
- SUNRPC: Revert 5f7fc5d69f6e92ec0b38774c387f5cf7812c5806
  (bsc#1012628).
- wifi: ieee80211: don't require protected vendor action frames
  (bsc#1012628).
- wifi: iwlwifi: pcie: add another missing bh-disable for
  rxq->lock (bsc#1012628).
- wifi: mac80211: check if the existing link config remains
  unchanged (bsc#1012628).
- wifi: mac80211: don't re-add debugfs during reconfig
  (bsc#1012628).
- wifi: mac80211: check defragmentation succeeded (bsc#1012628).
- wifi: mac80211: mesh: check element parsing succeeded
  (bsc#1012628).
- wifi: mac80211: mesh_plink: fix matches_local logic
  (bsc#1012628).
- ice: fix theoretical out-of-bounds access in ethtool link modes
  (bsc#1012628).
- bpf: syzkaller found null ptr deref in unix_bpf proto add
  (bsc#1012628).
- Revert "net/mlx5e: fix double free of encap_header in update
  funcs" (bsc#1012628).
- Revert "net/mlx5e: fix double free of encap_header"
  (bsc#1012628).
- net/mlx5e: Fix slab-out-of-bounds in
  mlx5_query_nic_vport_mac_list() (bsc#1012628).
- net/mlx5e: Fix a race in command alloc flow (bsc#1012628).
- net/mlx5e: fix a potential double-free in fs_udp_create_groups
  (bsc#1012628).
- net/mlx5e: Fix overrun reported by coverity (bsc#1012628).
- net/mlx5e: Decrease num_block_tc when unblock tc offload
  (bsc#1012628).
- net/mlx5e: XDP, Drop fragmented packets larger than MTU size
  (bsc#1012628).
- net/mlx5: Fix fw tracer first block check (bsc#1012628).
- net/mlx5: Refactor mlx5_flow_destination->rep pointer to vport
  num (bsc#1012628).
- net/mlx5e: Fix error code in mlx5e_tc_action_miss_mapping_get()
  (bsc#1012628).
- net/mlx5e: Fix error codes in alloc_branch_attr() (bsc#1012628).
- net/mlx5e: Correct snprintf truncation handling for fw_version
  buffer (bsc#1012628).
- net/mlx5e: Correct snprintf truncation handling for fw_version
  buffer used by representors (bsc#1012628).
- net: mscc: ocelot: fix eMAC TX RMON stats for bucket 256-511
  and above (bsc#1012628).
- net: mscc: ocelot: fix pMAC TX RMON stats for bucket 256-511
  and above (bsc#1012628).
- octeontx2-pf: Fix graceful exit during PFC configuration failure
  (bsc#1012628).
- net: Return error from sk_stream_wait_connect() if
  sk_wait_event() fails (bsc#1012628).
- net: sched: ife: fix potential use-after-free (bsc#1012628).
- ethernet: atheros: fix a memleak in atl1e_setup_ring_resources
  (bsc#1012628).
- net/rose: fix races in rose_kill_by_device() (bsc#1012628).
- Bluetooth: Fix not notifying when connection encryption changes
  (bsc#1012628).
- Bluetooth: Fix deadlock in vhci_send_frame (bsc#1012628).
- Bluetooth: hci_event: shut up a false-positive warning
  (bsc#1012628).
- Bluetooth: hci_core: Fix hci_conn_hash_lookup_cis (bsc#1012628).
- bnxt_en: do not map packet buffers twice (bsc#1012628).
- net: phy: skip LED triggers on PHYs on SFP modules
  (bsc#1012628).
- ice: stop trashing VF VSI aggregator node ID information
  (bsc#1012628).
- ice: alter feature support check for SRIOV and LAG
  (bsc#1012628).
- ice: Fix PF with enabled XDP going no-carrier after reset
  (bsc#1012628).
- net: mana: select PAGE_POOL (bsc#1012628).
- net: check vlan filter feature in vlan_vids_add_by_dev()
  and vlan_vids_del_by_dev() (bsc#1012628).
- afs: Fix the dynamic root's d_delete to always delete unused
  dentries (bsc#1012628).
- afs: Fix dynamic root lookup DNS check (bsc#1012628).
- net: ethernet: mtk_wed: fix possible NULL pointer dereference
  in mtk_wed_wo_queue_tx_clean() (bsc#1012628).
- net/ipv6: Revert remove expired routes with a separated list
  of routes (bsc#1012628).
- net: check dev->gso_max_size in gso_features_check()
  (bsc#1012628).
- keys, dns: Allow key types (eg. DNS) to be reclaimed immediately
  on expiry (bsc#1012628).
- afs: Fix overwriting of result of DNS query (bsc#1012628).
- afs: Fix use-after-free due to get/remove race in volume tree
  (bsc#1012628).
- drm/i915/hwmon: Fix static analysis tool reported issues
  (bsc#1012628).
- drm/i915/mtl: Fix HDMI/DP PLL clock selection (bsc#1012628).
- ASoC: hdmi-codec: fix missing report for jack initial status
  (bsc#1012628).
- ASoC: fsl_sai: Fix channel swap issue on i.MX8MP (bsc#1012628).
- i2c: qcom-geni: fix missing clk_disable_unprepare() and
  geni_se_resources_off() (bsc#1012628).
- drm/amdgpu: re-create idle bo's PTE during VM state machine
  reset (bsc#1012628).
- i2c: aspeed: Handle the coalesced stop conditions with the
  start conditions (bsc#1012628).
- x86/xen: add CPU dependencies for 32-bit build (bsc#1012628).
- pinctrl: at91-pio4: use dedicated lock class for IRQ
  (bsc#1012628).
- gpiolib: cdev: add gpio_device locking wrapper around
  gpio_ioctl() (bsc#1012628).
- nvme-pci: fix sleeping function called from interrupt context
  (bsc#1012628).
- interconnect: Treat xlate() returning NULL node as an error
  (bsc#1012628).
- iio: imu: inv_mpu6050: fix an error code problem in
  inv_mpu6050_read_raw (bsc#1012628).
- interconnect: qcom: sm8250: Enable sync_state (bsc#1012628).
- Input: ipaq-micro-keys - add error handling for devm_kmemdup
  (bsc#1012628).
- iio: adc: meson: add separate config for axg SoC family
  (bsc#1012628).
- scsi: bnx2fc: Fix skb double free in bnx2fc_rcv() (bsc#1012628).
- scsi: ufs: qcom: Return ufs_qcom_clk_scale_*() errors in
  ufs_qcom_clk_scale_notify() (bsc#1012628).
- scsi: ufs: core: Let the sq_lock protect sq_tail_slot access
  (bsc#1012628).
- iio: kx022a: Fix acceleration value scaling (bsc#1012628).
- iio: adc: imx93: add four channels for imx93 adc (bsc#1012628).
- iio: common: ms_sensors: ms_sensors_i2c: fix humidity conversion
  time table (bsc#1012628).
- iio: imu: adis16475: add spi_device_id table (bsc#1012628).
- iio: adc: ti_am335x_adc: Fix return value check of
  tiadc_request_dma() (bsc#1012628).
- iio: tmag5273: fix temperature offset (bsc#1012628).
- iio: triggered-buffer: prevent possible freeing of wrong buffer
  (bsc#1012628).
- ALSA: usb-audio: Increase delay in MOTU M quirk (bsc#1012628).
- ARM: dts: Fix occasional boot hang for am3 usb (bsc#1012628).
- usb-storage: Add quirk for incorrect WP on Kingston DT Ultimate
  3.0 G3 (bsc#1012628).
- wifi: mt76: fix crash with WED rx support enabled (bsc#1012628).
- wifi: cfg80211: Add my certificate (bsc#1012628).
- wifi: cfg80211: fix certs build to not depend on file order
  (bsc#1012628).
- USB: serial: ftdi_sio: update Actisense PIDs constant names
  (bsc#1012628).
- USB: serial: option: add Quectel EG912Y module support
  (bsc#1012628).
- USB: serial: option: add Foxconn T99W265 with new baseline
  (bsc#1012628).
- USB: serial: option: add Quectel RM500Q R13 firmware support
  (bsc#1012628).
- ALSA: hda/tas2781: select program 0, conf 0 by default
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ASUS ROG GV302XA (bsc#1012628).
- ASoC: tas2781: check the validity of prm_no/cfg_no
  (bsc#1012628).
- Bluetooth: hci_event: Fix not checking if HCI_OP_INQUIRY has
  been sent (bsc#1012628).
- Bluetooth: af_bluetooth: Fix Use-After-Free in bt_sock_recvmsg
  (bsc#1012628).
- Bluetooth: L2CAP: Send reject on command corrupted request
  (bsc#1012628).
- Bluetooth: MGMT/SMP: Fix address type when using SMP over
  BREDR/LE (bsc#1012628).
- Bluetooth: Add more enc key size check (bsc#1012628).
- usb: typec: ucsi: fix gpio-based orientation detection
  (bsc#1012628).
- usb: fotg210-hcd: delete an incorrect bounds test (bsc#1012628).
- net: usb: ax88179_178a: avoid failed operations when device
  is disconnected (bsc#1012628).
- Input: soc_button_array - add mapping for airplane mode button
  (bsc#1012628).
- net: 9p: avoid freeing uninit memory in p9pdu_vreadf
  (bsc#1012628).
- net: rfkill: gpio: set GPIO direction (bsc#1012628).
- net: ks8851: Fix TX stall caused by TX buffer overrun
  (bsc#1012628).
- net: avoid build bug in skb extension length calculation
  (bsc#1012628).
- net: stmmac: fix incorrect flag check in timestamp interrupt
  (bsc#1012628).
- dt-bindings: nvmem: mxs-ocotp: Document fsl,ocotp (bsc#1012628).
- nfsd: call nfsd_last_thread() before final nfsd_put()
  (bsc#1012628).
- smb: client: fix OOB in cifsd when receiving compounded resps
  (bsc#1012628).
- smb: client: fix potential OOB in cifs_dump_detail()
  (bsc#1012628).
- smb: client: fix OOB in SMB2_query_info_init() (bsc#1012628).
- drm/i915: Reject async flips with bigjoiner (bsc#1012628).
- drm/i915/dmc: Don't enable any pipe DMC events (bsc#1012628).
- 9p: prevent read overrun in protocol dump tracepoint
  (bsc#1012628).
- ring-buffer: Fix 32-bit rb_time_read() race with
  rb_time_cmpxchg() (bsc#1012628).
- ring-buffer: Remove useless update to write_stamp in
  rb_try_to_discard() (bsc#1012628).
- ring-buffer: Fix slowpath of interrupted event (bsc#1012628).
- spi: atmel: Do not cancel a transfer upon any signal
  (bsc#1012628).
- spi: atmel: Prevent spi transfers from being killed
  (bsc#1012628).
- spi: atmel: Fix clock issue when using devices with different
  polarities (bsc#1012628).
- nvmem: brcm_nvram: store a copy of NVRAM content (bsc#1012628).
- Revert "scsi: aacraid: Reply queue mapping to CPUs based on
  IRQ affinity" (bsc#1012628).
- scsi: core: Always send batch on reset or error handling command
  (bsc#1012628).
- tracing / synthetic: Disable events after testing in
  synth_event_gen_test_init() (bsc#1012628).
- dm-integrity: don't modify bio's immutable bio_vec in
  integrity_metadata() (bsc#1012628).
- selftests: mptcp: join: fix subflow_send_ack lookup
  (bsc#1012628).
- pinctrl: starfive: jh7110: ignore disabled device tree nodes
  (bsc#1012628).
- pinctrl: starfive: jh7100: ignore disabled device tree nodes
  (bsc#1012628).
- bus: ti-sysc: Flush posted write only after srst_udelay
  (bsc#1012628).
- gpio: dwapb: mask/unmask IRQ when disable/enale it
  (bsc#1012628).
- lib/vsprintf: Fix %%pfwf when current node refcount == 0
  (bsc#1012628).
- thunderbolt: Fix memory leak in margining_port_remove()
  (bsc#1012628).
- KVM: arm64: vgic: Simplify kvm_vgic_destroy() (bsc#1012628).
- KVM: arm64: vgic: Add a non-locking primitive for
  kvm_vgic_vcpu_destroy() (bsc#1012628).
- KVM: arm64: vgic: Force vcpu vgic teardown on vcpu destroy
  (bsc#1012628).
- x86/alternatives: Sync core before enabling interrupts
  (bsc#1012628).
- x86/alternatives: Disable interrupts and sync when optimizing
  NOPs in place (bsc#1012628).
- x86/smpboot/64: Handle X2APIC BIOS inconsistency gracefully
  (bsc#1012628).
- spi: cadence: revert "Add SPI transfer delays" (bsc#1012628).
- Rename to
  patches.kernel.org/6.6.9-128-smb-client-fix-OOB-in-smbCalcSize.patch.
- commit 61d1d44
* Mon Jan  1 2024 mkubecek@suse.cz
- Update to 6.7-rc8
- update configs
  - s390x/zfcpdump:
  - KEXEC_FILE=y
- commit 521bba4
* Wed Dec 27 2023 palcantara@suse.de
- smb: client: fix OOB in smbCalcSize() (bsc#1217947
  CVE-2023-6606).
- commit c2168b0
* Sun Dec 24 2023 mkubecek@suse.cz
- Update to 6.7-rc7
- refresh configs
- commit 65d9931
* Wed Dec 20 2023 jslaby@suse.cz
- Linux 6.6.8 (bsc#1012628).
- r8152: add vendor/device ID pair for ASUS USB-C2500
  (bsc#1012628).
- ext4: fix warning in ext4_dio_write_end_io() (bsc#1012628).
- ksmbd: fix memory leak in smb2_lock() (bsc#1012628).
- afs: Fix refcount underflow from error handling race
  (bsc#1012628).
- HID: lenovo: Restrict detection of patched firmware only to
  USB cptkbd (bsc#1012628).
- net/mlx5e: Honor user choice of IPsec replay window size
  (bsc#1012628).
- net/mlx5e: Ensure that IPsec sequence packet number starts
  from 1 (bsc#1012628).
- net/mlx5e: Unify esw and normal IPsec status table
  creation/destruction (bsc#1012628).
- net/mlx5e: Tidy up IPsec NAT-T SA discovery (bsc#1012628).
- net/mlx5e: Reduce eswitch mode_lock protection context
  (bsc#1012628).
- net/mlx5e: Check the number of elements before walk TC
  rhashtable (bsc#1012628).
- RDMA/mlx5: Send events from IB driver about device affiliation
  state (bsc#1012628).
- net/mlx5e: Disable IPsec offload support if not FW steering
  (bsc#1012628).
- net/mlx5e: Fix possible deadlock on mlx5e_tx_timeout_work
  (bsc#1012628).
- net/mlx5e: TC, Don't offload post action rule if not supported
  (bsc#1012628).
- net/mlx5: Nack sync reset request when HotPlug is enabled
  (bsc#1012628).
- net/mlx5e: Check netdev pointer before checking its net ns
  (bsc#1012628).
- net/mlx5: Fix a NULL vs IS_ERR() check (bsc#1012628).
- net: ipv6: support reporting otherwise unknown prefix flags
  in RTM_NEWPREFIX (bsc#1012628).
- qca_debug: Prevent crash on TX ring changes (bsc#1012628).
- qca_debug: Fix ethtool -G iface tx behavior (bsc#1012628).
- qca_spi: Fix reset behavior (bsc#1012628).
- bnxt_en: Clear resource reservation during resume (bsc#1012628).
- bnxt_en: Fix skb recycling logic in bnxt_deliver_skb()
  (bsc#1012628).
- bnxt_en: Fix wrong return value check in bnxt_close_nic()
  (bsc#1012628).
- bnxt_en: Fix HWTSTAMP_FILTER_ALL packet timestamp logic
  (bsc#1012628).
- atm: solos-pci: Fix potential deadlock on &cli_queue_lock
  (bsc#1012628).
- atm: solos-pci: Fix potential deadlock on &tx_queue_lock
  (bsc#1012628).
- net: fec: correct queue selection (bsc#1012628).
- octeontx2-af: fix a use-after-free in rvu_nix_register_reporters
  (bsc#1012628).
- net/sched: act_ct: Take per-cb reference to tcf_ct_flow_table
  (bsc#1012628).
- octeon_ep: explicitly test for firmware ready value
  (bsc#1012628).
- octeontx2-pf: Fix promisc mcam entry action (bsc#1012628).
- octeontx2-af: Update RSS algorithm index (bsc#1012628).
- octeontx2-af: Fix pause frame configuration (bsc#1012628).
- atm: Fix Use-After-Free in do_vcc_ioctl (bsc#1012628).
- net/rose: Fix Use-After-Free in rose_ioctl (bsc#1012628).
- iavf: Introduce new state machines for flow director
  (bsc#1012628).
- iavf: Handle ntuple on/off based on new state machines for
  flow director (bsc#1012628).
- iavf: Fix iavf_shutdown to call iavf_remove instead iavf_close
  (bsc#1012628).
- qed: Fix a potential use-after-free in qed_cxt_tables_alloc
  (bsc#1012628).
- net: Remove acked SYN flag from packet in the transmit queue
  correctly (bsc#1012628).
- net: ena: Destroy correct number of xdp queues upon failure
  (bsc#1012628).
- net: ena: Fix xdp drops handling due to multibuf packets
  (bsc#1012628).
- net: ena: Fix DMA syncing in XDP path when SWIOTLB is on
  (bsc#1012628).
- net: ena: Fix XDP redirection error (bsc#1012628).
- stmmac: dwmac-loongson: Make sure MDIO is initialized before
  use (bsc#1012628).
- sign-file: Fix incorrect return values check (bsc#1012628).
- vsock/virtio: Fix unsigned integer wrap around in
  virtio_transport_has_space() (bsc#1012628).
- dpaa2-switch: fix size of the dma_unmap (bsc#1012628).
- dpaa2-switch: do not ask for MDB, VLAN and FDB replay
  (bsc#1012628).
- net: stmmac: dwmac-qcom-ethqos: Fix drops in 10M SGMII RX
  (bsc#1012628).
- net: stmmac: Handle disabled MDIO busses from devicetree
  (bsc#1012628).
- appletalk: Fix Use-After-Free in atalk_ioctl (bsc#1012628).
- net: atlantic: fix double free in ring reinit logic
  (bsc#1012628).
- cred: switch to using atomic_long_t (bsc#1012628).
- cred: get rid of CONFIG_DEBUG_CREDENTIALS (bsc#1012628).
- HID: i2c-hid: Add IDEA5002 to i2c_hid_acpi_blacklist[]
  (bsc#1012628).
- HID: Add quirk for Labtec/ODDOR/aikeec handbrake (bsc#1012628).
- fuse: Rename DIRECT_IO_RELAX to DIRECT_IO_ALLOW_MMAP
  (bsc#1012628).
- fuse: share lookup state between submount and its parent
  (bsc#1012628).
- fuse: disable FOPEN_PARALLEL_DIRECT_WRITES with
  FUSE_DIRECT_IO_ALLOW_MMAP (bsc#1012628).
- fuse: dax: set fc->dax to NULL in fuse_dax_conn_free()
  (bsc#1012628).
- io_uring/cmd: fix breakage in SOCKET_URING_OP_SIOC*
  implementation (bsc#1012628).
- ALSA: hda/hdmi: add force-connect quirk for NUC5CPYB
  (bsc#1012628).
- ALSA: hda/hdmi: add force-connect quirks for ASUSTeK Z170
  variants (bsc#1012628).
- ALSA: hda/realtek: Apply mute LED quirk for HP15-db
  (bsc#1012628).
- ALSA: hda/tas2781: leave hda_component in usable state
  (bsc#1012628).
- ALSA: hda/tas2781: handle missing EFI calibration data
  (bsc#1012628).
- ALSA: hda/tas2781: call cleanup functions only once
  (bsc#1012628).
- ALSA: hda/tas2781: reset the amp before component_add
  (bsc#1012628).
- Revert "PCI: acpiphp: Reassign resources on bridge if necessary"
  (bsc#1012628).
- PCI: loongson: Limit MRRS to 256 (bsc#1012628).
- PCI/ASPM: Add pci_enable_link_state_locked() (bsc#1012628).
- ksmbd: fix wrong name of SMB2_CREATE_ALLOCATION_SIZE
  (bsc#1012628).
- PCI: vmd: Fix potential deadlock when enabling ASPM
  (bsc#1012628).
- drm/mediatek: fix kernel oops if no crtc is found (bsc#1012628).
- drm/mediatek: Add spinlock for setting vblank event in
  atomic_begin (bsc#1012628).
- accel/ivpu: Print information about used workarounds
  (bsc#1012628).
- accel/ivpu/37xx: Fix interrupt_clear_with_0 WA initialization
  (bsc#1012628).
- drm/i915/selftests: Fix engine reset count storage for
  multi-tile (bsc#1012628).
- drm/i915: Use internal class when counting engine resets
  (bsc#1012628).
- selftests/mm: cow: print ksft header before printing anything
  else (bsc#1012628).
- x86/hyperv: Fix the detection of E820_TYPE_PRAM in a Gen2 VM
  (bsc#1012628).
- usb: aqc111: check packet for fixup for true limit
  (bsc#1012628).
- stmmac: dwmac-loongson: Add architecture dependency
  (bsc#1012628).
- rxrpc: Fix some minor issues with bundle tracing (bsc#1012628).
- blk-throttle: fix lockdep warning of "cgroup_mutex or RCU read
  lock required!" (bsc#1012628).
- blk-cgroup: bypass blkcg_deactivate_policy after destroying
  (bsc#1012628).
- bcache: avoid oversize memory allocation by small stripe_size
  (bsc#1012628).
- bcache: remove redundant assignment to variable cur_idx
  (bsc#1012628).
- bcache: add code comments for bch_btree_node_get() and
  __bch_btree_node_alloc() (bsc#1012628).
- bcache: avoid NULL checking to c->root in run_cache_set()
  (bsc#1012628).
- nbd: fold nbd config initialization into nbd_alloc_config()
  (bsc#1012628).
- nbd: factor out a helper to get nbd_config without holding
  'config_lock' (bsc#1012628).
- nbd: fix null-ptr-dereference while accessing 'nbd->config'
  (bsc#1012628).
- nvme-auth: set explanation code for failure2 msgs (bsc#1012628).
- nvme: catch errors from nvme_configure_metadata() (bsc#1012628).
- selftests/bpf: fix bpf_loop_bench for new callback verification
  scheme (bsc#1012628).
- LoongArch: Add dependency between vmlinuz.efi and vmlinux.efi
  (bsc#1012628).
- LoongArch: Record pc instead of offset in la_abs relocation
  (bsc#1012628).
- LoongArch: Silence the boot warning about 'nokaslr'
  (bsc#1012628).
- LoongArch: Mark {dmw,tlb}_virt_to_page() exports as non-GPL
  (bsc#1012628).
- LoongArch: Implement constant timer shutdown interface
  (bsc#1012628).
- platform/x86: intel_telemetry: Fix kernel doc descriptions
  (bsc#1012628).
- HID: mcp2221: Set driver data before I2C adapter add
  (bsc#1012628).
- HID: mcp2221: Allow IO to start during probe (bsc#1012628).
- HID: apple: add Jamesdonkey and A3R to non-apple keyboards list
  (bsc#1012628).
- HID: glorious: fix Glorious Model I HID report (bsc#1012628).
- HID: add ALWAYS_POLL quirk for Apple kb (bsc#1012628).
- nbd: pass nbd_sock to nbd_read_reply() instead of index
  (bsc#1012628).
- HID: hid-asus: reset the backlight brightness level on resume
  (bsc#1012628).
- HID: multitouch: Add quirk for HONOR GLO-GXXX touchpad
  (bsc#1012628).
- nfc: virtual_ncidev: Add variable to check if ndev is running
  (bsc#1012628).
- scripts/checkstack.pl: match all stack sizes for s390
  (bsc#1012628).
- asm-generic: qspinlock: fix queued_spin_value_unlocked()
  implementation (bsc#1012628).
- eventfs: Do not allow NULL parent to eventfs_start_creating()
  (bsc#1012628).
- net: usb: qmi_wwan: claim interface 4 for ZTE MF290
  (bsc#1012628).
- smb: client: implement ->query_reparse_point() for SMB1
  (bsc#1012628).
- smb: client: introduce ->parse_reparse_point() (bsc#1012628).
- smb: client: set correct file type from NFS reparse points
  (bsc#1012628).
- arm64: add dependency between vmlinuz.efi and Image
  (bsc#1012628).
- HID: hid-asus: add const to read-only outgoing usb buffer
  (bsc#1012628).
- perf: Fix perf_event_validate_size() lockdep splat
  (bsc#1012628).
- btrfs: do not allow non subvolume root targets for snapshot
  (bsc#1012628).
- cxl/hdm: Fix dpa translation locking (bsc#1012628).
- soundwire: stream: fix NULL pointer dereference for multi_link
  (bsc#1012628).
- ext4: prevent the normalized size from exceeding EXT_MAX_BLOCKS
  (bsc#1012628).
- Revert "selftests: error out if kernel header files are not
  yet built" (bsc#1012628).
- arm64: mm: Always make sw-dirty PTEs hw-dirty in pte_modify
  (bsc#1012628).
- team: Fix use-after-free when an option instance allocation
  fails (bsc#1012628).
- drm/amdgpu/sdma5.2: add begin/end_use ring callbacks
  (bsc#1012628).
- drm/mediatek: Fix access violation in mtk_drm_crtc_dma_dev_get
  (bsc#1012628).
- dmaengine: stm32-dma: avoid bitfield overflow assertion
  (bsc#1012628).
- dmaengine: fsl-edma: fix DMA channel leak in eDMAv4
  (bsc#1012628).
- mm/mglru: fix underprotected page cache (bsc#1012628).
- mm/mglru: try to stop at high watermarks (bsc#1012628).
- mm/mglru: respect min_ttl_ms with memcgs (bsc#1012628).
- mm/mglru: reclaim offlined memcgs harder (bsc#1012628).
- mm/shmem: fix race in shmem_undo_range w/THP (bsc#1012628).
- kexec: drop dependency on ARCH_SUPPORTS_KEXEC from CRASH_DUMP
  (bsc#1012628).
- btrfs: free qgroup reserve when ORDERED_IOERR is set
  (bsc#1012628).
- btrfs: fix qgroup_free_reserved_data int overflow (bsc#1012628).
- btrfs: don't clear qgroup reserved bit in release_folio
  (bsc#1012628).
- drm/amdgpu: fix tear down order in amdgpu_vm_pt_free
  (bsc#1012628).
- drm/edid: also call add modes in EDID connector update fallback
  (bsc#1012628).
- drm/amd/display: Restore guard against default backlight value <
  1 nit (bsc#1012628).
- drm/amd/display: Disable PSR-SU on Parade 0803 TCON again
  (bsc#1012628).
- drm/i915: Fix ADL+ tiled plane stride when the POT stride is
  smaller than the original (bsc#1012628).
- drm/i915: Fix intel_atomic_setup_scalers() plane_state handling
  (bsc#1012628).
- drm/i915: Fix remapped stride with CCS on ADL+ (bsc#1012628).
- smb: client: fix OOB in receive_encrypted_standard()
  (bsc#1012628).
- smb: client: fix potential OOBs in smb2_parse_contexts()
  (bsc#1012628).
- smb: client: fix NULL deref in asn1_ber_decoder() (bsc#1012628).
- smb: client: fix OOB in smb2_query_reparse_point()
  (bsc#1012628).
- ring-buffer: Fix memory leak of free page (bsc#1012628).
- tracing: Update snapshot buffer on resize if it is allocated
  (bsc#1012628).
- ring-buffer: Do not update before stamp when switching
  sub-buffers (bsc#1012628).
- ring-buffer: Have saved event hold the entire event
  (bsc#1012628).
- ring-buffer: Fix writing to the buffer with max_data_size
  (bsc#1012628).
- ring-buffer: Fix a race in rb_time_cmpxchg() for 32 bit archs
  (bsc#1012628).
- ring-buffer: Do not try to put back write_stamp (bsc#1012628).
- ring-buffer: Have rb_time_cmpxchg() set the msb counter too
  (bsc#1012628).
- x86/speculation, objtool: Use absolute relocations for
  annotations (bsc#1012628).
- RDMA/mlx5: Change the key being sent for MPV device affiliation
  (bsc#1012628).
- Rename to
  patches.kernel.org/6.6.8-004-efi-x86-Avoid-physical-KASLR-on-older-Dell-syst.patch.
- commit e7a87d7
* Mon Dec 18 2023 mkubecek@suse.cz
- Update to 6.7-rc6
- refresh configs
- commit 8a25837
* Sat Dec 16 2023 dmueller@suse.com
- config: update riscv64
- sync few options with arm
- config.conf: reenable armv6hl/armv7hl
- Update config files.
- commit 4466ed8
* Sat Dec 16 2023 dmueller@suse.com
- config.conf: Reenable arm64
- Update config files for arm64. Take settings from x86_64, enable
  everthing that can be enabled as modules.
- commit 979aa1b
* Thu Dec 14 2023 tiwai@suse.de
- efi/x86: Avoid physical KASLR on older Dell systems
  (bsc#1217344).
- commit ee1123d
* Thu Dec 14 2023 jslaby@suse.cz
- Linux 6.6.7 (bsc#1012628).
- vdpa/mlx5: preserve CVQ vringh index (bsc#1012628).
- scsi: sd: Fix sshdr use in sd_suspend_common() (bsc#1012628).
- hrtimers: Push pending hrtimers away from outgoing CPU earlier
  (bsc#1012628).
- i2c: designware: Fix corrupted memory seen in the ISR
  (bsc#1012628).
- i2c: ocores: Move system PM hooks to the NOIRQ phase
  (bsc#1012628).
- netfilter: ipset: fix race condition between swap/destroy and
  kernel side add/del/test (bsc#1012628).
- nouveau: use an rwlock for the event lock (bsc#1012628).
- zstd: Fix array-index-out-of-bounds UBSAN warning (bsc#1012628).
- tg3: Move the [rt]x_dropped counters to tg3_napi (bsc#1012628).
- tg3: Increment tx_dropped in tg3_tso_bug() (bsc#1012628).
- modpost: fix section mismatch message for RELA (bsc#1012628).
- kconfig: fix memory leak from range properties (bsc#1012628).
- drm/amdgpu: Do not program VF copy regs in mmhub v1.8 under
  SRIOV (v2) (bsc#1012628).
- drm/amdgpu: finalizing mem_partitions at the end of GMC v9
  sw_fini (bsc#1012628).
- drm/amdgpu: correct chunk_ptr to a pointer to chunk
  (bsc#1012628).
- dm-crypt: start allocating with MAX_ORDER (bsc#1012628).
- x86: Introduce ia32_enabled() (bsc#1012628).
- x86/coco: Disable 32-bit emulation by default on TDX and SEV
  (bsc#1012628).
- x86/entry: Convert INT 0x80 emulation to IDTENTRY (bsc#1012628).
- x86/entry: Do not allow external 0x80 interrupts (bsc#1012628).
- x86/tdx: Allow 32-bit emulation by default (bsc#1012628).
- dt: dt-extract-compatibles: Handle cfile arguments in generator
  function (bsc#1012628).
- dt: dt-extract-compatibles: Don't follow symlinks when walking
  tree (bsc#1012628).
- platform/x86: asus-wmi: Move i8042 filter install to shared
  asus-wmi code (bsc#1012628).
- of: dynamic: Fix of_reconfig_get_state_change() return value
  documentation (bsc#1012628).
- platform/x86: wmi: Skip blocks with zero instances
  (bsc#1012628).
- ipv6: fix potential NULL deref in fib6_add() (bsc#1012628).
- octeontx2-pf: Add missing mutex lock in otx2_get_pauseparam
  (bsc#1012628).
- octeontx2-af: Check return value of nix_get_nixlf before using
  nixlf (bsc#1012628).
- bpf: Fix a verifier bug due to incorrect branch offset
  comparison with cpu=v4 (bsc#1012628).
- hv_netvsc: rndis_filter needs to select NLS (bsc#1012628).
- r8152: Hold the rtnl_lock for all of reset (bsc#1012628).
- r8152: Add RTL8152_INACCESSIBLE checks to more loops
  (bsc#1012628).
- r8152: Add RTL8152_INACCESSIBLE to r8156b_wait_loading_flash()
  (bsc#1012628).
- r8152: Add RTL8152_INACCESSIBLE to r8153_pre_firmware_1()
  (bsc#1012628).
- r8152: Add RTL8152_INACCESSIBLE to r8153_aldps_en()
  (bsc#1012628).
- mlxbf-bootctl: correctly identify secure boot with development
  keys (bsc#1012628).
- platform/mellanox: Add null pointer checks for devm_kasprintf()
  (bsc#1012628).
- platform/mellanox: Check
  devm_hwmon_device_register_with_groups() return value
  (bsc#1012628).
- arcnet: restoring support for multiple Sohard Arcnet cards
  (bsc#1012628).
- octeontx2-pf: consider both Rx and Tx packet stats for adaptive
  interrupt coalescing (bsc#1012628).
- net: stmmac: fix FPE events losing (bsc#1012628).
- xsk: Skip polling event check for unbound socket (bsc#1012628).
- octeontx2-af: fix a use-after-free in rvu_npa_register_reporters
  (bsc#1012628).
- ice: Restore fix disabling RX VLAN filtering (bsc#1012628).
- i40e: Fix unexpected MFS warning message (bsc#1012628).
- iavf: validate tx_coalesce_usecs even if rx_coalesce_usecs is
  zero (bsc#1012628).
- net: bnxt: fix a potential use-after-free in bnxt_init_tc
  (bsc#1012628).
- tcp: fix mid stream window clamp (bsc#1012628).
- ionic: fix snprintf format length warning (bsc#1012628).
- ionic: Fix dim work handling in split interrupt mode
  (bsc#1012628).
- ipv4: ip_gre: Avoid skb_pull() failure in ipgre_xmit()
  (bsc#1012628).
- net: atlantic: Fix NULL dereference of skb pointer in
  (bsc#1012628).
- net: hns: fix wrong head when modify the tx feature when
  sending packets (bsc#1012628).
- net: hns: fix fake link up on xge port (bsc#1012628).
- octeontx2-af: Adjust Tx credits when MCS external bypass is
  disabled (bsc#1012628).
- octeontx2-af: Fix mcs sa cam entries size (bsc#1012628).
- octeontx2-af: Fix mcs stats register address (bsc#1012628).
- octeontx2-af: Add missing mcs flr handler call (bsc#1012628).
- octeontx2-af: Update Tx link register range (bsc#1012628).
- dt-bindings: interrupt-controller: Allow #power-domain-cells
  (bsc#1012628).
- netfilter: bpf: fix bad registration on nf_defrag (bsc#1012628).
- netfilter: nf_tables: fix 'exist' matching on bigendian arches
  (bsc#1012628).
- netfilter: nf_tables: bail out on mismatching dynset and set
  expressions (bsc#1012628).
- netfilter: nf_tables: validate family when identifying table
  via handle (bsc#1012628).
- netfilter: xt_owner: Fix for unsafe access of sk->sk_socket
  (bsc#1012628).
- tcp: do not accept ACK of bytes we never sent (bsc#1012628).
- net: dsa: mv88e6xxx: Restore USXGMII support for 6393X
  (bsc#1012628).
- net: tls, update curr on splice as well (bsc#1012628).
- bpf: sockmap, updating the sg structure should also update curr
  (bsc#1012628).
- psample: Require 'CAP_NET_ADMIN' when joining "packets" group
  (bsc#1012628).
- drop_monitor: Require 'CAP_SYS_ADMIN' when joining "events"
  group (bsc#1012628).
- net: dsa: microchip: provide a list of valid protocols for
  xmit handler (bsc#1012628).
- net/smc: fix missing byte order conversion in CLC handshake
  (bsc#1012628).
- drm/amd/amdgpu/amdgpu_doorbell_mgr: Correct misdocumented param
  'doorbell_index' (bsc#1012628).
- drm/amdkfd: get doorbell's absolute offset based on the db_size
  (bsc#1012628).
- mm/damon/sysfs: eliminate potential uninitialized variable
  warning (bsc#1012628).
- tee: optee: Fix supplicant based device enumeration
  (bsc#1012628).
- RDMA/core: Fix uninit-value access in ib_get_eth_speed()
  (bsc#1012628).
- RDMA/hns: Fix unnecessary err return when using invalid congest
  control algorithm (bsc#1012628).
- RDMA/irdma: Do not modify to SQD on error (bsc#1012628).
- RDMA/irdma: Add wait for suspend on SQD (bsc#1012628).
- arm64: dts: rockchip: Expand reg size of vdec node for RK3328
  (bsc#1012628).
- arm64: dts: rockchip: Expand reg size of vdec node for RK3399
  (bsc#1012628).
- ASoC: fsl_sai: Fix no frame sync clock issue on i.MX8MP
  (bsc#1012628).
- RDMA/rtrs-srv: Do not unconditionally enable irq (bsc#1012628).
- RDMA/rtrs-clt: Start hb after path_up (bsc#1012628).
- RDMA/rtrs-srv: Check return values while processing info request
  (bsc#1012628).
- RDMA/rtrs-srv: Free srv_mr iu only when always_invalidate is
  true (bsc#1012628).
- RDMA/rtrs-srv: Destroy path files after making sure no IOs
  in-flight (bsc#1012628).
- RDMA/rtrs-clt: Fix the max_send_wr setting (bsc#1012628).
- RDMA/rtrs-clt: Remove the warnings for req in_use check
  (bsc#1012628).
- RDMA/bnxt_re: Correct module description string (bsc#1012628).
- RDMA/irdma: Fix UAF in irdma_sc_ccq_get_cqe_info()
  (bsc#1012628).
- arm64: dt: imx93: tqma9352-mba93xxla: Fix LPUART2 pad config
  (bsc#1012628).
- ARM: dts: imx6q: skov: fix ethernet clock regression
  (bsc#1012628).
- ARM: dts: rockchip: Fix sdmmc_pwren's pinmux setting for RK3128
  (bsc#1012628).
- ARM: dts: bcm2711-rpi-400: Fix delete-node of led_act
  (bsc#1012628).
- hwmon: (acpi_power_meter) Fix 4.29 MW bug (bsc#1012628).
- ASoC: codecs: lpass-tx-macro: set active_decimator correct
  default value (bsc#1012628).
- hwmon: (nzxt-kraken2) Fix error handling path in kraken2_probe()
  (bsc#1012628).
- firmware: arm_scmi: Extend perf protocol ops to get number of
  domains (bsc#1012628).
- firmware: arm_scmi: Extend perf protocol ops to get information
  of a domain (bsc#1012628).
- firmware: arm_scmi: Fix frequency truncation by promoting
  multiplier type (bsc#1012628).
- firmware: arm_scmi: Simplify error path in
  scmi_dvfs_device_opps_add() (bsc#1012628).
- firmware: arm_scmi: Fix possible frequency truncation when
  using level indexing mode (bsc#1012628).
- ASoC: wm_adsp: fix memleak in wm_adsp_buffer_populate
  (bsc#1012628).
- RDMA/core: Fix umem iterator when PAGE_SIZE is greater then
  HCA pgsz (bsc#1012628).
- RDMA/irdma: Ensure iWarp QP queue memory is OS paged aligned
  (bsc#1012628).
- RDMA/irdma: Fix support for 64k pages (bsc#1012628).
- RDMA/irdma: Avoid free the non-cqp_request scratch
  (bsc#1012628).
- drm/bridge: tc358768: select CONFIG_VIDEOMODE_HELPERS
  (bsc#1012628).
- arm64: dts: imx8mp: imx8mq: Add parkmode-disable-ss-quirk on
  DWC3 (bsc#1012628).
- ARM: dts: imx6ul-pico: Describe the Ethernet PHY clock
  (bsc#1012628).
- io_uring/kbuf: Fix an NULL vs IS_ERR() bug in
  io_alloc_pbuf_ring() (bsc#1012628).
- io_uring/kbuf: check for buffer list readiness after NULL check
  (bsc#1012628).
- tracing: Fix a warning when allocating buffered events fails
  (bsc#1012628).
- scsi: be2iscsi: Fix a memleak in beiscsi_init_wrb_handle()
  (bsc#1012628).
- arm64: dts: imx8-ss-lsio: Add PWM interrupts (bsc#1012628).
- arm64: dts: freescale: imx8-ss-lsio: Fix #pwm-cells
  (bsc#1012628).
- arm64: dts: imx93: correct mediamix power (bsc#1012628).
- ARM: imx: Check return value of devm_kasprintf in
  imx_mmdc_perf_init (bsc#1012628).
- arm64: dts: imx8-apalis: set wifi regulator to always-on
  (bsc#1012628).
- ARM: dts: imx7: Declare timers compatible with fsl,imx6dl-gpt
  (bsc#1012628).
- ARM: dts: imx28-xea: Pass the 'model' property (bsc#1012628).
- arm64: dts: rockchip: Fix eMMC Data Strobe PD on rk3588
  (bsc#1012628).
- riscv: fix misaligned access handling of C.SWSP and C.SDSP
  (bsc#1012628).
- riscv: errata: andes: Probe for IOCP only once in boot stage
  (bsc#1012628).
- md: don't leave 'MD_RECOVERY_FROZEN' in error path of
  md_set_readonly() (bsc#1012628).
- kernel/Kconfig.kexec: drop select of KEXEC for CRASH_DUMP
  (bsc#1012628).
- scripts/gdb: fix lx-device-list-bus and lx-device-list-class
  (bsc#1012628).
- rethook: Use __rcu pointer for rethook::handler (bsc#1012628).
- ASoC: amd: yc: Fix non-functional mic on ASUS E1504FA
  (bsc#1012628).
- io_uring/af_unix: disable sending io_uring over sockets
  (bsc#1012628).
- nvme-pci: Add sleep quirk for Kingston drives (bsc#1012628).
- io_uring: fix mutex_unlock with unreferenced ctx (bsc#1012628).
- ALSA: usb-audio: Add Pioneer DJM-450 mixer controls
  (bsc#1012628).
- ALSA: pcm: fix out-of-bounds in snd_pcm_state_names
  (bsc#1012628).
- ALSA: hda/realtek: Apply quirk for ASUS UM3504DA (bsc#1012628).
- ALSA: hda/realtek: fix speakers on XPS 9530 (2023)
  (bsc#1012628).
- ALSA: hda/realtek: Enable headset on Lenovo M90 Gen5
  (bsc#1012628).
- ALSA: hda/realtek: add new Framework laptop to quirks
  (bsc#1012628).
- ALSA: hda/realtek: Add Framework laptop 16 to quirks
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Lenovo Yoga Pro 7
  (bsc#1012628).
- ring-buffer: Test last update in 32bit version of
  __rb_time_read() (bsc#1012628).
- ring-buffer: Force absolute timestamp on discard of event
  (bsc#1012628).
- highmem: fix a memory copy problem in memcpy_from_folio
  (bsc#1012628).
- nilfs2: fix missing error check for sb_set_blocksize call
  (bsc#1012628).
- nilfs2: prevent WARNING in nilfs_sufile_set_segment_usage()
  (bsc#1012628).
- lib/group_cpus.c: avoid acquiring cpu hotplug lock in
  group_cpus_evenly (bsc#1012628).
- cgroup_freezer: cgroup_freezing: Check if not frozen
  (bsc#1012628).
- checkstack: fix printed address (bsc#1012628).
- tracing: Always update snapshot buffer size (bsc#1012628).
- tracing: Stop current tracer when resizing buffer (bsc#1012628).
- tracing: Disable snapshot buffer when stopping instance tracers
  (bsc#1012628).
- tracing: Fix incomplete locking when disabling buffered events
  (bsc#1012628).
- tracing: Fix a possible race when disabling buffered events
  (bsc#1012628).
- leds: trigger: netdev: fix RTNL handling to prevent potential
  deadlock (bsc#1012628).
- nfp: flower: fix for take a mutex lock in soft irq context
  and rcu lock (bsc#1012628).
- packet: Move reference count in packet_sock to atomic_long_t
  (bsc#1012628).
- r8169: fix rtl8125b PAUSE frames blasting when suspended
  (bsc#1012628).
- regmap: fix bogus error on regcache_sync success (bsc#1012628).
- platform/surface: aggregator: fix recv_buf() return value
  (bsc#1012628).
- workqueue: Make sure that wq_unbound_cpumask is never empty
  (bsc#1012628).
- hugetlb: fix null-ptr-deref in hugetlb_vma_lock_write
  (bsc#1012628).
- drivers/base/cpu: crash data showing should depends on
  KEXEC_CORE (bsc#1012628).
- mm/memory_hotplug: add missing mem_hotplug_lock (bsc#1012628).
- mm: fix oops when filemap_map_pmd() without prealloc_pte
  (bsc#1012628).
- mm/memory_hotplug: fix error handling in add_memory_resource()
  (bsc#1012628).
- powercap: DTPM: Fix missing cpufreq_cpu_put() calls
  (bsc#1012628).
- md/raid6: use valid sector values to determine if an I/O should
  wait on the reshape (bsc#1012628).
- drm/atomic-helpers: Invoke end_fb_access while owning plane
  state (bsc#1012628).
- drm/i915/mst: Fix .mode_valid_ctx() return values (bsc#1012628).
- drm/i915/mst: Reject modes that require the bigjoiner
  (bsc#1012628).
- drm/i915: Skip some timing checks on BXT/GLK DSI transcoders
  (bsc#1012628).
- arm64: dts: mt7986: change cooling trips (bsc#1012628).
- arm64: dts: mt7986: define 3W max power to both SFP on BPI-R3
  (bsc#1012628).
- arm64: dts: mt7986: fix emmc hs400 mode without uboot
  initialization (bsc#1012628).
- arm64: dts: mediatek: mt7622: fix memory node warning check
  (bsc#1012628).
- arm64: dts: mediatek: mt8183-kukui-jacuzzi: fix dsi unnecessary
  cells properties (bsc#1012628).
- arm64: dts: mediatek: cherry: Fix interrupt cells for MT6360
  on I2C7 (bsc#1012628).
- arm64: dts: mediatek: mt8173-evb: Fix regulator-fixed node names
  (bsc#1012628).
- arm64: dts: mediatek: mt8195: Fix PM suspend/resume with venc
  clocks (bsc#1012628).
- arm64: dts: mediatek: mt8183: Fix unit address for scp reserved
  memory (bsc#1012628).
- arm64: dts: mediatek: mt8183: Move thermal-zones to the root
  node (bsc#1012628).
- arm64: dts: mediatek: mt8183-evb: Fix unit_address_vs_reg
  warning on ntc (bsc#1012628).
- arm64: dts: mediatek: mt8186: fix clock names for power domains
  (bsc#1012628).
- arm64: dts: mediatek: mt8186: Change gpu speedbin nvmem cell
  name (bsc#1012628).
- coresight: etm4x: Remove bogous __exit annotation for some
  functions (bsc#1012628).
- coresight: Fix crash when Perf and sysfs modes are used
  concurrently (bsc#1012628).
- hwtracing: hisi_ptt: Add dummy callback pmu::read()
  (bsc#1012628).
- coresight: ultrasoc-smb: Fix sleep while close preempt in
  enable_smb (bsc#1012628).
- coresight: ultrasoc-smb: Config SMB buffer before register sink
  (bsc#1012628).
- coresight: ultrasoc-smb: Fix uninitialized before use
  buf_hw_base (bsc#1012628).
- misc: mei: client.c: return negative error code in mei_cl_write
  (bsc#1012628).
- misc: mei: client.c: fix problem of return '-EOVERFLOW' in
  mei_cl_write (bsc#1012628).
- perf vendor events arm64: AmpereOne: Add missing
  DefaultMetricgroupName fields (bsc#1012628).
- LoongArch: BPF: Don't sign extend memory load operand
  (bsc#1012628).
- LoongArch: BPF: Don't sign extend function return value
  (bsc#1012628).
- parisc: Reduce size of the bug_table on 64-bit kernel by half
  (bsc#1012628).
- arm64: dts: mediatek: add missing space before { (bsc#1012628).
- arm64: dts: mt8183: kukui: Fix underscores in node names
  (bsc#1012628).
- drm/amdgpu: disable MCBP by default (bsc#1012628).
- perf: Fix perf_event_validate_size() (bsc#1012628).
- x86/sev: Fix kernel crash due to late update to read-only
  ghcb_version (bsc#1012628).
- gpiolib: sysfs: Fix error handling on failed export
  (bsc#1012628).
- ASoC: ops: add correct range check for limiting volume
  (bsc#1012628).
- kprobes: consistent rcu api usage for kretprobe holder
  (bsc#1012628).
- usb: gadget: f_hid: fix report descriptor allocation
  (bsc#1012628).
- nvmem: Do not expect fixed layouts to grab a layout driver
  (bsc#1012628).
- serial: 8250_dw: Add ACPI ID for Granite Rapids-D UART
  (bsc#1012628).
- serial: ma35d1: Validate console index before assignment
  (bsc#1012628).
- parport: Add support for Brainboxes IX/UC/PX parallel cards
  (bsc#1012628).
- cifs: Fix non-availability of dedup breaking generic/304
  (bsc#1012628).
- Revert "xhci: Loosen RPM as default policy to cover for AMD
  xHC 1.1" (bsc#1012628).
- smb: client: fix potential NULL deref in parse_dfs_referrals()
  (bsc#1012628).
- usb: typec: class: fix typec_altmode_put_partner to put plugs
  (bsc#1012628).
- ARM: PL011: Fix DMA support (bsc#1012628).
- serial: sc16is7xx: address RX timeout interrupt errata
  (bsc#1012628).
- serial: 8250: 8250_omap: Clear UART_HAS_RHR_IT_DIS bit
  (bsc#1012628).
- serial: 8250: 8250_omap: Do not start RX DMA on THRI interrupt
  (bsc#1012628).
- serial: 8250_omap: Add earlycon support for the AM654 UART
  controller (bsc#1012628).
- devcoredump: Send uevent once devcd is ready (bsc#1012628).
- x86/CPU/AMD: Check vendor in the AMD microcode callback
  (bsc#1012628).
- powerpc/ftrace: Fix stack teardown in ftrace_no_trace
  (bsc#1012628).
- USB: gadget: core: adjust uevent timing on gadget unbind
  (bsc#1012628).
- cifs: Fix flushing, invalidation and file size with
  copy_file_range() (bsc#1012628).
- cifs: Fix flushing, invalidation and file size with FICLONE
  (bsc#1012628).
- MIPS: kernel: Clear FPU states when setting up kernel threads
  (bsc#1012628).
- KVM: s390/mm: Properly reset no-dat (bsc#1012628).
- KVM: SVM: Update EFER software model on CR0 trap for SEV-ES
  (bsc#1012628).
- perf list: Fix JSON segfault by setting the used
  skip_duplicate_pmus callback (bsc#1012628).
- perf metrics: Avoid segv if default metricgroup isn't set
  (bsc#1012628).
- MIPS: Loongson64: Reserve vgabios memory on boot (bsc#1012628).
- MIPS: Loongson64: Handle more memory types passed from firmware
  (bsc#1012628).
- MIPS: Loongson64: Enable DMA noncoherent support (bsc#1012628).
- netfilter: nft_set_pipapo: skip inactive elements during set
  walk (bsc#1012628).
- ASoC: qcom: sc8280xp: Limit speaker digital volumes
  (bsc#1012628).
- gcc-plugins: randstruct: Update code comment in
  relayout_struct() (bsc#1012628).
- riscv: Kconfig: Add select ARM_AMBA to SOC_STARFIVE
  (bsc#1012628).
- drm/amdgpu: Fix refclk reporting for SMU v13.0.6 (bsc#1012628).
- drm/amdgpu: update retry times for psp BL wait (bsc#1012628).
- drm/amdgpu: Restrict extended wait to PSP v13.0.6 (bsc#1012628).
- Update config files.
- Rename to
  patches.kernel.org/6.6.7-201-parisc-Fix-asm-operand-number-out-of-range-buil.patch.
- commit 59f1683
* Mon Dec 11 2023 jslaby@suse.cz
- Linux 6.6.6 (bsc#1012628).
- Revert "wifi: cfg80211: fix CQM for non-range use"
  (bsc#1012628).
- commit a946a9f
* Mon Dec 11 2023 mkubecek@suse.cz
- Update to 6.7-rc5
- refresh configs
- commit 91bd996
* Fri Dec  8 2023 petr.pavlu@suse.com
- kernel-source: Remove config-options.changes (jsc#PED-5021)
  The file doc/config-options.changes was used in the past to document
  kernel config changes. It was introduced in 2010 but haven't received
  any updates on any branch since 2015. The file is renamed by tar-up.sh
  to config-options.changes.txt and shipped in the kernel-source RPM
  package under /usr/share/doc. As its content now only contains outdated
  information, retaining it can lead to confusion for users encountering
  this file.
  Config changes are nowadays described in associated Git commit messages,
  which get automatically collected and are incorporated into changelogs
  of kernel RPM packages.
  Drop then this obsolete file, starting with its packaging logic.
  For branch maintainers: Upon merging this commit on your branch, please
  correspondingly delete the file doc/config-options.changes.
- commit adedbd2
* Fri Dec  8 2023 petr.pavlu@suse.com
- doc/README.SUSE: Simplify the list of references (jsc#PED-5021)
  Reduce indentation in the list of references, make the style consistent
  with README.md.
- commit 70e3c33
* Fri Dec  8 2023 jslaby@suse.cz
- parisc: Fix asm operand number out of range build error in
  bug table (git-fixes).
- commit 7675861
* Fri Dec  8 2023 jslaby@suse.cz
- Linux 6.6.5 (bsc#1012628).
- cifs: Fix FALLOC_FL_ZERO_RANGE by setting i_size if EOF moved
  (bsc#1012628).
- cifs: Fix FALLOC_FL_INSERT_RANGE by setting i_size after EOF
  moved (bsc#1012628).
- smb: client: fix missing mode bits for SMB symlinks
  (bsc#1012628).
- smb: client: report correct st_size for SMB and NFS symlinks
  (bsc#1012628).
- ksmbd: fix possible deadlock in smb2_open (bsc#1012628).
- pinctrl: avoid reload of p state in list iteration
  (bsc#1012628).
- firewire: core: fix possible memory leak in create_units()
  (bsc#1012628).
- mmc: sdhci-pci-gli: Disable LPM during initialization
  (bsc#1012628).
- mmc: sdhci-sprd: Fix vqmmc not shutting down after the card
  was pulled (bsc#1012628).
- mmc: cqhci: Increase recovery halt timeout (bsc#1012628).
- mmc: cqhci: Warn of halt or task clear failure (bsc#1012628).
- mmc: cqhci: Fix task clearing in CQE error recovery
  (bsc#1012628).
- mmc: block: Retry commands in CQE error recovery (bsc#1012628).
- mmc: block: Do not lose cache flush during CQE error recovery
  (bsc#1012628).
- mmc: block: Be sure to wait while busy in CQE error recovery
  (bsc#1012628).
- ALSA: hda: Disable power-save on KONTRON SinglePC (bsc#1012628).
- ALSA: hda/realtek: Headset Mic VREF to 100%% (bsc#1012628).
- ALSA: hda/realtek: Add supported ALC257 for ChromeOS
  (bsc#1012628).
- net: libwx: fix memory leak on msix entry (bsc#1012628).
- dm-verity: align struct dm_verity_fec_io properly (bsc#1012628).
- scsi: Change SCSI device boolean fields to single bit flags
  (bsc#1012628).
- scsi: sd: Fix system start for ATA devices (bsc#1012628).
- scsi: ufs: core: Clear cmd if abort succeeds in MCQ mode
  (bsc#1012628).
- drm/amd: Enable PCIe PME from D3 (bsc#1012628).
- drm/amdgpu: correct the amdgpu runtime dereference usage count
  (bsc#1012628).
- drm/amdgpu: Force order between a read and write to the same
  address (bsc#1012628).
- drm/amdgpu: fix memory overflow in the IB test (bsc#1012628).
- drm/amdgpu: Update EEPROM I2C address for smu v13_0_0
  (bsc#1012628).
- drm/amd/display: Include udelay when waiting for INBOX0 ACK
  (bsc#1012628).
- drm/amd/display: Remove min_dst_y_next_start check for Z8
  (bsc#1012628).
- drm/amd/display: Use DRAM speed from validation for dummy
  p-state (bsc#1012628).
- drm/amd/display: Update min Z8 residency time to 2100 for DCN314
  (bsc#1012628).
- drm/amd/display: fix ABM disablement (bsc#1012628).
- drm/amd/display: force toggle rate wa for first link training
  for a retimer (bsc#1012628).
- dm verity: initialize fec io before freeing it (bsc#1012628).
- dm verity: don't perform FEC for failed readahead IO
  (bsc#1012628).
- nvme: check for valid nvme_identify_ns() before using it
  (bsc#1012628).
- r8169: fix deadlock on RTL8125 in jumbo mtu mode (bsc#1012628).
- ACPI: video: Use acpi_video_device for cooling-dev driver data
  (bsc#1012628).
- io_uring: don't allow discontig pages for IORING_SETUP_NO_MMAP
  (bsc#1012628).
- iommu/vt-d: Fix incorrect cache invalidation for mm notification
  (bsc#1012628).
- io_uring: free io_buffer_list entries via RCU (bsc#1012628).
- nouveau: find the smallest page allocation to cover a buffer
  alloc (bsc#1012628).
- powercap: DTPM: Fix unneeded conversions to micro-Watts
  (bsc#1012628).
- cpufreq/amd-pstate: Fix the return value of
  amd_pstate_fast_switch() (bsc#1012628).
- dma-buf: fix check in dma_resv_add_fence (bsc#1012628).
- io_uring: don't guard IORING_OFF_PBUF_RING with SETUP_NO_MMAP
  (bsc#1012628).
- iommu: Avoid more races around device probe (bsc#1012628).
- bcache: revert replacing IS_ERR_OR_NULL with IS_ERR
  (bsc#1012628).
- ext2: Fix ki_pos update for DIO buffered-io fallback case
  (bsc#1012628).
- iommu/vt-d: Add MTL to quirk list to skip TE disabling
  (bsc#1012628).
- KVM: PPC: Book3S HV: Fix KVM_RUN clobbering FP/VEC user
  registers (bsc#1012628).
- powerpc: Don't clobber f0/vs0 during fp|altivec register save
  (bsc#1012628).
- parisc: Mark ex_table entries 32-bit aligned in assembly.h
  (bsc#1012628).
- parisc: Mark ex_table entries 32-bit aligned in uaccess.h
  (bsc#1012628).
- parisc: Use natural CPU alignment for bug_table (bsc#1012628).
- parisc: Mark lock_aligned variables 16-byte aligned on SMP
  (bsc#1012628).
- parisc: Drop the HP-UX ENOSYM and EREMOTERELEASE error codes
  (bsc#1012628).
- parisc: Mark jump_table naturally aligned (bsc#1012628).
- parisc: Ensure 32-bit alignment on parisc unwind section
  (bsc#1012628).
- parisc: Mark altinstructions read-only and 32-bit aligned
  (bsc#1012628).
- btrfs: add dmesg output for first mount and last unmount of
  a filesystem (bsc#1012628).
- btrfs: ref-verify: fix memory leaks in btrfs_ref_tree_mod()
  (bsc#1012628).
- btrfs: fix off-by-one when checking chunk map includes logical
  address (bsc#1012628).
- btrfs: send: ensure send_fd is writable (bsc#1012628).
- btrfs: make error messages more clear when getting a chunk map
  (bsc#1012628).
- btrfs: free the allocated memory if btrfs_alloc_page_array()
  fails (bsc#1012628).
- btrfs: fix 64bit compat send ioctl arguments not initializing
  version member (bsc#1012628).
- io_uring: enable io_mem_alloc/free to be used in other parts
  (bsc#1012628).
- io_uring/kbuf: defer release of mapped buffer rings
  (bsc#1012628).
- io_uring/kbuf: recycle freed mapped buffer ring entries
  (bsc#1012628).
- wifi: cfg80211: fix CQM for non-range use (bsc#1012628).
- pinctrl: stm32: Add check for devm_kcalloc (bsc#1012628).
- pinctrl: stm32: fix array read out of bound (bsc#1012628).
- media: v4l2-subdev: Fix a 64bit bug (bsc#1012628).
- netdevsim: Don't accept device bound programs (bsc#1012628).
- net: rswitch: Fix type of ret in rswitch_start_xmit()
  (bsc#1012628).
- net: rswitch: Fix return value in rswitch_start_xmit()
  (bsc#1012628).
- net: rswitch: Fix missing dev_kfree_skb_any() in error path
  (bsc#1012628).
- ipv4: igmp: fix refcnt uaf issue when receiving igmp query
  packet (bsc#1012628).
- wifi: iwlwifi: mvm: fix an error code in iwl_mvm_mld_add_sta()
  (bsc#1012628).
- wifi: mac80211: do not pass AP_VLAN vif pointer to drivers
  during flush (bsc#1012628).
- net: dsa: mv88e6xxx: fix marvell 6350 switch probing
  (bsc#1012628).
- net: dsa: mv88e6xxx: fix marvell 6350 probe crash (bsc#1012628).
- dpaa2-eth: increase the needed headroom to account for alignment
  (bsc#1012628).
- dpaa2-eth: recycle the RX buffer only after all processing done
  (bsc#1012628).
- bpf: Add missed allocation hint for bpf_mem_cache_alloc_flags()
  (bsc#1012628).
- uapi: propagate __struct_group() attributes to the container
  union (bsc#1012628).
- selftests/net: ipsec: fix constant out of range (bsc#1012628).
- selftests/net: fix a char signedness issue (bsc#1012628).
- selftests/net: unix: fix unused variable compiler warning
  (bsc#1012628).
- selftests/net: mptcp: fix uninitialized variable warnings
  (bsc#1012628).
- octeontx2-af: Fix possible buffer overflow (bsc#1012628).
- net: stmmac: xgmac: Disable FPE MMC interrupts (bsc#1012628).
- octeontx2-pf: Fix adding mbox work queue entry when num_vfs >
  64 (bsc#1012628).
- octeontx2-pf: Restore TC ingress police rules when interface
  is up (bsc#1012628).
- neighbour: Fix __randomize_layout crash in struct neighbour
  (bsc#1012628).
- efi/unaccepted: Fix off-by-one when checking for overlapping
  ranges (bsc#1012628).
- r8169: prevent potential deadlock in rtl8169_close
  (bsc#1012628).
- ravb: Fix races between ravb_tx_timeout_work() and net related
  ops (bsc#1012628).
- ethtool: don't propagate EOPNOTSUPP from dumps (bsc#1012628).
- bpf, sockmap: af_unix stream sockets need to hold ref for pair
  sock (bsc#1012628).
- ice: Fix VF Reset paths when interface in a failed over
  aggregate (bsc#1012628).
- net: ravb: Check return value of reset_control_deassert()
  (bsc#1012628).
- net: ravb: Use pm_runtime_resume_and_get() (bsc#1012628).
- net: ravb: Make write access to CXR35 first before accessing
  other EMAC registers (bsc#1012628).
- net: ravb: Start TX queues after HW initialization succeeded
  (bsc#1012628).
- net: ravb: Stop DMA in case of failures on ravb_open()
  (bsc#1012628).
- net: ravb: Keep reverse order of operations in ravb_remove()
  (bsc#1012628).
- powerpc/pseries/iommu: enable_ddw incorrectly returns direct
  mapping for SR-IOV device (bsc#1012628).
- s390/cmma: fix handling of swapper_pg_dir and invalid_pg_dir
  (bsc#1012628).
- drm/amd/display: Refactor edp power control (bsc#1012628).
- drm/amd/display: Remove power sequencing check (bsc#1012628).
- cpufreq: imx6q: Don't disable 792 Mhz OPP unnecessarily
  (bsc#1012628).
- iommu/vt-d: Omit devTLB invalidation requests when TES=0
  (bsc#1012628).
- iommu/vt-d: Disable PCI ATS in legacy passthrough mode
  (bsc#1012628).
- iommu/vt-d: Make context clearing consistent with context
  mapping (bsc#1012628).
- drm/i915/gsc: Mark internal GSC engine with reserved uabi class
  (bsc#1012628).
- drm/panel: starry-2081101qfh032011-53g: Fine tune the panel
  power sequence (bsc#1012628).
- drm/panel: nt36523: fix return value check in nt36523_probe()
  (bsc#1012628).
- cpufreq/amd-pstate: Fix scaling_min_freq and scaling_max_freq
  update (bsc#1012628).
- cpufreq/amd-pstate: Only print supported EPP values for
  performance governor (bsc#1012628).
- drm/amd/pm: fix a memleak in aldebaran_tables_init
  (bsc#1012628).
- iommu: Fix printk arg in of_iommu_get_resv_regions()
  (bsc#1012628).
- drm/amd/display: refactor ILR to make it work (bsc#1012628).
- drm/amd/display: Reduce default backlight min from 5 nits to
  1 nits (bsc#1012628).
- drm/amd/display: Simplify brightness initialization
  (bsc#1012628).
- drm/amd/display: Fix MPCC 1DLUT programming (bsc#1012628).
- vfio/pds: Fix mutex lock->magic != lock warning (bsc#1012628).
- vfio/pds: Fix possible sleep while in atomic context
  (bsc#1012628).
- x86/xen: fix percpu vcpu_info allocation (bsc#1012628).
- vfio: Drop vfio_file_iommu_group() stub to fudge around a KVM
  wart (bsc#1012628).
- Rename to
  patches.kernel.org/6.6.5-001-leds-class-Don-t-expose-color-sysfs-entry.patch.
- Rename to
  patches.kernel.org/6.6.5-017-drm-i915-Also-check-for-VGA-converter-in-eDP-pr.patch.
- commit 30a850b
* Thu Dec  7 2023 petr.pavlu@suse.com
- doc/README.SUSE: Add how to update the config for module signing
  (jsc#PED-5021)
  Configuration files for SUSE kernels include settings to integrate with
  signing support provided by the Open Build Service. This creates
  problems if someone tries to use such a configuration file to build
  a "standalone" kernel as described in doc/README.SUSE:
  * Default configuration files available in the kernel-source repository
  unset CONFIG_MODULE_SIG_ALL to leave module signing to
  pesign-obs-integration. In case of a "standalone" build, this
  integration is not available and the modules don't get signed.
  * The kernel spec file overrides CONFIG_MODULE_SIG_KEY to
  ".kernel_signing_key.pem" which is a file populated by certificates
  provided by OBS but otherwise not available. The value ends up in
  /boot/config-$VERSION-$RELEASE-$FLAVOR and /proc/config.gz. If someone
  decides to use one of these files as their base configuration then the
  build fails with an error because the specified module signing key is
  missing.
  Add information on how to enable module signing and where to find the
  relevant upstream documentation.
- commit a699dc3
* Wed Dec  6 2023 petr.pavlu@suse.com
- doc/README.SUSE: Remove how to build modules using kernel-source
  (jsc#PED-5021)
  Remove the first method how to build kernel modules from the readme. It
  describes a process consisting of the kernel-source installation,
  configuring this kernel and then performing an ad-hoc module build.
  This method is not ideal as no modversion data is involved in the
  process. It results in a module with no symbol CRCs which can be wrongly
  loaded on an incompatible kernel.
  Removing the method also simplifies the readme because only two main
  methods how to build the modules are then described, either doing an
  ad-hoc build using kernel-devel, or creating a proper Kernel Module
  Package.
- commit 9285bb8
* Tue Dec  5 2023 jslaby@suse.cz
- Refresh
  patches.suse/drm-i915-Also-check-for-VGA-converter-in-eDP-probe.patch.
- Refresh
  patches.suse/leds-class-Don-t-expose-color-sysfs-entry.patch.
  Update upstream status and move to sorted section.
- commit a1661c2
* Sun Dec  3 2023 mkubecek@suse.cz
- Update to 6.7-rc4
- update configs
  - BCACHEFS_ERASURE_CODING=n
- commit 900d9a2
* Sun Dec  3 2023 jslaby@suse.cz
- Linux 6.6.4 (bsc#1012628).
- USB: dwc3: qcom: fix wakeup after probe deferral (bsc#1012628).
- USB: dwc3: qcom: fix software node leak on probe errors
  (bsc#1012628).
- usb: dwc3: set the dma max_seg_size (bsc#1012628).
- usb: dwc3: Fix default mode initialization (bsc#1012628).
- USB: dwc2: write HCINT with INTMASK applied (bsc#1012628).
- usb: typec: tcpm: Skip hard reset when in error recovery
  (bsc#1012628).
- usb: typec: tcpm: Fix sink caps op current check (bsc#1012628).
- USB: serial: option: don't claim interface 4 for ZTE MF290
  (bsc#1012628).
- USB: serial: option: fix FM101R-GL defines (bsc#1012628).
- USB: serial: option: add Fibocom L7xx modules (bsc#1012628).
- usb: cdnsp: Fix deadlock issue during using NCM gadget
  (bsc#1012628).
- usb: config: fix iteration issue in 'usb_get_bos_descriptor()'
  (bsc#1012628).
- USB: xhci-plat: fix legacy PHY double init (bsc#1012628).
- bcache: fixup lock c->root error (bsc#1012628).
- bcache: fixup init dirty data errors (bsc#1012628).
- bcache: prevent potential division by zero error (bsc#1012628).
- bcache: check return value from btree_node_alloc_replacement()
  (bsc#1012628).
- veth: Use tstats per-CPU traffic counters (bsc#1012628).
- dm-delay: fix a race between delay_presuspend and delay_bio
  (bsc#1012628).
- ALSA: hda/realtek: Add quirks for ASUS 2024 Zenbooks
  (bsc#1012628).
- ALSA: hda: ASUS UM5302LA: Added quirks for cs35L41/10431A83
  on i2c bus (bsc#1012628).
- cifs: fix leak of iface for primary channel (bsc#1012628).
- cifs: account for primary channel in the interface list
  (bsc#1012628).
- cifs: distribute channels across interfaces based on speed
  (bsc#1012628).
- Revert "phy: realtek: usb: Add driver for the Realtek SoC USB
  2.0 PHY" (bsc#1012628).
- Revert "phy: realtek: usb: Add driver for the Realtek SoC USB
  3.0 PHY" (bsc#1012628).
- Revert "usb: phy: add usb phy notify port status API"
  (bsc#1012628).
- hv_netvsc: Mark VF as slave before exposing it to user-mode
  (bsc#1012628).
- hv_netvsc: Fix race of register_netdevice_notifier and VF
  register (bsc#1012628).
- hv_netvsc: fix race of netvsc and VF register_netdevice
  (bsc#1012628).
- platform/x86: ideapad-laptop: Set max_brightness before using it
  (bsc#1012628).
- platform/x86/amd/pmc: adjust getting DRAM size behavior
  (bsc#1012628).
- USB: serial: option: add Luat Air72*U series products
  (bsc#1012628).
- usb: misc: onboard-hub: add support for Microchip USB5744
  (bsc#1012628).
- dt-bindings: usb: microchip,usb5744: Add second supply
  (bsc#1012628).
- platform/x86: hp-bioscfg: Fix error handling in
  hp_add_other_attributes() (bsc#1012628).
- platform/x86: hp-bioscfg: move mutex_lock() down in
  hp_add_other_attributes() (bsc#1012628).
- platform/x86: hp-bioscfg: Simplify return check in
  hp_add_other_attributes() (bsc#1012628).
- s390/dasd: protect device queue against concurrent access
  (bsc#1012628).
- io_uring/fs: consider link->flags when getting path for LINKAT
  (bsc#1012628).
- bcache: fixup multi-threaded bch_sectors_dirty_init() wake-up
  race (bsc#1012628).
- md: fix bi_status reporting in md_end_clone_io (bsc#1012628).
- bcache: replace a mistaken IS_ERR() by IS_ERR_OR_NULL() in
  btree_gc_coalesce() (bsc#1012628).
- io_uring: fix off-by one bvec index (bsc#1012628).
- tls: fix NULL deref on tls_sw_splice_eof() with empty record
  (bsc#1012628).
- swiotlb-xen: provide the "max_mapping_size" method
  (bsc#1012628).
- ACPI: PM: Add acpi_device_fix_up_power_children() function
  (bsc#1012628).
- ACPI: resource: Skip IRQ override on ASUS ExpertBook B1402CVA
  (bsc#1012628).
- ACPI: processor_idle: use raw_safe_halt() in
  acpi_idle_play_dead() (bsc#1012628).
- ACPI: video: Use acpi_device_fix_up_power_children()
  (bsc#1012628).
- thunderbolt: Set lane bonding bit only for downstream port
  (bsc#1012628).
- drm/ast: Disconnect BMC if physical connector is connected
  (bsc#1012628).
- drm/msm/dpu: Add missing safe_lut_tbl in sc8280xp catalog
  (bsc#1012628).
- kselftest/arm64: Fix output formatting for za-fork
  (bsc#1012628).
- prctl: Disable prctl(PR_SET_MDWE) on parisc (bsc#1012628).
- mm: add a NO_INHERIT flag to the PR_SET_MDWE prctl
  (bsc#1012628).
- lockdep: Fix block chain corruption (bsc#1012628).
- USB: dwc3: qcom: fix ACPI platform device leak (bsc#1012628).
- USB: dwc3: qcom: fix resource leaks on probe deferral
  (bsc#1012628).
- nvmet: nul-terminate the NQNs passed in the connect command
  (bsc#1012628).
- nvme: blank out authentication fabrics options if not configured
  (bsc#1012628).
- afs: Fix file locking on R/O volumes to operate in local mode
  (bsc#1012628).
- afs: Return ENOENT if no cell DNS record can be found
  (bsc#1012628).
- net: ipa: fix one GSI register field width (bsc#1012628).
- net: axienet: Fix check for partial TX checksum (bsc#1012628).
- vsock/test: fix SEQPACKET message bounds test (bsc#1012628).
- i40e: Fix adding unsupported cloud filters (bsc#1012628).
- amd-xgbe: propagate the correct speed and duplex status
  (bsc#1012628).
- amd-xgbe: handle the corner-case during tx completion
  (bsc#1012628).
- amd-xgbe: handle corner-case during sfp hotplug (bsc#1012628).
- net: veth: fix ethtool stats reporting (bsc#1012628).
- octeontx2-pf: Fix ntuple rule creation to direct packet to VF
  with higher Rx queue than its PF (bsc#1012628).
- arm/xen: fix xen_vcpu_info allocation alignment (bsc#1012628).
- arm64: mm: Fix "rodata=on" when
  CONFIG_RODATA_FULL_DEFAULT_ENABLED=y (bsc#1012628).
- s390/ipl: add missing IPL_TYPE_ECKD_DUMP case to ipl_init()
  (bsc#1012628).
- net/smc: avoid data corruption caused by decline (bsc#1012628).
- net: usb: ax88179_178a: fix failed operations during
  ax88179_reset (bsc#1012628).
- drm/panel: boe-tv101wum-nl6: Fine tune Himax83102-j02 panel
  HFP and HBP (bsc#1012628).
- ipv4: Correct/silence an endian warning in __ip_do_redirect
  (bsc#1012628).
- HID: fix HID device resource race between HID core and debugging
  support (bsc#1012628).
- accel/ivpu/37xx: Fix hangs related to MMIO reset (bsc#1012628).
- accel/ivpu: Do not initialize parameters on power up
  (bsc#1012628).
- bpf: Fix dev's rx stats for bpf_redirect_peer traffic
  (bsc#1012628).
- net: Move {l,t,d}stats allocation to core and convert veth &
  vrf (bsc#1012628).
- net, vrf: Move dstats structure to core (bsc#1012628).
- PM: tools: Fix sleepgraph syntax error (bsc#1012628).
- drm/rockchip: vop: Fix color for RGB888/BGR888 format on VOP
  full (bsc#1012628).
- libfs: getdents() should return 0 after reaching EOD
  (bsc#1012628).
- block: update the stable_writes flag in bdev_add (bsc#1012628).
- filemap: add a per-mapping stable writes flag (bsc#1012628).
- drm/i915: do not clean GT table on error path (bsc#1012628).
- ata: pata_isapnp: Add missing error check for devm_ioport_map()
  (bsc#1012628).
- octeontx2-pf: Fix memory leak during interface down
  (bsc#1012628).
- wireguard: use DEV_STATS_INC() (bsc#1012628).
- net: wangxun: fix kernel panic due to null pointer
  (bsc#1012628).
- drm/panel: simple: Fix Innolux G101ICE-L01 timings
  (bsc#1012628).
- drm/panel: simple: Fix Innolux G101ICE-L01 bus flags
  (bsc#1012628).
- fs: Pass AT_GETATTR_NOSEC flag to getattr interface function
  (bsc#1012628).
- drm/panel: auo,b101uan08.3: Fine tune the panel power sequence
  (bsc#1012628).
- blk-cgroup: avoid to warn !rcu_read_lock_held() in blkg_lookup()
  (bsc#1012628).
- afs: Make error on cell lookup failure consistent with OpenAFS
  (bsc#1012628).
- afs: Fix afs_server_list to be cleaned up with RCU
  (bsc#1012628).
- rxrpc: Defer the response to a PING ACK until we've parsed it
  (bsc#1012628).
- rxrpc: Fix RTT determination to use any ACK as a source
  (bsc#1012628).
- s390/ism: ism driver implies smc protocol (bsc#1012628).
- drm/msm/dsi: use the correct VREG_CTRL_1 value for 4nm cphy
  (bsc#1012628).
- sched/fair: Fix the decision for load balance (bsc#1012628).
- sched/eevdf: Fix vruntime adjustment on reweight (bsc#1012628).
- hv/hv_kvp_daemon: Some small fixes for handling NM keyfiles
  (bsc#1012628).
- irqchip/gic-v3-its: Flush ITS tables correctly in non-coherent
  GIC designs (bsc#1012628).
- NFSD: Fix checksum mismatches in the duplicate reply cache
  (bsc#1012628).
- NFSD: Fix "start of NFS reply" pointer passed to
  nfsd_cache_update() (bsc#1012628).
- commit eafb2e8
* Fri Dec  1 2023 msuchanek@suse.de
- kernel-binary: suse-module-tools is also required when installed
  Requires(pre) adds dependency for the specific sciptlet.
  However, suse-module-tools also ships modprobe.d files which may be
  needed at posttrans time or any time the kernel is on the system for
  generating ramdisk. Add plain Requires as well.
- commit 8c12816
* Fri Dec  1 2023 msuchanek@suse.de
- rpm: Use run_if_exists for all external scriptlets
  With that the scriptlets do not need to be installed for build.
- commit 25edd65
* Thu Nov 30 2023 jslaby@suse.cz
- README.SUSE: fix patches.addon use
  It's series, not series.conf in there.
  And make it more precise on when the patches are applied.
- commit cb8969c
* Wed Nov 29 2023 bwiedemann@suse.de
- Do not store build host name in initrd
  Without this patch, kernel-obs-build stored the build host name
  in its .build.initrd.kvm
  This patch allows for reproducible builds of kernel-obs-build and thus
  avoids re-publishing the kernel-obs-build.rpm when nothing changed.
  Note that this has no influence on the /etc/hosts file
  that is used during other OBS builds.
  https://bugzilla.opensuse.org/show_bug.cgi?id=1084909
- commit fd3a75e
* Wed Nov 29 2023 tiwai@suse.de
- Update ath11k hibernation patches from the latest code (bsc#1207948)
- commit 9b910a2
* Wed Nov 29 2023 jslaby@suse.cz
- Linux 6.6.3 (bsc#1012628).
- locking/ww_mutex/test: Fix potential workqueue corruption
  (bsc#1012628).
- btrfs: abort transaction on generation mismatch when marking
  eb as dirty (bsc#1012628).
- lib/generic-radix-tree.c: Don't overflow in peek()
  (bsc#1012628).
- x86/retpoline: Make sure there are no unconverted return thunks
  due to KCSAN (bsc#1012628).
- perf/core: Bail out early if the request AUX area is out of
  bound (bsc#1012628).
- srcu: Fix srcu_struct node grpmask overflow on 64-bit systems
  (bsc#1012628).
- selftests/lkdtm: Disable CONFIG_UBSAN_TRAP in test config
  (bsc#1012628).
- clocksource/drivers/timer-imx-gpt: Fix potential memory leak
  (bsc#1012628).
- clocksource/drivers/timer-atmel-tcb: Fix initialization on
  SAM9 hardware (bsc#1012628).
- srcu: Only accelerate on enqueue time (bsc#1012628).
- smp,csd: Throw an error if a CSD lock is stuck for too long
  (bsc#1012628).
- cpu/hotplug: Don't offline the last non-isolated CPU
  (bsc#1012628).
- workqueue: Provide one lock class key per work_on_cpu() callsite
  (bsc#1012628).
- x86/mm: Drop the 4 MB restriction on minimal NUMA node memory
  size (bsc#1012628).
- wifi: plfxlc: fix clang-specific fortify warning (bsc#1012628).
- wifi: ath12k: Ignore fragments from uninitialized peer in dp
  (bsc#1012628).
- wifi: mac80211_hwsim: fix clang-specific fortify warning
  (bsc#1012628).
- wifi: mac80211: don't return unset power in
  ieee80211_get_tx_power() (bsc#1012628).
- atl1c: Work around the DMA RX overflow issue (bsc#1012628).
- bpf: Detect IP == ksym.end as part of BPF program (bsc#1012628).
- wifi: ath9k: fix clang-specific fortify warnings (bsc#1012628).
- wifi: ath12k: fix possible out-of-bound read in
  ath12k_htt_pull_ppdu_stats() (bsc#1012628).
- wifi: ath10k: fix clang-specific fortify warning (bsc#1012628).
- wifi: ath12k: fix possible out-of-bound write in
  ath12k_wmi_ext_hal_reg_caps() (bsc#1012628).
- ACPI: APEI: Fix AER info corruption when error status data
  has multiple sections (bsc#1012628).
- net: sfp: add quirk for Fiberstone GPON-ONU-34-20BI
  (bsc#1012628).
- wifi: mt76: mt7921e: Support MT7992 IP in Xiaomi Redmibook 15
  Pro (2023) (bsc#1012628).
- wifi: mt76: fix clang-specific fortify warnings (bsc#1012628).
- net: annotate data-races around sk->sk_tx_queue_mapping
  (bsc#1012628).
- net: annotate data-races around sk->sk_dst_pending_confirm
  (bsc#1012628).
- wifi: ath12k: mhi: fix potential memory leak in
  ath12k_mhi_register() (bsc#1012628).
- wifi: ath10k: Don't touch the CE interrupt registers after
  power up (bsc#1012628).
- net: sfp: add quirk for FS's 2.5G copper SFP (bsc#1012628).
- vsock: read from socket's error queue (bsc#1012628).
- bpf: Ensure proper register state printing for cond jumps
  (bsc#1012628).
- wifi: iwlwifi: mvm: fix size check for fw_link_id (bsc#1012628).
- Bluetooth: btusb: Add date->evt_skb is NULL check (bsc#1012628).
- Bluetooth: Fix double free in hci_conn_cleanup (bsc#1012628).
- ACPI: EC: Add quirk for HP 250 G7 Notebook PC (bsc#1012628).
- tsnep: Fix tsnep_request_irq() format-overflow warning
  (bsc#1012628).
- gpiolib: acpi: Add a ignore interrupt quirk for Peaq C1010
  (bsc#1012628).
- platform/chrome: kunit: initialize lock for fake ec_dev
  (bsc#1012628).
- of: address: Fix address translation when address-size is
  greater than 2 (bsc#1012628).
- platform/x86: thinkpad_acpi: Add battery quirk for Thinkpad
  X120e (bsc#1012628).
- drm/gma500: Fix call trace when psb_gem_mm_init() fails
  (bsc#1012628).
- drm/amdkfd: ratelimited SQ interrupt messages (bsc#1012628).
- drm/komeda: drop all currently held locks if deadlock happens
  (bsc#1012628).
- drm/amd/display: Blank phantom OTG before enabling
  (bsc#1012628).
- drm/amd/display: Don't lock phantom pipe on disabling
  (bsc#1012628).
- drm/amd/display: add seamless pipe topology transition check
  (bsc#1012628).
- drm/edid: Fixup h/vsync_end instead of h/vtotal (bsc#1012628).
- md: don't rely on 'mddev->pers' to be set in mddev_suspend()
  (bsc#1012628).
- drm/amdgpu: not to save bo in the case of RAS err_event_athub
  (bsc#1012628).
- drm/amdkfd: Fix a race condition of vram buffer unref in svm
  code (bsc#1012628).
- drm/amdgpu: update retry times for psp vmbx wait (bsc#1012628).
- drm/amd: Update `update_pcie_parameters` functions to use
  uint8_t arguments (bsc#1012628).
- drm/amd/display: use full update for clip size increase of
  large plane source (bsc#1012628).
- string.h: add array-wrappers for (v)memdup_user() (bsc#1012628).
- kernel: kexec: copy user-array safely (bsc#1012628).
- kernel: watch_queue: copy user-array safely (bsc#1012628).
- drm_lease.c: copy user-array safely (bsc#1012628).
- drm: vmwgfx_surface.c: copy user-array safely (bsc#1012628).
- drm/msm/dp: skip validity check for DP CTS EDID checksum
  (bsc#1012628).
- drm/amd: Fix UBSAN array-index-out-of-bounds for SMU7
  (bsc#1012628).
- drm/amd: Fix UBSAN array-index-out-of-bounds for Polaris and
  Tonga (bsc#1012628).
- drm/amdgpu: Fix potential null pointer derefernce (bsc#1012628).
- drm/panel: fix a possible null pointer dereference
  (bsc#1012628).
- drm/panel/panel-tpo-tpg110: fix a possible null pointer
  dereference (bsc#1012628).
- drm/radeon: fix a possible null pointer dereference
  (bsc#1012628).
- drm/amdgpu/vkms: fix a possible null pointer dereference
  (bsc#1012628).
- drm/panel: st7703: Pick different reset sequence (bsc#1012628).
- drm/amdkfd: Fix shift out-of-bounds issue (bsc#1012628).
- drm/amdgpu: Fix a null pointer access when the smc_rreg pointer
  is NULL (bsc#1012628).
- drm/amd: Disable PP_PCIE_DPM_MASK when dynamic speed switching
  not supported (bsc#1012628).
- drm/amd/display: fix num_ways overflow error (bsc#1012628).
- drm/amd: check num of link levels when update pcie param
  (bsc#1012628).
- soc: qcom: pmic: Fix resource leaks in a
  device_for_each_child_node() loop (bsc#1012628).
- arm64: dts: rockchip: Add NanoPC T6 PCIe e-key support
  (bsc#1012628).
- arm64: dts: ls208xa: use a pseudo-bus to constrain usb dma size
  (bsc#1012628).
- selftests/efivarfs: create-read: fix a resource leak
  (bsc#1012628).
- ASoC: mediatek: mt8188-mt6359: support dynamic pinctrl
  (bsc#1012628).
- ASoC: soc-card: Add storage for PCI SSID (bsc#1012628).
- ASoC: SOF: Pass PCI SSID to machine driver (bsc#1012628).
- ASoC: Intel: sof_sdw: Copy PCI SSID to struct snd_soc_card
  (bsc#1012628).
- ASoC: cs35l56: Use PCI SSID as the firmware UID (bsc#1012628).
- crypto: pcrypt - Fix hungtask for PADATA_RESET (bsc#1012628).
- ASoC: SOF: ipc4: handle EXCEPTION_CAUGHT notification from
  firmware (bsc#1012628).
- RDMA/hfi1: Use FIELD_GET() to extract Link Width (bsc#1012628).
- scsi: hisi_sas: Set debugfs_dir pointer to NULL after removing
  debugfs (bsc#1012628).
- scsi: ibmvfc: Remove BUG_ON in the case of an empty event pool
  (bsc#1012628).
- fs/jfs: Add check for negative db_l2nbperpage (bsc#1012628).
- fs/jfs: Add validity check for db_maxag and db_agpref
  (bsc#1012628).
- jfs: fix array-index-out-of-bounds in dbFindLeaf (bsc#1012628).
- jfs: fix array-index-out-of-bounds in diAlloc (bsc#1012628).
- HID: lenovo: Detect quirk-free fw on cptkbd and stop applying
  workaround (bsc#1012628).
- ARM: 9320/1: fix stack depot IRQ stack filter (bsc#1012628).
- ALSA: hda: Fix possible null-ptr-deref when assigning a stream
  (bsc#1012628).
- gpiolib: of: Add quirk for mt2701-cs42448 ASoC sound
  (bsc#1012628).
- PCI: tegra194: Use FIELD_GET()/FIELD_PREP() with Link Width
  fields (bsc#1012628).
- PCI: mvebu: Use FIELD_PREP() with Link Width (bsc#1012628).
- atm: iphase: Do PCI error checks on own line (bsc#1012628).
- PCI: Do error check on own line to split long "if" conditions
  (bsc#1012628).
- scsi: libfc: Fix potential NULL pointer dereference in
  fc_lport_ptp_setup() (bsc#1012628).
- PCI: Use FIELD_GET() to extract Link Width (bsc#1012628).
- PCI: Extract ATS disabling to a helper function (bsc#1012628).
- PCI: Disable ATS for specific Intel IPU E2000 devices
  (bsc#1012628).
- PCI: dwc: Add dw_pcie_link_set_max_link_width() (bsc#1012628).
- PCI: dwc: Add missing PCI_EXP_LNKCAP_MLW handling (bsc#1012628).
- misc: pci_endpoint_test: Add Device ID for R-Car S4-8 PCIe
  controller (bsc#1012628).
- PCI: Use FIELD_GET() in Sapphire RX 5600 XT Pulse quirk
  (bsc#1012628).
- ASoC: Intel: soc-acpi-cht: Add Lenovo Yoga Tab 3 Pro YT3-X90
  quirk (bsc#1012628).
- crypto: hisilicon/qm - prevent soft lockup in receive loop
  (bsc#1012628).
- HID: Add quirk for Dell Pro Wireless Keyboard and Mouse KM5221W
  (bsc#1012628).
- exfat: support handle zero-size directory (bsc#1012628).
- mfd: intel-lpss: Add Intel Lunar Lake-M PCI IDs (bsc#1012628).
- iio: adc: stm32-adc: harden against NULL pointer deref in
  stm32_adc_probe() (bsc#1012628).
- thunderbolt: Apply USB 3.x bandwidth quirk only in software
  connection manager (bsc#1012628).
- tty: vcc: Add check for kstrdup() in vcc_probe() (bsc#1012628).
- dt-bindings: phy: qcom,snps-eusb2-repeater: Add magic tuning
  overrides (bsc#1012628).
- phy: qualcomm: phy-qcom-eusb2-repeater: Use regmap_fields
  (bsc#1012628).
- phy: qualcomm: phy-qcom-eusb2-repeater: Zero out untouched
  tuning regs (bsc#1012628).
- usb: dwc3: core: configure TX/RX threshold for DWC3_IP
  (bsc#1012628).
- usb: ucsi: glink: use the connector orientation GPIO to provide
  switch events (bsc#1012628).
- soundwire: dmi-quirks: update HP Omen match (bsc#1012628).
- f2fs: fix error path of __f2fs_build_free_nids (bsc#1012628).
- f2fs: fix error handling of __get_node_page (bsc#1012628).
- usb: host: xhci: Avoid XHCI resume delay if SSUSB device is
  not present (bsc#1012628).
- usb: gadget: f_ncm: Always set current gadget in ncm_bind()
  (bsc#1012628).
- 9p/trans_fd: Annotate data-racy writes to file::f_flags
  (bsc#1012628).
- 9p: v9fs_listxattr: fix %%s null argument warning (bsc#1012628).
- i3c: mipi-i3c-hci: Fix out of bounds access in
  hci_dma_irq_handler (bsc#1012628).
- i2c: i801: Add support for Intel Birch Stream SoC (bsc#1012628).
- i2c: fix memleak in i2c_new_client_device() (bsc#1012628).
- i2c: sun6i-p2wi: Prevent potential division by zero
  (bsc#1012628).
- virtio-blk: fix implicit overflow on virtio_max_dma_size
  (bsc#1012628).
- i3c: master: mipi-i3c-hci: Fix a kernel panic for accessing
  DAT_data (bsc#1012628).
- media: gspca: cpia1: shift-out-of-bounds in set_flicker
  (bsc#1012628).
- media: vivid: avoid integer overflow (bsc#1012628).
- media: ipu-bridge: increase sensor_name size (bsc#1012628).
- gfs2: ignore negated quota changes (bsc#1012628).
- gfs2: fix an oops in gfs2_permission (bsc#1012628).
- media: cobalt: Use FIELD_GET() to extract Link Width
  (bsc#1012628).
- media: ccs: Fix driver quirk struct documentation (bsc#1012628).
- media: imon: fix access to invalid resource for the second
  interface (bsc#1012628).
- drm/amd/display: Avoid NULL dereference of timing generator
  (bsc#1012628).
- gfs2: Fix slab-use-after-free in gfs2_qd_dealloc (bsc#1012628).
- kgdb: Flush console before entering kgdb on panic (bsc#1012628).
- riscv: VMAP_STACK overflow detection thread-safe (bsc#1012628).
- i2c: dev: copy userspace array safely (bsc#1012628).
- ASoC: ti: omap-mcbsp: Fix runtime PM underflow warnings
  (bsc#1012628).
- drm/qxl: prevent memory leak (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ASUS UX7602ZM (bsc#1012628).
- drm/amdgpu: fix software pci_unplug on some chips (bsc#1012628).
- pwm: Fix double shift bug (bsc#1012628).
- mtd: rawnand: tegra: add missing check for platform_get_irq()
  (bsc#1012628).
- wifi: iwlwifi: Use FW rate for non-data frames (bsc#1012628).
- sched/core: Optimize in_task() and in_interrupt() a bit
  (bsc#1012628).
- samples/bpf: syscall_tp_user: Rename num_progs into nr_tests
  (bsc#1012628).
- samples/bpf: syscall_tp_user: Fix array out-of-bound access
  (bsc#1012628).
- dt-bindings: serial: fix regex pattern for matching serial
  node children (bsc#1012628).
- SUNRPC: ECONNRESET might require a rebind (bsc#1012628).
- mtd: rawnand: intel: check return value of devm_kasprintf()
  (bsc#1012628).
- mtd: rawnand: meson: check return value of devm_kasprintf()
  (bsc#1012628).
- drm/i915/mtl: avoid stringop-overflow warning (bsc#1012628).
- NFSv4.1: fix handling NFS4ERR_DELAY when testing for session
  trunking (bsc#1012628).
- SUNRPC: Add an IS_ERR() check back to where it was
  (bsc#1012628).
- NFSv4.1: fix SP4_MACH_CRED protection for pnfs IO (bsc#1012628).
- SUNRPC: Fix RPC client cleaned up the freed pipefs dentries
  (bsc#1012628).
- RISC-V: hwprobe: Fix vDSO SIGSEGV (bsc#1012628).
- riscv: provide riscv-specific is_trap_insn() (bsc#1012628).
- gfs2: Silence "suspicious RCU usage in gfs2_permission" warning
  (bsc#1012628).
- drm/i915/tc: Fix -Wformat-truncation in intel_tc_port_init
  (bsc#1012628).
- riscv: split cache ops out of dma-noncoherent.c (bsc#1012628).
- vdpa_sim_blk: allocate the buffer zeroed (bsc#1012628).
- vhost-vdpa: fix use after free in vhost_vdpa_probe()
  (bsc#1012628).
- gcc-plugins: randstruct: Only warn about true flexible arrays
  (bsc#1012628).
- bpf: handle ldimm64 properly in check_cfg() (bsc#1012628).
- bpf: fix precision backtracking instruction iteration
  (bsc#1012628).
- bpf: fix control-flow graph checking in privileged mode
  (bsc#1012628).
- net: set SOCK_RCU_FREE before inserting socket into hashtable
  (bsc#1012628).
- ipvlan: add ipvlan_route_v6_outbound() helper (bsc#1012628).
- tty: Fix uninit-value access in ppp_sync_receive()
  (bsc#1012628).
- net: ti: icssg-prueth: Add missing icss_iep_put to error path
  (bsc#1012628).
- net: ti: icssg-prueth: Fix error cleanup on failing
  pruss_request_mem_region (bsc#1012628).
- xen/events: avoid using info_for_irq() in xen_send_IPI_one()
  (bsc#1012628).
- net: hns3: fix add VLAN fail issue (bsc#1012628).
- net: hns3: add barrier in vf mailbox reply process
  (bsc#1012628).
- net: hns3: fix incorrect capability bit display for copper port
  (bsc#1012628).
- net: hns3: fix out-of-bounds access may occur when coalesce
  info is read via debugfs (bsc#1012628).
- net: hns3: fix variable may not initialized problem in
  hns3_init_mac_addr() (bsc#1012628).
- net: hns3: fix VF reset fail issue (bsc#1012628).
- net: hns3: fix VF wrong speed and duplex issue (bsc#1012628).
- tipc: Fix kernel-infoleak due to uninitialized TLV value
  (bsc#1012628).
- net: mvneta: fix calls to page_pool_get_stats (bsc#1012628).
- ppp: limit MRU to 64K (bsc#1012628).
- xen/events: fix delayed eoi list handling (bsc#1012628).
- blk-mq: make sure active queue usage is held for
  bio_integrity_prep() (bsc#1012628).
- ptp: annotate data-race around q->head and q->tail
  (bsc#1012628).
- bonding: stop the device in bond_setup_by_slave() (bsc#1012628).
- net: ethernet: cortina: Fix max RX frame define (bsc#1012628).
- net: ethernet: cortina: Handle large frames (bsc#1012628).
- net: ethernet: cortina: Fix MTU max setting (bsc#1012628).
- af_unix: fix use-after-free in unix_stream_read_actor()
  (bsc#1012628).
- netfilter: nf_conntrack_bridge: initialize err to 0
  (bsc#1012628).
- netfilter: nf_tables: fix pointer math issue in
  nft_byteorder_eval() (bsc#1012628).
- netfilter: nf_tables: bogus ENOENT when destroying element
  which does not exist (bsc#1012628).
- net: stmmac: fix rx budget limit check (bsc#1012628).
- net: stmmac: avoid rx queue overrun (bsc#1012628).
- pds_core: use correct index to mask irq (bsc#1012628).
- pds_core: fix up some format-truncation complaints
  (bsc#1012628).
- gve: Fixes for napi_poll when budget is 0 (bsc#1012628).
- io_uring/fdinfo: remove need for sqpoll lock for thread/pid
  retrieval (bsc#1012628).
- Revert "net/mlx5: DR, Supporting inline WQE when possible"
  (bsc#1012628).
- net/mlx5: Free used cpus mask when an IRQ is released
  (bsc#1012628).
- net/mlx5: Decouple PHC .adjtime and .adjphase implementations
  (bsc#1012628).
- net/mlx5e: fix double free of encap_header (bsc#1012628).
- net/mlx5e: fix double free of encap_header in update funcs
  (bsc#1012628).
- net/mlx5e: Fix pedit endianness (bsc#1012628).
- net/mlx5e: Don't modify the peer sent-to-vport rules for IPSec
  offload (bsc#1012628).
- net/mlx5e: Avoid referencing skb after free-ing in drop path
  of mlx5e_sq_xmit_wqe (bsc#1012628).
- net/mlx5e: Track xmit submission to PTP WQ after populating
  metadata map (bsc#1012628).
- net/mlx5e: Update doorbell for port timestamping CQ before
  the software counter (bsc#1012628).
- net/mlx5: Increase size of irq name buffer (bsc#1012628).
- net/mlx5e: Reduce the size of icosq_str (bsc#1012628).
- net/mlx5e: Check return value of snprintf writing to fw_version
  buffer (bsc#1012628).
- net/mlx5e: Check return value of snprintf writing to fw_version
  buffer for representors (bsc#1012628).
- net: sched: do not offload flows with a helper in act_ct
  (bsc#1012628).
- macvlan: Don't propagate promisc change to lower dev in passthru
  (bsc#1012628).
- tools/power/turbostat: Fix a knl bug (bsc#1012628).
- tools/power/turbostat: Enable the C-state Pre-wake printing
  (bsc#1012628).
- scsi: ufs: core: Expand MCQ queue slot to DeviceQueueDepth +
  1 (bsc#1012628).
- cifs: spnego: add ';' in HOST_KEY_LEN (bsc#1012628).
- cifs: fix check of rc in function generate_smb3signingkey
  (bsc#1012628).
- perf/core: Fix cpuctx refcounting (bsc#1012628).
- i915/perf: Fix NULL deref bugs with drm_dbg() calls
  (bsc#1012628).
- perf: arm_cspmu: Reject events meant for other PMUs
  (bsc#1012628).
- drivers: perf: Check find_first_bit() return value
  (bsc#1012628).
- media: venus: hfi: add checks to perform sanity on queue
  pointers (bsc#1012628).
- perf intel-pt: Fix async branch flags (bsc#1012628).
- powerpc/perf: Fix disabling BHRB and instruction sampling
  (bsc#1012628).
- randstruct: Fix gcc-plugin performance mode to stay in group
  (bsc#1012628).
- spi: Fix null dereference on suspend (bsc#1012628).
- bpf: Fix check_stack_write_fixed_off() to correctly spill imm
  (bsc#1012628).
- bpf: Fix precision tracking for BPF_ALU | BPF_TO_BE | BPF_END
  (bsc#1012628).
- scsi: mpt3sas: Fix loop logic (bsc#1012628).
- scsi: megaraid_sas: Increase register read retry rount from
  3 to 30 for selected registers (bsc#1012628).
- scsi: ufs: qcom: Update PHY settings only when scaling to
  higher gears (bsc#1012628).
- scsi: qla2xxx: Fix system crash due to bad pointer access
  (bsc#1012628).
- scsi: ufs: core: Fix racing issue between ufshcd_mcq_abort()
  and ISR (bsc#1012628).
- x86/shstk: Delay signal entry SSP write until after user
  accesses (bsc#1012628).
- crypto: x86/sha - load modules based on CPU features
  (bsc#1012628).
- x86/PCI: Avoid PME from D3hot/D3cold for AMD Rembrandt and
  Phoenix USB4 (bsc#1012628).
- x86/apic/msi: Fix misconfigured non-maskable MSI quirk
  (bsc#1012628).
- x86/cpu/hygon: Fix the CPU topology evaluation for real
  (bsc#1012628).
- KVM: x86: hyper-v: Don't auto-enable stimer on write from
  user-space (bsc#1012628).
- KVM: x86: Ignore MSR_AMD64_TW_CFG access (bsc#1012628).
- KVM: x86: Clear bit12 of ICR after APIC-write VM-exit
  (bsc#1012628).
- KVM: x86: Fix lapic timer interrupt lost after loading a
  snapshot (bsc#1012628).
- mmc: sdhci-pci-gli: GL9755: Mask the replay timer timeout of
  AER (bsc#1012628).
- sched: psi: fix unprivileged polling against cgroups
  (bsc#1012628).
- audit: don't take task_lock() in audit_exe_compare() code path
  (bsc#1012628).
- audit: don't WARN_ON_ONCE(!current->mm) in audit_exe_compare()
  (bsc#1012628).
- proc: sysctl: prevent aliased sysctls from getting passed to
  init (bsc#1012628).
- tty/sysrq: replace smp_processor_id() with get_cpu()
  (bsc#1012628).
- tty: serial: meson: fix hard LOCKUP on crtscts mode
  (bsc#1012628).
- acpi/processor: sanitize _OSC/_PDC capabilities for Xen dom0
  (bsc#1012628).
- hvc/xen: fix console unplug (bsc#1012628).
- hvc/xen: fix error path in xen_hvc_init() to always register
  frontend driver (bsc#1012628).
- hvc/xen: fix event channel handling for secondary consoles
  (bsc#1012628).
- PCI/sysfs: Protect driver's D3cold preference from user space
  (bsc#1012628).
- mm/damon/sysfs: remove requested targets when online-commit
  inputs (bsc#1012628).
- mm/damon/sysfs: update monitoring target regions for online
  input commit (bsc#1012628).
- watchdog: move softlockup_panic back to early_param
  (bsc#1012628).
- iommufd: Fix missing update of domains_itree after splitting
  iopt_area (bsc#1012628).
- fbdev: stifb: Make the STI next font pointer a 32-bit signed
  offset (bsc#1012628).
- dm crypt: account large pages in cc->n_allocated_pages
  (bsc#1012628).
- mm/damon/lru_sort: avoid divide-by-zero in hot threshold
  calculation (bsc#1012628).
- mm/damon/ops-common: avoid divide-by-zero during region hotness
  calculation (bsc#1012628).
- mm/damon: implement a function for max nr_accesses safe
  calculation (bsc#1012628).
- mm/damon/core: avoid divide-by-zero during monitoring results
  update (bsc#1012628).
- mm/damon/sysfs-schemes: handle tried region directory allocation
  failure (bsc#1012628).
- mm/damon/sysfs-schemes: handle tried regions sysfs directory
  allocation failure (bsc#1012628).
- mm/damon/core.c: avoid unintentional filtering out of schemes
  (bsc#1012628).
- mm/damon/sysfs: check error from damon_sysfs_update_target()
  (bsc#1012628).
- parisc: Add nop instructions after TLB inserts (bsc#1012628).
- ACPI: resource: Do IRQ override on TongFang GMxXGxx
  (bsc#1012628).
- regmap: Ensure range selector registers are updated after
  cache sync (bsc#1012628).
- wifi: ath11k: fix temperature event locking (bsc#1012628).
- wifi: ath11k: fix dfs radar event locking (bsc#1012628).
- wifi: ath11k: fix htt pktlog locking (bsc#1012628).
- wifi: ath11k: fix gtk offload status event locking
  (bsc#1012628).
- wifi: ath12k: fix htt mlo-offset event locking (bsc#1012628).
- wifi: ath12k: fix dfs-radar and temperature event locking
  (bsc#1012628).
- mmc: meson-gx: Remove setting of CMD_CFG_ERROR (bsc#1012628).
- genirq/generic_chip: Make irq_remove_generic_chip() irqdomain
  aware (bsc#1012628).
- sched/core: Fix RQCF_ACT_SKIP leak (bsc#1012628).
- pmdomain: bcm: bcm2835-power: check if the ASB register is
  equal to enable (bsc#1012628).
- KEYS: trusted: tee: Refactor register SHM usage (bsc#1012628).
- KEYS: trusted: Rollback init_trusted() consistently
  (bsc#1012628).
- PCI: keystone: Don't discard .remove() callback (bsc#1012628).
- PCI: keystone: Don't discard .probe() callback (bsc#1012628).
- pmdomain: amlogic: Fix mask for the second NNA mem PD domain
  (bsc#1012628).
- arm64: Restrict CPU_BIG_ENDIAN to GNU as or LLVM IAS 15.x or
  newer (bsc#1012628).
- arm64: module: Fix PLT counting when CONFIG_RANDOMIZE_BASE=n
  (bsc#1012628).
- pmdomain: imx: Make imx pgc power domain also set the fwnode
  (bsc#1012628).
- parisc/agp: Use 64-bit LE values in SBA IOMMU PDIR table
  (bsc#1012628).
- parisc/pdc: Add width field to struct pdc_model (bsc#1012628).
- parisc/power: Add power soft-off when running on qemu
  (bsc#1012628).
- cpufreq: stats: Fix buffer overflow detection in trans_stats()
  (bsc#1012628).
- powercap: intel_rapl: Downgrade BIOS locked limits pr_warn()
  to pr_debug() (bsc#1012628).
- clk: socfpga: Fix undefined behavior bug in struct
  stratix10_clock_data (bsc#1012628).
- clk: visconti: Fix undefined behavior bug in struct
  visconti_pll_provider (bsc#1012628).
- integrity: powerpc: Do not select CA_MACHINE_KEYRING
  (bsc#1012628).
- clk: qcom: ipq8074: drop the CLK_SET_RATE_PARENT flag from
  PLL clocks (bsc#1012628).
- clk: qcom: ipq6018: drop the CLK_SET_RATE_PARENT flag from
  PLL clocks (bsc#1012628).
- ksmbd: fix recursive locking in vfs helpers (bsc#1012628).
- ksmbd: handle malformed smb1 message (bsc#1012628).
- ksmbd: fix slab out of bounds write in smb_inherit_dacl()
  (bsc#1012628).
- mmc: vub300: fix an error code (bsc#1012628).
- mmc: sdhci_am654: fix start loop index for TAP value parsing
  (bsc#1012628).
- mmc: Add quirk MMC_QUIRK_BROKEN_CACHE_FLUSH for Micron eMMC
  Q2J54A (bsc#1012628).
- PCI: qcom-ep: Add dedicated callback for writing to DBI2
  registers (bsc#1012628).
- PCI/ASPM: Fix L1 substate handling in aspm_attr_store_common()
  (bsc#1012628).
- PCI: kirin: Don't discard .remove() callback (bsc#1012628).
- PCI: exynos: Don't discard .remove() callback (bsc#1012628).
- PCI: Lengthen reset delay for VideoPropulsion Torrent QN16e card
  (bsc#1012628).
- wifi: wilc1000: use vmm_table as array in wilc struct
  (bsc#1012628).
- svcrdma: Drop connection after an RDMA Read error (bsc#1012628).
- rcu/tree: Defer setting of jiffies during stall reset
  (bsc#1012628).
- arm64: dts: qcom: ipq6018: Fix hwlock index for SMEM
  (bsc#1012628).
- dt-bindings: timer: renesas,rz-mtu3: Fix overflow/underflow
  interrupt names (bsc#1012628).
- PM: hibernate: Use __get_safe_page() rather than touching the
  list (bsc#1012628).
- PM: hibernate: Clean up sync_read handling in
  snapshot_write_next() (bsc#1012628).
- rcu: kmemleak: Ignore kmemleak false positives when RCU-freeing
  objects (bsc#1012628).
- btrfs: don't arbitrarily slow down delalloc if we're committing
  (bsc#1012628).
- thermal: intel: powerclamp: fix mismatch in get function for
  max_idle (bsc#1012628).
- arm64: dts: qcom: ipq5332: Fix hwlock index for SMEM
  (bsc#1012628).
- arm64: dts: qcom: ipq8074: Fix hwlock index for SMEM
  (bsc#1012628).
- firmware: qcom_scm: use 64-bit calling convention only when
  client is 64-bit (bsc#1012628).
- ACPI: FPDT: properly handle invalid FPDT subtables
  (bsc#1012628).
- arm64: dts: qcom: ipq9574: Fix hwlock index for SMEM
  (bsc#1012628).
- arm64: dts: qcom: ipq6018: Fix tcsr_mutex register size
  (bsc#1012628).
- leds: trigger: netdev: Move size check in set_device_name
  (bsc#1012628).
- mfd: qcom-spmi-pmic: Fix reference leaks in revid helper
  (bsc#1012628).
- mfd: qcom-spmi-pmic: Fix revid implementation (bsc#1012628).
- ima: annotate iint mutex to avoid lockdep false positive
  warnings (bsc#1012628).
- ima: detect changes to the backing overlay file (bsc#1012628).
- netfilter: nf_tables: remove catchall element in GC sync path
  (bsc#1012628).
- netfilter: nf_tables: split async and sync catchall in two
  functions (bsc#1012628).
- selftests/resctrl: Fix uninitialized .sa_flags (bsc#1012628).
- selftests/resctrl: Remove duplicate feature check from CMT test
  (bsc#1012628).
- selftests/resctrl: Move _GNU_SOURCE define into Makefile
  (bsc#1012628).
- selftests/resctrl: Refactor feature check to use resource and
  feature name (bsc#1012628).
- selftests/resctrl: Fix feature checks (bsc#1012628).
- selftests/resctrl: Reduce failures due to outliers in MBA/MBM
  tests (bsc#1012628).
- hid: lenovo: Resend all settings on reset_resume for compact
  keyboards (bsc#1012628).
- ASoC: codecs: wsa-macro: fix uninitialized stack variables
  with name prefix (bsc#1012628).
- jbd2: fix potential data lost in recovering journal raced with
  synchronizing fs bdev (bsc#1012628).
- quota: explicitly forbid quota files from being encrypted
  (bsc#1012628).
- kernel/reboot: emergency_restart: Set correct system_state
  (bsc#1012628).
- scripts/gdb/vmalloc: disable on no-MMU (bsc#1012628).
- fs: use nth_page() in place of direct struct page manipulation
  (bsc#1012628).
- mips: use nth_page() in place of direct struct page manipulation
  (bsc#1012628).
- i2c: core: Run atomic i2c xfer when !preemptible (bsc#1012628).
- selftests/clone3: Fix broken test under !CONFIG_TIME_NS
  (bsc#1012628).
- tracing: Have the user copy of synthetic event address use
  correct context (bsc#1012628).
- driver core: Release all resources during unbind before updating
  device links (bsc#1012628).
- mcb: fix error handling for different scenarios when parsing
  (bsc#1012628).
- dmaengine: stm32-mdma: correct desc prep when channel running
  (bsc#1012628).
- s390/mm: add missing arch_set_page_dat() call to
  vmem_crst_alloc() (bsc#1012628).
- s390/mm: add missing arch_set_page_dat() call to gmap
  allocations (bsc#1012628).
- s390/cmma: fix detection of DAT pages (bsc#1012628).
- mm/cma: use nth_page() in place of direct struct page
  manipulation (bsc#1012628).
- mm/hugetlb: use nth_page() in place of direct struct page
  manipulation (bsc#1012628).
- mm/memory_hotplug: use pfn math in place of direct struct page
  manipulation (bsc#1012628).
- mm: make PR_MDWE_REFUSE_EXEC_GAIN an unsigned long
  (bsc#1012628).
- mtd: cfi_cmdset_0001: Byte swap OTP info (bsc#1012628).
- cxl/region: Do not try to cleanup after
  cxl_region_setup_targets() fails (bsc#1012628).
- i3c: master: cdns: Fix reading status register (bsc#1012628).
- i3c: master: svc: fix race condition in ibi work thread
  (bsc#1012628).
- i3c: master: svc: fix wrong data return when IBI happen during
  start frame (bsc#1012628).
- i3c: master: svc: fix ibi may not return mandatory data byte
  (bsc#1012628).
- i3c: master: svc: fix check wrong status register in irq handler
  (bsc#1012628).
- i3c: master: svc: fix SDA keep low when polling IBIWON timeout
  happen (bsc#1012628).
- i3c: master: svc: fix random hot join failure since timeout
  error (bsc#1012628).
- cxl/region: Fix x1 root-decoder granularity calculations
  (bsc#1012628).
- cxl/port: Fix delete_endpoint() vs parent unregistration race
  (bsc#1012628).
- apparmor: Fix kernel-doc warnings in apparmor/audit.c
  (bsc#1012628).
- apparmor: Fix kernel-doc warnings in apparmor/lib.c
  (bsc#1012628).
- apparmor: Fix kernel-doc warnings in apparmor/resource.c
  (bsc#1012628).
- apparmor: Fix kernel-doc warnings in apparmor/policy.c
  (bsc#1012628).
- apparmor: combine common_audit_data and apparmor_audit_data
  (bsc#1012628).
- apparmor: rename audit_data->label to audit_data->subj_label
  (bsc#1012628).
- apparmor: pass cred through to audit info (bsc#1012628).
- apparmor: Fix regression in mount mediation (bsc#1012628).
- Bluetooth: btusb: Add RTW8852BE device 13d3:3570 to device
  tables (bsc#1012628).
- Bluetooth: btusb: Add 0bda:b85b for Fn-Link RTL8852BE
  (bsc#1012628).
- drm/amd/display: enable dsc_clk even if dsc_pg disabled
  (bsc#1012628).
- torture: Make torture_hrtimeout_ns() take an hrtimer mode
  parameter (bsc#1012628).
- rcutorture: Fix stuttering races and other issues (bsc#1012628).
- selftests/resctrl: Remove bw_report and bm_type from main()
  (bsc#1012628).
- selftests/resctrl: Simplify span lifetime (bsc#1012628).
- selftests/resctrl: Make benchmark command const and build it
  with pointers (bsc#1012628).
- selftests/resctrl: Extend signal handler coverage to unmount
  on receiving signal (bsc#1012628).
- parisc: Prevent booting 64-bit kernels on PA1.x machines
  (bsc#1012628).
- parisc/pgtable: Do not drop upper 5 address bits of physical
  address (bsc#1012628).
- parisc/power: Fix power soft-off when running on qemu
  (bsc#1012628).
- parisc: fix mmap_base calculation when stack grows upwards
  (bsc#1012628).
- xhci: Enable RPM on controllers that support low-power states
  (bsc#1012628).
- smb3: fix creating FIFOs when mounting with "sfu" mount option
  (bsc#1012628).
- smb3: fix touch -h of symlink (bsc#1012628).
- smb3: allow dumping session and tcon id to improve stats
  analysis and debugging (bsc#1012628).
- smb3: fix caching of ctime on setxattr (bsc#1012628).
- smb: client: fix use-after-free bug in
  cifs_debug_data_proc_show() (bsc#1012628).
- smb: client: fix use-after-free in smb2_query_info_compound()
  (bsc#1012628).
- smb: client: fix potential deadlock when releasing mids
  (bsc#1012628).
- smb: client: fix mount when dns_resolver key is not available
  (bsc#1012628).
- cifs: reconnect helper should set reconnect for the right
  channel (bsc#1012628).
- cifs: force interface update before a fresh session setup
  (bsc#1012628).
- cifs: do not reset chan_max if multichannel is not supported
  at mount (bsc#1012628).
- cifs: do not pass cifs_sb when trying to add channels
  (bsc#1012628).
- cifs: Fix encryption of cleared, but unset rq_iter data buffers
  (bsc#1012628).
- xfs: recovery should not clear di_flushiter unconditionally
  (bsc#1012628).
- btrfs: zoned: wait for data BG to be finished on direct IO
  allocation (bsc#1012628).
- ALSA: info: Fix potential deadlock at disconnection
  (bsc#1012628).
- ALSA: hda/realtek: Enable Mute LED on HP 255 G8 (bsc#1012628).
- ALSA: hda/realtek - Add Dell ALC295 to pin fall back table
  (bsc#1012628).
- ALSA: hda/realtek - Enable internal speaker of ASUS K6500ZC
  (bsc#1012628).
- ALSA: hda/realtek: Enable Mute LED on HP 255 G10 (bsc#1012628).
- ALSA: hda/realtek: Add quirks for HP Laptops (bsc#1012628).
- Revert ncsi: Propagate carrier gain/loss events to the NCSI
  controller (bsc#1012628).
- Revert "i2c: pxa: move to generic GPIO recovery" (bsc#1012628).
- lsm: fix default return value for vm_enough_memory
  (bsc#1012628).
- lsm: fix default return value for inode_getsecctx (bsc#1012628).
- sbsa_gwdt: Calculate timeout with 64-bit math (bsc#1012628).
- i2c: designware: Disable TX_EMPTY irq while waiting for block
  length byte (bsc#1012628).
- s390/ap: fix AP bus crash on early config change callback
  invocation (bsc#1012628).
- net: ethtool: Fix documentation of ethtool_sprintf()
  (bsc#1012628).
- net: dsa: lan9303: consequently nested-lock physical MDIO
  (bsc#1012628).
- net: phylink: initialize carrier state at creation
  (bsc#1012628).
- gfs2: don't withdraw if init_threads() got interrupted
  (bsc#1012628).
- i2c: i801: fix potential race in
  i801_block_transaction_byte_by_byte (bsc#1012628).
- f2fs: do not return EFSCORRUPTED, but try to run online repair
  (bsc#1012628).
- f2fs: set the default compress_level on ioctl (bsc#1012628).
- f2fs: avoid format-overflow warning (bsc#1012628).
- f2fs: split initial and dynamic conditions for extent_cache
  (bsc#1012628).
- media: lirc: drop trailing space from scancode transmit
  (bsc#1012628).
- media: sharp: fix sharp encoding (bsc#1012628).
- media: venus: hfi_parser: Add check to keep the number of
  codecs within range (bsc#1012628).
- media: venus: hfi: fix the check to handle session buffer
  requirement (bsc#1012628).
- media: venus: hfi: add checks to handle capabilities from
  firmware (bsc#1012628).
- media: ccs: Correctly initialise try compose rectangle
  (bsc#1012628).
- drm/mediatek/dp: fix memory leak on ->get_edid callback audio
  detection (bsc#1012628).
- drm/mediatek/dp: fix memory leak on ->get_edid callback error
  path (bsc#1012628).
- dm-bufio: fix no-sleep mode (bsc#1012628).
- dm-verity: don't use blocking calls from tasklets (bsc#1012628).
- nfsd: fix file memleak on client_opens_release (bsc#1012628).
- NFSD: Update nfsd_cache_append() to use xdr_stream
  (bsc#1012628).
- LoongArch: Mark __percpu functions as always inline
  (bsc#1012628).
- tracing: fprobe-event: Fix to check tracepoint event and return
  (bsc#1012628).
- swiotlb: do not free decrypted pages if dynamic (bsc#1012628).
- swiotlb: fix out-of-bounds TLB allocations with
  CONFIG_SWIOTLB_DYNAMIC (bsc#1012628).
- riscv: Using TOOLCHAIN_HAS_ZIHINTPAUSE marco replace zihintpause
  (bsc#1012628).
- riscv: put interrupt entries into .irqentry.text (bsc#1012628).
- riscv: mm: Update the comment of CONFIG_PAGE_OFFSET
  (bsc#1012628).
- riscv: correct pt_level name via pgtable_l5/4_enabled
  (bsc#1012628).
- riscv: kprobes: allow writing to x0 (bsc#1012628).
- mmc: sdhci-pci-gli: A workaround to allow GL9750 to enter ASPM
  L1.2 (bsc#1012628).
- mm: fix for negative counter: nr_file_hugepages (bsc#1012628).
- mm: kmem: drop __GFP_NOFAIL when allocating objcg vectors
  (bsc#1012628).
- mptcp: deal with large GSO size (bsc#1012628).
- mptcp: add validity check for sending RM_ADDR (bsc#1012628).
- mptcp: fix setsockopt(IP_TOS) subflow locking (bsc#1012628).
- selftests: mptcp: fix fastclose with csum failure (bsc#1012628).
- r8169: fix network lost after resume on DASH systems
  (bsc#1012628).
- r8169: add handling DASH when DASH is disabled (bsc#1012628).
- mmc: sdhci-pci-gli: GL9750: Mask the replay timer timeout of
  AER (bsc#1012628).
- media: qcom: camss: Fix pm_domain_on sequence in probe
  (bsc#1012628).
- media: qcom: camss: Fix vfe_get() error jump (bsc#1012628).
- media: qcom: camss: Fix VFE-17x vfe_disable_output()
  (bsc#1012628).
- media: qcom: camss: Fix VFE-480 vfe_disable_output()
  (bsc#1012628).
- media: qcom: camss: Fix missing vfe_lite clocks check
  (bsc#1012628).
- media: qcom: camss: Fix set CSI2_RX_CFG1_VC_MODE when VC is
  greater than 3 (bsc#1012628).
- media: qcom: camss: Fix invalid clock enable bit disjunction
  (bsc#1012628).
- media: qcom: camss: Fix csid-gen2 for test pattern generator
  (bsc#1012628).
- Revert "HID: logitech-dj: Add support for a new lightspeed
  receiver iteration" (bsc#1012628).
- Revert "net: r8169: Disable multicast filter for RTL8168H and
  RTL8107E" (bsc#1012628).
- ext4: fix race between writepages and remount (bsc#1012628).
- ext4: no need to generate from free list in mballoc
  (bsc#1012628).
- ext4: make sure allocate pending entry not fail (bsc#1012628).
- ext4: apply umask if ACL support is disabled (bsc#1012628).
- ext4: correct offset of gdb backup in non meta_bg group to
  update_backups (bsc#1012628).
- ext4: mark buffer new if it is unwritten to avoid stale data
  exposure (bsc#1012628).
- ext4: correct return value of ext4_convert_meta_bg
  (bsc#1012628).
- ext4: correct the start block of counting reserved clusters
  (bsc#1012628).
- ext4: remove gdb backup copy for meta bg in
  setup_new_flex_group_blocks (bsc#1012628).
- ext4: add missed brelse in update_backups (bsc#1012628).
- ext4: properly sync file size update after O_SYNC direct IO
  (bsc#1012628).
- ext4: fix racy may inline data check in dio write (bsc#1012628).
- drm/amd/pm: Handle non-terminated overdrive commands
  (bsc#1012628).
- drm: bridge: it66121: ->get_edid callback must not return err
  pointers (bsc#1012628).
- x86/srso: Move retbleed IBPB check into existing 'has_microcode'
  code block (bsc#1012628).
- drm/amd/display: Add Null check for DPP resource (bsc#1012628).
- drm/i915/mtl: Support HBR3 rate with C10 phy and eDP in MTL
  (bsc#1012628).
- drm/i915: Bump GLK CDCLK frequency when driving multiple pipes
  (bsc#1012628).
- drm/i915: Fix potential spectre vulnerability (bsc#1012628).
- drm/i915: Flush WC GGTT only on required platforms
  (bsc#1012628).
- drm/amd/pm: Fix error of MACO flag setting code (bsc#1012628).
- drm/amdgpu/smu13: drop compute workload workaround
  (bsc#1012628).
- drm/amdgpu: don't use pci_is_thunderbolt_attached()
  (bsc#1012628).
- drm/amdgpu: fix GRBM read timeout when do mes_self_test
  (bsc#1012628).
- drm/amdgpu: add a retry for IP discovery init (bsc#1012628).
- drm/amdgpu: don't use ATRM for external devices (bsc#1012628).
- drm/amdgpu: fix error handling in amdgpu_vm_init (bsc#1012628).
- drm/amdgpu: fix error handling in amdgpu_bo_list_get()
  (bsc#1012628).
- drm/amdgpu: lower CS errors to debug severity (bsc#1012628).
- drm/amdgpu: Fix possible null pointer dereference (bsc#1012628).
- drm/amd/display: Guard against invalid RPTR/WPTR being set
  (bsc#1012628).
- drm/amd/display: Fix DSC not Enabled on Direct MST Sink
  (bsc#1012628).
- drm/amd/display: fix a NULL pointer dereference in
  amdgpu_dm_i2c_xfer() (bsc#1012628).
- drm/amd/display: Enable fast plane updates on DCN3.2 and above
  (bsc#1012628).
- drm/amd/display: Clear dpcd_sink_ext_caps if not set
  (bsc#1012628).
- drm/amd/display: Change the DMCUB mailbox memory location from
  FB to inbox (bsc#1012628).
- Refresh patches.suse/vfs-add-super_operations-get_inode_dev.
- Rename to
  patches.kernel.org/6.6.3-350-ASoC-soc-dai-add-flag-to-mute-and-unmute-stream.patch.
- Rename to
  patches.kernel.org/6.6.3-351-ASoC-codecs-wsa883x-make-use-of-new-mute_unmute.patch.
- commit d766c57
* Mon Nov 27 2023 duwe@suse.de
- rpm/mkspec-dtb: build DTBs for Sophgo based riscv64 systems.
  These are new in 6.7 and required for the Milk-V Pioneer.
- commit c86e052
* Mon Nov 27 2023 mkubecek@suse.cz
- Update to 6.7-rc3
- refresh configs
- commit e7296f9
* Fri Nov 24 2023 fcrozat@suse.com
- Ensure ia32_emulation is always enabled for kernel-obs-build
  If ia32_emulation is disabled by default, ensure it is enabled
  back for OBS kernel to allow building 32bit binaries (jsc#PED-3184)
  [ms: Always pass the parameter, no need to grep through the config which
  may not be very reliable]
- commit 56a2c2f
* Wed Nov 22 2023 tiwai@suse.de
- ASoC: codecs: wsa883x: make use of new mute_unmute_on_trigger
  flag (bsc#1217412).
- ASoC: soc-dai: add flag to mute and unmute stream during trigger
  (bsc#1217412).
- commit 1a298a3
* Wed Nov 22 2023 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_WSA883X=m for Thinkpad X13s audio (bsc#1217412)
- commit 9bf78b1
* Wed Nov 22 2023 msuchanek@suse.de
- rpm: Define git commit as macro
- commit bcc92c8
* Wed Nov 22 2023 msuchanek@suse.de
- kernel-source: Move provides after sources
- commit dbbf742
* Tue Nov 21 2023 tiwai@suse.de
- leds: class: Don't expose color sysfs entry (bsc#1217172).
- commit 1be1eb4
* Mon Nov 20 2023 tiwai@suse.de
- drm/i915: Also check for VGA converter in eDP probe
  (bsc#1217282).
- commit b22e785
* Mon Nov 20 2023 jslaby@suse.cz
- Linux 6.6.2 (bsc#1012628).
- hwmon: (nct6775) Fix incorrect variable reuse in fan_div
  calculation (bsc#1012628).
- numa: Generalize numa_map_to_online_node() (bsc#1012628).
- sched/topology: Fix sched_numa_find_nth_cpu() in CPU-less case
  (bsc#1012628).
- sched/topology: Fix sched_numa_find_nth_cpu() in non-NUMA case
  (bsc#1012628).
- sched/fair: Fix cfs_rq_is_decayed() on !SMP (bsc#1012628).
- iov_iter, x86: Be consistent about the __user tag on
  copy_mc_to_user() (bsc#1012628).
- sched/uclamp: Set max_spare_cap_cpu even if max_spare_cap is 0
  (bsc#1012628).
- sched/uclamp: Ignore (util == 0) optimization in feec() when
  p_util_max = 0 (bsc#1012628).
- objtool: Propagate early errors (bsc#1012628).
- sched: Fix stop_one_cpu_nowait() vs hotplug (bsc#1012628).
- nfsd: Handle EOPENSTALE correctly in the filecache
  (bsc#1012628).
- vfs: fix readahead(2) on block devices (bsc#1012628).
- writeback, cgroup: switch inodes with dirty timestamps to
  release dying cgwbs (bsc#1012628).
- x86/srso: Fix SBPB enablement for (possible) future fixed HW
  (bsc#1012628).
- x86/srso: Print mitigation for retbleed IBPB case (bsc#1012628).
- x86/srso: Fix vulnerability reporting for missing microcode
  (bsc#1012628).
- x86/srso: Fix unret validation dependencies (bsc#1012628).
- futex: Don't include process MM in futex key on no-MMU
  (bsc#1012628).
- x86/numa: Introduce numa_fill_memblks() (bsc#1012628).
- ACPI/NUMA: Apply SRAT proximity domain to entire CFMWS window
  (bsc#1012628).
- cgroup/cpuset: Fix load balance state in
  update_partition_sd_lb() (bsc#1012628).
- x86/sev-es: Allow copy_from_kernel_nofault() in earlier boot
  (bsc#1012628).
- x86/boot: Fix incorrect startup_gdt_descr.size (bsc#1012628).
- cpu/SMT: Make SMT control more robust against enumeration
  failures (bsc#1012628).
- x86/apic: Fake primary thread mask for XEN/PV (bsc#1012628).
- srcu: Fix callbacks acceleration mishandling (bsc#1012628).
- drivers/clocksource/timer-ti-dm: Don't call clk_get_rate()
  in stop function (bsc#1012628).
- x86/nmi: Fix out-of-order NMI nesting checks & false positive
  warning (bsc#1012628).
- pstore/platform: Add check for kstrdup (bsc#1012628).
- perf: Optimize perf_cgroup_switch() (bsc#1012628).
- selftests/x86/lam: Zero out buffer for readlink() (bsc#1012628).
- PCI/MSI: Provide stubs for IMS functions (bsc#1012628).
- string: Adjust strtomem() logic to allow for smaller sources
  (bsc#1012628).
- genirq/matrix: Exclude managed interrupts in
  irq_matrix_allocated() (bsc#1012628).
- irqchip/sifive-plic: Fix syscore registration for multi-socket
  systems (bsc#1012628).
- wifi: ath12k: fix undefined behavior with __fls in dp
  (bsc#1012628).
- wifi: cfg80211: add flush functions for wiphy work
  (bsc#1012628).
- wifi: mac80211: move radar detect work to wiphy work
  (bsc#1012628).
- wifi: mac80211: move scan work to wiphy work (bsc#1012628).
- wifi: mac80211: move offchannel works to wiphy work
  (bsc#1012628).
- wifi: mac80211: move sched-scan stop work to wiphy work
  (bsc#1012628).
- wifi: mac80211: fix RCU usage warning in mesh fast-xmit
  (bsc#1012628).
- wifi: cfg80211: fix off-by-one in element defrag (bsc#1012628).
- wifi: mac80211: fix # of MSDU in A-MSDU calculation
  (bsc#1012628).
- wifi: iwlwifi: honor the enable_ini value (bsc#1012628).
- wifi: iwlwifi: don't use an uninitialized variable
  (bsc#1012628).
- i40e: fix potential memory leaks in i40e_remove() (bsc#1012628).
- iavf: Fix promiscuous mode configuration flow messages
  (bsc#1012628).
- selftests/bpf: Correct map_fd to data_fd in tailcalls
  (bsc#1012628).
- bpf, x64: Fix tailcall infinite loop (bsc#1012628).
- wifi: cfg80211: fix kernel-doc for wiphy_delayed_work_flush()
  (bsc#1012628).
- udp: introduce udp->udp_flags (bsc#1012628).
- udp: move udp->no_check6_tx to udp->udp_flags (bsc#1012628).
- udp: move udp->no_check6_rx to udp->udp_flags (bsc#1012628).
- udp: move udp->gro_enabled to udp->udp_flags (bsc#1012628).
- udp: add missing WRITE_ONCE() around up->encap_rcv
  (bsc#1012628).
- udp: move udp->accept_udp_{l4|fraglist} to udp->udp_flags
  (bsc#1012628).
- udp: lockless UDP_ENCAP_L2TPINUDP / UDP_GRO (bsc#1012628).
- udp: annotate data-races around udp->encap_type (bsc#1012628).
- udplite: remove UDPLITE_BIT (bsc#1012628).
- udplite: fix various data-races (bsc#1012628).
- selftests/bpf: Skip module_fentry_shadow test when bpf_testmod
  is not available (bsc#1012628).
- tcp: call tcp_try_undo_recovery when an RTOd TFO SYNACK is ACKed
  (bsc#1012628).
- bpf: Fix kfunc callback register type handling (bsc#1012628).
- gve: Use size_add() in call to struct_size() (bsc#1012628).
- mlxsw: Use size_mul() in call to struct_size() (bsc#1012628).
- tls: Use size_add() in call to struct_size() (bsc#1012628).
- tipc: Use size_add() in calls to struct_size() (bsc#1012628).
- net: spider_net: Use size_add() in call to struct_size()
  (bsc#1012628).
- ice: fix pin assignment for E810-T without SMA control
  (bsc#1012628).
- net: ethernet: mtk_wed: fix EXT_INT_STATUS_RX_FBUF definitions
  for MT7986 SoC (bsc#1012628).
- wifi: rtw88: debug: Fix the NULL vs IS_ERR() bug for
  debugfs_create_file() (bsc#1012628).
- wifi: ath12k: fix DMA unmap warning on NULL DMA address
  (bsc#1012628).
- wifi: ath11k: fix boot failure with one MSI vector
  (bsc#1012628).
- wifi: mac80211: fix check for unusable RX result (bsc#1012628).
- PM: sleep: Fix symbol export for _SIMPLE_ variants of _PM_OPS()
  (bsc#1012628).
- cpufreq: tegra194: fix warning due to missing opp_put
  (bsc#1012628).
- wifi: mt76: mt7603: rework/fix rx pse hang check (bsc#1012628).
- wifi: mt76: mt7603: improve watchdog reset reliablity
  (bsc#1012628).
- wifi: mt76: mt7603: improve stuck beacon handling (bsc#1012628).
- wifi: mt76: remove unused error path in
  mt76_connac_tx_complete_skb (bsc#1012628).
- wifi: mt76: mt7996: set correct wcid in txp (bsc#1012628).
- wifi: mt76: mt7996: fix beamform mcu cmd configuration
  (bsc#1012628).
- wifi: mt76: mt7996: fix beamformee ss subfield in EHT PHY cap
  (bsc#1012628).
- wifi: mt76: mt7996: fix wmm queue mapping (bsc#1012628).
- wifi: mt76: mt7996: fix rx rate report for CBW320-2
  (bsc#1012628).
- wifi: mt76: mt7996: fix TWT command format (bsc#1012628).
- wifi: mt76: update beacon size limitation (bsc#1012628).
- wifi: mt76: fix potential memory leak of beacon commands
  (bsc#1012628).
- wifi: mt76: get rid of false alamrs of tx emission issues
  (bsc#1012628).
- wifi: mt76: fix per-band IEEE80211_CONF_MONITOR flag comparison
  (bsc#1012628).
- wifi: mt76: mt7915: fix beamforming availability check
  (bsc#1012628).
- wifi: mt76: move struct ieee80211_chanctx_conf up to struct
  mt76_vif (bsc#1012628).
- wifi: mt76: mt7921: fix the wrong rate pickup for the chanctx
  driver (bsc#1012628).
- wifi: mt76: mt7921: fix the wrong rate selected in fw for the
  chanctx driver (bsc#1012628).
- wifi: ath: dfs_pattern_detector: Fix a memory initialization
  issue (bsc#1012628).
- tcp_metrics: add missing barriers on delete (bsc#1012628).
- tcp_metrics: properly set tp->snd_ssthresh in tcp_init_metrics()
  (bsc#1012628).
- tcp_metrics: do not create an entry from tcp_init_metrics()
  (bsc#1012628).
- wifi: rtlwifi: fix EDCA limit set by BT coexistence
  (bsc#1012628).
- ACPI: property: Allow _DSD buffer data only for byte accessors
  (bsc#1012628).
- =?UTF-8?q?ACPI:=20video:=20Add=20acpi=5Fbacklight=3Dvendo?=
  =?UTF-8?q?r=20quirk=20for=20Toshiba=20Port=C3=A9g=C3=A9=20R100?=
  (bsc#1012628).
- can: etas_es58x: rework the version check logic to silence
  - Wformat-truncation (bsc#1012628).
- can: etas_es58x: add missing a blank line after declaration
  (bsc#1012628).
- libbpf: Fix syscall access arguments on riscv (bsc#1012628).
- selftests/bpf: Define SYS_PREFIX for riscv (bsc#1012628).
- selftests/bpf: Define SYS_NANOSLEEP_KPROBE_NAME for riscv
  (bsc#1012628).
- r8152: break the loop when the budget is exhausted
  (bsc#1012628).
- wifi: ath11k: fix Tx power value during active CAC
  (bsc#1012628).
- can: dev: can_restart(): don't crash kernel if carrier is OK
  (bsc#1012628).
- can: dev: can_restart(): fix race condition between controller
  restart and netif_carrier_on() (bsc#1012628).
- can: dev: can_put_echo_skb(): don't crash kernel if
  can_priv::echo_skb is accessed out of bounds (bsc#1012628).
- PM / devfreq: rockchip-dfi: Make pmu regmap mandatory
  (bsc#1012628).
- wifi: wfx: fix case where rates are out of order (bsc#1012628).
- netfilter: nf_tables: Drop pointless memset when dumping rules
  (bsc#1012628).
- virtio-net: fix mismatch of getting tx-frames (bsc#1012628).
- virtio-net: consistently save parameters for per-queue
  (bsc#1012628).
- virtio-net: fix per queue coalescing parameter setting
  (bsc#1012628).
- virtio-net: fix the vq coalescing setting for vq resize
  (bsc#1012628).
- wifi: rtw88: Remove duplicate NULL check before calling
  usb_kill/free_urb() (bsc#1012628).
- thermal: core: prevent potential string overflow (bsc#1012628).
- r8169: fix rare issue with broken rx after link-down on RTL8125
  (bsc#1012628).
- thermal/drivers/mediatek: Fix probe for THERMAL_V2
  (bsc#1012628).
- bpf: Fix missed rcu read lock in bpf_task_under_cgroup()
  (bsc#1012628).
- net: skb_find_text: Ignore patterns extending past 'to'
  (bsc#1012628).
- selftests/bpf: Make linked_list failure test more robust
  (bsc#1012628).
- thermal: core: Don't update trip points inside the hysteresis
  range (bsc#1012628).
- chtls: fix tp->rcv_tstamp initialization (bsc#1012628).
- tcp: fix cookie_init_timestamp() overflows (bsc#1012628).
- wifi: iwlwifi: mvm: update station's MFP flag after association
  (bsc#1012628).
- wifi: iwlwifi: mvm: fix removing pasn station for responder
  (bsc#1012628).
- wifi: iwlwifi: mvm: use correct sta ID for IGTK/BIGTK
  (bsc#1012628).
- wifi: mac80211: don't recreate driver link debugfs in reconfig
  (bsc#1012628).
- wifi: mac80211: Fix setting vif links (bsc#1012628).
- wifi: iwlwifi: yoyo: swap cdb and jacket bits values
  (bsc#1012628).
- wifi: iwlwifi: mvm: Correctly set link configuration
  (bsc#1012628).
- wifi: iwlwifi: mvm: Fix key flags for IGTK on AP interface
  (bsc#1012628).
- wifi: iwlwifi: mvm: Don't always bind/link the P2P Device
  interface (bsc#1012628).
- wifi: iwlwifi: mvm: change iwl_mvm_flush_sta() API
  (bsc#1012628).
- wifi: iwlwifi: mvm: fix iwl_mvm_mac_flush_sta() (bsc#1012628).
- wifi: iwlwifi: mvm: remove TDLS stations from FW (bsc#1012628).
- wifi: iwlwifi: increase number of RX buffers for EHT devices
  (bsc#1012628).
- wifi: iwlwifi: mvm: fix netif csum flags (bsc#1012628).
- wifi: iwlwifi: pcie: synchronize IRQs before NAPI (bsc#1012628).
- wifi: iwlwifi: mvm: update IGTK in mvmvif upon D3 resume
  (bsc#1012628).
- wifi: iwlwifi: empty overflow queue during flush (bsc#1012628).
- Bluetooth: ISO: Pass BIG encryption info through QoS
  (bsc#1012628).
- Bluetooth: Make handle of hci_conn be unique (bsc#1012628).
- Bluetooth: hci_sync: Fix Opcode prints in bt_dev_dbg/err
  (bsc#1012628).
- bpf: Fix unnecessary -EBUSY from htab_lock_bucket (bsc#1012628).
- ACPI: sysfs: Fix create_pnp_modalias() and create_of_modalias()
  (bsc#1012628).
- mptcp: properly account fastopen data (bsc#1012628).
- ipv6: avoid atomic fragment on GSO packets (bsc#1012628).
- virtio_net: use u64_stats_t infra to avoid data-races
  (bsc#1012628).
- net: add DEV_STATS_READ() helper (bsc#1012628).
- ipvlan: properly track tx_errors (bsc#1012628).
- regmap: debugfs: Fix a erroneous check after snprintf()
  (bsc#1012628).
- spi: tegra: Fix missing IRQ check in tegra_slink_probe()
  (bsc#1012628).
- clk: qcom: ipq5332: Drop set rate parent from gpll0 dependent
  clocks (bsc#1012628).
- clk: qcom: gcc-msm8996: Remove RPM bus clocks (bsc#1012628).
- clk: qcom: clk-rcg2: Fix clock rate overflow for high parent
  frequencies (bsc#1012628).
- clk: qcom: mmcc-msm8998: Don't check halt bit on some branch
  clks (bsc#1012628).
- clk: qcom: mmcc-msm8998: Fix the SMMU GDSC (bsc#1012628).
- clk: qcom: gcc-sm8150: Fix gcc_sdcc2_apps_clk_src (bsc#1012628).
- gpio: sim: initialize a managed pointer when declaring it
  (bsc#1012628).
- regulator: mt6358: Fail probe on unknown chip ID (bsc#1012628).
- clk: imx: Select MXC_CLK for CLK_IMX8QXP (bsc#1012628).
- clk: imx: imx8: Fix an error handling path in
  clk_imx_acm_attach_pm_domains() (bsc#1012628).
- clk: imx: imx8: Fix an error handling path if
  devm_clk_hw_register_mux_parent_data_table() fails
  (bsc#1012628).
- clk: imx: imx8: Fix an error handling path in
  imx8_acm_clk_probe() (bsc#1012628).
- clk: imx: imx8mq: correct error handling path (bsc#1012628).
- clk: imx: imx8qxp: Fix elcdif_pll clock (bsc#1012628).
- clk: renesas: rcar-gen3: Extend SDnH divider table
  (bsc#1012628).
- clk: renesas: rzg2l: Wait for status bit of SD mux before
  continuing (bsc#1012628).
- clk: renesas: rzg2l: Lock around writes to mux register
  (bsc#1012628).
- clk: renesas: rzg2l: Trust value returned by hardware
  (bsc#1012628).
- clk: renesas: rzg2l: Use FIELD_GET() for PLL register fields
  (bsc#1012628).
- clk: renesas: rzg2l: Fix computation formula (bsc#1012628).
- clk: linux/clk-provider.h: fix kernel-doc warnings and typos
  (bsc#1012628).
- spi: nxp-fspi: use the correct ioremap function (bsc#1012628).
- clk: ralink: mtmips: quiet unused variable warning
  (bsc#1012628).
- clk: keystone: pll: fix a couple NULL vs IS_ERR() checks
  (bsc#1012628).
- clk: ti: fix double free in of_ti_divider_clk_setup()
  (bsc#1012628).
- clk: npcm7xx: Fix incorrect kfree (bsc#1012628).
- clk: mediatek: clk-mt6765: Add check for mtk_alloc_clk_data
  (bsc#1012628).
- clk: mediatek: clk-mt6779: Add check for mtk_alloc_clk_data
  (bsc#1012628).
- clk: mediatek: clk-mt6797: Add check for mtk_alloc_clk_data
  (bsc#1012628).
- clk: mediatek: clk-mt7629-eth: Add check for mtk_alloc_clk_data
  (bsc#1012628).
- clk: mediatek: clk-mt7629: Add check for mtk_alloc_clk_data
  (bsc#1012628).
- clk: mediatek: clk-mt2701: Add check for mtk_alloc_clk_data
  (bsc#1012628).
- clk: qcom: config IPQ_APSS_6018 should depend on QCOM_SMEM
  (bsc#1012628).
- clk: qcom: clk-alpha-pll: introduce stromer plus ops
  (bsc#1012628).
- clk: qcom: apss-ipq-pll: Use stromer plus ops for stromer plus
  pll (bsc#1012628).
- clk: qcom: apss-ipq-pll: Fix 'l' value for ipq5332_pll_config
  (bsc#1012628).
- clk: qcom: ipq5018: drop the CLK_SET_RATE_PARENT flag from
  GPLL clocks (bsc#1012628).
- clk: qcom: ipq9574: drop the CLK_SET_RATE_PARENT flag from
  GPLL clocks (bsc#1012628).
- clk: qcom: ipq5332: drop the CLK_SET_RATE_PARENT flag from
  GPLL clocks (bsc#1012628).
- clk: mediatek: fix double free in mtk_clk_register_pllfh()
  (bsc#1012628).
- platform/x86: wmi: Fix probe failure when failing to register
  WMI devices (bsc#1012628).
- platform/x86: wmi: Fix opening of char device (bsc#1012628).
- regulator: qcom-rpmh: Fix smps4 regulator for pm8550ve
  (bsc#1012628).
- hwmon: (axi-fan-control) Fix possible NULL pointer dereference
  (bsc#1012628).
- hwmon: (coretemp) Fix potentially truncated sysfs attribute name
  (bsc#1012628).
- Revert "hwmon: (sch56xx-common) Add DMI override table"
  (bsc#1012628).
- Revert "hwmon: (sch56xx-common) Add automatic module loading
  on supported devices" (bsc#1012628).
- hwmon: (pmbus/mp2975) Move PGOOD fix (bsc#1012628).
- hwmon: (sch5627) Use bit macros when accessing the control
  register (bsc#1012628).
- hwmon: (sch5627) Disallow write access if virtual registers
  are locked (bsc#1012628).
- hte: tegra: Fix missing error code in tegra_hte_test_probe()
  (bsc#1012628).
- platform/chrome: cros_ec_lpc: Separate host command and irq
  disable (bsc#1012628).
- spi: omap2-mcspi: switch to use modern name (bsc#1012628).
- spi: omap2-mcspi: Fix hardcoded reference clock (bsc#1012628).
- drm: bridge: samsung-dsim: Initialize ULPS EXIT for i.MX8M DSIM
  (bsc#1012628).
- drm: bridge: for GENERIC_PHY_MIPI_DPHY also select GENERIC_PHY
  (bsc#1012628).
- drm: bridge: samsung-dsim: Fix waiting for empty cmd transfer
  FIFO on older Exynos (bsc#1012628).
- drm/loongson: Fix error handling in lsdc_pixel_pll_setup()
  (bsc#1012628).
- drm/rockchip: vop: Fix reset of state in duplicate state crtc
  funcs (bsc#1012628).
- drm/rockchip: vop: Fix call to crtc reset helper (bsc#1012628).
- drm/rockchip: vop2: Don't crash for invalid duplicate_state
  (bsc#1012628).
- drm/rockchip: vop2: Add missing call to crtc reset helper
  (bsc#1012628).
- drm/radeon: possible buffer overflow (bsc#1012628).
- drm/radeon: Remove the references of radeon_gem_ pread &
  pwrite ioctls (bsc#1012628).
- drm: bridge: it66121: Fix invalid connector dereference
  (bsc#1012628).
- drm/bridge: lt8912b: Fix bridge_detach (bsc#1012628).
- drm/bridge: lt8912b: Fix crash on bridge detach (bsc#1012628).
- drm/bridge: lt8912b: Manually disable HPD only if it was enabled
  (bsc#1012628).
- drm/bridge: lt8912b: Add missing drm_bridge_attach call
  (bsc#1012628).
- drm/ssd130x: Fix screen clearing (bsc#1012628).
- drm/mediatek: Fix coverity issue with unintentional integer
  overflow (bsc#1012628).
- x86/tdx: Zero out the missing RSI in TDX_HYPERCALL macro
  (bsc#1012628).
- drm/bridge: tc358768: Fix use of uninitialized variable
  (bsc#1012628).
- drm/bridge: tc358768: Fix bit updates (bsc#1012628).
- drm/bridge: tc358768: Use struct videomode (bsc#1012628).
- drm/bridge: tc358768: Print logical values, not raw register
  values (bsc#1012628).
- drm/bridge: tc358768: Use dev for dbg prints, not priv->dev
  (bsc#1012628).
- drm/bridge: tc358768: Rename dsibclk to hsbyteclk (bsc#1012628).
- drm/bridge: tc358768: Clean up clock period code (bsc#1012628).
- drm/bridge: tc358768: Fix tc358768_ns_to_cnt() (bsc#1012628).
- drm: Call drm_atomic_helper_shutdown() at shutdown/remove time
  for misc drivers (bsc#1012628).
- drm/amdgpu: Increase IH soft ring size for GFX v9.4.3 dGPU
  (bsc#1012628).
- drm/amdkfd: fix some race conditions in vram buffer alloc/free
  of svm code (bsc#1012628).
- drm/amdkfd: Remove svm range validated_once flag (bsc#1012628).
- drm/amdkfd: Handle errors from svm validate and map
  (bsc#1012628).
- drm/amd/display: Fix null pointer dereference in error message
  (bsc#1012628).
- drm/amd/display: Check all enabled planes in
  dm_check_crtc_cursor (bsc#1012628).
- drm/amd/display: Refactor dm_get_plane_scale helper
  (bsc#1012628).
- drm/amd/display: Bail from dm_check_crtc_cursor if no relevant
  change (bsc#1012628).
- io_uring/kbuf: Fix check of BID wrapping in provided buffers
  (bsc#1012628).
- io_uring/kbuf: Allow the full buffer id space for provided
  buffers (bsc#1012628).
- drm/mediatek: Add mmsys_dev_num to mt8188 vdosys0 driver data
  (bsc#1012628).
- drm/mediatek: Fix iommu fault by swapping FBs after updating
  plane state (bsc#1012628).
- drm/mediatek: Fix iommu fault during crtc enabling
  (bsc#1012628).
- accel/habanalabs/gaudi2: Fix incorrect string length computation
  in gaudi2_psoc_razwi_get_engines() (bsc#1012628).
- drm/msm/adreno: Fix SM6375 GPU ID (bsc#1012628).
- drm/msm/a6xx: Fix unknown speedbin case (bsc#1012628).
- drm/rockchip: cdn-dp: Fix some error handling paths in
  cdn_dp_probe() (bsc#1012628).
- gpu: host1x: Correct allocated size for contexts (bsc#1012628).
- drm/bridge: lt9611uxc: fix the race in the error path
  (bsc#1012628).
- arm64/arm: xen: enlighten: Fix KPTI checks (bsc#1012628).
- drm/rockchip: Fix type promotion bug in rockchip_gem_iommu_map()
  (bsc#1012628).
- xenbus: fix error exit in xenbus_init() (bsc#1012628).
- xen: Make struct privcmd_irqfd's layout architecture independent
  (bsc#1012628).
- xen: irqfd: Use _IOW instead of the internal _IOC() macro
  (bsc#1012628).
- xen-pciback: Consider INTx disabled when MSI/MSI-X is enabled
  (bsc#1012628).
- drm/msm/dsi: use msm_gem_kernel_put to free TX buffer
  (bsc#1012628).
- drm/msm/dsi: free TX buffer in unbind (bsc#1012628).
- clocksource/drivers/arm_arch_timer: limit XGene-1 workaround
  (bsc#1012628).
- drm: mediatek: mtk_dsi: Fix NO_EOT_PACKET settings/handling
  (bsc#1012628).
- drivers/perf: hisi: use cpuhp_state_remove_instance_nocalls()
  for hisi_hns3_pmu uninit process (bsc#1012628).
- drm/amd/pm: Fix a memory leak on an error path (bsc#1012628).
- perf/arm-cmn: Fix DTC domain detection (bsc#1012628).
- drivers/perf: hisi_pcie: Check the type first in
  pmu::event_init() (bsc#1012628).
- perf: hisi: Fix use-after-free when register pmu fails
  (bsc#1012628).
- ARM: dts: renesas: blanche: Fix typo in GP_11_2 pin name
  (bsc#1012628).
- arm64: dts: qcom: sdm845: Fix PSCI power domain names
  (bsc#1012628).
- arm64: dts: qcom: sdm845: cheza doesn't support LMh node
  (bsc#1012628).
- arm64: dts: qcom: sc7280: link
  usb3_phy_wrapper_gcc_usb30_pipe_clk (bsc#1012628).
- arm64: dts: qcom: msm8916: Fix iommu local address range
  (bsc#1012628).
- arm64: dts: qcom: msm8992-libra: drop duplicated reserved memory
  (bsc#1012628).
- arm64: dts: qcom: sm6125: Pad APPS IOMMU address to 8 characters
  (bsc#1012628).
- arm64: dts: qcom: sc7280: Add missing LMH interrupts
  (bsc#1012628).
- arm64: dts: qcom: qrb2210-rb1: Swap UART index (bsc#1012628).
- arm64: dts: qcom: qrb2210-rb1: Fix regulators (bsc#1012628).
- arm64: dts: qcom: sdm670: Fix pdc mapping (bsc#1012628).
- arm64: dts: qcom: sc7280: drop incorrect EUD port on SoC side
  (bsc#1012628).
- arm64: dts: qcom: sm8150: add ref clock to PCIe PHYs
  (bsc#1012628).
- arm64: dts: qcom: sm8350: fix pinctrl for UART18 (bsc#1012628).
- arm64: dts: qcom: sdm845-mtp: fix WiFi configuration
  (bsc#1012628).
- arm64: dts: qcom: sdx75-idp: align RPMh regulator nodes with
  bindings (bsc#1012628).
- ARM64: dts: marvell: cn9310: Use appropriate label for spi1 pins
  (bsc#1012628).
- arm64: dts: qcom: msm8976: Fix ipc bit shifts (bsc#1012628).
- arm64: dts: qcom: msm8939: Fix iommu local address range
  (bsc#1012628).
- riscv: dts: allwinner: remove address-cells from intc node
  (bsc#1012628).
- arm64: dts: qcom: apq8016-sbc: Add missing ADV7533 regulators
  (bsc#1012628).
- ARM: dts: qcom: apq8026-samsung-matisse-wifi: Fix inverted
  hall sensor (bsc#1012628).
- ARM: dts: qcom: mdm9615: populate vsdcc fixed regulator
  (bsc#1012628).
- soc: qcom: llcc: Handle a second device without data corruption
  (bsc#1012628).
- kunit: Fix missed memory release in kunit_free_suite_set()
  (bsc#1012628).
- kunit: Fix the wrong kfree of copy for kunit_filter_suites()
  (bsc#1012628).
- kunit: Fix possible memory leak in kunit_filter_suites()
  (bsc#1012628).
- kunit: test: Fix the possible memory leak in executor_test
  (bsc#1012628).
- ARM: dts: stm32: stm32f7-pinctrl: don't use multiple blank lines
  (bsc#1012628).
- firmware: ti_sci: Mark driver as non removable (bsc#1012628).
- arm64: dts: ti: k3-j721s2-evm-gesi: Specify base dtb for
  overlay file (bsc#1012628).
- arm64: dts: ti: verdin-am62: disable MIPI DSI bridge
  (bsc#1012628).
- arm64: dts: ti: k3-am625-beagleplay: Fix typo in ramoops reg
  (bsc#1012628).
- arm64: dts: ti: k3-am62a7-sk: Drop i2c-1 to 100Khz
  (bsc#1012628).
- arm64: dts: ti: Fix HDMI Audio overlay in Makefile
  (bsc#1012628).
- firmware: arm_ffa: Assign the missing IDR allocation ID to
  the FFA device (bsc#1012628).
- firmware: arm_ffa: Allow the FF-A drivers to use 32bit mode
  of messaging (bsc#1012628).
- ARM: dts: am3517-evm: Fix LED3/4 pinmux (bsc#1012628).
- clk: scmi: Free scmi_clk allocated when the clocks with invalid
  info are skipped (bsc#1012628).
- arm64: dts: imx8qm-ss-img: Fix jpegenc compatible entry
  (bsc#1012628).
- arm64: dts: imx8mp-debix-model-a: Remove USB hub reset-gpios
  (bsc#1012628).
- arm64: dts: imx8mm: Add sound-dai-cells to micfil node
  (bsc#1012628).
- arm64: dts: imx8mn: Add sound-dai-cells to micfil node
  (bsc#1012628).
- arm64: tegra: Fix P3767 card detect polarity (bsc#1012628).
- arm64: tegra: Fix P3767 QSPI speed (bsc#1012628).
- firmware: tegra: Add suspend hook and reset BPMP IPC early on
  resume (bsc#1012628).
- memory: tegra: Set BPMP msg flags to reset IPC channels
  (bsc#1012628).
- arm64: tegra: Use correct interrupts for Tegra234 TKE
  (bsc#1012628).
- selftests/pidfd: Fix ksft print formats (bsc#1012628).
- selftests/resctrl: Ensure the benchmark commands fits to its
  array (bsc#1012628).
- soc: qcom: pmic_glink: fix connector type to be DisplayPort
  (bsc#1012628).
- ARM: dts: BCM5301X: Explicitly disable unused switch CPU ports
  (bsc#1012628).
- iommufd: Add iopt_area_alloc() (bsc#1012628).
- module/decompress: use vmalloc() for gzip decompression
  workspace (bsc#1012628).
- KEYS: Include linux/errno.h in linux/verification.h
  (bsc#1012628).
- crypto: ccp - Get a free page to use while fetching initial
  nonce (bsc#1012628).
- crypto: ccp - Fix ioctl unit tests (bsc#1012628).
- crypto: ccp - Fix DBC sample application error handling
  (bsc#1012628).
- crypto: ccp - Fix sample application signature passing
  (bsc#1012628).
- crypto: ccp - Fix some unfused tests (bsc#1012628).
- crypto: hisilicon/hpre - Fix a erroneous check after snprintf()
  (bsc#1012628).
- hwrng: bcm2835 - Fix hwrng throughput regression (bsc#1012628).
- hwrng: geode - fix accessing registers (bsc#1012628).
- RDMA/core: Use size_{add,sub,mul}() in calls to struct_size()
  (bsc#1012628).
- crypto: qat - fix state machines cleanup paths (bsc#1012628).
- crypto: qat - ignore subsequent state up commands (bsc#1012628).
- crypto: qat - fix unregistration of crypto algorithms
  (bsc#1012628).
- crypto: qat - fix unregistration of compression algorithms
  (bsc#1012628).
- scsi: ibmvfc: Fix erroneous use of rtas_busy_delay with hcall
  return code (bsc#1012628).
- ASoC: soc-pcm.c: Make sure DAI parameters cleared if the DAI
  becomes inactive (bsc#1012628).
- libnvdimm/of_pmem: Use devm_kstrdup instead of kstrdup and
  check its return value (bsc#1012628).
- nd_btt: Make BTT lanes preemptible (bsc#1012628).
- crypto: caam/qi2 - fix Chacha20 + Poly1305 self test failure
  (bsc#1012628).
- crypto: caam/jr - fix Chacha20 + Poly1305 self test failure
  (bsc#1012628).
- crypto: qat - increase size of buffers (bsc#1012628).
- ASoC: SOF: ipc4-topology: Use size_add() in call to
  struct_size() (bsc#1012628).
- PCI: vmd: Correct PCI Header Type Register's multi-function
  check (bsc#1012628).
- hid: cp2112: Fix duplicate workqueue initialization
  (bsc#1012628).
- crypto: hisilicon/qm - fix PF queue parameter issue
  (bsc#1012628).
- ARM: 9321/1: memset: cast the constant byte to unsigned char
  (bsc#1012628).
- ARM: 9323/1: mm: Fix ARCH_LOW_ADDRESS_LIMIT when CONFIG_ZONE_DMA
  (bsc#1012628).
- ext4: add missing initialization of call_notify_error in
  update_super_work() (bsc#1012628).
- ext4: move 'ix' sanity check to corrent position (bsc#1012628).
- kselftest: vm: fix mdwe's mmap_FIXED test case (bsc#1012628).
- ASoC: fsl: mpc5200_dma.c: Fix warning of Function parameter
  or member not described (bsc#1012628).
- backlight: pwm_bl: Disable PWM on shutdown, suspend and remove
  (bsc#1012628).
- ASoC: Intel: sof_sdw_rt_sdca_jack_common: add rt713 support
  (bsc#1012628).
- ASoC: fsl-asoc-card: Add comment for mclk in the codec_priv
  (bsc#1012628).
- fs: dlm: Fix the size of a buffer in dlm_create_debug_file()
  (bsc#1012628).
- dlm: fix creating multiple node structures (bsc#1012628).
- dlm: fix remove member after close call (bsc#1012628).
- dlm: be sure we reset all nodes at forced shutdown
  (bsc#1012628).
- dlm: fix no ack after final message (bsc#1012628).
- IB/mlx5: Fix rdma counter binding for RAW QP (bsc#1012628).
- RDMA/hns: Fix printing level of asynchronous events
  (bsc#1012628).
- RDMA/hns: Fix uninitialized ucmd in hns_roce_create_qp_common()
  (bsc#1012628).
- RDMA/hns: Fix signed-unsigned mixed comparisons (bsc#1012628).
- RDMA/hns: Add check for SL (bsc#1012628).
- RDMA/hns: The UD mode can only be configured with DCQCN
  (bsc#1012628).
- RDMA/hns: Fix unnecessary port_num transition in HW stats
  allocation (bsc#1012628).
- RDMA/hns: Fix init failure of RoCE VF and HIP08 (bsc#1012628).
- ASoC: SOF: core: Ensure sof_ops_free() is still called when
  probe never ran (bsc#1012628).
- ASoC: intel: sof_sdw: Stop processing CODECs when enough are
  found (bsc#1012628).
- ASoC: fsl: Fix PM disable depth imbalance in fsl_easrc_probe
  (bsc#1012628).
- scsi: ufs: core: Leave space for '\0' in utf8 desc string
  (bsc#1012628).
- RDMA/hfi1: Workaround truncation compilation error
  (bsc#1012628).
- hid: cp2112: Fix IRQ shutdown stopping polling for all IRQs
  on chip (bsc#1012628).
- HID: uclogic: Fix user-memory-access bug in
  uclogic_params_ugee_v2_init_event_hooks() (bsc#1012628).
- HID: uclogic: Fix a work->entry not empty bug in __queue_work()
  (bsc#1012628).
- sh: bios: Revive earlyprintk support (bsc#1012628).
- HID: logitech-hidpp: Don't restart IO, instead defer
  hid_connect() only (bsc#1012628).
- HID: logitech-hidpp: Revert "Don't restart communication if
  not necessary" (bsc#1012628).
- HID: logitech-hidpp: Move get_wireless_feature_index() check
  to hidpp_connect_event() (bsc#1012628).
- ASoC: Intel: Skylake: Fix mem leak when parsing UUIDs fails
  (bsc#1012628).
- PCI: endpoint: Fix double free in __pci_epc_create()
  (bsc#1012628).
- padata: Fix refcnt handling in padata_free_shell()
  (bsc#1012628).
- certs: Break circular dependency when selftest is modular
  (bsc#1012628).
- crypto: qat - consolidate services structure (bsc#1012628).
- crypto: qat - enable dc chaining service (bsc#1012628).
- crypto: qat - refactor fw config related functions
  (bsc#1012628).
- crypto: qat - use masks for AE groups (bsc#1012628).
- crypto: qat - fix ring to service map for QAT GEN4
  (bsc#1012628).
- crypto: qat - fix deadlock in backlog processing (bsc#1012628).
- ASoC: ams-delta.c: use component after check (bsc#1012628).
- erofs: fix erofs_insert_workgroup() lockref usage (bsc#1012628).
- IB/mlx5: Fix init stage error handling to avoid double free
  of same QP and UAF (bsc#1012628).
- mfd: core: Un-constify mfd_cell.of_reg (bsc#1012628).
- mfd: core: Ensure disabled devices are skipped without aborting
  (bsc#1012628).
- mfd: dln2: Fix double put in dln2_probe (bsc#1012628).
- dt-bindings: mfd: mt6397: Split out compatible for MediaTek
  MT6366 PMIC (bsc#1012628).
- mfd: arizona-spi: Set pdata.hpdet_channel for ACPI enumerated
  devs (bsc#1012628).
- leds: turris-omnia: Do not use SMBUS calls (bsc#1012628).
- leds: pwm: Don't disable the PWM when the LED should be off
  (bsc#1012628).
- leds: trigger: ledtrig-cpu:: Fix 'output may be truncated'
  issue for 'cpu' (bsc#1012628).
- scripts/gdb: fix usage of MOD_TEXT not defined when
  CONFIG_MODULES=n (bsc#1012628).
- apparmor: fix invalid reference on profile->disconnected
  (bsc#1012628).
- perf stat: Fix aggr mode initialization (bsc#1012628).
- iio: frequency: adf4350: Use device managed functions and fix
  power down issue (bsc#1012628).
- pinctrl: baytrail: fix debounce disable case (bsc#1012628).
- perf kwork: Fix incorrect and missing free atom in
  work_push_atom() (bsc#1012628).
- perf kwork: Add the supported subcommands to the document
  (bsc#1012628).
- perf kwork: Set ordered_events to true in 'struct perf_tool'
  (bsc#1012628).
- f2fs: compress: fix deadloop in f2fs_write_cache_pages()
  (bsc#1012628).
- f2fs: compress: fix to avoid use-after-free on dic
  (bsc#1012628).
- f2fs: compress: fix to avoid redundant compress extension
  (bsc#1012628).
- f2fs: fix to drop meta_inode's page cache in f2fs_put_super()
  (bsc#1012628).
- tty: tty_jobctrl: fix pid memleak in disassociate_ctty()
  (bsc#1012628).
- perf parse-events: Fix tracepoint name memory leak
  (bsc#1012628).
- livepatch: Fix missing newline character in
  klp_resolve_symbols() (bsc#1012628).
- pinctrl: renesas: rzg2l: Make reverse order of enable() for
  disable() (bsc#1012628).
- perf vendor events arm64: Fix for AmpereOne metrics
  (bsc#1012628).
- perf record: Fix BTF type checks in the off-cpu profiling
  (bsc#1012628).
- dmaengine: idxd: Register dsa_bus_type before registering idxd
  sub-drivers (bsc#1012628).
- usb: dwc2: fix possible NULL pointer dereference caused by
  driver concurrency (bsc#1012628).
- usb: chipidea: Fix DMA overwrite for Tegra (bsc#1012628).
- usb: chipidea: Simplify Tegra DMA alignment code (bsc#1012628).
- dmaengine: ti: edma: handle irq_of_parse_and_map() errors
  (bsc#1012628).
- tools/perf: Update call stack check in builtin-lock.c
  (bsc#1012628).
- misc: st_core: Do not call kfree_skb() under spin_lock_irqsave()
  (bsc#1012628).
- debugfs: Fix __rcu type comparison warning (bsc#1012628).
- tools: iio: iio_generic_buffer ensure alignment (bsc#1012628).
- USB: usbip: fix stub_dev hub disconnect (bsc#1012628).
- dmaengine: pxa_dma: Remove an erroneous BUG_ON() in
  pxad_free_desc() (bsc#1012628).
- f2fs: fix to initialize map.m_pblk in f2fs_precache_extents()
  (bsc#1012628).
- interconnect: qcom: qdu1000: Set ACV enable_mask (bsc#1012628).
- interconnect: qcom: sc7180: Set ACV enable_mask (bsc#1012628).
- interconnect: qcom: sc7280: Set ACV enable_mask (bsc#1012628).
- interconnect: qcom: sc8180x: Set ACV enable_mask (bsc#1012628).
- interconnect: qcom: sc8280xp: Set ACV enable_mask (bsc#1012628).
- interconnect: qcom: sdm670: Set ACV enable_mask (bsc#1012628).
- interconnect: qcom: sdm845: Set ACV enable_mask (bsc#1012628).
- interconnect: qcom: sm6350: Set ACV enable_mask (bsc#1012628).
- interconnect: qcom: sm8150: Set ACV enable_mask (bsc#1012628).
- interconnect: qcom: sm8250: Set ACV enable_mask (bsc#1012628).
- interconnect: qcom: sm8350: Set ACV enable_mask (bsc#1012628).
- interconnect: qcom: osm-l3: Replace custom implementation of
  COUNT_ARGS() (bsc#1012628).
- powerpc: Only define __parse_fpscr() when required
  (bsc#1012628).
- interconnect: fix error handling in qnoc_probe() (bsc#1012628).
- perf build: Add missing comment about NO_LIBTRACEEVENT=1
  (bsc#1012628).
- perf parse-events: Fix for term values that are raw events
  (bsc#1012628).
- perf mem-events: Avoid uninitialized read (bsc#1012628).
- s390/ap: re-init AP queues on config on (bsc#1012628).
- modpost: fix tee MODULE_DEVICE_TABLE built on big-endian host
  (bsc#1012628).
- modpost: fix ishtp MODULE_DEVICE_TABLE built on big-endian host
  (bsc#1012628).
- perf tools: Do not ignore the default vmlinux.h (bsc#1012628).
- powerpc/40x: Remove stale PTE_ATOMIC_UPDATES macro
  (bsc#1012628).
- powerpc/xive: Fix endian conversion size (bsc#1012628).
- powerpc: Hide empty pt_regs at base of the stack (bsc#1012628).
- perf trace: Use the right bpf_probe_read(_str) variant for
  reading user data (bsc#1012628).
- powerpc/vas: Limit open window failure messages in log bufffer
  (bsc#1012628).
- powerpc/imc-pmu: Use the correct spinlock initializer
  (bsc#1012628).
- powerpc/pseries: fix potential memory leak in
  init_cpu_associativity() (bsc#1012628).
- perf vendor events: Update PMC used in PM_RUN_INST_CMPL event
  for power10 platform (bsc#1012628).
- xhci: Loosen RPM as default policy to cover for AMD xHC 1.1
  (bsc#1012628).
- usb: host: xhci-plat: fix possible kernel oops while resuming
  (bsc#1012628).
- powerpc/vmcore: Add MMU information to vmcoreinfo (bsc#1012628).
- perf machine: Avoid out of bounds LBR memory read (bsc#1012628).
- libperf rc_check: Make implicit enabling work for GCC
  (bsc#1012628).
- perf hist: Add missing puts to hist__account_cycles
  (bsc#1012628).
- perf vendor events intel: Fix broadwellde
  tma_info_system_dram_bw_use metric (bsc#1012628).
- perf vendor events intel: Add broadwellde two metrics
  (bsc#1012628).
- 9p/net: fix possible memory leak in p9_check_errors()
  (bsc#1012628).
- rtla: Fix uninitialized variable found (bsc#1012628).
- i3c: Fix potential refcount leak in
  i3c_master_register_new_i3c_devs (bsc#1012628).
- rtc: brcmstb-waketimer: support level alarm_irq (bsc#1012628).
- cxl/pci: Remove unnecessary device reference management in
  sanitize work (bsc#1012628).
- cxl/pci: Cleanup 'sanitize' to always poll (bsc#1012628).
- cxl/pci: Remove inconsistent usage of dev_err_probe()
  (bsc#1012628).
- cxl/pci: Clarify devm host for memdev relative setup
  (bsc#1012628).
- cxl/pci: Fix sanitize notifier setup (bsc#1012628).
- cxl/memdev: Fix sanitize vs decoder setup locking (bsc#1012628).
- cxl/mem: Fix shutdown order (bsc#1012628).
- virt: sevguest: Fix passing a stack buffer as a scatterlist
  target (bsc#1012628).
- rtc: pcf85363: fix wrong mask/val parameters in
  regmap_update_bits call (bsc#1012628).
- cxl/region: Prepare the decoder match range helper for reuse
  (bsc#1012628).
- cxl/region: Calculate a target position in a region interleave
  (bsc#1012628).
- cxl/region: Use cxl_calc_interleave_pos() for auto-discovery
  (bsc#1012628).
- cxl/region: Fix cxl_region_rwsem lock held when returning to
  user space (bsc#1012628).
- cxl/core/regs: Rename @dev to @host in struct cxl_register_map
  (bsc#1012628).
- cxl/port: Fix @host confusion in cxl_dport_setup_regs()
  (bsc#1012628).
- cxl/hdm: Remove broken error path (bsc#1012628).
- pcmcia: cs: fix possible hung task and memory leak pccardd()
  (bsc#1012628).
- pcmcia: ds: fix refcount leak in pcmcia_device_add()
  (bsc#1012628).
- pcmcia: ds: fix possible name leak in error path in
  pcmcia_device_add() (bsc#1012628).
- media: imx-jpeg: initiate a drain of the capture queue in
  dynamic resolution change (bsc#1012628).
- media: hantro: Check whether reset op is defined before use
  (bsc#1012628).
- media: verisilicon: Do not enable G2 postproc downscale if
  source is narrower than destination (bsc#1012628).
- media: ov13b10: Fix some error checking in probe (bsc#1012628).
- media: ov5640: fix vblank unchange issue when work at dvp mode
  (bsc#1012628).
- media: i2c: max9286: Fix some redundant of_node_put() calls
  (bsc#1012628).
- media: ov5640: Fix a memory leak when ov5640_probe fails
  (bsc#1012628).
- media: bttv: fix use after free error due to btv->timeout timer
  (bsc#1012628).
- media: amphion: handle firmware debug message (bsc#1012628).
- media: mtk-jpegenc: Fix bug in JPEG encode quality selection
  (bsc#1012628).
- media: s3c-camif: Avoid inappropriate kfree() (bsc#1012628).
- media: vidtv: psi: Add check for kstrdup (bsc#1012628).
- media: vidtv: mux: Add check and kfree for kstrdup
  (bsc#1012628).
- media: cedrus: Fix clock/reset sequence (bsc#1012628).
- media: i2c: imx219: Convert to CCI register access helpers
  (bsc#1012628).
- media: i2c: imx219: Replace register addresses with macros
  (bsc#1012628).
- media: i2c: imx219: Drop IMX219_REG_CSI_LANE_MODE from common
  regs array (bsc#1012628).
- media: cadence: csi2rx: Unregister v4l2 async notifier
  (bsc#1012628).
- media: dvb-usb-v2: af9035: fix missing unlock (bsc#1012628).
- media: verisilicon: Fixes clock list for rk3588 av1 decoder
  (bsc#1012628).
- media: mediatek: vcodec: Handle invalid encoder vsi
  (bsc#1012628).
- media: imx-jpeg: notify source chagne event when the first
  picture parsed (bsc#1012628).
- media: mediatek: vcodec: using encoder device to alloc/free
  encoder memory (bsc#1012628).
- media: platform: mtk-mdp3: fix uninitialized variable in
  mdp_path_config() (bsc#1012628).
- media: cec: meson: always include meson sub-directory in
  Makefile (bsc#1012628).
- cpupower: fix reference to nonexistent document (bsc#1012628).
- regmap: prevent noinc writes from clobbering cache
  (bsc#1012628).
- drm/amdgpu/gfx10,11: use memcpy_to/fromio for MQDs
  (bsc#1012628).
- drm/amdgpu: don't put MQDs in VRAM on ARM | ARM64 (bsc#1012628).
- pwm: sti: Reduce number of allocations and drop usage of
  chip_data (bsc#1012628).
- pwm: brcmstb: Utilize appropriate clock APIs in suspend/resume
  (bsc#1012628).
- Input: synaptics-rmi4 - fix use after free in
  rmi_unregister_function() (bsc#1012628).
- watchdog: marvell_gti_wdt: Fix error code in probe()
  (bsc#1012628).
- watchdog: ixp4xx: Make sure restart always works (bsc#1012628).
- llc: verify mac len before reading mac header (bsc#1012628).
- hsr: Prevent use after free in prp_create_tagged_frame()
  (bsc#1012628).
- tipc: Change nla_policy for bearer-related names to
  NLA_NUL_STRING (bsc#1012628).
- rxrpc: Fix two connection reaping bugs (bsc#1012628).
- bpf: Check map->usercnt after timer->timer is assigned
  (bsc#1012628).
- inet: shrink struct flowi_common (bsc#1012628).
- octeontx2-pf: Fix error codes (bsc#1012628).
- octeontx2-pf: Fix holes in error code (bsc#1012628).
- net: page_pool: add missing free_percpu when page_pool_init fail
  (bsc#1012628).
- dccp: Call security_inet_conn_request() after setting IPv4
  addresses (bsc#1012628).
- dccp/tcp: Call security_inet_conn_request() after setting IPv6
  addresses (bsc#1012628).
- net: r8169: Disable multicast filter for RTL8168H and RTL8107E
  (bsc#1012628).
- Fix termination state for idr_for_each_entry_ul() (bsc#1012628).
- net: stmmac: xgmac: Enable support for multiple Flexible PPS
  outputs (bsc#1012628).
- selftests: pmtu.sh: fix result checking (bsc#1012628).
- octeontx2-pf: Free pending and dropped SQEs (bsc#1012628).
- net/smc: fix dangling sock under state SMC_APPFINCLOSEWAIT
  (bsc#1012628).
- net/smc: allow cdc msg send rather than drop it with NULL
  sndbuf_desc (bsc#1012628).
- net/smc: put sk reference if close work was canceled
  (bsc#1012628).
- nvme: fix error-handling for io_uring nvme-passthrough
  (bsc#1012628).
- riscv: boot: Fix creation of loader.bin (bsc#1012628).
- ice: Fix SRIOV LAG disable on non-compliant aggregate
  (bsc#1012628).
- ice: lag: in RCU, use atomic allocation (bsc#1012628).
- ice: Fix VF-VF filter rules in switchdev mode (bsc#1012628).
- ice: Fix VF-VF direction matching in drop rule in switchdev
  (bsc#1012628).
- tg3: power down device only on SYSTEM_POWER_OFF (bsc#1012628).
- nbd: fix uaf in nbd_open (bsc#1012628).
- blk-core: use pr_warn_ratelimited() in bio_check_ro()
  (bsc#1012628).
- vsock/virtio: remove socket from connected/bound list on
  shutdown (bsc#1012628).
- r8169: respect userspace disabling IFF_MULTICAST (bsc#1012628).
- virtio/vsock: Fix uninit-value in virtio_transport_recv_pkt()
  (bsc#1012628).
- net: enetc: shorten enetc_setup_xdp_prog() error message to
  fit NETLINK_MAX_FMTMSG_LEN (bsc#1012628).
- i2c: iproc: handle invalid slave state (bsc#1012628).
- netfilter: xt_recent: fix (increase) ipv6 literal buffer length
  (bsc#1012628).
- netfilter: nat: fix ipv6 nat redirect with mapped and scoped
  addresses (bsc#1012628).
- net/sched: act_ct: Always fill offloading tuple iifidx
  (bsc#1012628).
- RISC-V: Don't fail in riscv_of_parent_hartid() for disabled
  HARTs (bsc#1012628).
- net: ti: icss-iep: fix setting counter value (bsc#1012628).
- drivers: perf: Do not broadcast to other cpus when starting
  a counter (bsc#1012628).
- module/decompress: use kvmalloc() consistently (bsc#1012628).
- fs: dlm: Simplify buffer size computation in
  dlm_create_debug_file() (bsc#1012628).
- drm/vc4: tests: Fix UAF in the mock helpers (bsc#1012628).
- drm/syncobj: fix DRM_SYNCOBJ_WAIT_FLAGS_WAIT_AVAILABLE
  (bsc#1012628).
- ASoC: rt712-sdca: fix speaker route missing issue (bsc#1012628).
- ASoC: mediatek: mt8186_mt6366_rt1019_rt5682s: trivial: fix
  error messages (bsc#1012628).
- ASoC: hdmi-codec: register hpd callback on component probe
  (bsc#1012628).
- ASoC: dapm: fix clock get name (bsc#1012628).
- spi: spi-zynq-qspi: add spi-mem to driver kconfig dependencies
  (bsc#1012628).
- arm64/arm: arm_pmuv3: perf: Don't truncate 64-bit registers
  (bsc#1012628).
- fbdev: imsttfb: fix double free in probe() (bsc#1012628).
- fbdev: imsttfb: fix a resource leak in probe (bsc#1012628).
- ALSA: hda/realtek: Add support dual speaker for Dell
  (bsc#1012628).
- fbdev: fsl-diu-fb: mark wr_reg_wa() static (bsc#1012628).
- tracing/kprobes: Fix the order of argument descriptions
  (bsc#1012628).
- eventfs: Check for NULL ef in eventfs_set_attr() (bsc#1012628).
- selftests: mptcp: run userspace pm tests slower (bsc#1012628).
- selftests: mptcp: fix wait_rm_addr/sf parameters (bsc#1012628).
- io_uring/net: ensure socket is marked connected on connect retry
  (bsc#1012628).
- x86/amd_nb: Use Family 19h Models 60h-7Fh Function 4 IDs
  (bsc#1012628).
- Revert "PCI/ASPM: Disable only ASPM_STATE_L1 when driver,
  disables L1" (bsc#1012628).
- Revert "mmc: core: Capture correct oemid-bits for eMMC cards"
  (bsc#1012628).
- btrfs: use u64 for buffer sizes in the tree search ioctls
  (bsc#1012628).
- btrfs: make found_logical_ret parameter mandatory for function
  queue_scrub_stripe() (bsc#1012628).
- Refresh
  patches.suse/ALSA-hda-cs35l41-Support-mute-notifications-for-CS35.patch.
- Rename to
  patches.kernel.org/6.6.2-328-ASoC-cs35l41-Handle-mdsync_down-reg-write-error.patch.
- Rename to
  patches.kernel.org/6.6.2-329-ASoC-cs35l41-Handle-mdsync_up-reg-write-errors.patch.
- Rename to
  patches.kernel.org/6.6.2-330-ASoC-cs35l41-Initialize-completion-object-befor.patch.
- Rename to
  patches.kernel.org/6.6.2-331-ASoC-cs35l41-Fix-broken-shared-boost-activation.patch.
- Rename to
  patches.kernel.org/6.6.2-332-ASoC-cs35l41-Verify-PM-runtime-resume-errors-in.patch.
- Rename to
  patches.kernel.org/6.6.2-333-ASoC-cs35l41-Undo-runtime-PM-changes-at-driver-.patch.
- Rename to
  patches.kernel.org/6.6.2-334-ALSA-hda-cs35l41-Fix-unbalanced-pm_runtime_get.patch.
- Rename to
  patches.kernel.org/6.6.2-335-ALSA-hda-cs35l41-Undo-runtime-PM-changes-at-dri.patch.
- commit 263a855
* Mon Nov 20 2023 mkubecek@suse.cz
- Update to 6.7-rc2
- refresh
  - patches.suse/firmware-qemu_fw_cfg-Do-not-hard-depend-on-CONFIG_HA.patch
- update configs
  - riscv64
  - FW_CFG_SYSFS=m
  - FW_CFG_SYSFS_CMDLINE=y
- commit e1d4442
* Wed Nov 15 2023 tiwai@suse.de
- Refresh patches.suse/iwlwifi-cfg-Add-missing-MODULE_FIRMWARE-for-pnvm.patch
  Add entries for more *.pnvm files
- commit 880a670
* Wed Nov 15 2023 tiwai@suse.de
- ALSA: hda: cs35l41: Fix missing error code in
  cs35l41_smart_amp() (bsc#1213745).
- ALSA: hda: cs35l41: mark cs35l41_verify_id() static
  (bsc#1213745).
- ASoC: cs35l41: Detect CSPL errors when sending CSPL commands
  (bsc#1213745).
- ALSA: hda: cs35l41: Check CSPL state after loading firmware
  (bsc#1213745).
- ALSA: hda: cs35l41: Do not unload firmware before reset in
  system suspend (bsc#1213745).
- ALSA: hda: cs35l41: Force a software reset after hardware reset
  (bsc#1213745).
- ALSA: hda: cs35l41: Run boot process during resume callbacks
  (bsc#1213745).
- ALSA: hda: cs35l41: Assert Reset prior to de-asserting in
  probe and system resume (bsc#1213745).
- ALSA: hda: cs35l41: Assert reset before system suspend
  (bsc#1213745).
- ALSA: hda: cs35l41: Use reset label to get GPIO for HP Zbook
  Fury 17 G9 (bsc#1213745).
- ALSA: hda: cs35l41: Consistently use dev_err_probe()
  (bsc#1213745).
- ALSA: hda: cs35l41: Undo runtime PM changes at driver exit time
  (bsc#1213745).
- ALSA: hda: cs35l41: Fix unbalanced pm_runtime_get()
  (bsc#1213745).
- ASoC: cs35l41: Use modern pm_ops (bsc#1213745).
- ASoC: cs35l41: Make use of dev_err_probe() (bsc#1213745).
- ASoC: cs35l41: Undo runtime PM changes at driver exit time
  (bsc#1213745).
- ASoC: cs35l41: Verify PM runtime resume errors in IRQ handler
  (bsc#1213745).
- ASoC: cs35l41: Fix broken shared boost activation (bsc#1213745).
- ASoC: cs35l41: Initialize completion object before requesting
  IRQ (bsc#1213745).
- ASoC: cs35l41: Handle mdsync_up reg write errors (bsc#1213745).
- ASoC: cs35l41: Handle mdsync_down reg write errors
  (bsc#1213745).
- ALSA: hda: cs35l41: Add read-only ALSA control for forced mute
  (bsc#1213745).
- ALSA: hda: cs35l41: Support mute notifications for CS35L41 HDA
  (bsc#1213745).
- ALSA: hda/realtek: Support ACPI Notification framework via
  component binding (bsc#1213745).
- ALSA: hda: cs35l41: Add notification support into component
  binding (bsc#1213745).
- commit 1b0014b
* Mon Nov 13 2023 schwab@suse.de
- rpm/check-for-config-changes: add HAVE_SHADOW_CALL_STACK to IGNORED_CONFIGS_RE
  Not supported by our compiler.
- commit eb32b5a
* Mon Nov 13 2023 mkubecek@suse.cz
- Update to 6.7-rc1
- drop 36 patches (31 stable, 5 mainline)
  - patches.kernel.org/*
  - patches.rpmify/kbuild-dummy-tools-pretend-we-understand-fpatchable-.patch
  - patches.suse/firmware-Add-support-for-Qualcomm-UEFI-Secure-Applic.patch
  - patches.suse/firmware-qcom_scm-Add-support-for-Qualcomm-Secure-Ex.patch
  - patches.suse/lib-ucs2_string-Add-UCS-2-strscpy-function.patch
  - patches.suse/wifi-ath11k-rename-the-sc-naming-convention-to-ab.patch
- refresh
  - patches.rpmify/Add-ksym-provides-tool.patch
  - patches.suse/add-product-identifying-information-to-vmcoreinfo.patch
  - patches.suse/add-suse-supported-flag.patch
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/vfs-add-super_operations-get_inode_dev
  - patches.suse/wifi-ath11k-support-hibernation.patch
- fix patch metadata
  - patches.rpmify/Add-ksym-provides-tool.patch
- disable ARM architectures (need config update)
- new config options
  - Processor type and features
  - CONFIG_INTEL_TDX_HOST=n
  - Binary Emulations
  - CONFIG_IA32_EMULATION_DEFAULT_DISABLED=n
  - Virtualization
  - CONFIG_KVM_MAX_NR_VCPUS=4096
  - Enable loadable module support
  - CONFIG_MODULE_SIG_SHA3_256=n
  - CONFIG_MODULE_SIG_SHA3_384=n
  - CONFIG_MODULE_SIG_SHA3_512=n
  - Memory Management options
  - CONFIG_PCP_BATCH_SCALE_MAX=5
  - Networking support
  - CONFIG_TCP_AO=y
  - File systems
  - CONFIG_BCACHEFS_FS=m
  - CONFIG_BCACHEFS_QUOTA=y
  - CONFIG_BCACHEFS_POSIX_ACL=y
  - CONFIG_BCACHEFS_DEBUG_TRANSACTIONS=n
  - CONFIG_BCACHEFS_DEBUG=n
  - CONFIG_BCACHEFS_TESTS=n
  - CONFIG_BCACHEFS_LOCK_TIME_STATS=n
  - CONFIG_BCACHEFS_NO_LATENCY_ACCT=n
  - Cryptographic API
  - CONFIG_CRYPTO_JITTERENTROPY_MEMSIZE_2=y
  - CONFIG_CRYPTO_JITTERENTROPY_MEMSIZE_128=n
  - CONFIG_CRYPTO_JITTERENTROPY_MEMSIZE_1024=n
  - CONFIG_CRYPTO_JITTERENTROPY_MEMSIZE_8192=n
  - CONFIG_CRYPTO_JITTERENTROPY_OSR=1
  - CONFIG_SECONDARY_TRUSTED_KEYRING_SIGNED_BY_BUILTIN=n
  - Library routines
  - CONFIG_LWQ_TEST=n
  - Kernel hacking
  - CONFIG_DEBUG_CLOSURES=n
  - CONFIG_TEST_OBJPOOL=n
  - PCI support
  - CONFIG_PCIEAER_CXL=y
  - NVME Support
  - CONFIG_NVME_TCP_TLS=y
  - CONFIG_NVME_HOST_AUTH=y
  - CONFIG_NVME_TARGET_TCP_TLS=y
  - Network device support
  - CONFIG_NETKIT=y
  - CONFIG_IDPF=m
  - CONFIG_MLX5_DPLL=m
  - CONFIG_MCTP_TRANSPORT_I3C=m
  - CONFIG_MT7925E=m
  - CONFIG_MT7925U=m
  - Hardware Monitoring support
  - CONFIG_SENSORS_POWERZ=m
  - CONFIG_SENSORS_LTC2991=m
  - Multimedia support
  - CONFIG_VIDEO_MGB4=m
  - CONFIG_VIDEO_MT9M114=m
  - Sound card support
  - CONFIG_SND_AMD_ASOC_ACP63=m
  - CONFIG_SND_SOC_INTEL_AVS_MACH_RT5514=m
  - CONFIG_SND_SOC_INTEL_SOF_DA7219_MACH=m
  - CONFIG_SND_SOC_SOF_AMD_ACP63=m
  - CONFIG_SND_SOC_AW87390=n
  - CONFIG_SND_SOC_AW88399=n
  - CONFIG_SND_SOC_RTQ9128=m
  - USB support
  - CONFIG_USB_PCI_AMD=y
  - CONFIG_USB_LJCA=m
  - CONFIG_TYPEC_MUX_PTN36502=m
  - Industrial I/O support
  - CONFIG_LTC2309=n
  - CONFIG_MCP3564=n
  - CONFIG_ROHM_BM1390=n
  - Misc drivers
  - CONFIG_I2C_LJCA=m
  - CONFIG_SPI_LJCA=m
  - CONFIG_GPIO_LJCA=m
  - CONFIG_FUEL_GAUGE_MM8013=m
  - CONFIG_REGULATOR_MAX77503=m
  - CONFIG_LEDS_TRIGGER_GPIO=m
  - CONFIG_XEN_PRIVCMD_EVENTFD=y
  - CONFIG_INSPUR_PLATFORM_PROFILE=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - DRM_PANEL_ILITEK_ILI9882T=n
  - DRM_PANEL_JDI_LPM102A188A=n
  - DRM_PANEL_RAYDIUM_RM692E5=n
  - LEDS_KTD202X=m
  - ppc64le
  - PROBE_EVENTS_BTF_ARGS=y
  - s390x/zfcdump
  - CERT_STORE=y
  - BLK_SED_OPAL=n
  - DNS_RESOLVER=n
  - QUOTA_NETLINK_INTERFACE=n
  - KEYS_REQUEST_CACHE=n
  - PERSISTENT_KEYRINGS=n
  - TRUSTED_KEYS=n
  - ENCRYPTED_KEYS=n
  - KEY_DH_OPERATIONS=n
  - KEY_NOTIFICATIONS=n
  - ASYMMETRIC_KEY_TYPE=n
  - SYSTEM_BLACKLIST_KEYRING=n
  - RAID6_PQ_BENCHMARK=n
  - riscv64
  - ARCH_SOPHGO=y
  - RISCV_MISALIGNED=y
  - SHADOW_CALL_STACK=y
  - PCIE_RCAR_GEN4_HOST=m
  - PCIE_RCAR_GEN4_EP=m
  - SND_SOC_JH7110_PWMDAC=m
  - RUNTIME_KERNEL_TESTING_MENU=n
  - copied from arm64
  - SERIO_AMBAKMI=n
  - SERIAL_AMBA_PL010=y
  - SERIAL_AMBA_PL011=y
  - I2C_NOMADIK=n
  - SPI_PL022=m
  - GPIO_PL061=y
  - MMC_ARMMMCI=m
  - MMC_SDHI_INTERNAL_DMAC=m
  - RTC_DRV_PL030=y
  - RTC_DRV_PL031=y
  - AMBA_PL08X=n
  - PL330_DMA=m
  - ARM_MHU=n
  - ARM_MHU_V2=m
  - PL320_MBOX=n
  - ARM_PL172_MPMC=m
  - SERIAL_AMBA_PL010_CONSOLE=y
  - SERIAL_AMBA_PL011_CONSOLE=y
  - MMC_STM32_SDMMC=y
- commit 47d658a
* Fri Nov 10 2023 jdelvare@suse.de
- Disable Loongson drivers
  Loongson is a mips architecture, I don't think it makes sense to
  build Loongson drivers on other architectures.
- commit 4d5bd14
* Fri Nov 10 2023 tiwai@suse.de
- wifi: ath11k: support hibernation (bsc#1207948).
- wifi: ath11k: thermal: don't try to register multiple times
  (bsc#1207948).
- wifi: ath11k: fix warning on DMA ring capabilities event
  (bsc#1207948).
- wifi: ath11k: do not dump SRNG statistics during resume
  (bsc#1207948).
- wifi: ath11k: remove MHI LOOPBACK channels (bsc#1207948).
- wifi: ath11k: handle irq enable/disable in several code path
  (bsc#1207948).
- bus: mhi: host: add new interfaces to handle MHI channels
  directly (bsc#1207948).
- bus: mhi: host: add mhi_power_down_no_destroy() (bsc#1207948).
- commit 10bbcec
* Fri Nov 10 2023 tiwai@suse.de
- wifi: ath11k: rename the sc naming convention to ab
  (bsc#1207948).
- commit e66948e
* Fri Nov 10 2023 tiwai@suse.de
- Drop ath11k hibernation patch set once for renewal (bsc#1207948)
- commit 9ecdaa5
* Thu Nov  9 2023 jslaby@suse.cz
- Linux 6.6.1 (bsc#1012628).
- ASoC: SOF: sof-pci-dev: Fix community key quirk detection
  (bsc#1012628).
- ALSA: hda: intel-dsp-config: Fix JSL Chromebook quirk detection
  (bsc#1012628).
- serial: core: Fix runtime PM handling for pending tx
  (bsc#1012628).
- misc: pci_endpoint_test: Add deviceID for J721S2 PCIe EP device
  support (bsc#1012628).
- dt-bindings: serial: rs485: Add rs485-rts-active-high
  (bsc#1012628).
- tty: 8250: Add Brainboxes Oxford Semiconductor-based quirks
  (bsc#1012628).
- tty: 8250: Add support for Intashield IX cards (bsc#1012628).
- tty: 8250: Add support for additional Brainboxes PX cards
  (bsc#1012628).
- tty: 8250: Fix up PX-803/PX-857 (bsc#1012628).
- tty: 8250: Fix port count of PX-257 (bsc#1012628).
- tty: 8250: Add support for Intashield IS-100 (bsc#1012628).
- tty: 8250: Add support for Brainboxes UP cards (bsc#1012628).
- tty: 8250: Add support for additional Brainboxes UC cards
  (bsc#1012628).
- tty: 8250: Remove UC-257 and UC-431 (bsc#1012628).
- tty: n_gsm: fix race condition in status line change on dead
  connections (bsc#1012628).
- Bluetooth: hci_bcm4377: Mark bcm4378/bcm4387 as BROKEN_LE_CODED
  (bsc#1012628).
- usb: raw-gadget: properly handle interrupted requests
  (bsc#1012628).
- usb: typec: tcpm: Fix NULL pointer dereference in tcpm_pd_svdm()
  (bsc#1012628).
- usb: typec: tcpm: Add additional checks for contaminant
  (bsc#1012628).
- usb: storage: set 1.50 as the lower bcdDevice for older "Super
  Top" compatibility (bsc#1012628).
- PCI: Prevent xHCI driver from claiming AMD VanGogh USB3 DRD
  device (bsc#1012628).
- ALSA: usb-audio: add quirk flag to enable native DSD for
  McIntosh devices (bsc#1012628).
- eventfs: Use simple_recursive_removal() to clean up dentries
  (bsc#1012628).
- eventfs: Delete eventfs_inode when the last dentry is freed
  (bsc#1012628).
- eventfs: Save ownership and mode (bsc#1012628).
- eventfs: Remove "is_freed" union with rcu head (bsc#1012628).
- tracing: Have trace_event_file have ref counters (bsc#1012628).
- perf evlist: Avoid frequency mode for the dummy event
  (bsc#1012628).
- power: supply: core: Use blocking_notifier_call_chain to avoid
  RCU complaint (bsc#1012628).
- drm/amd/display: Don't use fsleep for PSR exit waits
  (bsc#1012628).
- commit 758e4f0
* Mon Nov  6 2023 mkubecek@suse.cz
- update patch metadata
- update upstream reference
  - patches.rpmify/kbuild-dummy-tools-pretend-we-understand-fpatchable-.patch
- commit 93ae682
* Thu Nov  2 2023 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  - patches.suse/firmware-Add-support-for-Qualcomm-UEFI-Secure-Applic.patch
  - patches.suse/firmware-qcom_scm-Add-support-for-Qualcomm-Secure-Ex.patch
  - patches.suse/lib-ucs2_string-Add-UCS-2-strscpy-function.patch
- commit 157ac85
* Thu Nov  2 2023 jslaby@suse.cz
- kbuild: dummy-tools: pretend we understand
  - fpatchable-function-entry (ppc64le-build-fix).
- Delete
  patches.rpmify/kbuild-dummy-tools-Add-support-for-fpatchable-functi.patch.
  Replace the latter with the former (upstream accepted solution).
- commit 8050c17
* Wed Nov  1 2023 schwab@suse.de
- riscv: enable CONFIG_PCI_HOST_GENERIC
  Needed for the pci host controller emulated by qemu.
- commit ebb7db3
* Wed Nov  1 2023 jslaby@suse.cz
- Delete patches.rpmify/x86-Let-AS_WRUSS-depend-on-X86_64.patch.
- Update config files.
  This effectively reverts 9ab2e0780c8a2fb9a84db5bad59fbe3ab526a6c3. The
  patch was not accepted upstream:
  https://lore.kernel.org/all/20231031140504.GCZUEJkMPXSrEDh3MA@fat_crate.local/
  Instead, we merged the packaging branch which fixes this in
  rpm/check-for-config-changes instead.
- rpm/check-for-config-changes: add AS_WRUSS to IGNORED_CONFIGS_RE
  Add AS_WRUSS as an IGNORED_CONFIGS_RE entry in check-for-config-changes
  to fix build on x86_32.
  There was a fix submitted to upstream but it was not accepted:
  https://lore.kernel.org/all/20231031140504.GCZUEJkMPXSrEDh3MA@fat_crate.local/
  So carry this in IGNORED_CONFIGS_RE instead.
- commit ce5bc31
* Tue Oct 31 2023 petr@tesarici.cz
- config: enable NFS_V4_2_READ_PLUS (bsc#1216736)
  This option was introduced and disabled by default because of unresolved
  issues. As stated in mainline commit 9cf2744d2491 ("NFS: Enable the
  READ_PLUS operation by default") which changes the upstream default to
  enabled, these issues are addressed so that it is safe to enable the
  option and as it allows to transfer sparse files more efficiently, it is
  desirable to do so.
- commit c4f1dc1
* Tue Oct 31 2023 jslaby@suse.cz
- x86: Let AS_WRUSS depend on X86_64 (i386-build-fix).
- Update config files.
- commit 9ab2e07
* Mon Oct 30 2023 jslaby@suse.cz
- kbuild: dummy-tools: pretend we understand
  - fpatchable-function-entry (ppc64le-build-fix).
- Update config files.
- commit 2c8a930
* Mon Oct 30 2023 msuchanek@suse.de
- kbuild: dummy-tools: Add support for -fpatchable-function-entry (dummy-tools).
  Update config files.
- commit 494c209
* Mon Oct 30 2023 jslaby@suse.cz
- Delete
  patches.suse/ACPI-video-Add-backlight-native-DMI-quirk-for-Lenovo.patch.
  Already present in 6.6-rc1. This was applied twice due to too few
  context in the diff. But it did not hurt...
- commit 2a844dc
* Mon Oct 30 2023 mkubecek@suse.cz
- Update to 6.6 final
- refresh configs (headers only)
- commit e0904b6
* Sun Oct 29 2023 mkubecek@suse.cz
- update and reenable armv7hl configs
  Where possible, new values are copied from arm64. The rest is guessed,
  mostly based on existing values of similar config options.
- armv7hl specific config options:
  - TI_ICSS_IEP=m
- commit 09e0fd1
* Fri Oct 27 2023 vkarasulli@suse.de
- Update
  patches.kernel.org/6.5.9-016-x86-sev-Disable-MMIO-emulation-from-user-mode.patch
  (bsc#1012628 bsc#1212649 CVE-2023-46813).
- Update
  patches.kernel.org/6.5.9-017-x86-sev-Check-IOBM-for-IOIO-exceptions-from-use.patch
  (bsc#1012628 bsc#1212649 CVE-2023-46813).
- Update
  patches.kernel.org/6.5.9-018-x86-sev-Check-for-user-space-IOIO-pointing-to-k.patch
  (bsc#1012628 bsc#1212649 CVE-2023-46813).
- commit b854e69
* Wed Oct 25 2023 jslaby@suse.cz
- Linux 6.5.9 (bsc#1012628).
- Bluetooth: hci_event: Ignore NULL link key (bsc#1012628).
- Bluetooth: Reject connection with the device which has same
  BD_ADDR (bsc#1012628).
- Bluetooth: Fix a refcnt underflow problem for hci_conn
  (bsc#1012628).
- Bluetooth: vhci: Fix race when opening vhci device
  (bsc#1012628).
- Bluetooth: hci_event: Fix coding style (bsc#1012628).
- Bluetooth: avoid memcmp() out of bounds warning (bsc#1012628).
- Bluetooth: hci_conn: Fix modifying handle while aborting
  (bsc#1012628).
- ice: fix over-shifted variable (bsc#1012628).
- ice: Fix safe mode when DDP is missing (bsc#1012628).
- ice: reset first in crash dump kernels (bsc#1012628).
- net/smc: return the right falback reason when prefix checks fail
  (bsc#1012628).
- btrfs: fix stripe length calculation for non-zoned data chunk
  allocation (bsc#1012628).
- nfc: nci: fix possible NULL pointer dereference in
  send_acknowledge() (bsc#1012628).
- regmap: fix NULL deref on lookup (bsc#1012628).
- KVM: x86: Mask LVTPC when handling a PMI (bsc#1012628).
- x86/sev: Disable MMIO emulation from user mode (bsc#1012628).
- x86/sev: Check IOBM for IOIO exceptions from user-space
  (bsc#1012628).
- x86/sev: Check for user-space IOIO pointing to kernel space
  (bsc#1012628).
- x86/fpu: Allow caller to constrain xfeatures when copying to
  uabi buffer (bsc#1012628).
- KVM: x86/pmu: Truncate counter value to allowed width on write
  (bsc#1012628).
- KVM: x86: Constrain guest-supported xfeatures only at
  KVM_GET_XSAVE{2} (bsc#1012628).
- x86: KVM: SVM: always update the x2avic msr interception
  (bsc#1012628).
- x86: KVM: SVM: add support for Invalid IPI Vector interception
  (bsc#1012628).
- x86: KVM: SVM: refresh AVIC inhibition in svm_leave_nested()
  (bsc#1012628).
- audit,io_uring: io_uring openat triggers audit reference count
  underflow (bsc#1012628).
- tcp: check mptcp-level constraints for backlog coalescing
  (bsc#1012628).
- mptcp: more conservative check for zero probes (bsc#1012628).
- selftests: mptcp: join: no RST when rm subflow/addr
  (bsc#1012628).
- mm: slab: Do not create kmalloc caches smaller than
  arch_slab_minalign() (bsc#1012628).
- fs/ntfs3: Fix OOB read in ntfs_init_from_boot (bsc#1012628).
- fs/ntfs3: Fix possible null-pointer dereference in hdr_find_e()
  (bsc#1012628).
- fs/ntfs3: fix panic about slab-out-of-bounds caused by
  ntfs_list_ea() (bsc#1012628).
- fs/ntfs3: Fix shift-out-of-bounds in ntfs_fill_super
  (bsc#1012628).
- fs/ntfs3: fix deadlock in mark_as_free_ex (bsc#1012628).
- Revert "net: wwan: iosm: enable runtime pm support for 7560"
  (bsc#1012628).
- netfilter: nft_payload: fix wrong mac header matching
  (bsc#1012628).
- io_uring: fix crash with IORING_SETUP_NO_MMAP and invalid SQ
  ring address (bsc#1012628).
- nvmet-tcp: Fix a possible UAF in queue intialization setup
  (bsc#1012628).
- drm/i915: Retry gtt fault when out of fence registers
  (bsc#1012628).
- drm/mediatek: Correctly free sg_table in gem prime vmap
  (bsc#1012628).
- drm/nouveau/disp: fix DP capable DSM connectors (bsc#1012628).
- drm/edid: add 8 bpc quirk to the BenQ GW2765 (bsc#1012628).
- ALSA: hda/realtek - Fixed ASUS platform headset Mic issue
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ASUS ROG GU603ZV (bsc#1012628).
- ALSA: hda/relatek: Enable Mute LED on HP Laptop 15s-fq5xxx
  (bsc#1012628).
- ASoC: codecs: wcd938x-sdw: fix use after free on driver unbind
  (bsc#1012628).
- ASoC: codecs: wcd938x-sdw: fix runtime PM imbalance on probe
  errors (bsc#1012628).
- ASoC: codecs: wcd938x: drop bogus bind error handling
  (bsc#1012628).
- ASoC: codecs: wcd938x: fix unbind tear down order (bsc#1012628).
- ASoC: codecs: wcd938x: fix resource leaks on bind errors
  (bsc#1012628).
- ASoC: codecs: wcd938x: fix regulator leaks on probe errors
  (bsc#1012628).
- ASoC: codecs: wcd938x: fix runtime PM imbalance on remove
  (bsc#1012628).
- qed: fix LL2 RX buffer allocation (bsc#1012628).
- xfrm: fix a data-race in xfrm_lookup_with_ifid() (bsc#1012628).
- xfrm6: fix inet6_dev refcount underflow problem (bsc#1012628).
- xfrm: fix a data-race in xfrm_gen_index() (bsc#1012628).
- xfrm: interface: use DEV_STATS_INC() (bsc#1012628).
- net: xfrm: skip policies marked as dead while reinserting
  policies (bsc#1012628).
- fprobe: Fix to ensure the number of active retprobes is not zero
  (bsc#1012628).
- wifi: cfg80211: use system_unbound_wq for wiphy work
  (bsc#1012628).
- net: ipv4: fix return value check in esp_remove_trailer
  (bsc#1012628).
- net: ipv6: fix return value check in esp_remove_trailer
  (bsc#1012628).
- net: rfkill: gpio: prevent value glitch during probe
  (bsc#1012628).
- tcp: fix excessive TLP and RACK timeouts from HZ rounding
  (bsc#1012628).
- tcp: tsq: relax tcp_small_queue_check() when rtx queue contains
  a single skb (bsc#1012628).
- tcp: Fix listen() warning with v4-mapped-v6 address
  (bsc#1012628).
- docs: fix info about representor identification (bsc#1012628).
- tun: prevent negative ifindex (bsc#1012628).
- gve: Do not fully free QPL pages on prefill errors
  (bsc#1012628).
- ipv4: fib: annotate races around nh->nh_saddr_genid and
  nh->nh_saddr (bsc#1012628).
- net: usb: smsc95xx: Fix an error code in smsc95xx_reset()
  (bsc#1012628).
- octeon_ep: update BQL sent bytes before ringing doorbell
  (bsc#1012628).
- i40e: prevent crash on probe if hw registers have invalid values
  (bsc#1012628).
- net: dsa: bcm_sf2: Fix possible memory leak in
  bcm_sf2_mdio_register() (bsc#1012628).
- bonding: Return pointer to data after pull on skb (bsc#1012628).
- net/sched: sch_hfsc: upgrade 'rt' to 'sc' when it becomes a
  inner curve (bsc#1012628).
- neighbor: tracing: Move pin6 inside CONFIG_IPV6=y section
  (bsc#1012628).
- selftests: openvswitch: Catch cases where the tests are killed
  (bsc#1012628).
- selftests: openvswitch: Fix the ct_tuple for v4 (bsc#1012628).
- selftests: netfilter: Run nft_audit.sh in its own netns
  (bsc#1012628).
- netfilter: nft_set_rbtree: .deactivate fails if element has
  expired (bsc#1012628).
- netlink: Correct offload_xstats size (bsc#1012628).
- netfilter: nf_tables: do not refresh timeout when resetting
  element (bsc#1012628).
- nf_tables: fix NULL pointer dereference in
  nft_expr_inner_parse() (bsc#1012628).
- nf_tables: fix NULL pointer dereference in nft_inner_init()
  (bsc#1012628).
- netfilter: nf_tables: do not remove elements if set backend
  implements .abort (bsc#1012628).
- netfilter: nf_tables: revert do not remove elements if set
  backend implements .abort (bsc#1012628).
- selftests: openvswitch: Add version check for pyroute2
  (bsc#1012628).
- net: phy: bcm7xxx: Add missing 16nm EPHY statistics
  (bsc#1012628).
- net: pktgen: Fix interface flags printing (bsc#1012628).
- net: more strict VIRTIO_NET_HDR_GSO_UDP_L4 validation
  (bsc#1012628).
- net: mdio-mux: fix C45 access returning -EIO after API change
  (bsc#1012628).
- net: avoid UAF on deleted altname (bsc#1012628).
- net: fix ifname in netlink ntf during netns move (bsc#1012628).
- net: check for altname conflicts when changing netdev's netns
  (bsc#1012628).
- iio: light: vcnl4000: Don't power on/off chip in config
  (bsc#1012628).
- pwr-mlxbf: extend Kconfig to include gpio-mlxbf3 dependency
  (bsc#1012628).
- ARM: dts: ti: omap: Fix noisy serial with overrun-throttle-ms
  for mapphone (bsc#1012628).
- arm64: dts: mediatek: Fix "mediatek,merge-mute" and
  "mediatek,merge-fifo-en" types (bsc#1012628).
- fs-writeback: do not requeue a clean inode having skipped pages
  (bsc#1012628).
- btrfs: fix race when refilling delayed refs block reserve
  (bsc#1012628).
- btrfs: prevent transaction block reserve underflow when starting
  transaction (bsc#1012628).
- btrfs: return -EUCLEAN for delayed tree ref with a ref count
  not equals to 1 (bsc#1012628).
- btrfs: initialize start_slot in btrfs_log_prealloc_extents
  (bsc#1012628).
- i2c: mux: Avoid potential false error message in
  i2c_mux_add_adapter (bsc#1012628).
- overlayfs: set ctime when setting mtime and atime (bsc#1012628).
- accel/ivpu: Don't flood dmesg with VPU ready message
  (bsc#1012628).
- gpio: timberdale: Fix potential deadlock on &tgpio->lock
  (bsc#1012628).
- ata: libata-core: Fix compilation warning in
  ata_dev_config_ncq() (bsc#1012628).
- ata: libata-eh: Fix compilation warning in ata_eh_link_report()
  (bsc#1012628).
- tracing: relax trace_event_eval_update() execution with
  cond_resched() (bsc#1012628).
- wifi: mwifiex: Sanity check tlv_len and tlv_bitmap_len
  (bsc#1012628).
- wifi: cfg80211: validate AP phy operation before starting it
  (bsc#1012628).
- wifi: iwlwifi: Ensure ack flag is properly cleared
  (bsc#1012628).
- rfkill: sync before userspace visibility/changes (bsc#1012628).
- HID: logitech-hidpp: Add Bluetooth ID for the Logitech M720
  Triathlon mouse (bsc#1012628).
- HID: holtek: fix slab-out-of-bounds Write in
  holtek_kbd_input_event (bsc#1012628).
- Bluetooth: btusb: add shutdown function for QCA6174
  (bsc#1012628).
- Bluetooth: Avoid redundant authentication (bsc#1012628).
- Bluetooth: hci_core: Fix build warnings (bsc#1012628).
- wifi: cfg80211: Fix 6GHz scan configuration (bsc#1012628).
- wifi: mac80211: work around Cisco AP 9115 VHT MPDU length
  (bsc#1012628).
- wifi: mac80211: allow transmitting EAPOL frames with tainted
  key (bsc#1012628).
- wifi: cfg80211: avoid leaking stack data into trace
  (bsc#1012628).
- regulator/core: Revert "fix kobject release warning and memory
  leak in regulator_register()" (bsc#1012628).
- SUNRPC: Fail quickly when server does not recognize TLS
  (bsc#1012628).
- SUNRPC/TLS: Lock the lower_xprt during the tls handshake
  (bsc#1012628).
- nfs: decrement nrequests counter before releasing the req
  (bsc#1012628).
- sky2: Make sure there is at least one frag_addr available
  (bsc#1012628).
- ipv4/fib: send notify when delete source address routes
  (bsc#1012628).
- drm: panel-orientation-quirks: Add quirk for One Mix 2S
  (bsc#1012628).
- btrfs: fix some -Wmaybe-uninitialized warnings in ioctl.c
  (bsc#1012628).
- btrfs: error out when COWing block using a stale transaction
  (bsc#1012628).
- btrfs: error when COWing block from a root that is being deleted
  (bsc#1012628).
- btrfs: error out when reallocating block for defrag using a
  stale transaction (bsc#1012628).
- platform/x86: touchscreen_dmi: Add info for the BUSH Bush
  Windows tablet (bsc#1012628).
- drm/amd/pm: add unique_id for gc 11.0.3 (bsc#1012628).
- HID: multitouch: Add required quirk for Synaptics 0xcd7e device
  (bsc#1012628).
- HID: nintendo: reinitialize USB Pro Controller after resuming
  from suspend (bsc#1012628).
- HID: Add quirk to ignore the touchscreen battery on HP ENVY
  15-eu0556ng (bsc#1012628).
- platform/x86: touchscreen_dmi: Add info for the Positivo C4128B
  (bsc#1012628).
- cpufreq: schedutil: Update next_freq when cpufreq_limits change
  (bsc#1012628).
- io-wq: fully initialize wqe before calling
  cpuhp_state_add_instance_nocalls() (bsc#1012628).
- Bluetooth: hci_sync: Fix not handling ISO_LINK in
  hci_abort_conn_sync (bsc#1012628).
- Bluetooth: hci_sync: Introduce PTR_UINT/UINT_PTR macros
  (bsc#1012628).
- Bluetooth: ISO: Fix invalid context error (bsc#1012628).
- Bluetooth: hci_sync: delete CIS in BT_OPEN/CONNECT/BOUND when
  aborting (bsc#1012628).
- Bluetooth: hci_sync: always check if connection is alive before
  deleting (bsc#1012628).
- net/mlx5: E-switch, register event handler before arming the
  event (bsc#1012628).
- net/mlx5: Handle fw tracer change ownership event based on MTRC
  (bsc#1012628).
- net/mlx5e: RX, Fix page_pool allocation failure recovery for
  striding rq (bsc#1012628).
- net/mlx5e: RX, Fix page_pool allocation failure recovery for
  legacy rq (bsc#1012628).
- net/mlx5e: XDP, Fix XDP_REDIRECT mpwqe page fragment leaks on
  shutdown (bsc#1012628).
- net/mlx5e: Take RTNL lock before triggering netdev notifiers
  (bsc#1012628).
- net/mlx5e: Don't offload internal port if filter device is
  out device (bsc#1012628).
- net/mlx5e: Fix VF representors reporting zero counters to
  "ip -s" command (bsc#1012628).
- net/tls: split tls_rx_reader_lock (bsc#1012628).
- tcp: allow again tcp_disconnect() when threads are waiting
  (bsc#1012628).
- Bluetooth: hci_event: Fix using memcmp when comparing keys
  (bsc#1012628).
- tcp_bpf: properly release resources on error paths
  (bsc#1012628).
- mtd: rawnand: qcom: Unmap the right resource upon probe failure
  (bsc#1012628).
- mtd: rawnand: pl353: Ensure program page operations are
  successful (bsc#1012628).
- mtd: rawnand: marvell: Ensure program page operations are
  successful (bsc#1012628).
- mtd: rawnand: arasan: Ensure program page operations are
  successful (bsc#1012628).
- mtd: rawnand: Ensure the nand chip supports cached reads
  (bsc#1012628).
- mtd: spinand: micron: correct bitmask for ecc status
  (bsc#1012628).
- mtd: physmap-core: Restore map_rom fallback (bsc#1012628).
- dt-bindings: mmc: sdhci-msm: correct minimum number of clocks
  (bsc#1012628).
- mmc: sdhci-pci-gli: fix LPM negotiation so x86/S0ix SoCs can
  suspend (bsc#1012628).
- mmc: mtk-sd: Use readl_poll_timeout_atomic in msdc_reset_hw
  (bsc#1012628).
- mmc: core: Fix error propagation for some ioctl commands
  (bsc#1012628).
- mmc: core: sdio: hold retuning if sdio in 1-bit mode
  (bsc#1012628).
- mmc: core: Capture correct oemid-bits for eMMC cards
  (bsc#1012628).
- pinctrl: qcom: lpass-lpi: fix concurrent register updates
  (bsc#1012628).
- Revert "pinctrl: avoid unsafe code pattern in find_pinctrl()"
  (bsc#1012628).
- pNFS: Fix a hang in nfs4_evict_inode() (bsc#1012628).
- pNFS/flexfiles: Check the layout validity in
  ff_layout_mirror_prepare_stats (bsc#1012628).
- ACPI: irq: Fix incorrect return value in acpi_register_gsi()
  (bsc#1012628).
- ACPI: bus: Move acpi_arm_init() to the place of after
  acpi_ghes_init() (bsc#1012628).
- perf dlfilter: Fix use of addr_location__exit() in
  dlfilter__object_code() (bsc#1012628).
- Revert "accel/ivpu: Use cached buffers for FW loading"
  (bsc#1012628).
- fanotify: limit reporting of event with non-decodeable file
  handles (bsc#1012628).
- NFS: Fix potential oops in nfs_inode_remove_request()
  (bsc#1012628).
- nfs42: client needs to strip file mode's suid/sgid bit after
  ALLOCATE op (bsc#1012628).
- nvme: sanitize metadata bounce buffer for reads (bsc#1012628).
- nvme-pci: add BOGUS_NID for Intel 0a54 device (bsc#1012628).
- nvme-auth: use chap->s2 to indicate bidirectional authentication
  (bsc#1012628).
- nvmet-auth: complete a request only after freeing the dhchap
  pointers (bsc#1012628).
- nvme-rdma: do not try to stop unallocated queues (bsc#1012628).
- USB: serial: option: add Telit LE910C4-WWX 0x1035 composition
  (bsc#1012628).
- USB: serial: option: add entry for Sierra EM9191 with new
  firmware (bsc#1012628).
- USB: serial: option: add Fibocom to DELL custom modem FM101R-GL
  (bsc#1012628).
- thunderbolt: Call tb_switch_put() once DisplayPort bandwidth
  request is finished (bsc#1012628).
- perf: Disallow mis-matched inherited group reads (bsc#1012628).
- s390/pci: fix iommu bitmap allocation (bsc#1012628).
- tracing/kprobes: Return EADDRNOTAVAIL when func matches several
  symbols (bsc#1012628).
- selftests/ftrace: Add new test case which checks non unique
  symbol (bsc#1012628).
- KEYS: asymmetric: Fix sign/verify on pkcs1pad without a hash
  (bsc#1012628).
- apple-gmux: Hard Code max brightness for MMIO gmux
  (bsc#1012628).
- s390/cio: fix a memleak in css_alloc_subchannel (bsc#1012628).
- platform/surface: platform_profile: Propagate error if profile
  registration fails (bsc#1012628).
- platform/x86: intel-uncore-freq: Conditionally create attribute
  for read frequency (bsc#1012628).
- platform/x86: msi-ec: Fix the 3rd config (bsc#1012628).
- platform/x86: asus-wmi: Change ASUS_WMI_BRN_DOWN code from
  0x20 to 0x2e (bsc#1012628).
- platform/x86: asus-wmi: Only map brightness codes when using
  asus-wmi backlight control (bsc#1012628).
- platform/x86: asus-wmi: Map 0x2a code, Ignore 0x2b and 0x2c
  events (bsc#1012628).
- rust: error: fix the description for `ECHILD` (bsc#1012628).
- gpiolib: acpi: Add missing memset(0) to
  acpi_get_gpiod_from_data() (bsc#1012628).
- gpio: vf610: set value before the direction to avoid a glitch
  (bsc#1012628).
- gpio: vf610: mask the gpio irq in system suspend and support
  wakeup (bsc#1012628).
- ASoC: cs35l56: Fix illegal use of init_completion()
  (bsc#1012628).
- ASoC: pxa: fix a memory leak in probe() (bsc#1012628).
- ASoC: cs42l42: Fix missing include of gpio/consumer.h
  (bsc#1012628).
- drm/bridge: ti-sn65dsi86: Associate DSI device lifetime with
  auxiliary device (bsc#1012628).
- drm/i915/cx0: Only clear/set the Pipe Reset bit of the PHY
  Lanes Owned (bsc#1012628).
- drm/amdgpu: Fix possible null pointer dereference (bsc#1012628).
- powerpc/mm: Allow ARCH_FORCE_MAX_ORDER up to 12 (bsc#1012628).
- powerpc/qspinlock: Fix stale propagated yield_cpu (bsc#1012628).
- docs: Move rustdoc output, cross-reference it (bsc#1012628).
- rust: docs: fix logo replacement (bsc#1012628).
- phy: mapphone-mdm6600: Fix runtime disable on probe
  (bsc#1012628).
- phy: mapphone-mdm6600: Fix runtime PM for remove (bsc#1012628).
- phy: mapphone-mdm6600: Fix pinctrl_pm handling for sleep pins
  (bsc#1012628).
- phy: qcom-qmp-usb: initialize PCS_USB registers (bsc#1012628).
- phy: qcom-qmp-usb: split PCS_USB init table for sc8280xp and
  sa8775p (bsc#1012628).
- phy: qcom-qmp-combo: Square out 8550 POWER_STATE_CONFIG1
  (bsc#1012628).
- phy: qcom-qmp-combo: initialize PCS_USB registers (bsc#1012628).
- efi/unaccepted: Fix soft lockups caused by parallel memory
  acceptance (bsc#1012628).
- net: move altnames together with the netdevice (bsc#1012628).
- Bluetooth: hci_sock: fix slab oob read in create_monitor_event
  (bsc#1012628).
- net: rfkill: reduce data->mtx scope in rfkill_fop_open
  (bsc#1012628).
- docs: rust: update Rust docs output path (bsc#1012628).
- kbuild: remove old Rust docs output path (bsc#1012628).
- Bluetooth: hci_sock: Correctly bounds check and pad
  HCI_MON_NEW_INDEX name (bsc#1012628).
- mptcp: avoid sending RST when closing the initial subflow
  (bsc#1012628).
- selftests: mptcp: join: correctly check for no RST
  (bsc#1012628).
- Rename to
  patches.kernel.org/6.5.9-178-NFSv4.1-fixup-use-EXCHGID4_FLAG_USE_PNFS_DS-for.patch.
- commit 29edc7c
* Mon Oct 23 2023 jslaby@suse.cz
- Refresh
  patches.suse/NFSv4-1-fixup-use-EXCHGID4-FLAG-USE-PNFS-DS-for-DS-server-.patch.
  Update upstream status.
- commit 06d7c82
* Mon Oct 23 2023 mkubecek@suse.cz
- Update to 6.6-rc7
- refresh configs
- commit 4a117b4
* Fri Oct 20 2023 dmueller@suse.com
- config.conf: Reenable arm64
- Update config files:
  * Same settings like x86_64, plus all ARM specific errata turned on
  * rest all mod
- commit 5e5e96e
* Fri Oct 20 2023 clin@suse.com
- Refresh
  patches.suse/firmware-Add-support-for-Qualcomm-UEFI-Secure-Applic.patch.
- Refresh
  patches.suse/firmware-qcom_scm-Add-support-for-Qualcomm-Secure-Ex.patch.
- Refresh
  patches.suse/lib-ucs2_string-Add-UCS-2-strscpy-function.patch.
  Update upstream status.
- commit ee580b5
* Fri Oct 20 2023 clin@suse.com
- Delete
  patches.suse/clk-qcom-sc8280xp-Add-fallback-compatibles-to-lpasscc.patch.
  Removed lpasscc fallback compatibles since Lenovo X13s UEFI FW has fixes since v1.58
- commit d32d7cb
* Fri Oct 20 2023 jslaby@suse.cz
- Linux 6.5.8 (bsc#1012628).
- net: stmmac: remove unneeded stmmac_poll_controller
  (bsc#1012628).
- RDMA/cxgb4: Check skb value for failure to allocate
  (bsc#1012628).
- perf/arm-cmn: Fix the unhandled overflow status of counter 4
  to 7 (bsc#1012628).
- platform/x86: think-lmi: Fix reference leak (bsc#1012628).
- drm/i915: Register engines early to avoid type confusion
  (bsc#1012628).
- cpuidle, ACPI: Evaluate LPI arch_flags for broadcast timer
  (bsc#1012628).
- drm/amdgpu: Fix a memory leak (bsc#1012628).
- platform/x86: hp-wmi:: Mark driver struct with __refdata to
  prevent section mismatch warning (bsc#1012628).
- media: dt-bindings: imx7-csi: Make power-domains not required
  for imx8mq (bsc#1012628).
- drm/amd/display: implement pipe type definition and adding
  accessors (bsc#1012628).
- drm/amd/display: apply edge-case DISPCLK WDIVIDER changes to
  master OTG pipes only (bsc#1012628).
- scsi: Do not rescan devices with a suspended queue
  (bsc#1012628).
- ata: pata_parport: fix pata_parport_devchk (bsc#1012628).
- ata: pata_parport: implement set_devctl (bsc#1012628).
- HID: logitech-hidpp: Fix kernel crash on receiver USB disconnect
  (bsc#1012628).
- quota: Fix slow quotaoff (bsc#1012628).
- dm crypt: Fix reqsize in crypt_iv_eboiv_gen (bsc#1012628).
- ASoC: amd: yc: Fix non-functional mic on Lenovo 82YM
  (bsc#1012628).
- ASoC: hdmi-codec: Fix broken channel map reporting
  (bsc#1012628).
- ata: libata-scsi: Disable scsi device manage_system_start_stop
  (bsc#1012628).
- net: prevent address rewrite in kernel_bind() (bsc#1012628).
- arm64: dts: qcom: sm8150: extend the size of the PDC resource
  (bsc#1012628).
- dt-bindings: interrupt-controller: renesas,rzg2l-irqc: Update
  description for '#interrupt-cells' property (bsc#1012628).
- irqchip: renesas-rzg2l: Fix logic to clear TINT interrupt source
  (bsc#1012628).
- KEYS: trusted: Remove redundant static calls usage
  (bsc#1012628).
- ALSA: usb-audio: Fix microphone sound on Opencomm2 Headset
  (bsc#1012628).
- ALSA: usb-audio: Fix microphone sound on Nexigo webcam
  (bsc#1012628).
- ALSA: hda: cs35l41: Cleanup and fix double free in firmware
  request (bsc#1012628).
- ALSA: hda/realtek: Change model for Intel RVP board
  (bsc#1012628).
- ASoC: SOF: amd: fix for firmware reload failure after playback
  (bsc#1012628).
- ASoC: simple-card-utils: fixup simple_util_startup() error
  handling (bsc#1012628).
- ASoC: Intel: soc-acpi: fix Dell SKU 0B34 (bsc#1012628).
- ASoC: Intel: soc-acpi: Add entry for HDMI_In capture support
  in MTL match table (bsc#1012628).
- ASoC: fsl_sai: Don't disable bitclock for i.MX8MP (bsc#1012628).
- ASoC: Intel: sof_sdw: add support for SKU 0B14 (bsc#1012628).
- ASoC: Intel: soc-acpi: Add entry for sof_es8336 in MTL match
  table (bsc#1012628).
- ALSA: hda/realtek: Add quirk for HP Victus 16-d1xxx to enable
  mute LED (bsc#1012628).
- ALSA: hda/realtek: Add quirk for mute LEDs on HP ENVY x360
  15-eu0xxx (bsc#1012628).
- ALSA: hda/realtek - ALC287 I2S speaker platform support
  (bsc#1012628).
- ALSA: hda/realtek - ALC287 merge RTK codec with CS CS35L41 AMP
  (bsc#1012628).
- pinctrl: nuvoton: wpcm450: fix out of bounds write
  (bsc#1012628).
- pinctrl: starfive: jh7110: Fix failure to set irq after
  CONFIG_PM is enabled (bsc#1012628).
- drm/msm/dp: do not reinitialize phy unless retry during link
  training (bsc#1012628).
- drm/msm/dsi: skip the wait for video mode done if not applicable
  (bsc#1012628).
- drm/msm/dsi: fix irq_of_parse_and_map() error checking
  (bsc#1012628).
- drm/msm/dpu: change _dpu_plane_calc_bw() to use u64 to avoid
  overflow (bsc#1012628).
- drm/msm/dp: Add newlines to debug printks (bsc#1012628).
- drm/msm/dpu: fail dpu_plane_atomic_check() based on mdp clk
  limits (bsc#1012628).
- phy: lynx-28g: cancel the CDR check work item on the remove path
  (bsc#1012628).
- phy: lynx-28g: lock PHY while performing CDR lock workaround
  (bsc#1012628).
- phy: lynx-28g: serialize concurrent phy_set_mode_ext() calls
  to shared registers (bsc#1012628).
- net: dsa: qca8k: fix regmap bulk read/write methods on big
  endian systems (bsc#1012628).
- net: dsa: qca8k: fix potential MDIO bus conflict when accessing
  internal PHYs via management frames (bsc#1012628).
- can: isotp: isotp_sendmsg(): fix TX state detection and wait
  behavior (bsc#1012628).
- can: sun4i_can: Only show Kconfig if ARCH_SUNXI is set
  (bsc#1012628).
- arm64: dts: mediatek: fix t-phy unit name (bsc#1012628).
- arm64: dts: mediatek: mt8195: Set DSU PMU status to fail
  (bsc#1012628).
- devlink: Hold devlink lock on health reporter dump get
  (bsc#1012628).
- ravb: Fix up dma_free_coherent() call in ravb_remove()
  (bsc#1012628).
- ravb: Fix use-after-free issue in ravb_tx_timeout_work()
  (bsc#1012628).
- ieee802154: ca8210: Fix a potential UAF in ca8210_probe
  (bsc#1012628).
- mlxsw: fix mlxsw_sp2_nve_vxlan_learning_set() return type
  (bsc#1012628).
- xen-netback: use default TX queue size for vifs (bsc#1012628).
- riscv, bpf: Sign-extend return values (bsc#1012628).
- riscv, bpf: Track both a0 (RISC-V ABI) and a5 (BPF) return
  values (bsc#1012628).
- xdp: Fix zero-size allocation warning in xskq_create()
  (bsc#1012628).
- drm/vmwgfx: fix typo of sizeof argument (bsc#1012628).
- bpf: Fix verifier log for async callback return values
  (bsc#1012628).
- net: refine debug info in skb_checksum_help() (bsc#1012628).
- octeontx2-pf: mcs: update PN only when update_pn is true
  (bsc#1012628).
- net: macsec: indicate next pn update when offloading
  (bsc#1012628).
- net: phy: mscc: macsec: reject PN update requests (bsc#1012628).
- net/mlx5e: macsec: use update_pn flag instead of PN comparation
  (bsc#1012628).
- drm/panel: boe-tv101wum-nl6: Completely pull GPW to VGL before
  TP term (bsc#1012628).
- ixgbe: fix crash with empty VF macvlan list (bsc#1012628).
- net/smc: Fix dependency of SMC on ISM (bsc#1012628).
- net/mlx5e: Again mutually exclude RX-FCS and RX-port-timestamp
  (bsc#1012628).
- s390/bpf: Fix clobbering the caller's backchain in the
  trampoline (bsc#1012628).
- s390/bpf: Fix unwinding past the trampoline (bsc#1012628).
- net: nfc: fix races in nfc_llcp_sock_get() and
  nfc_llcp_sock_get_sn() (bsc#1012628).
- net/smc: Fix pos miscalculation in statistics (bsc#1012628).
- net: tcp: fix crashes trying to free half-baked MTU probes
  (bsc#1012628).
- pinctrl: renesas: rzn1: Enable missing PINMUX (bsc#1012628).
- af_packet: Fix fortified memcpy() without flex array
  (bsc#1012628).
- nfc: nci: assert requested protocol is valid (bsc#1012628).
- octeontx2-pf: Fix page pool frag allocation warning
  (bsc#1012628).
- rswitch: Fix renesas_eth_sw_remove() implementation
  (bsc#1012628).
- rswitch: Fix imbalance phy_power_off() calling (bsc#1012628).
- workqueue: Override implicit ordered attribute in
  workqueue_apply_unbound_cpumask() (bsc#1012628).
- riscv: signal: fix sigaltstack frame size checking
  (bsc#1012628).
- ovl: temporarily disable appending lowedirs (bsc#1012628).
- dmaengine: stm32-mdma: abort resume if no ongoing transfer
  (bsc#1012628).
- dmaengine: stm32-dma: fix stm32_dma_prep_slave_sg in case of
  MDMA chaining (bsc#1012628).
- dmaengine: stm32-dma: fix residue in case of MDMA chaining
  (bsc#1012628).
- dmaengine: stm32-mdma: use Link Address Register to compute
  residue (bsc#1012628).
- dmaengine: stm32-mdma: set in_flight_bytes in case CRQA flag
  is set (bsc#1012628).
- usb: xhci: xhci-ring: Use sysdev for mapping bounce buffer
  (bsc#1012628).
- xhci: track port suspend state correctly in unsuccessful resume
  cases (bsc#1012628).
- xhci: Clear EHB bit only at end of interrupt handler
  (bsc#1012628).
- xhci: Preserve RsvdP bits in ERSTBA register correctly
  (bsc#1012628).
- net: usb: dm9601: fix uninitialized variable use in
  dm9601_mdio_read (bsc#1012628).
- usb: dwc3: Soft reset phy on probe for host (bsc#1012628).
- usb: cdns3: Modify the return value of cdns_set_active ()
  to void when CONFIG_PM_SLEEP is disabled (bsc#1012628).
- usb: hub: Guard against accesses to uninitialized BOS
  descriptors (bsc#1012628).
- usb: musb: Get the musb_qh poniter after musb_giveback
  (bsc#1012628).
- usb: musb: Modify the "HWVers" register address (bsc#1012628).
- iio: pressure: bmp280: Fix NULL pointer exception (bsc#1012628).
- iio: imu: bno055: Fix missing Kconfig dependencies
  (bsc#1012628).
- iio: cros_ec: fix an use-after-free in
  cros_ec_sensors_push_data() (bsc#1012628).
- iio: adc: imx8qxp: Fix address for command buffer registers
  (bsc#1012628).
- iio: dac: ad3552r: Correct device IDs (bsc#1012628).
- iio: admv1013: add mixer_vgate corner cases (bsc#1012628).
- iio: pressure: dps310: Adjust Timeout Settings (bsc#1012628).
- iio: pressure: ms5611: ms5611_prom_is_valid false negative bug
  (bsc#1012628).
- iio: adc: ad7192: Correct reference voltage (bsc#1012628).
- iio: addac: Kconfig: update ad74413r selections (bsc#1012628).
- media: subdev: Don't report V4L2_SUBDEV_CAP_STREAMS when the
  streams API is disabled (bsc#1012628).
- arm64: dts: mediatek: mt8195-demo: fix the memory size to 8GB
  (bsc#1012628).
- arm64: dts: mediatek: mt8195-demo: update and reorder reserved
  memory regions (bsc#1012628).
- drm: Do not overrun array in drm_gem_get_pages() (bsc#1012628).
- drm/tiny: correctly print `struct resource *` on error
  (bsc#1012628).
- drm/atomic-helper: relax unregistered connector check
  (bsc#1012628).
- drm/amdgpu: add missing NULL check (bsc#1012628).
- drm/amd/display: Don't set dpms_off for seamless boot
  (bsc#1012628).
- drm/vmwgfx: Keep a gem reference to user bos in surfaces
  (bsc#1012628).
- ACPI: resource: Skip IRQ override on ASUS ExpertBook B1402CBA
  (bsc#1012628).
- ACPI: resource: Add TongFang GM6BGEQ, GM6BG5Q and GM6BG0Q to
  irq1_edge_low_force_override[] (bsc#1012628).
- ACPI: EC: Add quirk for the HP Pavilion Gaming 15-dk1xxx
  (bsc#1012628).
- serial: Reduce spinlocked portion of uart_rs485_config()
  (bsc#1012628).
- serial: 8250_omap: Fix errors with no_console_suspend
  (bsc#1012628).
- serial: core: Fix checks for tx runtime PM state (bsc#1012628).
- binder: fix memory leaks of spam and pending work (bsc#1012628).
- ksmbd: not allow to open file if delelete on close bit is set
  (bsc#1012628).
- perf/x86/lbr: Filter vsyscall addresses (bsc#1012628).
- x86/cpu: Fix AMD erratum #1485 on Zen4-based CPUs (bsc#1012628).
- x86/alternatives: Disable KASAN in apply_alternatives()
  (bsc#1012628).
- mcb: remove is_added flag from mcb_device struct (bsc#1012628).
- thunderbolt: Workaround an IOMMU fault on certain systems with
  Intel Maple Ridge (bsc#1012628).
- thunderbolt: Check that lane 1 is in CL0 before enabling lane
  bonding (bsc#1012628).
- thunderbolt: Correct TMU mode initialization from hardware
  (bsc#1012628).
- thunderbolt: Restart XDomain discovery handshake after failure
  (bsc#1012628).
- powerpc/pseries: Fix STK_PARAM access in the hcall tracing code
  (bsc#1012628).
- powerpc/47x: Fix 47x syscall return crash (bsc#1012628).
- libceph: use kernel_connect() (bsc#1012628).
- ceph: fix incorrect revoked caps assert in ceph_fill_file_size()
  (bsc#1012628).
- ceph: fix type promotion bug on 32bit systems (bsc#1012628).
- Input: powermate - fix use-after-free in
  powermate_config_complete (bsc#1012628).
- Input: psmouse - fix fast_reconnect function for PS/2 mode
  (bsc#1012628).
- Input: xpad - add PXN V900 support (bsc#1012628).
- Input: i8042 - add Fujitsu Lifebook E5411 to i8042 quirk table
  (bsc#1012628).
- Input: xpad - add HyperX Clutch Gladiate Support (bsc#1012628).
- Input: goodix - ensure int GPIO is in input for gpio_count ==
  1 && gpio_int_idx == 0 case (bsc#1012628).
- tee: amdtee: fix use-after-free vulnerability in
  amdtee_close_session (bsc#1012628).
- mctp: perform route lookups under a RCU read-side lock
  (bsc#1012628).
- block: Don't invalidate pagecache for invalid falloc modes
  (bsc#1012628).
- nfp: flower: avoid rmmod nfp crash issues (bsc#1012628).
- can: sja1000: Always restart the Tx queue after an overrun
  (bsc#1012628).
- power: supply: qcom_battmgr: fix battery_id type (bsc#1012628).
- power: supply: qcom_battmgr: fix enable request endianness
  (bsc#1012628).
- usb: typec: ucsi: Use GET_CAPABILITY attributes data to set
  power supply scope (bsc#1012628).
- cgroup: Remove duplicates in cgroup v1 tasks file (bsc#1012628).
- dma-buf: add dma_fence_timestamp helper (bsc#1012628).
- pinctrl: avoid unsafe code pattern in find_pinctrl()
  (bsc#1012628).
- scsi: ufs: core: Correct clear TM error log (bsc#1012628).
- riscv: Only consider swbp/ss handlers for correct privileged
  mode (bsc#1012628).
- counter: chrdev: fix getting array extensions (bsc#1012628).
- counter: microchip-tcb-capture: Fix the use of internal GCLK
  logic (bsc#1012628).
- coresight: Fix run time warnings while reusing ETR buffer
  (bsc#1012628).
- riscv: Remove duplicate objcopy flag (bsc#1012628).
- RISC-V: Fix wrong use of CONFIG_HAVE_SOFTIRQ_ON_OWN_STACK
  (bsc#1012628).
- usb: typec: ucsi: Fix missing link removal (bsc#1012628).
- usb: typec: altmodes/displayport: Signal hpd low when exiting
  mode (bsc#1012628).
- usb: typec: ucsi: Clear EVENT_PENDING bit if ucsi_send_command
  fails (bsc#1012628).
- usb: gadget: udc-xilinx: replace memcpy with memcpy_toio
  (bsc#1012628).
- usb: gadget: ncm: Handle decoding of multiple NTB's in unwrap
  call (bsc#1012628).
- usb: cdnsp: Fixes issue with dequeuing not queued requests
  (bsc#1012628).
- usb: typec: qcom: Update the logic of regulator enable and
  disable (bsc#1012628).
- usb: misc: onboard_hub: add support for Microchip USB2412 USB
  2.0 hub (bsc#1012628).
- dmaengine: idxd: use spin_lock_irqsave before
  wait_event_lock_irq (bsc#1012628).
- dmaengine: mediatek: Fix deadlock caused by synchronize_irq()
  (bsc#1012628).
- powerpc/8xx: Fix pte_access_permitted() for PAGE_NONE
  (bsc#1012628).
- powerpc/64e: Fix wrong test in __ptep_test_and_clear_young()
  (bsc#1012628).
- fs: Fix kernel-doc warnings (bsc#1012628).
- fs: factor out vfs_parse_monolithic_sep() helper (bsc#1012628).
- ovl: fix regression in parsing of mount options with escaped
  comma (bsc#1012628).
- ovl: make use of ->layers safe in rcu pathwalk (bsc#1012628).
- ovl: fix regression in showing lowerdir mount option
  (bsc#1012628).
- ALSA: hda/realtek - Fixed two speaker platform (bsc#1012628).
- Rename to
  patches.kernel.org/6.5.8-179-Revert-x86-smp-Put-CPUs-into-INIT-on-shutdown-i.patch.
- commit 51baea8
* Thu Oct 19 2023 mbrugger@suse.com
- arm64: Update config files.
  Make iMX93 clock and pinctrl driver build-in.
- commit 897b0cf
* Tue Oct 17 2023 neilb@suse.de
- NFSv4.1: fixup use EXCHGID4_FLAG_USE_PNFS_DS for DS server
  (bsc#1216201).
- commit 1dbb418
* Mon Oct 16 2023 jslaby@suse.cz
- Revert "x86/smp: Put CPUs into INIT on shutdown if possible"
  (shutdown-issue).
- commit 9fcbf99
* Sun Oct 15 2023 mkubecek@suse.cz
- Update to 6.6-rc6
- refresh configs
- commit 8f5995d
* Sat Oct 14 2023 matwey.kornilov@gmail.com
- config: Reenable Rockchip RK8XX hardware
  In Linux commit
    c20e8c5b1203 ("mfd: rk808: Split into core and i2c")
  CONFIG_MFD_RK808 was renamed to CONFIG_MFD_RK8XX.
  Reenable options required to boot kernel 6.5 on Rock64 board.
- commit 41037b9
* Wed Oct 11 2023 jslaby@suse.cz
- Linux 6.5.7 (bsc#1012628).
- xen/events: replace evtchn_rwlock with RCU (bsc#1012628).
- RDMA/mlx5: Remove not-used cache disable flag (bsc#1012628).
- ksmbd: fix race condition from parallel smb2 lock requests
  (bsc#1012628).
- ksmbd: fix uaf in smb20_oplock_break_ack (bsc#1012628).
- ksmbd: fix race condition between session lookup and expire
  (bsc#1012628).
- x86/sev: Use the GHCB protocol when available for SNP CPUID
  requests (bsc#1012628).
- x86/sev: Change npages to unsigned long in snp_accept_memory()
  (bsc#1012628).
- RDMA/mlx5: Fix NULL string error (bsc#1012628).
- RDMA/mlx5: Fix mutex unlocking on error flow for steering
  anchor creation (bsc#1012628).
- RDMA/mlx5: Fix assigning access flags to cache mkeys
  (bsc#1012628).
- RDMA/mlx5: Fix mkey cache possible deadlock on cleanup
  (bsc#1012628).
- RDMA/siw: Fix connection failure handling (bsc#1012628).
- RDMA/srp: Do not call scsi_done() from srp_abort()
  (bsc#1012628).
- RDMA/uverbs: Fix typo of sizeof argument (bsc#1012628).
- RDMA/bnxt_re: Fix the handling of control path response data
  (bsc#1012628).
- RDMA/cma: Fix truncation compilation warning in make_cma_ports
  (bsc#1012628).
- RDMA/cma: Initialize ib_sa_multicast structure to 0 when join
  (bsc#1012628).
- gpio: pxa: disable pinctrl calls for MMP_GPIO (bsc#1012628).
- gpio: aspeed: fix the GPIO number passed to
  pinctrl_gpio_set_config() (bsc#1012628).
- IB/mlx4: Fix the size of a buffer in add_port_entries()
  (bsc#1012628).
- of: dynamic: Fix potential memory leak in of_changeset_action()
  (bsc#1012628).
- RDMA/core: Require admin capabilities to set system parameters
  (bsc#1012628).
- dm zoned: free dmz->ddev array in dmz_put_zoned_devices
  (bsc#1012628).
- parisc: Fix crash with nr_cpus=1 option (bsc#1012628).
- smb: use kernel_connect() and kernel_bind() (bsc#1012628).
- parisc: Restore __ldcw_align for PA-RISC 2.0 processors
  (bsc#1012628).
- net: lan743x: also select PHYLIB (bsc#1012628).
- HID: intel-ish-hid: ipc: Disable and reenable ACPI GPE bit
  (bsc#1012628).
- HID: sony: remove duplicate NULL check before calling
  usb_free_urb() (bsc#1012628).
- HID: nvidia-shield: Fix a missing led_classdev_unregister()
  in the probe error handling path (bsc#1012628).
- net: mana: Fix oversized sge0 for GSO packets (bsc#1012628).
- net: mana: Fix the tso_bytes calculation (bsc#1012628).
- netlink: annotate data-races around sk->sk_err (bsc#1012628).
- sctp: update hb timer immediately after users change hb_interval
  (bsc#1012628).
- sctp: update transport state when processing a dupcook packet
  (bsc#1012628).
- tcp: fix delayed ACKs for MSS boundary condition (bsc#1012628).
- tcp: fix quick-ack counting to count actual ACKs of new data
  (bsc#1012628).
- tipc: fix a potential deadlock on &tx->lock (bsc#1012628).
- net: stmmac: dwmac-stm32: fix resume on STM32 MCU (bsc#1012628).
- ipv4: Set offload_failed flag in fibmatch results (bsc#1012628).
- netfilter: nf_tables: nft_set_rbtree: fix spurious insertion
  failure (bsc#1012628).
- netfilter: nf_tables: Deduplicate nft_register_obj audit logs
  (bsc#1012628).
- selftests: netfilter: Extend nft_audit.sh (bsc#1012628).
- selftests: netfilter: Test nf_tables audit logging
  (bsc#1012628).
- netfilter: handle the connecting collision properly in
  nf_conntrack_proto_sctp (bsc#1012628).
- netfilter: nft_payload: rebuild vlan header on h_proto access
  (bsc#1012628).
- ibmveth: Remove condition to recompute TCP header checksum
  (bsc#1012628).
- net: ethernet: ti: am65-cpsw: Fix error code in
  am65_cpsw_nuss_init_tx_chns() (bsc#1012628).
- rswitch: Fix PHY station management clock setting (bsc#1012628).
- net: renesas: rswitch: Add spin lock protection for irq {un}mask
  (bsc#1012628).
- net: nfc: llcp: Add lock when modifying device list
  (bsc#1012628).
- ethtool: plca: fix plca enable data type while parsing the value
  (bsc#1012628).
- net: usb: smsc75xx: Fix uninit-value access in
  __smsc75xx_read_reg (bsc#1012628).
- ipv6: tcp: add a missing nf_reset_ct() in 3WHS handling
  (bsc#1012628).
- ovl: fetch inode once in ovl_dentry_revalidate_common()
  (bsc#1012628).
- ovl: move freeing ovl_entry past rcu delay (bsc#1012628).
- net: dsa: mv88e6xxx: Avoid EEPROM timeout when EEPROM is absent
  (bsc#1012628).
- ptp: ocp: Fix error handling in ptp_ocp_device_init
  (bsc#1012628).
- ipv4, ipv6: Fix handling of transhdrlen in
  __ip{,6}_append_data() (bsc#1012628).
- neighbour: fix data-races around n->output (bsc#1012628).
- net: fix possible store tearing in neigh_periodic_work()
  (bsc#1012628).
- net: stmmac: platform: fix the incorrect parameter
  (bsc#1012628).
- modpost: add missing else to the "of" check (bsc#1012628).
- bpf, sockmap: Reject sk_msg egress redirects to non-TCP sockets
  (bsc#1012628).
- bpf, sockmap: Do not inc copied_seq when PEEK flag set
  (bsc#1012628).
- bpf: tcp_read_skb needs to pop skb regardless of seq
  (bsc#1012628).
- ice: always add legacy 32byte RXDID in supported_rxdids
  (bsc#1012628).
- NFSv4: Fix a nfs4_state_manager() race (bsc#1012628).
- ima: rework CONFIG_IMA dependency block (bsc#1012628).
- scsi: target: core: Fix deadlock due to recursive locking
  (bsc#1012628).
- wifi: iwlwifi: mvm: Fix incorrect usage of scan API
  (bsc#1012628).
- ima: Finish deprecation of IMA_TRUSTED_KEYRING Kconfig
  (bsc#1012628).
- Update config files (set the defaults).
- regulator/core: regulator_register: set device->class earlier
  (bsc#1012628).
- wifi: mac80211: Create resources for disabled links
  (bsc#1012628).
- iommu/mediatek: Fix share pgtable for iova over 4GB
  (bsc#1012628).
- perf/x86/amd: Do not WARN() on every IRQ (bsc#1012628).
- wifi: mac80211: fix potential key use-after-free (bsc#1012628).
- regmap: rbtree: Fix wrong register marked as in-cache when
  creating new node (bsc#1012628).
- rtla/timerlat: Do not stop user-space if a cpu is offline
  (bsc#1012628).
- perf/x86/amd/core: Fix overflow reset on hotplug (bsc#1012628).
- wifi: mt76: mt76x02: fix MT76x0 external LNA gain handling
  (bsc#1012628).
- drivers/net: process the result of hdlc_open() and add call
  of hdlc_close() in uhdlc_close() (bsc#1012628).
- Bluetooth: ISO: Fix handling of listen for unicast
  (bsc#1012628).
- Bluetooth: Fix hci_link_tx_to RCU lock usage (bsc#1012628).
- Bluetooth: Delete unused hci_req_prepare_suspend() declaration
  (bsc#1012628).
- regulator: mt6358: split ops for buck and linear range LDO
  regulators (bsc#1012628).
- bpf: unconditionally reset backtrack_state masks on global
  func exit (bsc#1012628).
- bpf: Fix tr dereferencing (bsc#1012628).
- leds: Drop BUG_ON check for LED_COLOR_ID_MULTI (bsc#1012628).
- s390/bpf: Let arch_prepare_bpf_trampoline return program size
  (bsc#1012628).
- erofs: allow empty device tags in flatdev mode (bsc#1012628).
- HID: nvidia-shield: add LEDS_CLASS dependency (bsc#1012628).
- wifi: mwifiex: Fix oob check condition in
  mwifiex_process_rx_packet (bsc#1012628).
- wifi: mac80211: fix mesh id corruption on 32 bit systems
  (bsc#1012628).
- wifi: cfg80211: add missing kernel-doc for cqm_rssi_work
  (bsc#1012628).
- rtla/timerlat_aa: Fix previous IRQ delay for IRQs that happens
  after thread sample (bsc#1012628).
- rtla/timerlat_aa: Fix negative IRQ delay (bsc#1012628).
- rtla/timerlat_aa: Zero thread sum after every sample analysis
  (bsc#1012628).
- wifi: cfg80211: fix cqm_config access race (bsc#1012628).
- wifi: iwlwifi: mvm: Fix a memory corruption issue (bsc#1012628).
- wifi: iwlwifi: dbg_ini: fix structure packing (bsc#1012628).
- iwlwifi: mvm: handle PS changes in vif_cfg_changed
  (bsc#1012628).
- wifi: cfg80211/mac80211: hold link BSSes when assoc fails for
  MLO connection (bsc#1012628).
- erofs: fix memory leak of LZMA global compressed deduplication
  (bsc#1012628).
- ubi: Refuse attaching if mtd's erasesize is 0 (bsc#1012628).
- wifi: mt76: fix lock dependency problem for wed_lock
  (bsc#1012628).
- HID: sony: Fix a potential memory leak in sony_probe()
  (bsc#1012628).
- arm64: errata: Add Cortex-A520 speculative unprivileged load
  workaround (bsc#1012628).
- Update config files (use the default).
- arm64: Add Cortex-A520 CPU part definition (bsc#1012628).
- drm/amd: Fix logic error in
  sienna_cichlid_update_pcie_parameters() (bsc#1012628).
- drm/amd: Fix detection of _PR3 on the PCIe root port
  (bsc#1012628).
- drm/i915: Don't set PIPE_CONTROL_FLUSH_L3 for aux inval
  (bsc#1012628).
- net: prevent rewrite of msg_name in sock_sendmsg()
  (bsc#1012628).
- btrfs: always print transaction aborted messages with an error
  level (bsc#1012628).
- io_uring: ensure io_lockdep_assert_cq_locked() handles disabled
  rings (bsc#1012628).
- io_uring/kbuf: don't allow registered buffer rings on highmem
  pages (bsc#1012628).
- net: replace calls to sock->ops->connect() with kernel_connect()
  (bsc#1012628).
- platform/x86/intel/ifs: release cpus_read_lock() (bsc#1012628).
- PCI: qcom: Fix IPQ8074 enumeration (bsc#1012628).
- PCI/PM: Mark devices disconnected if upstream PCIe link is
  down on resume (bsc#1012628).
- md/raid5: release batch_last before waiting for another
  stripe_head (bsc#1012628).
- io_uring: don't allow IORING_SETUP_NO_MMAP rings on highmem
  pages (bsc#1012628).
- wifi: mwifiex: Fix tlv_buf_left calculation (bsc#1012628).
- wifi: rtw88: rtw8723d: Fix MAC address offset in EEPROM
  (bsc#1012628).
- Bluetooth: hci_sync: Fix handling of
  HCI_QUIRK_STRICT_DUPLICATE_FILTER (bsc#1012628).
- wifi: brcmfmac: Replace 1-element arrays with flexible arrays
  (bsc#1012628).
- Bluetooth: hci_codec: Fix leaking content of local_codecs
  (bsc#1012628).
- qed/red_ll2: Fix undefined behavior bug in struct qed_ll2_info
  (bsc#1012628).
- mptcp: userspace pm allow creating id 0 subflow (bsc#1012628).
- mptcp: fix delegated action races (bsc#1012628).
- net: ethernet: mediatek: disable irq before schedule napi
  (bsc#1012628).
- vringh: don't use vringh_kiov_advance() in vringh_iov_xfer()
  (bsc#1012628).
- net: mana: Fix TX CQE error handling (bsc#1012628).
- iommu/vt-d: Avoid memory allocation in iommu_suspend()
  (bsc#1012628).
- scsi: zfcp: Fix a double put in zfcp_port_enqueue()
  (bsc#1012628).
- iommu/apple-dart: Handle DMA_FQ domains in attach_dev()
  (bsc#1012628).
- maple_tree: add MAS_UNDERFLOW and MAS_OVERFLOW states
  (bsc#1012628).
- maple_tree: reduce resets during store setup (bsc#1012628).
- iommu/arm-smmu-v3: Avoid constructing invalid range commands
  (bsc#1012628).
- net: release reference to inet6_dev pointer (bsc#1012628).
- net: change accept_ra_min_rtr_lft to affect all RA lifetimes
  (bsc#1012628).
- net: add sysctl accept_ra_min_rtr_lft (bsc#1012628).
- arm64: cpufeature: Fix CLRBHB and BC detection (bsc#1012628).
- arm64: add HWCAP for FEAT_HBC (hinted conditional branches)
  (bsc#1012628).
- btrfs: don't clear uptodate on write errors (bsc#1012628).
- btrfs: remove end_extent_writepage (bsc#1012628).
- btrfs: remove btrfs_writepage_endio_finish_ordered
  (bsc#1012628).
- ata: libata-scsi: Fix delayed scsi_rescan_device() execution
  (bsc#1012628).
- scsi: Do not attempt to rescan suspended devices (bsc#1012628).
- scsi: core: Improve type safety of scsi_rescan_device()
  (bsc#1012628).
- mptcp: fix dangling connection hang-up (bsc#1012628).
- mptcp: rename timer related helper to less confusing names
  (bsc#1012628).
- mptcp: Remove unnecessary test for __mptcp_init_sock()
  (bsc#1012628).
- maple_tree: add mas_is_active() to detect in-tree walks
  (bsc#1012628).
- ASoC: tegra: Fix redundant PLLA and PLLA_OUT0 updates
  (bsc#1012628).
- ASoC: soc-utils: Export snd_soc_dai_is_dummy() symbol
  (bsc#1012628).
- commit e060757
* Mon Oct  9 2023 svarbanov@suse.de
- config/arm64: Unset default IOMMU passthrough option (jsc#PED-7009)
  This will effectively enable ARM64 SMMU translation by default,
  which will help to avoid installation and runtime issues on some
  platforms. The passtrhough mode could still be enabled by kernel
  cmdline.
- commit d8da3f8
* Mon Oct  9 2023 schwab@suse.de
- mkspec-dtb: add toplevel symlinks also on arm
- commit ed29cae
* Sun Oct  8 2023 mkubecek@suse.cz
- Update to 6.6-rc5
- update configs
  - IMA_BLACKLIST_KEYRING=n
  - IMA_LOAD_X509=n
  - IPU_BRIDGE=m (new on riscv64)
- commit a59832f
* Sat Oct  7 2023 petr.pavlu@suse.com
- doc/README.PATCH-POLICY.SUSE: Convert the document to Markdown
  (jsc#PED-5021)
- commit c05cfc9
* Sat Oct  7 2023 petr.pavlu@suse.com
- doc/README.SUSE: Convert the document to Markdown (jsc#PED-5021)
- commit bff5e3e
* Fri Oct  6 2023 jslaby@suse.cz
- Linux 6.5.6 (bsc#1012628).
- NFS: Fix error handling for O_DIRECT write scheduling
  (bsc#1012628).
- NFS: Fix O_DIRECT locking issues (bsc#1012628).
- NFS: More O_DIRECT accounting fixes for error paths
  (bsc#1012628).
- NFS: Use the correct commit info in nfs_join_page_group()
  (bsc#1012628).
- NFS: More fixes for nfs_direct_write_reschedule_io()
  (bsc#1012628).
- NFS/pNFS: Report EINVAL errors from connect() to the server
  (bsc#1012628).
- SUNRPC: Mark the cred for revalidation if the server rejects it
  (bsc#1012628).
- NFSv4.1: use EXCHGID4_FLAG_USE_PNFS_DS for DS server
  (bsc#1012628).
- NFSv4.1: fix pnfs MDS=DS session trunking (bsc#1012628).
- media: v4l: Use correct dependency for camera sensor drivers
  (bsc#1012628).
- media: via: Use correct dependency for camera sensor drivers
  (bsc#1012628).
- gfs2: Fix another freeze/thaw hang (bsc#1012628).
- netfs: Only call folio_start_fscache() one time for each folio
  (bsc#1012628).
- btrfs: improve error message after failure to add delayed dir
  index item (bsc#1012628).
- btrfs: remove BUG() after failure to insert delayed dir index
  item (bsc#1012628).
- ext4: replace the traditional ternary conditional operator
  with with max()/min() (bsc#1012628).
- ext4: move setting of trimmed bit into ext4_try_to_trim_range()
  (bsc#1012628).
- ext4: do not let fstrim block system suspend (bsc#1012628).
- netfilter: nft_set_rbtree: use read spinlock to avoid datapath
  contention (bsc#1012628).
- netfilter: nft_set_pipapo: call nft_trans_gc_queue_sync()
  in catchall GC (bsc#1012628).
- netfilter: nft_set_pipapo: stop GC iteration if GC transaction
  allocation fails (bsc#1012628).
- netfilter: nft_set_hash: try later when GC hits EAGAIN on
  iteration (bsc#1012628).
- netfilter: nf_tables: fix memleak when more than 255 elements
  expired (bsc#1012628).
- netfilter: nf_tables: disallow rule removal from chain binding
  (bsc#1012628).
- ASoC: meson: spdifin: start hw on dai probe (bsc#1012628).
- netfilter: nf_tables: disallow element removal on anonymous sets
  (bsc#1012628).
- bpf: Avoid deadlock when using queue and stack maps from NMI
  (bsc#1012628).
- bpf: Avoid dummy bpf_offload_netdev in __bpf_prog_dev_bound_init
  (bsc#1012628).
- ALSA: docs: Fix a typo of midi2_ump_probe option for
  snd-usb-audio (bsc#1012628).
- ALSA: seq: Avoid delivery of events for disabled UMP groups
  (bsc#1012628).
- ASoC: rt5640: Revert "Fix sleep in atomic context"
  (bsc#1012628).
- ASoC: rt5640: Fix sleep in atomic context (bsc#1012628).
- ASoC: rt5640: fix typos (bsc#1012628).
- ASoC: rt5640: Do not disable/enable IRQ twice on suspend/resume
  (bsc#1012628).
- ASoC: rt5640: Enable the IRQ on resume after configuring
  jack-detect (bsc#1012628).
- ASoC: rt5640: Fix IRQ not being free-ed for HDA jack detect mode
  (bsc#1012628).
- bpf: Fix a erroneous check after snprintf() (bsc#1012628).
- selftests/bpf: fix unpriv_disabled check in test_verifier
  (bsc#1012628).
- ALSA: hda/realtek: Splitting the UX3402 into two separate models
  (bsc#1012628).
- netfilter: conntrack: fix extension size table (bsc#1012628).
- netfilter: nf_tables: Fix entries val in rule reset audit log
  (bsc#1012628).
- Compiler Attributes: counted_by: Adjust name and identifier
  expansion (bsc#1012628).
- uapi: stddef.h: Fix header guard location (bsc#1012628).
- uapi: stddef.h: Fix __DECLARE_FLEX_ARRAY for C++ (bsc#1012628).
- memblock tests: Fix compilation errors (bsc#1012628).
- ASoC: SOF: ipc4-topology: fix wrong sizeof argument
  (bsc#1012628).
- net: microchip: sparx5: Fix memory leak for
  vcap_api_rule_add_keyvalue_test() (bsc#1012628).
- net: microchip: sparx5: Fix memory leak for
  vcap_api_rule_add_actionvalue_test() (bsc#1012628).
- net: microchip: sparx5: Fix possible memory leak in
  vcap_api_encode_rule_test() (bsc#1012628).
- net: microchip: sparx5: Fix possible memory leaks in
  test_vcap_xn_rule_creator() (bsc#1012628).
- net: microchip: sparx5: Fix possible memory leaks in
  vcap_api_kunit (bsc#1012628).
- selftests: tls: swap the TX and RX sockets in some tests
  (bsc#1012628).
- net/core: Fix ETH_P_1588 flow dissector (bsc#1012628).
- ALSA: seq: ump: Fix -Wformat-truncation warning (bsc#1012628).
- ASoC: hdaudio.c: Add missing check for devm_kstrdup
  (bsc#1012628).
- ASoC: imx-audmix: Fix return error with devm_clk_get()
  (bsc#1012628).
- octeon_ep: fix tx dma unmap len values in SG (bsc#1012628).
- iavf: do not process adminq tasks when __IAVF_IN_REMOVE_TASK
  is set (bsc#1012628).
- ASoC: SOF: core: Only call sof_ops_free() on remove if the
  probe was successful (bsc#1012628).
- iavf: add iavf_schedule_aq_request() helper (bsc#1012628).
- iavf: schedule a request immediately after add/delete vlan
  (bsc#1012628).
- i40e: Fix VF VLAN offloading when port VLAN is configured
  (bsc#1012628).
- netfilter, bpf: Adjust timeouts of non-confirmed CTs in
  bpf_ct_insert_entry() (bsc#1012628).
- ionic: fix 16bit math issue when PAGE_SIZE >= 64KB
  (bsc#1012628).
- igc: Fix infinite initialization loop with early XDP redirect
  (bsc#1012628).
- scsi: iscsi_tcp: restrict to TCP sockets (bsc#1012628).
- powerpc/perf/hv-24x7: Update domain value check (bsc#1012628).
- powerpc/dexcr: Move HASHCHK trap handler (bsc#1012628).
- dccp: fix dccp_v4_err()/dccp_v6_err() again (bsc#1012628).
- x86/mm, kexec, ima: Use memblock_free_late() from
  ima_free_kexec_buffer() (bsc#1012628).
- net: hsr: Properly parse HSRv1 supervisor frames (bsc#1012628).
- platform/x86: intel_scu_ipc: Check status after timeout in
  busy_loop() (bsc#1012628).
- platform/x86: intel_scu_ipc: Check status upon timeout in
  ipc_wait_for_interrupt() (bsc#1012628).
- platform/x86: intel_scu_ipc: Don't override scu in
  intel_scu_ipc_dev_simple_command() (bsc#1012628).
- platform/x86: intel_scu_ipc: Fail IPC send if still busy
  (bsc#1012628).
- x86/asm: Fix build of UML with KASAN (bsc#1012628).
- x86/srso: Fix srso_show_state() side effect (bsc#1012628).
- x86/srso: Set CPUID feature bits independently of bug or
  mitigation status (bsc#1012628).
- x86/srso: Don't probe microcode in a guest (bsc#1012628).
- x86/srso: Fix SBPB enablement for spec_rstack_overflow=off
  (bsc#1012628).
- net: hns3: add cmdq check for vf periodic service task
  (bsc#1012628).
- net: hns3: fix GRE checksum offload issue (bsc#1012628).
- net: hns3: only enable unicast promisc when mac table full
  (bsc#1012628).
- net: hns3: fix fail to delete tc flower rules during reset issue
  (bsc#1012628).
- net: hns3: add 5ms delay before clear firmware reset irq source
  (bsc#1012628).
- net: bridge: use DEV_STATS_INC() (bsc#1012628).
- team: fix null-ptr-deref when team device type is changed
  (bsc#1012628).
- locking/atomic: scripts: fix fallback ifdeffery (bsc#1012628).
- net: rds: Fix possible NULL-pointer dereference (bsc#1012628).
- vxlan: Add missing entries to vxlan_get_size() (bsc#1012628).
- netfilter: nf_tables: disable toggling dormant table state
  more than once (bsc#1012628).
- net: hinic: Fix warning-hinic_set_vlan_fliter() warn: variable
  dereferenced before check 'hwdev' (bsc#1012628).
- net/handshake: Fix memory leak in __sock_create() and
  sock_alloc_file() (bsc#1012628).
- i915/pmu: Move execlist stats initialization to execlist
  specific setup (bsc#1012628).
- drm/virtio: clean out_fence on complete_submit (bsc#1012628).
- locking/seqlock: Do the lockdep annotation before locking in
  do_write_seqcount_begin_nested() (bsc#1012628).
- net: ena: Flush XDP packets on error (bsc#1012628).
- bnxt_en: Flush XDP for bnxt_poll_nitroa0()'s NAPI (bsc#1012628).
- octeontx2-pf: Do xdp_do_flush() after redirects (bsc#1012628).
- igc: Expose tx-usecs coalesce setting to user (bsc#1012628).
- cxl/region: Match auto-discovered region decoders by HPA range
  (bsc#1012628).
- proc: nommu: /proc/<pid>/maps: release mmap read lock
  (bsc#1012628).
- proc: nommu: fix empty /proc/<pid>/maps (bsc#1012628).
- gpio: tb10x: Fix an error handling path in tb10x_gpio_probe()
  (bsc#1012628).
- i2c: mux: demux-pinctrl: check the return value of
  devm_kstrdup() (bsc#1012628).
- i2c: mux: gpio: Add missing fwnode_handle_put() (bsc#1012628).
- i2c: xiic: Correct return value check for xiic_reinit()
  (bsc#1012628).
- ASoC: cs35l56: Disable low-power hibernation mode (bsc#1012628).
- drm/amd/display: Update DPG test pattern programming
  (bsc#1012628).
- drm/amd/display: fix a regression in blank pixel data caused
  by coding mistake (bsc#1012628).
- arm64: dts: qcom: sdm845-db845c: Mark cont splash memory region
  as reserved (bsc#1012628).
- direct_write_fallback(): on error revert the ->ki_pos update
  from buffered write (bsc#1012628).
- btrfs: reset destination buffer when read_extent_buffer()
  gets invalid range (bsc#1012628).
- vfio/mdev: Fix a null-ptr-deref bug for mdev_unregister_parent()
  (bsc#1012628).
- MIPS: Alchemy: only build mmc support helpers if au1xmmc is
  enabled (bsc#1012628).
- spi: spi-gxp: BUG: Correct spi write return value (bsc#1012628).
- bus: ti-sysc: Use fsleep() instead of usleep_range() in
  sysc_reset() (bsc#1012628).
- bus: ti-sysc: Fix missing AM35xx SoC matching (bsc#1012628).
- firmware: arm_scmi: Harden perf domain info access
  (bsc#1012628).
- firmware: arm_scmi: Fixup perf power-cost/microwatt support
  (bsc#1012628).
- power: supply: mt6370: Fix missing error code in
  mt6370_chg_toggle_cfo() (bsc#1012628).
- clk: sprd: Fix thm_parents incorrect configuration
  (bsc#1012628).
- clk: si521xx: Use REGCACHE_FLAT instead of NONE (bsc#1012628).
- clk: si521xx: Fix regmap write accessor (bsc#1012628).
- clk: tegra: fix error return case for recalc_rate (bsc#1012628).
- ARM: dts: ti: omap: Fix bandgap thermal cells addressing for
  omap3/4 (bsc#1012628).
- ARM: dts: ti: omap: motorola-mapphone: Fix abe_clkctrl warning
  on boot (bsc#1012628).
- bus: ti-sysc: Fix SYSC_QUIRK_SWSUP_SIDLE_ACT handling for uart
  wake-up (bsc#1012628).
- swiotlb: use the calculated number of areas (bsc#1012628).
- power: supply: ucs1002: fix error code in ucs1002_get_property()
  (bsc#1012628).
- power: supply: rt9467: Fix rt9467_run_aicl() (bsc#1012628).
- power: supply: core: fix use after free in uevent (bsc#1012628).
- firmware: imx-dsp: Fix an error handling path in
  imx_dsp_setup_channels() (bsc#1012628).
- xtensa: add default definition for XCHAL_HAVE_DIV32
  (bsc#1012628).
- xtensa: iss/network: make functions static (bsc#1012628).
- xtensa: boot: don't add include-dirs (bsc#1012628).
- xtensa: umulsidi3: fix conditional expression (bsc#1012628).
- xtensa: boot/lib: fix function prototypes (bsc#1012628).
- power: supply: rk817: Fix node refcount leak (bsc#1012628).
- powerpc/stacktrace: Fix arch_stack_walk_reliable()
  (bsc#1012628).
- selftests/powerpc: Fix emit_tests to work with run_kselftest.sh
  (bsc#1012628).
- arm64: dts: imx8mp: Fix SDMA2/3 clocks (bsc#1012628).
- arm64: dts: imx8mp-beacon-kit: Fix audio_pll2 clock
  (bsc#1012628).
- soc: imx8m: Enable OCOTP clock for imx8mm before reading
  registers (bsc#1012628).
- arm64: dts: imx8mm-evk: Fix hdmi@3d node (bsc#1012628).
- arm64: dts: imx: Add imx8mm-prt8mm.dtb to build (bsc#1012628).
- firmware: arm_ffa: Don't set the memory region attributes for
  MEM_LEND (bsc#1012628).
- i915/guc: Get runtime pm in busyness worker only if already
  active (bsc#1012628).
- accel/ivpu: Do not use wait event interruptible (bsc#1012628).
- accel/ivpu: Use cached buffers for FW loading (bsc#1012628).
- gpio: pmic-eic-sprd: Add can_sleep flag for PMIC EIC chip
  (bsc#1012628).
- i2c: npcm7xx: Fix callback completion ordering (bsc#1012628).
- NFSD: Fix zero NFSv4 READ results when RQ_SPLICE_OK is not set
  (bsc#1012628).
- x86/reboot: VMCLEAR active VMCSes before emergency reboot
  (bsc#1012628).
- ceph: drop messages from MDS when unmounting (bsc#1012628).
- dma-debug: don't call __dma_entry_alloc_check_leak() under
  free_entries_lock (bsc#1012628).
- bpf: Annotate bpf_long_memcpy with data_race (bsc#1012628).
- ASoC: amd: yc: Add DMI entries to support Victus by HP Gaming
  Laptop 15-fb0xxx (8A3E) (bsc#1012628).
- spi: sun6i: reduce DMA RX transfer width to single byte
  (bsc#1012628).
- spi: sun6i: fix race between DMA RX transfer completion and
  RX FIFO drain (bsc#1012628).
- nvme-fc: Prevent null pointer dereference in
  nvme_fc_io_getuuid() (bsc#1012628).
- parisc: sba: Fix compile warning wrt list of SBA devices
  (bsc#1012628).
- parisc: sba-iommu: Fix sparse warnigs (bsc#1012628).
- parisc: ccio-dma: Fix sparse warnings (bsc#1012628).
- parisc: iosapic.c: Fix sparse warnings (bsc#1012628).
- parisc: drivers: Fix sparse warning (bsc#1012628).
- parisc: irq: Make irq_stack_union static to avoid sparse warning
  (bsc#1012628).
- scsi: qedf: Add synchronization between I/O completions and
  abort (bsc#1012628).
- scsi: ufs: core: Move __ufshcd_send_uic_cmd() outside host_lock
  (bsc#1012628).
- scsi: ufs: core: Poll HCS.UCRDY before issuing a UIC command
  (bsc#1012628).
- selftests/ftrace: Correctly enable event in instance-event.tc
  (bsc#1012628).
- ring-buffer: Avoid softlockup in ring_buffer_resize()
  (bsc#1012628).
- btrfs: assert delayed node locked when removing delayed item
  (bsc#1012628).
- selftests: fix dependency checker script (bsc#1012628).
- ring-buffer: Do not attempt to read past "commit" (bsc#1012628).
- net/smc: bugfix for smcr v2 server connect success statistic
  (bsc#1012628).
- ata: sata_mv: Fix incorrect string length computation in
  mv_dump_mem() (bsc#1012628).
- efi/x86: Ensure that EFI_RUNTIME_MAP is enabled for kexec
  (bsc#1012628).
- platform/mellanox: mlxbf-bootctl: add NET dependency into
  Kconfig (bsc#1012628).
- platform/x86: asus-wmi: Support 2023 ROG X16 tablet mode
  (bsc#1012628).
- thermal/of: add missing of_node_put() (bsc#1012628).
- drm/amdgpu: Store CU info from all XCCs for GFX v9.4.3
  (bsc#1012628).
- drm/amdkfd: Update cache info reporting for GFX v9.4.3
  (bsc#1012628).
- drm/amdkfd: Update CU masking for GFX 9.4.3 (bsc#1012628).
- drm/amd/display: Don't check registers, if using AUX BL control
  (bsc#1012628).
- drm/amdgpu/soc21: don't remap HDP registers for SR-IOV
  (bsc#1012628).
- drm/amdgpu/nbio4.3: set proper rmmio_remap.reg_offset for SR-IOV
  (bsc#1012628).
- drm/amdgpu: fallback to old RAS error message for aqua_vanjaram
  (bsc#1012628).
- drm/amdkfd: Checkpoint and restore queues on GFX11
  (bsc#1012628).
- drm/amdgpu: Handle null atom context in VBIOS info ioctl
  (bsc#1012628).
- objtool: Fix _THIS_IP_ detection for cold functions
  (bsc#1012628).
- nvme-pci: do not set the NUMA node of device if it has none
  (bsc#1012628).
- riscv: errata: fix T-Head dcache.cva encoding (bsc#1012628).
- scsi: pm80xx: Use phy-specific SAS address when sending
  PHY_START command (bsc#1012628).
- scsi: pm80xx: Avoid leaking tags when processing
  OPC_INB_SET_CONTROLLER_CONFIG command (bsc#1012628).
- smb3: correct places where ENOTSUPP is used instead of preferred
  EOPNOTSUPP (bsc#1012628).
- ata: libata-eh: do not clear ATA_PFLAG_EH_PENDING in
  ata_eh_reset() (bsc#1012628).
- ata: libata-eh: do not thaw the port twice in ata_eh_reset()
  (bsc#1012628).
- Add DMI ID for MSI Bravo 15 B7ED (bsc#1012628).
- spi: nxp-fspi: reset the FLSHxCR1 registers (bsc#1012628).
- spi: stm32: add a delay before SPI disable (bsc#1012628).
- ASoC: fsl: imx-pcm-rpmsg: Add SNDRV_PCM_INFO_BATCH flag
  (bsc#1012628).
- spi: intel-pci: Add support for Granite Rapids SPI serial flash
  (bsc#1012628).
- bpf: Clarify error expectations from bpf_clone_redirect
  (bsc#1012628).
- ASoC: rt5640: Only cancel jack-detect work on suspend if active
  (bsc#1012628).
- ALSA: hda: intel-sdw-acpi: Use u8 type for link index
  (bsc#1012628).
- ASoC: cs42l42: Ensure a reset pulse meets minimum pulse width
  (bsc#1012628).
- ASoC: cs42l42: Don't rely on GPIOD_OUT_LOW to set RESET
  initially low (bsc#1012628).
- ASoC: cs42l42: Avoid stale SoundWire ATTACH after hard reset
  (bsc#1012628).
- firmware: cirrus: cs_dsp: Only log list of algorithms in debug
  build (bsc#1012628).
- ASoC: wm_adsp: Fix missing locking in wm_adsp_[read|write]_ctl()
  (bsc#1012628).
- memblock tests: fix warning: "__ALIGN_KERNEL" redefined
  (bsc#1012628).
- =?UTF-8?q?memblock=20tests:=20fix=20warning=20=E2=80=98st?=
  =?UTF-8?q?ruct=20seq=5Ffile=E2=80=99=20declared=20inside=20parameter=20li?=
  =?UTF-8?q?st?= (bsc#1012628).
- ASoC: imx-rpmsg: Set ignore_pmdown_time for dai_link
  (bsc#1012628).
- ASoC: SOF: sof-audio: Fix DSP core put imbalance on widget
  setup failure (bsc#1012628).
- media: vb2: frame_vector.c: replace WARN_ONCE with a comment
  (bsc#1012628).
- NFSv4.1: fix zero value filehandle in post open getattr
  (bsc#1012628).
- ASoC: SOF: Intel: MTL: Reduce the DSP init timeout
  (bsc#1012628).
- powerpc/watchpoints: Disable preemption in thread_change_pc()
  (bsc#1012628).
- powerpc/watchpoint: Disable pagefaults when getting user
  instruction (bsc#1012628).
- powerpc/watchpoints: Annotate atomic context in more places
  (bsc#1012628).
- ncsi: Propagate carrier gain/loss events to the NCSI controller
  (bsc#1012628).
- net: hsr: Add __packed to struct hsr_sup_tlv (bsc#1012628).
- tsnep: Fix NAPI scheduling (bsc#1012628).
- tsnep: Fix ethtool channels (bsc#1012628).
- tsnep: Fix NAPI polling with budget 0 (bsc#1012628).
- gfs2: fix glock shrinker ref issues (bsc#1012628).
- i2c: designware: fix __i2c_dw_disable() in case master is
  holding SCL low (bsc#1012628).
- LoongArch: Use _UL() and _ULL() (bsc#1012628).
- LoongArch: Set all reserved memblocks on Node#0 at
  initialization (bsc#1012628).
- fbdev/sh7760fb: Depend on FB=y (bsc#1012628).
- perf build: Define YYNOMEM as YYNOABORT for bison < 3.81
  (bsc#1012628).
- ASoC: cs35l56: Call pm_runtime_dont_use_autosuspend()
  (bsc#1012628).
- iommu/arm-smmu-v3: Fix soft lockup triggered by
  arm_smmu_mm_invalidate_range (bsc#1012628).
- spi: zynqmp-gqspi: fix clock imbalance on probe failure
  (bsc#1012628).
- x86/sgx: Resolves SECS reclaim vs. page fault for EAUG race
  (bsc#1012628).
- x86/srso: Add SRSO mitigation for Hygon processors
  (bsc#1012628).
- KVM: SVM: INTERCEPT_RDTSCP is never intercepted anyway
  (bsc#1012628).
- KVM: SVM: Fix TSC_AUX virtualization setup (bsc#1012628).
- KVM: x86/mmu: Open code leaf invalidation from mmu_notifier
  (bsc#1012628).
- KVM: x86/mmu: Do not filter address spaces in
  for_each_tdp_mmu_root_yield_safe() (bsc#1012628).
- KVM: x86/mmu: Stop zapping invalidated TDP MMU roots
  asynchronously (bsc#1012628).
- mptcp: fix bogus receive window shrinkage with multiple subflows
  (bsc#1012628).
- mptcp: move __mptcp_error_report in protocol.c (bsc#1012628).
- mptcp: process pending subflow error on close (bsc#1012628).
- Revert "tty: n_gsm: fix UAF in gsm_cleanup_mux" (bsc#1012628).
- scsi: core: ata: Do no try to probe for CDL on old drives
  (bsc#1012628).
- serial: 8250_port: Check IRQ data before use (bsc#1012628).
- nilfs2: fix potential use after free in
  nilfs_gccache_submit_read_data() (bsc#1012628).
- crypto: sm2 - Fix crash caused by uninitialized context
  (bsc#1012628).
- ALSA: rawmidi: Fix NULL dereference at proc read (bsc#1012628).
- ALSA: hda: Disable power save for solving pop issue on Lenovo
  ThinkCentre M70q (bsc#1012628).
- LoongArch: Fix lockdep static memory detection (bsc#1012628).
- LoongArch: Define relocation types for ABI v2.10 (bsc#1012628).
- LoongArch: numa: Fix high_memory calculation (bsc#1012628).
- LoongArch: Add support for 32_PCREL relocation type
  (bsc#1012628).
- LoongArch: Add support for 64_PCREL relocation type
  (bsc#1012628).
- ata: libata-scsi: link ata port and scsi device (bsc#1012628).
- scsi: sd: Differentiate system and runtime start/stop management
  (bsc#1012628).
- scsi: sd: Do not issue commands to suspended disks on shutdown
  (bsc#1012628).
- ata: libata-scsi: ignore reserved bits for REPORT SUPPORTED
  OPERATION CODES (bsc#1012628).
- io_uring/fs: remove sqe->rw_flags checking from LINKAT
  (bsc#1012628).
- i2c: i801: unregister tco_pdev in i801_probe() error path
  (bsc#1012628).
- ASoC: amd: yc: Fix non-functional mic on Lenovo 82QF and 82UG
  (bsc#1012628).
- kernel/sched: Modify initial boot task idle setup (bsc#1012628).
- sched/rt: Fix live lock between select_fallback_rq() and RT push
  (bsc#1012628).
- Revert "SUNRPC dont update timeout value on connection reset"
  (bsc#1012628).
- NFSv4: Fix a state manager thread deadlock regression
  (bsc#1012628).
- ACPI: NFIT: Fix incorrect calculation of idt size (bsc#1012628).
- timers: Tag (hr)timer softirq as hotplug safe (bsc#1012628).
- drm/tests: Fix incorrect argument in drm_test_mm_insert_range
  (bsc#1012628).
- cxl/mbox: Fix CEL logic for poison and security commands
  (bsc#1012628).
- arm64: defconfig: remove CONFIG_COMMON_CLK_NPCM8XX=y
  (bsc#1012628).
- mm/damon/vaddr-test: fix memory leak in
  damon_do_test_apply_three_regions() (bsc#1012628).
- selftests/mm: fix awk usage in charge_reserved_hugetlb.sh and
  hugetlb_reparenting_test.sh that may cause error (bsc#1012628).
- mm: mempolicy: keep VMA walk if both MPOL_MF_STRICT and
  MPOL_MF_MOVE are specified (bsc#1012628).
- mm/slab_common: fix slab_caches list corruption after
  kmem_cache_destroy() (bsc#1012628).
- mm: page_alloc: fix CMA and HIGHATOMIC landing on the wrong
  buddy list (bsc#1012628).
- mm: memcontrol: fix GFP_NOFS recursion in memory.high
  enforcement (bsc#1012628).
- cxl/port: Fix cxl_test register enumeration regression
  (bsc#1012628).
- cxl/pci: Fix appropriate checking for _OSC while handling CXL
  RAS registers (bsc#1012628).
- ring-buffer: Fix bytes info in per_cpu buffer stats
  (bsc#1012628).
- ring-buffer: Update "shortest_full" in polling (bsc#1012628).
- btrfs: refresh dir last index during a rewinddir(3) call
  (bsc#1012628).
- btrfs: file_remove_privs needs an exclusive lock in direct io
  write (bsc#1012628).
- btrfs: set last dir index to the current last index when
  opening dir (bsc#1012628).
- btrfs: fix race between reading a directory and adding entries
  to it (bsc#1012628).
- btrfs: properly report 0 avail for very full file systems
  (bsc#1012628).
- media: uvcvideo: Fix OOB read (bsc#1012628).
- bpf: Add override check to kprobe multi link attach
  (bsc#1012628).
- bpf: Fix BTF_ID symbol generation collision (bsc#1012628).
- bpf: Fix BTF_ID symbol generation collision in tools/
  (bsc#1012628).
- net: thunderbolt: Fix TCPv6 GSO checksum calculation
  (bsc#1012628).
- thermal: sysfs: Fix trip_point_hyst_store() (bsc#1012628).
- tracing/user_events: Align set_bit() address for all archs
  (bsc#1012628).
- ata: libata-core: Fix ata_port_request_pm() locking
  (bsc#1012628).
- ata: libata-core: Fix port and device removal (bsc#1012628).
- ata: libata-core: Do not register PM operations for SAS ports
  (bsc#1012628).
- ata: libata-sata: increase PMP SRST timeout to 10s
  (bsc#1012628).
- i915: Limit the length of an sg list to the requested length
  (bsc#1012628).
- drm/i915/gt: Fix reservation address in ggtt_reserve_guc_top
  (bsc#1012628).
- power: supply: rk817: Add missing module alias (bsc#1012628).
- power: supply: ab8500: Set typing and props (bsc#1012628).
- fs: binfmt_elf_efpic: fix personality for ELF-FDPIC
  (bsc#1012628).
- drm/amdkfd: Use gpu_offset for user queue's wptr (bsc#1012628).
- drm/amd/display: fix the ability to use lower resolution modes
  on eDP (bsc#1012628).
- drm/meson: fix memory leak on ->hpd_notify callback
  (bsc#1012628).
- rbd: move rbd_dev_refresh() definition (bsc#1012628).
- rbd: decouple header read-in from updating rbd_dev->header
  (bsc#1012628).
- rbd: decouple parent info read-in from updating rbd_dev
  (bsc#1012628).
- rbd: take header_rwsem in rbd_dev_refresh() only when updating
  (bsc#1012628).
- memcg: drop kmem.limit_in_bytes (bsc#1012628).
- mm, memcg: reconsider kmem.limit_in_bytes deprecation
  (bsc#1012628).
- ASoC: amd: yc: Fix a non-functional mic on Lenovo 82TL
  (bsc#1012628).
- Rename to
  patches.kernel.org/6.5.6-066-ipv4-fix-null-deref-in-ipv4_link_failure.patch.
- Rename to
  patches.kernel.org/6.5.6-093-netfilter-ipset-Fix-race-between-IPSET_CMD_CREA.patch.
- Rename to
  patches.kernel.org/6.5.6-106-cifs-Fix-UAF-in-cifs_demultiplex_thread.patch.
- Rename to
  patches.kernel.org/6.5.6-111-drm-amdgpu-set-completion-status-as-preempted-f.patch.
- Rename to
  patches.kernel.org/6.5.6-250-misc-rtsx-Fix-some-platforms-can-not-boot-and-m.patch.
- Rename to
  patches.kernel.org/6.5.6-300-fs-smb-client-Reset-password-pointer-to-NULL.patch.
- commit c97c2df
* Thu Oct  5 2023 jslaby@suse.cz
- misc: rtsx: Fix some platforms can not boot and move the l1ss
  judgment to probe (bsc#1214428).
- Delete
  patches.suse/Revert-101bd907b424-misc-rtsx-judge-ASPM-Mode-to-set.patch.
  Replace the revert by the upstream fix.
- commit e5944a3
* Wed Oct  4 2023 mkubecek@suse.cz
- Update
  patches.kernel.org/6.5.3-625-netfilter-xt_sctp-validate-the-flag_info-count.patch
  references (add CVE-2023-39193 bsc#1215860).
- commit c56e2dd
* Wed Oct  4 2023 mkubecek@suse.cz
- Update
  patches.kernel.org/6.5.3-624-netfilter-xt_u32-validate-user-space-input.patch
  references (add CVE-2023-39192 bsc#1215858).
- commit d5f1e57
* Wed Oct  4 2023 mkubecek@suse.cz
- ipv4: fix null-deref in ipv4_link_failure (CVE-2023-42754
  bsc#1215467).
- commit a4ade06
* Tue Oct  3 2023 palcantara@suse.de
- cifs: Fix UAF in cifs_demultiplex_thread() (bsc#1208995
  CVE-2023-1192).
- commit 34d5680
* Tue Oct  3 2023 palcantara@suse.de
- fs/smb/client: Reset password pointer to NULL (bsc#1215899
  CVE-2023-5345).
- commit 180c31b
* Tue Oct  3 2023 petr.pavlu@suse.com
- doc/README.PATCH-POLICY.SUSE: Remove the list of links (jsc#PED-5021)
  All links have been incorporated into the text. Remove now unnecessary
  list at the end of the document.
- commit 43d62b1
* Tue Oct  3 2023 petr.pavlu@suse.com
- doc/README.SUSE: Adjust heading style (jsc#PED-5021)
  * Underscore all headings as a preparation for Markdown conversion.
  * Use title-style capitalization for the document name and
  sentence-style capitalization for section headings, as recommended in
  the current SUSE Documentation Style Guide.
- commit 11e3267
* Tue Oct  3 2023 mkubecek@suse.cz
- netfilter: ipset: Fix race between IPSET_CMD_CREATE and
  IPSET_CMD_SWAP (CVE-2023-42756 bsc#1215767).
- commit 5c8516c
* Tue Oct  3 2023 mkubecek@suse.cz
- Update
  patches.kernel.org/6.5.3-622-netfilter-ipset-add-the-missing-IP_SET_HASH_WIT.patch
  references (add CVE-2023-42753 bsc#1215150).
- commit ddd076d
* Mon Oct  2 2023 mkubecek@suse.cz
- Update to 6.6-rc4
- eliminate 1 patch
  - patches.suse/Revert-101bd907b424-misc-rtsx-judge-ASPM-Mode-to-set.patch (0e4cac557531)
- commit 019d4ec
* Tue Sep 26 2023 petr.pavlu@suse.com
- doc/README.PATCH-POLICY.SUSE: Reflow text to 80-column width
  (jsc#PED-5021)
- commit be0158c
* Tue Sep 26 2023 petr.pavlu@suse.com
- doc/README.PATCH-POLICY.SUSE: Update information about the tools
  (jsc#PED-5021)
  * Replace bugzilla.novell.com with bugzilla.suse.com and FATE with Jira.
  * Limit the range of commits in the exportpatch example to prevent it
  from running for too long.
  * Incorporate URLs directly into the text.
  * Fix typos and improve some wording, in particular avoid use of "there
  is/are" and prefer the present tense over the future one.
- commit c0bea0c
* Tue Sep 26 2023 petr.pavlu@suse.com
- doc/README.PATCH-POLICY.SUSE: Update information about the patch
  format (jsc#PED-5021)
  * Replace bugzilla.novell.com with bugzilla.suse.com and FATE with Jira.
  * Remove references to links to the patchtools and kernel source. They
  are incorporated in other parts of the text.
  * Use sentence-style capitalization for section headings, as recommended
  in the current SUSE Documentation Style Guide.
  * Fix typos and some wording, in particular avoid use of "there is/are".
- commit ce98345
* Tue Sep 26 2023 petr.pavlu@suse.com
- doc/README.PATCH-POLICY.SUSE: Update the summary and background
  (jsc#PED-5021)
  * Drop information about patches being split into directories per
  a subsystem because that is no longer the case.
  * Remove the mention that the expanded tree is present since SLE11-SP2
  as that is now only a historical detail.
  * Incorporate URLs and additional information in parenthenses directly
  into the text.
  * Fix typos and improve some wording.
- commit 640988f
* Mon Sep 25 2023 msuchanek@suse.de
- kernel-binary: Move build-time definitions together
  Move source list and build architecture to buildrequires to aid in
  future reorganization of the spec template.
- commit 30e2cef
* Mon Sep 25 2023 jslaby@suse.cz
- Refresh
  patches.suse/firmware-Add-support-for-Qualcomm-UEFI-Secure-Applic.patch.
- Refresh
  patches.suse/firmware-qcom_scm-Add-support-for-Qualcomm-Secure-Ex.patch.
- Refresh
  patches.suse/lib-ucs2_string-Add-UCS-2-strscpy-function.patch.
  Update upstream status.
- commit ea38674
* Mon Sep 25 2023 tzimmermann@suse.com
- drm/amdgpu: Update invalid PTE flag setting (boo#1215470)
- commit 74bb304
* Mon Sep 25 2023 jslaby@suse.cz
- Linux 6.5.5 (bsc#1012628).
- iomap: Fix possible overflow condition in
  iomap_write_delalloc_scan (bsc#1012628).
- autofs: fix memory leak of waitqueues in autofs_catatonic_mode
  (bsc#1012628).
- btrfs: handle errors properly in update_inline_extent_backref()
  (bsc#1012628).
- btrfs: output extra debug info if we failed to find an inline
  backref (bsc#1012628).
- locks: fix KASAN: use-after-free in
  trace_event_raw_event_filelock_lock (bsc#1012628).
- ACPICA: Add AML_NO_OPERAND_RESOLVE flag to Timer (bsc#1012628).
- kernel/fork: beware of __put_task_struct() calling context
  (bsc#1012628).
- rcuscale: Move rcu_scale_writer()
  schedule_timeout_uninterruptible() to _idle() (bsc#1012628).
- scftorture: Forgive memory-allocation failure if KASAN
  (bsc#1012628).
- platform/chrome: cros_ec_lpc: Remove EC panic shutdown timeout
  (bsc#1012628).
- x86/amd_nb: Add PCI IDs for AMD Family 1Ah-based models
  (bsc#1012628).
- perf/smmuv3: Enable HiSilicon Erratum 162001900 quirk for
  HIP08/09 (bsc#1012628).
- s390/boot: cleanup number of page table levels setup
  (bsc#1012628).
- kselftest/arm64: fix a memleak in zt_regs_run() (bsc#1012628).
- perf/imx_ddr: speed up overflow frequency of cycle
  (bsc#1012628).
- ACPI: video: Add backlight=native DMI quirk for Apple iMac12,1
  and iMac12,2 (bsc#1012628).
- hw_breakpoint: fix single-stepping when using
  bpf_overflow_handler (bsc#1012628).
- ACPI: x86: s2idle: Catch multiple ACPI_TYPE_PACKAGE objects
  (bsc#1012628).
- selftests/nolibc: fix up kernel parameters support
  (bsc#1012628).
- selftests/nolibc: prevent out of bounds access in
  expect_vfprintf (bsc#1012628).
- spi: sun6i: add quirk for dual and quad SPI modes support
  (bsc#1012628).
- devlink: remove reload failed checks in params get/set callbacks
  (bsc#1012628).
- crypto: lrw,xts - Replace strlcpy with strscpy (bsc#1012628).
- ice: Don't tx before switchdev is fully configured
  (bsc#1012628).
- wifi: ath9k: fix fortify warnings (bsc#1012628).
- wifi: ath9k: fix printk specifier (bsc#1012628).
- wifi: rtw88: delete timer and free skb queue when unloading
  (bsc#1012628).
- wifi: mwifiex: fix fortify warning (bsc#1012628).
- mt76: mt7921: don't assume adequate headroom for SDIO headers
  (bsc#1012628).
- wifi: wil6210: fix fortify warnings (bsc#1012628).
- can: sun4i_can: Add acceptance register quirk (bsc#1012628).
- can: sun4i_can: Add support for the Allwinner D1 (bsc#1012628).
- net: Use sockaddr_storage for getsockopt(SO_PEERNAME)
  (bsc#1012628).
- wifi: ath12k: Fix a NULL pointer dereference in
  ath12k_mac_op_hw_scan() (bsc#1012628).
- wifi: ath12k: avoid array overflow of hw mode for
  preferred_hw_mode (bsc#1012628).
- net/ipv4: return the real errno instead of -EINVAL
  (bsc#1012628).
- crypto: lib/mpi - avoid null pointer deref in mpi_cmp_ui()
  (bsc#1012628).
- Bluetooth: btusb: Add device 0489:e0f5 as MT7922 device
  (bsc#1012628).
- Bluetooth: btusb: Add a new VID/PID 0489/e0f6 for MT7922
  (bsc#1012628).
- Bluetooth: btusb: Add new VID/PID 0489/e102 for MT7922
  (bsc#1012628).
- Bluetooth: btusb: Add new VID/PID 04ca/3804 for MT7922
  (bsc#1012628).
- Bluetooth: Fix hci_suspend_sync crash (bsc#1012628).
- Bluetooth: btusb: Add support for another MediaTek 7922 VID/PID
  (bsc#1012628).
- netlink: convert nlk->flags to atomic flags (bsc#1012628).
- tpm_tis: Resend command to recover from data transfer errors
  (bsc#1012628).
- mmc: sdhci-esdhc-imx: improve ESDHC_FLAG_ERR010450
  (bsc#1012628).
- alx: fix OOB-read compiler warning (bsc#1012628).
- wifi: iwlwifi: pcie: avoid a warning in case prepare card failed
  (bsc#1012628).
- wifi: mac80211: check S1G action frame size (bsc#1012628).
- netfilter: ebtables: fix fortify warnings in size_entry_mwt()
  (bsc#1012628).
- wifi: cfg80211: reject auth/assoc to AP with our address
  (bsc#1012628).
- wifi: cfg80211: ocb: don't leave if not joined (bsc#1012628).
- wifi: mac80211: check for station first in client probe
  (bsc#1012628).
- wifi: mac80211_hwsim: drop short frames (bsc#1012628).
- Revert "wifi: mac80211_hwsim: check the return value of
  nla_put_u32" (bsc#1012628).
- libbpf: Free btf_vmlinux when closing bpf_object (bsc#1012628).
- wifi: ath12k: Fix memory leak in rx_desc and tx_desc
  (bsc#1012628).
- wifi: ath12k: add check max message length while scanning with
  extraie (bsc#1012628).
- Fix nomenclature for USB and PCI wireless devices (bsc#1012628).
- bpf: Consider non-owning refs trusted (bsc#1012628).
- bpf: Consider non-owning refs to refcounted nodes RCU protected
  (bsc#1012628).
- drm/bridge: tc358762: Instruct DSI host to generate HSE packets
  (bsc#1012628).
- drm/edid: Add quirk for OSVR HDK 2.0 (bsc#1012628).
- drm: bridge: samsung-dsim: Drain command transfer FIFO before
  transfer (bsc#1012628).
- arm64: dts: qcom: sm6125-pdx201: correct ramoops pmsg-size
  (bsc#1012628).
- arm64: dts: qcom: sm6125-sprout: correct ramoops pmsg-size
  (bsc#1012628).
- arm64: dts: qcom: sm6350: correct ramoops pmsg-size
  (bsc#1012628).
- arm64: dts: qcom: sm8150-kumano: correct ramoops pmsg-size
  (bsc#1012628).
- arm64: dts: qcom: sm8250-edo: correct ramoops pmsg-size
  (bsc#1012628).
- drm/amdgpu: Increase soft IH ring size (bsc#1012628).
- samples/hw_breakpoint: Fix kernel BUG 'invalid opcode: 0000'
  (bsc#1012628).
- drm/amdgpu: Update ring scheduler info as needed (bsc#1012628).
- drm/amd/display: Fix underflow issue on 175hz timing
  (bsc#1012628).
- ASoC: SOF: topology: simplify code to prevent static analysis
  warnings (bsc#1012628).
- ASoC: Intel: sof_sdw: Update BT offload config for soundwire
  config (bsc#1012628).
- ALSA: hda: intel-dsp-cfg: add LunarLake support (bsc#1012628).
- drm/amd/display: Use DTBCLK as refclk instead of DPREFCLK
  (bsc#1012628).
- drm/amd/display: Blocking invalid 420 modes on HDMI TMDS for
  DCN31 (bsc#1012628).
- drm/amd/display: Blocking invalid 420 modes on HDMI TMDS for
  DCN314 (bsc#1012628).
- drm/amd/display: Use max memclk variable when setting max memclk
  (bsc#1012628).
- drm/msm/adreno: Use quirk identify hw_apriv (bsc#1012628).
- drm/msm/adreno: Use quirk to identify cached-coherent support
  (bsc#1012628).
- drm/exynos: fix a possible null-pointer dereference due to
  data race in exynos_drm_crtc_atomic_disable() (bsc#1012628).
- io_uring: annotate the struct io_kiocb slab for appropriate
  user copy (bsc#1012628).
- drm/mediatek: dp: Change logging to dev for
  mtk_dp_aux_transfer() (bsc#1012628).
- bus: ti-sysc: Configure uart quirks for k3 SoC (bsc#1012628).
- arm64: dts: qcom: sc8280xp-x13s: Add camera activity LED
  (bsc#1012628).
- md: raid1: fix potential OOB in raid1_remove_disk()
  (bsc#1012628).
- ext2: fix datatype of block number in ext2_xattr_set2()
  (bsc#1012628).
- blk-mq: fix tags leak when shrink nr_hw_queues (bsc#1012628).
- ASoC: SOF: amd: clear panic mask status when panic occurs
  (bsc#1012628).
- x86: bring back rep movsq for user access on CPUs without ERMS
  (bsc#1012628).
- fs/jfs: prevent double-free in dbUnmount() after failed
  jfs_remount() (bsc#1012628).
- jfs: fix invalid free of JFS_IP(ipimap)->i_imap in diUnmount
  (bsc#1012628).
- ext4: add two helper functions extent_logical_end() and
  pa_logical_end() (bsc#1012628).
- ext4: avoid overlapping preallocations due to overflow
  (bsc#1012628).
- PCI: dwc: Provide deinit callback for i.MX (bsc#1012628).
- ARM: 9317/1: kexec: Make smp stop calls asynchronous
  (bsc#1012628).
- powerpc/pseries: fix possible memory leak in ibmebus_bus_init()
  (bsc#1012628).
- PCI: vmd: Disable bridge window for domain reset (bsc#1012628).
- PCI: fu740: Set the number of MSI vectors (bsc#1012628).
- media: mdp3: Fix resource leaks in of_find_device_by_node
  (bsc#1012628).
- media: dvb-usb-v2: af9035: Fix null-ptr-deref in
  af9035_i2c_master_xfer (bsc#1012628).
- media: dw2102: Fix null-ptr-deref in dw2102_i2c_transfer()
  (bsc#1012628).
- media: af9005: Fix null-ptr-deref in af9005_i2c_xfer
  (bsc#1012628).
- media: anysee: fix null-ptr-deref in anysee_master_xfer
  (bsc#1012628).
- media: az6007: Fix null-ptr-deref in az6007_i2c_xfer()
  (bsc#1012628).
- media: dvb-usb-v2: gl861: Fix null-ptr-deref in
  gl861_i2c_master_xfer (bsc#1012628).
- scsi: lpfc: Abort outstanding ELS cmds when mailbox timeout
  error is detected (bsc#1012628).
- media: tuners: qt1010: replace BUG_ON with a regular error
  (bsc#1012628).
- media: pci: cx23885: replace BUG with error return
  (bsc#1012628).
- usb: cdns3: Put the cdns set active part outside the spin lock
  (bsc#1012628).
- usb: typec: intel_pmc_mux: Add new ACPI ID for Lunar Lake IOM
  device (bsc#1012628).
- usb: gadget: fsl_qe_udc: validate endpoint index for ch9 udc
  (bsc#1012628).
- tools: iio: iio_generic_buffer: Fix some integer type and
  calculation (bsc#1012628).
- scsi: target: iscsi: Fix buffer overflow in
  lio_target_nacl_info_show() (bsc#1012628).
- serial: cpm_uart: Avoid suspicious locking (bsc#1012628).
- misc: open-dice: make OPEN_DICE depend on HAS_IOMEM
  (bsc#1012628).
- usb: dwc3: dwc3-octeon: Verify clock divider (bsc#1012628).
- usb: ehci: add workaround for chipidea PORTSC.PEC bug
  (bsc#1012628).
- usb: chipidea: add workaround for chipidea PEC bug
  (bsc#1012628).
- media: pci: ipu3-cio2: Initialise timing struct to avoid a
  compiler warning (bsc#1012628).
- kobject: Add sanity check for kset->kobj.ktype in
  kset_register() (bsc#1012628).
- interconnect: Fix locking for runpm vs reclaim (bsc#1012628).
- usb: typec: qcom-pmic-typec: register drm_bridge (bsc#1012628).
- printk: Reduce console_unblank() usage in unsafe scenarios
  (bsc#1012628).
- printk: Keep non-panic-CPUs out of console lock (bsc#1012628).
- printk: Do not take console lock for console_flush_on_panic()
  (bsc#1012628).
- printk: Consolidate console deferred printing (bsc#1012628).
- printk: Rename abandon_console_lock_in_panic() to
  other_cpu_in_panic() (bsc#1012628).
- ext4: fix BUG in ext4_mb_new_inode_pa() due to overflow
  (bsc#1012628).
- btrfs: introduce struct to consolidate extent buffer write
  context (bsc#1012628).
- btrfs: zoned: introduce block group context to
  btrfs_eb_write_context (bsc#1012628).
- btrfs: zoned: return int from btrfs_check_meta_write_pointer
  (bsc#1012628).
- btrfs: zoned: defer advancing meta write pointer (bsc#1012628).
- btrfs: zoned: activate metadata block group on write time
  (bsc#1012628).
- mtd: spi-nor: spansion: use CLPEF as an alternative to CLSR
  (bsc#1012628).
- mtd: spi-nor: spansion: preserve CFR2V[7] when writing MEMLAT
  (bsc#1012628).
- btrfs: add a helper to read the superblock metadata_uuid
  (bsc#1012628).
- btrfs: compare the correct fsid/metadata_uuid in
  btrfs_validate_super (bsc#1012628).
- nvmet-tcp: pass iov_len instead of sg->length to bvec_set_page()
  (bsc#1012628).
- drm: gm12u320: Fix the timeout usage for usb_bulk_msg()
  (bsc#1012628).
- scsi: qla2xxx: Fix NULL vs IS_ERR() bug for debugfs_create_dir()
  (bsc#1012628).
- md: don't dereference mddev after export_rdev() (bsc#1012628).
- md: fix warning for holder mismatch from export_rdev()
  (bsc#1012628).
- PM: hibernate: Fix the exclusive get block device in test_resume
  mode (bsc#1012628).
- selftests: tracing: Fix to unmount tracefs for recovering
  environment (bsc#1012628).
- x86/ibt: Suppress spurious ENDBR (bsc#1012628).
- x86/ibt: Avoid duplicate ENDBR in __put_user_nocheck*()
  (bsc#1012628).
- riscv: kexec: Align the kexeced kernel entry (bsc#1012628).
- x86/sched: Restore the SD_ASYM_PACKING flag in the DIE domain
  (bsc#1012628).
- scsi: target: core: Fix target_cmd_counter leak (bsc#1012628).
- scsi: lpfc: Fix the NULL vs IS_ERR() bug for
  debugfs_create_file() (bsc#1012628).
- panic: Reenable preemption in WARN slowpath (bsc#1012628).
- ata: libata-core: fetch sense data for successful commands
  iff CDL enabled (bsc#1012628).
- x86/boot/compressed: Reserve more memory for page tables
  (bsc#1012628).
- x86/purgatory: Remove LTO flags (bsc#1012628).
- samples/hw_breakpoint: fix building without module unloading
  (bsc#1012628).
- blk-mq: prealloc tags when increase tagset nr_hw_queues
  (bsc#1012628).
- blk-mq: fix tags UAF when shrinking q->nr_hw_queues
  (bsc#1012628).
- md/raid1: fix error: ISO C90 forbids mixed declarations
  (bsc#1012628).
- Revert "SUNRPC: Fail faster on bad verifier" (bsc#1012628).
- attr: block mode changes of symlinks (bsc#1012628).
- ovl: fix failed copyup of fileattr on a symlink (bsc#1012628).
- ovl: fix incorrect fdput() on aio completion (bsc#1012628).
- io_uring/net: fix iter retargeting for selected buf
  (bsc#1012628).
- nvme: avoid bogus CRTO values (bsc#1012628).
- x86/platform/uv: Use alternate source for socket to node data
  (bsc#1012628).
- Revert "firewire: core: obsolete usage of GFP_ATOMIC at building
  node tree" (bsc#1012628).
- md: Put the right device in md_seq_next (bsc#1012628).
- drm/amd: Make fence wait in suballocator uninterruptible
  (bsc#1012628).
- Revert "drm/amd: Disable S/G for APUs when 64GB or more host
  memory" (bsc#1012628).
- dm: don't attempt to queue IO under RCU protection
  (bsc#1012628).
- dm: fix a race condition in retrieve_deps (bsc#1012628).
- btrfs: fix lockdep splat and potential deadlock after failure
  running delayed items (bsc#1012628).
- btrfs: fix a compilation error if DEBUG is defined in
  btree_dirty_folio (bsc#1012628).
- btrfs: fix race between finishing block group creation and
  its item update (bsc#1012628).
- btrfs: release path before inode lookup during the ino lookup
  ioctl (bsc#1012628).
- btrfs: check for BTRFS_FS_ERROR in pending ordered assert
  (bsc#1012628).
- tracing/synthetic: Fix order of struct trace_dynamic_info
  (bsc#1012628).
- tracing: Have tracing_max_latency inc the trace array ref count
  (bsc#1012628).
- tracing: Have event inject files inc the trace array ref count
  (bsc#1012628).
- tracing/synthetic: Print out u64 values properly (bsc#1012628).
- tracing: Increase trace array ref count on enable and filter
  files (bsc#1012628).
- tracing: Have current_trace inc the trace array ref count
  (bsc#1012628).
- tracing: Have option files inc the trace array ref count
  (bsc#1012628).
- selinux: fix handling of empty opts in
  selinux_fs_context_submount() (bsc#1012628).
- nfsd: fix change_info in NFSv4 RENAME replies (bsc#1012628).
- tracefs: Add missing lockdown check to tracefs_create_dir()
  (bsc#1012628).
- i2c: aspeed: Reset the i2c controller when timeout occurs
  (bsc#1012628).
- ata: libata: disallow dev-initiated LPM transitions to
  unsupported states (bsc#1012628).
- ata: libahci: clear pending interrupt status (bsc#1012628).
- scsi: megaraid_sas: Fix deadlock on firmware crashdump
  (bsc#1012628).
- scsi: qla2xxx: Use raw_smp_processor_id() instead of
  smp_processor_id() (bsc#1012628).
- scsi: pm8001: Setup IRQs on resume (bsc#1012628).
- Revert "comedi: add HAS_IOPORT dependencies" (bsc#1012628).
- ext4: fix rec_len verify error (bsc#1012628).
- drm/radeon: make fence wait in suballocator uninterrruptable
  (bsc#1012628).
- drm/i915: Only check eDP HPD when AUX CH is shared
  (bsc#1012628).
- drm/amdkfd: Insert missing TLB flush on GFX10 and later
  (bsc#1012628).
- drm/tests: helpers: Avoid a driver uaf (bsc#1012628).
- drm/amd/display: Adjust the MST resume flow (bsc#1012628).
- drm/amd/display: fix the white screen issue when >= 64GB DRAM
  (bsc#1012628).
- drm/amd/display: Add DPIA Link Encoder Assignment Fix
  (bsc#1012628).
- drm/amd/display: Fix 2nd DPIA encoder Assignment (bsc#1012628).
- Revert "memcg: drop kmem.limit_in_bytes" (bsc#1012628).
- drm/amdgpu: fix amdgpu_cs_p1_user_fence (bsc#1012628).
- interconnect: Teach lockdep about icc_bw_lock order
  (bsc#1012628).
- x86/alternatives: Remove faulty optimization (bsc#1012628).
- x86,static_call: Fix static-call vs return-thunk (bsc#1012628).
- Update config files.
  * restore COMEDI_ISA_DRIVERS=n
  * CAN_SUN4I=m, following master
- Rename to
  patches.kernel.org/6.5.5-010-ACPI-video-Add-backlight-native-DMI-quirk-for-L.patch.
- Rename to
  patches.kernel.org/6.5.5-147-efivarfs-fix-statfs-on-efivarfs.patch.
- commit 2459c16
* Sun Sep 24 2023 mkubecek@suse.cz
- Update to 6.6-rc3
- commit 15b4ad8
* Fri Sep 22 2023 jslaby@suse.cz
- drm/amdgpu: set completion status
  as preempted for the resubmission
  (https://gitlab.freedesktop.org/drm/amd/-/issues/2447).
- commit f926df3
* Wed Sep 20 2023 msuchanek@suse.de
- kernel-binary: python3 is needed for build
  At least scripts/bpf_helpers_doc.py requires python3 since Linux 4.18
  Other simimlar scripts may exist.
- commit c882efa
* Wed Sep 20 2023 mkubecek@suse.cz
- Update
  patches.kernel.org/6.5.3-188-net-sched-sch_hfsc-Ensure-inner-classes-have-fs.patch
  references (add CVE-2023-4623 bsc#1215115).
- commit e836b0d
* Wed Sep 20 2023 jslaby@suse.cz
- smb3: move server check earlier when setting channel sequence
  number (git-fixes).
- commit fdd7e9e
* Tue Sep 19 2023 jlee@suse.com
- Update config files. (bsc#1205447, jsc#PED-6528)
  Set CONFIG_IMA_KEYRINGS_PERMIT_SIGNED_BY_BUILTIN_OR_SECONDARY=n
  to armv6hl/default, armv7hl/default
  Let's disable CONFIG_IMA_KEYRINGS_PERMIT_SIGNED_BY_BUILTIN_OR_SECONDARY
  before we have conclusion on PED-6528. Which means that the
  .secondary_trusted_keys keyring can NOT be used to verify .ima/.evm
  keys. It also means that MOK in .machine keyring can not be used to
  verify .ima/.evm keys. (bsc#1205447, jsc#PED-6528)
- commit 6f5f69b
* Tue Sep 19 2023 jslaby@suse.cz
- Linux 6.5.4 (bsc#1012628).
- drm/virtio: Conditionally allocate virtio_gpu_fence
  (bsc#1012628).
- scsi: ufs: core: Add advanced RPMB support where UFSHCI 4.0
  does not support EHS length in UTRD (bsc#1012628).
- scsi: qla2xxx: Adjust IOCB resource on qpair create
  (bsc#1012628).
- scsi: qla2xxx: Limit TMF to 8 per function (bsc#1012628).
- scsi: qla2xxx: Fix deletion race condition (bsc#1012628).
- scsi: qla2xxx: fix inconsistent TMF timeout (bsc#1012628).
- scsi: qla2xxx: Fix command flush during TMF (bsc#1012628).
- scsi: qla2xxx: Fix erroneous link up failure (bsc#1012628).
- scsi: qla2xxx: Turn off noisy message log (bsc#1012628).
- scsi: qla2xxx: Fix session hang in gnl (bsc#1012628).
- scsi: qla2xxx: Fix TMF leak through (bsc#1012628).
- scsi: qla2xxx: Remove unsupported ql2xenabledif option
  (bsc#1012628).
- scsi: qla2xxx: Flush mailbox commands on chip reset
  (bsc#1012628).
- scsi: qla2xxx: Fix smatch warn for qla_init_iocb_limit()
  (bsc#1012628).
- scsi: qla2xxx: Error code did not return to upper layer
  (bsc#1012628).
- scsi: qla2xxx: Fix firmware resource tracking (bsc#1012628).
- null_blk: fix poll request timeout handling (bsc#1012628).
- kernfs: fix missing kernfs_iattr_rwsem locking (bsc#1012628).
- fbdev/ep93xx-fb: Do not assign to struct fb_info.dev
  (bsc#1012628).
- clk: qcom: camcc-sc7180: fix async resume during probe
  (bsc#1012628).
- drm/ast: Fix DRAM init on AST2200 (bsc#1012628).
- ASoC: tegra: Fix SFC conversion for few rates (bsc#1012628).
- ARM: dts: samsung: exynos4210-i9100: Fix LCD screen's physical
  size (bsc#1012628).
- arm64: tegra: Update AHUB clock parent and rate on Tegra234
  (bsc#1012628).
- arm64: tegra: Update AHUB clock parent and rate (bsc#1012628).
- clk: qcom: turingcc-qcs404: fix missing resume during probe
  (bsc#1012628).
- ARM: dts: qcom: msm8974pro-castor: correct inverted X of
  touchscreen (bsc#1012628).
- arm64: dts: qcom: msm8953-vince: drop duplicated touschreen
  parent interrupt (bsc#1012628).
- ARM: dts: qcom: msm8974pro-castor: correct touchscreen function
  names (bsc#1012628).
- ARM: dts: qcom: msm8974pro-castor: correct touchscreen
  syna,nosleep-mode (bsc#1012628).
- arm64: dts: renesas: rzg2l: Fix txdv-skew-psec typos
  (bsc#1012628).
- ARM: dts: BCM5301X: Extend RAM to full 256MB for Linksys EA6500
  V2 (bsc#1012628).
- send channel sequence number in SMB3 requests after reconnects
  (bsc#1012628).
- memcg: drop kmem.limit_in_bytes (bsc#1012628).
- mm: hugetlb_vmemmap: fix a race between vmemmap pmd split
  (bsc#1012628).
- lib/test_meminit: allocate pages up to order MAX_ORDER
  (bsc#1012628).
- Multi-gen LRU: avoid race in inc_min_seq() (bsc#1012628).
- parisc: led: Fix LAN receive and transmit LEDs (bsc#1012628).
- parisc: led: Reduce CPU overhead for disk & lan LED computation
  (bsc#1012628).
- cifs: update desired access while requesting for directory lease
  (bsc#1012628).
- pinctrl: cherryview: fix address_space_handler() argument
  (bsc#1012628).
- dt-bindings: clock: xlnx,versal-clk: drop select:false
  (bsc#1012628).
- clk: imx: pll14xx: dynamically configure PLL for
  393216000/361267200Hz (bsc#1012628).
- clk: imx: pll14xx: align pdiv with reference manual
  (bsc#1012628).
- clk: qcom: gcc-mdm9615: use proper parent for pll0_vote clock
  (bsc#1012628).
- soc: qcom: qmi_encdec: Restrict string length in decode
  (bsc#1012628).
- clk: qcom: dispcc-sm8450: fix runtime PM imbalance on probe
  errors (bsc#1012628).
- clk: qcom: dispcc-sm8550: fix runtime PM imbalance on probe
  errors (bsc#1012628).
- clk: qcom: lpasscc-sc7280: fix missing resume during probe
  (bsc#1012628).
- clk: qcom: q6sstop-qcs404: fix missing resume during probe
  (bsc#1012628).
- clk: qcom: mss-sc7180: fix missing resume during probe
  (bsc#1012628).
- NFS: Fix a potential data corruption (bsc#1012628).
- NFSv4/pnfs: minor fix for cleanup path in nfs4_get_device_info
  (bsc#1012628).
- bus: mhi: host: Skip MHI reset if device is in RDDM
  (bsc#1012628).
- kbuild: rpm-pkg: define _arch conditionally (bsc#1012628).
- kbuild: do not run depmod for 'make modules_sign' (bsc#1012628).
- tpm_crb: Fix an error handling path in crb_acpi_add()
  (bsc#1012628).
- gfs2: Switch to wait_event in gfs2_logd (bsc#1012628).
- gfs2: low-memory forced flush fixes (bsc#1012628).
- mailbox: qcom-ipcc: fix incorrect num_chans counting
  (bsc#1012628).
- kconfig: fix possible buffer overflow (bsc#1012628).
- tools/mm: fix undefined reference to pthread_once (bsc#1012628).
- Input: iqs7222 - configure power mode before triggering ATI
  (bsc#1012628).
- perf trace: Really free the evsel->priv area (bsc#1012628).
- pwm: atmel-tcb: Harmonize resource allocation order
  (bsc#1012628).
- pwm: atmel-tcb: Fix resource freeing in error path and remove
  (bsc#1012628).
- backlight: lp855x: Initialize PWM state on first brightness
  change (bsc#1012628).
- backlight: gpio_backlight: Drop output GPIO direction check
  for initial power state (bsc#1012628).
- perf parse-events: Separate YYABORT and YYNOMEM cases
  (bsc#1012628).
- perf parse-events: Move instances of YYABORT to YYNOMEM
  (bsc#1012628).
- perf parse-events: Separate ENOMEM memory handling
  (bsc#1012628).
- perf parse-events: Additional error reporting (bsc#1012628).
- KVM: SVM: Don't defer NMI unblocking until next exit for SEV-ES
  guests (bsc#1012628).
- Input: tca6416-keypad - always expect proper IRQ number in
  i2c client (bsc#1012628).
- Input: tca6416-keypad - fix interrupt enable disbalance
  (bsc#1012628).
- perf annotate bpf: Don't enclose non-debug code with an assert()
  (bsc#1012628).
- x86/virt: Drop unnecessary check on extended CPUID level in
  cpu_has_svm() (bsc#1012628).
- perf script: Print "cgroup" field on the same line as "comm"
  (bsc#1012628).
- perf bpf-filter: Fix sample flag check with || (bsc#1012628).
- perf dlfilter: Initialize addr_location before passing it to
  thread__find_symbol_fb() (bsc#1012628).
- perf dlfilter: Add al_cleanup() (bsc#1012628).
- perf vendor events: Update the JSON/events descriptions for
  power10 platform (bsc#1012628).
- perf vendor events: Drop some of the JSON/events for power10
  platform (bsc#1012628).
- perf vendor events: Drop STORES_PER_INST metric event for
  power10 platform (bsc#1012628).
- perf vendor events: Move JSON/events to appropriate files for
  power10 platform (bsc#1012628).
- perf vendor events: Update metric event names for power10
  platform (bsc#1012628).
- perf top: Don't pass an ERR_PTR() directly to
  perf_session__delete() (bsc#1012628).
- perf lock: Don't pass an ERR_PTR() directly to
  perf_session__delete() (bsc#1012628).
- watchdog: intel-mid_wdt: add MODULE_ALIAS() to allow auto-load
  (bsc#1012628).
- perf vendor events arm64: Remove L1D_CACHE_LMISS from AmpereOne
  list (bsc#1012628).
- pwm: lpc32xx: Remove handling of PWM channels (bsc#1012628).
- accel/ivpu: refactor deprecated strncpy (bsc#1012628).
- perf header: Fix missing PMU caps (bsc#1012628).
- i3c: master: svc: Describe member 'saved_regs' (bsc#1012628).
- perf test stat_bpf_counters_cgrp: Fix shellcheck issue about
  logical operators (bsc#1012628).
- perf test stat_bpf_counters_cgrp: Enhance perf stat cgroup
  BPF counter test (bsc#1012628).
- regulator: tps6287x: Fix n_voltages (bsc#1012628).
- selftests/bpf: Fix flaky cgroup_iter_sleepable subtest
  (bsc#1012628).
- drm/i915: mark requests for GuC virtual engines to avoid
  use-after-free (bsc#1012628).
- blk-throttle: use calculate_io/bytes_allowed() for
  throtl_trim_slice() (bsc#1012628).
- blk-throttle: consider 'carryover_ios/bytes' in
  throtl_trim_slice() (bsc#1012628).
- netfilter: nf_tables: Audit log setelem reset (bsc#1012628).
- netfilter: nf_tables: Audit log rule reset (bsc#1012628).
- smb: propagate error code of extract_sharename() (bsc#1012628).
- net/sched: fq_pie: avoid stalls in fq_pie_timer() (bsc#1012628).
- sctp: annotate data-races around sk->sk_wmem_queued
  (bsc#1012628).
- ipv4: annotate data-races around fi->fib_dead (bsc#1012628).
- net: read sk->sk_family once in sk_mc_loop() (bsc#1012628).
- net: fib: avoid warn splat in flow dissector (bsc#1012628).
- xsk: Fix xsk_diag use-after-free error during socket cleanup
  (bsc#1012628).
- drm/i915/gvt: Verify pfn is "valid" before dereferencing
  "struct page" (bsc#1012628).
- drm/i915/gvt: Put the page reference obtained by KVM's
  gfn_to_pfn() (bsc#1012628).
- drm/i915/gvt: Drop unused helper intel_vgpu_reset_gtt()
  (bsc#1012628).
- drm/amd/display: fix mode scaling (RMX_.*) (bsc#1012628).
- net/handshake: fix null-ptr-deref in handshake_nl_done_doit()
  (bsc#1012628).
- net: use sk_forward_alloc_get() in sk_get_meminfo()
  (bsc#1012628).
- net: annotate data-races around sk->sk_forward_alloc
  (bsc#1012628).
- mptcp: annotate data-races around msk->rmem_fwd_alloc
  (bsc#1012628).
- net: annotate data-races around sk->sk_tsflags (bsc#1012628).
- net: annotate data-races around sk->sk_bind_phc (bsc#1012628).
- ipv4: ignore dst hint for multipath routes (bsc#1012628).
- ipv6: ignore dst hint for multipath routes (bsc#1012628).
- selftests/bpf: Fix a CI failure caused by vsock write
  (bsc#1012628).
- igb: disable virtualization features on 82580 (bsc#1012628).
- gve: fix frag_list chaining (bsc#1012628).
- veth: Fixing transmit return status for dropped packets
  (bsc#1012628).
- net: ipv6/addrconf: avoid integer underflow in
  ipv6_create_tempaddr (bsc#1012628).
- net: phy: micrel: Correct bit assignments for phy_device flags
  (bsc#1012628).
- bpf, sockmap: Fix skb refcnt race after locking changes
  (bsc#1012628).
- af_unix: Fix msg_controllen test in scm_pidfd_recv() for
  MSG_CMSG_COMPAT (bsc#1012628).
- af_unix: Fix data-races around user->unix_inflight
  (bsc#1012628).
- af_unix: Fix data-race around unix_tot_inflight (bsc#1012628).
- af_unix: Fix data-races around sk->sk_shutdown (bsc#1012628).
- af_unix: Fix data race around sk->sk_err (bsc#1012628).
- net: sched: sch_qfq: Fix UAF in qfq_dequeue() (bsc#1012628).
- kcm: Destroy mutex in kcm_exit_net() (bsc#1012628).
- octeontx2-af: Fix truncation of smq in CN10K NIX AQ enqueue
  mbox handler (bsc#1012628).
- igc: Change IGC_MIN to allow set rx/tx value between 64 and 80
  (bsc#1012628).
- igbvf: Change IGBVF_MIN to allow set rx/tx value between 64
  and 80 (bsc#1012628).
- igb: Change IGB_MIN to allow set rx/tx value between 64 and 80
  (bsc#1012628).
- s390/zcrypt: don't leak memory if dev_set_name() fails
  (bsc#1012628).
- regulator: tps6594-regulator: Fix random kernel crash
  (bsc#1012628).
- idr: fix param name in idr_alloc_cyclic() doc (bsc#1012628).
- ip_tunnels: use DEV_STATS_INC() (bsc#1012628).
- net/mlx5e: Clear mirred devices array if the rule is split
  (bsc#1012628).
- net/mlx5: Give esw_offloads_load/unload_rep() "mlx5_" prefix
  (bsc#1012628).
- net/mlx5: Rework devlink port alloc/free into init/cleanup
  (bsc#1012628).
- net/mlx5: Push devlink port PF/VF init/cleanup calls out of
  devlink_port_register/unregister() (bsc#1012628).
- mlx5/core: E-Switch, Create ACL FT for eswitch manager in
  switchdev mode (bsc#1012628).
- net: dsa: sja1105: fix bandwidth discrepancy between tc-cbs
  software and offload (bsc#1012628).
- net: dsa: sja1105: fix -ENOSPC when replacing the same tc-cbs
  too many times (bsc#1012628).
- net: dsa: sja1105: complete tc-cbs offload support on SJA1110
  (bsc#1012628).
- net: phylink: fix sphinx complaint about invalid literal
  (bsc#1012628).
- bpf: Invoke __bpf_prog_exit_sleepable_recur() on recursion in
  kern_sys_bpf() (bsc#1012628).
- bpf: Assign bpf_tramp_run_ctx::saved_run_ctx before recursion
  check (bsc#1012628).
- s390/bpf: Pass through tail call counter in trampolines
  (bsc#1012628).
- bpf: bpf_sk_storage: Fix invalid wait context lockdep report
  (bsc#1012628).
- bpf: bpf_sk_storage: Fix the missing uncharge in sk_omem_alloc
  (bsc#1012628).
- netfilter: nfnetlink_osf: avoid OOB read (bsc#1012628).
- netfilter: nft_set_rbtree: skip sync GC for new elements in
  this transaction (bsc#1012628).
- netfilter: nf_tables: Unbreak audit log reset (bsc#1012628).
- net: phy: Provide Module 4 KSZ9477 errata (DS80000754C)
  (bsc#1012628).
- net: hns3: fix tx timeout issue (bsc#1012628).
- net: hns3: fix byte order conversion issue in
  hclge_dbg_fd_tcam_read() (bsc#1012628).
- net: hns3: fix debugfs concurrency issue between kfree buffer
  and read (bsc#1012628).
- net: hns3: fix invalid mutex between tc qdisc and dcb ets
  command issue (bsc#1012628).
- net: hns3: fix the port information display when sfp is absent
  (bsc#1012628).
- net: hns3: remove GSO partial feature bit (bsc#1012628).
- net: enetc: distinguish error from valid pointers in
  enetc_fixup_clear_rss_rfs() (bsc#1012628).
- sh: boards: Fix CEU buffer size passed to
  dma_declare_coherent_memory() (bsc#1012628).
- sh: push-switch: Reorder cleanup operations to avoid
  use-after-free bug (bsc#1012628).
- linux/export: fix reference to exported functions for parisc64
  (bsc#1012628).
- watchdog: advantech_ec_wdt: fix Kconfig dependencies
  (bsc#1012628).
- drm/amd/display: Temporary Disable MST DP Colorspace Property
  (bsc#1012628).
- ARC: atomics: Add compiler barrier to atomic
  operations.. (bsc#1012628).
- clocksource/drivers/arm_arch_timer: Disable timer before
  programming CVAL (bsc#1012628).
- dmaengine: sh: rz-dmac: Fix destination and source data size
  setting (bsc#1012628).
- misc: fastrpc: Fix remote heap allocation request (bsc#1012628).
- misc: fastrpc: Fix incorrect DMA mapping unmap request
  (bsc#1012628).
- jbd2: fix checkpoint cleanup performance regression
  (bsc#1012628).
- jbd2: check 'jh->b_transaction' before removing it from
  checkpoint (bsc#1012628).
- jbd2: correct the end of the journal recovery scan range
  (bsc#1012628).
- ext4: fix slab-use-after-free in ext4_es_insert_extent()
  (bsc#1012628).
- ext4: add correct group descriptors and reserved GDT blocks
  to system zone (bsc#1012628).
- ext4: fix memory leaks in
  ext4_fname_{setup_filename,prepare_lookup} (bsc#1012628).
- ext4: drop dio overwrite only flag and associated warning
  (bsc#1012628).
- f2fs: get out of a repeat loop when getting a locked data page
  (bsc#1012628).
- f2fs: flush inode if atomic file is aborted (bsc#1012628).
- f2fs: avoid false alarm of circular locking (bsc#1012628).
- lib: test_scanf: Add explicit type cast to result initialization
  in test_number_prefix() (bsc#1012628).
- hwspinlock: qcom: add missing regmap config for SFPB MMIO
  implementation (bsc#1012628).
- memcontrol: ensure memcg acquired by id is properly set up
  (bsc#1012628).
- ata: ahci: Add Elkhart Lake AHCI controller (bsc#1012628).
- ata: pata_falcon: fix IO base selection for Q40 (bsc#1012628).
- ata: sata_gemini: Add missing MODULE_DESCRIPTION (bsc#1012628).
- ata: pata_ftide010: Add missing MODULE_DESCRIPTION
  (bsc#1012628).
- fuse: nlookup missing decrement in fuse_direntplus_link
  (bsc#1012628).
- btrfs: zoned: do not zone finish data relocation block group
  (bsc#1012628).
- btrfs: fix start transaction qgroup rsv double free
  (bsc#1012628).
- btrfs: free qgroup rsv on io failure (bsc#1012628).
- btrfs: don't start transaction when joining with
  TRANS_JOIN_NOSTART (bsc#1012628).
- btrfs: set page extent mapped after read_folio in
  relocate_one_page (bsc#1012628).
- btrfs: zoned: re-enable metadata over-commit for zoned mode
  (bsc#1012628).
- btrfs: use the correct superblock to compare fsid in
  btrfs_validate_super (bsc#1012628).
- btrfs: scrub: avoid unnecessary extent tree search preparing
  stripes (bsc#1012628).
- btrfs: scrub: avoid unnecessary csum tree search preparing
  stripes (bsc#1012628).
- btrfs: scrub: fix grouping of read IO (bsc#1012628).
- drm/mxsfb: Disable overlay plane in
  mxsfb_plane_overlay_atomic_disable() (bsc#1012628).
- mtd: rawnand: brcmnand: Fix crash during the panic_write
  (bsc#1012628).
- mtd: rawnand: brcmnand: Fix potential out-of-bounds access in
  oob write (bsc#1012628).
- mtd: spi-nor: Correct flags for Winbond w25q128 (bsc#1012628).
- mtd: rawnand: brcmnand: Fix potential false time out warning
  (bsc#1012628).
- mtd: rawnand: brcmnand: Fix ECC level field setting for v7.2
  controller (bsc#1012628).
- Revert "drm/amd/display: Remove v_startup workaround for dcn3+"
  (bsc#1012628).
- drm/amd/display: enable cursor degamma for DCN3+ DRM legacy
  gamma (bsc#1012628).
- drm/amd/display: limit the v_startup workaround to ASICs older
  than DCN3.1 (bsc#1012628).
- drm/amd/display: prevent potential division by zero errors
  (bsc#1012628).
- KVM: VMX: Refresh available regs and IDT vectoring info before
  NMI handling (bsc#1012628).
- KVM: SVM: Take and hold ir_list_lock when updating vCPU's
  Physical ID entry (bsc#1012628).
- KVM: SVM: Don't inject #UD if KVM attempts to skip SEV guest
  insn (bsc#1012628).
- KVM: SVM: Get source vCPUs from source VM for SEV-ES intrahost
  migration (bsc#1012628).
- KVM: nSVM: Check instead of asserting on nested TSC scaling
  support (bsc#1012628).
- KVM: nSVM: Load L1's TSC multiplier based on L1 state, not L2
  state (bsc#1012628).
- KVM: SVM: Set target pCPU during IRTE update if target vCPU
  is running (bsc#1012628).
- KVM: SVM: Skip VMSA init in sev_es_init_vmcb() if pointer is
  NULL (bsc#1012628).
- MIPS: Only fiddle with CHECKFLAGS if `need-compiler'
  (bsc#1012628).
- MIPS: Fix CONFIG_CPU_DADDI_WORKAROUNDS `modules_install'
  regression (bsc#1012628).
- perf hists browser: Fix hierarchy mode header (bsc#1012628).
- perf build: Update build rule for generated files (bsc#1012628).
- perf test shell stat_bpf_counters: Fix test on Intel
  (bsc#1012628).
- perf tools: Handle old data in PERF_RECORD_ATTR (bsc#1012628).
- perf build: Include generated header files properly
  (bsc#1012628).
- perf hists browser: Fix the number of entries for 'e' key
  (bsc#1012628).
- drm/amd/display: always switch off ODM before committing more
  streams (bsc#1012628).
- drm/amd/display: Remove wait while locked (bsc#1012628).
- drm/amdkfd: Add missing gfx11 MQD manager callbacks
  (bsc#1012628).
- drm/amdgpu: register a dirty framebuffer callback for fbcon
  (bsc#1012628).
- bpf: fix bpf_probe_read_kernel prototype mismatch (bsc#1012628).
- regulator: raa215300: Change the scope of the variables
  {clkin_name, xin_name} (bsc#1012628).
- regulator: raa215300: Fix resource leak in case of error
  (bsc#1012628).
- parisc: sba_iommu: Fix build warning if procfs if disabled
  (bsc#1012628).
- kunit: Fix wild-memory-access bug in kunit_free_suite_set()
  (bsc#1012628).
- net: ipv4: fix one memleak in __inet_del_ifa() (bsc#1012628).
- kselftest/runner.sh: Propagate SIGTERM to runner child
  (bsc#1012628).
- selftests: Keep symlinks, when possible (bsc#1012628).
- selftests/ftrace: Fix dependencies for some of the synthetic
  event tests (bsc#1012628).
- net: microchip: vcap api: Fix possible memory leak for
  vcap_dup_rule() (bsc#1012628).
- octeontx2-pf: Fix page pool cache index corruption
  (bsc#1012628).
- net/smc: use smc_lgr_list.lock to protect smc_lgr_list.list
  iterate in smcr_port_add (bsc#1012628).
- net: stmmac: fix handling of zero coalescing tx-usecs
  (bsc#1012628).
- net: ethernet: mvpp2_main: fix possible OOB write in
  mvpp2_ethtool_get_rxnfc() (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix possible NULL pointer
  dereference in mtk_hwlro_get_fdir_all() (bsc#1012628).
- hsr: Fix uninit-value access in fill_frame_info() (bsc#1012628).
- net: ethernet: adi: adin1110: use eth_broadcast_addr() to
  assign broadcast address (bsc#1012628).
- net:ethernet:adi:adin1110: Fix forwarding offload (bsc#1012628).
- net: dsa: sja1105: hide all multicast addresses from "bridge
  fdb show" (bsc#1012628).
- net: dsa: sja1105: propagate exact error code from
  sja1105_dynamic_config_poll_valid() (bsc#1012628).
- net: dsa: sja1105: fix multicast forwarding working only for
  last added mdb entry (bsc#1012628).
- net: dsa: sja1105: serialize sja1105_port_mcast_flood() with
  other FDB accesses (bsc#1012628).
- net: dsa: sja1105: block FDB accesses that are concurrent with
  a switch reset (bsc#1012628).
- r8152: check budget for r8152_poll() (bsc#1012628).
- kcm: Fix memory leak in error path of kcm_sendmsg()
  (bsc#1012628).
- platform/mellanox: mlxbf-tmfifo: Drop the Rx packet if no more
  descriptors (bsc#1012628).
- platform/mellanox: mlxbf-tmfifo: Drop jumbo frames
  (bsc#1012628).
- platform/mellanox: mlxbf-pmc: Fix potential buffer overflows
  (bsc#1012628).
- platform/mellanox: mlxbf-pmc: Fix reading of unprogrammed events
  (bsc#1012628).
- platform/mellanox: NVSW_SN2201 should depend on ACPI
  (bsc#1012628).
- net/tls: do not free tls_rec on async operation in
  bpf_exec_tx_verdict() (bsc#1012628).
- net: macb: fix sleep inside spinlock (bsc#1012628).
- veth: Update XDP feature set when bringing up device
  (bsc#1012628).
- ipv6: fix ip6_sock_set_addr_preferences() typo (bsc#1012628).
- tcp: Factorise sk_family-independent comparison in
  inet_bind2_bucket_match(_addr_any) (bsc#1012628).
- tcp: Fix bind() regression for v4-mapped-v6 wildcard address
  (bsc#1012628).
- tcp: Fix bind() regression for v4-mapped-v6 non-wildcard address
  (bsc#1012628).
- selftest: tcp: Fix address length in bind_wildcard.c
  (bsc#1012628).
- ixgbe: fix timestamp configuration code (bsc#1012628).
- igb: clean up in all error paths when enabling SR-IOV
  (bsc#1012628).
- net: renesas: rswitch: Fix unmasking irq condition
  (bsc#1012628).
- kcm: Fix error handling for SOCK_DGRAM in kcm_sendmsg()
  (bsc#1012628).
- vm: fix move_vma() memory accounting being off (bsc#1012628).
- drm/amd/display: Fix a bug when searching for insert_above_mpcc
  (bsc#1012628).
- Rename to
  patches.kernel.org/6.5.4-001-net-ipv6-SKB-symmetric-hash-should-incorporate-.patch.
- Rename to
  patches.kernel.org/6.5.4-058-kbuild-dummy-tools-make-MPROFILE_KERNEL-checks-.patch.
- Rename to
  patches.kernel.org/6.5.4-161-netfilter-nftables-exthdr-fix-4-byte-stack-OOB-.patch.
- Update config files.
- commit b203436
* Tue Sep 19 2023 schwab@suse.de
- riscv: enable CONFIG_MEDIA_PLATFORM_SUPPORT
  - MEDIA_PLATFORM_SUPPORT=y
  - V4L2_H264=m
  - V4L2_VP9=m
  - MEDIA_PLATFORM_DRIVERS=y
  - V4L_PLATFORM_DRIVERS=y
  - SDR_PLATFORM_DRIVERS=y
  - DVB_PLATFORM_DRIVERS=y
  - V4L_MEM2MEM_DRIVERS=y
  - VIDEO_MEM2MEM_DEINTERLACE=m
  - VIDEO_MUX=m
  - VIDEO_CADENCE_CSI2RX=m
  - VIDEO_CADENCE_CSI2TX=m
  - VIDEO_CAFE_CCIC=m
  - VIDEO_RCAR_ISP=m
  - VIDEO_RCAR_CSI2=m
  - VIDEO_RCAR_VIN=m
  - VIDEO_RZG2L_CSI2=m
  - VIDEO_RZG2L_CRU=m
  - VIDEO_RENESAS_FCP=m
  - VIDEO_RENESAS_FDP1=m
  - VIDEO_RENESAS_JPU=m
  - VIDEO_RENESAS_VSP1=m
  - VIDEO_RCAR_DRIF=m
  - VIDEO_SUN4I_CSI=m
  - VIDEO_SUN6I_CSI=m
  - VIDEO_SUN6I_MIPI_CSI2=m
  - VIDEO_SUN8I_A83T_MIPI_CSI2=m
  - VIDEO_SUN8I_DEINTERLACE=m
  - VIDEO_SUN8I_ROTATE=m
  - VIDEO_HANTRO=m
  - VIDEO_HANTRO_SUNXI=y
  - VIDEO_XILINX=m
  - VIDEO_XILINX_CSI2RXSS=m
  - VIDEO_XILINX_TPG=m
  - VIDEO_XILINX_VTC=m
  - SMS_SDIO_DRV=m
  - SMS_SIANO_DEBUGFS=n
  - VIDEO_SUN6I_ISP=m
- commit 337896e
* Tue Sep 19 2023 tiwai@suse.de
- efivarfs: fix statfs() on efivarfs (bsc#1215284).
- commit 6b704c5
* Mon Sep 18 2023 petr.pavlu@suse.com
- doc/README.SUSE: Reflow text to 80-column width (jsc#PED-5021)
- commit e8f2c67
* Mon Sep 18 2023 tiwai@suse.de
- Update config files: make SCSI/ATA drivers modules again
  As discussed on opensuse-kernel ML, we want to make SCSI and ATA
  drivers from built-in back to modules again:
  https://lists.opensuse.org/archives/list/kernel@lists.opensuse.org/thread/MLRQW7RFEAKTAP63NMPFFIYTXAF7E3I3/
  They were made as built-in many many years ago just for boot speed up
  and a slight hope of initrd-less systems.  But it makes more sense to
  align with the SLE configurations.
- commit 8c848c4
* Mon Sep 18 2023 petr.pavlu@suse.com
- doc/README.SUSE: Minor content clean up (jsc#PED-5021)
  * Mark the user's build directory as a variable, not a command:
  'make -C $(your_build_dir)' -> 'make -C $YOUR_BUILD_DIR'.
  * Unify how to get the current directory: 'M=$(pwd)' -> 'M=$PWD'.
  * 'GIT' / 'git' -> 'Git'.
- commit 1cb4ec8
* Mon Sep 18 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update information about module paths
  (jsc#PED-5021)
  * Use version variables to describe names of the
  /lib/modules/$VERSION-$RELEASE-$FLAVOR/... directories
  instead of using specific example versions which get outdated quickly.
  * Note: Keep the /lib/modules/ prefix instead of using the new
  /usr/lib/modules/ location for now. The updated README is expected to
  be incorporated to various branches that are not yet usrmerged.
- commit 7eba2f0
* Mon Sep 18 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update information about custom patches
  (jsc#PED-5021)
  * Replace mention of various patches.* directories with only
  patches.suse as the typical location for patches.
  * Replace i386 with x86_64 in the example how to define a config addon.
  * Fix some typos and wording.
- commit 2997d22
* Mon Sep 18 2023 clin@suse.com
- Update config files: enable arm64 regulator modules for mediatek boards (bsc#1215335)
- commit b197b36
* Mon Sep 18 2023 mkubecek@suse.cz
- Update to 6.6-rc2
- eliminate 1 patch
  - patches.rpmify/kbuild-avoid-long-argument-lists-in-make-modules_ins.patch
- refresh configs
- commit 8a1f7fd
* Fri Sep 15 2023 mkubecek@suse.cz
- netfilter: nftables: exthdr: fix 4-byte stack OOB write
  (CVE-2023-4881 bsc#1215221).
- commit 89de233
* Fri Sep 15 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update information about config files
  (jsc#PED-5021)
  * Use version variables to describe a name of the /boot/config-... file
  instead of using specific example versions which get outdated quickly.
  * Replace removed silentoldconfig with oldconfig.
  * Mention that oldconfig can automatically pick a base config from
  "/boot/config-$(uname -r)".
  * Avoid writing additional details in parentheses, incorporate them
  instead properly in the text.
- commit cba5807
* Fri Sep 15 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update the patch selection section
  (jsc#PED-5021)
  * Make the steps how to obtain expanded kernel source more generic in
  regards to version numbers.
  * Use '#' instead of '$' as the command line indicator to signal that
  the steps need to be run as root.
  * Update the format of linux-$SRCVERSION.tar.bz2 to xz.
  * Improve some wording.
- commit e14852c
* Fri Sep 15 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update information about (un)supported modules
  (jsc#PED-5021)
  * Update the list of taint flags. Convert it to a table that matches the
  upstream documentation format and describe specifically flags that are
  related to module support status.
  * Fix some typos and wording.
- commit e46f0df
* Fri Sep 15 2023 petr.pavlu@suse.com
- doc/README.SUSE: Bring information about compiling up to date
  (jsc#PED-5021)
  * When building the kernel, don't mention to initially change the
  current directory to /usr/src/linux because later description
  discourages it and specifies to use 'make -C /usr/src/linux'.
  * Avoid writing additional details in parentheses, incorporate them
  instead properly in the text.
  * Fix the obsolete name of /etc/modprobe.d/unsupported-modules ->
  /etc/modprobe.d/10-unsupported-modules.conf.
  * Drop a note that a newly built kernel should be added to the boot
  manager because that normally happens automatically when running
  'make install'.
  * Update a link to the Kernel Module Packages Manual.
  * When preparing a build for external modules, mention use of the
  upstream recommended 'make modules_prepare' instead of a pair of
  'make prepare' + 'make scripts'.
  * Fix some typos+grammar.
- commit b9b7e79
* Fri Sep 15 2023 jslaby@suse.cz
- Revert "Revert "io_uring/net: don't overflow multishot recv""
  This reverts commit 561ed6f4e7c483049221b51678bdddad3677fb61, liburing
  was fixed in by commit b73e940c9dd4.
- commit ba6631b
* Thu Sep 14 2023 jslaby@suse.cz
- Refresh
  patches.suse/ACPI-video-Add-backlight-native-DMI-quirk-for-Lenovo.patch.
  Update upstream status.
- commit 786e0d6
* Thu Sep 14 2023 jslaby@suse.cz
- Revert "io_uring/net: don't overflow multishot recv"
  (bsc#1215332).
- commit 561ed6f
* Thu Sep 14 2023 jslaby@suse.cz
- Update
  patches.kernel.org/6.5.3-669-media-dvb-symbol-fixup-for-dvb_attach.patch
  (bsc#1012628 bsc#1215264).
  Add a bsc reference.
- commit 3940da6
* Thu Sep 14 2023 clin@suse.com
- drm/msm/adreno: Add missing MODULE_FIRMWARE macros
  (bsc#1213614).
- commit 421188e
* Wed Sep 13 2023 petr.pavlu@suse.com
- doc/README.SUSE: Bring the overview section up to date
  (jsc#PED-5021)
  * Update information in the overview section that was no longer
  accurate.
  * Improve wording and fix some typos+grammar.
- commit 798c075
* Wed Sep 13 2023 jslaby@suse.cz
- sysctl/defaults: increase vm.max_map_count (bsc#1214445)
- commit ac3c174
* Wed Sep 13 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update the references list (jsc#PED-5021)
  * Remove the reference to Linux Documentation Project. It has been
  inactive for years and mostly contains old manuals that aren't
  relevant for contemporary systems and hardware.
  * Update the name and link to LWN.net. The original name "Linux Weekly
  News" has been deemphasized over time by its authors.
  * Update the link to Kernel newbies website.
  * Update the reference to The Linux Kernel Module Programming Guide. The
  document has not been updated for over a decade but it looks its
  content is still relevant for today.
  * Point Kernel Module Packages Manual to the current version.
  * Add a reference to SUSE SolidDriver Program.
- commit 0edac75
* Wed Sep 13 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update title information (jsc#PED-5021)
  * Drop the mention of kernel versions from the readme title.
  * Remove information about the original authors of the document. Rely as
  in case of other readmes on Git metadata to get information about all
  contributions.
  * Strip the table of contents. The document is short and easy to
  navigate just by scrolling through it.
- commit 06f5139
* Wed Sep 13 2023 petr.pavlu@suse.com
- doc/README.SUSE: Update information about DUD (jsc#PED-5021)
  Remove a dead link to description of Device Update Disks found
  previously on novell.com. Replace it with a short section summarizing
  what DUD is and reference the mkdud + mksusecd tools and their
  documentation for more information.
- commit 7eeba4e
* Wed Sep 13 2023 jslaby@suse.cz
- Linux 6.5.3 (bsc#1012628).
- drm/amd/display: ensure async flips are only accepted for fast
  updates (bsc#1012628).
- cpufreq: intel_pstate: set stale CPU frequency to minimum
  (bsc#1012628).
- tpm: Enable hwrng only for Pluton on AMD CPUs (bsc#1012628).
- net: Avoid address overwrite in kernel_connect (bsc#1012628).
- Bluetooth: btrtl: Load FW v2 otherwise FW v1 for RTL8852C
  (bsc#1012628).
- Input: i8042 - add quirk for TUXEDO Gemini 17 Gen1/Clevo PD70PN
  (bsc#1012628).
- Revert "fuse: in fuse_flush only wait if someone wants the
  return code" (bsc#1012628).
- Revert "f2fs: clean up w/ sbi->log_sectors_per_block"
  (bsc#1012628).
- Revert "PCI: tegra194: Enable support for 256 Byte payload"
  (bsc#1012628).
- Revert "net: macsec: preserve ingress frame ordering"
  (bsc#1012628).
- reiserfs: Check the return value from __getblk() (bsc#1012628).
- splice: always fsnotify_access(in), fsnotify_modify(out)
  on success (bsc#1012628).
- splice: fsnotify_access(fd)/fsnotify_modify(fd) in vmsplice
  (bsc#1012628).
- splice: fsnotify_access(in), fsnotify_modify(out) on success
  in tee (bsc#1012628).
- eventfd: prevent underflow for eventfd semaphores (bsc#1012628).
- fs: Fix error checking for d_hash_and_lookup() (bsc#1012628).
- iomap: Remove large folio handling in iomap_invalidate_folio()
  (bsc#1012628).
- tmpfs: verify {g,u}id mount options correctly (bsc#1012628).
- selftests/harness: Actually report SKIP for signal tests
  (bsc#1012628).
- vfs, security: Fix automount superblock LSM init problem,
  preventing NFS sb sharing (bsc#1012628).
- ARM: ptrace: Restore syscall restart tracing (bsc#1012628).
- ARM: ptrace: Restore syscall skipping for tracers (bsc#1012628).
- btrfs: zoned: skip splitting and logical rewriting on pre-alloc
  write (bsc#1012628).
- erofs: release ztailpacking pclusters properly (bsc#1012628).
- locking/arch: Avoid variable shadowing in local_try_cmpxchg()
  (bsc#1012628).
- refscale: Fix uninitalized use of wait_queue_head_t
  (bsc#1012628).
- clocksource: Handle negative skews in "skew is too large"
  messages (bsc#1012628).
- powercap: arm_scmi: Remove recursion while parsing zones
  (bsc#1012628).
- OPP: Fix potential null ptr dereference in
  dev_pm_opp_get_required_pstate() (bsc#1012628).
- OPP: Fix passing 0 to PTR_ERR in _opp_attach_genpd()
  (bsc#1012628).
- selftests/resctrl: Add resctrl.h into build deps (bsc#1012628).
- selftests/resctrl: Don't leak buffer in fill_cache()
  (bsc#1012628).
- selftests/resctrl: Unmount resctrl FS if child fails to run
  benchmark (bsc#1012628).
- selftests/resctrl: Close perf value read fd on errors
  (bsc#1012628).
- sched/fair: remove util_est boosting (bsc#1012628).
- arm64/ptrace: Clean up error handling path in sve_set_common()
  (bsc#1012628).
- sched/psi: Select KERNFS as needed (bsc#1012628).
- cpuidle: teo: Update idle duration estimate when choosing
  shallower state (bsc#1012628).
- x86/decompressor: Don't rely on upper 32 bits of GPRs being
  preserved (bsc#1012628).
- arm64/fpsimd: Only provide the length to cpufeature for xCR
  registers (bsc#1012628).
- sched/rt: Fix sysctl_sched_rr_timeslice intial value
  (bsc#1012628).
- perf/imx_ddr: don't enable counter0 if none of 4 counters are
  used (bsc#1012628).
- selftests/futex: Order calls to futex_lock_pi (bsc#1012628).
- s390/pkey: fix/harmonize internal keyblob headers (bsc#1012628).
- s390/pkey: fix PKEY_TYPE_EP11_AES handling in PKEY_GENSECK2
  IOCTL (bsc#1012628).
- s390/pkey: fix PKEY_TYPE_EP11_AES handling in PKEY_CLR2SECK2
  IOCTL (bsc#1012628).
- s390/pkey: fix PKEY_TYPE_EP11_AES handling in
  PKEY_KBLOB2PROTK[23] (bsc#1012628).
- s390/pkey: fix PKEY_TYPE_EP11_AES handling in PKEY_VERIFYKEY2
  IOCTL (bsc#1012628).
- s390/pkey: fix PKEY_TYPE_EP11_AES handling for sysfs attributes
  (bsc#1012628).
- s390/paes: fix PKEY_TYPE_EP11_AES handling for secure keyblobs
  (bsc#1012628).
- irqchip/loongson-eiointc: Fix return value checking of
  eiointc_index (bsc#1012628).
- ACPI: x86: s2idle: Post-increment variables when getting
  constraints (bsc#1012628).
- ACPI: x86: s2idle: Fix a logic error parsing AMD constraints
  table (bsc#1012628).
- thermal/of: Fix potential uninitialized value access
  (bsc#1012628).
- cpufreq: amd-pstate-ut: Remove module parameter access
  (bsc#1012628).
- cpufreq: amd-pstate-ut: Fix kernel panic when loading the driver
  (bsc#1012628).
- tools/nolibc: arch-*.h: add missing space after ','
  (bsc#1012628).
- tools/nolibc: fix up startup failures for -O0 under gcc <
  11.1.0 (bsc#1012628).
- x86/efistub: Fix PCI ROM preservation in mixed mode
  (bsc#1012628).
- cpufreq: powernow-k8: Use related_cpus instead of cpus in
  driver.exit() (bsc#1012628).
- cpufreq: tegra194: add online/offline hooks (bsc#1012628).
- cpufreq: tegra194: remove opp table in exit hook (bsc#1012628).
- selftests/bpf: Fix bpf_nf failure upon test rerun (bsc#1012628).
- libbpf: only reset sec_def handler when necessary (bsc#1012628).
- bpftool: use a local copy of perf_event to fix accessing ::
  Bpf_cookie (bsc#1012628).
- bpftool: Define a local bpf_perf_link to fix accessing its
  fields (bsc#1012628).
- bpftool: Use a local copy of BPF_LINK_TYPE_PERF_EVENT in
  pid_iter.bpf.c (bsc#1012628).
- bpftool: Use a local bpf_perf_event_value to fix accessing
  its fields (bsc#1012628).
- libbpf: Fix realloc API handling in zero-sized edge cases
  (bsc#1012628).
- bpf: Clear the probe_addr for uprobe (bsc#1012628).
- bpf: Fix an error around PTR_UNTRUSTED (bsc#1012628).
- bpf: Fix an error in verifying a field in a union (bsc#1012628).
- crypto: qat - change value of default idle filter (bsc#1012628).
- tcp: tcp_enter_quickack_mode() should be static (bsc#1012628).
- hwrng: nomadik - keep clock enabled while hwrng is registered
  (bsc#1012628).
- hwrng: pic32 - use devm_clk_get_enabled (bsc#1012628).
- regmap: maple: Use alloc_flags for memory allocations
  (bsc#1012628).
- regmap: rbtree: Use alloc_flags for memory allocations
  (bsc#1012628).
- wifi: rtw89: debug: Fix error handling in
  rtw89_debug_priv_btc_manual_set() (bsc#1012628).
- wifi: mt76: mt7996: fix header translation logic (bsc#1012628).
- wifi: mt76: mt7915: fix background radar event being blocked
  (bsc#1012628).
- wifi: mt76: mt7915: rework tx packets counting when WED is
  active (bsc#1012628).
- wifi: mt76: mt7915: rework tx bytes counting when WED is active
  (bsc#1012628).
- wifi: mt76: mt7921: fix non-PSC channel scan fail (bsc#1012628).
- wifi: mt76: mt7996: fix bss wlan_idx when sending bss_info
  command (bsc#1012628).
- wifi: mt76: mt7996: use correct phy for background radar event
  (bsc#1012628).
- wifi: mt76: mt7996: fix WA event ring size (bsc#1012628).
- udp: re-score reuseport groups when connected sockets are
  present (bsc#1012628).
- bpf: reject unhashed sockets in bpf_sk_assign (bsc#1012628).
- wifi: mt76: mt7915: fix command timeout in AP stop period
  (bsc#1012628).
- wifi: mt76: mt7915: fix capabilities in non-AP mode
  (bsc#1012628).
- wifi: mt76: mt7915: remove VHT160 capability on MT7915
  (bsc#1012628).
- wifi: mt76: testmode: add nla_policy for MT76_TM_ATTR_TX_LENGTH
  (bsc#1012628).
- spi: tegra20-sflash: fix to check return value of
  platform_get_irq() in tegra_sflash_probe() (bsc#1012628).
- can: gs_usb: gs_usb_receive_bulk_callback(): count RX overflow
  errors also in case of OOM (bsc#1012628).
- can: tcan4x5x: Remove reserved register 0x814 from writable
  table (bsc#1012628).
- wifi: mt76: mt7915: fix tlv length of
  mt7915_mcu_get_chan_mib_info (bsc#1012628).
- wifi: mt76: mt7915: fix power-limits while chan_switch
  (bsc#1012628).
- wifi: mwifiex: Fix OOB and integer underflow when rx packets
  (bsc#1012628).
- wifi: mwifiex: fix error recovery in PCIE buffer descriptor
  management (bsc#1012628).
- wifi: ath11k: fix band selection for ppdu received in channel
  177 of 5 GHz (bsc#1012628).
- wifi: ath12k: fix memcpy array overflow in
  ath12k_peer_assoc_h_he() (bsc#1012628).
- selftests/bpf: fix static assert compilation issue for
  test_cls_*.c (bsc#1012628).
- power: supply: qcom_pmi8998_charger: fix uninitialized variable
  (bsc#1012628).
- spi: mpc5xxx-psc: Fix unsigned expression compared with zero
  (bsc#1012628).
- crypto: af_alg - Fix missing initialisation affecting
  gcm-aes-s390 (bsc#1012628).
- bpf: fix bpf_dynptr_slice() to stop return an ERR_PTR
  (bsc#1012628).
- kbuild: rust_is_available: remove -v option (bsc#1012628).
- kbuild: rust_is_available: fix version check when CC has
  multiple arguments (bsc#1012628).
- kbuild: rust_is_available: add check for `bindgen` invocation
  (bsc#1012628).
- kbuild: rust_is_available: fix confusion when a version appears
  in the path (bsc#1012628).
- crypto: stm32 - Properly handle pm_runtime_get failing
  (bsc#1012628).
- crypto: api - Use work queue in crypto_destroy_instance
  (bsc#1012628).
- Bluetooth: ISO: Add support for connecting multiple BISes
  (bsc#1012628).
- Bluetooth: ISO: do not emit new LE Create CIS if previous is
  pending (bsc#1012628).
- Bluetooth: nokia: fix value check in
  nokia_bluetooth_serdev_probe() (bsc#1012628).
- Bluetooth: ISO: Fix not checking for valid CIG/CIS IDs
  (bsc#1012628).
- Bluetooth: hci_conn: Fix not allowing valid CIS ID
  (bsc#1012628).
- Bluetooth: hci_conn: Fix hci_le_set_cig_params (bsc#1012628).
- Bluetooth: Fix potential use-after-free when clear keys
  (bsc#1012628).
- Bluetooth: hci_sync: Don't double print name in add/remove
  adv_monitor (bsc#1012628).
- Bluetooth: hci_sync: Avoid use-after-free in dbg for
  hci_add_adv_monitor() (bsc#1012628).
- Bluetooth: hci_conn: Always allocate unique handles
  (bsc#1012628).
- Bluetooth: hci_event: drop only unbound CIS if Set CIG
  Parameters fails (bsc#1012628).
- net: tcp: fix unexcepted socket die when snd_wnd is 0
  (bsc#1012628).
- net: pcs: lynx: fix lynx_pcs_link_up_sgmii() not doing anything
  in fixed-link mode (bsc#1012628).
- libbpf: Set close-on-exec flag on gzopen (bsc#1012628).
- selftests/bpf: Fix repeat option when kfunc_call verification
  fails (bsc#1012628).
- selftests/bpf: Clean up fmod_ret in bench_rename test script
  (bsc#1012628).
- net: hns3: move dump regs function to a separate file
  (bsc#1012628).
- net: hns3: Support tlv in regs data for HNS3 PF driver
  (bsc#1012628).
- net: hns3: fix wrong rpu tln reg issue (bsc#1012628).
- net-memcg: Fix scope of sockmem pressure indicators
  (bsc#1012628).
- ice: ice_aq_check_events: fix off-by-one check when filling
  buffer (bsc#1012628).
- crypto: caam - fix unchecked return value error (bsc#1012628).
- hwrng: iproc-rng200 - Implement suspend and resume calls
  (bsc#1012628).
- lwt: Fix return values of BPF xmit ops (bsc#1012628).
- lwt: Check LWTUNNEL_XMIT_CONTINUE strictly (bsc#1012628).
- usb: typec: tcpm: set initial svdm version based on pd revision
  (bsc#1012628).
- usb: typec: bus: verify partner exists in
  typec_altmode_attention (bsc#1012628).
- USB: core: Unite old scheme and new scheme descriptor reads
  (bsc#1012628).
- USB: core: Change usb_get_device_descriptor() API (bsc#1012628).
- USB: core: Fix race by not overwriting udev->descriptor in
  hub_port_init() (bsc#1012628).
- scripts/gdb: fix 'lx-lsmod' show the wrong size (bsc#1012628).
- nmi_backtrace: allow excluding an arbitrary CPU (bsc#1012628).
- watchdog/hardlockup: avoid large stack frames in
  watchdog_hardlockup_check() (bsc#1012628).
- fs: ocfs2: namei: check return value of ocfs2_add_entry()
  (bsc#1012628).
- net: lan966x: Fix return value check for vcap_get_rule()
  (bsc#1012628).
- net: annotate data-races around sk->sk_lingertime (bsc#1012628).
- hwmon: (asus-ec-sensosrs) fix mutex path for X670E Hero
  (bsc#1012628).
- wifi: mwifiex: fix memory leak in mwifiex_histogram_read()
  (bsc#1012628).
- wifi: mwifiex: Fix missed return in oob checks failed path
  (bsc#1012628).
- wifi: rtw89: 8852b: rfk: fine tune IQK parameters to improve
  performance on 2GHz band (bsc#1012628).
- selftests: memfd: error out test process when child test fails
  (bsc#1012628).
- samples/bpf: fix bio latency check with tracepoint
  (bsc#1012628).
- samples/bpf: fix broken map lookup probe (bsc#1012628).
- wifi: ath9k: fix races between ath9k_wmi_cmd and
  ath9k_wmi_ctrl_rx (bsc#1012628).
- wifi: ath9k: protect WMI command response buffer replacement
  with a lock (bsc#1012628).
- bpf: Fix a bpf_kptr_xchg() issue with local kptr (bsc#1012628).
- wifi: mac80211: fix puncturing bitmap handling in CSA
  (bsc#1012628).
- wifi: nl80211/cfg80211: add forgotten nla_policy for BSS color
  attribute (bsc#1012628).
- mac80211: make ieee80211_tx_info padding explicit (bsc#1012628).
- bpf: Fix check_func_arg_reg_off bug for graph root/node
  (bsc#1012628).
- wifi: mwifiex: avoid possible NULL skb pointer dereference
  (bsc#1012628).
- Bluetooth: hci_conn: Consolidate code for aborting connections
  (bsc#1012628).
- Bluetooth: ISO: Notify user space about failed bis connections
  (bsc#1012628).
- Bluetooth: hci_sync: Fix UAF on hci_abort_conn_sync
  (bsc#1012628).
- Bluetooth: hci_sync: Fix UAF in hci_disconnect_all_sync
  (bsc#1012628).
- Bluetooth: hci_conn: fail SCO/ISO via hci_conn_failed if ACL
  gone early (bsc#1012628).
- Bluetooth: btusb: Do not call kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- arm64: mm: use ptep_clear() instead of pte_clear() in
  clear_flush() (bsc#1012628).
- net/mlx5: Dynamic cyclecounter shift calculation for PTP free
  running clock (bsc#1012628).
- wifi: ath9k: use IS_ERR() with debugfs_create_dir()
  (bsc#1012628).
- ice: avoid executing commands on other ports when driving sync
  (bsc#1012628).
- octeontx2-pf: fix page_pool creation fail for rings > 32k
  (bsc#1012628).
- net: arcnet: Do not call kfree_skb() under local_irq_disable()
  (bsc#1012628).
- kunit: Fix checksum tests on big endian CPUs (bsc#1012628).
- mlxsw: i2c: Fix chunk size setting in output mailbox buffer
  (bsc#1012628).
- mlxsw: i2c: Limit single transaction buffer size (bsc#1012628).
- mlxsw: core_hwmon: Adjust module label names based on MTCAP
  sensor counter (bsc#1012628).
- crypto: qat - fix crypto capability detection for 4xxx
  (bsc#1012628).
- hwmon: (tmp513) Fix the channel number in tmp51x_is_visible()
  (bsc#1012628).
- octeontx2-pf: Fix PFC TX scheduler free (bsc#1012628).
- octeontx2-af: CN10KB: fix PFC configuration (bsc#1012628).
- cteonxt2-pf: Fix backpressure config for multiple PFC priorities
  to work simultaneously (bsc#1012628).
- sfc: Check firmware supports Ethernet PTP filter (bsc#1012628).
- net/sched: sch_hfsc: Ensure inner classes have fsc curve
  (bsc#1012628).
- pds_core: protect devlink callbacks from fw_down state
  (bsc#1012628).
- pds_core: no health reporter in VF (bsc#1012628).
- pds_core: no reset command for VF (bsc#1012628).
- pds_core: check for work queue before use (bsc#1012628).
- pds_core: pass opcode to devcmd_wait (bsc#1012628).
- netrom: Deny concurrent connect() (bsc#1012628).
- drm/bridge: tc358764: Fix debug print parameter order
  (bsc#1012628).
- ASoC: soc-compress: Fix deadlock in soc_compr_open_fe
  (bsc#1012628).
- ASoC: cs43130: Fix numerator/denominator mixup (bsc#1012628).
- drm: bridge: dw-mipi-dsi: Fix enable/disable of DSI controller
  (bsc#1012628).
- quota: factor out dquot_write_dquot() (bsc#1012628).
- quota: rename dquot_active() to inode_quota_active()
  (bsc#1012628).
- quota: add new helper dquot_active() (bsc#1012628).
- quota: fix dqput() to follow the guarantees dquot_srcu should
  provide (bsc#1012628).
- drm/amd/display: Do not set drr on pipe commit (bsc#1012628).
- drm/hyperv: Fix a compilation issue because of not including
  screen_info.h (bsc#1012628).
- ASoC: stac9766: fix build errors with REGMAP_AC97 (bsc#1012628).
- soc: qcom: ocmem: Fix NUM_PORTS & NUM_MACROS macros
  (bsc#1012628).
- arm64: defconfig: enable Qualcomm MSM8996 Global Clock
  Controller as built-in (bsc#1012628).
- arm64: dts: qcom: sm8150: use proper DSI PHY compatible
  (bsc#1012628).
- arm64: dts: qcom: sm6350: Fix ZAP region (bsc#1012628).
- Revert "arm64: dts: qcom: msm8996: rename labels for HDMI nodes"
  (bsc#1012628).
- arm64: dts: qcom: sm8250: correct dynamic power coefficients
  (bsc#1012628).
- arm64: dts: qcom: sm8450: correct crypto unit address
  (bsc#1012628).
- arm64: dts: qcom: msm8916-l8150: correct light sensor VDDIO
  supply (bsc#1012628).
- arm64: dts: qcom: sm8250-edo: Add gpio line names for TLMM
  (bsc#1012628).
- arm64: dts: qcom: sm8250-edo: Add GPIO line names for PMIC GPIOs
  (bsc#1012628).
- arm64: dts: qcom: sm8250-edo: Rectify gpio-keys (bsc#1012628).
- arm64: dts: qcom: sc8280xp-crd: Correct vreg_misc_3p3 GPIO
  (bsc#1012628).
- arm64: dts: qcom: sc8280xp: Add missing SCM interconnect
  (bsc#1012628).
- arm64: dts: qcom: msm8939: Drop "qcom,idle-state-spc" compatible
  (bsc#1012628).
- arm64: dts: qcom: msm8939: Add missing 'cache-unified' to L2
  (bsc#1012628).
- arm64: dts: qcom: msm8996: Add missing interrupt to the USB2
  controller (bsc#1012628).
- arm64: dts: qcom: sdm845-tama: Set serial indices and
  stdout-path (bsc#1012628).
- arm64: dts: qcom: sm8350: Fix CPU idle state residency times
  (bsc#1012628).
- arm64: dts: qcom: sm8350: Add missing LMH interrupts to cpufreq
  (bsc#1012628).
- arm64: dts: qcom: sc8180x: Fix cluster PSCI suspend param
  (bsc#1012628).
- arm64: dts: qcom: sm8350: Use proper CPU compatibles
  (bsc#1012628).
- arm64: dts: qcom: pm8350: fix thermal zone name (bsc#1012628).
- arm64: dts: qcom: pm8350b: fix thermal zone name (bsc#1012628).
- arm64: dts: qcom: pmr735b: fix thermal zone name (bsc#1012628).
- arm64: dts: qcom: pmk8350: fix ADC-TM compatible string
  (bsc#1012628).
- arm64: dts: qcom: sm8450-hdk: remove pmr735b PMIC inclusion
  (bsc#1012628).
- arm64: dts: qcom: sm8250: Mark PCIe hosts as DMA coherent
  (bsc#1012628).
- arm64: dts: qcom: minor whitespace cleanup around '='
  (bsc#1012628).
- arm64: dts: qcom: sm8250: Mark SMMUs as DMA coherent
  (bsc#1012628).
- ARM: dts: stm32: Add missing detach mailbox for emtrion
  emSBC-Argon (bsc#1012628).
- ARM: dts: stm32: Add missing detach mailbox for Odyssey SoM
  (bsc#1012628).
- ARM: dts: stm32: Add missing detach mailbox for DHCOM SoM
  (bsc#1012628).
- ARM: dts: stm32: Add missing detach mailbox for DHCOR SoM
  (bsc#1012628).
- firmware: ti_sci: Use system_state to determine polling
  (bsc#1012628).
- drm/amdgpu: avoid integer overflow warning in
  amdgpu_device_resize_fb_bar() (bsc#1012628).
- ARM: dts: BCM53573: Drop nonexistent "default-off" LED trigger
  (bsc#1012628).
- ARM: dts: BCM53573: Drop nonexistent #usb-cells (bsc#1012628).
- ARM: dts: BCM53573: Add cells sizes to PCIe node (bsc#1012628).
- ARM: dts: BCM53573: Use updated "spi-gpio" binding properties
  (bsc#1012628).
- arm64: tegra: Add missing alias for NVIDIA IGX Orin
  (bsc#1012628).
- arm64: tegra: Fix HSUART for Jetson AGX Orin (bsc#1012628).
- arm64: dts: qcom: sm8250-sony-xperia: correct GPIO keys wakeup
  again (bsc#1012628).
- arm64: dts: qcom: pm6150l: Add missing short interrupt
  (bsc#1012628).
- arm64: dts: qcom: pm660l: Add missing short interrupt
  (bsc#1012628).
- arm64: dts: qcom: pmi8950: Add missing OVP interrupt
  (bsc#1012628).
- arm64: dts: qcom: pmi8994: Add missing OVP interrupt
  (bsc#1012628).
- arm64: dts: qcom: sc8180x: Add missing 'cache-unified' to L3
  (bsc#1012628).
- arm64: tegra: Fix HSUART for Smaug (bsc#1012628).
- drm/etnaviv: fix dumping of active MMU context (bsc#1012628).
- block: cleanup queue_wc_store (bsc#1012628).
- block: don't allow enabling a cache on devices that don't
  support it (bsc#1012628).
- blk-flush: fix rq->flush.seq for post-flush requests
  (bsc#1012628).
- x86/mm: Fix PAT bit missing from page protection modify mask
  (bsc#1012628).
- drm/bridge: anx7625: Use common macros for DP power sequencing
  commands (bsc#1012628).
- drm/bridge: anx7625: Use common macros for HDCP capabilities
  (bsc#1012628).
- ARM: dts: samsung: s3c6410-mini6410: correct ethernet reg
  addresses (split) (bsc#1012628).
- ARM: dts: samsung: s5pv210-smdkv210: correct ethernet reg
  addresses (split) (bsc#1012628).
- drm: adv7511: Fix low refresh rate register for ADV7533/5
  (bsc#1012628).
- ARM: dts: BCM53573: Fix Ethernet info for Luxul devices
  (bsc#1012628).
- arm64: dts: qcom: sdm845: Add missing RPMh power domain to GCC
  (bsc#1012628).
- arm64: dts: qcom: sdm845: Fix the min frequency of
  "ice_core_clk" (bsc#1012628).
- arm64: dts: qcom: sc8180x: Fix LLCC reg property (bsc#1012628).
- arm64: dts: qcom: msm8996-gemini: fix touchscreen VIO supply
  (bsc#1012628).
- arm64: dts: qcom: sc8180x-pmics: add missing qcom,spmi-gpio
  fallbacks (bsc#1012628).
- arm64: dts: qcom: sc8180x-pmics: add missing gpio-ranges
  (bsc#1012628).
- arm64: dts: qcom: sc8180x-pmics: align SPMI PMIC Power-on node
  name with dtschema (bsc#1012628).
- arm64: dts: qcom: sc8180x-pmics: align LPG node name with
  dtschema (bsc#1012628).
- dt-bindings: arm: msm: kpss-acc: Make the optional reg truly
  optional (bsc#1012628).
- drm/amdgpu: Update min() to min_t() in 'amdgpu_info_ioctl'
  (bsc#1012628).
- drm/amdgpu: Use seq_puts() instead of seq_printf()
  (bsc#1012628).
- arm64: dts: rockchip: Fix PCIe regulators on Radxa E25
  (bsc#1012628).
- arm64: dts: rockchip: Enable SATA on Radxa E25 (bsc#1012628).
- ASoC: loongson: drop of_match_ptr for OF device id
  (bsc#1012628).
- ASoC: fsl: fsl_qmc_audio: Fix snd_pcm_format_t values handling
  (bsc#1012628).
- md: restore 'noio_flag' for the last mddev_resume()
  (bsc#1012628).
- md/raid10: factor out dereference_rdev_and_rrdev()
  (bsc#1012628).
- md/raid10: use dereference_rdev_and_rrdev() to get devices
  (bsc#1012628).
- md/md-bitmap: remove unnecessary local variable in
  backlog_store() (bsc#1012628).
- md/md-bitmap: hold 'reconfig_mutex' in backlog_store()
  (bsc#1012628).
- drm/msm: Update dev core dump to not print backwards
  (bsc#1012628).
- drm/tegra: dpaux: Fix incorrect return value of platform_get_irq
  (bsc#1012628).
- of: unittest: fix null pointer dereferencing in
  of_unittest_find_node_by_name() (bsc#1012628).
- arm64: dts: qcom: sm8150: Fix the I2C7 interrupt (bsc#1012628).
- drm/ast: report connection status on Display Port (bsc#1012628).
- ARM: dts: BCM53573: Fix Tenda AC9 switch CPU port (bsc#1012628).
- drm/armada: Fix off-by-one error in
  armada_overlay_get_property() (bsc#1012628).
- drm/repaper: Reduce temporary buffer size in repaper_fb_dirty()
  (bsc#1012628).
- drm/panel: simple: Add missing connector type and pixel format
  for AUO T215HVN01 (bsc#1012628).
- ima: Remove deprecated IMA_TRUSTED_KEYRING Kconfig
  (bsc#1012628).
- drm: xlnx: zynqmp_dpsub: Add missing check for dma_set_mask
  (bsc#1012628).
- drm/msm/dpu: increase memtype count to 16 for sm8550
  (bsc#1012628).
- drm/msm/dpu: inline DSC_BLK and DSC_BLK_1_2 macros
  (bsc#1012628).
- drm/msm/dpu: fix DSC 1.2 block lengths (bsc#1012628).
- drm/msm/dpu1: Rename sm8150_dspp_blk to sdm845_dspp_blk
  (bsc#1012628).
- drm/msm/dpu: Define names for unnamed sblks (bsc#1012628).
- drm/msm/dpu: fix DSC 1.2 enc subblock length (bsc#1012628).
- arm64: dts: qcom: sm8550-mtp: Add missing supply for L1B
  regulator (bsc#1012628).
- soc: qcom: smem: Fix incompatible types in comparison
  (bsc#1012628).
- drm/msm/mdp5: Don't leak some plane state (bsc#1012628).
- firmware: meson_sm: fix to avoid potential NULL pointer
  dereference (bsc#1012628).
- drm/msm/dpu: fix the irq index in
  dpu_encoder_phys_wb_wait_for_commit_done (bsc#1012628).
- arm64: dts: ti: k3-j784s4-evm: Correct Pin mux offset for ospi
  (bsc#1012628).
- arm64: dts: ti: k3-j721s2: correct pinmux offset for ospi
  (bsc#1012628).
- smackfs: Prevent underflow in smk_set_cipso() (bsc#1012628).
- drm/amdgpu: Sort the includes in amdgpu/amdgpu_drv.c
  (bsc#1012628).
- drm/amdgpu: Move vram, gtt & flash defines to amdgpu_ ttm &
  _psp.h (bsc#1012628).
- drm/amd/pm: fix variable dereferenced issue in
  amdgpu_device_attr_create() (bsc#1012628).
- drm/msm/a2xx: Call adreno_gpu_init() earlier (bsc#1012628).
- drm/msm/a6xx: Fix GMU lockdep splat (bsc#1012628).
- ASoC: SOF: Intel: hda-mlink: fix off-by-one error (bsc#1012628).
- ASoC: SOF: Intel: fix u16/32 confusion in LSDIID (bsc#1012628).
- drm/mediatek: Fix uninitialized symbol (bsc#1012628).
- audit: fix possible soft lockup in __audit_inode_child()
  (bsc#1012628).
- block/mq-deadline: use correct way to throttling write requests
  (bsc#1012628).
- io_uring: fix drain stalls by invalid SQE (bsc#1012628).
- block: move the BIO_CLONED checks out of __bio_try_merge_page
  (bsc#1012628).
- block: move the bi_vcnt check out of __bio_try_merge_page
  (bsc#1012628).
- block: move the bi_size overflow check in __bio_try_merge_page
  (bsc#1012628).
- block: move the bi_size update out of __bio_try_merge_page
  (bsc#1012628).
- block: don't pass a bio to bio_try_merge_hw_seg (bsc#1012628).
- block: make bvec_try_merge_hw_page() non-static (bsc#1012628).
- bio-integrity: create multi-page bvecs in
  bio_integrity_add_page() (bsc#1012628).
- drm/mediatek: dp: Add missing error checks in
  mtk_dp_parse_capabilities (bsc#1012628).
- arm64: dts: ti: k3-j784s4-evm: Correct Pin mux offset for ADC
  (bsc#1012628).
- arm64: dts: ti: k3-j784s4: Fix interrupt ranges for wkup &
  main gpio (bsc#1012628).
- bus: ti-sysc: Fix build warning for 64-bit build (bsc#1012628).
- drm/mediatek: Remove freeing not dynamic allocated memory
  (bsc#1012628).
- drm/mediatek: Add cnt checking for coverity issue (bsc#1012628).
- arm64: dts: imx8mp-debix: remove unused fec pinctrl node
  (bsc#1012628).
- ARM: dts: qcom: ipq4019: correct SDHCI XO clock (bsc#1012628).
- arm64: dts: ti: k3-am62x-sk-common: Update main-i2c1 frequency
  (bsc#1012628).
- drm/mediatek: Fix potential memory leak if vmap() fail
  (bsc#1012628).
- drm/mediatek: Fix void-pointer-to-enum-cast warning
  (bsc#1012628).
- arm64: dts: qcom: apq8016-sbc: Fix ov5640 regulator supply names
  (bsc#1012628).
- arm64: dts: qcom: apq8016-sbc: Rename ov5640 enable-gpios to
  powerdown-gpios (bsc#1012628).
- arm64: dts: qcom: msm8998: Drop bus clock reference from MMSS
  SMMU (bsc#1012628).
- arm64: dts: qcom: msm8998: Add missing power domain to MMSS SMMU
  (bsc#1012628).
- ARM: dts: qcom: sdx65-mtp: Update the pmic used in sdx65
  (bsc#1012628).
- arm64: dts: qcom: msm8996: Fix dsi1 interrupts (bsc#1012628).
- arm64: dts: qcom: sc8280xp-x13s: Unreserve NC pins
  (bsc#1012628).
- bus: ti-sysc: Fix cast to enum warning (bsc#1012628).
- block: uapi: Fix compilation errors using ioprio.h with C++
  (bsc#1012628).
- md/raid5-cache: fix a deadlock in r5l_exit_log() (bsc#1012628).
- md/raid5-cache: fix null-ptr-deref for
  r5l_flush_stripe_to_raid() (bsc#1012628).
- firmware: cs_dsp: Fix new control name check (bsc#1012628).
- blk-cgroup: Fix NULL deref caused by blkg_policy_data being
  installed before init (bsc#1012628).
- md/raid0: Factor out helper for mapping and submitting a bio
  (bsc#1012628).
- md/raid0: Fix performance regression for large sequential writes
  (bsc#1012628).
- md: raid0: account for split bio in iostat accounting
  (bsc#1012628).
- ASoC: SOF: amd: clear dsp to host interrupt status
  (bsc#1012628).
- of: overlay: Call of_changeset_init() early (bsc#1012628).
- of: unittest: Fix overlay type in apply/revert check
  (bsc#1012628).
- ALSA: ac97: Fix possible error value of *rac97 (bsc#1012628).
- ALSA: usb-audio: Attach legacy rawmidi after probing all UMP
  EPs (bsc#1012628).
- ALSA: ump: Fill group names for legacy rawmidi substreams
  (bsc#1012628).
- ALSA: ump: Don't create unused substreams for static blocks
  (bsc#1012628).
- ALSA: ump: Fix -Wformat-truncation warnings (bsc#1012628).
- ipmi:ssif: Add check for kstrdup (bsc#1012628).
- ipmi:ssif: Fix a memory leak when scanning for an adapter
  (bsc#1012628).
- clk: qcom: gpucc-sm6350: Introduce index-based clk lookup
  (bsc#1012628).
- clk: qcom: gpucc-sm6350: Fix clock source names (bsc#1012628).
- clk: qcom: gcc-sc8280xp: Add missing GDSC flags (bsc#1012628).
- dt-bindings: clock: qcom,gcc-sc8280xp: Add missing GDSCs
  (bsc#1012628).
- clk: qcom: gcc-sc8280xp: Add missing GDSCs (bsc#1012628).
- clk: qcom: gcc-sm7150: Add CLK_OPS_PARENT_ENABLE to sdcc2 rcg
  (bsc#1012628).
- clk: rockchip: rk3568: Fix PLL rate setting for 78.75MHz
  (bsc#1012628).
- PCI: apple: Initialize pcie->nvecs before use (bsc#1012628).
- PCI: qcom-ep: Switch MHI bus master clock off during L1SS
  (bsc#1012628).
- clk: qcom: gcc-sc8280xp: fix runtime PM imbalance on probe
  errors (bsc#1012628).
- drivers: clk: keystone: Fix parameter judgment in
  _of_pll_clk_init() (bsc#1012628).
- EDAC/i10nm: Skip the absent memory controllers (bsc#1012628).
- iommufd: Fix locking around hwpt allocation (bsc#1012628).
- PCI/DOE: Fix destroy_work_on_stack() race (bsc#1012628).
- clk: qcom: dispcc-sc8280xp: Use ret registers on GDSCs
  (bsc#1012628).
- clk: sunxi-ng: Modify mismatched function name (bsc#1012628).
- clk: qcom: gcc-sc7180: Fix up gcc_sdcc2_apps_clk_src
  (bsc#1012628).
- EDAC/igen6: Fix the issue of no error events (bsc#1012628).
- ext4: correct grp validation in ext4_mb_good_group
  (bsc#1012628).
- ext4: avoid potential data overflow in next_linear_group
  (bsc#1012628).
- clk: qcom: gcc-sm8250: Fix gcc_sdcc2_apps_clk_src (bsc#1012628).
- clk: qcom: fix some Kconfig corner cases (bsc#1012628).
- kvm/vfio: Prepare for accepting vfio device fd (bsc#1012628).
- kvm/vfio: ensure kvg instance stays around in
  kvm_vfio_group_add() (bsc#1012628).
- clk: qcom: reset: Use the correct type of sleep/delay based
  on length (bsc#1012628).
- clk: qcom: gcc-sm6350: Fix gcc_sdcc2_apps_clk_src (bsc#1012628).
- PCI: microchip: Correct the DED and SEC interrupt bit offsets
  (bsc#1012628).
- PCI: Mark NVIDIA T4 GPUs to avoid bus reset (bsc#1012628).
- pinctrl: mcp23s08: check return value of devm_kasprintf()
  (bsc#1012628).
- PCI: Add locking to RMW PCI Express Capability Register
  accessors (bsc#1012628).
- PCI: Make link retraining use RMW accessors for changing LNKCTL
  (bsc#1012628).
- PCI: pciehp: Use RMW accessors for changing LNKCTL
  (bsc#1012628).
- PCI/ASPM: Use RMW accessors for changing LNKCTL (bsc#1012628).
- clk: qcom: gcc-sm8450: Use floor ops for SDCC RCGs
  (bsc#1012628).
- clk: qcom: gcc-qdu1000: Fix gcc_pcie_0_pipe_clk_src clock
  handling (bsc#1012628).
- clk: qcom: gcc-qdu1000: Fix clkref clocks handling
  (bsc#1012628).
- clk: imx: pllv4: Fix SPLL2 MULT range (bsc#1012628).
- clk: imx: imx8ulp: update SPLL2 type (bsc#1012628).
- clk: imx8mp: fix sai4 clock (bsc#1012628).
- clk: imx: composite-8m: fix clock pauses when set_rate would
  be a no-op (bsc#1012628).
- powerpc/radix: Move some functions into #ifdef
  CONFIG_KVM_BOOK3S_HV_POSSIBLE (bsc#1012628).
- vfio/type1: fix cap_migration information leak (bsc#1012628).
- nvdimm: Fix memleak of pmu attr_groups in
  unregister_nvdimm_pmu() (bsc#1012628).
- nvdimm: Fix dereference after free in register_nvdimm_pmu()
  (bsc#1012628).
- powerpc/fadump: reset dump area size if fadump memory reserve
  fails (bsc#1012628).
- powerpc/perf: Convert fsl_emb notifier to state machine
  callbacks (bsc#1012628).
- pinctrl: mediatek: fix pull_type data for MT7981 (bsc#1012628).
- pinctrl: mediatek: assign functions to configure pin bias on
  MT7986 (bsc#1012628).
- drm/amdgpu: Use RMW accessors for changing LNKCTL (bsc#1012628).
- drm/radeon: Use RMW accessors for changing LNKCTL (bsc#1012628).
- net/mlx5: Use RMW accessors for changing LNKCTL (bsc#1012628).
- wifi: ath11k: Use RMW accessors for changing LNKCTL
  (bsc#1012628).
- wifi: ath12k: Use RMW accessors for changing LNKCTL
  (bsc#1012628).
- wifi: ath10k: Use RMW accessors for changing LNKCTL
  (bsc#1012628).
- NFSv4.2: Fix READ_PLUS smatch warnings (bsc#1012628).
- NFSv4.2: Fix READ_PLUS size calculations (bsc#1012628).
- NFSv4.2: Rework scratch handling for READ_PLUS (again)
  (bsc#1012628).
- PCI: layerscape: Add workaround for lost link capabilities
  during reset (bsc#1012628).
- powerpc: Don't include lppaca.h in paca.h (bsc#1012628).
- powerpc/pseries: Rework lppaca_shared_proc() to avoid
  DEBUG_PREEMPT (bsc#1012628).
- nfs/blocklayout: Use the passed in gfp flags (bsc#1012628).
- powerpc/pseries: Fix hcall tracepoints with JUMP_LABEL=n
  (bsc#1012628).
- powerpc/mpc5xxx: Add missing fwnode_handle_put() (bsc#1012628).
- powerpc/iommu: Fix notifiers being shared by PCI and VIO buses
  (bsc#1012628).
- ext4: fix unttached inode after power cut with orphan file
  feature enabled (bsc#1012628).
- jfs: validate max amount of blocks before allocation
  (bsc#1012628).
- SUNRPC: Fix the recent bv_offset fix (bsc#1012628).
- fs: lockd: avoid possible wrong NULL parameter (bsc#1012628).
- NFSD: da_addr_body field missing in some GETDEVICEINFO replies
  (bsc#1012628).
- clk: qcom: Fix SM_GPUCC_8450 dependencies (bsc#1012628).
- NFS: Guard against READDIR loop when entry names exceed
  MAXNAMELEN (bsc#1012628).
- NFSv4.2: fix handling of COPY ERR_OFFLOAD_NO_REQ (bsc#1012628).
- pNFS: Fix assignment of xprtdata.cred (bsc#1012628).
- cgroup/cpuset: Inherit parent's load balance state in v2
  (bsc#1012628).
- RDMA/qedr: Remove a duplicate assignment in irdma_query_ah()
  (bsc#1012628).
- media: ov5640: fix low resolution image abnormal issue
  (bsc#1012628).
- media: i2c: imx290: drop format param from imx290_ctrl_update
  (bsc#1012628).
- media: ad5820: Drop unsupported ad5823 from i2c_ and
  of_device_id tables (bsc#1012628).
- media: i2c: tvp5150: check return value of devm_kasprintf()
  (bsc#1012628).
- media: v4l2-core: Fix a potential resource leak in
  v4l2_fwnode_parse_link() (bsc#1012628).
- iommu/amd/iommu_v2: Fix pasid_state refcount dec hit 0 warning
  on pasid unbind (bsc#1012628).
- iommu: rockchip: Fix directory table address encoding
  (bsc#1012628).
- drivers: usb: smsusb: fix error handling code in
  smsusb_init_device (bsc#1012628).
- media: dib7000p: Fix potential division by zero (bsc#1012628).
- media: dvb-usb: m920x: Fix a potential memory leak in
  m920x_i2c_xfer() (bsc#1012628).
- media: cx24120: Add retval check for cx24120_message_send()
  (bsc#1012628).
- RDMA/siw: Fabricate a GID on tun and loopback devices
  (bsc#1012628).
- scsi: hisi_sas: Fix normally completed I/O analysed as failed
  (bsc#1012628).
- dt-bindings: extcon: maxim,max77843: restrict connector
  properties (bsc#1012628).
- media: amphion: reinit vpu if reqbufs output 0 (bsc#1012628).
- media: amphion: add helper function to get id name
  (bsc#1012628).
- media: verisilicon: Fix TRY_FMT on encoder OUTPUT (bsc#1012628).
- media: mtk-jpeg: Fix use after free bug due to uncanceled work
  (bsc#1012628).
- media: amphion: decoder support display delay for all formats
  (bsc#1012628).
- media: rkvdec: increase max supported height for H.264
  (bsc#1012628).
- media: amphion: fix CHECKED_RETURN issues reported by coverity
  (bsc#1012628).
- media: amphion: fix REVERSE_INULL issues reported by coverity
  (bsc#1012628).
- media: amphion: fix UNINIT issues reported by coverity
  (bsc#1012628).
- media: amphion: fix UNUSED_VALUE issue reported by coverity
  (bsc#1012628).
- media: amphion: ensure the bitops don't cross boundaries
  (bsc#1012628).
- media: mediatek: vcodec: fix AV1 decode fail for 36bit iova
  (bsc#1012628).
- media: mediatek: vcodec: Return NULL if no vdec_fb is found
  (bsc#1012628).
- media: mediatek: vcodec: fix potential double free
  (bsc#1012628).
- media: mediatek: vcodec: fix resource leaks in
  vdec_msg_queue_init() (bsc#1012628).
- usb: phy: mxs: fix getting wrong state with
  mxs_phy_is_otg_host() (bsc#1012628).
- scsi: RDMA/srp: Fix residual handling (bsc#1012628).
- scsi: ufs: Fix residual handling (bsc#1012628).
- scsi: iscsi: Add length check for nlattr payload (bsc#1012628).
- scsi: iscsi: Add strlen() check in iscsi_if_set{_host}_param()
  (bsc#1012628).
- scsi: be2iscsi: Add length check when parsing nlattrs
  (bsc#1012628).
- scsi: qla4xxx: Add length check when parsing nlattrs
  (bsc#1012628).
- iio: accel: adxl313: Fix adxl313_i2c_id[] table (bsc#1012628).
- serial: sprd: Assign sprd_port after initialized to avoid
  wrong access (bsc#1012628).
- serial: sprd: Fix DMA buffer leak issue (bsc#1012628).
- x86/APM: drop the duplicate APM_MINOR_DEV macro (bsc#1012628).
- RDMA/rxe: Move work queue code to subroutines (bsc#1012628).
- RDMA/rxe: Fix unsafe drain work queue code (bsc#1012628).
- RDMA/rxe: Fix rxe_modify_srq (bsc#1012628).
- RDMA/rxe: Fix incomplete state save in rxe_requester
  (bsc#1012628).
- scsi: qedf: Do not touch __user pointer in
  qedf_dbg_stop_io_on_error_cmd_read() directly (bsc#1012628).
- scsi: qedf: Do not touch __user pointer in
  qedf_dbg_debug_cmd_read() directly (bsc#1012628).
- scsi: qedf: Do not touch __user pointer in
  qedf_dbg_fp_int_cmd_read() directly (bsc#1012628).
- RDMA/irdma: Replace one-element array with flexible-array member
  (bsc#1012628).
- coresight: tmc: Explicit type conversions to prevent integer
  overflow (bsc#1012628).
- interconnect: qcom: qcm2290: Enable sync state (bsc#1012628).
- dma-buf/sync_file: Fix docs syntax (bsc#1012628).
- driver core: test_async: fix an error code (bsc#1012628).
- driver core: Call dma_cleanup() on the test_remove path
  (bsc#1012628).
- kernfs: add stub helper for kernfs_generic_poll() (bsc#1012628).
- extcon: cht_wc: add POWER_SUPPLY dependency (bsc#1012628).
- iommu/mediatek: Fix two IOMMU share pagetable issue
  (bsc#1012628).
- iommu/sprd: Add missing force_aperture (bsc#1012628).
- iommu: Remove kernel-doc warnings (bsc#1012628).
- bnxt_en: Update HW interface headers (bsc#1012628).
- bnxt_en: Share the bar0 address with the RoCE driver
  (bsc#1012628).
- RDMA/bnxt_re: Initialize Doorbell pacing feature (bsc#1012628).
- RDMA/bnxt_re: Fix max_qp count for virtual functions
  (bsc#1012628).
- RDMA/bnxt_re: Remove a redundant flag (bsc#1012628).
- RDMA/hns: Fix port active speed (bsc#1012628).
- RDMA/hns: Fix incorrect post-send with direct wqe of wr-list
  (bsc#1012628).
- RDMA/hns: Fix inaccurate error label name in init instance
  (bsc#1012628).
- RDMA/hns: Fix CQ and QP cache affinity (bsc#1012628).
- IB/uverbs: Fix an potential error pointer dereference
  (bsc#1012628).
- fsi: aspeed: Reset master errors after CFAM reset (bsc#1012628).
- iommu/qcom: Disable and reset context bank before programming
  (bsc#1012628).
- tty: serial: qcom-geni-serial: Poll primary sequencer irq
  status after cancel_tx (bsc#1012628).
- iommu/vt-d: Fix to flush cache of PASID directory table
  (bsc#1012628).
- platform/x86: dell-sysman: Fix reference leak (bsc#1012628).
- media: cec: core: add adap_nb_transmit_canceled() callback
  (bsc#1012628).
- media: cec: core: add adap_unconfigured() callback
  (bsc#1012628).
- media: go7007: Remove redundant if statement (bsc#1012628).
- media: venus: hfi_venus: Only consider sys_idle_indicator on V1
  (bsc#1012628).
- arm64: defconfig: Drop CONFIG_VIDEO_IMX_MEDIA (bsc#1012628).
- media: ipu-bridge: Fix null pointer deref on SSDB/PLD parsing
  warnings (bsc#1012628).
- media: ipu3-cio2: rename cio2 bridge to ipu bridge and move
  out of ipu3 (bsc#1012628).
- media: ipu-bridge: Do not use on stack memory for
  software_node.name field (bsc#1012628).
- docs: ABI: fix spelling/grammar in SBEFIFO timeout interface
  (bsc#1012628).
- USB: gadget: core: Add missing kerneldoc for vbus_work
  (bsc#1012628).
- USB: gadget: f_mass_storage: Fix unused variable warning
  (bsc#1012628).
- drivers: base: Free devm resources when unregistering a device
  (bsc#1012628).
- HID: input: Support devices sending Eraser without Invert
  (bsc#1012628).
- HID: nvidia-shield: Remove led_classdev_unregister in
  thunderstrike_create (bsc#1012628).
- media: ov5640: Enable MIPI interface in ov5640_set_power_mipi()
  (bsc#1012628).
- media: ov5640: Fix initial RESETB state and annotate timings
  (bsc#1012628).
- media: Documentation: Fix [GS]_ROUTING documentation
  (bsc#1012628).
- media: ov2680: Remove auto-gain and auto-exposure controls
  (bsc#1012628).
- media: ov2680: Fix ov2680_bayer_order() (bsc#1012628).
- media: ov2680: Fix vflip / hflip set functions (bsc#1012628).
- media: ov2680: Remove VIDEO_V4L2_SUBDEV_API ifdef-s
  (bsc#1012628).
- media: ov2680: Don't take the lock for try_fmt calls
  (bsc#1012628).
- media: ov2680: Add ov2680_fill_format() helper function
  (bsc#1012628).
- media: ov2680: Fix ov2680_set_fmt() which ==
  V4L2_SUBDEV_FORMAT_TRY not working (bsc#1012628).
- media: ov2680: Fix regulators being left enabled on
  ov2680_power_on() errors (bsc#1012628).
- media: i2c: rdacm21: Fix uninitialized value (bsc#1012628).
- f2fs: fix spelling in ABI documentation (bsc#1012628).
- f2fs: fix to avoid mmap vs set_compress_option case
  (bsc#1012628).
- f2fs: don't reopen the main block device in f2fs_scan_devices
  (bsc#1012628).
- f2fs: check zone type before sending async reset zone command
  (bsc#1012628).
- f2fs: Only lfs mode is allowed with zoned block device feature
  (bsc#1012628).
- Revert "f2fs: fix to do sanity check on extent cache correctly"
  (bsc#1012628).
- f2fs: fix to account gc stats correctly (bsc#1012628).
- f2fs: fix to account cp stats correctly (bsc#1012628).
- cgroup:namespace: Remove unused cgroup_namespaces_init()
  (bsc#1012628).
- coresight: trbe: Allocate platform data per device
  (bsc#1012628).
- coresight: platform: acpi: Ignore the absence of graph
  (bsc#1012628).
- coresight: Fix memory leak in acpi_buffer->pointer
  (bsc#1012628).
- coresight: trbe: Fix TRBE potential sleep in atomic context
  (bsc#1012628).
- Revert "f2fs: do not issue small discard commands during
  checkpoint" (bsc#1012628).
- RDMA/irdma: Prevent zero-length STAG registration (bsc#1012628).
- scsi: core: Use 32-bit hostnum in scsi_host_lookup()
  (bsc#1012628).
- scsi: fcoe: Fix potential deadlock on &fip->ctlr_lock
  (bsc#1012628).
- interconnect: qcom: sm8450: Enable sync_state (bsc#1012628).
- interconnect: qcom: bcm-voter: Improve enable_mask handling
  (bsc#1012628).
- interconnect: qcom: bcm-voter: Use enable_maks for keepalive
  voting (bsc#1012628).
- dt-bindings: usb: samsung,exynos-dwc3: fix order of clocks on
  Exynos5433 (bsc#1012628).
- dt-bindings: usb: samsung,exynos-dwc3: Fix Exynos5433 compatible
  (bsc#1012628).
- serial: tegra: handle clk prepare error in tegra_uart_hw_init()
  (bsc#1012628).
- Documentation: devices.txt: Remove ttyIOC* (bsc#1012628).
- Documentation: devices.txt: Remove ttySIOC* (bsc#1012628).
- Documentation: devices.txt: Fix minors for ttyCPM*
  (bsc#1012628).
- amba: bus: fix refcount leak (bsc#1012628).
- Revert "IB/isert: Fix incorrect release of isert connection"
  (bsc#1012628).
- RDMA/siw: Balance the reference of cep->kref in the error path
  (bsc#1012628).
- RDMA/siw: Correct wrong debug message (bsc#1012628).
- RDMA/efa: Fix wrong resources deallocation order (bsc#1012628).
- HID: logitech-dj: Fix error handling in
  logi_dj_recv_switch_to_dj_mode() (bsc#1012628).
- nvmem: core: Return NULL when no nvmem layout is found
  (bsc#1012628).
- riscv: Require FRAME_POINTER for some configurations
  (bsc#1012628).
- f2fs: compress: fix to assign compress_level for lz4 correctly
  (bsc#1012628).
- HID: uclogic: Correct devm device reference for hidinput
  input_dev name (bsc#1012628).
- HID: multitouch: Correct devm device reference for hidinput
  input_dev name (bsc#1012628).
- HID: nvidia-shield: Reference hid_device devm allocation of
  input_dev name (bsc#1012628).
- platform/x86/amd/pmf: Fix a missing cleanup path (bsc#1012628).
- workqueue: fix data race with the pwq->stats[] increment
  (bsc#1012628).
- tick/rcu: Fix false positive "softirq work is pending" messages
  (bsc#1012628).
- x86/speculation: Mark all Skylake CPUs as vulnerable to GDS
  (bsc#1012628).
- tracing: Remove extra space at the end of hwlat_detector/mode
  (bsc#1012628).
- tracing: Fix race issue between cpu buffer write and swap
  (bsc#1012628).
- mm/pagewalk: fix bootstopping regression from extra pte_unmap()
  (bsc#1012628).
- mtd: rawnand: brcmnand: Fix mtd oobsize (bsc#1012628).
- dmaengine: idxd: Modify the dependence of attribute
  pasid_enabled (bsc#1012628).
- phy/rockchip: inno-hdmi: use correct vco_div_5 macro on rk3328
  (bsc#1012628).
- phy/rockchip: inno-hdmi: round fractal pixclock in rk3328
  recalc_rate (bsc#1012628).
- phy/rockchip: inno-hdmi: do not power on rk3328 post pll on
  reg write (bsc#1012628).
- rpmsg: glink: Add check for kstrdup (bsc#1012628).
- leds: aw200xx: Fix error code in probe() (bsc#1012628).
- leds: simatic-ipc-leds-gpio: Restore LEDS_CLASS dependency
  (bsc#1012628).
- leds: pwm: Fix error code in led_pwm_create_fwnode()
  (bsc#1012628).
- thermal/drivers/mediatek/lvts_thermal: Handle IRQ on all
  controllers (bsc#1012628).
- thermal/drivers/mediatek/lvts_thermal: Honor sensors in
  immediate mode (bsc#1012628).
- thermal/drivers/mediatek/lvts_thermal: Use offset threshold
  for IRQ (bsc#1012628).
- thermal/drivers/mediatek/lvts_thermal: Disable undesired
  interrupts (bsc#1012628).
- thermal/drivers/mediatek/lvts_thermal: Don't leave threshold
  zeroed (bsc#1012628).
- thermal/drivers/mediatek/lvts_thermal: Manage threshold between
  sensors (bsc#1012628).
- thermal/drivers/imx8mm: Suppress log message on probe deferral
  (bsc#1012628).
- leds: multicolor: Use rounded division when calculating color
  components (bsc#1012628).
- leds: Fix BUG_ON check for LED_COLOR_ID_MULTI that is always
  false (bsc#1012628).
- leds: trigger: tty: Do not use LED_ON/OFF constants, use
  led_blink_set_oneshot instead (bsc#1012628).
- mtd: spi-nor: Check bus width while setting QE bit
  (bsc#1012628).
- mtd: rawnand: fsmc: handle clk prepare error in
  fsmc_nand_resume() (bsc#1012628).
- mfd: rk808: Make MFD_RK8XX tristate (bsc#1012628).
- mfd: rz-mtu3: Link time dependencies (bsc#1012628).
- um: Fix hostaudio build errors (bsc#1012628).
- dmaengine: ste_dma40: Add missing IRQ check in d40_probe
  (bsc#1012628).
- dmaengine: idxd: Simplify WQ attribute visibility checks
  (bsc#1012628).
- dmaengine: idxd: Expose ATS disable knob only when WQ ATS is
  supported (bsc#1012628).
- dmaengine: idxd: Allow ATS disable update only for configurable
  devices (bsc#1012628).
- dmaengine: idxd: Fix issues with PRS disable sysfs knob
  (bsc#1012628).
- remoteproc: stm32: fix incorrect optional pointers
  (bsc#1012628).
- Drivers: hv: vmbus: Don't dereference ACPI root object handle
  (bsc#1012628).
- um: virt-pci: fix missing declaration warning (bsc#1012628).
- cpufreq: Fix the race condition while updating the
  transition_task of policy (bsc#1012628).
- virtio_vdpa: build affinity masks conditionally (bsc#1012628).
- virtio_ring: fix avail_wrap_counter in virtqueue_add_packed
  (bsc#1012628).
- net: deal with integer overflows in kmalloc_reserve()
  (bsc#1012628).
- igmp: limit igmpv3_newpack() packet size to IP_MAX_MTU
  (bsc#1012628).
- netfilter: ipset: add the missing IP_SET_HASH_WITH_NET0 macro
  for ip_set_hash_netportnet.c (bsc#1012628).
- netfilter: nft_exthdr: Fix non-linear header modification
  (bsc#1012628).
- netfilter: xt_u32: validate user space input (bsc#1012628).
- netfilter: xt_sctp: validate the flag_info count (bsc#1012628).
- skbuff: skb_segment, Call zero copy functions before using
  skbuff frags (bsc#1012628).
- drbd: swap bvec_set_page len and offset (bsc#1012628).
- gpio: zynq: restore zynq_gpio_irq_reqres/zynq_gpio_irq_relres
  callbacks (bsc#1012628).
- igb: set max size RX buffer when store bad packet is enabled
  (bsc#1012628).
- parisc: ccio-dma: Create private runway procfs root entry
  (bsc#1012628).
- PM / devfreq: Fix leak in devfreq_dev_release() (bsc#1012628).
- Multi-gen LRU: fix per-zone reclaim (bsc#1012628).
- ALSA: pcm: Fix missing fixup call in compat hw_refine ioctl
  (bsc#1012628).
- virtio_pmem: add the missing REQ_OP_WRITE for flush bio
  (bsc#1012628).
- rcu: dump vmalloc memory info safely (bsc#1012628).
- printk: ringbuffer: Fix truncating buffer size min_t cast
  (bsc#1012628).
- scsi: core: Fix the scsi_set_resid() documentation
  (bsc#1012628).
- mm/vmalloc: add a safer version of find_vm_area() for debug
  (bsc#1012628).
- cpu/hotplug: Prevent self deadlock on CPU hot-unplug
  (bsc#1012628).
- media: i2c: ccs: Check rules is non-NULL (bsc#1012628).
- media: i2c: Add a camera sensor top level menu (bsc#1012628).
- PCI: rockchip: Use 64-bit mask on MSI 64-bit PCI address
  (bsc#1012628).
- ipmi_si: fix a memleak in try_smi_init() (bsc#1012628).
- ARM: OMAP2+: Fix -Warray-bounds warning in _pwrdm_state_switch()
  (bsc#1012628).
- riscv: Move create_tmp_mapping() to init sections (bsc#1012628).
- riscv: Mark KASAN tmp* page tables variables as static
  (bsc#1012628).
- XArray: Do not return sibling entries from xa_load()
  (bsc#1012628).
- io_uring: fix false positive KASAN warnings (bsc#1012628).
- io_uring: break iopolling on signal (bsc#1012628).
- io_uring/sqpoll: fix io-wq affinity when IORING_SETUP_SQPOLL
  is used (bsc#1012628).
- io_uring/net: don't overflow multishot recv (bsc#1012628).
- io_uring/net: don't overflow multishot accept (bsc#1012628).
- io_uring: break out of iowq iopoll on teardown (bsc#1012628).
- backlight/gpio_backlight: Compare against struct fb_info.device
  (bsc#1012628).
- backlight/bd6107: Compare against struct fb_info.device
  (bsc#1012628).
- backlight/lv5207lp: Compare against struct fb_info.device
  (bsc#1012628).
- drm/amd/display: register edp_backlight_control() for DCN301
  (bsc#1012628).
- xtensa: PMU: fix base address for the newer hardware
  (bsc#1012628).
- LoongArch: mm: Add p?d_leaf() definitions (bsc#1012628).
- powercap: intel_rapl: Fix invalid setting of Power Limit 4
  (bsc#1012628).
- powerpc/ftrace: Fix dropping weak symbols with older toolchains
  (bsc#1012628).
- i3c: master: svc: fix probe failure when no i3c device exist
  (bsc#1012628).
- io_uring: Don't set affinity on a dying sqpoll thread
  (bsc#1012628).
- arm64: csum: Fix OoB access in IP checksum code for negative
  lengths (bsc#1012628).
- ALSA: usb-audio: Fix potential memory leaks at error path for
  UMP open (bsc#1012628).
- ALSA: seq: Fix snd_seq_expand_var_event() call to user-space
  (bsc#1012628).
- ALSA: hda/cirrus: Fix broken audio on hardware with two CS42L42
  codecs (bsc#1012628).
- selftests/landlock: Fix a resource leak (bsc#1012628).
- media: dvb: symbol fixup for dvb_attach() (bsc#1012628).
- media: venus: hfi_venus: Write to VIDC_CTRL_INIT after unmasking
  interrupts (bsc#1012628).
- media: nxp: Fix wrong return pointer check in
  mxc_isi_crossbar_init() (bsc#1012628).
- Revert "scsi: qla2xxx: Fix buffer overrun" (bsc#1012628).
- scsi: mpt3sas: Perform additional retries if doorbell read
  returns 0 (bsc#1012628).
- PCI: Free released resource after coalescing (bsc#1012628).
- PCI: hv: Fix a crash in hv_pci_restore_msi_msg() during
  hibernation (bsc#1012628).
- PCI/PM: Only read PCI_PM_CTRL register when available
  (bsc#1012628).
- dt-bindings: PCI: qcom: Fix SDX65 compatible (bsc#1012628).
- ntb: Drop packets when qp link is down (bsc#1012628).
- ntb: Clean up tx tail index on link down (bsc#1012628).
- ntb: Fix calculation ntb_transport_tx_free_entry()
  (bsc#1012628).
- Revert "PCI: Mark NVIDIA T4 GPUs to avoid bus reset"
  (bsc#1012628).
- block: fix pin count management when merging same-page segments
  (bsc#1012628).
- block: don't add or resize partition on the disk with
  GENHD_FL_NO_PART (bsc#1012628).
- procfs: block chmod on /proc/thread-self/comm (bsc#1012628).
- parisc: Fix /proc/cpuinfo output for lscpu (bsc#1012628).
- misc: fastrpc: Pass proper scm arguments for static process init
  (bsc#1012628).
- drm/amd/display: Add smu write msg id fail retry process
  (bsc#1012628).
- bpf: Fix issue in verifying allow_ptr_leaks (bsc#1012628).
- dlm: fix plock lookup when using multiple lockspaces
  (bsc#1012628).
- dccp: Fix out of bounds access in DCCP error handler
  (bsc#1012628).
- x86/sev: Make enc_dec_hypercall() accept a size instead of
  npages (bsc#1012628).
- r8169: fix ASPM-related issues on a number of systems with
  NIC version from RTL8168h (bsc#1012628).
- X.509: if signature is unsupported skip validation
  (bsc#1012628).
- net: handle ARPHRD_PPP in dev_is_mac_header_xmit()
  (bsc#1012628).
- fsverity: skip PKCS#7 parser when keyring is empty
  (bsc#1012628).
- x86/MCE: Always save CS register on AMD Zen IF Poison errors
  (bsc#1012628).
- crypto: af_alg - Decrement struct key.usage in
  alg_set_by_key_serial() (bsc#1012628).
- platform/chrome: chromeos_acpi: print hex string for
  ACPI_TYPE_BUFFER (bsc#1012628).
- mmc: renesas_sdhi: register irqs before registering controller
  (bsc#1012628).
- pstore/ram: Check start of empty przs during init (bsc#1012628).
- arm64: sdei: abort running SDEI handlers during crash
  (bsc#1012628).
- regulator: dt-bindings: qcom,rpm: fix pattern for children
  (bsc#1012628).
- iov_iter: Fix iov_iter_extract_pages() with zero-sized entries
  (bsc#1012628).
- RISC-V: Add ptrace support for vectors (bsc#1012628).
- s390/dcssblk: fix kernel crash with list_add corruption
  (bsc#1012628).
- s390/ipl: add missing secure/has_secure file to ipl type
  'unknown' (bsc#1012628).
- s390/dasd: fix string length handling (bsc#1012628).
- HID: logitech-hidpp: rework one more time the retries attempts
  (bsc#1012628).
- crypto: stm32 - fix loop iterating through scatterlist for DMA
  (bsc#1012628).
- crypto: stm32 - fix MDMAT condition (bsc#1012628).
- cpufreq: brcmstb-avs-cpufreq: Fix -Warray-bounds bug
  (bsc#1012628).
- of: property: fw_devlink: Add a devlink for panel followers
  (bsc#1012628).
- USB: core: Fix oversight in SuperSpeed initialization
  (bsc#1012628).
- x86/smp: Don't send INIT to non-present and non-booted CPUs
  (bsc#1012628).
- x86/sgx: Break up long non-preemptible delays in
  sgx_vepc_release() (bsc#1012628).
- x86/build: Fix linker fill bytes quirk/incompatibility for
  ld.lld (bsc#1012628).
- perf/x86/uncore: Correct the number of CHAs on EMR
  (bsc#1012628).
- media: ipu3-cio2: allow ipu_bridge to be a module again
  (bsc#1012628).
- Bluetooth: msft: Extended monitor tracking by address filter
  (bsc#1012628).
- serial: sc16is7xx: remove obsolete out_thread label
  (bsc#1012628).
- serial: sc16is7xx: fix regression with GPIO configuration
  (bsc#1012628).
- mm/memfd: sysctl: fix MEMFD_NOEXEC_SCOPE_NOEXEC_ENFORCED
  (bsc#1012628).
- selftests/memfd: sysctl: fix MEMFD_NOEXEC_SCOPE_NOEXEC_ENFORCED
  (bsc#1012628).
- memfd: do not -EACCES old memfd_create() users with
  vm.memfd_noexec=2 (bsc#1012628).
- memfd: replace ratcheting feature from vm.memfd_noexec with
  hierarchy (bsc#1012628).
- memfd: improve userspace warnings for missing exec-related flags
  (bsc#1012628).
- revert "memfd: improve userspace warnings for missing
  exec-related flags" (bsc#1012628).
- drm/amd/display: Block optimize on consecutive FAMS enables
  (bsc#1012628).
- Update config files.
- Rename to
  patches.kernel.org/6.5.3-099-wifi-rtw89-Fix-loading-of-compressed-firmware.patch.
- Rename to
  patches.kernel.org/6.5.3-346-drm-msm-a690-Switch-to-a660_gmu.bin.patch.
- Rename to
  patches.kernel.org/6.5.3-720-Bluetooth-HCI-Introduce-HCI_QUIRK_BROKEN_LE_COD.patch.
- commit 127fbf8
* Wed Sep 13 2023 jslaby@suse.cz
- config.conf: Drop ppc64 (BE)
- Delete config/ppc64/debug.
- Delete config/ppc64/default.
- Delete config/ppc64/kvmsmall.
- Delete config/ppc64/vanilla.
  The ppc64 builds are being stopped in OBS. Stop producing the big endian
  kernel too.
  See also:
  https://build.opensuse.org/request/show/1110638
  https://lists.opensuse.org/archives/list/factory@lists.opensuse.org/message/G6IJ4GAEHXL23FYDPZ4J6ML4Z2WY7ARF/
  https://lists.opensuse.org/archives/list/factory@lists.opensuse.org/message/SELOVYRDN5ZDDQ2EN7CXNS7BH33XACLU/
- commit d271544
* Wed Sep 13 2023 jslaby@suse.cz
- net/ipv6: SKB symmetric hash should incorporate transport ports
  (20230913065407.GA510095@bm02).
- commit dc48d90
* Wed Sep 13 2023 clin@suse.com
- Update config files: add QSEECOM support for Lenovo X13s (bsc#1215268)
- commit 574861d
* Wed Sep 13 2023 clin@suse.com
- firmware: Add support for Qualcomm UEFI Secure Application
  (bsc#1215268).
- firmware: qcom_scm: Add support for Qualcomm Secure Execution
  Environment SCM interface (bsc#1215268).
- lib/ucs2_string: Add UCS-2 strscpy function (bsc#1215268).
- clk: qcom: sc8280xp: Add fallback compatibles to lpasscc
  (bsc#1215268).
- firmware: Add support for Qualcomm UEFI Secure Application
  (bsc#1215268).
- firmware: qcom_scm: Add support for Qualcomm Secure Execution
  Environment SCM interface (bsc#1215268).
- lib/ucs2_string: Add UCS-2 strscpy function (bsc#1215268).
- commit 2eb2d4b
* Wed Sep 13 2023 clin@suse.com
- Update config files: Add audio support for Lenovo X13s (bsc#1215268)
- commit 11e1625
* Tue Sep 12 2023 tiwai@suse.de
- Update config files: enable audio on Lenovo X13s (bsc#1215256)
  Enable CONFIG_SND_SOC_LPASS_*_MACRO for arm64.
- commit 7859b9e
* Tue Sep 12 2023 petr.pavlu@suse.com
- rpm/kernel-binary.spec.in: Drop use of KBUILD_OVERRIDE=1
  Genksyms has functionality to specify an override for each type in
  a symtypes reference file. This override is then used instead of an
  actual type and allows to preserve modversions (CRCs) of symbols that
  reference the type. It is kind of an alternative to doing kABI fix-ups
  with '#ifndef __GENKSYMS__'. The functionality is hidden behind the
  genksyms --preserve option which primarily tells the tool to strictly
  verify modversions against a given reference file or fail.
  Downstream patch patches.suse/genksyms-add-override-flag.diff which is
  present in various kernel-source branches separates the override logic.
  It allows it to be enabled with a new --override flag and used without
  specifying the --preserve option. Setting KBUILD_OVERRIDE=1 in the spec
  file is then a way how the build is told that --override should be
  passed to all invocations of genksyms. This was needed for SUSE kernels
  because their build doesn't use --preserve but instead resulting CRCs
  are later checked by scripts/kabi.pl.
  However, this override functionality was not utilized much in practice
  and the only use currently to be found is in SLE11-SP1-LTSS. It means
  that no one should miss this option and KBUILD_OVERRIDE=1 together with
  patches.suse/genksyms-add-override-flag.diff can be removed.
  Notes for maintainers merging this commit to their branches:
  * Downstream patch patches.suse/genksyms-add-override-flag.diff can be
  dropped after merging this commit.
  * Branch SLE11-SP1-LTSS uses the mentioned override functionality and
  this commit should not be merged to it, or needs to be reverted
  afterwards.
- commit 4aa02b8
* Mon Sep 11 2023 clin@suse.com
- drm/msm/a690: Switch to a660_gmu.bin (bsc#1213614).
- commit 221ff83
* Mon Sep 11 2023 mkubecek@suse.cz
- Update to 6.6-rc1
- drop 47 patches (44 stable, 3 mainline)
  - patches.kernel.org/*
  - patches.rpmify/Revert-kbuild-Hack-for-depmod-not-handling-X.Y-versi.patch
  - patches.rpmify/kbuild-dummy-tools-support-make-MPROFILE_KERNEL-chec.patch
  - patches.suse/wifi-rtw89-Fix-loading-of-compressed-firmware.patch
- refresh
  - patches.suse/0001-bsc-1204315-Disable-sysfb-before-creating-simple-fra.patch
  - patches.suse/0002-efi-Add-an-EFI_SECURE_BOOT-flag-to-indicate-secure-boot-mode.patch
  - patches.suse/add-product-identifying-information-to-vmcoreinfo.patch
  - patches.suse/add-suse-supported-flag.patch
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/wifi-ath11k-add-support-for-suspend-in-power-down-st.patch
- add build failure fix
  - patches.rpmify/kbuild-avoid-long-argument-lists-in-make-modules_ins.patch
- disable ARM architectures (need config update)
- new config options
  - General setup
  - CRASH_HOTPLUG=y
  - CRASH_MAX_MEMORY_RANGES=8192
  - Processor type and features
  - X86_USER_SHADOW_STACK=n
  - Virtualization
  - KVM_PROVE_MMU=n
  - Memory Management options
  - RANDOM_KMALLOC_CACHES=n
  - File systems
  - OVERLAY_FS_DEBUG=n
  - TMPFS_QUOTA=y
  - EROFS_FS_ZIP_DEFLATE=y
  - Security options
  - SECURITY_SELINUX_DEBUG=n
  - LIST_HARDENED=n
  - Library routines
  - SWIOTLB_DYNAMIC=n
  - DMA_NUMA_CMA=y
  - Multiple devices driver support (RAID and LVM)
  - MD_BITMAP_FILE=y
  - Network device support
  - NETCONSOLE_EXTENDED_LOG=n
  - MLX5_MACSEC=y
  - MARVELL_88Q2XXX_PHY=m
  - Hardware Monitoring support
  - SENSORS_HS3001=m
  - SENSORS_MP2975_REGULATOR=y
  - Multifunction device drivers
  - MFD_CS42L43_I2C=m
  - MFD_CS42L43_SDW=m
  - Voltage and Current Regulator Support
  - REGULATOR_AW37503=m
  - REGULATOR_MAX77857=m
  - REGULATOR_RTQ2208=m
  - Multimedia support
  - INTEL_VSC=m
  - VIDEO_CAMERA_SENSOR=y
  - VIDEO_DW9719=m
  - Graphics support
  - DRM_LOONGSON=m
  - FB_DEVICE=y
  - Sound card support
  - SND_HDA_SCODEC_CS35L56_I2C=m
  - SND_HDA_SCODEC_CS35L56_SPI=m
  - SND_HDA_SCODEC_TAS2781_I2C=m
  - SND_SOC_INTEL_AVS_MACH_ES8336=m
  - SND_SOC_INTEL_AVS_MACH_RT5663=m
  - SND_SOC_SOF_AMD_VANGOGH=m
  - SND_SOC_SOF_LUNARLAKE=m
  - SND_SOC_AUDIO_IIO_AUX=n
  - SND_SOC_AW88261=n
  - SND_SOC_CS42L43=m
  - SND_SOC_CS42L43_SDW=m
  - SND_SOC_RT1017_SDCA_SDW=m
  - LED Support
  - LEDS_PCA995X=m
  - LEDS_SIEMENS_SIMATIC_IPC_ELKHARTLAKE=m
  - X86 Platform Specific Device Drivers
  - HP_BIOSCFG=m
  - SIEMENS_SIMATIC_IPC_BATT=m
  - SIEMENS_SIMATIC_IPC_BATT_APOLLOLAKE=m
  - SIEMENS_SIMATIC_IPC_BATT_ELKHARTLAKE=m
  - SIEMENS_SIMATIC_IPC_BATT_F7188X=m
  - SEL3350_PLATFORM=m
  - Industrial I/O support
  - MCP4728=n
  - IRSD200=n
  - PHY Subsystem
  - PHY_RTK_RTD_USB2PHY=m
  - PHY_RTK_RTD_USB3PHY=m
  - Counter support
  - 104_QUAD_8=m
  - INTEL_QEP=m
  - INTERRUPT_CNT=m
  - Misc drivers
  - TOUCHSCREEN_IQS7211=m
  - I2C_ATR=m
  - SPI_CS42L43=n
  - PTP_1588_CLOCK_MOCK=m
  - PINCTRL_CS42L43=m
  - GPIO_DS4520=m
  - HID_GOOGLE_STADIA_FF=m
  - USB_CONFIGFS_F_MIDI2=y
  - XILINX_DMA=m
  - PDS_VFIO_PCI=m
  - XEN_PRIVCMD_IRQFD=y
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - PCI_DYNAMIC_OF_NODES=y
  - REGULATOR_MAX5970=m
  - VIDEO_DS90UB913=m
  - VIDEO_DS90UB953=m
  - VIDEO_DS90UB960=m
  - DRM_PANEL_STARTEK_KD070FHFID015=n
  - DRM_PANEL_VISIONOX_R66451=n
  - LEDS_GROUP_MULTICOLOR=m
  - COMMON_CLK_VC3=m
  - ppc64 / ppc64le
  - FSI_MASTER_I2CR=n
  - INTEGRITY_MACHINE_KEYRING=y
  - ppc64le
  - CRYPTO_CHACHA20_P10=m
  - CRYPTO_POLY1305_P10=m
  - s390x
  - CERT_STORE=y
  - S390_HYPFS=y
  - FUNCTION_GRAPH_RETVAL=y
  - riscv64
  - PREEMPT_DYNAMIC=y
  - RANDOMIZE_BASE=y
  - RISCV_ISA_FALLBACK=y
  - CFI_CLANG=n
  - CAN_SUN4I=m
  - CEC_GPIO=m
  - CLK_STARFIVE_JH7110_STG=m
  - SUN20I_GPADC=n
  - PHY_STARFIVE_JH7110_DPHY_RX=m
  - PHY_STARFIVE_JH7110_PCIE=m
  - PHY_STARFIVE_JH7110_USB=m
  - DEBUG_FORCE_FUNCTION_ALIGN_64B=n
  - DEBUG_PREEMPT=n
  - PREEMPT_TRACER=n
  - CEC_PIN_ERROR_INJ=n
- commit 8c17599
* Fri Sep  8 2023 jslaby@suse.cz
- Linux 6.5.2 (bsc#1012628).
- drm/amdgpu: correct vmhub index in GMC v10/11 (bsc#1012628).
- erofs: ensure that the post-EOF tails are all zeroed
  (bsc#1012628).
- ksmbd: fix wrong DataOffset validation of create context
  (bsc#1012628).
- ksmbd: fix slub overflow in ksmbd_decode_ntlmssp_auth_blob()
  (bsc#1012628).
- ksmbd: replace one-element array with flex-array member in
  struct smb2_ea_info (bsc#1012628).
- ksmbd: reduce descriptor size if remaining bytes is less than
  request size (bsc#1012628).
- ARM: pxa: remove use of symbol_get() (bsc#1012628).
- mmc: au1xmmc: force non-modular build and remove symbol_get
  usage (bsc#1012628).
- net: enetc: use EXPORT_SYMBOL_GPL for enetc_phc_index
  (bsc#1012628).
- rtc: ds1685: use EXPORT_SYMBOL_GPL for ds1685_rtc_poweroff
  (bsc#1012628).
- modules: only allow symbol_get of EXPORT_SYMBOL_GPL modules
  (bsc#1012628).
- USB: serial: option: add Quectel EM05G variant (0x030e)
  (bsc#1012628).
- USB: serial: option: add FOXCONN T99W368/T99W373 product
  (bsc#1012628).
- ALSA: usb-audio: Fix init call orders for UAC1 (bsc#1012628).
- usb: dwc3: meson-g12a: do post init to fix broken usb after
  resumption (bsc#1012628).
- usb: chipidea: imx: improve logic if samsung,picophy-* parameter
  is 0 (bsc#1012628).
- HID: wacom: remove the battery when the EKR is off
  (bsc#1012628).
- staging: rtl8712: fix race condition (bsc#1012628).
- wifi: mt76: mt7921: do not support one stream on secondary
  antenna only (bsc#1012628).
- wifi: mt76: mt7921: fix skb leak by txs missing in AMSDU
  (bsc#1012628).
- wifi: ath11k: Don't drop tx_status when peer cannot be found
  (bsc#1012628).
- wifi: ath11k: Cleanup mac80211 references on failure during
  tx_complete (bsc#1012628).
- serial: qcom-geni: fix opp vote on shutdown (bsc#1012628).
- serial: sc16is7xx: fix broken port 0 uart init (bsc#1012628).
- serial: sc16is7xx: fix bug when first setting GPIO direction
  (bsc#1012628).
- firmware: stratix10-svc: Fix an NULL vs IS_ERR() bug in probe
  (bsc#1012628).
- fsi: master-ast-cf: Add MODULE_FIRMWARE macro (bsc#1012628).
- tcpm: Avoid soft reset when partner does not support get_status
  (bsc#1012628).
- dt-bindings: sc16is7xx: Add property to change GPIO function
  (bsc#1012628).
- tracing: Zero the pipe cpumask on alloc to avoid spurious -EBUSY
  (bsc#1012628).
- nilfs2: fix WARNING in mark_buffer_dirty due to discarded
  buffer reuse (bsc#1012628).
- usb: typec: tcpci: clear the fault status bit (bsc#1012628).
- Rename to
  patches.kernel.org/6.5.2-021-wifi-rtw88-usb-kill-and-free-rx-urbs-on-probe-f.patch.
- Rename to
  patches.kernel.org/6.5.2-034-pinctrl-amd-Don-t-show-Invalid-config-param-err.patch.
- commit e785fd6
* Wed Sep  6 2023 tiwai@suse.de
- Bluetooth: HCI: Introduce HCI_QUIRK_BROKEN_LE_CODED
  (bsc#1213972).
- commit 74930eb
* Wed Sep  6 2023 mkubecek@suse.cz
- update patch metadata
- update upstream references
  - patches.rpmify/Revert-kbuild-Hack-for-depmod-not-handling-X.Y-versi.patch
  - patches.rpmify/kbuild-dummy-tools-support-make-MPROFILE_KERNEL-chec.patch
- commit aaab89b
* Wed Sep  6 2023 mkubecek@suse.cz
- config: refresh
- commit bd40664
* Tue Sep  5 2023 msuchanek@suse.de
- Update config files.
  IPR is powerpc-only driver, disable on other architectures.
- commit 62fd4da
* Mon Sep  4 2023 jslaby@suse.cz
- Linux 6.5.1 (bsc#1012628).
- ACPI: thermal: Drop nocrt parameter (bsc#1012628).
- module: Expose module_init_layout_section() (bsc#1012628).
- arm64: module: Use module_init_layout_section() to spot init
  sections (bsc#1012628).
- ARM: module: Use module_init_layout_section() to spot init
  sections (bsc#1012628).
- module/decompress: use vmalloc() for zstd decompression
  workspace (bsc#1012628).
- lockdep: fix static memory detection even more (bsc#1012628).
- kallsyms: Fix kallsyms_selftest failure (bsc#1012628).
- commit d232ff6
* Thu Aug 31 2023 tiwai@suse.de
- firmware: qemu_fw_cfg: Do not hard depend on
  CONFIG_HAS_IOPORT_MAP (bsc#1214773).
- Update config files: enable CONFIG_FW_CFG_SYSFS for armv7hl
- commit b5edcad
* Thu Aug 31 2023 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and move into sorted section
  - patches.suse/pinctrl-amd-Don-t-show-Invalid-config-param-errors.patch
- update upstream references and resort
  - patches.suse/wifi-rtw89-Fix-loading-of-compressed-firmware.patch
  - patches.suse/wifi-rtw88-usb-kill-and-free-rx-urbs-on-probe-failure.patch
- commit de97d09
* Wed Aug 30 2023 jslaby@suse.cz
- rpm/mkspec-dtb: dtbs have moved to vendor sub-directories in 6.5
  By commit 724ba6751532 ("ARM: dts: Move .dts files to vendor
  sub-directories").
  So switch to them.
- rpm/mkspec-dtb: support for nested subdirs
  Commit 724ba6751532 ("ARM: dts: Move .dts files to vendor
  sub-directories") moved the dts to nested subdirs, add a support for
  that. That is, generate a %%dir entry in %%files for them.
- commit 7aee36a
* Wed Aug 30 2023 jslaby@suse.cz
- ipv6: remove hard coded limitation on ipv6_pinfo (ipv6-breakage
  20230829174957.0ae84f41@kernel.org).
- commit 7f2ff2a
* Tue Aug 29 2023 jslaby@suse.cz
- kbuild: dummy-tools: support make MPROFILE_KERNEL checks work
  on BE (ppc64-build-fix).
- Update config files.
  Fix ppc64 build and update configs accordingly (values taken from
  ppc64le).
- commit 6df272d
* Tue Aug 29 2023 mkubecek@suse.cz
- series.conf: cleanup
- move an unsortable patch out of sorted section
  - patches.suse/Revert-101bd907b424-misc-rtsx-judge-ASPM-Mode-to-set.patch
- update upstream references and move into sorted section
  - patches.suse/wifi-rtw89-Fix-loading-of-compressed-firmware.patch
  - patches.suse/wifi-rtw88-usb-kill-and-free-rx-urbs-on-probe-failure.patch
- commit 940b0a2
* Tue Aug 29 2023 mkubecek@suse.cz
- config: refresh
- commit 1042651
* Mon Aug 28 2023 jack@suse.cz
- patches.suse/add-suse-supported-flag.patch: Add CONFIG_MODULES dependency
- commit d5be025
* Mon Aug 28 2023 mkubecek@suse.cz
- Update to 6.5 final
- refresh configs (headers only)
- commit 2844291
* Fri Aug 25 2023 msuchanek@suse.de
- Revert 101bd907b424 ("misc: rtsx: judge ASPM Mode to set
  PETXCFG Reg") (boo#1214428 boo#1214397).
- commit 1b02b15
* Fri Aug 25 2023 jslaby@suse.cz
- Linux 6.4.12 (bsc#1012628).
- crypto, cifs: fix error handling in extract_iter_to_sg()
  (bsc#1012628).
- net: phy: at803x: Use devm_regulator_get_enable_optional()
  (bsc#1012628).
- net: phy: at803x: fix the wol setting functions (bsc#1012628).
- drm/amd/display: Update DTBCLK for DCN32 (bsc#1012628).
- drm/scheduler: set entity to NULL in drm_sched_entity_pop_job()
  (bsc#1012628).
- drm/amdgpu: fix calltrace warning in amddrm_buddy_fini
  (bsc#1012628).
- drm/amdgpu: Fix integer overflow in amdgpu_cs_pass1
  (bsc#1012628).
- drm/amdgpu: fix memory leak in mes self test (bsc#1012628).
- Revert "drm/amd/display: disable SubVP + DRR to prevent
  underflow" (bsc#1012628).
- ASoC: Intel: sof_sdw: add quirk for MTL RVP (bsc#1012628).
- ASoC: Intel: sof_sdw: add quirk for LNL RVP (bsc#1012628).
- PCI: tegra194: Fix possible array out of bounds access
  (bsc#1012628).
- ASoC: cs35l56: Move DSP part string generation so that it is
  done only once (bsc#1012628).
- ASoC: SOF: amd: Add pci revision id check (bsc#1012628).
- drm/stm: ltdc: fix late dereference check (bsc#1012628).
- arm64: dts: qcom: ipq5332: add QFPROM node (bsc#1012628).
- drm: rcar-du: remove R-Car H3 ES1.* workarounds (bsc#1012628).
- ASoC: amd: vangogh: Add check for acp config flags in vangogh
  platform (bsc#1012628).
- RDMA/mana_ib: Use v2 version of cfg_rx_steer_req to enable RX
  coalescing (bsc#1012628).
- ARM: dts: imx6dl: prtrvt, prtvt7, prti6q, prtwd2: fix USB
  related warnings (bsc#1012628).
- ASoC: Intel: sof_sdw_rt_sdca_jack_common: test SOF_JACK_JDSRC
  in _exit (bsc#1012628).
- ASoC: Intel: sof_sdw: add quick for Dell SKU 0BDA (bsc#1012628).
- ASoC: Intel: sof_sdw: Add support for Rex soundwire
  (bsc#1012628).
- iopoll: Call cpu_relax() in busy loops (bsc#1012628).
- ASoC: SOF: Intel: fix SoundWire/HDaudio mutual exclusion
  (bsc#1012628).
- dma-remap: use kvmalloc_array/kvfree for larger dma memory remap
  (bsc#1012628).
- accel/habanalabs: add pci health check during heartbeat
  (bsc#1012628).
- accel/habanalabs: fix mem leak in capture user mappings
  (bsc#1012628).
- dt-bindings: input: goodix: Add "goodix,no-reset-during-suspend"
  property (bsc#1012628).
- HID: i2c-hid: goodix: Add support for
  "goodix,no-reset-during-suspend" property (bsc#1012628).
- HID: logitech-hidpp: Add USB and Bluetooth IDs for the Logitech
  G915 TKL Keyboard (bsc#1012628).
- iommu/amd: Introduce Disable IRTE Caching Support (bsc#1012628).
- drm/amdgpu: install stub fence into potential unused fence
  pointers (bsc#1012628).
- drm/amd/display: Remove v_startup workaround for dcn3+
  (bsc#1012628).
- drm/amd/display: Apply 60us prefetch for DCFCLK <= 300Mhz
  (bsc#1012628).
- drm/amdgpu: unmap and remove csa_va properly (bsc#1012628).
- RDMA/mlx5: Return the firmware result upon destroying QP/RQ
  (bsc#1012628).
- RDMA/bnxt_re: consider timeout of destroy ah as success
  (bsc#1012628).
- drm/amd/display: Skip DPP DTO update if root clock is gated
  (bsc#1012628).
- drm/amd/display: Enable dcn314 DPP RCO (bsc#1012628).
- ASoC: SOF: core: Free the firmware trace before calling
  snd_sof_shutdown() (bsc#1012628).
- HID: intel-ish-hid: ipc: Add Arrow Lake PCI device ID
  (bsc#1012628).
- Revert "[PATCH] uml: export symbols added by GCC hardened"
  (bsc#1012628).
- smb: client: fix warning in cifs_smb3_do_mount() (bsc#1012628).
- cifs: fix session state check in reconnect to avoid
  use-after-free issue (bsc#1012628).
- serial: stm32: Ignore return value of uart_remove_one_port()
  in .remove() (bsc#1012628).
- led: qcom-lpg: Fix resource leaks in
  for_each_available_child_of_node() loops (bsc#1012628).
- media: v4l2-mem2mem: add lock to protect parameter num_rdy
  (bsc#1012628).
- media: camss: set VFE bpl_alignment to 16 for sdm845 and sm8250
  (bsc#1012628).
- usb: gadget: u_serial: Avoid spinlock recursion in
  __gs_console_push (bsc#1012628).
- usb: gadget: uvc: queue empty isoc requests if no video buffer
  is available (bsc#1012628).
- media: platform: mediatek: vpu: fix NULL ptr dereference
  (bsc#1012628).
- thunderbolt: Read retimer NVM authentication status prior
  tb_retimer_set_inbound_sbtx() (bsc#1012628).
- xhci: get rid of XHCI_PLAT quirk that used to prevent MSI setup
  (bsc#1012628).
- usb: chipidea: imx: don't request QoS for imx8ulp (bsc#1012628).
- usb: chipidea: imx: turn off vbus comparator when suspend
  (bsc#1012628).
- usb: chipidea: imx: add missing USB PHY DPDM wakeup setting
  (bsc#1012628).
- gfs2: Fix possible data races in gfs2_show_options()
  (bsc#1012628).
- pcmcia: rsrc_nonstatic: Fix memory leak in
  nonstatic_release_resource_db() (bsc#1012628).
- thunderbolt: Add Intel Barlow Ridge PCI ID (bsc#1012628).
- thunderbolt: Limit Intel Barlow Ridge USB3 bandwidth
  (bsc#1012628).
- firewire: net: fix use after free in
  fwnet_finish_incoming_packet() (bsc#1012628).
- watchdog: sp5100_tco: support Hygon FCH/SCH (Server Controller
  Hub) (bsc#1012628).
- Bluetooth: L2CAP: Fix use-after-free (bsc#1012628).
- Bluetooth: btusb: Add MT7922 bluetooth ID for the Asus Ally
  (bsc#1012628).
- ceph: try to dump the msgs when decoding fails (bsc#1012628).
- drm/amdgpu: Fix potential fence use-after-free v2 (bsc#1012628).
- fs/ntfs3: Enhance sanity check while generating attr_list
  (bsc#1012628).
- fs/ntfs3: Return error for inconsistent extended attributes
  (bsc#1012628).
- fs: ntfs3: Fix possible null-pointer dereferences in mi_read()
  (bsc#1012628).
- fs/ntfs3: Mark ntfs dirty when on-disk struct is corrupted
  (bsc#1012628).
- fs/ntfs3: Alternative boot if primary boot is corrupted
  (bsc#1012628).
- ALSA: hda/realtek: Add quirks for Unis H3C Desktop B760 & Q760
  (bsc#1012628).
- ALSA: hda: fix a possible null-pointer dereference due to data
  race in snd_hdac_regmap_sync() (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ASUS ROG GX650P (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ASUS ROG GA402X (bsc#1012628).
- ALSA: hda/realtek: Amend G634 quirk to enable rear speakers
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ASUS ROG G614Jx (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ASUS ROG GZ301V (bsc#1012628).
- powerpc/kasan: Disable KCOV in KASAN code (bsc#1012628).
- Bluetooth: MGMT: Use correct address for memcpy() (bsc#1012628).
- ring-buffer: Do not swap cpu_buffer during resize process
  (bsc#1012628).
- btrfs: move out now unused BG from the reclaim list
  (bsc#1012628).
- btrfs: fix use-after-free of new block group that became unused
  (bsc#1012628).
- regulator: qcom-rpmh: Fix LDO 12 regulator for PM8550
  (bsc#1012628).
- virtio-mmio: don't break lifecycle of vm_dev (bsc#1012628).
- vduse: Use proper spinlock for IRQ injection (bsc#1012628).
- virtio-vdpa: Fix cpumask memory leak in virtio_vdpa_find_vqs()
  (bsc#1012628).
- vdpa/mlx5: Fix mr->initialized semantics (bsc#1012628).
- vdpa/mlx5: Delete control vq iotlb in destroy_mr only when
  necessary (bsc#1012628).
- cifs: fix potential oops in cifs_oplock_break (bsc#1012628).
- rust: macros: vtable: fix `HAS_*` redefinition
  (`gen_const_name`) (bsc#1012628).
- i2c: bcm-iproc: Fix bcm_iproc_i2c_isr deadlock issue
  (bsc#1012628).
- i2c: hisi: Only handle the interrupt of the driver's transfer
  (bsc#1012628).
- i2c: tegra: Fix i2c-tegra DMA config option processing
  (bsc#1012628).
- blk-cgroup: hold queue_lock when removing blkg->q_node
  (bsc#1012628).
- fbdev: mmp: fix value check in mmphw_probe() (bsc#1012628).
- media: mtk-jpeg: Set platform driver data earlier (bsc#1012628).
- powerpc/rtas_flash: allow user copy to flash block cache objects
  (bsc#1012628).
- vdpa: Add features attr to vdpa_nl_policy for nlattr length
  check (bsc#1012628).
- vdpa: Add queue index attr to vdpa_nl_policy for nlattr length
  check (bsc#1012628).
- vdpa: Add max vqp attr to vdpa_nl_policy for nlattr length check
  (bsc#1012628).
- vdpa: Enable strict validation for netlinks ops (bsc#1012628).
- smb3: display network namespace in debug information
  (bsc#1012628).
- tty: n_gsm: fix the UAF caused by race condition in
  gsm_cleanup_mux (bsc#1012628).
- tty: serial: fsl_lpuart: Clear the error flags by writing 1
  for lpuart32 platforms (bsc#1012628).
- btrfs: fix infinite directory reads (bsc#1012628).
- btrfs: fix incorrect splitting in btrfs_drop_extent_map_range
  (bsc#1012628).
- btrfs: fix BUG_ON condition in btrfs_cancel_balance
  (bsc#1012628).
- btrfs: fix replace/scrub failure with metadata_uuid
  (bsc#1012628).
- btrfs: only subtract from len_to_oe_boundary when it is tracking
  an extent (bsc#1012628).
- i2c: designware: Correct length byte validation logic
  (bsc#1012628).
- i2c: designware: Handle invalid SMBus block data response
  length value (bsc#1012628).
- x86/cpu: Fix __x86_return_thunk symbol type (bsc#1012628).
- x86/cpu: Fix up srso_safe_ret() and __x86_return_thunk()
  (bsc#1012628).
- objtool/x86: Fix SRSO mess (bsc#1012628).
- x86/alternative: Make custom return thunk unconditional
  (bsc#1012628).
- x86/cpu: Clean up SRSO return thunk mess (bsc#1012628).
- x86/cpu: Rename original retbleed methods (bsc#1012628).
- x86/cpu: Rename srso_(.*)_alias to srso_alias_\1 (bsc#1012628).
- x86/cpu: Cleanup the untrain mess (bsc#1012628).
- x86/cpu/kvm: Provide UNTRAIN_RET_VM (bsc#1012628).
- x86/srso: Explain the untraining sequences a bit more
  (bsc#1012628).
- objtool/x86: Fixup frame-pointer vs rethunk (bsc#1012628).
- x86/static_call: Fix __static_call_fixup() (bsc#1012628).
- x86/retpoline: Don't clobber RFLAGS during srso_safe_ret()
  (bsc#1012628).
- x86/CPU/AMD: Fix the DIV(0) initial fix attempt (bsc#1012628).
- x86/srso: Disable the mitigation on unaffected configurations
  (bsc#1012628).
- x86/retpoline,kprobes: Fix position of thunk sections with
  CONFIG_LTO_CLANG (bsc#1012628).
- x86/retpoline,kprobes: Skip optprobe check for indirect jumps
  with retpolines and IBT (bsc#1012628).
- x86/srso: Correct the mitigation status when SMT is disabled
  (bsc#1012628).
- net: xfrm: Fix xfrm_address_filter OOB read (bsc#1012628).
- net: af_key: fix sadb_x_filter validation (bsc#1012628).
- net: xfrm: Amend XFRMA_SEC_CTX nla_policy structure
  (bsc#1012628).
- xfrm: Silence warnings triggerable by bad packets (bsc#1012628).
- xfrm: fix slab-use-after-free in decode_session6 (bsc#1012628).
- ip6_vti: fix slab-use-after-free in decode_session6
  (bsc#1012628).
- ip_vti: fix potential slab-use-after-free in decode_session6
  (bsc#1012628).
- xfrm: add NULL check in xfrm_update_ae_params (bsc#1012628).
- xfrm: add forgotten nla_policy for XFRMA_MTIMER_THRESH
  (bsc#1012628).
- xfrm: delete offloaded policy (bsc#1012628).
- xfrm: don't skip free of empty state in acquire policy
  (bsc#1012628).
- virtio-net: set queues after driver_ok (bsc#1012628).
- net: pcs: Add missing put_device call in miic_create
  (bsc#1012628).
- net: phy: fix IRQ-based wake-on-lan over hibernate / power off
  (bsc#1012628).
- selftests: mirror_gre_changes: Tighten up the TTL test match
  (bsc#1012628).
- drm/panel: simple: Fix AUO G121EAN01 panel timings according
  to the docs (bsc#1012628).
- drm/i915/guc/slpc: Restore efficient freq earlier (bsc#1012628).
- net: macb: In ZynqMP resume always configure PS GTR for
  non-wakeup source (bsc#1012628).
- octeon_ep: fix timeout value for waiting on mbox response
  (bsc#1012628).
- octeon_ep: cancel tx_timeout_task later in remove sequence
  (bsc#1012628).
- octeon_ep: cancel ctrl_mbox_task after intr_poll_task
  (bsc#1012628).
- octeon_ep: cancel queued works in probe error path
  (bsc#1012628).
- net: veth: Page pool creation error handling for existing
  pools only (bsc#1012628).
- accel/qaic: Fix slicing memory leak (bsc#1012628).
- accel/qaic: Clean up integer overflow checking in
  map_user_pages() (bsc#1012628).
- netfilter: nf_tables: fix false-positive lockdep splat
  (bsc#1012628).
- netfilter: nf_tables: deactivate catchall elements in next
  generation (bsc#1012628).
- netfilter: nf_tables: don't fail inserts if duplicate has
  expired (bsc#1012628).
- netfilter: set default timeout to 3 secs for sctp shutdown
  send and recv state (bsc#1012628).
- ipvs: fix racy memcpy in proc_do_sync_threshold (bsc#1012628).
- netfilter: nf_tables: fix GC transaction races with netns and
  netlink event exit path (bsc#1012628).
- netfilter: nf_tables: GC transaction race with netns dismantle
  (bsc#1012628).
- netfilter: nft_dynset: disallow object maps (bsc#1012628).
- net: phy: broadcom: stub c45 read/write for 54810 (bsc#1012628).
- team: Fix incorrect deletion of ETH_P_8021AD protocol vid from
  slaves (bsc#1012628).
- net: openvswitch: reject negative ifindex (bsc#1012628).
- iavf: fix FDIR rule fields masks validation (bsc#1012628).
- i40e: fix misleading debug logs (bsc#1012628).
- net/mlx5e: XDP, Fix fifo overrun on XDP_REDIRECT (bsc#1012628).
- net: dsa: mv88e6xxx: Wait for EEPROM done before HW reset
  (bsc#1012628).
- sfc: add fallback action-set-lists for TC offload (bsc#1012628).
- sfc: don't unregister flow_indr if it was never registered
  (bsc#1012628).
- sfc: don't fail probe if MAE/TC setup fails (bsc#1012628).
- sock: Fix misuse of sk_under_memory_pressure() (bsc#1012628).
- net: do not allow gso_size to be set to GSO_BY_FRAGS
  (bsc#1012628).
- qede: fix firmware halt over suspend and resume (bsc#1012628).
- ice: Block switchdev mode when ADQ is active and vice versa
  (bsc#1012628).
- bus: ti-sysc: Flush posted write on enable before reset
  (bsc#1012628).
- arm64: dts: qcom: qrb5165-rb5: fix thermal zone conflict
  (bsc#1012628).
- arm64: dts: rockchip: Disable HS400 for eMMC on ROCK Pi 4
  (bsc#1012628).
- arm64: dts: rockchip: Disable HS400 for eMMC on ROCK 4C+
  (bsc#1012628).
- ARM: dts: imx6: phytec: fix RTC interrupt level (bsc#1012628).
- ARM: dts: imx: Adjust dma-apbh node name (bsc#1012628).
- ARM: dts: imx: Set default tuning step for imx7d usdhc
  (bsc#1012628).
- arm64: dts: imx8mm: Drop CSI1 PHY reference clock configuration
  (bsc#1012628).
- ARM: dts: imx: Set default tuning step for imx6sx usdhc
  (bsc#1012628).
- ASoC: max98363: don't return on success reading revision ID
  (bsc#1012628).
- arm64: dts: imx93: Fix anatop node size (bsc#1012628).
- ASoC: rt5665: add missed regulator_bulk_disable (bsc#1012628).
- ASoC: meson: axg-tdm-formatter: fix channel slot allocation
  (bsc#1012628).
- ALSA: hda/realtek: Add quirks for HP G11 Laptops (bsc#1012628).
- pinctrl: qcom: Add intr_target_width field to support increased
  number of interrupt targets (bsc#1012628).
- soc: aspeed: uart-routing: Use __sysfs_match_string
  (bsc#1012628).
- soc: aspeed: socinfo: Add kfree for kstrdup (bsc#1012628).
- ALSA: hda/realtek - Remodified 3k pull low procedure
  (bsc#1012628).
- riscv: entry: set a0 = -ENOSYS only when syscall != -1
  (bsc#1012628).
- riscv: correct riscv_insn_is_c_jr() and riscv_insn_is_c_jalr()
  (bsc#1012628).
- riscv: uaccess: Return the number of bytes effectively not
  copied (bsc#1012628).
- serial: 8250: Fix oops for port->pm on uart_change_pm()
  (bsc#1012628).
- ALSA: usb-audio: Add support for Mythware XA001AU capture and
  playback interfaces (bsc#1012628).
- cifs: Release folio lock on fscache read hit (bsc#1012628).
- parisc: Fix CONFIG_TLB_PTLOCK to work with lightweight spinlock
  checks (bsc#1012628).
- smb: client: fix null auth (bsc#1012628).
- regulator: da9063: better fix null deref with partial DT
  (bsc#1012628).
- virtio-net: Zero max_tx_vq field for
  VIRTIO_NET_CTRL_MQ_HASH_CONFIG case (bsc#1012628).
- arm64: dts: rockchip: Fix Wifi/Bluetooth on ROCK Pi 4 boards
  (bsc#1012628).
- arm64/ptrace: Ensure that SME is set up for target when writing
  SSVE state (bsc#1012628).
- arm64/ptrace: Ensure that the task sees ZT writes on first use
  (bsc#1012628).
- blk-crypto: dynamically allocate fallback profile (bsc#1012628).
- media: uvcvideo: Fix menu count handling for userspace XU
  mappings (bsc#1012628).
- dt-bindings: pinctrl: qcom,sa8775p-tlmm: add gpio function
  constant (bsc#1012628).
- mmc: f-sdh30: fix order of function calls in
  sdhci_f_sdh30_remove (bsc#1012628).
- mmc: wbsd: fix double mmc_free_host() in wbsd_init()
  (bsc#1012628).
- mmc: block: Fix in_flight[issue_type] value error (bsc#1012628).
- mmc: sunplus: fix return value check of mmc_add_host()
  (bsc#1012628).
- mmc: sunplus: Fix error handling in spmmc_drv_probe()
  (bsc#1012628).
- drm/qxl: fix UAF on handle creation (bsc#1012628).
- Revert "Revert "drm/amdgpu/display: change pipe policy for
  DCN 2.0"" (bsc#1012628).
- drm/i915/sdvo: fix panel_type initialization (bsc#1012628).
- drm/amd: flush any delayed gfxoff on suspend entry
  (bsc#1012628).
- drm/amdgpu: skip fence GFX interrupts disable/enable for S0ix
  (bsc#1012628).
- drm/amdgpu/pm: fix throttle_status for other than MP1 11.0.7
  (bsc#1012628).
- ASoC: amd: vangogh: select CONFIG_SND_AMD_ACP_CONFIG
  (bsc#1012628).
- drm/amd/display: disable RCO for DCN314 (bsc#1012628).
- drm/amd/pm: skip the RLC stop when S0i3 suspend for SMU
  v13.0.4/11 (bsc#1012628).
- drm/amdgpu: keep irq count in amdgpu_irq_disable_all
  (bsc#1012628).
- Revert "perf report: Append inlines to non-DWARF callchains"
  (bsc#1012628).
- af_unix: Fix null-ptr-deref in unix_stream_sendpage()
  (bsc#1012628).
- net: fix the RTO timer retransmitting skb every 1ms if linear
  option is enabled (bsc#1012628).
- commit 4789ce4
* Thu Aug 24 2023 msuchanek@suse.de
- Update ppc64 config
  - CONFIG_COMPAT_32BIT_TIME=n
  - CONFIG_IMA_ARCH_POLICY=y
  - CONFIG_IMA_DISABLE_HTABLE=y
  - CONFIG_IMA_KEXEC=y
  - CONFIG_IMA_KEYRINGS_PERMIT_SIGNED_BY_BUILTIN_OR_SECONDARY=y
  - CONFIG_LOAD_PPC_KEYS=y
  - CONFIG_PPC_SECURE_BOOT=y
  - CONFIG_PPC_SECVAR_SYSFS=y
- commit 2b1052f
* Thu Aug 24 2023 tiwai@suse.de
- wifi: rtw88: usb: kill and free rx urbs on probe failure
  (bsc#1214385).
- commit 5c3979f
* Wed Aug 23 2023 vkarasulli@suse.de
- Update references in
  patches.kernel.org/6.4.4-230-Input-cyttsp4_core-change-del_timer_sync-to-tim.patch
  (bsc#1012628 bsc#1213971 CVE-2023-4134).
- commit f6b7737
* Wed Aug 23 2023 msuchanek@suse.de
- old-flavors: Drop 2.6 kernels.
  2.6 based kernels are EOL, upgrading from them is no longer suported.
- commit 7bb5087
* Tue Aug 22 2023 jslaby@suse.cz
- Refresh
  patches.suse/ASoC-SOF-intel-hda-Clean-up-link-DMA-for-IPC3-during.patch.
  Update to upstream version and move to sorted section.
- commit e2dbc84
* Tue Aug 22 2023 jslaby@suse.cz
- Refresh
  patches.suse/drm-nouveau-disp-fix-use-after-free-in-error-handlin.patch.
  Update to upstream version and move to sorted section.
- commit 2419864
* Tue Aug 22 2023 jslaby@suse.cz
- Refresh
  patches.suse/Revert-drm-edid-Fix-csync-detailed-mode-parsing.patch.
  Update to upstream version and move to sorted section.
- commit dcc3072
* Sun Aug 20 2023 mkubecek@suse.cz
- Update to 6.5-rc7
- commit 869afb7
* Fri Aug 18 2023 msuchanek@suse.de
- mkspec: Allow unsupported KMPs (bsc#1214386)
- commit 55d8b82
* Fri Aug 18 2023 msuchanek@suse.de
- check-for-config-changes: ignore BUILTIN_RETURN_ADDRESS_STRIPS_PAC (bsc#1214380).
  gcc7 on SLE 15 does not support this while later gcc does.
- commit 5b41c27
* Thu Aug 17 2023 jslaby@suse.cz
- Linux 6.4.11 (bsc#1012628).
- tpm: Disable RNG for all AMD fTPMs (bsc#1012628).
- tpm: Add a helper for checking hwrng enabled (bsc#1012628).
- ksmbd: validate command request size (bsc#1012628).
- ksmbd: fix wrong next length validation of ea buffer in
  smb2_set_ea() (bsc#1012628).
- KVM: SEV: snapshot the GHCB before accessing it (bsc#1012628).
- KVM: SEV: only access GHCB fields once (bsc#1012628).
- wifi: nl80211: fix integer overflow in
  nl80211_parse_mbssid_elems() (bsc#1012628).
- wifi: rtw89: fix 8852AE disconnection caused by RX full flags
  (bsc#1012628).
- selftests: forwarding: Set default IPv6 traceroute utility
  (bsc#1012628).
- wireguard: allowedips: expand maximum node depth (bsc#1012628).
- mmc: moxart: read scr register without changing byte order
  (bsc#1012628).
- mmc: sdhci-f-sdh30: Replace with sdhci_pltfm (bsc#1012628).
- ipv6: adjust ndisc_is_useropt() to also return true for PIO
  (bsc#1012628).
- selftests: mptcp: join: fix 'delete and re-add' test
  (bsc#1012628).
- selftests: mptcp: join: fix 'implicit EP' test (bsc#1012628).
- mptcp: avoid bogus reset on fallback close (bsc#1012628).
- mptcp: fix disconnect vs accept race (bsc#1012628).
- dmaengine: pl330: Return DMA_PAUSED when transaction is paused
  (bsc#1012628).
- dmaengine: xilinx: xdma: Fix interrupt vector setting
  (bsc#1012628).
- net: mana: Fix MANA VF unload when hardware is unresponsive
  (bsc#1012628).
- ACPI: resource: Add IRQ override quirk for PCSpecialist Elimina
  Pro 16 M (bsc#1012628).
- zram: take device and not only bvec offset into account
  (bsc#1012628).
- io_uring/parisc: Adjust pgoff in io_uring mmap() for parisc
  (bsc#1012628).
- parisc: Fix lightweight spinlock checks to not break futexes
  (bsc#1012628).
- riscv: Start of DRAM should at least be aligned on PMD size
  for the direct mapping (bsc#1012628).
- riscv/kexec: load initrd high in available memory (bsc#1012628).
- riscv,mmio: Fix readX()-to-delay() ordering (bsc#1012628).
- riscv/kexec: handle R_RISCV_CALL_PLT relocation type
  (bsc#1012628).
- riscv: mm: fix 2 instances of -Wmissing-variable-declarations
  (bsc#1012628).
- nvme: fix possible hang when removing a controller during
  error recovery (bsc#1012628).
- nvme-tcp: fix potential unbalanced freeze & unfreeze
  (bsc#1012628).
- nvme-rdma: fix potential unbalanced freeze & unfreeze
  (bsc#1012628).
- nvme-pci: add NVME_QUIRK_BOGUS_NID for Samsung PM9B1 256G and
  512G (bsc#1012628).
- drm/nouveau/gr: enable memory loads on helper invocation on
  all channels (bsc#1012628).
- drm/nouveau/nvkm/dp: Add workaround to fix DP 1.3+ DPCD issues
  (bsc#1012628).
- drm/shmem-helper: Reset vma->vm_ops before calling
  dma_buf_mmap() (bsc#1012628).
- drm/amdgpu: fix possible UAF in amdgpu_cs_pass1() (bsc#1012628).
- drm/amd/pm: correct the pcie width for smu 13.0.0 (bsc#1012628).
- drm/amd/display: check attr flag before set cursor degamma on
  DCN3+ (bsc#1012628).
- tpm: tpm_tis: Fix UPX-i11 DMI_MATCH condition (bsc#1012628).
- cpuidle: dt_idle_genpd: Add helper function to remove genpd
  topology (bsc#1012628).
- cpuidle: psci: Move enabling OSI mode after power domains
  creation (bsc#1012628).
- io_uring: correct check for O_TMPFILE (bsc#1012628).
- zsmalloc: fix races between modifications of fullness and
  isolated (bsc#1012628).
- hwmon: (pmbus/bel-pfe) Enable PMBUS_SKIP_STATUS_CHECK for
  pfe1100 (bsc#1012628).
- radix tree test suite: fix incorrect allocation size for
  pthreads (bsc#1012628).
- cpufreq: amd-pstate: fix global sysfs attribute type
  (bsc#1012628).
- fs/proc/kcore: reinstate bounce buffer for KCORE_TEXT regions
  (bsc#1012628).
- nilfs2: fix use-after-free of nilfs_root in dirtying inodes
  via iput (bsc#1012628).
- accel/ivpu: Add set_pages_array_wc/uc for internal buffers
  (bsc#1012628).
- hugetlb: do not clear hugetlb dtor until allocating vmemmap
  (bsc#1012628).
- mm/damon/core: initialize damo_filter->list from
  damos_new_filter() (bsc#1012628).
- selftests: mm: ksm: fix incorrect evaluation of parameter
  (bsc#1012628).
- mm: memory-failure: fix potential unexpected return value from
  unpoison_memory() (bsc#1012628).
- mm: memory-failure: avoid false hwpoison page mapped error info
  (bsc#1012628).
- drm/amd/pm: expose swctf threshold setting for legacy powerplay
  (bsc#1012628).
- drm/amd/pm: avoid unintentional shutdown due to temperature
  momentary fluctuation (bsc#1012628).
- iio: cros_ec: Fix the allocation size for cros_ec_command
  (bsc#1012628).
- iio: frequency: admv1013: propagate errors from
  regulator_get_voltage() (bsc#1012628).
- iio: adc: ad7192: Fix ac excitation feature (bsc#1012628).
- iio: adc: meson: fix core clock enable/disable moment
  (bsc#1012628).
- iio: adc: ina2xx: avoid NULL pointer dereference on OF device
  match (bsc#1012628).
- binder: fix memory leak in binder_init() (bsc#1012628).
- misc: rtsx: judge ASPM Mode to set PETXCFG Reg (bsc#1012628).
- thunderbolt: Fix memory leak in tb_handle_dp_bandwidth_request()
  (bsc#1012628).
- usb-storage: alauda: Fix uninit-value in alauda_check_media()
  (bsc#1012628).
- usb: dwc3: Properly handle processing of pending events
  (bsc#1012628).
- USB: Gadget: core: Help prevent panic during UVC unconfigure
  (bsc#1012628).
- usb: common: usb-conn-gpio: Prevent bailing out if initial
  role is none (bsc#1012628).
- usb: typec: tcpm: Fix response to vsafe0V event (bsc#1012628).
- usb: typec: altmodes/displayport: Signal hpd when configuring
  pin assignment (bsc#1012628).
- x86/srso: Fix build breakage with the LLVM linker (bsc#1012628).
- x86/vdso: Choose the right GDT_ENTRY_CPUNODE for 32-bit getcpu()
  on 64-bit kernel (bsc#1012628).
- x86/cpu/amd: Enable Zenbleed fix for AMD Custom APU 0405
  (bsc#1012628).
- x86/mm: Fix VDSO and VVAR placement on 5-level paging machines
  (bsc#1012628).
- x86/sev: Do not try to parse for the CC blob on non-AMD hardware
  (bsc#1012628).
- x86/linkage: Fix typo of BUILD_VDSO in asm/linkage.h
  (bsc#1012628).
- x86/speculation: Add cpu_show_gds() prototype (bsc#1012628).
- x86: Move gds_ucode_mitigated() declaration to header
  (bsc#1012628).
- Revert "PCI: mvebu: Mark driver as BROKEN" (bsc#1012628).
- drm/nouveau/disp: Revert a NULL check inside
  nouveau_connector_get_modes (bsc#1012628).
- netfilter: nf_tables: don't skip expired elements during walk
  (bsc#1012628).
- netfilter: nf_tables: GC transaction API to avoid race with
  control plane (bsc#1012628).
- netfilter: nf_tables: adapt set backend to use GC transaction
  API (bsc#1012628).
- netfilter: nft_set_hash: mark set element as dead when deleting
  from packet path (bsc#1012628).
- iio: imu: lsm6dsx: Fix mount matrix retrieval (bsc#1012628).
- iio: core: Prevent invalid memory access when there is no parent
  (bsc#1012628).
- iio: light: bu27034: Fix scale format (bsc#1012628).
- interconnect: qcom: Add support for mask-based BCMs
  (bsc#1012628).
- interconnect: qcom: sa8775p: add enable_mask for bcm nodes
  (bsc#1012628).
- interconnect: qcom: sm8450: add enable_mask for bcm nodes
  (bsc#1012628).
- interconnect: qcom: sm8550: add enable_mask for bcm nodes
  (bsc#1012628).
- selftests: forwarding: tc_tunnel_key: Make filters more specific
  (bsc#1012628).
- selftests: forwarding: ethtool_mm: Skip when MAC Merge is not
  supported (bsc#1012628).
- selftests: forwarding: bridge_mdb_max: Check iproute2 version
  (bsc#1012628).
- selftests: forwarding: bridge_mdb: Check iproute2 version
  (bsc#1012628).
- KVM: arm64: Fix hardware enable/disable flows for pKVM
  (bsc#1012628).
- dmaengine: xilinx: xdma: Fix typo (bsc#1012628).
- dmaengine: xilinx: xdma: Fix Judgment of the return value
  (bsc#1012628).
- selftests/bpf: fix a CI failure caused by vsock sockmap test
  (bsc#1012628).
- selftests/rseq: Fix build with undefined __weak (bsc#1012628).
- selftests: forwarding: Add a helper to skip test when using
  veth pairs (bsc#1012628).
- selftests: forwarding: ethtool: Skip when using veth pairs
  (bsc#1012628).
- selftests: forwarding: ethtool_extended_state: Skip when using
  veth pairs (bsc#1012628).
- selftests: forwarding: hw_stats_l3_gre: Skip when using veth
  pairs (bsc#1012628).
- selftests: forwarding: Skip test when no interfaces are
  specified (bsc#1012628).
- selftests: forwarding: Switch off timeout (bsc#1012628).
- selftests: forwarding: tc_actions: Use ncat instead of nc
  (bsc#1012628).
- selftests: forwarding: tc_flower: Relax success criterion
  (bsc#1012628).
- selftests: forwarding: bridge_mdb_max: Fix failing test with
  old libnet (bsc#1012628).
- selftests: forwarding: bridge_mdb: Fix failing test with old
  libnet (bsc#1012628).
- selftests: forwarding: bridge_mdb: Make test more robust
  (bsc#1012628).
- net: core: remove unnecessary frame_sz check in
  bpf_xdp_adjust_tail() (bsc#1012628).
- bpf, sockmap: Fix map type error in sock_map_del_link
  (bsc#1012628).
- bpf, sockmap: Fix bug that strp_done cannot be called
  (bsc#1012628).
- hwmon: (aquacomputer_d5next) Add selective 200ms delay after
  sending ctrl report (bsc#1012628).
- mISDN: Update parameter type of dsp_cmx_send() (bsc#1012628).
- macsec: use DEV_STATS_INC() (bsc#1012628).
- mptcp: fix the incorrect judgment for msk->cb_flags
  (bsc#1012628).
- igc: Add lock to safeguard global Qbv variables (bsc#1012628).
- ionic: Add missing err handling for queue reconfig
  (bsc#1012628).
- net/packet: annotate data-races around tp->status (bsc#1012628).
- net/smc: Fix setsockopt and sysctl to specify same buffer size
  again (bsc#1012628).
- net/smc: Use correct buffer sizes when switching between TCP
  and SMC (bsc#1012628).
- PCI: move OF status = "disabled" detection to dev->match_driver
  (bsc#1012628).
- tcp: add missing family to tcp_set_ca_state() tracepoint
  (bsc#1012628).
- tunnels: fix kasan splat when generating ipv4 pmtu error
  (bsc#1012628).
- xsk: fix refcount underflow in error path (bsc#1012628).
- bonding: Fix incorrect deletion of ETH_P_8021AD protocol vid
  from slaves (bsc#1012628).
- dccp: fix data-race around dp->dccps_mss_cache (bsc#1012628).
- drivers: net: prevent tun_build_skb() to exceed the packet
  size limit (bsc#1012628).
- drivers: vxlan: vnifilter: free percpu vni stats on error path
  (bsc#1012628).
- iavf: fix potential races for FDIR filters (bsc#1012628).
- IB/hfi1: Fix possible panic during hotplug remove (bsc#1012628).
- drm/amd/display: Don't show stack trace for missing eDP
  (bsc#1012628).
- drm/bridge: it6505: Check power state with it6505->powered in
  IRQ handler (bsc#1012628).
- drm/nouveau: remove unused tu102_gr_load() function
  (bsc#1012628).
- drm/rockchip: Don't spam logs in atomic check (bsc#1012628).
- wifi: brcm80211: handle params_v1 allocation failure
  (bsc#1012628).
- wifi: cfg80211: fix sband iftype data lookup for AP_VLAN
  (bsc#1012628).
- RDMA/umem: Set iova in ODP flow (bsc#1012628).
- RDMA/bnxt_re: Properly order ib_device_unalloc() to avoid UAF
  (bsc#1012628).
- RDMA/bnxt_re: Fix error handling in probe failure path
  (bsc#1012628).
- net: tls: avoid discarding data on record close (bsc#1012628).
- net: marvell: prestera: fix handling IPv4 routes with nhid
  (bsc#1012628).
- net: phy: at803x: remove set/get wol callbacks for AR8032
  (bsc#1012628).
- net: dsa: ocelot: call dsa_tag_8021q_unregister() under
  rtnl_lock() on driver remove (bsc#1012628).
- net: hns3: refactor hclge_mac_link_status_wait for interface
  reuse (bsc#1012628).
- net: hns3: add wait until mac link down (bsc#1012628).
- net: hns3: fix deadlock issue when externel_lb and reset are
  executed together (bsc#1012628).
- net: enetc: reimplement RFS/RSS memory clearing as PCI quirk
  (bsc#1012628).
- nexthop: Fix infinite nexthop dump when using maximum nexthop ID
  (bsc#1012628).
- nexthop: Make nexthop bucket dump more efficient (bsc#1012628).
- nexthop: Fix infinite nexthop bucket dump when using maximum
  nexthop ID (bsc#1012628).
- net: hns3: fix strscpy causing content truncation issue
  (bsc#1012628).
- dmaengine: mcf-edma: Fix a potential un-allocated memory access
  (bsc#1012628).
- dmaengine: idxd: Clear PRS disable flag when disabling IDXD
  device (bsc#1012628).
- dmaengine: owl-dma: Modify mismatched function name
  (bsc#1012628).
- net/mlx5e: Take RTNL lock when needed before calling
  xdp_set_features() (bsc#1012628).
- net/mlx5e: TC, Fix internal port memory leak (bsc#1012628).
- net/mlx5: DR, Fix wrong allocation of modify hdr pattern
  (bsc#1012628).
- net/mlx5: Allow 0 for total host VFs (bsc#1012628).
- net/mlx5e: Unoffload post act rule when handling FIB events
  (bsc#1012628).
- net/mlx5: LAG, Check correct bucket when modifying LAG
  (bsc#1012628).
- net/mlx5: Skip clock update work when device is in error state
  (bsc#1012628).
- net/mlx5: Reload auxiliary devices in pci error handlers
  (bsc#1012628).
- ibmvnic: Enforce stronger sanity checks on login response
  (bsc#1012628).
- ibmvnic: Unmap DMA login rsp buffer on send login fail
  (bsc#1012628).
- ibmvnic: Handle DMA unmapping of login buffs in release
  functions (bsc#1012628).
- ibmvnic: Do partial reset on login failure (bsc#1012628).
- ibmvnic: Ensure login failure recovery is safe from other resets
  (bsc#1012628).
- gpio: ws16c48: Fix off-by-one error in WS16C48 resource region
  extent (bsc#1012628).
- gpio: sim: mark the GPIO chip as a one that can sleep
  (bsc#1012628).
- btrfs: wait for actual caching progress during allocation
  (bsc#1012628).
- btrfs: don't stop integrity writeback too early (bsc#1012628).
- btrfs: don't wait for writeback on clean pages in
  extent_write_cache_pages (bsc#1012628).
- btrfs: properly clear end of the unreserved range in
  cow_file_range (bsc#1012628).
- btrfs: exit gracefully if reloc roots don't match (bsc#1012628).
- btrfs: reject invalid reloc tree root keys with stack dump
  (bsc#1012628).
- btrfs: set cache_block_group_error if we find an error
  (bsc#1012628).
- scsi: core: Fix legacy /proc parsing buffer overflow
  (bsc#1012628).
- scsi: storvsc: Fix handling of virtual Fibre Channel timeouts
  (bsc#1012628).
- scsi: ufs: renesas: Fix private allocation (bsc#1012628).
- scsi: 53c700: Check that command slot is not NULL (bsc#1012628).
- scsi: snic: Fix possible memory leak if device_add() fails
  (bsc#1012628).
- scsi: core: Fix possible memory leak if device_add() fails
  (bsc#1012628).
- scsi: fnic: Replace return codes in fnic_clean_pending_aborts()
  (bsc#1012628).
- scsi: qedi: Fix firmware halt over suspend and resume
  (bsc#1012628).
- scsi: qedf: Fix firmware halt over suspend and resume
  (bsc#1012628).
- platform/x86: msi-ec: Fix the build (bsc#1012628).
- platform/x86: lenovo-ymc: Only bind on machines with a
  convertible DMI chassis-type (bsc#1012628).
- platform: mellanox: Change register offset addresses
  (bsc#1012628).
- platform: mellanox: mlx-platform: Fix signals polarity and
  latch mask (bsc#1012628).
- platform: mellanox: mlx-platform: Modify graceful shutdown
  callback and power down mask (bsc#1012628).
- platform: mellanox: Fix order in exit flow (bsc#1012628).
- platform/x86: serial-multi-instantiate: Auto detect IRQ resource
  for CSC3551 (bsc#1012628).
- ACPI: scan: Create platform device for CS35L56 (bsc#1012628).
- alpha: remove __init annotation from exported page_is_ram()
  (bsc#1012628).
- Update config files.
- commit 2a5b3f6
* Wed Aug 16 2023 msuchanek@suse.de
- kernel-binary: Common dependencies cleanup
  Common dependencies are copied to a subpackage, there is no need for
  copying defines or build dependencies there.
- commit 254b03c
* Wed Aug 16 2023 msuchanek@suse.de
- kernel-binary: Drop code for kerntypes support
  Kerntypes was a SUSE-specific feature dropped before SLE 12.
- commit 2c37773
* Tue Aug 15 2023 palcantara@suse.de
- Update
  patches.kernel.org/6.4.5-008-ksmbd-fix-out-of-bounds-read-in-smb2_sess_setup.patch
  (bsc#1012628 bsc#1213545).
- commit d8f70b2
* Mon Aug 14 2023 tiwai@suse.de
- drm/nouveau/disp: fix use-after-free in error handling of
  nouveau_connector_create (bsc#1214073).
- Delete
  patches.suse/Revert-drm-nouveau-disp-PIOR-DP-uses-GPIO-for-HPD-no.patch.
- commit 1b3aee5
* Mon Aug 14 2023 tiwai@suse.de
- tpm_tis: Opt-in interrupts (bsc#1213779)
  Also dropped the obsoleted patch:
  patches.suse/tpm-tpm_tis-Disable-interrupts-categorically-for-Len.patch
- commit 80aa18d
* Mon Aug 14 2023 jslaby@suse.cz
- Refresh
  patches.suse/ACPI-resource-Always-use-MADT-override-IRQ-settings-.patch.
- Refresh
  patches.suse/ACPI-resource-Honor-MADT-INT_SRC_OVR-settings-for-IR.patch.
- Refresh
  patches.suse/ACPI-resource-revert-Remove-Zen-specific-match-and-q.patch.
  Update upstream status and move to sorted section.
- commit d0aa45f
* Mon Aug 14 2023 jslaby@suse.cz
- Refresh
  patches.suse/drm-amd-display-Fix-a-regression-on-Polaris-cards.patch.
  Update upstream status and move to sorted section.
- commit e1f43a2
* Mon Aug 14 2023 jslaby@suse.cz
- Linux 6.4.10 (bsc#1012628).
- iommu/arm-smmu-v3: Work around MMU-600 erratum 1076982
  (bsc#1012628).
- iommu/arm-smmu-v3: Document MMU-700 erratum 2812531
  (bsc#1012628).
- iommu/arm-smmu-v3: Add explicit feature for nesting
  (bsc#1012628).
- iommu/arm-smmu-v3: Document nesting-related errata
  (bsc#1012628).
- arm64: dts: imx8mm-venice-gw7903: disable disp_blk_ctrl
  (bsc#1012628).
- arm64: dts: imx8mm-venice-gw7904: disable disp_blk_ctrl
  (bsc#1012628).
- arm64: dts: phycore-imx8mm: Label typo-fix of VPU (bsc#1012628).
- arm64: dts: phycore-imx8mm: Correction in gpio-line-names
  (bsc#1012628).
- arm64: dts: imx8mn-var-som: add missing pull-up for onboard
  PHY reset pinmux (bsc#1012628).
- arm64: dts: freescale: Fix VPU G2 clock (bsc#1012628).
- firmware: smccc: Fix use of uninitialised results structure
  (bsc#1012628).
- firmware: arm_scmi: Fix signed error return values handling
  (bsc#1012628).
- lib/bitmap: workaround const_eval test build failure
  (bsc#1012628).
- ARM: dts: nxp/imx: limit sk-imx53 supported frequencies
  (bsc#1012628).
- soc: imx: imx8mp-blk-ctrl: register HSIO PLL clock as
  bus_power_dev child (bsc#1012628).
- firmware: arm_scmi: Fix chan_free cleanup on SMC (bsc#1012628).
- ARM: dts: at91: use clock-controller name for PMC nodes
  (bsc#1012628).
- ARM: dts: at91: use clock-controller name for sckc nodes
  (bsc#1012628).
- ARM: dts: at91: use generic name for shutdown controller
  (bsc#1012628).
- ARM: dts: at91: sam9x60: fix the SOC detection (bsc#1012628).
- word-at-a-time: use the same return type for has_zero regardless
  of endianness (bsc#1012628).
- s390/vmem: split pages when debug pagealloc is enabled
  (bsc#1012628).
- KVM: s390: fix sthyi error handling (bsc#1012628).
- erofs: fix wrong primary bvec selection on deduplicated extents
  (bsc#1012628).
- perf pmu arm64: Fix reading the PMU cpu slots in sysfs
  (bsc#1012628).
- wifi: cfg80211: Fix return value in scan logic (bsc#1012628).
- net/mlx5e: fix double free in
  macsec_fs_tx_create_crypto_table_groups (bsc#1012628).
- net/mlx5: DR, fix memory leak in mlx5dr_cmd_create_reformat_ctx
  (bsc#1012628).
- net/mlx5: fix potential memory leak in mlx5e_init_rep_rx
  (bsc#1012628).
- net/mlx5e: fix return value check in
  mlx5e_ipsec_remove_trailer() (bsc#1012628).
- net/mlx5: Honor user input for migratable port fn attr
  (bsc#1012628).
- net/mlx5e: Don't hold encap tbl lock if there is no encap action
  (bsc#1012628).
- net/mlx5e: Fix crash moving to switchdev mode when ntuple
  offload is set (bsc#1012628).
- net/mlx5e: Move representor neigh cleanup to profile cleanup_tx
  (bsc#1012628).
- net/mlx5e: xsk: Fix invalid buffer access for legacy rq
  (bsc#1012628).
- net/mlx5e: xsk: Fix crash on regular rq reactivation
  (bsc#1012628).
- net/mlx5e: kTLS, Fix protection domain in use syndrome when
  devlink reload (bsc#1012628).
- net/mlx5: fs_chains: Fix ft prio if ignore_flow_level is not
  supported (bsc#1012628).
- net/mlx5: Unregister devlink params in case interface is down
  (bsc#1012628).
- bpf: Add length check for SK_DIAG_BPF_STORAGE_REQ_MAP_FD parsing
  (bsc#1012628).
- rtnetlink: let rtnl_bridge_setlink checks IFLA_BRIDGE_MODE
  length (bsc#1012628).
- net: dsa: fix value check in bcm_sf2_sw_probe() (bsc#1012628).
- perf test uprobe_from_different_cu: Skip if there is no gcc
  (bsc#1012628).
- net: sched: cls_u32: Fix match key mis-addressing (bsc#1012628).
- mISDN: hfcpci: Fix potential deadlock on &hc->lock
  (bsc#1012628).
- net: stmmac: tegra: Properly allocate clock bulk data
  (bsc#1012628).
- qed: Fix scheduling in a tasklet while getting stats
  (bsc#1012628).
- net: move gso declarations and functions to their own files
  (bsc#1012628).
- net: gro: fix misuse of CB in udp socket lookup (bsc#1012628).
- net: annotate data-races around sk->sk_reserved_mem
  (bsc#1012628).
- net: annotate data-race around sk->sk_txrehash (bsc#1012628).
- net: annotate data-races around sk->sk_max_pacing_rate
  (bsc#1012628).
- net: add missing READ_ONCE(sk->sk_rcvlowat) annotation
  (bsc#1012628).
- net: add missing READ_ONCE(sk->sk_sndbuf) annotation
  (bsc#1012628).
- net: add missing READ_ONCE(sk->sk_rcvbuf) annotation
  (bsc#1012628).
- net: annotate data-races around sk->sk_mark (bsc#1012628).
- net: add missing data-race annotations around sk->sk_peek_off
  (bsc#1012628).
- net: add missing data-race annotation for sk_ll_usec
  (bsc#1012628).
- net: annotate data-races around sk->sk_priority (bsc#1012628).
- net/sched: taprio: Limit TCA_TAPRIO_ATTR_SCHED_CYCLE_TIME to
  INT_MAX (bsc#1012628).
- net: usb: lan78xx: reorder cleanup operations to avoid UAF bugs
  (bsc#1012628).
- ice: Fix RDMA VSI removal during queue rebuild (bsc#1012628).
- bnxt: don't handle XDP in netpoll (bsc#1012628).
- octeon_ep: initialize mbox mutexes (bsc#1012628).
- bpf: Move unprivileged checks into map_create() and
  bpf_prog_load() (bsc#1012628).
- bpf: Inline map creation logic in map_create() function
  (bsc#1012628).
- bpf: Centralize permissions checks for all BPF map types
  (bsc#1012628).
- bpf, cpumap: Make sure kthread is running before map update
  returns (bsc#1012628).
- bpf, cpumap: Handle skb as well when clean up ptr_ring
  (bsc#1012628).
- net/sched: cls_u32: No longer copy tcf_result on update to
  avoid use-after-free (bsc#1012628).
- net/sched: cls_fw: No longer copy tcf_result on update to
  avoid use-after-free (bsc#1012628).
- net/sched: cls_route: No longer copy tcf_result on update to
  avoid use-after-free (bsc#1012628).
- bpf: sockmap: Remove preempt_disable in sock_map_sk_acquire
  (bsc#1012628).
- net: ll_temac: fix error checking of irq_of_parse_and_map()
  (bsc#1012628).
- net: korina: handle clk prepare error in korina_probe()
  (bsc#1012628).
- net: netsec: Ignore 'phy-mode' on SynQuacer in DT mode
  (bsc#1012628).
- selftest: net: Assert on a proper value in so_incoming_cpu.c
  (bsc#1012628).
- bnxt_en: Fix page pool logic for page size >= 64K (bsc#1012628).
- bnxt_en: Fix max_mtu setting for multi-buf XDP (bsc#1012628).
- net: dcb: choose correct policy to parse DCB_ATTR_BCN
  (bsc#1012628).
- s390/qeth: Don't call dev_close/dev_open (DOWN/UP)
  (bsc#1012628).
- ip6mr: Fix skb_under_panic in ip6mr_cache_report()
  (bsc#1012628).
- vxlan: Fix nexthop hash size (bsc#1012628).
- net/mlx5: fs_core: Make find_closest_ft more generic
  (bsc#1012628).
- net/mlx5: fs_core: Skip the FTs in the same FS_TYPE_PRIO_CHAINS
  fs_prio (bsc#1012628).
- net/mlx5e: Set proper IPsec source port in L4 selector
  (bsc#1012628).
- prestera: fix fallback to previous version on same major version
  (bsc#1012628).
- tcp_metrics: fix addr_same() helper (bsc#1012628).
- tcp_metrics: annotate data-races around tm->tcpm_stamp
  (bsc#1012628).
- tcp_metrics: annotate data-races around tm->tcpm_lock
  (bsc#1012628).
- tcp_metrics: annotate data-races around tm->tcpm_vals[]
  (bsc#1012628).
- tcp_metrics: annotate data-races around tm->tcpm_net
  (bsc#1012628).
- tcp_metrics: fix data-race in tcpm_suck_dst() vs fastopen
  (bsc#1012628).
- test/vsock: remove vsock_perf executable on `make clean`
  (bsc#1012628).
- rust: allocator: Prevent mis-aligned allocation (bsc#1012628).
- scsi: zfcp: Defer fc_rport blocking until after ADISC response
  (bsc#1012628).
- scsi: storvsc: Limit max_sectors for virtual Fibre Channel
  devices (bsc#1012628).
- Documentation: kdump: Add va_kernel_pa_offset for RISCV64
  (bsc#1012628).
- libceph: fix potential hang in ceph_osdc_notify() (bsc#1012628).
- USB: zaurus: Add ID for A-300/B-500/C-700 (bsc#1012628).
- ceph: defer stopping mdsc delayed_work (bsc#1012628).
- firmware: arm_scmi: Drop OF node reference in the transport
  channel setup (bsc#1012628).
- exfat: use kvmalloc_array/kvfree instead of kmalloc_array/kfree
  (bsc#1012628).
- exfat: check if filename entries exceeds max filename length
  (bsc#1012628).
- exfat: release s_lock before calling dir_emit() (bsc#1012628).
- mtd: spinand: toshiba: Fix ecc_get_status (bsc#1012628).
- mtd: spinand: winbond: Fix ecc_get_status (bsc#1012628).
- mtd: rawnand: meson: fix OOB available bytes for ECC
  (bsc#1012628).
- riscv: Export va_kernel_pa_offset in vmcoreinfo (bsc#1012628).
- bpf: Disable preemption in bpf_perf_event_output (bsc#1012628).
- arm64: dts: stratix10: fix incorrect I2C property for SCL signal
  (bsc#1012628).
- wifi: mt76: mt7615: do not advertise 5 GHz on first phy of
  MT7615D (DBDC) (bsc#1012628).
- x86/hyperv: Disable IBT when hypercall page lacks ENDBR
  instruction (bsc#1012628).
- rbd: prevent busy loop when requesting exclusive lock
  (bsc#1012628).
- bpf: Disable preemption in bpf_event_output (bsc#1012628).
- smb: client: fix dfs link mount against w2k8 (bsc#1012628).
- powerpc/ftrace: Create a dummy stackframe to fix stack unwind
  (bsc#1012628).
- parisc/mm: preallocate fixmap page tables at init (bsc#1012628).
- arm64/fpsimd: Sync and zero pad FPSIMD state for streaming SVE
  (bsc#1012628).
- arm64/fpsimd: Clear SME state in the target task when setting
  the VL (bsc#1012628).
- arm64/fpsimd: Sync FPSIMD state with SVE for SME only systems
  (bsc#1012628).
- arm64/ptrace: Flush FP state when setting ZT0 (bsc#1012628).
- arm64/ptrace: Don't enable SVE when setting streaming SVE
  (bsc#1012628).
- open: make RESOLVE_CACHED correctly test for O_TMPFILE
  (bsc#1012628).
- drm/ttm: check null pointer before accessing when swapping
  (bsc#1012628).
- drm/i915: Fix premature release of request's reusable memory
  (bsc#1012628).
- drm/i915/gt: Cleanup aux invalidation registers (bsc#1012628).
- Revert "page cache: fix page_cache_next/prev_miss off by one"
  (bsc#1012628).
- sunvnet: fix sparc64 build error after gso code split
  (bsc#1012628).
- clk: imx93: Propagate correct error in imx93_clocks_probe()
  (bsc#1012628).
- file: reinstate f_pos locking optimization for regular files
  (bsc#1012628).
- mm: kmem: fix a NULL pointer dereference in
  obj_stock_flush_required() (bsc#1012628).
- fs/ntfs3: Use __GFP_NOWARN allocation at ntfs_load_attr_list()
  (bsc#1012628).
- kasan,kmsan: remove __GFP_KSWAPD_RECLAIM usage from kasan/kmsan
  (bsc#1012628).
- fs/sysv: Null check to prevent null-ptr-deref bug (bsc#1012628).
- Bluetooth: L2CAP: Fix use-after-free in l2cap_sock_ready_cb
  (bsc#1012628).
- debugobjects: Recheck debug_objects_enabled before reporting
  (bsc#1012628).
- net: usbnet: Fix WARNING in usbnet_start_xmit/usb_submit_urb
  (bsc#1012628).
- fs: Protect reconfiguration of sb read-write from racing writes
  (bsc#1012628).
- mm/gup: do not return 0 from pin_user_pages_fast() for bad args
  (bsc#1012628).
- ext2: Drop fragment support (bsc#1012628).
- btrfs: remove BUG_ON()'s in add_new_free_space() (bsc#1012628).
- f2fs: fix to do sanity check on direct node in truncate_dnode()
  (bsc#1012628).
- io_uring: annotate offset timeout races (bsc#1012628).
- mtd: rawnand: omap_elm: Fix incorrect type in assignment
  (bsc#1012628).
- mtd: rawnand: rockchip: fix oobfree offset and description
  (bsc#1012628).
- mtd: rawnand: rockchip: Align hwecc vs. raw page helper layouts
  (bsc#1012628).
- clk: mediatek: mt8183: Add back SSPM related clocks
  (bsc#1012628).
- mtd: spi-nor: avoid holes in struct spi_mem_op (bsc#1012628).
- mtd: rawnand: fsl_upm: Fix an off-by one test in fun_exec_op()
  (bsc#1012628).
- powerpc/mm/altmap: Fix altmap boundary check (bsc#1012628).
- drm/imx/ipuv3: Fix front porch adjustment upon hactive aligning
  (bsc#1012628).
- drm/amdgpu: Use apt name for FW reserved region (bsc#1012628).
- selftests/rseq: Play nice with binaries statically linked
  against glibc 2.35+ (bsc#1012628).
- ARM: dts: nxp/imx6sll: fix wrong property name in usbphy node
  (bsc#1012628).
- drm/i915: Add the gen12_needs_ccs_aux_inv helper (bsc#1012628).
- drm/i915/gt: Ensure memory quiesced before invalidation
  (bsc#1012628).
- drm/i915/gt: Add workaround 14016712196 (bsc#1012628).
- drm/i915/gt: Rename flags with bit_group_X according to the
  datasheet (bsc#1012628).
- drm/i915/gt: Poll aux invalidation register bit on invalidation
  (bsc#1012628).
- drm/i915/gt: Support aux invalidation on all engines
  (bsc#1012628).
- drm/i915/gt: Enable the CCS_FLUSH bit in the pipe control and
  in the CS (bsc#1012628).
- x86/CPU/AMD: Do not leak quotient data after a division by 0
  (bsc#1012628).
- commit eb77301
* Sun Aug 13 2023 mkubecek@suse.cz
- Update to 6.5-rc6
- update configs
  - x86
  - GDS_FORCE_MITIGATION=n
  - x86_64
  - CPU_SRSO=y
- commit c65258c
* Sat Aug 12 2023 tiwai@suse.de
- drm/amd: Disable S/G for APUs when 64GB or more host memory
  (bsc#1213787).
- commit 1b8ce3e
* Sat Aug 12 2023 tiwai@suse.de
- pinctrl: amd: Don't show `Invalid config param` errors
  (bsc#1214212).
- commit e95f7e7
* Fri Aug 11 2023 vkarasulli@suse.de
- net/sched: cls_route: No longer copy tcf_result on update  to
  avoid use-after-free (bsc#1214149 CVE-2023-4128).
- net/sched: cls_fw: No longer copy tcf_result on update to
  avoid use-after-free (bsc#1214149 CVE-2023-4128).
- net/sched: cls_u32: No longer copy tcf_result on update  to
  avoid use-after-free (bsc#1214149 CVE-2023-4128).
- commit 4368d3a
* Fri Aug 11 2023 tiwai@suse.de
- Revert "drm/nouveau/disp: PIOR DP uses GPIO for HPD, not PMGR
  AUX interrupts" (bsc#1214073).
- commit db7e8f0
* Fri Aug 11 2023 tiwai@suse.de
- tpm/tpm_tis: Disable interrupts categorically for Lenovo
  (bsc#1213779).
  Replaced the obsoleted fix patch:
  patches.suse/tpm-tpm_tis-Disable-interrupts-for-Lenovo-Thinkpad-E.patch
- commit efae9ac
* Fri Aug 11 2023 tiwai@suse.de
- tpm/tpm_tis: Disable interrupts for Lenovo P620 devices
  (bsc#1213779).
- commit 4f44748
* Fri Aug 11 2023 tiwai@suse.de
- Move upstreamed tpm_tis patch into sorted section
- commit 693df97
* Thu Aug 10 2023 jslaby@suse.cz
- mm: lock_vma_under_rcu() must check vma->anon_vma under vma lock
  (per-VMA_lock_fix).
- commit c5c7c45
* Thu Aug 10 2023 jslaby@suse.cz
- ACPI: resource: Honor MADT INT_SRC_OVR settings for IRQ1 on
  AMD Zen (20230809085526.84913-1-hdegoede@redhat.com).
- ACPI: resource: Always use MADT override
  IRQ settings for all legacy non i8042 IRQs
  (20230809085526.84913-1-hdegoede@redhat.com).
- ACPI: resource: revert "Remove "Zen" specific match and quirks"
  (20230809085526.84913-1-hdegoede@redhat.com).
- commit 17e449f
* Wed Aug  9 2023 jslaby@suse.cz
- Linux 6.4.9 (bsc#1012628).
- Update config files.
  Set:
  * CONFIG_GDS_FORCE_MITIGATION=n
  * CONFIG_CPU_SRSO=y
  as per default.
- x86: fix backwards merge of GDS/SRSO bit (bsc#1012628).
- xen/netback: Fix buffer overrun triggered by unusual packet
  (bsc#1012628).
- x86/srso: Tie SBPB bit setting to microcode patch detection
  (bsc#1012628).
- x86/srso: Add a forgotten NOENDBR annotation (bsc#1012628).
- x86/srso: Fix return thunks in generated code (bsc#1012628).
- x86/srso: Add IBPB on VMEXIT (bsc#1012628).
- x86/srso: Add IBPB (bsc#1012628).
- x86/srso: Add SRSO_NO support (bsc#1012628).
- x86/srso: Add IBPB_BRTYPE support (bsc#1012628).
- x86/srso: Add a Speculative RAS Overflow mitigation (bsc#1012628
  bsc#1213287 CVE-2023-20569).
- x86/bugs: Increase the x86 bugs vector size to two u32s
  (bsc#1012628).
- Documentation/x86: Fix backwards on/off logic about YMM support
  (bsc#1012628).
- x86/xen: Fix secondary processors' FPU initialization
  (bsc#1012628).
- x86/mem_encrypt: Unbreak the AMD_MEM_ENCRYPT=n build
  (bsc#1012628).
- KVM: Add GDS_NO support to KVM (bsc#1012628).
- x86/speculation: Add Kconfig option for GDS (bsc#1012628).
- x86/speculation: Add force option to GDS mitigation
  (bsc#1012628).
- x86/speculation: Add Gather Data Sampling mitigation
  (bsc#1012628 bsc#1206418 CVE-2022-40982).
- x86/fpu: Move FPU initialization into arch_cpu_finalize_init()
  (bsc#1012628).
- x86/fpu: Mark init functions __init (bsc#1012628).
- x86/fpu: Remove cpuinfo argument from init functions
  (bsc#1012628).
- x86/init: Initialize signal frame size late (bsc#1012628).
- init, x86: Move mem_encrypt_init() into arch_cpu_finalize_init()
  (bsc#1012628).
- init: Invoke arch_cpu_finalize_init() earlier (bsc#1012628).
- init: Remove check_bugs() leftovers (bsc#1012628).
- um/cpu: Switch to arch_cpu_finalize_init() (bsc#1012628).
- sparc/cpu: Switch to arch_cpu_finalize_init() (bsc#1012628).
- sh/cpu: Switch to arch_cpu_finalize_init() (bsc#1012628).
- mips/cpu: Switch to arch_cpu_finalize_init() (bsc#1012628).
- m68k/cpu: Switch to arch_cpu_finalize_init() (bsc#1012628).
- loongarch/cpu: Switch to arch_cpu_finalize_init() (bsc#1012628).
- ia64/cpu: Switch to arch_cpu_finalize_init() (bsc#1012628).
- ARM: cpu: Switch to arch_cpu_finalize_init() (bsc#1012628).
- x86/cpu: Switch to arch_cpu_finalize_init() (bsc#1012628).
- init: Provide arch_cpu_finalize_init() (bsc#1012628).
- commit 5b9ad20
* Mon Aug  7 2023 tiwai@suse.de
- tpm/tpm_tis: Disable interrupts for Lenovo Thinkpad E14 Gen
  2 and 13s-IML (bsc#1213779).
- commit c4adffc
* Mon Aug  7 2023 mfranc@suse.cz
- net: tun_chr_open(): set sk_uid from current_fsuid()
  (CVE-2023-4194 bsc#1214019).
- commit 8967829
* Mon Aug  7 2023 mfranc@suse.cz
- net: tap_open(): set sk_uid from current_fsuid() (CVE-2023-4194
  bsc#1214019).
- commit e5a2ecb
* Mon Aug  7 2023 tiwai@suse.de
- drm/amd/display: Fix a regression on Polaris cards
  (bsc#1212874).
- commit 9764e05
* Mon Aug  7 2023 mkubecek@suse.cz
- rpm/config.sh: switch to openSUSE.org repos for IBS
  Mirrored openSUSE repositories are long term more reliable than
  SUSE:Factory:HEAD we use now for IBS builds. Dropping the IBS_PROJECT*
  variables is the simplest way to switch to them as MyBS.pm prepends
  "openSUSE.org:" to the corresponding OBS_PROJECT* variable in their
  absence.
  This is a combination of kernel-source commits 21cafd1fd12a
  ("rpm/config.sh: switch to openSUSE.org repos for IBS") and 294d54140dd0
  ("rpm/config.sh: remove IBS repos completely") from stable branch.
- commit 997a7e4
* Mon Aug  7 2023 jslaby@suse.cz
- rpm/config.sh: remove IBS repos completely
  The commit 21cafd1f (rpm/config.sh: switch to openSUSE.org repos for
  IBS) duplicated the OBS repos in openSUSE.org: space. But this is done
  automatically in MyBS.pm. So drop all of them instead of duplicating.
- commit 294d541
* Mon Aug  7 2023 mkubecek@suse.cz
- Update to 6.5-rc5
- commit b685771
* Fri Aug  4 2023 jslaby@suse.cz
- rpm/config.sh: switch to openSUSE.org repos for IBS
  SUSE:Factory:HEAD is currently (and often) broken. Switch to
  openSUSE.org: repositories. They are up-to-date and provide the same
  archs plus armv6.
- commit 21cafd1
* Thu Aug  3 2023 jslaby@suse.cz
- Linux 6.4.8 (bsc#1012628).
- platform/x86/amd/pmf: Notify OS power slider update
  (bsc#1012628).
- platform/x86/amd/pmf: reduce verbosity of apmf_get_system_params
  (bsc#1012628).
- drm/amd: Move helper for dynamic speed switch check out of smu13
  (bsc#1012628).
- drm/amd: Align SMU11 SMU_MSG_OverridePcieParameters
  implementation with SMU13 (bsc#1012628).
- jbd2: Fix wrongly judgement for buffer head removing while
  doing checkpoint (bsc#1012628).
- KVM: arm64: Handle kvm_arm_init failure correctly in
  finalize_pkvm (bsc#1012628).
- blk-mq: Fix stall due to recursive flush plug (bsc#1012628).
- powerpc/pseries/vas: Hold mmap_mutex after mmap lock during
  window close (bsc#1012628).
- KVM: s390: pv: simplify shutdown and fix race (bsc#1012628).
- KVM: s390: pv: fix index value of replaced ASCE (bsc#1012628).
- s390/mm: fix per vma lock fault handling (bsc#1012628).
- io_uring: don't audit the capability check in io_uring_create()
  (bsc#1012628).
- gpio: tps68470: Make tps68470_gpio_output() always set the
  initial value (bsc#1012628).
- gpio: mvebu: Make use of devm_pwmchip_add (bsc#1012628).
- gpio: mvebu: fix irq domain leak (bsc#1012628).
- regmap: Disable locking for RBTREE and MAPLE unit tests
  (bsc#1012628).
- btrfs: factor out a btrfs_verify_page helper (bsc#1012628).
- btrfs: fix fsverify read error handling in end_page_read
  (bsc#1012628).
- btrfs: fix race between quota disable and relocation
  (bsc#1012628).
- i2c: Delete error messages for failed memory allocations
  (bsc#1012628).
- i2c: Improve size determinations (bsc#1012628).
- i2c: nomadik: Remove unnecessary goto label (bsc#1012628).
- i2c: nomadik: Use devm_clk_get_enabled() (bsc#1012628).
- i2c: nomadik: Remove a useless call in the remove function
  (bsc#1012628).
- PCI/ASPM: Return 0 or -ETIMEDOUT from pcie_retrain_link()
  (bsc#1012628).
- PCI/ASPM: Factor out pcie_wait_for_retrain() (bsc#1012628).
- PCI/ASPM: Avoid link retraining race (bsc#1012628).
- PCI: rockchip: Remove writes to unused registers (bsc#1012628).
- PCI: rockchip: Fix window mapping and address translation for
  endpoint (bsc#1012628).
- PCI: rockchip: Don't advertise MSI-X in PCIe capabilities
  (bsc#1012628).
- drm/amd/display: Convert Delaying Aux-I Disable To Monitor Patch
  (bsc#1012628).
- drm/amd/display: Keep disable aux-i delay as 0 (bsc#1012628).
- drm/amd/display: add pixel rate based CRB allocation support
  (bsc#1012628).
- drm/amd/display: fix dcn315 single stream crb allocation
  (bsc#1012628).
- drm/amd/display: Update correct DCN314 register header
  (bsc#1012628).
- drm/amd/display: Set minimum requirement for using PSR-SU on
  Rembrandt (bsc#1012628).
- drm/amd/display: Set minimum requirement for using PSR-SU on
  Phoenix (bsc#1012628).
- drm/ttm: never consider pinned BOs for eviction&swap
  (bsc#1012628).
- maple_tree: add __init and __exit to test module (bsc#1012628).
- maple_tree: fix 32 bit mas_next testing (bsc#1012628).
- drm/amd/display: Add FAMS validation before trying to use it
  (bsc#1012628).
- drm/amd/display: update extended blank for dcn314 onwards
  (bsc#1012628).
- drm/amd/display: Fix possible underflow for displays with
  large vblank (bsc#1012628).
- drm/amd/display: Prevent vtotal from being set to 0
  (bsc#1012628).
- ext4: add EXT4_MB_HINT_GOAL_ONLY test in
  ext4_mb_use_preallocated (bsc#1012628).
- ext4: mballoc: Remove useless setting of ac_criteria
  (bsc#1012628).
- ext4: fix rbtree traversal bug in ext4_mb_use_preallocated
  (bsc#1012628).
- phy: phy-mtk-dp: Fix an error code in probe() (bsc#1012628).
- phy: mediatek: hdmi: mt8195: fix prediv bad upper limit test
  (bsc#1012628).
- phy: qcom-snps-femto-v2: keep cfg_ahb_clk enabled during
  runtime suspend (bsc#1012628).
- phy: qcom-snps-femto-v2: properly enable ref clock
  (bsc#1012628).
- soundwire: qcom: update status correctly with mask
  (bsc#1012628).
- soundwire: amd: Fix a check for errors in probe() (bsc#1012628).
- media: tc358746: Address compiler warnings (bsc#1012628).
- media: staging: atomisp: select V4L2_FWNODE (bsc#1012628).
- media: amphion: Fix firmware path to match linux-firmware
  (bsc#1012628).
- media: mtk-jpeg: move data/code inside CONFIG_OF blocks
  (bsc#1012628).
- media: mtk_jpeg_core: avoid unused-variable warning
  (bsc#1012628).
- i40e: Fix an NULL vs IS_ERR() bug for debugfs_create_dir()
  (bsc#1012628).
- iavf: fix potential deadlock on allocation failure
  (bsc#1012628).
- iavf: check for removal state before IAVF_FLAG_PF_COMMS_FAILED
  (bsc#1012628).
- net: phy: marvell10g: fix 88x3310 power up (bsc#1012628).
- net: hns3: fix the imp capability bit cannot exceed 32 bits
  issue (bsc#1012628).
- net: hns3: fix wrong tc bandwidth weight data issue
  (bsc#1012628).
- net: hns3: fix wrong bw weight of disabled tc issue
  (bsc#1012628).
- vxlan: calculate correct header length for GPE (bsc#1012628).
- vxlan: generalize vxlan_parse_gpe_hdr and remove unused args
  (bsc#1012628).
- vxlan: fix GRO with VXLAN-GPE (bsc#1012628).
- phy: hisilicon: Fix an out of bounds check in
  hisi_inno_phy_probe() (bsc#1012628).
- atheros: fix return value check in atl1_tso() (bsc#1012628).
- ethernet: atheros: fix return value check in atl1e_tso_csum()
  (bsc#1012628).
- ipv6 addrconf: fix bug where deleting a mngtmpaddr can create
  a new temporary address (bsc#1012628).
- net: fec: avoid tx queue timeout when XDP is enabled
  (bsc#1012628).
- tcp: Reduce chance of collisions in inet6_hashfn()
  (bsc#1012628).
- ice: Fix memory management in ice_ethtool_fdir.c (bsc#1012628).
- bonding: reset bond's flags when down link is P2P device
  (bsc#1012628).
- team: reset team's flags when down link is P2P device
  (bsc#1012628).
- octeontx2-af: Fix hash extraction enable configuration
  (bsc#1012628).
- net: stmmac: Apply redundant write work around on 4.xx too
  (bsc#1012628).
- platform/x86: msi-laptop: Fix rfkill out-of-sync on MSI Wind
  U100 (bsc#1012628).
- x86/traps: Fix load_unaligned_zeropad() handling for shared
  TDX memory (bsc#1012628).
- macvlan: add forgotten nla_policy for IFLA_MACVLAN_BC_CUTOFF
  (bsc#1012628).
- igc: Fix Kernel Panic during ndo_tx_timeout callback
  (bsc#1012628).
- netfilter: nft_set_rbtree: fix overlap expiration walk
  (bsc#1012628).
- netfilter: nf_tables: skip immediate deactivate in
  _PREPARE_ERROR (bsc#1012628).
- netfilter: nf_tables: disallow rule addition to bound chain
  via NFTA_RULE_CHAIN_ID (bsc#1012628).
- mm: suppress mm fault logging if fatal signal already pending
  (bsc#1012628).
- tools: ynl-gen: fix enum index in
  _decode_enum(..) (bsc#1012628).
- net: fec: tx processing does not call XDP APIs if budget is 0
  (bsc#1012628).
- net/sched: mqprio: Add length check for
  TCA_MQPRIO_{MAX/MIN}_RATE64 (bsc#1012628).
- benet: fix return value check in be_lancer_xmit_workarounds()
  (bsc#1012628).
- tipc: check return value of pskb_trim() (bsc#1012628).
- tipc: stop tipc crypto on failure in tipc_node_create
  (bsc#1012628).
- fs/9p: Fix a datatype used with V9FS_DIRECT_IO (bsc#1012628).
- RDMA/mlx4: Make check for invalid flags stricter (bsc#1012628).
- drm/msm/mdss: correct UBWC programming for SM8550 (bsc#1012628).
- drm/msm/dpu: add missing flush and fetch bits for DMA4/DMA5
  planes (bsc#1012628).
- drm/msm/dpu: drop enum dpu_core_perf_data_bus_id (bsc#1012628).
- drm/msm/dsi: Drop unused regulators from QCM2290 14nm DSI PHY
  config (bsc#1012628).
- drm/msm/adreno: Fix snapshot BINDLESS_DATA size (bsc#1012628).
- RDMA/irdma: Add missing read barriers (bsc#1012628).
- RDMA/irdma: Fix data race on CQP completion stats (bsc#1012628).
- RDMA/irdma: Fix data race on CQP request done (bsc#1012628).
- RDMA/core: Update CMA destination address on rdma_resolve_addr
  (bsc#1012628).
- RDMA/mthca: Fix crash when polling CQ for shared QPs
  (bsc#1012628).
- RDMA/bnxt_re: Prevent handling any completions after qp destroy
  (bsc#1012628).
- RDMA/bnxt_re: Enhance the existing functions that wait for FW
  responses (bsc#1012628).
- RDMA/bnxt_re: Avoid the command wait if firmware is inactive
  (bsc#1012628).
- RDMA/bnxt_re: use shadow qd while posting non blocking rcfw
  command (bsc#1012628).
- RDMA/bnxt_re: Simplify the function that sends the FW commands
  (bsc#1012628).
- RDMA/bnxt_re: add helper function __poll_for_resp (bsc#1012628).
- RDMA/bnxt_re: Fix hang during driver unload (bsc#1012628).
- drm/msm: Fix IS_ERR_OR_NULL() vs NULL check in
  a5xx_submit_in_rb() (bsc#1012628).
- drm/msm: Fix hw_fence error path cleanup (bsc#1012628).
- cxl/acpi: Fix a use-after-free in cxl_parse_cfmws()
  (bsc#1012628).
- cxl/acpi: Return 'rc' instead of '0' in cxl_parse_cfmws()
  (bsc#1012628).
- ASoC: fsl_spdif: Silence output on stop (bsc#1012628).
- block: Fix a source code comment in
  include/uapi/linux/blkzoned.h (bsc#1012628).
- smb3: do not set NTLMSSP_VERSION flag for negotiate not auth
  request (bsc#1012628).
- drm/i915: Fix an error handling path in igt_write_huge()
  (bsc#1012628).
- xenbus: check xen_domain in xenbus_probe_initcall (bsc#1012628).
- dm raid: fix missing reconfig_mutex unlock in raid_ctr()
  error paths (bsc#1012628).
- dm raid: clean up four equivalent goto tags in raid_ctr()
  (bsc#1012628).
- dm raid: protect md_stop() with 'reconfig_mutex' (bsc#1012628).
- drm/amd: Fix an error handling mistake in psp_sw_init()
  (bsc#1012628).
- drm/amd/display: Unlock on error path in
  dm_handle_mst_sideband_msg_ready_event() (bsc#1012628).
- RDMA/irdma: Fix op_type reporting in CQEs (bsc#1012628).
- RDMA/irdma: Report correct WC error (bsc#1012628).
- drm/msm: Disallow submit with fence id 0 (bsc#1012628).
- ublk: fail to start device if queue setup is interrupted
  (bsc#1012628).
- ublk: fail to recover device if queue setup is interrupted
  (bsc#1012628).
- ublk: return -EINTR if breaking from waiting for existed users
  in DEL_DEV (bsc#1012628).
- iommufd: IOMMUFD_DESTROY should not increase the refcount
  (bsc#1012628).
- tmpfs: fix Documentation of noswap and huge mount options
  (bsc#1012628).
- ata: pata_ns87415: mark ns87560_tf_read static (bsc#1012628).
- ring-buffer: Fix wrong stat of cpu_buffer->read (bsc#1012628).
- tracing: Fix warning in trace_buffered_event_disable()
  (bsc#1012628).
- Revert "usb: gadget: tegra-xudc: Fix error check in
  tegra_xudc_powerdomain_init()" (bsc#1012628).
- usb: gadget: call usb_gadget_check_config() to verify UDC
  capability (bsc#1012628).
- USB: gadget: Fix the memory leak in raw_gadget driver
  (bsc#1012628).
- usb: gadget: core: remove unbalanced mutex_unlock in
  usb_gadget_activate (bsc#1012628).
- KVM: Grab a reference to KVM for VM and vCPU stats file
  descriptors (bsc#1012628).
- KVM: VMX: Don't fudge CR0 and CR4 for restricted L2 guest
  (bsc#1012628).
- KVM: x86: Disallow KVM_SET_SREGS{2} if incoming CR0 is invalid
  (bsc#1012628).
- serial: qcom-geni: drop bogus runtime pm state update
  (bsc#1012628).
- tty: serial: sh-sci: Fix sleeping in atomic context
  (bsc#1012628).
- serial: 8250_dw: Preserve original value of DLF register
  (bsc#1012628).
- serial: sifive: Fix sifive_serial_console_setup() section
  (bsc#1012628).
- USB: serial: option: support Quectel EM060K_128 (bsc#1012628).
- USB: serial: option: add Quectel EC200A module support
  (bsc#1012628).
- USB: serial: simple: add Kaufmann RKS+CAN VCP (bsc#1012628).
- USB: serial: simple: sort driver entries (bsc#1012628).
- can: gs_usb: gs_can_close(): add missing set of CAN state to
  CAN_STATE_STOPPED (bsc#1012628).
- TIOCSTI: always enable for CAP_SYS_ADMIN (bsc#1012628).
- usb: typec: Set port->pd before adding device for typec_port
  (bsc#1012628).
- usb: typec: Iterate pds array when showing the pd list
  (bsc#1012628).
- usb: typec: Use sysfs_emit_at when concatenating the string
  (bsc#1012628).
- Revert "usb: dwc3: core: Enable AutoRetry feature in the
  controller" (bsc#1012628).
- usb: dwc3: pci: skip BYT GPIO lookup table for hardwired phy
  (bsc#1012628).
- usb: dwc3: don't reset device side if dwc3 was configured as
  host-only (bsc#1012628).
- usb: misc: ehset: fix wrong if condition (bsc#1012628).
- usb: ohci-at91: Fix the unhandle interrupt when resume
  (bsc#1012628).
- USB: quirks: add quirk for Focusrite Scarlett (bsc#1012628).
- usb: cdns3: fix incorrect calculation of ep_buf_size when more
  than one config (bsc#1012628).
- usb: xhci-mtk: set the dma max_seg_size (bsc#1012628).
- Revert "usb: xhci: tegra: Fix error check" (bsc#1012628).
- Documentation: security-bugs.rst: update preferences when
  dealing with the linux-distros group (bsc#1012628).
- Documentation: security-bugs.rst: clarify CVE handling
  (bsc#1012628).
- staging: r8712: Fix memory leak in _r8712_init_xmit_priv()
  (bsc#1012628).
- staging: ks7010: potential buffer overflow in
  ks_wlan_set_encode_ext() (bsc#1012628).
- tty: n_gsm: fix UAF in gsm_cleanup_mux (bsc#1012628).
- Revert "xhci: add quirk for host controllers that don't update
  endpoint DCS" (bsc#1012628).
- ALSA: hda/realtek: Support ASUS G713PV laptop (bsc#1012628).
- ALSA: hda/relatek: Enable Mute LED on HP 250 G8 (bsc#1012628).
- hwmon: (k10temp) Enable AMD3255 Proc to show negative
  temperature (bsc#1012628).
- hwmon: (nct7802) Fix for temp6 (PECI1) processed even if PECI1
  disabled (bsc#1012628).
- hwmon: (aquacomputer_d5next) Fix incorrect PWM value readout
  (bsc#1012628).
- hwmon: (pmbus_core) Fix pmbus_is_enabled() (bsc#1012628).
- hwmon: (pmbus_core) Fix NULL pointer dereference (bsc#1012628).
- hwmon: (pmbus_core) Fix Deadlock in pmbus_regulator_get_status
  (bsc#1012628).
- btrfs: zoned: do not enable async discard (bsc#1012628).
- btrfs: account block group tree when calculating global reserve
  size (bsc#1012628).
- btrfs: check if the transaction was aborted at
  btrfs_wait_for_commit() (bsc#1012628).
- btrfs: check for commit error at
  btrfs_attach_transaction_barrier() (bsc#1012628).
- x86/MCE/AMD: Decrement threshold_bank refcount when removing
  threshold blocks (bsc#1012628).
- x86/cpu: Enable STIBP on AMD if Automatic IBRS is enabled
  (bsc#1012628).
- file: always lock position for FMODE_ATOMIC_POS (bsc#1012628).
- nfsd: Remove incorrect check in nfsd4_validate_stateid
  (bsc#1012628).
- ksmbd: check if a mount point is crossed during path lookup
  (bsc#1012628).
- ACPI/IORT: Remove erroneous id_count check in
  iort_node_get_rmr_info() (bsc#1012628).
- tpm_tis: Explicitly check for error code (bsc#1012628).
- irq-bcm6345-l1: Do not assume a fixed block to cpu mapping
  (bsc#1012628).
- irqchip/gic-v4.1: Properly lock VPEs when doing a directLPI
  invalidation (bsc#1012628).
- locking/rtmutex: Fix task->pi_waiters integrity (bsc#1012628).
- proc/vmcore: fix signedness bug in read_from_oldmem()
  (bsc#1012628).
- xen: speed up grant-table reclaim (bsc#1012628).
- virtio-net: fix race between set queues and probe (bsc#1012628).
- net: ipa: only reset hashed tables when supported (bsc#1012628).
- net: dsa: qca8k: enable use_single_write for qca8xxx
  (bsc#1012628).
- net: dsa: qca8k: fix search_and_insert wrong handling of new
  rule (bsc#1012628).
- net: dsa: qca8k: fix broken search_and_del (bsc#1012628).
- net: dsa: qca8k: fix mdb add/del case with 0 VID (bsc#1012628).
- io_uring: gate iowait schedule on having pending requests
  (bsc#1012628).
- iommufd: Set end correctly when doing batch carry (bsc#1012628).
- selftests: mptcp: join: only check for ip6tables if needed
  (bsc#1012628).
- soundwire: fix enumeration completion (bsc#1012628).
- Revert "um: Use swap() to make code cleaner" (bsc#1012628).
- LoongArch: Fix return value underflow in exception path
  (bsc#1012628).
- LoongArch: BPF: Fix check condition to call lu32id in move_imm()
  (bsc#1012628).
- LoongArch: BPF: Enable bpf_probe_read{, str}() on LoongArch
  (bsc#1012628).
- 9p: fix ignored return value in v9fs_dir_release (bsc#1012628).
- fs/9p: remove unnecessary and overrestrictive check
  (bsc#1012628).
- fs/9p: fix typo in comparison logic for cache mode
  (bsc#1012628).
- fs/9p: fix type mismatch in file cache mode helper
  (bsc#1012628).
- fs/9p: remove unnecessary invalidate_inode_pages2 (bsc#1012628).
- s390/dasd: fix hanging device after quiesce/resume
  (bsc#1012628).
- s390/dasd: print copy pair message only for the correct error
  (bsc#1012628).
- mptcp: more accurate NL event generation (bsc#1012628).
- ASoC: wm8904: Fill the cache for WM8904_ADC_TEST_0 register
  (bsc#1012628).
- arm64/sme: Set new vector length before reallocating
  (bsc#1012628).
- PM: sleep: wakeirq: fix wake irq arming (bsc#1012628).
- thermal: of: fix double-free on unregistration (bsc#1012628).
- ceph: never send metrics if disable_send_metrics is set
  (bsc#1012628).
- drm/i915/dpt: Use shmem for dpt objects (bsc#1012628).
- dm cache policy smq: ensure IO doesn't prevent cleaner policy
  progress (bsc#1012628).
- rbd: make get_lock_owner_info() return a single locker or NULL
  (bsc#1012628).
- rbd: harden get_lock_owner_info() a bit (bsc#1012628).
- rbd: retrieve and check lock owner twice before blocklisting
  (bsc#1012628).
- mm: lock VMA in dup_anon_vma() before setting ->anon_vma
  (bsc#1012628).
- mm: fix memory ordering for mm_lock_seq and vm_lock_seq
  (bsc#1012628).
- mm/memory-failure: fix hardware poison check in
  unpoison_memory() (bsc#1012628).
- mm/mempolicy: Take VMA lock before replacing policy
  (bsc#1012628).
- dma-buf: keep the signaling time of merged fences v3
  (bsc#1012628).
- dma-buf: fix an error pointer vs NULL bug (bsc#1012628).
- commit c24ac79
* Tue Aug  1 2023 jslaby@suse.cz
- Refresh
  patches.suse/ALSA-usb-audio-Add-quirk-for-Microsoft-Modern-Wirele.patch.
  Update upstream status.
- commit cba3fa8
* Sun Jul 30 2023 mkubecek@suse.cz
- Update to 6.5-rc4
- refresh configs
- commit 2390421
* Sun Jul 30 2023 tiwai@suse.de
- Revert "drm/edid: Fix csync detailed mode parsing"
  (bsc#1213693).
- commit 8de9301
* Fri Jul 28 2023 tiwai@suse.de
- Update MHI and ath11k hibernation fix patches (bsc#1207948)
  Upstream updated / cleaned up the patch set slightly
- commit 5da2543
* Fri Jul 28 2023 msuchanek@suse.de
- kernel-binary.spec.in: Remove superfluous %%%% in Supplements
  Fixes: 02b7735e0caf ("rpm/kernel-binary.spec.in: Add Enhances and Supplements tags to in-tree KMPs")
- commit 264db74
* Thu Jul 27 2023 tiwai@suse.de
- wifi: rtw89: Fix loading of compressed firmware (bsc#1212808).
- commit 6cc40be
* Thu Jul 27 2023 tiwai@suse.de
- ASoC: SOF: intel: hda: Clean up link DMA for IPC3 during stop
  (bsc#1213583).
- commit e67f54f
* Thu Jul 27 2023 jslaby@suse.cz
- Linux 6.4.7 (bsc#1012628).
- io_uring: treat -EAGAIN for REQ_F_NOWAIT as final for io-wq
  (bsc#1012628).
- ALSA: hda/realtek - remove 3k pull low procedure (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Clevo NS70AU (bsc#1012628).
- ALSA: hda/realtek: Enable Mute LED on HP Laptop 15s-eq2xxx
  (bsc#1012628).
- maple_tree: set the node limit when creating a new root node
  (bsc#1012628).
- mm/mlock: fix vma iterator conversion of apply_vma_lock_flags()
  (bsc#1012628).
- maple_tree: fix node allocation testing on 32 bit (bsc#1012628).
- selftests/mm: mkdirty: fix incorrect position of #endif
  (bsc#1012628).
- keys: Fix linking a duplicate key to a keyring's assoc_array
  (bsc#1012628).
- prctl: move PR_GET_AUXV out of PR_MCE_KILL (bsc#1012628).
- perf probe: Add test for regression introduced by switch to
  die_get_decl_file() (bsc#1012628).
- perf probe: Read DWARF files from the correct CU (bsc#1012628).
- btrfs: fix iput() on error pointer after error during orphan
  cleanup (bsc#1012628).
- btrfs: fix warning when putting transaction with qgroups
  enabled after abort (bsc#1012628).
- fuse: revalidate: don't invalidate if interrupted (bsc#1012628).
- fuse: add feature flag for expire-only (bsc#1012628).
- fuse: Apply flags2 only when userspace set the FUSE_INIT_EXT
  (bsc#1012628).
- btrfs: raid56: always verify the P/Q contents for scrub
  (bsc#1012628).
- btrfs: set_page_extent_mapped after read_folio in
  btrfs_cont_expand (bsc#1012628).
- btrfs: fix double iput() on inode after an error during orphan
  cleanup (bsc#1012628).
- btrfs: zoned: fix memory leak after finding block group with
  super blocks (bsc#1012628).
- fuse: ioctl: translate ENOSYS in outarg (bsc#1012628).
- btrfs: fix race between balance and cancel/pause (bsc#1012628).
- selftests: tc: set timeout to 15 minutes (bsc#1012628).
- accel/qaic: Fix a leak in map_user_pages() (bsc#1012628).
- selftests: tc: add 'ct' action kconfig dep (bsc#1012628).
- regmap: Drop initial version of maximum transfer length fixes
  (bsc#1012628).
- s390/zcrypt: fix reply buffer calculations for CCA replies
  (bsc#1012628).
- regmap: Account for register length in SMBus I/O limits
  (bsc#1012628).
- ia64: mmap: Consider pgoff when searching for free mapping
  (bsc#1012628).
- arm64/fpsimd: Ensure SME storage is allocated after SVE VL
  changes (bsc#1012628).
- can: mcp251xfd: __mcp251xfd_chip_set_mode(): increase poll
  timeout (bsc#1012628).
- can: bcm: Fix UAF in bcm_proc_show() (bsc#1012628).
- can: gs_usb: gs_can_open(): improve error handling
  (bsc#1012628).
- can: gs_usb: fix time stamp counter initialization
  (bsc#1012628).
- selftests: tc: add ConnTrack procfs kconfig (bsc#1012628).
- accel/qaic: tighten bounds checking in encode_message()
  (bsc#1012628).
- accel/qaic: tighten bounds checking in decode_message()
  (bsc#1012628).
- accel/qaic: Add consistent integer overflow checks
  (bsc#1012628).
- dma-buf/dma-resv: Stop leaking on krealloc() failure
  (bsc#1012628).
- drm/amdgpu/vkms: relax timer deactivation by
  hrtimer_try_to_cancel (bsc#1012628).
- drm/amdgpu/pm: make gfxclock consistent for sienna cichlid
  (bsc#1012628).
- drm/amdgpu/pm: make mclk consistent for smu 13.0.7
  (bsc#1012628).
- drm/nouveau/disp: PIOR DP uses GPIO for HPD, not PMGR AUX
  interrupts (bsc#1012628).
- drm/nouveau/kms/nv50-: init hpd_irq_lock for PIOR DP
  (bsc#1012628).
- drm/nouveau/i2c: fix number of aux event slots (bsc#1012628).
- drm/client: Fix memory leak in drm_client_target_cloned
  (bsc#1012628).
- drm/client: Fix memory leak in drm_client_modeset_probe
  (bsc#1012628).
- drm/amd/display: only accept async flips for fast updates
  (bsc#1012628).
- drm/amd/display: Disable MPC split by default on special asic
  (bsc#1012628).
- drm/amd/display: check TG is non-null before checking if enabled
  (bsc#1012628).
- drm/amd/display: Keep PHY active for DP displays on DCN31
  (bsc#1012628).
- ASoC: fsl_sai: Disable bit clock with transmitter (bsc#1012628).
- ASoC: fsl_sai: Revert "ASoC: fsl_sai: Enable MCTL_MCLK_EN bit
  for master mode" (bsc#1012628).
- ASoC: tegra: Fix ADX byte map (bsc#1012628).
- ASoC: rt5640: Fix sleep in atomic context (bsc#1012628).
- ASoC: cs42l51: fix driver to properly autoload with automatic
  module loading (bsc#1012628).
- ASoC: codecs: wcd938x: fix missing clsh ctrl error handling
  (bsc#1012628).
- ASoC: cs35l45: Select REGMAP_IRQ (bsc#1012628).
- ASoC: codecs: wcd-mbhc-v2: fix resource leaks on component
  remove (bsc#1012628).
- ASoC: qdsp6: audioreach: fix topology probe deferral
  (bsc#1012628).
- ASoC: tegra: Fix AMX byte map (bsc#1012628).
- ASoC: codecs: wcd938x: fix resource leaks on component remove
  (bsc#1012628).
- ASoC: codecs: wcd938x: fix missing mbhc init error handling
  (bsc#1012628).
- ASoC: codecs: wcd934x: fix resource leaks on component remove
  (bsc#1012628).
- ASoC: codecs: wcd938x: fix codec initialisation race
  (bsc#1012628).
- ASoC: codecs: wcd938x: fix soundwire initialisation race
  (bsc#1012628).
- KVM: arm64: timers: Use CNTHCTL_EL2 when setting non-CNTKCTL_EL1
  bits (bsc#1012628).
- KVM: arm64: Correctly handle page aging notifiers for unaligned
  memslot (bsc#1012628).
- KVM: arm64: Disable preemption in kvm_arch_hardware_enable()
  (bsc#1012628).
- KVM: arm64: vgic-v4: Make the doorbell request robust w.r.t
  preemption (bsc#1012628).
- ext4: correct inline offset when handling xattrs in inode body
  (bsc#1012628).
- drm/radeon: Fix integer overflow in radeon_cs_parser_init
  (bsc#1012628).
- ALSA: emu10k1: roll up loops in DSP setup code for Audigy
  (bsc#1012628).
- quota: Properly disable quotas when add_dquot_ref() fails
  (bsc#1012628).
- quota: fix warning in dqgrab() (bsc#1012628).
- HID: add quirk for 03f0:464a HP Elite Presenter Mouse
  (bsc#1012628).
- ovl: check type and offset of struct vfsmount in ovl_entry
  (bsc#1012628).
- udf: Fix uninitialized array access for some pathnames
  (bsc#1012628).
- ALSA: hda/realtek: Add quirks for ROG ALLY CS35l41 audio
  (bsc#1012628).
- fs: jfs: Fix UBSAN: array-index-out-of-bounds in dbAllocDmapLev
  (bsc#1012628).
- MIPS: dec: prom: Address -Warray-bounds warning (bsc#1012628).
- FS: JFS: Fix null-ptr-deref Read in txBegin (bsc#1012628).
- FS: JFS: Check for read-only mounted filesystem in txBegin
  (bsc#1012628).
- md: fix data corruption for raid456 when reshape restart while
  grow up (bsc#1012628).
- md/raid10: prevent soft lockup while flush writes (bsc#1012628).
- scsi: sg: fix blktrace debugfs entries leakage (bsc#1012628).
- blk-mq: fix NULL dereference on q->elevator in
  blk_mq_elv_switch_none (bsc#1012628).
- posix-timers: Ensure timer ID search-loop limit is valid
  (bsc#1012628).
- btrfs: add xxhash to fast checksum implementations
  (bsc#1012628).
- btrfs: don't check PageError in __extent_writepage
  (bsc#1012628).
- btrfs: abort transaction at update_ref_for_cow() when ref
  count is zero (bsc#1012628).
- erofs: Fix detection of atomic context (bsc#1012628).
- ACPI: x86: Add skip i2c clients quirk for Nextbook Ares 8A
  (bsc#1012628).
- ACPI: button: Add lid disable DMI quirk for Nextbook Ares 8A
  (bsc#1012628).
- ACPI: x86: Add ACPI_QUIRK_UART1_SKIP for Lenovo Yoga Book
  yb1-x90f/l (bsc#1012628).
- ACPI: video: Add backlight=native DMI quirk for Apple iMac11,3
  (bsc#1012628).
- ACPI: video: Add backlight=native DMI quirk for Lenovo ThinkPad
  X131e (3371 AMD version) (bsc#1012628).
- ACPI: resource: Remove "Zen" specific match and quirks
  (bsc#1012628).
- arm64: set __exception_irq_entry with __irq_entry as a default
  (bsc#1012628).
- arm64: mm: fix VA-range sanity check (bsc#1012628).
- ACPI: video: Add backlight=native DMI quirk for Dell Studio 1569
  (bsc#1012628).
- rcu-tasks: Avoid pr_info() with spin lock in
  cblist_init_generic() (bsc#1012628).
- rcu: Mark additional concurrent load from ->cpu_no_qs.b.exp
  (bsc#1012628).
- tools/nolibc: ensure stack protector guard is never zero
  (bsc#1012628).
- sched/fair: Don't balance task to its current running CPU
  (bsc#1012628).
- wifi: ath11k: fix registration of 6Ghz-only phy without the
  full channel range (bsc#1012628).
- bpf: Print a warning only if writing to
  unprivileged_bpf_disabled (bsc#1012628).
- bpf: Address KCSAN report on bpf_lru_list (bsc#1012628).
- spi: cadence-quadspi: Add compatible for AMD Pensando Elba SoC
  (bsc#1012628).
- bpf: drop unnecessary user-triggerable WARN_ONCE in verifierl
  log (bsc#1012628).
- bpf: tcp: Avoid taking fast sock lock in iterator (bsc#1012628).
- wifi: rtw88: sdio: Check the HISR RX_REQUEST bit in
  rtw_sdio_rx_isr() (bsc#1012628).
- bpf: Silence a warning in btf_type_id_size() (bsc#1012628).
- devlink: make health report on unregistered instance warn just
  once (bsc#1012628).
- wifi: ath11k: add support default regdb while searching
  board-2.bin for WCN6855 (bsc#1012628).
- wifi: mac80211_hwsim: Fix possible NULL dereference
  (bsc#1012628).
- spi: dw: Add compatible for Intel Mount Evans SoC (bsc#1012628).
- wifi: ath12k: Avoid NULL pointer access during management
  transmit cleanup (bsc#1012628).
- wifi: ath11k: fix memory leak in WMI firmware stats
  (bsc#1012628).
- wifi: iwlwifi: mvm: fix potential array out of bounds access
  (bsc#1012628).
- net: ethernet: litex: add support for 64 bit stats
  (bsc#1012628).
- devlink: report devlink_port_type_warn source device
  (bsc#1012628).
- wifi: iwlwifi: mvm: Add NULL check before dereferencing the
  pointer (bsc#1012628).
- wifi: wext-core: Fix -Wstringop-overflow warning in
  ioctl_standard_iw_point() (bsc#1012628).
- wifi: iwlwifi: Add support for new PCI Id (bsc#1012628).
- wifi: iwlwifi: mvm: avoid baid size integer overflow
  (bsc#1012628).
- wifi: iwlwifi: pcie: add device id 51F1 for killer 1675
  (bsc#1012628).
- igb: Fix igb_down hung on surprise removal (bsc#1012628).
- net: hns3: fix strncpy() not using dest-buf length as length
  issue (bsc#1012628).
- ASoC: amd: acp: fix for invalid dai id handling in
  acp_get_byte_count() (bsc#1012628).
- ASoC: codecs: wcd938x: fix mbhc impedance loglevel
  (bsc#1012628).
- ASoC: codecs: wcd938x: fix dB range for HPHL and HPHR
  (bsc#1012628).
- ASoC: qcom: q6apm: do not close GPR port before closing graph
  (bsc#1012628).
- iov_iter: Mark copy_iovec_from_user() noclone (bsc#1012628).
- sched/fair: Use recent_used_cpu to test p->cpus_ptr
  (bsc#1012628).
- sched/psi: use kernfs polling functions for PSI trigger polling
  (bsc#1012628).
- pinctrl: renesas: rzv2m: Handle non-unique subnode names
  (bsc#1012628).
- pinctrl: renesas: rzg2l: Handle non-unique subnode names
  (bsc#1012628).
- spi: bcm63xx: fix max prepend length (bsc#1012628).
- fbdev: imxfb: warn about invalid left/right margin
  (bsc#1012628).
- fbdev: imxfb: Removed unneeded release_mem_region (bsc#1012628).
- perf build: Fix library not found error when using CSLIBS
  (bsc#1012628).
- btrfs: be a bit more careful when setting mirror_num_ret in
  btrfs_map_block (bsc#1012628).
- spi: s3c64xx: clear loopback bit after loopback test
  (bsc#1012628).
- kallsyms: strip LTO-only suffixes from promoted global functions
  (bsc#1012628).
- smb: client: fix missed ses refcounting (bsc#1012628).
- arm64: Fix HFGxTR_EL2 field naming (bsc#1012628).
- dsa: mv88e6xxx: Do a final check before timing out
  (bsc#1012628).
- net: ethernet: ti: cpsw_ale: Fix
  cpsw_ale_get_field()/cpsw_ale_set_field() (bsc#1012628).
- bridge: Add extack warning when enabling STP in netns
  (bsc#1012628).
- net: ethernet: mtk_eth_soc: handle probe deferral (bsc#1012628).
- gso: fix dodgy bit handling for GSO_UDP_L4 (bsc#1012628).
- iommu/sva: Fix signedness bug in iommu_sva_alloc_pasid()
  (bsc#1012628).
- cifs: fix mid leak during reconnection after timeout threshold
  (bsc#1012628).
- ice: Unregister netdev and devlink_port only once (bsc#1012628).
- ice: prevent NULL pointer deref during reload (bsc#1012628).
- ASoC: SOF: ipc3-dtrace: uninitialized data in
  dfsentry_trace_filter_write() (bsc#1012628).
- regulator: da9063: fix null pointer deref with partial DT config
  (bsc#1012628).
- net: sched: cls_matchall: Undo tcf_bind_filter in case of
  failure after mall_set_parms (bsc#1012628).
- net: sched: cls_u32: Undo tcf_bind_filter if
  u32_replace_hw_knode (bsc#1012628).
- net: sched: cls_u32: Undo refcount decrement in case update
  failed (bsc#1012628).
- net: sched: cls_bpf: Undo tcf_bind_filter in case of an error
  (bsc#1012628).
- net: dsa: microchip: correct KSZ8795 static MAC table access
  (bsc#1012628).
- drm/i915/perf: add sentinel to xehp_oa_b_counters (bsc#1012628).
- iavf: Fix use-after-free in free_netdev (bsc#1012628).
- iavf: Fix out-of-bounds when setting channels on remove
  (bsc#1012628).
- iavf: use internal state to free traffic IRQs (bsc#1012628).
- iavf: make functions static where possible (bsc#1012628).
- iavf: Wait for reset in callbacks which trigger it
  (bsc#1012628).
- iavf: fix a deadlock caused by rtnl and driver's lock circular
  dependencies (bsc#1012628).
- iavf: fix reset task race with iavf_remove() (bsc#1012628).
- security: keys: Modify mismatched function name (bsc#1012628).
- vrf: Fix lockdep splat in output path (bsc#1012628).
- octeontx2-pf: Dont allocate BPIDs for LBK interfaces
  (bsc#1012628).
- bpf: Fix subprog idx logic in check_max_stack_depth
  (bsc#1012628).
- bpf: Repeat check_max_stack_depth for async callbacks
  (bsc#1012628).
- bpf, arm64: Fix BTI type used for freplace attached functions
  (bsc#1012628).
- igc: Avoid transmit queue timeout for XDP (bsc#1012628).
- igc: Prevent garbled TX queue with XDP ZEROCOPY (bsc#1012628).
- net: ipv4: use consistent txhash in TIME_WAIT and SYN_RECV
  (bsc#1012628).
- tcp: annotate data-races around tcp_rsk(req)->txhash
  (bsc#1012628).
- tcp: annotate data-races around tcp_rsk(req)->ts_recent
  (bsc#1012628).
- net: ipv4: Use kfree_sensitive instead of kfree (bsc#1012628).
- net:ipv6: check return value of pskb_trim() (bsc#1012628).
- Revert "tcp: avoid the lookup process failing to get sk in
  ehash table" (bsc#1012628).
- net: ethernet: mtk_eth_soc: always mtk_get_ib1_pkt_type
  (bsc#1012628).
- fbdev: au1200fb: Fix missing IRQ check in au1200fb_drv_probe
  (bsc#1012628).
- llc: Don't drop packet from non-root netns (bsc#1012628).
- ALSA: hda/realtek: Fix generic fixup definition for cs35l41 amp
  (bsc#1012628).
- netfilter: nf_tables: fix spurious set element insertion failure
  (bsc#1012628).
- netfilter: nf_tables: can't schedule in nft_chain_validate
  (bsc#1012628).
- netfilter: nft_set_pipapo: fix improper element removal
  (bsc#1012628).
- netfilter: nf_tables: skip bound chain in netns release path
  (bsc#1012628).
- netfilter: nf_tables: skip bound chain on rule flush
  (bsc#1012628).
- Bluetooth: use RCU for hci_conn_params and iterate safely in
  hci_sync (bsc#1012628).
- Bluetooth: hci_event: call disconnect callback before deleting
  conn (bsc#1012628).
- Bluetooth: ISO: fix iso_conn related locking and validity issues
  (bsc#1012628).
- Bluetooth: hci_sync: Avoid use-after-free in dbg for
  hci_remove_adv_monitor() (bsc#1012628).
- Bluetooth: hci_conn: return ERR_PTR instead of NULL when there
  is no link (bsc#1012628).
- Bluetooth: SCO: fix sco_conn related locking and validity issues
  (bsc#1012628).
- Bluetooth: btusb: Fix bluetooth on Intel Macbook 2014
  (bsc#1012628).
- tcp: annotate data-races around tp->tcp_tx_delay (bsc#1012628).
- tcp: annotate data-races around tp->tsoffset (bsc#1012628).
- tcp: annotate data-races around tp->keepalive_time
  (bsc#1012628).
- tcp: annotate data-races around tp->keepalive_intvl
  (bsc#1012628).
- tcp: annotate data-races around tp->keepalive_probes
  (bsc#1012628).
- tcp: annotate data-races around icsk->icsk_syn_retries
  (bsc#1012628).
- tcp: annotate data-races around tp->linger2 (bsc#1012628).
- tcp: annotate data-races around rskq_defer_accept (bsc#1012628).
- tcp: annotate data-races around tp->notsent_lowat (bsc#1012628).
- tcp: annotate data-races around icsk->icsk_user_timeout
  (bsc#1012628).
- tcp: annotate data-races around fastopenq.max_qlen
  (bsc#1012628).
- net: phy: prevent stale pointer dereference in phy_init()
  (bsc#1012628).
- jbd2: recheck chechpointing non-dirty buffer (bsc#1012628).
- kbuild: rust: avoid creating temporary files (bsc#1012628).
- tracing/histograms: Return an error if we fail to add histogram
  to hist_vars list (bsc#1012628).
- drm/ttm: fix bulk_move corruption when adding a entry
  (bsc#1012628).
- spi: dw: Remove misleading comment for Mount Evans SoC
  (bsc#1012628).
- scsi/sg: don't grab scsi host module reference (bsc#1012628).
- scsi: sg: Fix checking return value of blk_get_queue()
  (bsc#1012628).
- drm/amd/display: Clean up errors & warnings in amdgpu_dm.c
  (bsc#1012628).
- drm/amd/display: Add polling method to handle MST reply packet
  (bsc#1012628).
- Revert "drm/amd/display: edp do not add non-edid timings"
  (bsc#1012628).
- commit 90999e4
* Wed Jul 26 2023 tiwai@suse.de
- tpm/tpm_tis: Disable interrupts for TUXEDO InfinityBook S
  15/17 Gen7 (bsc#1213645).
- commit 74a8144
* Wed Jul 26 2023 tiwai@suse.de
- bus: mhi: host: add destroy_device argument to mhi_power_down()
  (bsc#1207948).
- commit fad4ac5
* Wed Jul 26 2023 tiwai@suse.de
- wifi: ath11k: remove MHI LOOPBACK channels (bsc#1207948).
- wifi: ath11k: handle thermal device registeration together
  with MAC (bsc#1207948).
- wifi: ath11k: handle irq enable/disable in several code path
  (bsc#1207948).
- wifi: ath11k: add support for suspend in power down state
  (bsc#1207948).
- bus: mhi: add new interfaces to handle MHI channels directly
  (bsc#1207948).
- wifi: ath11k: remove MHI LOOPBACK channels (bsc#1207948).
- wifi: ath11k: handle thermal device registeration together
  with MAC (bsc#1207948).
- wifi: ath11k: handle irq enable/disable in several code path
  (bsc#1207948).
- wifi: ath11k: add support for suspend in power down state
  (bsc#1207948).
- bus: mhi: add new interfaces to handle MHI channels directly
  (bsc#1207948).
- commit 5408d73
* Tue Jul 25 2023 tiwai@suse.de
- ALSA: usb-audio: Add quirk for Microsoft Modern Wireless Headset
  (bsc#1207129).
- commit 24fe873
* Tue Jul 25 2023 jslaby@suse.cz
- Update
  patches.kernel.org/6.4.6-002-x86-cpu-amd-Add-a-Zenbleed-fix.patch
  (bsc#1012628 bsc#1213286 CVE-2023-20593).
  Add references.
- commit 55520bc
* Tue Jul 25 2023 jslaby@suse.cz
- Linux 6.4.6 (bsc#1012628).
- x86/cpu/amd: Add a Zenbleed fix (bsc#1012628).
- x86/cpu/amd: Move the errata checking functionality up
  (bsc#1012628).
- commit cd14b53
* Mon Jul 24 2023 mkubecek@suse.cz
- Delete patches.suse/Revert-io_uring-Adjust-mapping-wrt-architecture-alia.patch.
  As confirmed by Jiří Slabý, the issue should be fixed by mainline commit
  32832a407a71 ("io_uring: Fix io_uring mmap() by using architecture-provided
  get_unmapped_area()") present in 6.5-rc3 so that the revert is no longer
  needed.
- commit c2a47b2
* Mon Jul 24 2023 jslaby@suse.cz
- Update config files. (bsc#1213592)
  Disable old unmaintained serial drivers
- commit 6254189
* Mon Jul 24 2023 jslaby@suse.cz
- io_uring: Fix io_uring mmap() by using architecture-provided
  get_unmapped_area() (bsc#1212773).
- Delete
  patches.suse/Revert-io_uring-Adjust-mapping-wrt-architecture-alia.patch.
  Replace the temporary fix by an upstream fix.
- commit 2f220f8
* Mon Jul 24 2023 jslaby@suse.cz
- Refresh
  patches.suse/of-Preserve-of-display-device-name-for-compatibility.patch.
  Update upstream status.
- commit 8817ac3
* Mon Jul 24 2023 jslaby@suse.cz
- Linux 6.4.5 (bsc#1012628).
- security/integrity: fix pointer to ESL data and its size on
  pseries (bsc#1012628).
- HID: input: fix mapping for camera access keys (bsc#1012628).
- HID: amd_sfh: Rename the float32 variable (bsc#1012628).
- HID: amd_sfh: Fix for shift-out-of-bounds (bsc#1012628).
- net: lan743x: Don't sleep in atomic context (bsc#1012628).
- net: lan743x: select FIXED_PHY (bsc#1012628).
- ksmbd: add missing compound request handing in some commands
  (bsc#1012628).
- ksmbd: fix out of bounds read in smb2_sess_setup (bsc#1012628).
- drm/panel: simple: Add connector_type for innolux_at043tn24
  (bsc#1012628).
- drm: bridge: dw_hdmi: fix connector access for scdc
  (bsc#1012628).
- drm/bridge: ti-sn65dsi86: Fix auxiliary bus lifetime
  (bsc#1012628).
- swiotlb: always set the number of areas before allocating the
  pool (bsc#1012628).
- swiotlb: reduce the number of areas to match actual memory
  pool size (bsc#1012628).
- drm/panel: simple: Add Powertip PH800480T013 drm_display_mode
  flags (bsc#1012628).
- xen/virtio: Fix NULL deref when a bridge of PCI root bus has
  no parent (bsc#1012628).
- netfilter: nf_tables: report use refcount overflow
  (bsc#1012628).
- netfilter: conntrack: don't fold port numbers into addresses
  before hashing (bsc#1012628).
- ice: Fix max_rate check while configuring TX rate limits
  (bsc#1012628).
- ice: Fix tx queue rate limit when TCs are configured
  (bsc#1012628).
- igc: Add condition for qbv_config_change_errors counter
  (bsc#1012628).
- igc: Remove delay during TX ring configuration (bsc#1012628).
- igc: Add igc_xdp_buff wrapper for xdp_buff in driver
  (bsc#1012628).
- igc: Add XDP hints kfuncs for RX hash (bsc#1012628).
- igc: Fix TX Hang issue when QBV Gate is closed (bsc#1012628).
- net/mlx5e: fix double free in mlx5e_destroy_flow_table
  (bsc#1012628).
- net/mlx5e: fix memory leak in mlx5e_fs_tt_redirect_any_create
  (bsc#1012628).
- net/mlx5e: fix memory leak in mlx5e_ptp_open (bsc#1012628).
- net/mlx5e: RX, Fix flush and close release flow of regular rq
  for legacy rq (bsc#1012628).
- net/mlx5: Register a unique thermal zone per device
  (bsc#1012628).
- net/mlx5e: Check for NOT_READY flag state after locking
  (bsc#1012628).
- net/mlx5e: TC, CT: Offload ct clear only once (bsc#1012628).
- net/mlx5: Query hca_cap_2 only when supported (bsc#1012628).
- net/mlx5e: RX, Fix page_pool page fragment tracking for XDP
  (bsc#1012628).
- igc: set TP bit in 'supported' and 'advertising' fields of
  ethtool_link_ksettings (bsc#1012628).
- igc: Include the length/type field and VLAN tag in queueMaxSDU
  (bsc#1012628).
- igc: Handle PPS start time programming for past time values
  (bsc#1012628).
- blk-crypto: use dynamic lock class for blk_crypto_profile::lock
  (bsc#1012628).
- scsi: qla2xxx: Fix error code in qla2x00_start_sp()
  (bsc#1012628).
- scsi: ufs: ufs-mediatek: Add dependency for RESET_CONTROLLER
  (bsc#1012628).
- bpf: Fix max stack depth check for async callbacks
  (bsc#1012628).
- net: mvneta: fix txq_map in case of txq_number==1 (bsc#1012628).
- net: dsa: felix: make vsc9959_tas_guard_bands_update() visible
  to ocelot->ops (bsc#1012628).
- net: mscc: ocelot: fix oversize frame dropping for preemptible
  TCs (bsc#1012628).
- net/sched: cls_fw: Fix improper refcount update leads to
  use-after-free (bsc#1012628).
- gve: Set default duplex configuration to full (bsc#1012628).
- drm/fbdev-dma: Fix documented default preferred_bpp value
  (bsc#1012628).
- octeontx2-af: Promisc enable/disable through mbox (bsc#1012628).
- octeontx2-af: Move validation of ptp pointer before its usage
  (bsc#1012628).
- ionic: remove WARN_ON to prevent panic_on_warn (bsc#1012628).
- udp6: add a missing call into udp_fail_queue_rcv_skb tracepoint
  (bsc#1012628).
- net: bgmac: postpone turning IRQs off to avoid SoC hangs
  (bsc#1012628).
- net: prevent skb corruption on frag list segmentation
  (bsc#1012628).
- s390/ism: Fix locking for forwarding of IRQs and events to
  clients (bsc#1012628).
- s390/ism: Fix and simplify add()/remove() callback handling
  (bsc#1012628).
- s390/ism: Do not unregister clients with registered DMBs
  (bsc#1012628).
- icmp6: Fix null-ptr-deref of ip6_null_entry->rt6i_idev in
  icmp6_dev() (bsc#1012628).
- udp6: fix udp6_ehashfn() typo (bsc#1012628).
- ntb: idt: Fix error handling in idt_pci_driver_init()
  (bsc#1012628).
- NTB: amd: Fix error handling in amd_ntb_pci_driver_init()
  (bsc#1012628).
- ntb: intel: Fix error handling in intel_ntb_pci_driver_init()
  (bsc#1012628).
- NTB: ntb_transport: fix possible memory leak while
  device_register() fails (bsc#1012628).
- NTB: ntb_tool: Add check for devm_kcalloc (bsc#1012628).
- ipv6/addrconf: fix a potential refcount underflow for idev
  (bsc#1012628).
- HID: hyperv: avoid struct memcpy overrun warning (bsc#1012628).
- net: dsa: qca8k: Add check for skb_copy (bsc#1012628).
- platform/x86: wmi: Break possible infinite loop when parsing
  GUID (bsc#1012628).
- net/sched: taprio: replace tc_taprio_qopt_offload :: enable
  with a "cmd" enum (bsc#1012628).
- igc: Rename qbv_enable to taprio_offload_enable (bsc#1012628).
- igc: Do not enable taprio offload for invalid arguments
  (bsc#1012628).
- igc: Handle already enabled taprio offload for basetime 0
  (bsc#1012628).
- kernel/trace: Fix cleanup logic of enable_trace_eprobe
  (bsc#1012628).
- fprobe: add unlock to match a succeeded
  ftrace_test_recursion_trylock (bsc#1012628).
- igc: No strict mode in pure launchtime/CBS offload
  (bsc#1012628).
- igc: Fix launchtime before start of cycle (bsc#1012628).
- igc: Fix inserting of empty frame for launchtime (bsc#1012628).
- nvme: fix the NVME_ID_NS_NVM_STS_MASK definition (bsc#1012628).
- openrisc: Union fpcsr and oldmask in sigcontext to unbreak
  userspace ABI (bsc#1012628).
- riscv, bpf: Fix inconsistent JIT image generation (bsc#1012628).
- net: fec: remove useless fec_enet_reset_skb() (bsc#1012628).
- net: fec: remove last_bdp from fec_enet_txq_xmit_frame()
  (bsc#1012628).
- net: fec: recycle pages for transmitted XDP frames
  (bsc#1012628).
- net: fec: increase the size of tx ring and update
  tx_wake_threshold (bsc#1012628).
- drm/i915: Don't preserve dpll_hw_state for slave crtc in
  Bigjoiner (bsc#1012628).
- drm/i915: Fix one wrong caching mode enum usage (bsc#1012628).
- net: dsa: Removed unneeded of_node_put in felix_parse_ports_node
  (bsc#1012628).
- octeontx2-pf: Add additional check for MCAM rules (bsc#1012628).
- erofs: avoid useless loops in z_erofs_pcluster_readmore()
  when reading beyond EOF (bsc#1012628).
- erofs: avoid infinite loop in z_erofs_do_read_page() when
  reading beyond EOF (bsc#1012628).
- erofs: fix fsdax unavailability for chunk-based regular files
  (bsc#1012628).
- wifi: airo: avoid uninitialized warning in airo_get_rate()
  (bsc#1012628).
- bpf: cpumap: Fix memory leak in cpu_map_update_elem
  (bsc#1012628).
- xdp: use trusted arguments in XDP hints kfuncs (bsc#1012628).
- net/sched: flower: Ensure both minimum and maximum ports are
  specified (bsc#1012628).
- riscv: mm: fix truncation warning on RV32 (bsc#1012628).
- drm/nouveau/disp: fix HDMI on gt215+ (bsc#1012628).
- drm/nouveau/disp/g94: enable HDMI (bsc#1012628).
- netdevsim: fix uninitialized data in
  nsim_dev_trap_fa_cookie_write() (bsc#1012628).
- drm/nouveau/acr: Abort loading ACR if no firmware was found
  (bsc#1012628).
- drm/nouveau: bring back blit subchannel for pre nv50 GPUs
  (bsc#1012628).
- net/sched: make psched_mtu() RTNL-less safe (bsc#1012628).
- net: txgbe: fix eeprom calculation error (bsc#1012628).
- wifi: rtw89: debug: fix error code in
  rtw89_debug_priv_send_h2c_set() (bsc#1012628).
- net/sched: sch_qfq: reintroduce lmax bound check for MTU
  (bsc#1012628).
- net/sched: sch_qfq: account for stab overhead in qfq_enqueue
  (bsc#1012628).
- nvme-pci: fix DMA direction of unmapping integrity data
  (bsc#1012628).
- smb: client: improve DFS mount check (bsc#1012628).
- cifs: fix session state check in smb2_find_smb_ses
  (bsc#1012628).
- smb: client: fix parsing of source mount option (bsc#1012628).
- drm/client: Send hotplug event after registering a client
  (bsc#1012628).
- f2fs: don't reset unchangable mount option in f2fs_remount()
  (bsc#1012628).
- f2fs: fix deadlock in i_xattr_sem and inode page lock
  (bsc#1012628).
- kbuild: make modules_install copy modules.builtin(.modinfo)
  (bsc#1012628).
- tpm: Do not remap from ACPI resources again for Pluton TPM
  (bsc#1012628).
- tpm: tpm_vtpm_proxy: fix a race condition in /dev/vtpmx creation
  (bsc#1012628).
- tpm: tpm_tis: Disable interrupts *only* for AEON UPX-i11
  (bsc#1012628).
- tpm: tis_i2c: Limit read bursts to I2C_SMBUS_BLOCK_MAX (32)
  bytes (bsc#1012628).
- tpm/tpm_tis: Disable interrupts for Framework Laptop Intel
  12th gen (bsc#1012628).
- tpm: tis_i2c: Limit write bursts to I2C_SMBUS_BLOCK_MAX (32)
  bytes (bsc#1012628).
- tpm: return false from tpm_amd_is_rng_defective on non-x86
  platforms (bsc#1012628).
- tpm/tpm_tis: Disable interrupts for Framework Laptop Intel
  13th gen (bsc#1012628).
- tpm,tpm_tis: Disable interrupts after 1000 unhandled IRQs
  (bsc#1012628).
- tpm/tpm_tis: Disable interrupts for Lenovo L590 devices
  (bsc#1012628).
- mtd: rawnand: meson: fix unaligned DMA buffers handling
  (bsc#1012628).
- net: bcmgenet: Ensure MDIO unregistration has clocks enabled
  (bsc#1012628).
- net: phy: dp83td510: fix kernel stall during netboot in
  DP83TD510E PHY driver (bsc#1012628).
- kasan: add kasan_tag_mismatch prototype (bsc#1012628).
- kasan: use internal prototypes matching gcc-13 builtins
  (bsc#1012628).
- kasan, slub: fix HW_TAGS zeroing with slub_debug (bsc#1012628).
- kasan: fix type cast in memory_is_poisoned_n (bsc#1012628).
- tracing/user_events: Fix incorrect return value for writing
  operation when events are disabled (bsc#1012628).
- powerpc: Fail build if using recordmcount with binutils v2.37
  (bsc#1012628).
- misc: fastrpc: Create fastrpc scalar with correct buffer count
  (bsc#1012628).
- powerpc/security: Fix Speculation_Store_Bypass reporting on
  Power10 (bsc#1012628).
- powerpc/64s: Fix native_hpte_remove() to be irq-safe
  (bsc#1012628).
- MIPS: cpu-features: Use boot_cpu_type for CPU type based
  features (bsc#1012628).
- MIPS: Loongson: Fix cpu_probe_loongson() again (bsc#1012628).
- MIPS: Loongson: Fix build error when make modules_install
  (bsc#1012628).
- MIPS: KVM: Fix NULL pointer dereference (bsc#1012628).
- ext4: Fix reusing stale buffer heads from last failed mounting
  (bsc#1012628).
- ext4: fix wrong unit use in ext4_mb_clear_bb (bsc#1012628).
- ext4: get block from bh in ext4_free_blocks for fast commit
  replay (bsc#1012628).
- ext4: fix wrong unit use in ext4_mb_new_blocks (bsc#1012628).
- ext4: avoid updating the superblock on a r/o mount if not needed
  (bsc#1012628).
- ext4: fix to check return value of freeze_bdev() in
  ext4_shutdown() (bsc#1012628).
- ext4: turn quotas off if mount failed after enabling quotas
  (bsc#1012628).
- ext4: only update i_reserved_data_blocks on successful block
  allocation (bsc#1012628).
- fs: dlm: revert check required context while close
  (bsc#1012628).
- mm/mmap: Fix error return in do_vmi_align_munmap()
  (bsc#1012628).
- soc: qcom: mdt_loader: Fix unconditional call to
  scm_pas_mem_setup (bsc#1012628).
- ext2/dax: Fix ext2_setsize when len is page aligned
  (bsc#1012628).
- jfs: jfs_dmap: Validate db_l2nbperpage while mounting
  (bsc#1012628).
- arm64: dts: mt7986: use size of reserved partition for bl2
  (bsc#1012628).
- arm64: dts: ti: k3-j721s2: Fix wkup pinmux range (bsc#1012628).
- hwrng: imx-rngc - fix the timeout for init and self check
  (bsc#1012628).
- dm integrity: reduce vmalloc space footprint on 32-bit
  architectures (bsc#1012628).
- scsi: mpi3mr: Propagate sense data for admin queue SCSI I/O
  (bsc#1012628).
- s390/zcrypt: do not retry administrative requests (bsc#1012628).
- PCI/PM: Avoid putting EloPOS E2/S2/H2 PCIe Ports in D3cold
  (bsc#1012628).
- PCI: Release resource invalidated by coalescing (bsc#1012628).
- PCI: Add function 1 DMA alias quirk for Marvell 88SE9235
  (bsc#1012628).
- PCI: qcom: Disable write access to read only registers for IP
  v2.3.3 (bsc#1012628).
- PCI: epf-test: Fix DMA transfer completion initialization
  (bsc#1012628).
- PCI: epf-test: Fix DMA transfer completion detection
  (bsc#1012628).
- PCI: rockchip: Assert PCI Configuration Enable bit after probe
  (bsc#1012628).
- PCI: rockchip: Write PCI Device ID to correct register
  (bsc#1012628).
- PCI: rockchip: Add poll and timeout to wait for PHY PLLs to
  be locked (bsc#1012628).
- PCI: rockchip: Fix legacy IRQ generation for RK3399 PCIe
  endpoint core (bsc#1012628).
- PCI: rockchip: Use u32 variable to access 32-bit registers
  (bsc#1012628).
- PCI: rockchip: Set address alignment for endpoint mode
  (bsc#1012628).
- misc: pci_endpoint_test: Free IRQs before removing the device
  (bsc#1012628).
- misc: pci_endpoint_test: Re-init completion for every test
  (bsc#1012628).
- mfd: pm8008: Fix module autoloading (bsc#1012628).
- md/raid0: add discard support for the 'original' layout
  (bsc#1012628).
- fs: dlm: return positive pid value for F_GETLK (bsc#1012628).
- fs: dlm: fix cleanup pending ops when interrupted (bsc#1012628).
- fs: dlm: interrupt posix locks only when process is killed
  (bsc#1012628).
- fs: dlm: make F_SETLK use unkillable wait_event (bsc#1012628).
- fs: dlm: fix mismatch of plock results from userspace
  (bsc#1012628).
- fs: dlm: clear pending bit when queue was empty (bsc#1012628).
- fs: dlm: fix missing pending to false (bsc#1012628).
- scsi: lpfc: Fix double free in lpfc_cmpl_els_logo_acc() caused
  by lpfc_nlp_not_used() (bsc#1012628).
- drm/atomic: Allow vblank-enabled + self-refresh "disable"
  (bsc#1012628).
- drm/rockchip: vop: Leave vblank enabled in self-refresh
  (bsc#1012628).
- drm/dp_mst: Clear MSG_RDY flag before sending new message
  (bsc#1012628).
- drm/amd/display: Limit DCN32 8 channel or less parts to DPM1
  for FPO (bsc#1012628).
- drm/amd/display: Fix in secure display context creation
  (bsc#1012628).
- drm/amd/display: fix seamless odm transitions (bsc#1012628).
- drm/amd/display: edp do not add non-edid timings (bsc#1012628).
- drm/amd/display: Remove Phantom Pipe Check When Calculating
  K1 and K2 (bsc#1012628).
- drm/amd/display: Correct `DMUB_FW_VERSION` macro (bsc#1012628).
- drm/amd/display: Add monitor specific edid quirk (bsc#1012628).
- drm/amdgpu: avoid restore process run into dead loop
  (bsc#1012628).
- drm/amd/pm: fix smu i2c data read risk (bsc#1012628).
- drm/ttm: Don't leak a resource on eviction error (bsc#1012628).
- drm/ttm: Don't leak a resource on swapout move error
  (bsc#1012628).
- serial: atmel: don't enable IRQs prematurely (bsc#1012628).
- tty: serial: samsung_tty: Fix a memory leak in
  s3c24xx_serial_getclk() in case of error (bsc#1012628).
- tty: serial: samsung_tty: Fix a memory leak in
  s3c24xx_serial_getclk() when iterating clk (bsc#1012628).
- tty: serial: imx: fix rs485 rx after tx (bsc#1012628).
- tty: fix hang on tty device with no_room set (bsc#1012628).
- firmware: stratix10-svc: Fix a potential resource leak in
  svc_create_memory_pool() (bsc#1012628).
- libceph: harden msgr2.1 frame segment length checks
  (bsc#1012628).
- ceph: add a dedicated private data for netfs rreq (bsc#1012628).
- ceph: fix blindly expanding the readahead windows (bsc#1012628).
- ceph: don't let check_caps skip sending responses for revoke
  msgs (bsc#1012628).
- nfp: clean mc addresses in application firmware when closing
  port (bsc#1012628).
- arm64: errata: Mitigate Ampere1 erratum AC03_CPU_38 at stage-2
  (bsc#1012628).
- xhci: Fix resume issue of some ZHAOXIN hosts (bsc#1012628).
- xhci: Fix TRB prefetch issue of ZHAOXIN hosts (bsc#1012628).
- xhci: Show ZHAOXIN xHCI root hub speed correctly (bsc#1012628).
- meson saradc: fix clock divider mask length (bsc#1012628).
- opp: Fix use-after-free in lazy_opp_tables after probe deferral
  (bsc#1012628).
- soundwire: qcom: fix storing port config out-of-bounds
  (bsc#1012628).
- media: uapi: Fix [GS]_ROUTING ACTIVE flag value (bsc#1012628).
- Revert "8250: add support for ASIX devices with a FIFO bug"
  (bsc#1012628).
- bus: ixp4xx: fix IXP4XX_EXP_T1_MASK (bsc#1012628).
- s390/decompressor: fix misaligned symbol build error
  (bsc#1012628).
- dm: verity-loadpin: Add NULL pointer check for 'bdev' parameter
  (bsc#1012628).
- tracing/histograms: Add histograms to hist_vars if they have
  referenced variables (bsc#1012628).
- tracing: Fix memory leak of iter->temp when reading trace_pipe
  (bsc#1012628).
- nvme: don't reject probe due to duplicate IDs for single-ported
  PCIe devices (bsc#1012628).
- samples: ftrace: Save required argument registers in sample
  trampolines (bsc#1012628).
- perf: RISC-V: Remove PERF_HES_STOPPED flag checking in
  riscv_pmu_start() (bsc#1012628).
- regmap-irq: Fix out-of-bounds access when allocating config
  buffers (bsc#1012628).
- net: ena: fix shift-out-of-bounds in exponential backoff
  (bsc#1012628).
- ring-buffer: Fix deadloop issue on reading trace_pipe
  (bsc#1012628).
- ftrace: Fix possible warning on checking all pages used in
  ftrace_process_locs() (bsc#1012628).
- drm/amd/pm: share the code around SMU13 pcie parameters update
  (bsc#1012628).
- drm/amd/pm: conditionally disable pcie lane/speed switching
  for SMU13 (bsc#1012628).
- cifs: if deferred close is disabled then close files immediately
  (bsc#1012628).
- xtensa: ISS: fix call to split_if_spec (bsc#1012628).
- perf/x86: Fix lockdep warning in for_each_sibling_event()
  on SPR (bsc#1012628).
- PM: QoS: Restore support for default value on frequency QoS
  (bsc#1012628).
- pwm: meson: modify and simplify calculation in
  meson_pwm_get_state (bsc#1012628).
- pwm: meson: fix handling of period/duty if greater than UINT_MAX
  (bsc#1012628).
- accel/ivpu: Fix VPU register access in irq disable
  (bsc#1012628).
- accel/ivpu: Clear specific interrupt status bits on C0
  (bsc#1012628).
- fprobe: Release rethook after the ftrace_ops is unregistered
  (bsc#1012628).
- fprobe: Ensure running fprobe_exit_handler() finished before
  calling rethook_free() (bsc#1012628).
- tracing: Fix null pointer dereference in tracing_err_log_open()
  (bsc#1012628).
- mptcp: do not rely on implicit state check in mptcp_listen()
  (bsc#1012628).
- mptcp: ensure subflow is unhashed before cleaning the backlog
  (bsc#1012628).
- selftests: mptcp: sockopt: use 'iptables-legacy' if available
  (bsc#1012628).
- selftests: mptcp: connect: fail if nft supposed to work
  (bsc#1012628).
- selftests: mptcp: sockopt: return error if wrong mark
  (bsc#1012628).
- selftests: mptcp: userspace_pm: use correct server port
  (bsc#1012628).
- selftests: mptcp: userspace_pm: report errors with 'remove'
  tests (bsc#1012628).
- selftests: mptcp: depend on SYN_COOKIES (bsc#1012628).
- selftests: mptcp: pm_nl_ctl: fix 32-bit support (bsc#1012628).
- smb: client: Fix -Wstringop-overflow issues (bsc#1012628).
- tracing/probes: Fix to avoid double count of the string length
  on the array (bsc#1012628).
- tracing/probes: Fix not to count error code to total length
  (bsc#1012628).
- tracing/probes: Fix to update dynamic data counter if fetcharg
  uses it (bsc#1012628).
- Revert "tracing: Add "(fault)" name injection to kernel probes"
  (bsc#1012628).
- tracing/probes: Fix to record 0-length data_loc in
  fetch_store_string*() if fails (bsc#1012628).
- tracing/user_events: Fix struct arg size match check
  (bsc#1012628).
- scsi: qla2xxx: Multi-que support for TMF (bsc#1012628).
- scsi: qla2xxx: Fix task management cmd failure (bsc#1012628).
- scsi: qla2xxx: Fix task management cmd fail due to unavailable
  resource (bsc#1012628).
- scsi: qla2xxx: Fix hang in task management (bsc#1012628).
- scsi: qla2xxx: Wait for io return on terminate rport
  (bsc#1012628).
- scsi: qla2xxx: Fix mem access after free (bsc#1012628).
- scsi: qla2xxx: Array index may go out of bound (bsc#1012628).
- scsi: qla2xxx: Avoid fcport pointer dereference (bsc#1012628).
- scsi: qla2xxx: Fix buffer overrun (bsc#1012628).
- scsi: qla2xxx: Fix potential NULL pointer dereference
  (bsc#1012628).
- scsi: qla2xxx: Check valid rport returned by fc_bsg_to_rport()
  (bsc#1012628).
- scsi: qla2xxx: Correct the index of array (bsc#1012628).
- scsi: qla2xxx: Pointer may be dereferenced (bsc#1012628).
- scsi: qla2xxx: Remove unused nvme_ls_waitq wait queue
  (bsc#1012628).
- scsi: qla2xxx: Fix end of loop test (bsc#1012628).
- net: dsa: ocelot: unlock on error in vsc9959_qos_port_tas_set()
  (bsc#1012628).
- MIPS: kvm: Fix build error with KVM_MIPS_DEBUG_COP0_COUNTERS
  enabled (bsc#1012628).
- Revert "drm/amd: Disable PSR-SU on Parade 0803 TCON"
  (bsc#1012628).
- drm/atomic: Fix potential use-after-free in nonblocking commits
  (bsc#1012628).
- net/ncsi: make one oem_gma function for all mfr id
  (bsc#1012628).
- net/ncsi: change from ndo_set_mac_address to dev_set_mac_address
  (bsc#1012628).
- Update config files. Set CONFIG_AMPERE_ERRATUM_AC03_CPU_38=y (the
  default)
- commit 6282d80
* Mon Jul 24 2023 mkubecek@suse.cz
- Update to 6.5-rc2
- disable
  patches.suse/Revert-io_uring-Adjust-mapping-wrt-architecture-alia.patch
- commit de7235b
* Sun Jul 23 2023 schwab@suse.de
- rpm/mkspec-dtb: add riscv64 dtb-thead subpackage
- commit 5f4d0a7
* Sun Jul 23 2023 schwab@suse.de
- rpm/mkspec-dtb: add riscv64 dtb-allwinner subpackage
- commit ec82ffc
* Sun Jul 23 2023 tiwai@suse.de
- Revert "r8169: disable ASPM during NAPI poll" (bsc#1213491).
- r8169: revert 2ab19de62d67 ("r8169: remove ASPM restrictions
  now that ASPM is disabled during NAPI poll") (bsc#1213491).
- r8169: fix ASPM-related problem for chip version 42 and 43
  (bsc#1213491).
- commit 8d5ae5f
* Thu Jul 20 2023 jslaby@suse.cz
- Linux 6.4.4 (bsc#1012628).
- start_kernel: Add __no_stack_protector function attribute
  (bsc#1012628).
- USB: serial: option: add LARA-R6 01B PIDs (bsc#1012628).
- usb: dwc3: gadget: Propagate core init errors to UDC during
  pullup (bsc#1012628).
- phy: tegra: xusb: Clear the driver reference in usb-phy dev
  (bsc#1012628).
- extcon: usbc-tusb320: Unregister typec port on driver removal
  (bsc#1012628).
- dt-bindings: iio: ad7192: Add mandatory reference voltage source
  (bsc#1012628).
- iio: addac: ad74413: don't set DIN_SINK for functions other
  than digital input (bsc#1012628).
- iio: adc: ad7192: Fix null ad7192_state pointer access
  (bsc#1012628).
- iio: adc: ad7192: Fix internal/external clock selection
  (bsc#1012628).
- iio: accel: fxls8962af: errata bug only applicable for
  FXLS8962AF (bsc#1012628).
- iio: accel: fxls8962af: fixup buffer scan element type
  (bsc#1012628).
- Revert "drm/amd/display: edp do not add non-edid timings"
  (bsc#1012628).
- fs: pipe: reveal missing function protoypes (bsc#1012628).
- s390/kasan: fix insecure W+X mapping warning (bsc#1012628).
- blk-mq: don't queue plugged passthrough requests into scheduler
  (bsc#1012628).
- block: Fix the type of the second bdev_op_is_zoned_write()
  argument (bsc#1012628).
- block/rq_qos: protect rq_qos apis with a new lock (bsc#1012628).
- splice: Fix filemap_splice_read() to use the correct inode
  (bsc#1012628).
- erofs: kill hooked chains to avoid loops on deduplicated
  compressed images (bsc#1012628).
- x86/resctrl: Only show tasks' pid in current pid namespace
  (bsc#1012628).
- fsverity: use shash API instead of ahash API (bsc#1012628).
- fsverity: don't use bio_first_page_all() in
  fsverity_verify_bio() (bsc#1012628).
- blk-iocost: use spin_lock_irqsave in adjust_inuse_and_calc_cost
  (bsc#1012628).
- x86/sev: Fix calculation of end address based on number of pages
  (bsc#1012628).
- blk-cgroup: Reinit blkg_iostat_set after clearing in
  blkcg_reset_stats() (bsc#1012628).
- virt: sevguest: Add CONFIG_CRYPTO dependency (bsc#1012628).
- blk-mq: fix potential io hang by wrong 'wake_batch'
  (bsc#1012628).
- lockd: drop inappropriate svc_get() from locked_get()
  (bsc#1012628).
- nvme-core: fix memory leak in dhchap_secret_store (bsc#1012628).
- nvme-core: fix memory leak in dhchap_ctrl_secret (bsc#1012628).
- nvme-core: add missing fault-injection cleanup (bsc#1012628).
- nvme-core: fix dev_pm_qos memleak (bsc#1012628).
- md/raid10: check slab-out-of-bounds in md_bitmap_get_counter
  (bsc#1012628).
- md/raid10: fix overflow of md/safe_mode_delay (bsc#1012628).
- md/raid10: fix wrong setting of max_corr_read_errors
  (bsc#1012628).
- md/raid10: fix null-ptr-deref of mreplace in raid10_sync_request
  (bsc#1012628).
- md/raid10: fix io loss while replacement replace rdev
  (bsc#1012628).
- md/raid1-10: factor out a helper to add bio to plug
  (bsc#1012628).
- md/raid1-10: factor out a helper to submit normal write
  (bsc#1012628).
- md/raid1-10: submit write io directly if bitmap is not enabled
  (bsc#1012628).
- block: fix blktrace debugfs entries leakage (bsc#1012628).
- irqchip/loongson-eiointc: Fix irq affinity setting during resume
  (bsc#1012628).
- splice: don't call file_accessed in copy_splice_read
  (bsc#1012628).
- irqchip/stm32-exti: Fix warning on initialized field overwritten
  (bsc#1012628).
- irqchip/jcore-aic: Fix missing allocation of IRQ descriptors
  (bsc#1012628).
- svcrdma: Prevent page release when nothing was received
  (bsc#1012628).
- erofs: fix compact 4B support for 16k block size (bsc#1012628).
- posix-timers: Prevent RT livelock in itimer_delete()
  (bsc#1012628).
- tick/rcu: Fix bogus ratelimit condition (bsc#1012628).
- tracing/timer: Add missing hrtimer modes to
  decode_hrtimer_mode() (bsc#1012628).
- btrfs: always read the entire extent_buffer (bsc#1012628).
- btrfs: don't use btrfs_bio_ctrl for extent buffer reading
  (bsc#1012628).
- btrfs: return bool from lock_extent_buffer_for_io (bsc#1012628).
- btrfs: submit a writeback bio per extent_buffer (bsc#1012628).
- btrfs: fix range_end calculation in extent_write_locked_range
  (bsc#1012628).
- btrfs: don't fail writeback when allocating the compression
  context fails (bsc#1012628).
- btrfs: only call __extent_writepage_io from
  extent_write_locked_range (bsc#1012628).
- btrfs: don't treat zoned writeback as being from an async
  helper thread (bsc#1012628).
- btrfs: fix file_offset for REQ_BTRFS_ONE_ORDERED bios that
  get split (bsc#1012628).
- blk-mq: don't insert passthrough request into sw queue
  (bsc#1012628).
- clocksource/drivers/cadence-ttc: Fix memory leak in
  ttc_timer_probe (bsc#1012628).
- PM: domains: fix integer overflow issues in genpd_parse_state()
  (bsc#1012628).
- perf/arm-cmn: Fix DTC reset (bsc#1012628).
- drivers/perf: apple_m1: Force 63bit counters for M2 CPUs
  (bsc#1012628).
- x86/mm: Allow guest.enc_status_change_prepare() to fail
  (bsc#1012628).
- x86/tdx: Fix race between set_memory_encrypted() and
  load_unaligned_zeropad() (bsc#1012628).
- drivers/perf: hisi: Don't migrate perf to the CPU going to
  teardown (bsc#1012628).
- perf: arm_cspmu: Set irq affinitiy only if overflow interrupt
  is used (bsc#1012628).
- perf/arm_cspmu: Fix event attribute type (bsc#1012628).
- APEI: GHES: correctly return NULL for ghes_get_devices()
  (bsc#1012628).
- powercap: RAPL: fix invalid initialization for pl4_supported
  field (bsc#1012628).
- powercap: RAPL: Fix CONFIG_IOSF_MBI dependency (bsc#1012628).
- PM: domains: Move the verification of in-params from
  genpd_add_device() (bsc#1012628).
- ARM: 9303/1: kprobes: avoid missing-declaration warnings
  (bsc#1012628).
- cpufreq: intel_pstate: Fix energy_performance_preference for
  passive (bsc#1012628).
- thermal/drivers/qcom/tsens-v0_1: Add support for MSM8226
  (bsc#1012628).
- thermal/drivers/qcom/tsens-v0_1: Fix mdm9607 slope values
  (bsc#1012628).
- thermal/drivers/qcom/tsens-v0_1: Add mdm9607 correction offsets
  (bsc#1012628).
- thermal/drivers/sun8i: Fix some error handling paths in
  sun8i_ths_probe() (bsc#1012628).
- thermal/drivers/qoriq: Only enable supported sensors
  (bsc#1012628).
- kunit: tool: undo type subscripts for subprocess.Popen
  (bsc#1012628).
- rcu: Make rcu_cpu_starting() rely on interrupts being disabled
  (bsc#1012628).
- rcu-tasks: Stop rcu_tasks_invoke_cbs() from using never-onlined
  CPUs (bsc#1012628).
- rcutorture: Correct name of use_softirq module parameter
  (bsc#1012628).
- rcu/rcuscale: Move rcu_scale_*() after kfree_scale_cleanup()
  (bsc#1012628).
- rcu/rcuscale: Stop kfree_scale_thread thread(s) after unloading
  rcuscale (bsc#1012628).
- x86/mtrr: Remove physical address size calculation
  (bsc#1012628).
- x86/mtrr: Support setting MTRR state for software defined MTRRs
  (bsc#1012628).
- x86/hyperv: Set MTRR state when running as SEV-SNP Hyper-V guest
  (bsc#1012628).
- x86/mtrr: Replace size_or_mask and size_and_mask with a much
  easier concept (bsc#1012628).
- x86/xen: Set MTRR state when running as Xen PV initial domain
  (bsc#1012628).
- tools/nolibc: ensure fast64 integer types have 64 bits
  (bsc#1012628).
- kselftest: vDSO: Fix accumulation of uninitialized ret when
  CLOCK_REALTIME is undefined (bsc#1012628).
- selftests/ftace: Fix KTAP output ordering (bsc#1012628).
- perf/ibs: Fix interface via core pmu events (bsc#1012628).
- x86/mm: Fix __swp_entry_to_pte() for Xen PV guests
  (bsc#1012628).
- reiserfs: Initialize sec->length in reiserfs_security_init()
  (bsc#1012628).
- locking/atomic: arm: fix sync ops (bsc#1012628).
- evm: Complete description of evm_inode_setattr() (bsc#1012628).
- evm: Fix build warnings (bsc#1012628).
- ima: Fix build warnings (bsc#1012628).
- pstore/ram: Add check for kstrdup (bsc#1012628).
- sched/core: Avoid multiple calling update_rq_clock() in
  __cfsb_csd_unthrottle() (bsc#1012628).
- igc: Enable and fix RX hash usage by netstack (bsc#1012628).
- wifi: ath9k: fix AR9003 mac hardware hang check register offset
  calculation (bsc#1012628).
- wifi: ath9k: avoid referencing uninit memory in
  ath9k_wmi_ctrl_rx (bsc#1012628).
- libbpf: btf_dump_type_data_check_overflow needs to consider
  BTF_MEMBER_BITFIELD_SIZE (bsc#1012628).
- bpf: encapsulate precision backtracking bookkeeping
  (bsc#1012628).
- bpf: improve precision backtrack logging (bsc#1012628).
- bpf: maintain bitmasks across all active frames in
  __mark_chain_precision (bsc#1012628).
- bpf: fix propagate_precision() logic for inner frames
  (bsc#1012628).
- wifi: rtw89: fix rtw89_read_chip_ver() for RTL8852B and RTL8851B
  (bsc#1012628).
- samples/bpf: Fix buffer overflow in tcp_basertt (bsc#1012628).
- spi: spi-geni-qcom: Correct CS_TOGGLE bit in SPI_TRANS_CFG
  (bsc#1012628).
- wifi: wilc1000: fix for absent RSN capabilities WFA testcase
  (bsc#1012628).
- wifi: rtw88: unlock on error path in rtw_ops_add_interface()
  (bsc#1012628).
- wifi: mwifiex: Fix the size of a memory allocation in
  mwifiex_ret_802_11_scan() (bsc#1012628).
- sctp: add bpf_bypass_getsockopt proto callback (bsc#1012628).
- sfc: release encap match in efx_tc_flow_free() (bsc#1012628).
- libbpf: fix offsetof() and container_of() to work with CO-RE
  (bsc#1012628).
- bpf: Don't EFAULT for {g,s}setsockopt with wrong optlen
  (bsc#1012628).
- spi: dw: Round of n_bytes to power of 2 (bsc#1012628).
- nfc: llcp: fix possible use of uninitialized variable in
  nfc_llcp_send_connect() (bsc#1012628).
- bpftool: JIT limited misreported as negative value on aarch64
  (bsc#1012628).
- bpf: Remove bpf trampoline selector (bsc#1012628).
- bpf: Fix memleak due to fentry attach failure (bsc#1012628).
- selftests/bpf: Do not use sign-file as testcase (bsc#1012628).
- regulator: rk808: fix asynchronous probing (bsc#1012628).
- regulator: core: Fix more error checking for
  debugfs_create_dir() (bsc#1012628).
- regulator: core: Streamline debugfs operations (bsc#1012628).
- wifi: orinoco: Fix an error handling path in spectrum_cs_probe()
  (bsc#1012628).
- wifi: orinoco: Fix an error handling path in orinoco_cs_probe()
  (bsc#1012628).
- wifi: atmel: Fix an error handling path in atmel_probe()
  (bsc#1012628).
- wifi: wl3501_cs: Fix an error handling path in wl3501_probe()
  (bsc#1012628).
- wifi: ray_cs: Fix an error handling path in ray_probe()
  (bsc#1012628).
- wifi: ath9k: don't allow to overwrite ENDPOINT0 attributes
  (bsc#1012628).
- wifi: rtw88: usb: silence log flooding error message
  (bsc#1012628).
- samples/bpf: xdp1 and xdp2 reduce XDPBUFSIZE to 60
  (bsc#1012628).
- wifi: ath10k: Trigger STA disconnect after reconfig complete
  on hardware restart (bsc#1012628).
- bpf: Remove anonymous union in bpf_kfunc_call_arg_meta
  (bsc#1012628).
- bpf: Set kptr_struct_meta for node param to list and rbtree
  insert funcs (bsc#1012628).
- bpf: Fix __bpf_{list,rbtree}_add's beginning-of-node calculation
  (bsc#1012628).
- bpf: Make bpf_refcount_acquire fallible for non-owning refs
  (bsc#1012628).
- tools/resolve_btfids: Fix setting HOSTCFLAGS (bsc#1012628).
- wifi: iwlwifi: mvm: send time sync only if needed (bsc#1012628).
- wifi: mac80211: recalc min chandef for new STA links
  (bsc#1012628).
- selftests/bpf: Fix check_mtu using wrong variable type
  (bsc#1012628).
- soc: qcom: geni-se: Add interfaces geni_se_tx_init_dma()
  and geni_se_rx_init_dma() (bsc#1012628).
- spi: spi-geni-qcom: Do not do DMA map/unmap inside driver,
  use framework instead (bsc#1012628).
- wifi: rsi: Do not configure WoWlan in shutdown hook if not
  enabled (bsc#1012628).
- wifi: rsi: Do not set MMC_PM_KEEP_POWER in shutdown
  (bsc#1012628).
- ice: handle extts in the miscellaneous interrupt thread
  (bsc#1012628).
- selftests: cgroup: fix unexpected failure on test_memcg_low
  (bsc#1012628).
- watchdog/perf: define dummy watchdog_update_hrtimer_threshold()
  on correct config (bsc#1012628).
- watchdog/perf: more properly prevent false positives with
  turbo modes (bsc#1012628).
- kexec: fix a memory leak in crash_shrink_memory() (bsc#1012628).
- mmc: mediatek: Avoid ugly error message when SDIO wakeup IRQ
  isn't used (bsc#1012628).
- memstick r592: make memstick_debug_get_tpc_name() static
  (bsc#1012628).
- selftests/bpf: Fix invalid pointer check in get_xlated_program()
  (bsc#1012628).
- wifi: ath9k: Fix possible stall on ath9k_txq_list_has_key()
  (bsc#1012628).
- bpf: Use scalar ids in mark_chain_precision() (bsc#1012628).
- bpf: Verify scalar ids mapping in regsafe() using check_ids()
  (bsc#1012628).
- wifi: mac80211: Fix permissions for valid_links debugfs entry
  (bsc#1012628).
- wifi: iwlwifi: mvm: Handle return value for iwl_mvm_sta_init
  (bsc#1012628).
- wifi: iwlwifi: fw: print PC register value instead of address
  (bsc#1012628).
- rtnetlink: extend RTEXT_FILTER_SKIP_STATS to IFLA_VF_INFO
  (bsc#1012628).
- wifi: ath11k: Add missing check for ioremap (bsc#1012628).
- wifi: ath11k: Add missing ops config for IPQ5018 in
  ath11k_ahb_probe() (bsc#1012628).
- wifi: ath11k: Restart firmware after cold boot calibration
  for IPQ5018 (bsc#1012628).
- wifi: ath11k: Add missing hw_ops->get_ring_selector() for
  IPQ5018 (bsc#1012628).
- wifi: mac80211: add helpers to access sband iftype data
  (bsc#1012628).
- wifi: iwlwifi: mvm: add support for Extra EHT LTF (bsc#1012628).
- wifi: iwlwifi: mvm: correctly access HE/EHT sband capa
  (bsc#1012628).
- wifi: iwlwifi: pull from TXQs with softirqs disabled
  (bsc#1012628).
- wifi: iwlwifi: pcie: fix NULL pointer dereference in
  iwl_pcie_irq_rx_msix_handler() (bsc#1012628).
- wifi: mac80211: Remove "Missing iftype sband data/EHT cap"
  spam (bsc#1012628).
- wifi: cfg80211: rewrite merging of inherited elements
  (bsc#1012628).
- wifi: cfg80211: drop incorrect nontransmitted BSS update code
  (bsc#1012628).
- wifi: cfg80211: fix regulatory disconnect with OCB/NAN
  (bsc#1012628).
- wifi: ieee80211: Fix the common size calculation for
  reconfiguration ML (bsc#1012628).
- mm: move mm_count into its own cache line (bsc#1012628).
- watchdog: remove WATCHDOG_DEFAULT (bsc#1012628).
- watchdog/hardlockup: change watchdog_nmi_enable() to void
  (bsc#1012628).
- watchdog/hardlockup: move perf hardlockup checking/panic to
  common watchdog.c (bsc#1012628).
- watchdog/hardlockup: rename some "NMI watchdog"
  constants/function (bsc#1012628).
- watchdog/perf: adapt the watchdog_perf interface for async model
  (bsc#1012628).
- watchdog/hardlockup: keep kernel.nmi_watchdog sysctl as 0444
  if probe fails (bsc#1012628).
- mmc: Add MMC_QUIRK_BROKEN_SD_CACHE for Kingston Canvas Go Plus
  from 11/2019 (bsc#1012628).
- wifi: iwlwifi: mvm: indicate HW decrypt for beacon protection
  (bsc#1012628).
- wifi: iwlwifi: mvm: check only affected links (bsc#1012628).
- wifi: ath9k: convert msecs to jiffies where needed
  (bsc#1012628).
- bpf: Factor out socket lookup functions for the TC hookpoint
  (bsc#1012628).
- bpf: Call __bpf_sk_lookup()/__bpf_skc_lookup() directly via
  TC hookpoint (bsc#1012628).
- bpf: Fix bpf socket lookup from tc/xdp to respect socket VRF
  bindings (bsc#1012628).
- can: length: fix bitstuffing count (bsc#1012628).
- can: kvaser_pciefd: Add function to set skb hwtstamps
  (bsc#1012628).
- can: kvaser_pciefd: Set hardware timestamp on transmitted
  packets (bsc#1012628).
- igc: Fix race condition in PTP tx code (bsc#1012628).
- igc: Check if hardware TX timestamping is enabled earlier
  (bsc#1012628).
- igc: Retrieve TX timestamp during interrupt handling
  (bsc#1012628).
- igc: Work around HW bug causing missing timestamps
  (bsc#1012628).
- net: stmmac: fix double serdes powerdown (bsc#1012628).
- netlink: fix potential deadlock in netlink_set_err()
  (bsc#1012628).
- netlink: do not hard code device address lenth in fdb dumps
  (bsc#1012628).
- bonding: do not assume skb mac_header is set (bsc#1012628).
- sch_netem: fix issues in netem_change() vs get_dist_table()
  (bsc#1012628).
- selftests: rtnetlink: remove netdevsim device after ipsec
  offload test (bsc#1012628).
- gtp: Fix use-after-free in __gtp_encap_destroy() (bsc#1012628).
- net: axienet: Move reset before 64-bit DMA detection
  (bsc#1012628).
- ocfs2: Fix use of slab data with sendpage (bsc#1012628).
- sfc: fix crash when reading stats while NIC is resetting
  (bsc#1012628).
- net: nfc: Fix use-after-free caused by nfc_llcp_find_local
  (bsc#1012628).
- lib/ts_bm: reset initial match offset for every block of text
  (bsc#1012628).
- netfilter: conntrack: dccp: copy entire header to stack buffer,
  not just basic one (bsc#1012628).
- netfilter: nf_conntrack_sip: fix the
  ct_sip_parse_numerical_param() return value (bsc#1012628).
- netfilter: nf_tables: unbind non-anonymous set if rule
  construction fails (bsc#1012628).
- netfilter: nf_tables: fix underflow in chain reference counter
  (bsc#1012628).
- ipvlan: Fix return value of ipvlan_queue_xmit() (bsc#1012628).
- net: dsa: avoid suspicious RCU usage for synced VLAN-aware
  MAC addresses (bsc#1012628).
- netlink: Add __sock_i_ino() for __netlink_diag_dump()
  (bsc#1012628).
- drm/imx/lcdc: fix a NULL vs IS_ERR() bug in probe (bsc#1012628).
- drm/amd/display: Unconditionally print when DP sink power
  state fails (bsc#1012628).
- drm/amd/display: Add logging for display MALL refresh setting
  (bsc#1012628).
- drm/amd/display: fix is_timing_changed() prototype
  (bsc#1012628).
- radeon: avoid double free in ci_dpm_init() (bsc#1012628).
- drm/amd/display: Explicitly specify update type per plane info
  change (bsc#1012628).
- drm/i915/guc/slpc: Provide sysfs for efficient freq
  (bsc#1012628).
- drm/bridge: it6505: Move a variable assignment behind a null
  pointer check in receive_timing_debugfs_show() (bsc#1012628).
- Input: drv260x - sleep between polling GO bit (bsc#1012628).
- Input: cyttsp4_core - change del_timer_sync() to
  timer_shutdown_sync() (bsc#1012628).
- Input: tests - fix use-after-free and refcount underflow in
  input_test_exit() (bsc#1012628).
- Input: tests - modular KUnit tests should not depend on KUNIT=y
  (bsc#1012628).
- drm/bridge: ti-sn65dsi83: Fix enable error path (bsc#1012628).
- drm/bridge: tc358768: always enable HS video mode (bsc#1012628).
- drm/bridge: tc358768: fix PLL parameters computation
  (bsc#1012628).
- drm/bridge: tc358768: fix PLL target frequency (bsc#1012628).
- drm/bridge: tc358768: fix TCLK_ZEROCNT computation
  (bsc#1012628).
- drm/bridge: tc358768: Add atomic_get_input_bus_fmts()
  implementation (bsc#1012628).
- drm/bridge: tc358768: fix TCLK_TRAILCNT computation
  (bsc#1012628).
- drm/bridge: tc358768: fix THS_ZEROCNT computation (bsc#1012628).
- drm/bridge: tc358768: fix TXTAGOCNT computation (bsc#1012628).
- drm/bridge: tc358768: fix THS_TRAILCNT computation
  (bsc#1012628).
- Input: tests - fix input_test_match_device_id test
  (bsc#1012628).
- drm/vram-helper: fix function names in vram helper doc
  (bsc#1012628).
- ARM: dts: BCM5301X: Drop "clock-names" from the SPI node
  (bsc#1012628).
- ARM: dts: meson8b: correct uart_B and uart_C clock references
  (bsc#1012628).
- clk: vc5: Fix .driver_data content in i2c_device_id
  (bsc#1012628).
- clk: vc7: Fix .driver_data content in i2c_device_id
  (bsc#1012628).
- clk: rs9: Fix .driver_data content in i2c_device_id
  (bsc#1012628).
- Input: adxl34x - do not hardcode interrupt trigger type
  (bsc#1012628).
- drm: sun4i_tcon: use devm_clk_get_enabled in
  `sun4i_tcon_init_clocks` (bsc#1012628).
- drm/panel: sharp-ls043t1le01: adjust mode settings
  (bsc#1012628).
- driver: soc: xilinx: use _safe loop iterator to avoid a use
  after free (bsc#1012628).
- ASoC: dt-bindings: mediatek,mt8188-afe: correct clock name
  (bsc#1012628).
- ASoC: Intel: sof_sdw: remove SOF_SDW_TGL_HDMI for MeteorLake
  devices (bsc#1012628).
- ASoC: Intel: sof_sdw: start set codec init function with an
  adr index (bsc#1012628).
- drm/vkms: isolate pixel conversion functionality (bsc#1012628).
- drm: Add fixed-point helper to get rounded integer values
  (bsc#1012628).
- drm/vkms: Fix RGB565 pixel conversion (bsc#1012628).
- ARM: dts: stm32: Move ethernet MAC EEPROM from SoM to carrier
  boards (bsc#1012628).
- bus: ti-sysc: Fix dispc quirk masking bool variables
  (bsc#1012628).
- arm64: dts: microchip: sparx5: do not use PSCI on reference
  boards (bsc#1012628).
- drm/bridge: tc358767: Switch to devm MIPI-DSI helpers
  (bsc#1012628).
- arm64: dts: qcom: ipq9574: Update the size of GICC & GICV
  regions (bsc#1012628).
- clk: imx: scu: use _safe list iterator to avoid a use after free
  (bsc#1012628).
- hwmon: (f71882fg) prevent possible division by zero
  (bsc#1012628).
- RDMA/bnxt_re: Disable/kill tasklet only if it is enabled
  (bsc#1012628).
- RDMA/bnxt_re: Fix to remove unnecessary return labels
  (bsc#1012628).
- RDMA/bnxt_re: Use unique names while registering interrupts
  (bsc#1012628).
- RDMA/bnxt_re: Remove a redundant check inside bnxt_re_update_gid
  (bsc#1012628).
- RDMA/bnxt_re: Fix to remove an unnecessary log (bsc#1012628).
- drm/msm/dpu: enable DSPP_2/3 for LM_2/3 on sm8450 (bsc#1012628).
- drm/msm/dsi: don't allow enabling 14nm VCO with unprogrammed
  rate (bsc#1012628).
- drm/msm/dpu: fix cursor block register bit offset in msm8998
  hw catalog (bsc#1012628).
- drm/msm/dpu: Use V4.0 PCC DSPP sub-block in SC7[12]80
  (bsc#1012628).
- drm/msm/dpu: Set DPU_DATA_HCTL_EN for in INTF_SC7180_MASK
  (bsc#1012628).
- drm/nouveau: dispnv50: fix missing-prototypes warning
  (bsc#1012628).
- iommu/virtio: Detach domain on endpoint release (bsc#1012628).
- iommu/virtio: Return size mapped for a detached domain
  (bsc#1012628).
- clk: renesas: rzg2l: Fix CPG_SIPLL5_CLK1 register write
  (bsc#1012628).
- ARM: dts: gta04: Move model property out of pinctrl node
  (bsc#1012628).
- arm64: dts: qcom: qrb4210-rb2: Fix CD gpio for SDHC2
  (bsc#1012628).
- drm/bridge: anx7625: Prevent endless probe loop (bsc#1012628).
- ARM/mfd/gpio: Fixup TPS65010 regression on OMAP1 OSK1
  (bsc#1012628).
- ARM: omap1: Drop header on AMS Delta (bsc#1012628).
- ARM: omap1: Remove reliance on GPIO numbers from PalmTE
  (bsc#1012628).
- ARM: omap1: Remove reliance on GPIO numbers from SX1
  (bsc#1012628).
- Input: ads7846 - Convert to use software nodes (bsc#1012628).
- ARM/mmc: Convert old mmci-omap to GPIO descriptors
  (bsc#1012628).
- ARM: omap1: Fix up the Nokia 770 board device IRQs
  (bsc#1012628).
- ARM: omap1: Make serial wakeup GPIOs use descriptors
  (bsc#1012628).
- ARM: omap1: Exorcise the legacy GPIO header (bsc#1012628).
- ARM/gpio: Push OMAP2 quirk down into TWL4030 driver
  (bsc#1012628).
- ARM: omap2: Get USB hub reset GPIO from descriptor
  (bsc#1012628).
- ARM: omap2: Rewrite WLAN quirk to use GPIO descriptors
  (bsc#1012628).
- ARM/musb: omap2: Remove global GPIO numbers from TUSB6010
  (bsc#1012628).
- ARM: dts: qcom: msm8974: do not use underscore in node name
  (again) (bsc#1012628).
- arm64: dts: qcom: pm8998: don't use GIC_SPI for SPMI interrupts
  (bsc#1012628).
- arm64: dts: qcom: ipq6018: correct qrng unit address
  (bsc#1012628).
- arm64: dts: qcom: msm8916: correct camss unit address
  (bsc#1012628).
- arm64: dts: qcom: msm8916: correct MMC unit address
  (bsc#1012628).
- arm64: dts: qcom: msm8916: correct WCNSS unit address
  (bsc#1012628).
- arm64: dts: qcom: msm8953: correct IOMMU unit address
  (bsc#1012628).
- arm64: dts: qcom: msm8953: correct WCNSS unit address
  (bsc#1012628).
- arm64: dts: qcom: msm8976: correct MMC unit address
  (bsc#1012628).
- arm64: dts: qcom: msm8994: correct SPMI unit address
  (bsc#1012628).
- arm64: dts: qcom: msm8996: correct camss unit address
  (bsc#1012628).
- arm64: dts: qcom: sdm630: correct camss unit address
  (bsc#1012628).
- arm64: dts: qcom: sdm845: correct camss unit address
  (bsc#1012628).
- arm64: dts: qcom: sm6115: correct thermal-sensor unit address
  (bsc#1012628).
- arm64: dts: qcom: sm8350: correct DMA controller unit address
  (bsc#1012628).
- arm64: dts: qcom: sm8350: correct PCI phy unit address
  (bsc#1012628).
- arm64: dts: qcom: sm8350: correct USB phy unit address
  (bsc#1012628).
- arm64: dts: qcom: sm8550: correct crypto unit address
  (bsc#1012628).
- arm64: dts: qcom: sm8550: correct pinctrl unit address
  (bsc#1012628).
- arm64: dts: qcom: sdm845-polaris: add missing touchscreen
  child node reg (bsc#1012628).
- arm64: dts: qcom: apq8016-sbc: Fix regulator constraints
  (bsc#1012628).
- arm64: dts: qcom: apq8016-sbc: Fix 1.8V power rail on LS
  expansion (bsc#1012628).
- drm/bridge: ti-sn65dsi83: Fix enable/disable flow to meet spec
  (bsc#1012628).
- drm: bridge: samsung-dsim: Fix PMS Calculator on imx8m[mnp]
  (bsc#1012628).
- drm/panel: simple: fix active size for Ampire
  AM-480272H3TMQW-T01H (bsc#1012628).
- ARM: ep93xx: fix missing-prototype warnings (bsc#1012628).
- ARM: omap2: fix missing tick_broadcast() prototype
  (bsc#1012628).
- arm64: dts: qcom: pm7250b: add missing spmi-vadc include
  (bsc#1012628).
- arm64: dts: qcom: apq8096: fix fixed regulator name property
  (bsc#1012628).
- arm64: dts: mediatek: mt8183: Add
  mediatek,broken-save-restore-fw to kukui (bsc#1012628).
- arm64: dts: mediatek: mt8192: Add
  mediatek,broken-save-restore-fw to asurada (bsc#1012628).
- arm64: dts: mediatek: mt8195: Add
  mediatek,broken-save-restore-fw to cherry (bsc#1012628).
- ARM: dts: stm32: Shorten the AV96 HDMI sound card name
  (bsc#1012628).
- memory: brcmstb_dpfe: fix testing array offset after use
  (bsc#1012628).
- ARM: dts: qcom: apq8074-dragonboard: Set DMA as remotely
  controlled (bsc#1012628).
- ASoC: es8316: Increment max value for ALC Capture Target Volume
  control (bsc#1012628).
- ASoC: es8316: Do not set rate constraints for unsupported MCLKs
  (bsc#1012628).
- ARM: dts: meson8: correct uart_B and uart_C clock references
  (bsc#1012628).
- soc/fsl/qe: fix usb.c build errors (bsc#1012628).
- RDMA/irdma: avoid fortify-string warning in irdma_clr_wqes
  (bsc#1012628).
- IB/hfi1: Fix wrong mmu_node used for user SDMA packet after
  invalidate (bsc#1012628).
- RDMA/hns: Fix hns_roce_table_get return value (bsc#1012628).
- ARM: dts: iwg20d-q7-common: Fix backlight pwm specifier
  (bsc#1012628).
- arm64: dts: renesas: ulcb-kf: Remove flow control for SCIF1
  (bsc#1012628).
- drm/msm/dpu: set DSC flush bit correctly at MDP CTL flush
  register (bsc#1012628).
- drm/msm/dpu: always clear every individual pending flush mask
  (bsc#1012628).
- fbdev: omapfb: lcd_mipid: Fix an error handling path in
  mipid_spi_probe() (bsc#1012628).
- dt-bindings: arm-smmu: Fix SC8280XP Adreno binding
  (bsc#1012628).
- drm/i915: Fix limited range csc matrix (bsc#1012628).
- drm/i915: hide mkwrite_device_info() better (bsc#1012628).
- drm/i915/display: Move display device info to header under
  display/ (bsc#1012628).
- drm/i915: Convert INTEL_INFO()->display to a pointer
  (bsc#1012628).
- drm/i915/display: Move display runtime info to display structure
  (bsc#1012628).
- drm/i915/display: Make display responsible for probing its
  own IP (bsc#1012628).
- drm/i915: No 10bit gamma on desktop gen3 parts (bsc#1012628).
- arm64: dts: rockchip: Assign ES8316 MCLK rate on rk3588-rock-5b
  (bsc#1012628).
- arm64: dts: ti: k3-j7200: Fix physical address of pin
  (bsc#1012628).
- Input: pm8941-powerkey - fix debounce on gen2+ PMICs
  (bsc#1012628).
- arm64: dts: rockchip: Fix compatible for Bluetooth on
  rk3566-anbernic (bsc#1012628).
- ARM: dts: stm32: Fix audio routing on STM32MP15xx DHCOM PDK2
  (bsc#1012628).
- accel/habanalabs: fix gaudi2_get_tpc_idle_status() return
  (bsc#1012628).
- ARM: dts: stm32: fix i2s endpoint format property for
  stm32mp15xx-dkx (bsc#1012628).
- hwmon: (gsc-hwmon) fix fan pwm temperature scaling
  (bsc#1012628).
- hwmon: (pmbus/adm1275) Fix problems with temperature monitoring
  on ADM1272 (bsc#1012628).
- ARM: dts: BCM5301X: fix duplex-full => full-duplex
  (bsc#1012628).
- clk: Export clk_hw_forward_rate_request() (bsc#1012628).
- drm/amd/display: Fix a test CalculatePrefetchSchedule()
  (bsc#1012628).
- drm/amd/display: Fix a test dml32_rq_dlg_get_rq_reg()
  (bsc#1012628).
- drm/amdkfd: Fix potential deallocation of previously deallocated
  memory (bsc#1012628).
- soc: mediatek: SVS: Fix MT8192 GPU node name (bsc#1012628).
- drm/amd/display: Fix artifacting on eDP panels when engaging
  freesync video mode (bsc#1012628).
- drm/radeon: fix possible division-by-zero errors (bsc#1012628).
- HID: uclogic: Modular KUnit tests should not depend on KUNIT=y
  (bsc#1012628).
- RDMA/rxe: Fix access checks in rxe_check_bind_mw (bsc#1012628).
- amdgpu: validate offset_in_bo of drm_amdgpu_gem_va
  (bsc#1012628).
- drm/msm/a6xx: don't set IO_PGTABLE_QUIRK_ARM_OUTER_WBWA with
  coherent SMMU (bsc#1012628).
- drm/msm/a5xx: really check for A510 in a5xx_gpu_init
  (bsc#1012628).
- RDMA/bnxt_re: wraparound mbox producer index (bsc#1012628).
- RDMA/bnxt_re: Avoid calling wake_up threads from spin_lock
  context (bsc#1012628).
- clk: imx: composite-8m: Add imx8m_divider_determine_rate
  (bsc#1012628).
- clk: imx: clk-imxrt1050: fix memory leak in
  imxrt1050_clocks_probe (bsc#1012628).
- clk: imx: clk-imx8mn: fix memory leak in imx8mn_clocks_probe
  (bsc#1012628).
- clk: imx93: fix memory leak and missing unwind goto in
  imx93_clocks_probe (bsc#1012628).
- clk: imx: clk-imx8mp: improve error handling in
  imx8mp_clocks_probe() (bsc#1012628).
- clk: mediatek: fix of_iomap memory leak (bsc#1012628).
- arm64: dts: qcom: qdu1000: Flush RSC sleep & wake votes
  (bsc#1012628).
- arm64: dts: qcom: sdm670: Flush RSC sleep & wake votes
  (bsc#1012628).
- arm64: dts: qcom: sdm845: Flush RSC sleep & wake votes
  (bsc#1012628).
- arm64: dts: qcom: sm8550: Flush RSC sleep & wake votes
  (bsc#1012628).
- arm64: dts: qcom: sm8250-edo: Panel framebuffer is 2.5k instead
  of 4k (bsc#1012628).
- arm64: dts: qcom: sm8550: Add missing interconnect path to
  USB HC (bsc#1012628).
- clk: bcm: rpi: Fix off by one in raspberrypi_discover_clocks()
  (bsc#1012628).
- clk: clocking-wizard: Fix Oops in clk_wzrd_register_divider()
  (bsc#1012628).
- clk: tegra: tegra124-emc: Fix potential memory leak
  (bsc#1012628).
- arm64: dts: ti: k3-j721e-beagleboneai64: Fix mailbox node status
  (bsc#1012628).
- arm64: dts: ti: k3-j784s4-evm: Fix main_i2c0 alias
  (bsc#1012628).
- arm64: dts: ti: k3-j784s4: Fix wakeup pinmux range and pinctrl
  node offsets (bsc#1012628).
- arm64: dts: ti: k3-am69-sk: Fix main_i2c0 alias (bsc#1012628).
- ALSA: ac97: Fix possible NULL dereference in snd_ac97_mixer
  (bsc#1012628).
- drm/msm/dpu: do not enable color-management if DSPPs are not
  available (bsc#1012628).
- drm/msm/dpu: Fix slice_last_group_size calculation
  (bsc#1012628).
- drm/msm/dsi: Remove incorrect references to slice_count
  (bsc#1012628).
- drm/msm/dp: Drop aux devices together with DP controller
  (bsc#1012628).
- drm/msm/dp: Free resources after unregistering them
  (bsc#1012628).
- arm64: dts: mediatek: Add cpufreq nodes for MT8192
  (bsc#1012628).
- arm64: dts: mediatek: mt8192: Fix CPUs capacity-dmips-mhz
  (bsc#1012628).
- arm64: dts: mt7986: increase bl2 partition on NAND of Bananapi
  R3 (bsc#1012628).
- drm/amdgpu: Fix memcpy() in
  sienna_cichlid_append_powerplay_table function (bsc#1012628).
- drm/amdgpu: Fix usage of UMC fill record in RAS (bsc#1012628).
- drm/msm/dpu: Drop unused poll_timeout_wr_ptr PINGPONG callback
  (bsc#1012628).
- drm/msm/dpu: Move autorefresh disable from CMD encoder to
  pingpong (bsc#1012628).
- drm/msm/dpu: Disable pingpong TE on DPU 5.0.0 and above
  (bsc#1012628).
- drm/msm/dpu: fix sc7280 and sc7180 PINGPONG done interrupts
  (bsc#1012628).
- drm/msm/dpu: correct MERGE_3D length (bsc#1012628).
- clk: mediatek: clk-mtk: Grab iomem pointer for divider clocks
  (bsc#1012628).
- clk: mediatek: clk-mt8173-apmixedsys: Fix return value for
  of_iomap() error (bsc#1012628).
- clk: mediatek: clk-mt8173-apmixedsys: Fix iomap not released
  issue (bsc#1012628).
- clk: vc5: check memory returned by kasprintf() (bsc#1012628).
- clk: cdce925: check return value of kasprintf() (bsc#1012628).
- clk: si5341: return error if one synth clock registration fails
  (bsc#1012628).
- clk: si5341: check return value of {devm_}kasprintf()
  (bsc#1012628).
- clk: si5341: free unused memory on probe failure (bsc#1012628).
- clk: keystone: sci-clk: check return value of kasprintf()
  (bsc#1012628).
- clk: ti: clkctrl: check return value of kasprintf()
  (bsc#1012628).
- clk: clocking-wizard: check return value of devm_kasprintf()
  (bsc#1012628).
- drivers: meson: secure-pwrc: always enable DMA domain
  (bsc#1012628).
- ovl: update of dentry revalidate flags after copy up
  (bsc#1012628).
- ASoC: imx-audmix: check return value of devm_kasprintf()
  (bsc#1012628).
- clk: Fix memory leak in devm_clk_notifier_register()
  (bsc#1012628).
- ARM: dts: lan966x: kontron-d10: fix board reset (bsc#1012628).
- ARM: dts: lan966x: kontron-d10: fix SPI CS (bsc#1012628).
- ASoC: amd: acp: clear pdm dma interrupt mask (bsc#1012628).
- iommufd: Do not access the area pointer after unlocking
  (bsc#1012628).
- iommufd: Call iopt_area_contig_done() under the lock
  (bsc#1012628).
- PCI: cadence: Fix Gen2 Link Retraining process (bsc#1012628).
- PCI: vmd: Reset VMD config register between soft reboots
  (bsc#1012628).
- scsi: qedf: Fix NULL dereference in error handling
  (bsc#1012628).
- pinctrl: bcm2835: Handle gpiochip_add_pin_range() errors
  (bsc#1012628).
- platform/x86: lenovo-yogabook: Fix work race on remove()
  (bsc#1012628).
- platform/x86: lenovo-yogabook: Reprobe devices on remove()
  (bsc#1012628).
- platform/x86: lenovo-yogabook: Set default keyboard backligh
  brightness on probe() (bsc#1012628).
- PCI/ASPM: Disable ASPM on MFD function removal to avoid
  use-after-free (bsc#1012628).
- scsi: 3w-xxxx: Add error handling for initialization failure
  in tw_probe() (bsc#1012628).
- pinctrl: at91: fix a couple NULL vs IS_ERR() checks
  (bsc#1012628).
- PCI: pciehp: Cancel bringup sequence if card is not present
  (bsc#1012628).
- perf evsel: Don't let for_each_group() treat the head of the
  list as one of its nodes (bsc#1012628).
- PCI: ftpci100: Release the clock resources (bsc#1012628).
- pinctrl: sunplus: Add check for kmalloc (bsc#1012628).
- scsi: ufs: Declare ufshcd_{hold,release}() once (bsc#1012628).
- PCI: Add pci_clear_master() stub for non-CONFIG_PCI
  (bsc#1012628).
- scsi: lpfc: Revise NPIV ELS unsol rcv cmpl logic to drop ndlp
  based on nlp_state (bsc#1012628).
- scsi: ufs: core: Increase the START STOP UNIT timeout from
  one to ten seconds (bsc#1012628).
- scsi: ufs: core: Fix handling of lrbp->cmd (bsc#1012628).
- pinctrl: tegra: Duplicate pinmux functions table (bsc#1012628).
- perf bench: Add missing setlocale() call to allow usage of
  %%'d style formatting (bsc#1012628).
- pinctrl: cherryview: Return correct value if pin in push-pull
  mode (bsc#1012628).
- platform/x86:intel/pmc: Remove Meteor Lake S platform support
  (bsc#1012628).
- platform/x86: think-lmi: mutex protection around multiple WMI
  calls (bsc#1012628).
- platform/x86: think-lmi: Correct System password interface
  (bsc#1012628).
- platform/x86: think-lmi: Correct NVME password handling
  (bsc#1012628).
- pinctrl:sunplus: Add check for kmalloc (bsc#1012628).
- pinctrl: npcm7xx: Add missing check for ioremap (bsc#1012628).
- kcsan: Don't expect 64 bits atomic builtins from 32 bits
  architectures (bsc#1012628).
- powerpc/interrupt: Don't read MSR from
  interrupt_exit_kernel_prepare() (bsc#1012628).
- powerpc/signal32: Force inlining of __unsafe_save_user_regs()
  and save_tm_user_regs_unsafe() (bsc#1012628).
- perf script: Fix allocation of evsel->priv related to per-event
  dump files (bsc#1012628).
- platform/x86: thinkpad_acpi: Fix lkp-tests warnings for platform
  profiles (bsc#1012628).
- platform/x86/intel/pmc: Add resume callback (bsc#1012628).
- platform/x86/intel/pmc/mtl: Put devices in D3 during resume
  (bsc#1012628).
- perf dwarf-aux: Fix off-by-one in die_get_varname()
  (bsc#1012628).
- perf metric: Fix no group check (bsc#1012628).
- perf tests task_analyzer: Fix bad substitution ${$1}
  (bsc#1012628).
- perf tests task_analyzer: Skip tests if no libtraceevent support
  (bsc#1012628).
- platform/x86/dell/dell-rbtn: Fix resources leaking on error path
  (bsc#1012628).
- perf tool x86: Consolidate is_amd check into single function
  (bsc#1012628).
- perf tool x86: Fix perf_env memory leak (bsc#1012628).
- powerpc/64s: Fix VAS mm use after free (bsc#1012628).
- pinctrl: freescale: Fix a memory out of bounds when num_configs
  is 1 (bsc#1012628).
- pinctrl: microchip-sgpio: check return value of devm_kasprintf()
  (bsc#1012628).
- pinctrl: at91-pio4: check return value of devm_kasprintf()
  (bsc#1012628).
- perf stat: Reset aggr stats for each run (bsc#1012628).
- scsi: ufs: core: Remove a ufshcd_add_command_trace() call
  (bsc#1012628).
- scsi: ufs: core: mcq: Fix the incorrect OCS value for the
  device command (bsc#1012628).
- powerpc/powernv/sriov: perform null check on iov before
  dereferencing iov (bsc#1012628).
- powerpc: update ppc_save_regs to save current r1 in pt_regs
  (bsc#1012628).
- riscv: hibernation: Remove duplicate call of
  suspend_restore_csrs (bsc#1012628).
- PCI: qcom: Use DWC helpers for modifying the read-only DBI
  registers (bsc#1012628).
- PCI: qcom: Disable write access to read only registers for IP
  v2.9.0 (bsc#1012628).
- platform/x86:intel/pmc: Update maps for Meteor Lake P/M
  platforms (bsc#1012628).
- riscv: uprobes: Restore thread.bad_cause (bsc#1012628).
- powerpc/book3s64/mm: Fix DirectMap stats in /proc/meminfo
  (bsc#1012628).
- powerpc/mm/dax: Fix the condition when checking if altmap
  vmemap can cross-boundary (bsc#1012628).
- perf test: Set PERF_EXEC_PATH for script execution
  (bsc#1012628).
- riscv: hibernate: remove WARN_ON in save_processor_state
  (bsc#1012628).
- PCI: endpoint: Fix a Kconfig prompt of vNTB driver
  (bsc#1012628).
- PCI: endpoint: functions/pci-epf-test: Fix dma_chan direction
  (bsc#1012628).
- PCI: vmd: Fix uninitialized variable usage in
  vmd_enable_domain() (bsc#1012628).
- vfio/mdev: Move the compat_class initialization to module init
  (bsc#1012628).
- hwrng: virtio - Fix race on data_avail and actual data
  (bsc#1012628).
- modpost: remove broken calculation of exception_table_entry size
  (bsc#1012628).
- crypto: nx - fix build warnings when DEBUG_FS is not enabled
  (bsc#1012628).
- modpost: fix section mismatch message for R_ARM_ABS32
  (bsc#1012628).
- modpost: fix section mismatch message for
  R_ARM_{PC24,CALL,JUMP24} (bsc#1012628).
- crypto: marvell/cesa - Fix type mismatch warning (bsc#1012628).
- crypto: jitter - correct health test during initialization
  (bsc#1012628).
- dt-bindings: qcom-qce: Fix compatible combinations for SM8150
  and IPQ4019 SoCs (bsc#1012628).
- scripts/mksysmap: Fix badly escaped '$' (bsc#1012628).
- modpost: fix off by one in is_executable_section()
  (bsc#1012628).
- ARC: define ASM_NL and __ALIGN(_STR) outside #ifdef __ASSEMBLY__
  guard (bsc#1012628).
- crypto: qat - unmap buffer before free for DH (bsc#1012628).
- crypto: qat - unmap buffers before free for RSA (bsc#1012628).
- NFSv4.2: fix wrong shrinker_id (bsc#1012628).
- NFSv4.1: freeze the session table upon receiving
  NFS4ERR_BADSESSION (bsc#1012628).
- SMB3: Do not send lease break acknowledgment if all file
  handles have been closed (bsc#1012628).
- dax: Fix dax_mapping_release() use after free (bsc#1012628).
- dax: Introduce alloc_dev_dax_id() (bsc#1012628).
- dax/kmem: Pass valid argument to memory_group_register_static
  (bsc#1012628).
- hwrng: st - keep clock enabled while hwrng is registered
  (bsc#1012628).
- ALSA: hda/realtek: Enable mute/micmute LEDs and limit mic
  boost on EliteBook (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Clevo NPx0SNx (bsc#1012628).
- ALSA: jack: Fix mutex call in snd_jack_report() (bsc#1012628).
- ALSA: pcm: Fix potential data race at PCM memory allocation
  helpers (bsc#1012628).
- apparmor: fix: kzalloc perms tables for shared dfas
  (bsc#1012628).
- block: fix signed int overflow in Amiga partition support
  (bsc#1012628).
- block: add overflow checks for Amiga partition support
  (bsc#1012628).
- block: change all __u32 annotations to __be32 in
  affs_hardblocks.h (bsc#1012628).
- block: increment diskseq on all media change events
  (bsc#1012628).
- mmc: block: ioctl: do write error check for spi (bsc#1012628).
- btrfs: fix race when deleting free space root from the dirty
  cow roots list (bsc#1012628).
- btrfs: do not BUG_ON() on tree mod log failure at
  balance_level() (bsc#1012628).
- SUNRPC: Fix UAF in svc_tcp_listen_data_ready() (bsc#1012628).
- kbuild: Fix CFI failures with GCOV (bsc#1012628).
- kbuild: Disable GCOV for *.mod.o (bsc#1012628).
- cxl/region: Move cache invalidation before region teardown,
  and before setup (bsc#1012628).
- cxl/region: Flag partially torn down regions as unusable
  (bsc#1012628).
- cxl/region: Fix state transitions after reset failure
  (bsc#1012628).
- tools/testing/cxl: Fix command effects for inject/clear poison
  (bsc#1012628).
- kbuild: builddeb: always make modules_install, to install
  modules.builtin* (bsc#1012628).
- kbuild: deb-pkg: remove the CONFIG_MODULES check in buildeb
  (bsc#1012628).
- efi/libstub: Disable PCI DMA before grabbing the EFI memory map
  (bsc#1012628).
- cifs: prevent use-after-free by freeing the cfile later
  (bsc#1012628).
- cifs: do all necessary checks for credits within or before
  locking (bsc#1012628).
- smb: client: fix broken file attrs with nodfs mounts
  (bsc#1012628).
- smb: client: fix shared DFS root mounts with different prefixes
  (bsc#1012628).
- ksmbd: avoid field overflow warning (bsc#1012628).
- arm64: sme: Use STR P to clear FFR context field in streaming
  SVE mode (bsc#1012628).
- x86/efi: Make efi_set_virtual_address_map IBT safe
  (bsc#1012628).
- w1: w1_therm: fix locking behavior in convert_t (bsc#1012628).
- w1: fix loop in w1_fini() (bsc#1012628).
- dt-bindings: power: reset: qcom-pon: Only allow reboot-mode
  pre-pmk8350 (bsc#1012628).
- f2fs: do not allow to defragment files have FI_COMPRESS_RELEASED
  (bsc#1012628).
- sh: j2: Use ioremap() to translate device tree address into
  kernel memory (bsc#1012628).
- cpufreq: tegra194: Fix an error handling path in
  tegra194_cpufreq_probe() (bsc#1012628).
- USB: Extend pci resume function to handle PM events
  (bsc#1012628).
- xhci: Improve the XHCI system resume time (bsc#1012628).
- usb: dwc2: Fix some error handling paths (bsc#1012628).
- serial: 8250: omap: Fix freeing of resources on failed register
  (bsc#1012628).
- interconnect: qcom: rpm: Rename icc provider num_clocks to
  num_bus_clocks (bsc#1012628).
- interconnect: qcom: rpm: Don't use clk_get_optional for bus
  clocks anymore (bsc#1012628).
- clk: qcom: gcc: ipq5332: Use floor ops for SDCC clocks
  (bsc#1012628).
- clk: qcom: mmcc-msm8974: remove oxili_ocmemgx_clk (bsc#1012628).
- clk: qcom: camcc-sc7180: Add parent dependency to all camera
  GDSCs (bsc#1012628).
- clk: qcom: gcc-ipq6018: Use floor ops for sdcc clocks
  (bsc#1012628).
- clk: qcom: gcc-qcm2290: Mark RCGs shared where applicable
  (bsc#1012628).
- media: usb: Check az6007_read() return value (bsc#1012628).
- media: amphion: drop repeated codec data for vc1l format
  (bsc#1012628).
- media: amphion: drop repeated codec data for vc1g format
  (bsc#1012628).
- media: common: saa7146: Avoid a leak in vmalloc_to_sg()
  (bsc#1012628).
- media: videodev2.h: Fix p_s32 and p_s64 pointer types
  (bsc#1012628).
- media: amphion: initiate a drain of the capture queue in
  dynamic resolution change (bsc#1012628).
- media: videodev2.h: Fix struct v4l2_input tuner index comment
  (bsc#1012628).
- media: usb: siano: Fix warning due to null work_func_t function
  pointer (bsc#1012628).
- media: i2c: imx296: fix error checking in
  imx296_read_temperature() (bsc#1012628).
- media: i2c: Correct format propagation for st-mipid02
  (bsc#1012628).
- media: renesas: fdp1: Identify R-Car Gen2 versions
  (bsc#1012628).
- media: hi846: fix usage of pm_runtime_get_if_in_use()
  (bsc#1012628).
- media: mediatek: vcodec: using decoder status instead of core
  work count (bsc#1012628).
- clk: qcom: ipq6018: fix networking resets (bsc#1012628).
- clk: qcom: dispcc-qcm2290: Fix BI_TCXO_AO handling
  (bsc#1012628).
- clk: qcom: dispcc-qcm2290: Fix GPLL0_OUT_DIV handling
  (bsc#1012628).
- clk: qcom: ipq5332: fix the src parameter in
  ftbl_gcc_apss_axi_clk_src (bsc#1012628).
- clk: qcom: ipq5332: fix the order of SLEEP_CLK and XO clock
  (bsc#1012628).
- clk: qcom: mmcc-msm8974: use clk_rcg2_shared_ops for mdp_clk_src
  clock (bsc#1012628).
- staging: vchiq_arm: mark vchiq_platform_init() static
  (bsc#1012628).
- soundwire: qcom: use consistently 'ctrl' as state variable name
  (bsc#1012628).
- soundwire: qcom: fix unbalanced pm_runtime_put() (bsc#1012628).
- soundwire: debugfs: fix unbalanced pm_runtime_put()
  (bsc#1012628).
- usb: dwc3: qcom: Fix potential memory leak (bsc#1012628).
- usb: gadget: u_serial: Add null pointer check in gserial_suspend
  (bsc#1012628).
- extcon: Fix kernel doc of property fields to avoid warnings
  (bsc#1012628).
- extcon: Fix kernel doc of property capability fields to avoid
  warnings (bsc#1012628).
- usb: phy: phy-tahvo: fix memory leak in tahvo_usb_probe()
  (bsc#1012628).
- usb: hide unused usbfs_notify_suspend/resume functions
  (bsc#1012628).
- usb: misc: eud: Fix eud sysfs path (use 'qcom_eud')
  (bsc#1012628).
- serial: core: lock port for stop_rx() in uart_suspend_port()
  (bsc#1012628).
- serial: 8250: lock port for stop_rx() in omap8250_irq()
  (bsc#1012628).
- serial: core: lock port for start_rx() in uart_resume_port()
  (bsc#1012628).
- serial: 8250: lock port for UART_IER access in omap8250_irq()
  (bsc#1012628).
- kernfs: fix missing kernfs_idr_lock to remove an ID from the
  IDR (bsc#1012628).
- lkdtm: replace ll_rw_block with submit_bh (bsc#1012628).
- i3c: master: svc: fix cpu schedule in spin lock (bsc#1012628).
- coresight: Fix loss of connection info when a module is unloaded
  (bsc#1012628).
- coresight: etm4x: Fix missing trctraceidr file in sysfs
  (bsc#1012628).
- power: supply: rt9467: Make charger-enable control as logic
  level (bsc#1012628).
- mfd: rt5033: Drop rt5033-battery sub-device (bsc#1012628).
- media: venus: helpers: Fix ALIGN() of non power of two
  (bsc#1012628).
- media: atomisp: gc0310: Fix double free in gc0310_remove()
  (bsc#1012628).
- media: atomisp: gmin_platform: fix out_len in
  gmin_get_config_dsm_var() (bsc#1012628).
- media: atomisp: ov2680: Stop using half pixelclock for binned
  modes (bsc#1012628).
- sh: Avoid using IRQ0 on SH3 and SH4 (bsc#1012628).
- gfs2: Fix duplicate should_fault_in_pages() call (bsc#1012628).
- f2fs: fix potential deadlock due to unpaired node_write lock
  use (bsc#1012628).
- f2fs: fix to avoid NULL pointer dereference f2fs_write_end_io()
  (bsc#1012628).
- f2fs: support errors=remount-ro|continue|panic mountoption
  (bsc#1012628).
- f2fs: fix the wrong condition to determine atomic context
  (bsc#1012628).
- f2fs: flush error flags in workqueue (bsc#1012628).
- KVM: s390: fix KVM_S390_GET_CMMA_BITS for GFNs in memslot holes
  (bsc#1012628).
- usb: dwc3: qcom: Release the correct resources in
  dwc3_qcom_remove() (bsc#1012628).
- usb: dwc3: qcom: Fix an error handling path in dwc3_qcom_probe()
  (bsc#1012628).
- usb: common: usb-conn-gpio: Set last role to unknown before
  initial detection (bsc#1012628).
- usb: dwc3-meson-g12a: Fix an error handling path in
  dwc3_meson_g12a_probe() (bsc#1012628).
- rtla/hwnoise: Reduce runtime to 75%% (bsc#1012628).
- mfd: wcd934x: Fix an error handling path in wcd934x_slim_probe()
  (bsc#1012628).
- mfd: intel-lpss: Add missing check for platform_get_resource
  (bsc#1012628).
- Revert "usb: common: usb-conn-gpio: Set last role to unknown
  before initial detection" (bsc#1012628).
- serial: 8250_omap: Use force_suspend and resume for system
  suspend (bsc#1012628).
- drivers: fwnode: fix fwnode_irq_get[_byname]() (bsc#1012628).
- cdx: fix driver managed dma support (bsc#1012628).
- nvmem: sunplus-ocotp: release otp->clk before return
  (bsc#1012628).
- nvmem: imx-ocotp: Reverse MAC addresses on all i.MX derivates
  (bsc#1012628).
- test_firmware: return ENOMEM instead of ENOSPC on failed memory
  allocation (bsc#1012628).
- nvmem: rmem: Use NVMEM_DEVID_AUTO (bsc#1012628).
- bus: fsl-mc: don't assume child devices are all fsl-mc devices
  (bsc#1012628).
- mfd: stmfx: Fix error path in stmfx_chip_init (bsc#1012628).
- mfd: stmfx: Nullify stmfx->vdd in case of error (bsc#1012628).
- KVM: s390: vsie: fix the length of APCB bitmap (bsc#1012628).
- KVM: s390/diag: fix racy access of physical cpu number in diag
  9c handler (bsc#1012628).
- cpufreq: mediatek: correct voltages for MT7622 and MT7623
  (bsc#1012628).
- misc: fastrpc: check return value of devm_kasprintf()
  (bsc#1012628).
- clk: qcom: mmcc-msm8974: fix MDSS_GDSC power flags
  (bsc#1012628).
- hwtracing: hisi_ptt: Fix potential sleep in atomic context
  (bsc#1012628).
- phy: qcom: qmp-combo: fix Display Port PHY configuration for
  SM8550 (bsc#1012628).
- mfd: stmpe: Only disable the regulators if they are enabled
  (bsc#1012628).
- phy: tegra: xusb: check return value of devm_kzalloc()
  (bsc#1012628).
- lib/bitmap: drop optimization of bitmap_{from,to}_arr64
  (bsc#1012628).
- pwm: imx-tpm: force 'real_period' to be zero in suspend
  (bsc#1012628).
- pwm: sysfs: Do not apply state to already disabled PWMs
  (bsc#1012628).
- pwm: ab8500: Fix error code in probe() (bsc#1012628).
- pwm: mtk_disp: Fix the disable flow of disp_pwm (bsc#1012628).
- md/raid10: fix the condition to call bio_end_io_acct()
  (bsc#1012628).
- perf bpf: Move the declaration of struct rq (bsc#1012628).
- blk-throttle: Fix io statistics for cgroup v1 (bsc#1012628).
- rtc: st-lpc: Release some resources in st_rtc_probe() in case
  of error (bsc#1012628).
- drm/i915/psr: Use hw.adjusted mode when calculating io/fast
  wake times (bsc#1012628).
- drm/i915/guc/slpc: Apply min softlimit correctly (bsc#1012628).
- f2fs: check return value of freeze_super() (bsc#1012628).
- virtio-vdpa: Fix unchecked call to NULL set_vq_affinity
  (bsc#1012628).
- tools/virtio: fix build break for aarch64 (bsc#1012628).
- media: tc358746: select CONFIG_GENERIC_PHY (bsc#1012628).
- media: cec: i2c: ch7322: also select REGMAP (bsc#1012628).
- sctp: fix potential deadlock on &net->sctp.addr_wq_lock
  (bsc#1012628).
- net/sched: act_ipt: add sanity checks on table name and hook
  locations (bsc#1012628).
- net/sched: act_ipt: add sanity checks on skb before calling
  target (bsc#1012628).
- net/sched: act_ipt: zero skb->cb before calling target
  (bsc#1012628).
- spi: spi-geni-qcom: enable SPI_CONTROLLER_MUST_TX for GPI DMA
  mode (bsc#1012628).
- net: mscc: ocelot: don't report that RX timestamping is enabled
  by default (bsc#1012628).
- net: mscc: ocelot: don't keep PTP configuration of all ports
  in single structure (bsc#1012628).
- net: dsa: felix: don't drop PTP frames with tag_8021q when RX
  timestamping is disabled (bsc#1012628).
- net: dsa: sja1105: always enable the INCL_SRCPT option
  (bsc#1012628).
- net: dsa: tag_sja1105: always prefer source port information
  from INCL_SRCPT (bsc#1012628).
- Add MODULE_FIRMWARE() for FIRMWARE_TG357766 (bsc#1012628).
- Bluetooth: fix invalid-bdaddr quirk for non-persistent setup
  (bsc#1012628).
- Bluetooth: ISO: use hci_sync for setting CIG parameters
  (bsc#1012628).
- Bluetooth: MGMT: Fix marking SCAN_RSP as not connectable
  (bsc#1012628).
- sfc: support for devlink port requires MAE access (bsc#1012628).
- ibmvnic: Do not reset dql stats on NON_FATAL err (bsc#1012628).
- net: dsa: vsc73xx: fix MTU configuration (bsc#1012628).
- mlxsw: minimal: fix potential memory leak in
  mlxsw_m_linecards_init (bsc#1012628).
- spi: bcm-qspi: return error if neither hif_mspi nor mspi is
  available (bsc#1012628).
- mailbox: ti-msgmgr: Fill non-message tx data fields with 0x0
  (bsc#1012628).
- f2fs: fix error path handling in truncate_dnode() (bsc#1012628).
- octeontx2-af: cn10kb: fix interrupt csr addresses (bsc#1012628).
- octeontx2-af: Fix mapping for NIX block from CGX connection
  (bsc#1012628).
- octeontx2-af: Add validation before accessing cgx and lmac
  (bsc#1012628).
- octeontx2-af: Reset MAC features in FLR (bsc#1012628).
- ntfs: Fix panic about slab-out-of-bounds caused by
  ntfs_listxattr() (bsc#1012628).
- powerpc: allow PPC_EARLY_DEBUG_CPM only when SERIAL_CPM=y
  (bsc#1012628).
- powerpc: dts: turris1x.dts: Fix PCIe MEM size for pci2 node
  (bsc#1012628).
- net: bridge: keep ports without IFF_UNICAST_FLT in BR_PROMISC
  mode (bsc#1012628).
- net: dsa: tag_sja1105: fix source port decoding in
  vlan_filtering=0 bridge mode (bsc#1012628).
- net: fix net_dev_start_xmit trace event vs
  skb_transport_offset() (bsc#1012628).
- tcp: annotate data races in __tcp_oow_rate_limited()
  (bsc#1012628).
- vduse: fix NULL pointer dereference (bsc#1012628).
- bpf, btf: Warn but return no error for NULL btf from
  __register_btf_kfunc_id_set() (bsc#1012628).
- xsk: Honor SO_BINDTODEVICE on bind (bsc#1012628).
- net/sched: act_pedit: Add size check for TCA_PEDIT_PARMS_EX
  (bsc#1012628).
- drm/i915/psr: Fix BDW PSR AUX CH data register offsets
  (bsc#1012628).
- fanotify: disallow mount/sb marks on kernel internal pseudo fs
  (bsc#1012628).
- riscv: move memblock_allow_resize() after linear mapping is
  ready (bsc#1012628).
- pptp: Fix fib lookup calls (bsc#1012628).
- net: dsa: tag_sja1105: fix MAC DA patching from meta frames
  (bsc#1012628).
- net: dsa: sja1105: always enable the send_meta options
  (bsc#1012628).
- octeontx-af: fix hardware timestamp configuration (bsc#1012628).
- afs: Fix accidental truncation when storing data (bsc#1012628).
- s390/qeth: Fix vipa deletion (bsc#1012628).
- risc-v: Fix order of IPI enablement vs RCU startup
  (bsc#1012628).
- sh: dma: Fix DMA channel offset calculation (bsc#1012628).
- apparmor: fix missing error check for rhashtable_insert_fast
  (bsc#1012628).
- apparmor: add missing failure check in compute_xmatch_perms
  (bsc#1012628).
- apparmor: fix policy_compat permission remap with extended
  permissions (bsc#1012628).
- apparmor: fix profile verification and enable it (bsc#1012628).
- i2c: xiic: Don't try to handle more interrupt events after error
  (bsc#1012628).
- writeback: account the number of pages written back
  (bsc#1012628).
- lib: dhry: fix sleeping allocations inside non-preemptable
  section (bsc#1012628).
- Revert "drm/amd/display: Move DCN314 DOMAIN power control to
  DMCUB" (bsc#1012628).
- arm64/signal: Restore TPIDR2 register rather than memory state
  (bsc#1012628).
- irqchip/loongson-liointc: Fix IRQ trigger polarity
  (bsc#1012628).
- nfsd: move init of percpu reply_cache_stats counters back to
  nfsd_init_net (bsc#1012628).
- irqchip/loongson-pch-pic: Fix potential incorrect hwirq
  assignment (bsc#1012628).
- NFSD: add encoding of op_recall flag for write delegation
  (bsc#1012628).
- irqchip/loongson-pch-pic: Fix initialization of HT vector
  register (bsc#1012628).
- io_uring: wait interruptibly for request completions on exit
  (bsc#1012628).
- mm/mglru: make memcg_lru->lock irq safe (bsc#1012628).
- mmc: core: disable TRIM on Kingston EMMC04G-M627 (bsc#1012628).
- mmc: core: disable TRIM on Micron MTFC4GACAJCN-1M (bsc#1012628).
- mmc: mmci: Set PROBE_PREFER_ASYNCHRONOUS (bsc#1012628).
- mmc: sdhci: fix DMA configure compatibility issue when 64bit
  DMA mode is used (bsc#1012628).
- wifi: cfg80211: fix regulatory disconnect for non-MLO
  (bsc#1012628).
- wifi: ath10k: Serialize wake_tx_queue ops (bsc#1012628).
- wifi: cfg80211: fix receiving mesh packets without RFC1042
  header (bsc#1012628).
- wifi: mt76: mt7921e: fix init command fail with enabled device
  (bsc#1012628).
- bcache: fixup btree_cache_wait list damage (bsc#1012628).
- bcache: Remove unnecessary NULL point check in node allocations
  (bsc#1012628).
- bcache: Fix __bch_btree_node_alloc to make the failure behavior
  consistent (bsc#1012628).
- watch_queue: prevent dangling pipe pointer (bsc#1012628).
- um: Use HOST_DIR for mrproper (bsc#1012628).
- integrity: Fix possible multiple allocation in
  integrity_inode_get() (bsc#1012628).
- autofs: use flexible array in ioctl structure (bsc#1012628).
- mm/damon/ops-common: atomically test and clear young on ptes
  and pmds (bsc#1012628).
- shmem: use ramfs_kill_sb() for kill_sb method of ramfs-based
  tmpfs (bsc#1012628).
- nfsd: use vfs setgid helper (bsc#1012628).
- jffs2: reduce stack usage in jffs2_build_xattr_subsystem()
  (bsc#1012628).
- fs: avoid empty option when generating legacy mount string
  (bsc#1012628).
- ext4: Remove ext4 locking of moved directory (bsc#1012628).
- Revert "f2fs: fix potential corruption when moving a directory"
  (bsc#1012628).
- Revert "udf: Protect rename against modification of moved
  directory" (bsc#1012628).
- fs: Establish locking order for unrelated directories
  (bsc#1012628).
- fs: Lock moved directories (bsc#1012628).
- usb: typec: ucsi: Mark dGPUs as DEVICE scope (bsc#1012628).
- ipvs: increase ip_vs_conn_tab_bits range for 64BIT
  (bsc#1012628).
- btrfs: add handling for RAID1C23/DUP to
  btrfs_reduce_alloc_profile (bsc#1012628).
- btrfs: fix dirty_metadata_bytes for redirtied buffers
  (bsc#1012628).
- btrfs: insert tree mod log move in push_node_left (bsc#1012628).
- btrfs: warn on invalid slot in tree mod log rewind
  (bsc#1012628).
- btrfs: delete unused BGs while reclaiming BGs (bsc#1012628).
- btrfs: bail out reclaim process if filesystem is read-only
  (bsc#1012628).
- btrfs: add block-group tree to lockdep classes (bsc#1012628).
- btrfs: reinsert BGs failed to reclaim (bsc#1012628).
- btrfs: fix race when deleting quota root from the dirty cow
  roots list (bsc#1012628).
- btrfs: add missing error handling when logging operation while
  COWing extent buffer (bsc#1012628).
- btrfs: fix extent buffer leak after tree mod log failure at
  split_node() (bsc#1012628).
- btrfs: do not BUG_ON() on tree mod log failure at
  __btrfs_cow_block() (bsc#1012628).
- ASoC: mediatek: mt8173: Fix irq error path (bsc#1012628).
- ASoC: mediatek: mt8173: Fix snd_soc_component_initialize error
  path (bsc#1012628).
- regulator: tps65219: Fix matching interrupts for their
  regulators (bsc#1012628).
- ARM: dts: qcom: msm8660: Fix regulator node names (bsc#1012628).
- ARM: dts: qcom: ipq4019: fix broken NAND controller properties
  override (bsc#1012628).
- ARM: orion5x: fix d2net gpio initialization (bsc#1012628).
- leds: trigger: netdev: Recheck NETDEV_LED_MODE_LINKUP on dev
  rename (bsc#1012628).
- blktrace: use inline function for blk_trace_remove() while
  blktrace is disabled (bsc#1012628).
- Input: ads7846 - Fix usage of match data (bsc#1012628).
- md/raid1-10: fix casting from randomized structure in
  raid1_submit_write() (bsc#1012628).
- fs: no need to check source (bsc#1012628).
- Input: ads7846 - fix pointer cast warning (bsc#1012628).
- mips: Include KBUILD_CPPFLAGS in CHECKFLAGS invocation
  (bsc#1012628).
- powerpc/vdso: Include CLANG_FLAGS explicitly in ldflags-y
  (bsc#1012628).
- kbuild: Add CLANG_FLAGS to as-instr (bsc#1012628).
- kbuild: Add KBUILD_CPPFLAGS to as-option invocation
  (bsc#1012628).
- kbuild: add $(CLANG_FLAGS) to KBUILD_CPPFLAGS (bsc#1012628).
- ovl: fix null pointer dereference in ovl_permission()
  (bsc#1012628).
- ovl: let helper ovl_i_path_real() return the realinode
  (bsc#1012628).
- ovl: fix null pointer dereference in ovl_get_acl_rcu()
  (bsc#1012628).
- LoongArch: Include KBUILD_CPPFLAGS in CHECKFLAGS invocation
  (bsc#1012628).
- netfilter: conntrack: Avoid nf_ct_helper_hash uses after free
  (bsc#1012628).
- netfilter: nf_tables: do not ignore genmask when looking up
  chain by id (bsc#1012628).
- netfilter: nf_tables: prevent OOB access in nft_byteorder_eval
  (bsc#1012628).
- wireguard: queueing: use saner cpu selection wrapping
  (bsc#1012628).
- wireguard: netlink: send staged packets when setting initial
  private key (bsc#1012628).
- tty: serial: fsl_lpuart: add earlycon for imx8ulp platform
  (bsc#1012628).
- io_uring: Use io_schedule* in cqring wait (bsc#1012628).
- block/partition: fix signedness issue for Amiga partitions
  (bsc#1012628).
- sh: mach-r2d: Handle virq offset in cascaded IRL demux
  (bsc#1012628).
- sh: mach-highlander: Handle virq offset in cascaded IRL demux
  (bsc#1012628).
- sh: mach-dreamcast: Handle virq offset in cascaded IRQ demux
  (bsc#1012628).
- sh: hd64461: Handle virq offset for offchip IRQ base and
  HD64461 IRQ (bsc#1012628).
- commit 919c802
* Tue Jul 18 2023 msuchanek@suse.de
- Revert "kbuild: Hack for depmod not handling X.Y versions" (bsc#1212835).
- Refresh patches.rpmify/usrmerge-Adjust-module-path-in-the-kernel-sources.patch.
- commit 8a9c423
* Tue Jul 18 2023 jslaby@suse.cz
- ACPI: video: Add backlight=native DMI quirk for Lenovo Ideapad
  Z470 (bsc#1208724).
- commit 54e3bad
* Tue Jul 18 2023 jslaby@suse.cz
- pinctrl: amd: Unify debounce handling into amd_pinconf_set()
  (bko#217336).
- pinctrl: amd: Drop pull up select configuration (bko#217336).
- pinctrl: amd: Use amd_pinconf_set() for all config options
  (bko#217336).
- pinctrl: amd: Only use special debounce behavior for GPIO 0
  (bko#217336).
- pinctrl: amd: Revert "pinctrl: amd: disable and mask interrupts
  on probe" (bko#217336).
- pinctrl: amd: Detect and mask spurious interrupts (bko#217336).
- pinctrl: amd: Fix mistake in handling clearing pins at startup
  (bko#217336).
- pinctrl: amd: Detect internal GPIO0 debounce handling
  (bko#217336).
- commit a3dbbc0
* Mon Jul 17 2023 msuchanek@suse.de
- rpm: Update dependency to match current kmod.
- Refresh patches.rpmify/usrmerge-Adjust-module-path-in-the-kernel-sources.patch.
  Update to match current kmod (bsc#1212835).
- commit d687dc3
* Mon Jul 17 2023 jslaby@suse.cz
- Refresh
  patches.suse/drm-amdgpu-sdma4-set-align-mask-to-255.patch.
  Update to upstream version. 6.4 already contains 4_4_2.
- commit 48f7169
* Mon Jul 17 2023 mkubecek@suse.cz
- Update to 6.5-rc2
- eliminate 1 patch
  - patches.rpmify/objtool-initialize-all-of-struct-elf.patch (9f71fbcde282)
- commit c159bc5
* Thu Jul 13 2023 msuchanek@suse.de
- of: Preserve "of-display" device name for compatibility
  (bsc#1212405).
- commit 58e8dc0
* Thu Jul 13 2023 msuchanek@suse.de
- depmod: Handle installing modules under a prefix (bsc#1212835).
- commit b2abe86
* Wed Jul 12 2023 jgross@suse.com
- Restore kABI for NVidia vGPU driver (bsc#1210825).
- commit 01c9bbd
* Wed Jul 12 2023 tiwai@suse.de
- Move upstreamed AMDGPU patches into sorted section
- commit f6ca0bc
* Tue Jul 11 2023 jslaby@suse.cz
- Linux 6.4.3 (bsc#1012628).
- mm: call arch_swap_restore() from do_swap_page() (bsc#1012628).
- bootmem: remove the vmemmap pages from kmemleak in
  free_bootmem_page (bsc#1012628).
- commit 5fb5b21
* Mon Jul 10 2023 schwab@suse.de
- rpm/check-for-config-changes: ignore also RISCV_ISA_* and DYNAMIC_SIGFRAME
  They depend on CONFIG_TOOLCHAIN_HAS_*.
- commit 1007103
* Mon Jul 10 2023 jslaby@suse.cz
- Refresh
  patches.suse/fork-lock-VMAs-of-the-parent-process-when-forking.patch.
  Replace by the correct one. It was merged to upstream twice. And this is
  the right version.
- commit b97b894
* Mon Jul 10 2023 jslaby@suse.cz
- Update vanilla config files.
  Just run oldconfig for vanillas too. No actual changes.
- commit dcdca04
* Mon Jul 10 2023 jslaby@suse.cz
- Update
  patches.kernel.org/6.4.1-021-mm-always-expand-the-stack-with-the-mmap-write-.patch
  (bsc#1012628 bsc#1212395 CVE-2023-3269).
  Add references to CVE.
- commit 5a45f18
* Mon Jul 10 2023 mkubecek@suse.cz
- refresh vanilla configs
- commit ab4066a
* Mon Jul 10 2023 jslaby@suse.cz
- Update config files.
  Only run_oldconfig.
- commit 37ad463
* Mon Jul 10 2023 jslaby@suse.cz
- fork: lock VMAs of the parent process when forking
  (bsc#1212775).
- mm: lock a vma before stack expansion (bsc#1212775).
- mm: lock newly mapped VMA which can be modified after it
  becomes visible (bsc#1212775).
- mm: lock newly mapped VMA with corrected ordering (bsc#1212775).
- Update config files.
- Delete
  patches.suse/Revert-x86-mm-try-VMA-lock-based-page-fault-handling.patch.
  Drop the downstream revert in favor of upstream fixes above and reset
  the configs -- leave STATS off as per default.
- commit e2dafc9
* Mon Jul 10 2023 jslaby@suse.cz
- Delete
  patches.suse/Revert-x86-mm-try-VMA-lock-based-page-fault-handling.patch.
- Update config files.
  It was fixed in 6.5-rc1 by commits:
  fb49c455 fork: lock VMAs of the parent process when forking
  2b4f3b49 fork: lock VMAs of the parent process when forking
  1c7873e3 mm: lock newly mapped VMA with corrected ordering
  33313a74 mm: lock newly mapped VMA which can be modified after it becomes visible
  c137381f mm: lock a vma before stack expansion
  So drop the downstream revert and reset the configs -- leave STATS off
  as per default.
- commit 50f64ca
* Mon Jul 10 2023 mkubecek@suse.cz
- Update to 6.5-rc1
- drop 34 patches (33 stable, 1 mainline)
  - patches.kernel.org/*
  - patches.suse/HID-microsoft-Add-rumble-support-to-latest-xbox-cont.patch
- refresh
  - patches.suse/0003-efi-Lock-down-the-kernel-if-booted-in-secure-boot-mode.patch
  - patches.suse/0004-efi-Lock-down-the-kernel-at-the-integrity-level-if-b.patch
  - patches.suse/HID-microsoft-Add-rumble-support-to-latest-xbox-cont.patch
  - patches.suse/add-suse-supported-flag.patch
  - patches.suse/iwlwifi-cfg-Add-missing-MODULE_FIRMWARE-for-pnvm.patch
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/vfs-add-super_operations-get_inode_dev
- add build failure fix
  - patches.rpmify/objtool-initialize-all-of-struct-elf.patch
- disable ARM architectures (need config update)
- new config options
  - General setup
  - CACHESTAT_SYSCALL=y
  - Power management and ACPI options
  - X86_AMD_PSTATE_DEFAULT_MODE=3
  - Memory Management options
  - ZSWAP_EXCLUSIVE_LOADS_DEFAULT_ON=n
  - SLAB_DEPRECATED=n
  - Cryptographic API
  - CRYPTO_JITTERENTROPY_TESTINTERFACE=n
  - Kernel hacking
  - HARDLOCKUP_DETECTOR_PREFER_BUDDY=n
  - WQ_CPU_INTENSIVE_REPORT=n
  - FUNCTION_GRAPH_RETVAL=y
  - FPROBE_EVENTS=y
  - PROBE_EVENTS_BTF_ARGS=y
  - PCI support
  - PCI_EPF_MHI=m
  - CXL_PMU=m
  - Misc devices
  - INTEL_MEI_GSC_PROXY=m
  - TPS6594_ESM=m
  - TPS6594_PFSM=m
  - Network device support
  - CAN_F81604=m
  - PPPOE_HASH_BITS_1=n
  - PPPOE_HASH_BITS_2=n
  - PPPOE_HASH_BITS_4=y
  - PPPOE_HASH_BITS_8=n
  - RTW88_8723DS=m
  - RTW89_8851BE=m
  - Hardware Monitoring support
  - MAX31827=m
  - SENSORS_HP_WMI=m
  - Multifunction device drivers
  - MFD_MAX77541=n
  - MFD_TPS6594_I2C=m
  - MFD_TPS6594_SPI=m
  - Sound card support
  - SND_SEQ_UMP=y
  - SND_UMP_LEGACY_RAWMIDI=y
  - SND_PCMTEST=m
  - SND_USB_AUDIO_MIDI_V2=y
  - SND_SOC_CHV3_I2S=m
  - SND_SOC_CHV3_CODEC=m
  - SND_SOC_MAX98388=m
  - SND_SOC_RT722_SDCA_SDW=m
  - SND_SOC_TAS2781_I2C=n
  - SND_SOC_WSA884X=n
  - HID bus support
  - HID_NVIDIA_SHIELD=m
  - NVIDIA_SHIELD_FF=y
  - USB support
  - USB_CDNS2_UDC=m
  - TYPEC_MUX_NB7VPQ904M=m
  - LED Support
  - LEDS_AW200XX=m
  - LEDS_CHT_WCOVE=m
  - LEDS_SIEMENS_SIMATIC_IPC_APOLLOLAKE=m
  - LEDS_SIEMENS_SIMATIC_IPC_F7188X=m
  - X86 Platform Specific Device Drivers
  - YOGABOOK=m
  - AMD_PMF_DEBUG=n
  - Industrial I/O support
  - ROHM_BU27008=m
  - OPT4001=n
  - X9250=m
  - MPRLS0025PA=n
  - Misc devices
  - INTEL_MEI_GSC_PROXY=m
  - TPS6594_ESM=m
  - TPS6594_PFSM=m
  - THERMAL_DEFAULT_GOV_BANG_BANG=n
  - REGULATOR_RAA215300=m
  - VIDEO_OV01A10=m
  - DRM_AMDGPU_WERROR=n
  - PDS_VDPA=m
  - INTEL_RAPL_TPMI=m
  - CXL_PMU=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - MFD_MAX5970=m
  - MFD_RK8XX_I2C=n
  - MFD_RK8XX_SPI=n
  - REGULATOR_TPS6287X=m
  - REGULATOR_TPS6594=m
  - DRM_PANEL_SAMSUNG_S6D7AA0=n
  - i386
  - SND_SOC_SSM3515=n
  - i386/default
  - TOUCHSCREEN_MK712=m
  - s390x
  - RFKILL_GPIO=m
  - TI_ST=m
  - GP_PCI1XXXX=m
  - MDIO_GPIO=m
  - ISDN=n
  - I2C_CBUS_GPIO=m
  - I2C_GPIO=m
  - I2C_GPIO_FAULT_INJECTOR=n
  - GPIOLIB_FASTPATH_LIMIT=512
  - DEBUG_GPIO=n
  - GPIO_SYSFS=y
  - GPIO_CDEV_V1=y
  - GPIO_DWAPB=n
  - GPIO_GENERIC_PLATFORM=m
  - GPIO_MB86S7X=n
  - GPIO_AMD_FCH=m
  - GPIO_FXL6408=m
  - GPIO_MAX7300=m
  - GPIO_MAX732X=m
  - GPIO_PCA953X=m
  - GPIO_PCA953X_IRQ=y
  - GPIO_PCA9570=m
  - GPIO_PCF857X=m
  - GPIO_TPIC2810=m
  - GPIO_BT8XX=n
  - GPIO_PCI_IDIO_16=m
  - GPIO_PCIE_IDIO_24=m
  - GPIO_RDC321X=n
  - GPIO_AGGREGATOR=m
  - GPIO_LATCH=m
  - GPIO_MOCKUP=m
  - GPIO_VIRTIO=m
  - GPIO_SIM=m
  - SENSORS_LTC2992=n
  - SENSORS_SHT15=m
  - MEN_A21_WDT=m
  - SSB_DRIVER_GPIO=y
  - TPS65010=m
  - REGULATOR_GPIO=m
  - REGULATOR_TPS65132=m
  - FB_SSD1307=n
  - HD44780=m
  - PANEL_CHANGE_MESSAGE=n
  - EXTCON_GPIO=m
  - EXTCON_MAX3355=m
  - EXTCON_PTN5150=m
  - EXTCON_USB_GPIO=n
  - MUX_GPIO=n
  - s390x/zfcpdump
  - NVME_TARGET=y
  - NVME_TARGET_LOOP=y
  - NVME_TARGET_FC=y
  - NVME_TARGET_AUTH=n
  - NVME_MULTIPATH=y
  - NVME_VERBOSE_ERRORS=n
  - NVME_AUTH=n
  - NVME_TARGET_PASSTHRU=n
  - MOST=n
  - riscv64
  - LD_DEAD_CODE_DATA_ELIMINATION=n
  - ARCH_THEAD=y
  - IRQ_STACKS=y
  - THREAD_SIZE_ORDER=2
  - SUSPEND=y
  - SUSPEND_SKIP_SYNC=n
  - PM_AUTOSLEEP=n
  - PM_USERSPACE_AUTOSLEEP=n
  - PM_WAKELOCKS=n
  - PM_TEST_SUSPEND=n
  - ACPI=y
  - ACPI_DEBUGGER=n
  - ACPI_SPCR_TABLE=y
  - ACPI_EC_DEBUGFS=m
  - ACPI_AC=m
  - ACPI_BATTERY=m
  - ACPI_BUTTON=m
  - ACPI_TINY_POWER_BUTTON=m
  - ACPI_TINY_POWER_BUTTON_SIGNAL=38
  - ACPI_VIDEO=m
  - ACPI_FAN=m
  - ACPI_TAD=m
  - ACPI_DOCK=y
  - ACPI_IPMI=m
  - ACPI_CUSTOM_DSDT_FILE=""
  - ACPI_DEBUG=y
  - ACPI_PCI_SLOT=y
  - ACPI_CONTAINER=y
  - ACPI_HED=y
  - ACPI_CUSTOM_METHOD=m
  - ACPI_NFIT=m
  - NFIT_SECURITY_DEBUG=n
  - ACPI_CONFIGFS=m
  - ACPI_PFRUT=m
  - ACPI_FFH=y
  - PMIC_OPREGION=y
  - BT_HCIUART_RTL=y
  - PCIE_EDR=y
  - HOTPLUG_PCI_ACPI=y
  - HOTPLUG_PCI_ACPI_IBM=m
  - CXL_ACPI=m
  - FW_CACHE=y
  - ISCSI_IBFT=m
  - EFI_CUSTOM_SSDT_OVERLAYS=y
  - PNP_DEBUG_MESSAGES=n
  - ATA_ACPI=y
  - SATA_ZPODD=y
  - PATA_ACPI=m
  - NET_SB1000=n
  - FUJITSU_ES=m
  - TOUCHSCREEN_CHIPONE_ICN8505=m
  - INPUT_SOC_BUTTON_ARRAY=m
  - SERIAL_8250_PNP=y
  - TCG_INFINEON=m
  - ACPI_I2C_OPREGIOSENSORS_ACPI_POWERN=y
  - I2C_AMD_MP2=m
  - I2C_SCMI=m
  - SPI_RZV2M_CSI=m
  - PINCTRL_AMD=y
  - GPIO_AMDPT=m
  - SENSORS_NCT6775=m
  - SENSORS_ACPI_POWER=m
  - WDAT_WDT=m
  - IR_ENE=m
  - IR_FINTEK=m
  - IR_ITE_CIR=m
  - IR_NUVOTON=m
  - VIDEO_OV2740=m
  - VIDEO_OV9734=m
  - DRM_SHMOBILE=n
  - SND_HDA_SCODEC_CS35L41_I2C=m
  - SND_HDA_SCODEC_CS35L41_SPI=m
  - SND_SOC_AMD_CZ_DA7219MX98357_MACH=m
  - SND_SOC_AMD_ST_ES8336_MACH=m
  - SND_SOC_SOF_ACPI=m
  - SND_SOC_STARFIVE=m
  - SND_SOC_JH7110_TDM=m
  - SND_SOC_SSM3515=n
  - I2C_HID_ACPI=m
  - USB_CDNS3_PCI_WRAP=m
  - USB_CDNS3_STARFIVE=m
  - USB_CDNSP_PCI=m
  - USB_CDNSP_HOST=y
  - UCSI_ACPI=m
  - MMC_SDHCI_ACPI=m
  - VMGENID=m
  - PCC=y
  - ACPI_ALS=m
  - PWM_MICROCHIP_CORE=m
  - INTEL_TH_ACPI=m
  - CRYPTO_DEV_JH7110=m
  - PER_VMA_LOCK_STATS=y
  - HARDLOCKUP_DETECTOR=y
  - BOOTPARAM_HARDLOCKUP_PANIC=y
  - ACPI_PCC=y
  - SENSORS_XGENE=m
- commit fe612b0
* Sun Jul  9 2023 jslaby@suse.cz
- Linux 6.4.2 (bsc#1012628).
- arch/arm64/mm/fault: Fix undeclared variable error in
  do_page_fault() (bsc#1012628).
- drm/amdgpu: Validate VM ioctl flags (bsc#1012628).
- dm ioctl: Avoid double-fetch of version (bsc#1012628).
- docs: Set minimal gtags / GNU GLOBAL version to 6.6.5
  (bsc#1012628).
- scripts/tags.sh: Resolve gtags empty index generation
  (bsc#1012628).
- hugetlb: revert use of page_cache_next_miss() (bsc#1012628).
- nubus: Partially revert proc_create_single_data() conversion
  (bsc#1012628).
- Revert "cxl/port: Enable the HDM decoder capability for switch
  ports" (bsc#1012628).
- nfs: don't report STATX_BTIME in ->getattr (bsc#1012628).
- execve: always mark stack as growing down during early stack
  setup (bsc#1012628).
- PCI/ACPI: Call _REG when transitioning D-states (bsc#1012628).
- PCI/ACPI: Validate acpi_pci_set_power_state() parameter
  (bsc#1012628).
- tools/nolibc: x86_64: disable stack protector for _start
  (bsc#1012628).
- xtensa: fix lock_mm_and_find_vma in case VMA not found
  (bsc#1012628).
- commit 648ac3b
* Fri Jul  7 2023 duwe@suse.de
- regulator: axp20x: Add AXP15060 support.
- commit db7b000
* Wed Jul  5 2023 jslaby@suse.cz
- Revert "Refresh patches.rpmify/usrmerge-Adjust-module-path-in-the-kernel-sources.patch."
  This reverts commit b8411965e8341c82ba2e01bb38698945be2390a0. It breaks
  the build:
  + ln -s /usr/src/linux-6.4.1-1 /home/abuild/rpmbuild/BUILDROOT/kernel-default-6.4.1-1.1.x86_64/usr/lib/modules/6.4.1-1-default/source
  ln: failed to create symbolic link '/home/abuild/rpmbuild/BUILDROOT/kernel-default-6.4.1-1.1.x86_64/usr/lib/modules/6.4.1-1-default/source': No such file or directory
- commit 3561b10
* Wed Jul  5 2023 tiwai@suse.de
- drm/amd: Don't try to enable secure display TA multiple times
  (bsc#1212848).
- drm/amdgpu: fix number of fence calculations (bsc#1212848).
- drm/amd/display: perform a bounds check before filling dirty
  rectangles (bsc#1212848).
- drm/amdgpu: check RAS irq existence for VCN/JPEG (bsc#1212848).
- drm/amd/pm: add abnormal fan detection for smu 13.0.0
  (bsc#1212848).
- drm/amd: Disable PSR-SU on Parade 0803 TCON (bsc#1212848).
- drm/amd/pm: update the LC_L1_INACTIVITY setting to address
  possible noise issue (bsc#1212848).
- drm/amd/display: Fix 128b132b link loss handling (bsc#1212848).
- drm/amd/display: disable seamless boot if force_odm_combine
  is enabled (bsc#1212848).
- drm/amd/display: add a NULL pointer check (bsc#1212848).
- drm/amd/pm: revise the ASPM settings for thunderbolt attached
  scenario (bsc#1212848).
- drm/amdgpu: fix clearing mappings for BOs that are always
  valid in VM (bsc#1212848).
- drm/amdgpu: Skip mark offset for high priority rings
  (bsc#1212848).
- drm/amdgpu: make sure that BOs have a backing store
  (bsc#1212848).
- drm/amdgpu: make sure BOs are locked in amdgpu_vm_get_memory
  (bsc#1212848).
- commit a695138
* Mon Jul  3 2023 msuchanek@suse.de
- Remove more packaging cruft for SLE < 12 SP3
- commit a16781c
* Mon Jul  3 2023 jslaby@suse.cz
- Linux 6.4.1 (bsc#1012628).
- x86/microcode/AMD: Load late on both threads too (bsc#1012628).
- x86/smp: Make stop_other_cpus() more robust (bsc#1012628).
- x86/smp: Dont access non-existing CPUID leaf (bsc#1012628).
- x86/smp: Remove pointless wmb()s from native_stop_other_cpus()
  (bsc#1012628).
- x86/smp: Use dedicated cache-line for mwait_play_dead()
  (bsc#1012628).
- x86/smp: Cure kexec() vs. mwait_play_dead() breakage
  (bsc#1012628).
- cpufreq: amd-pstate: Make amd-pstate EPP driver name hyphenated
  (bsc#1012628).
- can: isotp: isotp_sendmsg(): fix return error fix on TX path
  (bsc#1012628).
- maple_tree: fix potential out-of-bounds access in
  mas_wr_end_piv() (bsc#1012628).
- mm: introduce new 'lock_mm_and_find_vma()' page fault helper
  (bsc#1012628).
- mm: make the page fault mmap locking killable (bsc#1012628).
- arm64/mm: Convert to using lock_mm_and_find_vma() (bsc#1012628).
- powerpc/mm: Convert to using lock_mm_and_find_vma()
  (bsc#1012628).
- mips/mm: Convert to using lock_mm_and_find_vma() (bsc#1012628).
- riscv/mm: Convert to using lock_mm_and_find_vma() (bsc#1012628).
- arm/mm: Convert to using lock_mm_and_find_vma() (bsc#1012628).
- mm/fault: convert remaining simple cases to
  lock_mm_and_find_vma() (bsc#1012628).
- powerpc/mm: convert coprocessor fault to lock_mm_and_find_vma()
  (bsc#1012628).
- mm: make find_extend_vma() fail if write lock not held
  (bsc#1012628).
- execve: expand new process stack manually ahead of time
  (bsc#1012628).
- mm: always expand the stack with the mmap write lock held
  (bsc#1012628).
- HID: wacom: Use ktime_t rather than int when dealing with
  timestamps (bsc#1012628).
- gup: add warning if some caller would seem to want stack
  expansion (bsc#1012628).
- mm/khugepaged: fix regression in collapse_file() (bsc#1012628).
- fbdev: fix potential OOB read in fast_imageblit() (bsc#1012628).
- HID: hidraw: fix data race on device refcount (bsc#1012628).
- HID: logitech-hidpp: add HIDPP_QUIRK_DELAYED_INIT for the T651
  (bsc#1012628).
- Revert "thermal/drivers/mediatek: Use devm_of_iomap to avoid
  resource leak in mtk_thermal_probe" (bsc#1012628).
- sparc32: fix lock_mm_and_find_vma() conversion (bsc#1012628).
- parisc: fix expand_stack() conversion (bsc#1012628).
- csky: fix up lock_mm_and_find_vma() conversion (bsc#1012628).
- xtensa: fix NOMMU build with lock_mm_and_find_vma() conversion
  (bsc#1012628).
- Refresh
  patches.suse/Revert-x86-mm-try-VMA-lock-based-page-fault-handling.patch.
- Update config files (CONFIG_LOCK_MM_AND_FIND_VMA=y).
  There is no choice.
- commit eb53035
* Fri Jun 30 2023 msuchanek@suse.de
- Refresh patches.rpmify/usrmerge-Adjust-module-path-in-the-kernel-sources.patch.
  Get module prefix from kmod (bsc#1212835).
  Uses jq to parse 'kmod config' output.
- Get module prefix from kmod (bsc#1212835).
- Refresh patches.rpmify/usrmerge-Adjust-module-path-in-the-kernel-sources.patch.
  Get module prefix from kmod (bsc#1212835).
- commit 75e1d32
* Fri Jun 30 2023 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and move into sorted section:
  - patches.suse/HID-microsoft-Add-rumble-support-to-latest-xbox-cont.patch
- commit ce0878a
* Fri Jun 30 2023 mkubecek@suse.cz
- rpm/check-for-config-changes: ignore also PAHOLE_HAS_*
  We now also have options like CONFIG_PAHOLE_HAS_LANG_EXCLUDE.
- commit 86b52c1
* Thu Jun 29 2023 msuchanek@suse.de
- Update vanilla config files.
- commit 94a0f63
* Thu Jun 29 2023 msuchanek@suse.de
- usrmerge: Adjust module path in the kernel sources (bsc#1212835).
  With the module path adjustment applied as source patch only
  ALP/Tumbleweed kernel built on SLE/Leap needs the path changed back to
  non-usrmerged.
- commit bde5158
* Thu Jun 29 2023 jslaby@suse.cz
- Revert "x86/mm: try VMA lock-based page fault handling first"
  (bsc#1212775).
- Update config files.
- commit 43c9b6b
* Wed Jun 28 2023 jslaby@suse.cz
- Revert "io_uring: Adjust mapping wrt architecture aliasing
  requirements" (bsc#1212773).
- commit d2e19af
* Mon Jun 26 2023 msuchanek@suse.de
- kernel-docs: Use python3 together with python3-Sphinx (bsc#1212741).
- commit 95a40a6
* Mon Jun 26 2023 jslaby@suse.cz
- Refresh
  patches.suse/HID-microsoft-Add-rumble-support-to-latest-xbox-cont.patch.
  Update upstream status and move to upstream-soon section.
- commit 1a327c7
* Mon Jun 26 2023 mkubecek@suse.cz
- Update to 6.4 final
- refresh configs (headers only)
- commit 4b7bbac
* Thu Jun 22 2023 jslaby@suse.cz
- Linux 6.3.9 (bsc#1012628).
- x86/head/64: Switch to KERNEL_CS as soon as new GDT is installed
  (bsc#1012628).
- cgroup: bpf: use cgroup_lock()/cgroup_unlock() wrappers
  (bsc#1012628).
- cgroup: always put cset in cgroup_css_set_put_fork
  (bsc#1012628).
- cgroup: fix missing cpus_read_{lock,unlock}() in
  cgroup_transfer_tasks() (bsc#1012628).
- qcom: llcc/edac: Fix the base address used for accessing LLCC
  banks (bsc#1012628).
- EDAC/qcom: Get rid of hardcoded register offsets (bsc#1012628).
- ksmbd: validate smb request protocol id (bsc#1012628).
- of: overlay: Fix missing of_node_put() in error case of
  init_overlay_changeset() (bsc#1012628).
- power: supply: ab8500: Fix external_power_changed race
  (bsc#1012628).
- power: supply: sc27xx: Fix external_power_changed race
  (bsc#1012628).
- power: supply: bq27xxx: Use mod_delayed_work() instead of
  cancel() + schedule() (bsc#1012628).
- ARM: dts: vexpress: add missing cache properties (bsc#1012628).
- arm64: dts: arm: add missing cache properties (bsc#1012628).
- tools: gpio: fix debounce_period_us output of lsgpio
  (bsc#1012628).
- selftests: gpio: gpio-sim: Fix BUG: test FAILED due to recent
  change (bsc#1012628).
- power: supply: Ratelimit no data debug output (bsc#1012628).
- PCI/DPC: Quirk PIO log size for Intel Ice Lake Root Ports
  (bsc#1012628).
- platform/x86: asus-wmi: Ignore WMI events with codes 0x7B,
  0xC0 (bsc#1012628).
- regulator: Fix error checking for debugfs_create_dir
  (bsc#1012628).
- irqchip/gic-v3: Disable pseudo NMIs on Mediatek devices w/
  firmware issues (bsc#1012628).
- irqchip/meson-gpio: Mark OF related data as maybe unused
  (bsc#1012628).
- power: supply: Fix logic checking if system is running from
  battery (bsc#1012628).
- drm: panel-orientation-quirks: Change Air's quirk to support
  Air Plus (bsc#1012628).
- btrfs: scrub: try harder to mark RAID56 block groups read-only
  (bsc#1012628).
- btrfs: handle memory allocation failure in btrfs_csum_one_bio
  (bsc#1012628).
- ASoC: soc-pcm: test if a BE can be prepared (bsc#1012628).
- sfc: fix devlink info error handling (bsc#1012628).
- ASoC: Intel: avs: Account for UID of ACPI device (bsc#1012628).
- ASoC: Intel: avs: Fix avs_path_module::instance_id size
  (bsc#1012628).
- ASoC: Intel: avs: Add missing checks on FE startup
  (bsc#1012628).
- parisc: Improve cache flushing for PCXL in
  arch_sync_dma_for_cpu() (bsc#1012628).
- parisc: Flush gatt writes and adjust gatt mask in
  parisc_agp_mask_memory() (bsc#1012628).
- erofs: use HIPRI by default if per-cpu kthreads are enabled
  (bsc#1012628).
- MIPS: unhide PATA_PLATFORM (bsc#1012628).
- MIPS: Restore Au1300 support (bsc#1012628).
- MIPS: Alchemy: fix dbdma2 (bsc#1012628).
- mips: Move initrd_start check after initrd address sanitisation
  (bsc#1012628).
- ASoC: cs35l41: Fix default regmap values for some registers
  (bsc#1012628).
- ASoC: dwc: move DMA init to snd_soc_dai_driver probe()
  (bsc#1012628).
- xen/blkfront: Only check REQ_FUA for writes (bsc#1012628).
- drm:amd:amdgpu: Fix missing buffer object unlock in failure path
  (bsc#1012628).
- io_uring: unlock sqd->lock before sq thread release CPU
  (bsc#1012628).
- NVMe: Add MAXIO 1602 to bogus nid list (bsc#1012628).
- irqchip/gic: Correctly validate OF quirk descriptors
  (bsc#1012628).
- wifi: cfg80211: fix locking in regulatory disconnect
  (bsc#1012628).
- wifi: cfg80211: fix double lock bug in reg_wdev_chan_valid()
  (bsc#1012628).
- epoll: ep_autoremove_wake_function should use
  list_del_init_careful (bsc#1012628).
- ocfs2: fix use-after-free when unmounting read-only filesystem
  (bsc#1012628).
- ocfs2: check new file size on fallocate call (bsc#1012628).
- zswap: do not shrink if cgroup may not zswap (bsc#1012628).
- mm/damon/core: fix divide error in
  damon_nr_accesses_to_accesses_bp() (bsc#1012628).
- nios2: dts: Fix tse_mac "max-frame-size" property (bsc#1012628).
- mm/uffd: fix vma operation where start addr cuts part of vma
  (bsc#1012628).
- nilfs2: fix incomplete buffer cleanup in
  nilfs_btnode_abort_change_key() (bsc#1012628).
- nilfs2: fix possible out-of-bounds segment allocation in resize
  ioctl (bsc#1012628).
- nilfs2: reject devices with insufficient block count
  (bsc#1012628).
- LoongArch: Fix debugfs_create_dir() error checking
  (bsc#1012628).
- LoongArch: Fix perf event id calculation (bsc#1012628).
- io_uring/net: save msghdr->msg_control for retries
  (bsc#1012628).
- Revert "drm/amdgpu: remove TOPDOWN flags when allocating VRAM
  in large bar system" (bsc#1012628).
- kexec: support purgatories with .text.hot sections
  (bsc#1012628).
- x86/purgatory: remove PGO flags (bsc#1012628).
- riscv/purgatory: remove PGO flags (bsc#1012628).
- powerpc/purgatory: remove PGO flags (bsc#1012628).
- btrfs: subpage: fix a crash in metadata repair path
  (bsc#1012628).
- btrfs: properly enable async discard when switching from RO->RW
  (bsc#1012628).
- btrfs: do not ASSERT() on duplicated global roots (bsc#1012628).
- btrfs: fix iomap_begin length for nocow writes (bsc#1012628).
- btrfs: can_nocow_file_extent should pass down args->strict
  from callers (bsc#1012628).
- ALSA: usb-audio: Fix broken resume due to UAC3 power state
  (bsc#1012628).
- ALSA: usb-audio: Add quirk flag for HEM devices to enable
  native DSD playback (bsc#1012628).
- s390/ism: Fix trying to free already-freed IRQ by repeated
  ism_dev_exit() (bsc#1012628).
- dm thin metadata: check fail_io before using data_sm
  (bsc#1012628).
- dm thin: fix issue_discard to pass GFP_NOIO to
  __blkdev_issue_discard (bsc#1012628).
- net: ethernet: stmicro: stmmac: fix possible memory leak in
  __stmmac_open (bsc#1012628).
- mm/gup_test: fix ioctl fail for compat task (bsc#1012628).
- RDMA/uverbs: Restrict usage of privileged QKEYs (bsc#1012628).
- drm/amdgpu: vcn_4_0 set instance 0 init sched score to 1
  (bsc#1012628).
- net: usb: qmi_wwan: add support for Compal RXM-G1 (bsc#1012628).
- drm/amd/display: limit DPIA link rate to HBR3 (bsc#1012628).
- drm/amd/display: edp do not add non-edid timings (bsc#1012628).
- drm/amd: Make sure image is written to trigger VBIOS image
  update flow (bsc#1012628).
- drm/amd: Tighten permissions on VBIOS flashing attributes
  (bsc#1012628).
- drm/amd/pm: workaround for compute workload type on some skus
  (bsc#1012628).
- drm/amdgpu: add missing radeon secondary PCI ID (bsc#1012628).
- drm/amdgpu: Reset CP_VMID_PREEMPT after trailing fence signaled
  (bsc#1012628).
- drm/amdgpu: Program gds backup address as zero if no gds
  allocated (bsc#1012628).
- drm/amdgpu: Implement gfx9 patch functions for resubmission
  (bsc#1012628).
- drm/amdgpu: Modify indirect buffer packages for resubmission
  (bsc#1012628).
- ALSA: hda/realtek: Add a quirk for Compaq N14JP6 (bsc#1012628).
- thunderbolt: Increase DisplayPort Connection Manager handshake
  timeout (bsc#1012628).
- thunderbolt: Do not touch CL state configuration during
  discovery (bsc#1012628).
- thunderbolt: dma_test: Use correct value for absent rings when
  creating paths (bsc#1012628).
- clk: pxa: fix NULL pointer dereference in pxa3xx_clk_update_accr
  (bsc#1012628).
- USB: serial: option: add Quectel EM061KGL series (bsc#1012628).
- serial: lantiq: add missing interrupt ack (bsc#1012628).
- tty: serial: fsl_lpuart: reduce RX watermark to 0 on LS1028A
  (bsc#1012628).
- usb: typec: ucsi: Fix command cancellation (bsc#1012628).
- usb: typec: Fix fast_role_swap_current show function
  (bsc#1012628).
- usb: gadget: udc: core: Offload usb_udc_vbus_handler processing
  (bsc#1012628).
- usb: gadget: udc: core: Prevent soft_connect_store() race
  (bsc#1012628).
- usb: gadget: udc: renesas_usb3: Fix RZ/V2M {modprobe,bind}
  error (bsc#1012628).
- USB: dwc3: qcom: fix NULL-deref on suspend (bsc#1012628).
- USB: dwc3: fix use-after-free on core driver unbind
  (bsc#1012628).
- usb: dwc3: gadget: Reset num TRBs before giving back the request
  (bsc#1012628).
- RDMA/rtrs: Fix the last iu->buf leak in err path (bsc#1012628).
- RDMA/rtrs: Fix rxe_dealloc_pd warning (bsc#1012628).
- RDMA/rxe: Fix packet length checks (bsc#1012628).
- RDMA/rxe: Fix ref count error in check_rkey() (bsc#1012628).
- RDMA/bnxt_re: Fix reporting active_{speed,width} attributes
  (bsc#1012628).
- spi: cadence-quadspi: Add missing check for dma_set_mask
  (bsc#1012628).
- spi: fsl-dspi: avoid SCK glitches with continuous transfers
  (bsc#1012628).
- regulator: qcom-rpmh: add support for pmm8654au regulators
  (bsc#1012628).
- regulator: qcom-rpmh: Fix regulators for PM8550 (bsc#1012628).
- netfilter: nf_tables: integrate pipapo into commit protocol
  (bsc#1012628).
- netfilter: nfnetlink: skip error delivery on batch in case of
  ENOMEM (bsc#1012628).
- ice: do not busy-wait to read GNSS data (bsc#1012628).
- ice: Don't dereference NULL in ice_gnss_read error path
  (bsc#1012628).
- ice: Fix XDP memory leak when NIC is brought up and down
  (bsc#1012628).
- netfilter: nf_tables: incorrect error path handling with
  NFT_MSG_NEWRULE (bsc#1012628).
- net: enetc: correct the indexes of highest and 2nd highest TCs
  (bsc#1012628).
- ping6: Fix send to link-local addresses with VRF (bsc#1012628).
- igb: Fix extts capture value format for 82580/i354/i350
  (bsc#1012628).
- net/sched: act_pedit: remove extra check for key type
  (bsc#1012628).
- net/sched: act_pedit: Parse L3 Header for L4 offset
  (bsc#1012628).
- net: renesas: rswitch: Fix timestamp feature after all
  descriptors are used (bsc#1012628).
- octeontx2-af: Fix promiscuous mode (bsc#1012628).
- net/sched: taprio: fix slab-out-of-bounds Read in
  taprio_dequeue_from_txq (bsc#1012628).
- net/sched: cls_u32: Fix reference counter leak leading to
  overflow (bsc#1012628).
- wifi: mac80211: fix link activation settings order
  (bsc#1012628).
- wifi: cfg80211: fix link del callback to call correct handler
  (bsc#1012628).
- wifi: mac80211: take lock before setting vif links
  (bsc#1012628).
- RDMA/rxe: Fix the use-before-initialization error of resp_pkts
  (bsc#1012628).
- iavf: remove mask from iavf_irq_enable_queues() (bsc#1012628).
- octeontx2-af: fixed resource availability check (bsc#1012628).
- octeontx2-af: fix lbk link credits on cn10k (bsc#1012628).
- RDMA/mlx5: Initiate dropless RQ for RAW Ethernet functions
  (bsc#1012628).
- RDMA/mlx5: Create an indirect flow table for steering anchor
  (bsc#1012628).
- RDMA/cma: Always set static rate to 0 for RoCE (bsc#1012628).
- IB/uverbs: Fix to consider event queue closing also upon
  non-blocking mode (bsc#1012628).
- RDMA/mlx5: Fix affinity assignment (bsc#1012628).
- IB/isert: Fix dead lock in ib_isert (bsc#1012628).
- IB/isert: Fix possible list corruption in CMA handler
  (bsc#1012628).
- IB/isert: Fix incorrect release of isert connection
  (bsc#1012628).
- net: ethtool: correct MAX attribute value for stats
  (bsc#1012628).
- wifi: mac80211: fragment per STA profile correctly
  (bsc#1012628).
- ipvlan: fix bound dev checking for IPv6 l3s mode (bsc#1012628).
- sctp: fix an error code in sctp_sf_eat_auth() (bsc#1012628).
- igc: Clean the TX buffer and TX descriptor ring (bsc#1012628).
- igc: Fix possible system crash when loading module
  (bsc#1012628).
- igb: fix nvm.ops.read() error handling (bsc#1012628).
- net: phylink: report correct max speed for QUSGMII
  (bsc#1012628).
- net: phylink: use a dedicated helper to parse usgmii control
  word (bsc#1012628).
- drm/nouveau: don't detect DSM for non-NVIDIA device
  (bsc#1012628).
- drm/bridge: ti-sn65dsi86: Avoid possible buffer overflow
  (bsc#1012628).
- drm/nouveau/dp: check for NULL nv_connector->native_mode
  (bsc#1012628).
- drm/nouveau: add nv_encoder pointer check for NULL
  (bsc#1012628).
- net: ethernet: ti: am65-cpsw: Call of_node_put() on error path
  (bsc#1012628).
- selftests/tc-testing: Fix Error: Specified qdisc kind is unknown
  (bsc#1012628).
- selftests/tc-testing: Fix Error: failed to find target LOG
  (bsc#1012628).
- selftests/tc-testing: Fix SFB db test (bsc#1012628).
- net/sched: act_ct: Fix promotion of offloaded unreplied tuple
  (bsc#1012628).
- net/sched: Refactor qdisc_graft() for ingress and clsact Qdiscs
  (bsc#1012628).
- net/sched: qdisc_destroy() old ingress and clsact Qdiscs before
  grafting (bsc#1012628).
- selftests: forwarding: hw_stats_l3: Set addrgenmode in a
  separate step (bsc#1012628).
- cifs: fix lease break oops in xfstest generic/098 (bsc#1012628).
- RDMA/rxe: Fix rxe_cq_post (bsc#1012628).
- ext4: drop the call to ext4_error() from ext4_get_group_info()
  (bsc#1012628).
- ice: Fix ice module unload (bsc#1012628).
- net/sched: cls_api: Fix lockup on flushing explicitly created
  chain (bsc#1012628).
- net: dsa: felix: fix taprio guard band overflow at 10Mbps with
  jumbo frames (bsc#1012628).
- net: lapbether: only support ethernet devices (bsc#1012628).
- net: macsec: fix double free of percpu stats (bsc#1012628).
- sfc: fix XDP queues mode with legacy IRQ (bsc#1012628).
- dm: don't lock fs when the map is NULL during suspend or resume
  (bsc#1012628).
- net: tipc: resize nlattr array to correct size (bsc#1012628).
- selftests/ptp: Fix timestamp printf format for PTP_SYS_OFFSET
  (bsc#1012628).
- octeon_ep: Add missing check for ioremap (bsc#1012628).
- afs: Fix vlserver probe RTT handling (bsc#1012628).
- parisc: Delete redundant register definitions in
  <asm/assembly.h> (bsc#1012628).
- arm64: dts: qcom: sm8550: Use the correct LLCC register scheme
  (bsc#1012628).
- neighbour: delete neigh_lookup_nodev as not used (bsc#1012628).
- scsi: target: core: Fix error path in target_setup_session()
  (bsc#1012628).
- blk-cgroup: Flush stats before releasing blkcg_gq (bsc#1012628).
- commit 0df701d
* Wed Jun 21 2023 jslaby@suse.cz
- Revert "Revert "Fix usrmerge error (boo#1211796)""
  This reverts commit 4b4675f106bef7714110771742fd12e4791f94a8.
  https://github.com/openSUSE/installation-images/pull/648 was merged
  finally.
- commit 5587eea
* Mon Jun 19 2023 jslaby@suse.cz
- drm/amdgpu/sdma4: set align mask to 255
  (https://gitlab.freedesktop.org/drm/amd/-/issues/2447).
- commit e044c8e
* Mon Jun 19 2023 jslaby@suse.cz
- Refresh
  patches.suse/thunderbolt-Mask-ring-interrupt-on-Intel-hardware-as.patch.
  Update upstream status and move to sorted section.
- commit 27c2ccc
* Mon Jun 19 2023 jslaby@suse.cz
- series: move the previously updated patch to the sorted section
- commit 19aa3e4
* Mon Jun 19 2023 jslaby@suse.cz
- Refresh
  patches.suse/nouveau-fix-client-work-fence-deletion-race.patch.
  Update upstream status.
- commit 26b9458
* Sun Jun 18 2023 mkubecek@suse.cz
- Update to 6.4-rc7
- commit a8abd7d
* Fri Jun 16 2023 tiwai@suse.de
- Revert "media: dvb-core: Fix use-after-free on race condition
  at dvb_frontend" (bsc#1212439).
- commit 4dead9b
* Fri Jun 16 2023 tiwai@suse.de
- nouveau: fix client work fence deletion race (bsc#1211217
  bsc#1211568).
- thunderbolt: Mask ring interrupt on Intel hardware as well
  (bsc#1210165).
- commit 4abd087
* Thu Jun 15 2023 msuchanek@suse.de
- kernel-docs: Add buildrequires on python3-base when using python3
  The python3 binary is provided by python3-base.
- commit c5df526
* Wed Jun 14 2023 jslaby@suse.cz
- Linux 6.3.8 (bsc#1012628).
- Revert "staging: rtl8192e: Replace macro RTL_PCI_DEVICE with
  PCI_DEVICE" (bsc#1012628).
- wifi: rtw88: correct PS calculation for SUPPORTS_DYNAMIC_PS
  (bsc#1012628).
- wifi: rtw89: correct PS calculation for SUPPORTS_DYNAMIC_PS
  (bsc#1012628).
- ext4: only check dquot_initialize_needed() when debugging
  (bsc#1012628).
- Revert "ext4: don't clear SB_RDONLY when remounting r/w until
  quota is re-enabled" (bsc#1012628).
- Bluetooth: Fix UAF in hci_conn_hash_flush again (bsc#1012628).
- Bluetooth: Refcnt drop must be placed last in hci_conn_unlink
  (bsc#1012628).
- Bluetooth: Fix potential double free caused by hci_conn_unlink
  (bsc#1012628).
- ksmbd: check the validation of pdu_size in
  ksmbd_conn_handler_loop (bsc#1012628).
- ksmbd: fix posix_acls and acls dereferencing possible ERR_PTR()
  (bsc#1012628).
- ksmbd: fix out-of-bound read in parse_lease_state()
  (bsc#1012628).
- ksmbd: fix out-of-bound read in deassemble_neg_contexts()
  (bsc#1012628).
- vhost_vdpa: support PACKED when setting-getting vring_base
  (bsc#1012628).
- vhost: support PACKED when setting-getting vring_base
  (bsc#1012628).
- vdpa/mlx5: Fix hang when cvq commands are triggered during
  device unregister (bsc#1012628).
- vduse: avoid empty string for dev name (bsc#1012628).
- riscv: fix kprobe __user string arg print fault issue
  (bsc#1012628).
- Update config files.
- soundwire: stream: Add missing clear of alloc_slave_rt
  (bsc#1012628).
- eeprom: at24: also select REGMAP (bsc#1012628).
- riscv: mm: Ensure prot of VM_WRITE and VM_EXEC must be readable
  (bsc#1012628).
- i2c: sprd: Delete i2c adapter in .remove's error path
  (bsc#1012628).
- gpio: sim: fix memory corruption when adding named lines and
  unnamed hogs (bsc#1012628).
- firmware: arm_ffa: Set handle field to zero in memory descriptor
  (bsc#1012628).
- i2c: mv64xxx: Fix reading invalid status value in atomic mode
  (bsc#1012628).
- arm64: dts: imx8mn-beacon: Fix SPI CS pinmux (bsc#1012628).
- blk-mq: fix blk_mq_hw_ctx active request accounting
  (bsc#1012628).
- ASoC: simple-card-utils: fix PCM constraint error check
  (bsc#1012628).
- ASoC: mediatek: mt8195: fix use-after-free in driver remove path
  (bsc#1012628).
- ASoC: mediatek: mt8195-afe-pcm: Convert to platform remove
  callback returning void (bsc#1012628).
- ASoC: mediatek: mt8188: fix use-after-free in driver remove path
  (bsc#1012628).
- ASoC: amd: ps: fix for acp_lock access in pdm driver
  (bsc#1012628).
- arm64: dts: imx8-ss-dma: assign default clock rate for lpuarts
  (bsc#1012628).
- arm64: dts: imx8qm-mek: correct GPIOs for USDHC2 CD and WP
  signals (bsc#1012628).
- arm64: dts: qcom: sc7180-lite: Fix SDRAM freq for misidentified
  sc7180-lite boards (bsc#1012628).
- soc: qcom: rmtfs: Fix error code in probe() (bsc#1012628).
- soc: qcom: ramp_controller: Fix an error handling path in
  qcom_ramp_controller_probe() (bsc#1012628).
- ASoC: codecs: wsa881x: do not set can_multi_write flag
  (bsc#1012628).
- ASoC: codecs: wsa883x: do not set can_multi_write flag
  (bsc#1012628).
- ARM: dts: at91: sama7g5ek: fix debounce delay property for shdwc
  (bsc#1012628).
- ARM: at91: pm: fix imbalanced reference counter for ethernet
  devices (bsc#1012628).
- arm64: dts: qcom: sm6375-pdx225: Fix remoteproc firmware paths
  (bsc#1012628).
- arm64: dts: qcom: sc8280xp: Flush RSC sleep & wake votes
  (bsc#1012628).
- soc: qcom: rpmh-rsc: drop redundant unsigned >=0 comparision
  (bsc#1012628).
- mm: page_table_check: Ensure user pages are not slab pages
  (bsc#1012628).
- mm: page_table_check: Make it dependent on EXCLUSIVE_SYSTEM_RAM
  (bsc#1012628).
- usb: usbfs: Use consistent mmap functions (bsc#1012628).
- usb: usbfs: Enforce page requirements for mmap (bsc#1012628).
- pinctrl: meson-axg: add missing GPIOA_18 gpio group
  (bsc#1012628).
- soc: qcom: icc-bwmon: fix incorrect error code passed to
  dev_err_probe() (bsc#1012628).
- virtio_net: use control_buf for coalesce params (bsc#1012628).
- rbd: get snapshot context after exclusive lock is ensured to
  be held (bsc#1012628).
- rbd: move RBD_OBJ_FLAG_COPYUP_ENABLED flag setting
  (bsc#1012628).
- tee: amdtee: Add return_origin to 'struct tee_cmd_load_ta'
  (bsc#1012628).
- Bluetooth: hci_qca: fix debugfs registration (bsc#1012628).
- Bluetooth: fix debugfs registration (bsc#1012628).
- Bluetooth: Fix use-after-free in hci_remove_ltk/hci_remove_irk
  (bsc#1012628).
- s390/dasd: Use correct lock while counting channel queue length
  (bsc#1012628).
- accel/ivpu: Fix sporadic VPU boot failure (bsc#1012628).
- accel/ivpu: Do not trigger extra VPU reset if the VPU is idle
  (bsc#1012628).
- ceph: fix use-after-free bug for inodes when flushing capsnaps
  (bsc#1012628).
- selftests: mptcp: update userspace pm subflow tests
  (bsc#1012628).
- selftests: mptcp: update userspace pm addr tests (bsc#1012628).
- mptcp: update userspace pm infos (bsc#1012628).
- mptcp: add address into userspace pm list (bsc#1012628).
- mptcp: only send RM_ADDR in nl_cmd_remove (bsc#1012628).
- can: j1939: avoid possible use-after-free when
  j1939_can_rx_register fails (bsc#1012628).
- can: j1939: change j1939_netdev_lock type to mutex
  (bsc#1012628).
- can: j1939: j1939_sk_send_loop_abort(): improved error queue
  handling in J1939 Socket (bsc#1012628).
- wifi: iwlwifi: mvm: Fix -Warray-bounds bug in
  iwl_mvm_wait_d3_notif() (bsc#1012628).
- drm/amd/display: add ODM case when looking for first split pipe
  (bsc#1012628).
- drm/amd/display: Reduce sdp bw after urgent to 90%%
  (bsc#1012628).
- drm/amd/pm: Fix power context allocation in SMU13 (bsc#1012628).
- drm/amd: Disallow s0ix without BIOS support again (bsc#1012628).
- drm/amdgpu: change reserved vram info print (bsc#1012628).
- drm/amdgpu: fix xclk freq on CHIP_STONEY (bsc#1012628).
- drm/amd/pm: conditionally disable pcie lane switching for some
  sienna_cichlid SKUs (bsc#1012628).
- drm/i915/gt: Use the correct error value when kernel_context()
  fails (bsc#1012628).
- ALSA: hda/realtek: Add quirks for Asus ROG 2024 laptops using
  CS35L41 (bsc#1012628).
- ALSA: hda/realtek: Add Lenovo P3 Tower platform (bsc#1012628).
- ALSA: hda/realtek: Add a quirk for HP Slim Desktop S01
  (bsc#1012628).
- ALSA: ice1712,ice1724: fix the kcontrol->id initialization
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Clevo NS50AU (bsc#1012628).
- ALSA: cmipci: Fix kctl->id initialization (bsc#1012628).
- ALSA: gus: Fix kctl->id initialization (bsc#1012628).
- ALSA: ymfpci: Fix kctl->id initialization (bsc#1012628).
- ALSA: hda: Fix kctl->id initialization (bsc#1012628).
- Input: fix open count when closing inhibited device
  (bsc#1012628).
- Input: psmouse - fix OOB access in Elantech protocol
  (bsc#1012628).
- Input: cyttsp5 - fix array length (bsc#1012628).
- Input: xpad - delete a Razer DeathAdder mouse VID/PID entry
  (bsc#1012628).
- batman-adv: Broken sync while rescheduling delayed work
  (bsc#1012628).
- drm/msm/a6xx: initialize GMU mutex earlier (bsc#1012628).
- bnxt_en: Implement .set_port / .unset_port UDP tunnel callbacks
  (bsc#1012628).
- bnxt_en: Prevent kernel panic when receiving unexpected
  PHC_UPDATE event (bsc#1012628).
- bnxt_en: Skip firmware fatal error recovery if chip is not
  accessible (bsc#1012628).
- bnxt_en: Query default VLAN before VNIC setup on a VF
  (bsc#1012628).
- bnxt_en: Don't issue AP reset during ethtool's reset operation
  (bsc#1012628).
- bnxt_en: Fix bnxt_hwrm_update_rss_hash_cfg() (bsc#1012628).
- accel/ivpu: Do not use mutex_lock_interruptible (bsc#1012628).
- net: bcmgenet: Fix EEE implementation (bsc#1012628).
- lib: cpu_rmap: Fix potential use-after-free in
  irq_cpu_rmap_release() (bsc#1012628).
- drm/amdgpu: fix Null pointer dereference error in
  amdgpu_device_recover_vram (bsc#1012628).
- bpf: Add extra path pointer check to d_path helper
  (bsc#1012628).
- net: sched: fix possible refcount leak in tc_chain_tmplt_add()
  (bsc#1012628).
- net: sched: act_police: fix sparse errors in tcf_police_dump()
  (bsc#1012628).
- net: openvswitch: fix upcall counter access before allocation
  (bsc#1012628).
- net: sched: move rtm_tca_policy declaration to include file
  (bsc#1012628).
- ice: make writes to /dev/gnssX synchronous (bsc#1012628).
- drm/i915/selftests: Add some missing error propagation
  (bsc#1012628).
- net: sched: add rcu annotations around qdisc->qdisc_sleeping
  (bsc#1012628).
- rfs: annotate lockless accesses to RFS sock flow table
  (bsc#1012628).
- rfs: annotate lockless accesses to sk->sk_rxhash (bsc#1012628).
- tcp: gso: really support BIG TCP (bsc#1012628).
- ipv6: rpl: Fix Route of Death (bsc#1012628).
- drm/lima: fix sched context destroy (bsc#1012628).
- netfilter: nf_tables: out-of-bound check in chain blob
  (bsc#1012628).
- netfilter: ipset: Add schedule point in call_ad() (bsc#1012628).
- netfilter: conntrack: fix NULL pointer dereference in
  nf_confirm_cthelper (bsc#1012628).
- netfilter: nft_bitwise: fix register tracking (bsc#1012628).
- netfilter: nf_tables: Add null check for nla_nest_start_noflag()
  in nft_dump_basechain_hook() (bsc#1012628).
- selftests/bpf: Fix sockopt_sk selftest (bsc#1012628).
- selftests/bpf: Verify optval=NULL case (bsc#1012628).
- wifi: cfg80211: fix locking in sched scan stop work
  (bsc#1012628).
- accel/ivpu: Reserve all non-command bo's using
  DMA_RESV_USAGE_BOOKKEEP (bsc#1012628).
- accel/ivpu: ivpu_ipc needs GENERIC_ALLOCATOR (bsc#1012628).
- qed/qede: Fix scheduling while atomic (bsc#1012628).
- wifi: mac80211: don't translate beacon/presp addrs
  (bsc#1012628).
- wifi: mac80211: mlme: fix non-inheritence element (bsc#1012628).
- wifi: cfg80211: reject bad AP MLD address (bsc#1012628).
- wifi: mac80211: use correct iftype HE cap (bsc#1012628).
- Bluetooth: L2CAP: Add missing checks for invalid DCID
  (bsc#1012628).
- Bluetooth: ISO: use correct CIS order in Set CIG Parameters
  event (bsc#1012628).
- Bluetooth: hci_conn: Fix not matching by CIS ID (bsc#1012628).
- Bluetooth: hci_conn: Add support for linking multiple hcon
  (bsc#1012628).
- Bluetooth: ISO: don't try to remove CIG if there are bound
  CIS left (bsc#1012628).
- Bluetooth: Fix l2cap_disconnect_req deadlock (bsc#1012628).
- Bluetooth: hci_sync: add lock to protect HCI_UNREGISTER
  (bsc#1012628).
- Bluetooth: ISO: Fix CIG auto-allocation to select configurable
  CIG (bsc#1012628).
- Bluetooth: ISO: consider right CIS when removing CIG at cleanup
  (bsc#1012628).
- Bluetooth: Split bt_iso_qos into dedicated structures
  (bsc#1012628).
- drm/i915: Use 18 fast wake AUX sync len (bsc#1012628).
- drm/i915: Explain the magic numbers for AUX SYNC/precharge
  length (bsc#1012628).
- net/sched: fq_pie: ensure reasonable TCA_FQ_PIE_QUANTUM values
  (bsc#1012628).
- net: enetc: correct rx_bytes statistics of XDP (bsc#1012628).
- net: enetc: correct the statistics of rx bytes (bsc#1012628).
- net/smc: Avoid to access invalid RMBs' MRs in SMCRv1 ADD LINK
  CONT (bsc#1012628).
- net/ipv6: fix bool/int mismatch for skip_notify_on_dev_down
  (bsc#1012628).
- bpf: Fix elem_size not being set for inner maps (bsc#1012628).
- bpf: Fix UAF in task local storage (bsc#1012628).
- net/ipv4: ping_group_range: allow GID from 2147483648 to
  4294967294 (bsc#1012628).
- net: dsa: lan9303: allow vid != 0 in port_fdb_{add|del} methods
  (bsc#1012628).
- neighbour: fix unaligned access to pneigh_entry (bsc#1012628).
- bpf, sockmap: Avoid potential NULL dereference in
  sk_psock_verdict_data_ready() (bsc#1012628).
- wifi: mt76: mt7615: fix possible race in mt7615_mac_sta_poll
  (bsc#1012628).
- afs: Fix setting of mtime when creating a file/dir/symlink
  (bsc#1012628).
- spi: qup: Request DMA before enabling clocks (bsc#1012628).
- platform/surface: aggregator_tabletsw: Add support for book
  mode in KIP subsystem (bsc#1012628).
- platform/surface: aggregator: Allow completion work-items to
  be executed in parallel (bsc#1012628).
- spi: mt65xx: make sure operations completed before unloading
  (bsc#1012628).
- commit 627a49e
* Tue Jun 13 2023 dmueller@suse.com
- config.conf: reenable armv6 configs
- Update config files (same settings like armv7hl)
- commit d3ab761
* Tue Jun 13 2023 tzimmermann@suse.com
- drm/prime: reject DMA-BUF attach when get_sg_table is missing (bsc#1212133)
- commit d322cd6
* Tue Jun 13 2023 tzimmermann@suse.com
- drm/vram-helper: turn on PRIME import/export (bsc#1212133)
- commit 6c91918
* Tue Jun 13 2023 jslaby@suse.cz
- Update config files.
  Only run oldconfig to accumulate all the past changes.
- commit c0cd722
* Mon Jun 12 2023 jslaby@suse.cz
- Linux 6.3.7 (bsc#1012628).
- RDMA/bnxt_re: Fix the page_size used during the MR creation
  (bsc#1012628).
- phy: amlogic: phy-meson-g12a-mipi-dphy-analog: fix
  CNTL2_DIF_TX_CTL0 value (bsc#1012628).
- RDMA/efa: Fix unsupported page sizes in device (bsc#1012628).
- RDMA/hns: Fix timeout attr in query qp for HIP08 (bsc#1012628).
- RDMA/hns: Fix base address table allocation (bsc#1012628).
- RDMA/hns: Modify the value of long message loopback slice
  (bsc#1012628).
- dmaengine: at_xdmac: fix potential Oops in
  at_xdmac_prep_interleaved() (bsc#1012628).
- RDMA/bnxt_re: Fix a possible memory leak (bsc#1012628).
- RDMA/bnxt_re: Fix return value of bnxt_re_process_raw_qp_pkt_rx
  (bsc#1012628).
- iommu: Make IPMMU_VMSA dependencies more strict (bsc#1012628).
- iommu/rockchip: Fix unwind goto issue (bsc#1012628).
- iommu/amd: Don't block updates to GATag if guest mode is on
  (bsc#1012628).
- iommu/amd: Handle GALog overflows (bsc#1012628).
- iommu/amd: Fix up merge conflict resolution (bsc#1012628).
- iommu/amd: Add missing domain type checks (bsc#1012628).
- nfsd: make a copy of struct iattr before calling notify_change
  (bsc#1012628).
- dmaengine: pl330: rename _start to prevent build error
  (bsc#1012628).
- crypto: x86/aria - Use 16 byte alignment for GFNI constant
  vectors (bsc#1012628).
- riscv: Fix unused variable warning when BUILTIN_DTB is set
  (bsc#1012628).
- net/mlx5e: TC, Remove unused vf_tun variable (bsc#1012628).
- net/mlx5e: TC, Move main flow attribute cleanup to helper func
  (bsc#1012628).
- net/mlx5e: Extract remaining tunnel encap code to dedicated file
  (bsc#1012628).
- net/mlx5e: Prevent encap offload when neigh update is running
  (bsc#1012628).
- net/mlx5e: Consider internal buffers size in port buffer
  calculations (bsc#1012628).
- net/mlx5e: Do not update SBCM when prio2buffer command is
  invalid (bsc#1012628).
- net/mlx5: Drain health before unregistering devlink
  (bsc#1012628).
- net/mlx5: SF, Drain health before removing device (bsc#1012628).
- net/mlx5: fw_tracer, Fix event handling (bsc#1012628).
- net/mlx5e: Use query_special_contexts cmd only once per mdev
  (bsc#1012628).
- net/mlx5e: CT: Use per action stats (bsc#1012628).
- net/mlx5e: TC, Remove CT action reordering (bsc#1012628).
- net/mlx5: Fix post parse infra to only parse every action once
  (bsc#1012628).
- net/mlx5e: Don't attach netdev profile while handling internal
  error (bsc#1012628).
- net/mlx5e: Move Ethernet driver debugfs to profile init callback
  (bsc#1012628).
- net: mellanox: mlxbf_gige: Fix skb_panic splat under memory
  pressure (bsc#1012628).
- net: stmmac: fix call trace when stmmac_xdp_xmit() is invoked
  (bsc#1012628).
- netrom: fix info-leak in nr_write_internal() (bsc#1012628).
- af_packet: Fix data-races of pkt_sk(sk)->num (bsc#1012628).
- tls: improve lockless access safety of tls_err_abort()
  (bsc#1012628).
- amd-xgbe: fix the false linkup in xgbe_phy_status (bsc#1012628).
- perf ftrace latency: Remove unnecessary "--" from --use-nsec
  option (bsc#1012628).
- mtd: rawnand: ingenic: fix empty stub helper definitions
  (bsc#1012628).
- efi: Bump stub image version for macOS HVF compatibility
  (bsc#1012628).
- RDMA/irdma: Prevent QP use after free (bsc#1012628).
- RDMA/irdma: Fix Local Invalidate fencing (bsc#1012628).
- af_packet: do not use READ_ONCE() in packet_bind()
  (bsc#1012628).
- tcp: deny tcp_disconnect() when threads are waiting
  (bsc#1012628).
- tcp: Return user_mss for TCP_MAXSEG in CLOSE/LISTEN state if
  user_mss set (bsc#1012628).
- rxrpc: Truncate UTS_RELEASE for rxrpc version (bsc#1012628).
- net/smc: Scan from current RMB list when no position specified
  (bsc#1012628).
- net/smc: Don't use RMBs not mapped to new link in SMCRv2 ADD
  LINK (bsc#1012628).
- net/sched: sch_ingress: Only create under TC_H_INGRESS
  (bsc#1012628).
- net/sched: sch_clsact: Only create under TC_H_CLSACT
  (bsc#1012628).
- net/sched: Reserve TC_H_INGRESS (TC_H_CLSACT) for ingress
  (clsact) Qdiscs (bsc#1012628).
- net/sched: Prohibit regrafting ingress or clsact Qdiscs
  (bsc#1012628).
- net: sched: fix NULL pointer dereference in mq_attach
  (bsc#1012628).
- net/netlink: fix NETLINK_LIST_MEMBERSHIPS length report
  (bsc#1012628).
- udp6: Fix race condition in udp6_sendmsg & connect
  (bsc#1012628).
- nfsd: fix double fget() bug in __write_ports_addfd()
  (bsc#1012628).
- HID: logitech-hidpp: Handle timeout differently from busy
  (bsc#1012628).
- nvme: fix the name of Zone Append for verbose logging
  (bsc#1012628).
- net/mlx5e: Fix error handling in mlx5e_refresh_tirs
  (bsc#1012628).
- net/mlx5: Read embedded cpu after init bit cleared
  (bsc#1012628).
- sfc: fix error unwinds in TC offload (bsc#1012628).
- iommu/mediatek: Flush IOTLB completely only if domain has been
  attached (bsc#1012628).
- net/sched: flower: fix possible OOB write in fl_set_geneve_opt()
  (bsc#1012628).
- tcp: fix mishandling when the sack compression is deferred
  (bsc#1012628).
- net: ipa: Use correct value for IPA_STATUS_SIZE (bsc#1012628).
- net: dsa: mv88e6xxx: Increase wait after reset deactivation
  (bsc#1012628).
- mtd: rawnand: marvell: ensure timing values are written
  (bsc#1012628).
- mtd: rawnand: marvell: don't set the NAND frequency select
  (bsc#1012628).
- net: renesas: rswitch: Fix return value in error path of xmit
  (bsc#1012628).
- net: phy: mxl-gpy: extend interrupt fix to all impacted variants
  (bsc#1012628).
- ice: recycle/free all of the fragments from multi-buffer frame
  (bsc#1012628).
- rtnetlink: call validate_linkmsg in rtnl_create_link
  (bsc#1012628).
- rtnetlink: move IFLA_GSO_ tb check to validate_linkmsg
  (bsc#1012628).
- rtnetlink: add the missing IFLA_GRO_ tb check in
  validate_linkmsg (bsc#1012628).
- mptcp: avoid unneeded __mptcp_nmpc_socket() usage (bsc#1012628).
- mptcp: add annotations around msk->subflow accesses
  (bsc#1012628).
- mptcp: avoid unneeded address copy (bsc#1012628).
- mptcp: simplify subflow_syn_recv_sock() (bsc#1012628).
- mptcp: consolidate passive msk socket initialization
  (bsc#1012628).
- mptcp: fix data race around msk->first access (bsc#1012628).
- mptcp: add annotations around sk->sk_shutdown accesses
  (bsc#1012628).
- drm/amdgpu: release gpu full access after
  "amdgpu_device_ip_late_init" (bsc#1012628).
- watchdog: menz069_wdt: fix watchdog initialisation
  (bsc#1012628).
- ALSA: hda: Glenfly: add HD Audio PCI IDs and HDMI Codec Vendor
  IDs (bsc#1012628).
- drm/amd/display: fix memleak in aconnector->timing_requested
  (bsc#1012628).
- LoongArch: Add ARCH_HAS_FORTIFY_SOURCE selection (bsc#1012628).
- ASoC: Intel: soc-acpi-cht: Add quirk for Nextbook Ares 8A tablet
  (bsc#1012628).
- drm/amdgpu: Use the default reset when loading or reloading
  the driver (bsc#1012628).
- mailbox: mailbox-test: Fix potential double-free in
  mbox_test_message_write() (bsc#1012628).
- drm/ast: Fix ARM compatibility (bsc#1012628).
- btrfs: abort transaction when sibling keys check fails for
  leaves (bsc#1012628).
- ARM: 9295/1: unwind:fix unwind abort for uleb128 case
  (bsc#1012628).
- perf/x86/intel/ds: Flush PEBS DS when changing PEBS_DATA_CFG
  (bsc#1012628).
- hwmon: (k10temp) Add PCI ID for family 19, model 78h
  (bsc#1012628).
- media: rcar-vin: Gen3 can not scale NV12 (bsc#1012628).
- media: rcar-vin: Fix NV12 size alignment (bsc#1012628).
- media: rcar-vin: Select correct interrupt mode for
  V4L2_FIELD_ALTERNATE (bsc#1012628).
- platform/x86: intel_scu_pcidrv: Add back PCI ID for Medfield
  (bsc#1012628).
- platform/mellanox: fix potential race in mlxbf-tmfifo driver
  (bsc#1012628).
- gfs2: Don't deref jdesc in evict (bsc#1012628).
- drm/amdgpu/nv: update VCN 3 max HEVC encoding resolution
  (bsc#1012628).
- drm/amdgpu: set gfx9 onwards APU atomics support to be true
  (bsc#1012628).
- fbdev: imsttfb: Fix use after free bug in imsttfb_probe
  (bsc#1012628).
- fbdev: modedb: Add 1920x1080 at 60 Hz video mode (bsc#1012628).
- fbdev: stifb: Fix info entry in sti_struct on error path
  (bsc#1012628).
- nbd: Fix debugfs_create_dir error checking (bsc#1012628).
- block/rnbd: replace REQ_OP_FLUSH with REQ_OP_WRITE
  (bsc#1012628).
- nvme-pci: add NVME_QUIRK_BOGUS_NID for HS-SSD-FUTURE 2048G
  (bsc#1012628).
- nvme-pci: add quirk for missing secondary temperature thresholds
  (bsc#1012628).
- nvme-pci: clamp max_hw_sectors based on DMA optimized limitation
  (bsc#1012628).
- ASoC: amd: yc: Add DMI entry to support System76 Pangolin 12
  (bsc#1012628).
- ASoC: dwc: limit the number of overrun messages (bsc#1012628).
- cpupower:Fix resource leaks in sysfs_get_enabled()
  (bsc#1012628).
- ASoC: SOF: amd: Fix NULL pointer crash in acp_sof_ipc_msg_data
  function (bsc#1012628).
- um: harddog: fix modular build (bsc#1012628).
- xfrm: Check if_id in inbound policy/secpath match (bsc#1012628).
- ASoC: jz4740-i2s: Make I2S divider calculations more robust
  (bsc#1012628).
- ASoC: dt-bindings: Adjust #sound-dai-cells on TI's single-DAI
  codecs (bsc#1012628).
- ALSA: hda/realtek: Add quirks for ASUS GU604V and GU603V
  (bsc#1012628).
- ASoC: ssm2602: Add workaround for playback distortions
  (bsc#1012628).
- media: dvb_demux: fix a bug for the continuity counter
  (bsc#1012628).
- media: dvb-usb: az6027: fix three null-ptr-deref in
  az6027_i2c_xfer() (bsc#1012628).
- media: dvb-usb-v2: ec168: fix null-ptr-deref in ec168_i2c_xfer()
  (bsc#1012628).
- media: dvb-usb-v2: ce6230: fix null-ptr-deref in
  ce6230_i2c_master_xfer() (bsc#1012628).
- media: dvb-usb-v2: rtl28xxu: fix null-ptr-deref in
  rtl28xxu_i2c_xfer (bsc#1012628).
- media: dvb-usb: digitv: fix null-ptr-deref in digitv_i2c_xfer()
  (bsc#1012628).
- media: dvb-usb: dw2102: fix uninit-value in
  su3000_read_mac_address (bsc#1012628).
- media: netup_unidvb: fix irq init by register it at the end
  of probe (bsc#1012628).
- media: dvb_ca_en50221: fix a size write bug (bsc#1012628).
- media: mn88443x: fix !CONFIG_OF error by drop of_match_ptr
  from ID table (bsc#1012628).
- ASoC: SOF: debug: conditionally bump runtime_pm counter on
  exceptions (bsc#1012628).
- ASoC: SOF: pcm: fix pm_runtime imbalance in error handling
  (bsc#1012628).
- ASoC: SOF: sof-client-probes: fix pm_runtime imbalance in
  error handling (bsc#1012628).
- ASoC: SOF: pm: save io region state in case of errors in resume
  (bsc#1012628).
- s390/pkey: zeroize key blobs (bsc#1012628).
- s390/topology: honour nr_cpu_ids when adding CPUs (bsc#1012628).
- s390/ipl: fix IPIB virtual vs physical address confusion
  (bsc#1012628).
- ACPI: resource: Add IRQ override quirk for LG UltraPC 17U70P
  (bsc#1012628).
- wifi: rtl8xxxu: fix authentication timeout due to incorrect
  RCR value (bsc#1012628).
- ARM: dts: stm32: add pin map for CAN controller on stm32f7
  (bsc#1012628).
- arm64/mm: mark private VM_FAULT_X defines as vm_fault_t
  (bsc#1012628).
- arm64: vdso: Pass (void *) to virt_to_page() (bsc#1012628).
- wifi: mac80211: simplify chanctx allocation (bsc#1012628).
- wifi: mac80211: consider reserved chanctx for mindef
  (bsc#1012628).
- wifi: mac80211: recalc chanctx mindef before assigning
  (bsc#1012628).
- wifi: iwlwifi: mvm: Add locking to the rate read flow
  (bsc#1012628).
- scsi: ufs: core: Fix MCQ tag calculation (bsc#1012628).
- scsi: ufs: core: Rename symbol sizeof_utp_transfer_cmd_desc()
  (bsc#1012628).
- scsi: ufs: core: Fix MCQ nr_hw_queues (bsc#1012628).
- scsi: core: Decrease scsi_device's iorequest_cnt if dispatch
  failed (bsc#1012628).
- wifi: b43: fix incorrect __packed annotation (bsc#1012628).
- net: wwan: t7xx: Ensure init is completed before system sleep
  (bsc#1012628).
- netfilter: conntrack: define variables exp_nat_nla_policy and
  any_addr with CONFIG_NF_NAT (bsc#1012628).
- nvme-multipath: don't call blk_mark_disk_dead in
  nvme_mpath_remove_disk (bsc#1012628).
- nvme: do not let the user delete a ctrl before a complete
  initialization (bsc#1012628).
- ALSA: oss: avoid missing-prototype warnings (bsc#1012628).
- drm/msm: Be more shouty if per-process pgtables aren't working
  (bsc#1012628).
- atm: hide unused procfs functions (bsc#1012628).
- ceph: silence smatch warning in reconnect_caps_cb()
  (bsc#1012628).
- drm/amdgpu: skip disabling fence driver src_irqs when device
  is unplugged (bsc#1012628).
- ublk: fix AB-BA lockdep warning (bsc#1012628).
- nvme-pci: Add quirk for Teamgroup MP33 SSD (bsc#1012628).
- block: Deny writable memory mapping if block is read-only
  (bsc#1012628).
- iio: adc: imx93: fix a signedness bug in imx93_adc_read_raw()
  (bsc#1012628).
- KVM: arm64: vgic: Fix a circular locking issue (bsc#1012628).
- KVM: arm64: vgic: Wrap vgic_its_create() with config_lock
  (bsc#1012628).
- KVM: arm64: vgic: Fix locking comment (bsc#1012628).
- KVM: arm64: Prevent unconditional donation of unmapped regions
  from the host (bsc#1012628).
- scsi: qla2xxx: Fix NULL pointer dereference in target mode
  (bsc#1012628).
- perf/x86/intel: Save/restore cpuc->active_pebs_data_cfg when
  using guest PEBS (bsc#1012628).
- KVM: arm64: Reload PTE after invoking walker callback on
  preorder traversal (bsc#1012628).
- media: mediatek: vcodec: Only apply 4K frame sizes on decoder
  formats (bsc#1012628).
- mailbox: mailbox-test: fix a locking issue in
  mbox_test_message_write() (bsc#1012628).
- drivers: base: cacheinfo: Fix shared_cpu_map changes in event
  of CPU hotplug (bsc#1012628).
- drivers: base: cacheinfo: Update cpu_map_populated during CPU
  Hotplug (bsc#1012628).
- dt-bindings: serial: 8250_omap: add rs485-rts-active-high
  (bsc#1012628).
- media: uvcvideo: Don't expose unsupported formats to userspace
  (bsc#1012628).
- selftests/ftrace: Choose target function for filter test from
  samples (bsc#1012628).
- iio: accel: st_accel: Fix invalid mount_matrix on devices
  without ACPI _ONT method (bsc#1012628).
- iio: adc: mxs-lradc: fix the order of two cleanup operations
  (bsc#1012628).
- iio: tmag5273: Fix runtime PM leak on measurement error
  (bsc#1012628).
- iio: ad4130: Make sure clock provider gets removed
  (bsc#1012628).
- iio: adc: mt6370: Fix ibus and ibat scaling value of some
  specific vendor ID chips (bsc#1012628).
- HID: google: add jewel USB id (bsc#1012628).
- HID: wacom: avoid integer overflow in wacom_intuos_inout()
  (bsc#1012628).
- iio: imu: inv_icm42600: fix timestamp reset (bsc#1012628).
- dt-bindings: iio: adc: renesas,rcar-gyroadc: Fix adi,ad7476
  compatible value (bsc#1012628).
- iio: light: vcnl4035: fixed chip ID check (bsc#1012628).
- iio: accel: kx022a fix irq getting (bsc#1012628).
- iio: adc: stm32-adc: skip adc-channels setup if none is present
  (bsc#1012628).
- iio: adc: ad_sigma_delta: Fix IRQ issue by setting
  IRQ_DISABLE_UNLAZY flag (bsc#1012628).
- iio: dac: mcp4725: Fix i2c_master_send() return value handling
  (bsc#1012628).
- iio: addac: ad74413: fix resistance input processing
  (bsc#1012628).
- iio: adc: ad7192: Change "shorted" channels to differential
  (bsc#1012628).
- iio: adc: stm32-adc: skip adc-diff-channels setup if none is
  present (bsc#1012628).
- iio: dac: build ad5758 driver when AD5758 is selected
  (bsc#1012628).
- net: usb: qmi_wwan: Set DTR quirk for BroadMobi BM818
  (bsc#1012628).
- dt-bindings: usb: snps,dwc3: Fix "snps,hsphy_interface" type
  (bsc#1012628).
- usb: cdns3: fix NCM gadget RX speed 20x slow than expection
  at iMX8QM (bsc#1012628).
- usb: gadget: f_fs: Add unbind event before functionfs_unbind
  (bsc#1012628).
- md/raid5: fix miscalculation of 'end_sector' in
  raid5_read_one_chunk() (bsc#1012628).
- misc: fastrpc: Reassign memory ownership only for remote heap
  (bsc#1012628).
- misc: fastrpc: return -EPIPE to invocations on device removal
  (bsc#1012628).
- misc: fastrpc: reject new invocations during device removal
  (bsc#1012628).
- scsi: stex: Fix gcc 13 warnings (bsc#1012628).
- ata: libata-scsi: Use correct device no in ata_find_dev()
  (bsc#1012628).
- drm/amdgpu: enable tmz by default for GC 11.0.1 (bsc#1012628).
- drm/amd/pm: reverse mclk and fclk clocks levels for SMU v13.0.4
  (bsc#1012628).
- drm/amd/pm: reverse mclk and fclk clocks levels for vangogh
  (bsc#1012628).
- drm/amd/pm: resolve reboot exception for si oland (bsc#1012628).
- drm/amd/pm: reverse mclk clocks levels for SMU v13.0.5
  (bsc#1012628).
- drm/amd/pm: reverse mclk and fclk clocks levels for yellow carp
  (bsc#1012628).
- drm/amd/pm: reverse mclk and fclk clocks levels for renoir
  (bsc#1012628).
- mmc: vub300: fix invalid response handling (bsc#1012628).
- mmc: pwrseq: sd8787: Fix WILC CHIP_EN and RESETN toggling order
  (bsc#1012628).
- tty: serial: fsl_lpuart: use UARTCTRL_TXINV to send break
  instead of UARTCTRL_SBK (bsc#1012628).
- btrfs: fix csum_tree_block page iteration to avoid tripping
  on -Werror=array-bounds (bsc#1012628).
- phy: qcom-qmp-combo: fix init-count imbalance (bsc#1012628).
- phy: qcom-qmp-pcie-msm8996: fix init-count imbalance
  (bsc#1012628).
- block: fix revalidate performance regression (bsc#1012628).
- powerpc/iommu: Limit number of TCEs to 512 for H_STUFF_TCE hcall
  (bsc#1012628).
- iommu/amd: Fix domain flush size when syncing iotlb
  (bsc#1012628).
- tpm, tpm_tis: correct tpm_tis_flags enumeration values
  (bsc#1012628).
- module/decompress: Fix error checking on zstd decompression
  (bsc#1012628).
- firmware: qcom_scm: Use fixed width src vm bitmap (bsc#1012628).
- misc: fastrpc: Pass proper scm arguments for secure map request
  (bsc#1012628).
- btrfs: call btrfs_orig_bbio_end_io in btrfs_end_bio_work
  (bsc#1012628).
- HID: hidpp: terminate retry loop on success (bsc#1012628).
- dmaengine: at_hdmac: Repair bitfield macros for peripheral ID
  handling (bsc#1012628).
- dmaengine: at_hdmac: Extend the Flow Controller bitfield to
  three bits (bsc#1012628).
- riscv: perf: Fix callchain parse error with kernel tracepoint
  events (bsc#1012628).
- io_uring: undeprecate epoll_ctl support (bsc#1012628).
- selinux: don't use make's grouped targets feature yet
  (bsc#1012628).
- mtdchar: mark bits of ioctl handler noinline (bsc#1012628).
- tracing/timerlat: Always wakeup the timerlat thread
  (bsc#1012628).
- tracing/histograms: Allow variables to have some modifiers
  (bsc#1012628).
- tracing/probe: trace_probe_primary_from_call(): checked
  list_first_entry (bsc#1012628).
- selftests: mptcp: connect: skip if MPTCP is not supported
  (bsc#1012628).
- selftests: mptcp: pm nl: skip if MPTCP is not supported
  (bsc#1012628).
- selftests: mptcp: join: skip if MPTCP is not supported
  (bsc#1012628).
- selftests: mptcp: join: avoid using 'cmp --bytes' (bsc#1012628).
- selftests: mptcp: diag: skip if MPTCP is not supported
  (bsc#1012628).
- selftests: mptcp: simult flows: skip if MPTCP is not supported
  (bsc#1012628).
- selftests: mptcp: sockopt: skip if MPTCP is not supported
  (bsc#1012628).
- selftests: mptcp: userspace pm: skip if MPTCP is not supported
  (bsc#1012628).
- mptcp: fix connect timeout handling (bsc#1012628).
- mptcp: fix active subflow finalization (bsc#1012628).
- ext4: add EA_INODE checking to ext4_iget() (bsc#1012628).
- ext4: set lockdep subclass for the ea_inode in
  ext4_xattr_inode_cache_find() (bsc#1012628).
- ext4: disallow ea_inodes with extended attributes (bsc#1012628).
- ext4: add lockdep annotations for i_data_sem for ea_inode's
  (bsc#1012628).
- fbcon: Fix null-ptr-deref in soft_cursor (bsc#1012628).
- serial: 8250_tegra: Fix an error handling path in
  tegra_uart_probe() (bsc#1012628).
- serial: cpm_uart: Fix a COMPILE_TEST dependency (bsc#1012628).
- powerpc/xmon: Use KSYM_NAME_LEN in array size (bsc#1012628).
- test_firmware: prevent race conditions by a correct
  implementation of locking (bsc#1012628).
- test_firmware: fix a memory leak with reqs buffer (bsc#1012628).
- test_firmware: fix the memory leak of the allocated firmware
  buffer (bsc#1012628).
- KVM: arm64: Populate fault info for watchpoint (bsc#1012628).
- KVM: arm64: Drop last page ref in
  kvm_pgtable_stage2_free_removed() (bsc#1012628).
- KVM: x86/mmu: Grab memslot for correct address space in NX
  recovery worker (bsc#1012628).
- KVM: x86: Account fastpath-only VM-Exits in vCPU stats
  (bsc#1012628).
- KVM: x86: Bail from kvm_recalculate_phys_map() if x2APIC ID
  is out-of-bounds (bsc#1012628).
- ksmbd: fix credit count leakage (bsc#1012628).
- ksmbd: fix UAF issue from opinfo->conn (bsc#1012628).
- ksmbd: fix incorrect AllocationSize set in smb2_get_info
  (bsc#1012628).
- ksmbd: fix slab-out-of-bounds read in smb2_handle_negotiate
  (bsc#1012628).
- ksmbd: fix multiple out-of-bounds read during context decoding
  (bsc#1012628).
- KEYS: asymmetric: Copy sig and digest in
  public_key_verify_signature() (bsc#1012628).
- regmap: Account for register length when chunking (bsc#1012628).
- tpm, tpm_tis: Request threaded interrupt handler (bsc#1012628).
- iommu/amd/pgtbl_v2: Fix domain max address (bsc#1012628).
- riscv: vmlinux.lds.S: Explicitly handle '.got' section
  (bsc#1012628).
- ext4: enable the lazy init thread when remounting read/write
  (bsc#1012628).
- commit b5f9ff5
* Sun Jun 11 2023 mkubecek@suse.cz
- Update to 6.4-rc6
- refresh configs
- commit e5bdb6f
* Sun Jun 11 2023 mkubecek@suse.cz
- config: refresh arm64/vanilla
- commit 3087200
* Sun Jun 11 2023 dmueller@suse.com
- config.conf: reenable armv7hl
- Update config files for armv7hl/6.4.0rc6
- commit 782615b
* Sun Jun 11 2023 dmueller@suse.com
- config.conf: Reenable arm64 configs
- config: Update to 6.4-rc5:
  * this includes lowering the ARCH_FORCE_MAX_ORDER by one given the
    change of definition in mainline commit 23baf831a32c
    ("mm, treewide: redefine MAX_ORDER sanely")
  * config change from x86_64 adopted for arm64. Enabled all erratas,
    rest compile as modules
- commit 084e86f
* Fri Jun  9 2023 msuchanek@suse.de
- Move setting %%%%build_html to config.sh
- commit dd39da3
* Fri Jun  9 2023 tiwai@suse.de
- Update patch reference for memstick fix (CVE-2023-3141 bsc#1212129 bsc#1211449)
- commit 2c9fe82
* Fri Jun  9 2023 msuchanek@suse.de
- Fix missing top level chapter numbers on SLE12 SP5 (bsc#1212158).
- commit 7ebcbd5
* Thu Jun  8 2023 msuchanek@suse.de
- Move setting %%%%split_optional to config.sh
- commit 8b0828d
* Thu Jun  8 2023 msuchanek@suse.de
- Move setting %%%%supported_modules_check to config.sh
- commit 3fcb4e0
* Thu Jun  8 2023 msuchanek@suse.de
- rpm/kernel-docs.spec.in: pass PYTHON=python3 to fix build error (bsc#1160435)
- commit 799f050
* Thu Jun  8 2023 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Fix compatibility wth newer rpm
- commit 334fb4d
* Wed Jun  7 2023 msuchanek@suse.de
- Also include kernel-docs build requirements for ALP
- commit 114d088
* Wed Jun  7 2023 msuchanek@suse.de
- Move the kernel-binary conflicts out of the spec file.
  Thie list of conflicting packages varies per release.
  To reduce merge conflicts move the list out of the spec file.
- commit 4d81125
* Wed Jun  7 2023 msuchanek@suse.de
- Avoid unsuported tar parameter on SLE12
- commit f11765a
* Wed Jun  7 2023 msuchanek@suse.de
- Move obsolete KMP list into a separate file.
  The list of obsoleted KMPs varies per release, move it out of the spec
  file.
- commit 016bc55
* Wed Jun  7 2023 msuchanek@suse.de
- Trim obsolete KMP list.
  SLE11 is out of support, we do not need to handle upgrading from SLE11
  SP1.
- commit 08819bb
* Wed Jun  7 2023 msuchanek@suse.de
- Generalize kernel-docs build requirements.
- Generalize kernel-doc build requirements.
- commit c80fe12
* Tue Jun  6 2023 msuchanek@suse.de
- Refresh patches.suse/add-suse-supported-flag.patch.
  Fix table alignment.
- commit 6152a50
* Tue Jun  6 2023 msuchanek@suse.de
- kernel-binary: Add back kernel-default-base guarded by option
  Add configsh option for splitting off kernel-default-base, and for
  not signing the kernel on non-efi
- commit 28c22af
* Mon Jun  5 2023 mfranc@suse.cz
- s390/ap: add ap status asynch error support (jsc#PED-3332).
- s390/ap: implement SE AP bind, unbind and associate
  (jsc#PED-3332).
- s390/ap: introduce low frequency polling possibility
  (jsc#PED-3332).
- s390/ap: new low level inline functions ap_bapq() and ap_aapq()
  (jsc#PED-3332).
- s390/ap: provide F bit parameter for ap_rapq() and ap_zapq()
  (jsc#PED-3332).
- s390/ap: filter ap card functions, new queue functions attribute
  (jsc#PED-3332).
- s390/ap: make tapq gr2 response a struct (jsc#PED-3332).
- s390/ap: introduce new AP bus sysfs attribute features
  (jsc#PED-3332).
- s390/ap: exploit new B bit from QCI config info (jsc#PED-3332).
- s390/zcrypt: replace scnprintf with sysfs_emit (jsc#PED-3332).
- s390/zcrypt: rework length information for dqap (jsc#PED-3332).
- s390/zcrypt: make psmid unsigned long instead of long long
  (jsc#PED-3332).
- commit 589eabc
* Mon Jun  5 2023 tiwai@suse.de
- media: dvb-core: Fix use-after-free due to race condition at
  dvb_ca_en50221 (CVE-2022-45919 bsc#1205803).
- media: dvb-core: Fix kernel WARNING for blocking operation in
  wait_event*() (CVE-2023-31084 bsc#1210783).
- media: dvb-core: Fix use-after-free due to race at
  dvb_register_device() (CVE-2022-45884 bsc#1205756).
- media: dvb-core: Fix use-after-free due on race condition at
  dvb_net (CVE-2022-45886 bsc#1205760).
- media: dvb-core: Fix use-after-free on race condition at
  dvb_frontend (CVE-2022-45885 bsc#1205758).
- media: ttusb-dec: fix memory leak in ttusb_dec_exit_dvb()
  (CVE-2022-45887 bsc#1205762).
- commit c56eadf
* Mon Jun  5 2023 tiwai@suse.de
- Update patch metadata for security fixes (bsc#1209287 CVE-2023-1380 bsc#1210533 CVE-2023-2002 bsc#1210806 CVE-2023-2269 CVE-2023-32233 bsc#1211043)
- commit 461c57a
* Mon Jun  5 2023 jslaby@suse.cz
- Linux 6.3.6 (bsc#1012628).
- netfilter: ctnetlink: Support offloaded conntrack entry deletion
  (bsc#1012628).
- cpufreq: amd-pstate: Add ->fast_switch() callback (bsc#1012628).
- cpufreq: amd-pstate: Update policy->cur in
  amd_pstate_adjust_perf() (bsc#1012628).
- bluetooth: Add cmd validity checks at the start of
  hci_sock_ioctl() (bsc#1012628).
- net: phy: mscc: enable VSC8501/2 RGMII RX clock (bsc#1012628).
- cpufreq: amd-pstate: Remove fast_switch_possible flag from
  active driver (bsc#1012628).
- vfio/type1: check pfn valid before converting to struct page
  (bsc#1012628).
- blk-mq: fix race condition in active queue accounting
  (bsc#1012628).
- blk-wbt: fix that wbt can't be disabled by default
  (bsc#1012628).
- bpf, sockmap: Incorrectly handling copied_seq (bsc#1012628).
- bpf, sockmap: Wake up polling after data copy (bsc#1012628).
- bpf, sockmap: TCP data stall on recv before accept
  (bsc#1012628).
- bpf, sockmap: Handle fin correctly (bsc#1012628).
- bpf, sockmap: Improved check for empty queue (bsc#1012628).
- bpf, sockmap: Reschedule is now done through backlog
  (bsc#1012628).
- bpf, sockmap: Convert schedule_work into delayed_work
  (bsc#1012628).
- bpf, sockmap: Pass skb ownership through read_skb (bsc#1012628).
- gpio-f7188x: fix chip name and pin count on Nuvoton chip
  (bsc#1012628).
- net/mlx5: E-switch, Devcom, sync devcom events and devcom comp
  register (bsc#1012628).
- Revert "net/mlx5: Expose vnic diagnostic counters for eswitch
  managed vports" (bsc#1012628).
- Revert "net/mlx5: Expose steering dropped packets counter"
  (bsc#1012628).
- net/mlx5e: TC, Fix using eswitch mapping in nic mode
  (bsc#1012628).
- drm/i915: Fix PIPEDMC disabling for a bigjoiner configuration
  (bsc#1012628).
- drm/i915: Disable DPLLs before disconnecting the TC PHY
  (bsc#1012628).
- drm/i915: Move shared DPLL disabling into CRTC disable hook
  (bsc#1012628).
- ASoC: Intel: avs: Fix module lookup (bsc#1012628).
- cxl/port: Fix NULL pointer access in devm_cxl_add_port()
  (bsc#1012628).
- net: fec: add dma_wmb to ensure correct descriptor values
  (bsc#1012628).
- tls: rx: strp: don't use GFP_KERNEL in softirq context
  (bsc#1012628).
- tls: rx: strp: preserve decryption status of skbs when needed
  (bsc#1012628).
- tls: rx: strp: factor out copying skb data (bsc#1012628).
- tls: rx: strp: force mixed decrypted records into copy mode
  (bsc#1012628).
- tls: rx: strp: fix determining record length in copy mode
  (bsc#1012628).
- tls: rx: strp: set the skb->len of detached / CoW'ed skbs
  (bsc#1012628).
- tls: rx: device: fix checking decryption status (bsc#1012628).
- gpiolib: fix allocation of mixed dynamic/static GPIOs
  (bsc#1012628).
- bpf: netdev: init the offload table earlier (bsc#1012628).
- platform/x86/amd/pmf: Fix CnQF and auto-mode after resume
  (bsc#1012628).
- power: supply: rt9467: Fix passing zero to 'dev_err_probe'
  (bsc#1012628).
- selftests/bpf: Fix pkg-config call building sign-file
  (bsc#1012628).
- ARM: dts: imx6ull-dhcor: Set and limit the mode for PMIC buck 1,
  2 and 3 (bsc#1012628).
- coresight: perf: Release Coresight path when alloc trace id
  failed (bsc#1012628).
- spi: spi-geni-qcom: Select FIFO mode for chip select
  (bsc#1012628).
- firmware: arm_ffa: Fix usage of partition info get count flag
  (bsc#1012628).
- firmware: arm_scmi: Fix incorrect alloc_workqueue() invocation
  (bsc#1012628).
- commit f583ba4
* Mon Jun  5 2023 jslaby@suse.cz
- drm/amd/display: Only wait for blank completion if OTG active
  (https://gitlab.freedesktop.org/drm/amd/-/issues/2447).
- commit fc379fb
* Sun Jun  4 2023 mkubecek@suse.cz
- Update to 6.4-rc5
- refresh configs
- commit 2cab33e
* Fri Jun  2 2023 msuchanek@suse.de
- usrmerge: Compatibility with earlier rpm (boo#1211796)
- commit 2191d32
* Fri Jun  2 2023 jslaby@suse.cz
- Revert "Remove usrmerge compatibility symlink in buildroot (boo#1211796)"
  This reverts commit b8e00c5a84bcd75a1e2c491b6de601278e1572c7. It still
  breaks build as it needs support in kmod (SR#1089967).
- commit 6db9c44
* Fri Jun  2 2023 jslaby@suse.cz
- Revert "Fix usrmerge error (boo#1211796)"
  This reverts commit da84579e78f4c4efa5b3b910484fdaedc79fefec. It still
  breaks build as it needs support in kmod (SR#1089967).
- commit 4b4675f
* Fri Jun  2 2023 jslaby@suse.cz
- Revert "Revert "Remove usrmerge compatibility symlink in buildroot (boo#1211796)""
  This reverts commit 6db9c44d07ee5bb9d1556fb52efbec6bb26b00a3.
  https://github.com/openSUSE/installation-images/pull/648 was merged
  finally.
- Revert "Revert "Remove usrmerge compatibility symlink in buildroot (boo#1211796)""
  This reverts commit d3cbce2379049d1657919d6ced51f6f5141f66fd, we will
  merge a fix from the packaging branch.
- commit 92dc30d
* Thu Jun  1 2023 msuchanek@suse.de
- Fix usrmerge error (boo#1211796)
- commit da84579
* Thu Jun  1 2023 jslaby@suse.cz
- Revert "Remove usrmerge compatibility symlink in buildroot (boo#1211796)"
  This reverts commit b8e00c5a84bcd75a1e2c491b6de601278e1572c7, as it
  breaks the build:
  + sed -ie s,/lib/modules/,/usr/lib/modules/,linux-6.3.5-0.g99c5100/Makefile scripts/depmod.sh
  sed: can't read linux-6.3.5-0.g99c5100/Makefile: No such file or directory
- commit d3cbce2
* Thu Jun  1 2023 ailiop@suse.com
- xfs: verify buffer contents when we skip log replay (bsc#1210498
  CVE-2023-2124).
- commit 394c575
* Thu Jun  1 2023 jslaby@suse.cz
- Update config files -- X86_KERNEL_IBT=y (bsc#1211890).
- commit 50dbc0a
* Wed May 31 2023 jslaby@suse.cz
- Linux 6.3.5 (bsc#1012628).
- wifi: rtw89: 8852b: adjust quota to avoid SER L1 caused by
  access null page (bsc#1012628).
- usb: dwc3: fix gadget mode suspend interrupt handler issue
  (bsc#1012628).
- tpm, tpm_tis: Avoid cache incoherency in test for interrupts
  (bsc#1012628).
- tpm, tpm_tis: Only handle supported interrupts (bsc#1012628).
- tpm_tis: Use tpm_chip_{start,stop} decoration inside
  tpm_tis_resume (bsc#1012628).
- tpm, tpm_tis: startup chip before testing for interrupts
  (bsc#1012628).
- tpm: Re-enable TPM chip boostrapping non-tpm_tis TPM drivers
  (bsc#1012628).
- tpm: Prevent hwrng from activating during resume (bsc#1012628).
- zsmalloc: move LRU update from zs_map_object() to zs_malloc()
  (bsc#1012628).
- watchdog: sp5100_tco: Immediately trigger upon starting
  (bsc#1012628).
- mm/vmemmap/devdax: fix kernel crash when probing devdax devices
  (bsc#1012628).
- ocfs2: Switch to security_inode_init_security() (bsc#1012628).
- x86/mm: Avoid incomplete Global INVLPG flushes (bsc#1012628).
- platform/x86/intel/ifs: Annotate work queue on stack so object
  debug does not complain (bsc#1012628).
- cifs: Fix cifs_limit_bvec_subset() to correctly check the
  maxmimum size (bsc#1012628).
- cifs: fix smb1 mount regression (bsc#1012628).
- ALSA: hda/ca0132: add quirk for EVGA X299 DARK (bsc#1012628).
- ALSA: hda: Fix unhandled register update during auto-suspend
  period (bsc#1012628).
- ALSA: hda/realtek: Enable headset onLenovo M70/M90
  (bsc#1012628).
- SUNRPC: Don't change task->tk_status after the call to
  rpc_exit_task (bsc#1012628).
- mmc: sdhci-esdhc-imx: make "no-mmc-hs400" works (bsc#1012628).
- mmc: block: ensure error propagation for non-blk (bsc#1012628).
- power: supply: axp288_fuel_gauge: Fix external_power_changed
  race (bsc#1012628).
- power: supply: bq25890: Fix external_power_changed race
  (bsc#1012628).
- ASoC: rt5682: Disable jack detection interrupt during suspend
  (bsc#1012628).
- net: cdc_ncm: Deal with too low values of dwNtbOutMaxSize
  (bsc#1012628).
- m68k: Move signal frame following exception on 68020/030
  (bsc#1012628).
- ipv{4,6}/raw: fix output xfrm lookup wrt protocol (bsc#1012628).
- xtensa: fix signal delivery to FDPIC process (bsc#1012628).
- xtensa: add __bswap{si,di}2 helpers (bsc#1012628).
- parisc: Use num_present_cpus() in alternative patching code
  (bsc#1012628).
- parisc: Handle kgdb breakpoints only in kernel context
  (bsc#1012628).
- parisc: Fix flush_dcache_page() for usage from irq context
  (bsc#1012628).
- parisc: Allow to reboot machine after system halt (bsc#1012628).
- parisc: Enable LOCKDEP support (bsc#1012628).
- parisc: Handle kprobes breakpoints only in kernel context
  (bsc#1012628).
- cxl/port: Enable the HDM decoder capability for switch ports
  (bsc#1012628).
- gpio: mockup: Fix mode of debugfs files (bsc#1012628).
- btrfs: use nofs when cleaning up aborted transactions
  (bsc#1012628).
- thermal: intel: int340x: Add new line for UUID display
  (bsc#1012628).
- block: fix bio-cache for passthru IO (bsc#1012628).
- dt-binding: cdns,usb3: Fix cdns,on-chip-buff-size type
  (bsc#1012628).
- drm/amd/display: Have Payload Properly Created After Resume
  (bsc#1012628).
- drm/mgag200: Fix gamma lut not initialized (bsc#1012628).
- drm/radeon: reintroduce radeon_dp_work_func content
  (bsc#1012628).
- drm/amdgpu: don't enable secure display on incompatible
  platforms (bsc#1012628).
- drm/amd/pm: add missing NotifyPowerSource message mapping for
  SMU13.0.7 (bsc#1012628).
- drm/amd/pm: Fix output of pp_od_clk_voltage (bsc#1012628).
- Revert "binder_alloc: add missing mmap_lock calls when using
  the VMA" (bsc#1012628).
- Revert "android: binder: stop saving a pointer to the VMA"
  (bsc#1012628).
- binder: add lockless binder_alloc_(set|get)_vma() (bsc#1012628).
- binder: fix UAF caused by faulty buffer cleanup (bsc#1012628).
- binder: fix UAF of alloc->vma in race with munmap()
  (bsc#1012628).
- drm/amd/amdgpu: limit one queue per gang (bsc#1012628).
- perf/x86/uncore: Correct the number of CHAs on SPR
  (bsc#1012628).
- x86/topology: Fix erroneous smp_num_siblings on Intel Hybrid
  platforms (bsc#1012628).
- irqchip/mips-gic: Don't touch vl_map if a local interrupt is
  not routable (bsc#1012628).
- irqchip/mips-gic: Use raw spinlock for gic_lock (bsc#1012628).
- debugobjects: Don't wake up kswapd from fill_pool()
  (bsc#1012628).
- fbdev: udlfb: Fix endpoint check (bsc#1012628).
- net: fix stack overflow when LRO is disabled for virtual
  interfaces (bsc#1012628).
- udplite: Fix NULL pointer dereference in
  __sk_mem_raise_allocated() (bsc#1012628).
- USB: core: Add routines for endpoint checks in old drivers
  (bsc#1012628).
- USB: sisusbvga: Add endpoint checks (bsc#1012628).
- media: radio-shark: Add endpoint checks (bsc#1012628).
- ASoC: lpass: Fix for KASAN use_after_free out of bounds
  (bsc#1012628).
- net: fix skb leak in __skb_tstamp_tx() (bsc#1012628).
- drm: fix drmm_mutex_init() (bsc#1012628).
- selftests: fib_tests: mute cleanup error message (bsc#1012628).
- octeontx2-pf: Fix TSOv6 offload (bsc#1012628).
- bpf: Fix mask generation for 32-bit narrow loads of 64-bit
  fields (bsc#1012628).
- bpf: fix a memory leak in the LRU and LRU_PERCPU hash maps
  (bsc#1012628).
- lan966x: Fix unloading/loading of the driver (bsc#1012628).
- ipv6: Fix out-of-bounds access in ipv6_find_tlv() (bsc#1012628).
- cifs: mapchars mount option ignored (bsc#1012628).
- power: supply: leds: Fix blink to LED on transition
  (bsc#1012628).
- power: supply: mt6360: add a check of devm_work_autocancel in
  mt6360_charger_probe (bsc#1012628).
- power: supply: bq27xxx: Fix bq27xxx_battery_update() race
  condition (bsc#1012628).
- power: supply: bq27xxx: Fix I2C IRQ race on remove
  (bsc#1012628).
- power: supply: bq27xxx: Fix poll_interval handling and races
  on remove (bsc#1012628).
- power: supply: bq27xxx: Add cache parameter to
  bq27xxx_battery_current_and_status() (bsc#1012628).
- power: supply: bq27xxx: Move bq27xxx_battery_update() down
  (bsc#1012628).
- power: supply: bq27xxx: Ensure power_supply_changed() is called
  on current sign changes (bsc#1012628).
- power: supply: bq27xxx: After charger plug in/out wait 0.5s
  for things to stabilize (bsc#1012628).
- power: supply: bq25890: Call power_supply_changed() after
  updating input current or voltage (bsc#1012628).
- power: supply: bq24190: Call power_supply_changed() after
  updating input current (bsc#1012628).
- power: supply: sbs-charger: Fix INHIBITED bit for Status reg
  (bsc#1012628).
- optee: fix uninited async notif value (bsc#1012628).
- firmware: arm_ffa: Check if ffa_driver remove is present before
  executing (bsc#1012628).
- firmware: arm_ffa: Fix FFA device names for logical partitions
  (bsc#1012628).
- fs: fix undefined behavior in bit shift for SB_NOUSER
  (bsc#1012628).
- regulator: pca9450: Fix BUCK2 enable_mask (bsc#1012628).
- platform/x86: ISST: Remove 8 socket limit (bsc#1012628).
- coresight: Fix signedness bug in
  tmc_etr_buf_insert_barrier_packet() (bsc#1012628).
- ARM: dts: imx6qdl-mba6: Add missing pvcie-supply regulator
  (bsc#1012628).
- x86/pci/xen: populate MSI sysfs entries (bsc#1012628).
- xen/pvcalls-back: fix double frees with
  pvcalls_new_active_socket() (bsc#1012628).
- x86/show_trace_log_lvl: Ensure stack pointer is aligned, again
  (bsc#1012628).
- ASoC: Intel: Skylake: Fix declaration of enum skl_ch_cfg
  (bsc#1012628).
- ASoC: Intel: avs: Fix declaration of enum avs_channel_config
  (bsc#1012628).
- ASoC: Intel: avs: Access path components under lock
  (bsc#1012628).
- cxl: Wait Memory_Info_Valid before access memory related info
  (bsc#1012628).
- cxl: Move cxl_await_media_ready() to before capacity info
  retrieval (bsc#1012628).
- sctp: fix an issue that plpmtu can never go to complete state
  (bsc#1012628).
- forcedeth: Fix an error handling path in nv_probe()
  (bsc#1012628).
- platform/mellanox: mlxbf-pmc: fix sscanf() error checking
  (bsc#1012628).
- net/mlx5e: Fix SQ wake logic in ptp napi_poll context
  (bsc#1012628).
- net/mlx5e: Fix deadlock in tc route query code (bsc#1012628).
- net/mlx5e: Use correct encap attribute during invalidation
  (bsc#1012628).
- net/mlx5e: do as little as possible in napi poll when budget
  is 0 (bsc#1012628).
- net/mlx5: DR, Fix crc32 calculation to work on big-endian (BE)
  CPUs (bsc#1012628).
- net/mlx5: Handle pairing of E-switch via uplink un/load APIs
  (bsc#1012628).
- net/mlx5: DR, Check force-loopback RC QP capability
  independently from RoCE (bsc#1012628).
- net/mlx5: Fix error message when failing to allocate device
  memory (bsc#1012628).
- net/mlx5: Collect command failures data only for known commands
  (bsc#1012628).
- net/mlx5: Devcom, fix error flow in mlx5_devcom_register_device
  (bsc#1012628).
- net/mlx5: Devcom, serialize devcom registration (bsc#1012628).
- arm64: dts: imx8mn-var-som: fix PHY detection bug by adding
  deassert delay (bsc#1012628).
- firmware: arm_ffa: Set reserved/MBZ fields to zero in the
  memory descriptors (bsc#1012628).
- regulator: mt6359: add read check for PMIC MT6359 (bsc#1012628).
- net/smc: Reset connection when trying to use SMCRv2 fails
  (bsc#1012628).
- 3c589_cs: Fix an error handling path in tc589_probe()
  (bsc#1012628).
- page_pool: fix inconsistency for page_pool_ring_[un]lock()
  (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix QoS on DSA MAC on non
  MTK_NETSYS_V2 SoCs (bsc#1012628).
- net: phy: mscc: add VSC8502 to MODULE_DEVICE_TABLE
  (bsc#1012628).
- Revert "arm64: dts: imx8mp: Drop simple-bus from
  fsl,imx8mp-media-blk-ctrl" (bsc#1012628).
- commit fc86ff2
* Mon May 29 2023 msuchanek@suse.de
- Remove usrmerge compatibility symlink in buildroot (boo#1211796)
  Besides Makefile depmod.sh needs to be patched to prefix /lib/modules.
  Requires corresponding patch to kmod.
- commit b8e00c5
* Mon May 29 2023 jslaby@suse.cz
- xfs: fix livelock in delayed allocation at ENOSPC (brc#2208553
  xfs-issue).
- commit 2c66b1f
* Sun May 28 2023 mkubecek@suse.cz
- Update to 6.4-rc4
- refresh configs
- commit 2e9e157
* Fri May 26 2023 mkoutny@suse.com
- supported.conf: Add a guard for unsupported rose module
- commit ffa03aa
* Fri May 26 2023 jlee@suse.com
- Revert "Disable lockdown. (bsc#1209006)"
  This reverts commit 44ca817f15b215421a4c788790dd5351c186d1df.
  Let's enable kernel lockdown function in master branch again.
  This time we will test with NVIDIA KMP.
- commit 5ab030f
* Fri May 26 2023 jlee@suse.com
- Revert "Revert "Update config files." (bsc#1211166)"
  This reverts commit 944713a45f59680c926e1a4d51798970f8af1767.
  Let's enable kernel lockdown function in master branch again.
  This time we will test with NVIDIA KMP.
- commit 1bf0f73
* Thu May 25 2023 mkoutny@suse.com
- supported.conf: Add guard against future CVE-2016-3695 (bsc#1023051)
  Just add more comment in support.conf, no change.
- commit 337e000
* Thu May 25 2023 jslaby@suse.cz
- Linux 6.3.4 (bsc#1012628).
- drm/fbdev-generic: prohibit potential out-of-bounds access
  (bsc#1012628).
- drm/dsc: fix DP_DSC_MAX_BPP_DELTA_* macro values (bsc#1012628).
- drm/nouveau/disp: More DP_RECEIVER_CAP_SIZE array fixes
  (bsc#1012628).
- drm/mipi-dsi: Set the fwnode for mipi_dsi_device (bsc#1012628).
- ARM: 9296/1: HP Jornada 7XX: fix kernel-doc warnings
  (bsc#1012628).
- net: skb_partial_csum_set() fix against transport header magic
  value (bsc#1012628).
- net: mdio: mvusb: Fix an error handling path in
  mvusb_mdio_probe() (bsc#1012628).
- perf/core: Fix perf_sample_data not properly initialized for
  different swevents in perf_tp_event() (bsc#1012628).
- scsi: ufs: core: Fix I/O hang that occurs when BKOPS fails in
  W-LUN suspend (bsc#1012628).
- tick/broadcast: Make broadcast device replacement work correctly
  (bsc#1012628).
- linux/dim: Do nothing if no time delta between samples
  (bsc#1012628).
- net: stmmac: Initialize MAC_ONEUS_TIC_COUNTER register
  (bsc#1012628).
- net: Fix load-tearing on sk->sk_stamp in sock_recv_cmsgs()
  (bsc#1012628).
- net: phy: bcm7xx: Correct read from expansion register
  (bsc#1012628).
- netfilter: nf_tables: always release netdev hooks from notifier
  (bsc#1012628).
- netfilter: conntrack: fix possible bug_on with enable_hooks=1
  (bsc#1012628).
- bonding: fix send_peer_notif overflow (bsc#1012628).
- netlink: annotate accesses to nlk->cb_running (bsc#1012628).
- net: annotate sk->sk_err write from do_recvmmsg() (bsc#1012628).
- net: deal with most data-races in sk_wait_event() (bsc#1012628).
- net: add vlan_get_protocol_and_depth() helper (bsc#1012628).
- tcp: add annotations around sk->sk_shutdown accesses
  (bsc#1012628).
- gve: Remove the code of clearing PBA bit (bsc#1012628).
- ipvlan:Fix out-of-bounds caused by unclear skb->cb
  (bsc#1012628).
- net: mscc: ocelot: fix stat counter register values
  (bsc#1012628).
- drm/sched: Check scheduler work queue before calling timeout
  handling (bsc#1012628).
- net: datagram: fix data-races in datagram_poll() (bsc#1012628).
- af_unix: Fix a data race of sk->sk_receive_queue->qlen
  (bsc#1012628).
- af_unix: Fix data races around sk->sk_shutdown (bsc#1012628).
- drm/i915/guc: Don't capture Gen8 regs on Xe devices
  (bsc#1012628).
- drm/i915: Fix NULL ptr deref by checking new_crtc_state
  (bsc#1012628).
- drm/i915/dp: prevent potential div-by-zero (bsc#1012628).
- drm/i915: taint kernel when force probing unsupported devices
  (bsc#1012628).
- fbdev: arcfb: Fix error handling in arcfb_probe() (bsc#1012628).
- ext4: reflect error codes from ext4_multi_mount_protect()
  to its callers (bsc#1012628).
- ext4: don't clear SB_RDONLY when remounting r/w until quota
  is re-enabled (bsc#1012628).
- ext4: allow to find by goal if EXT4_MB_HINT_GOAL_ONLY is set
  (bsc#1012628).
- ext4: allow ext4_get_group_info() to fail (bsc#1012628).
- refscale: Move shutdown from wait_event() to wait_event_idle()
  (bsc#1012628).
- selftests: cgroup: Add 'malloc' failures checks in
  test_memcontrol (bsc#1012628).
- rcu: Protect rcu_print_task_exp_stall() ->exp_tasks access
  (bsc#1012628).
- open: return EINVAL for O_DIRECTORY | O_CREAT (bsc#1012628).
- fs: hfsplus: remove WARN_ON() from
  hfsplus_cat_{read,write}_inode() (bsc#1012628).
- drm/displayid: add displayid_get_header() and check bounds
  better (bsc#1012628).
- drm/amd/display: populate subvp cmd info only for the top pipe
  (bsc#1012628).
- drm/amd/display: Correct DML calculation to align HW formula
  (bsc#1012628).
- drm/amd/display: enable DPG when disabling plane for phantom
  pipe (bsc#1012628).
- platform/x86: x86-android-tablets: Add Acer Iconia One 7 B1-750
  data (bsc#1012628).
- drm/amd/display: Enable HostVM based on rIOMMU active
  (bsc#1012628).
- drm/amd/display: Use DC_LOG_DC in the trasform pixel function
  (bsc#1012628).
- regmap: cache: Return error in cache sync operations for
  REGCACHE_NONE (bsc#1012628).
- remoteproc: imx_dsp_rproc: Add custom memory copy implementation
  for i.MX DSP Cores (bsc#1012628).
- arm64: dts: qcom: msm8996: Add missing DWC3 quirks
  (bsc#1012628).
- accel/habanalabs: postpone mem_mgr IDR destruction to
  hpriv_release() (bsc#1012628).
- drm/amd/display: reallocate DET for dual displays with high
  pixel rate ratio (bsc#1012628).
- media: imx-jpeg: Bounds check sizeimage access (bsc#1012628).
- media: cx23885: Fix a null-ptr-deref bug in buffer_prepare()
  and buffer_finish() (bsc#1012628).
- media: pci: tw68: Fix null-ptr-deref bug in buf prepare and
  finish (bsc#1012628).
- media: pvrusb2: VIDEO_PVRUSB2 depends on DVB_CORE to use dvb_*
  symbols (bsc#1012628).
- platform/x86/intel: vsec: Explicitly enable capabilities
  (bsc#1012628).
- ACPI: processor: Check for null return of devm_kzalloc()
  in fch_misc_setup() (bsc#1012628).
- drm/rockchip: dw_hdmi: cleanup drm encoder during unbind
  (bsc#1012628).
- memstick: r592: Fix UAF bug in r592_remove due to race condition
  (bsc#1012628).
- arm64: dts: imx8mq-librem5: Remove dis_u3_susphy_quirk from
  usb_dwc3_0 (bsc#1012628).
- firmware: arm_sdei: Fix sleep from invalid context BUG
  (bsc#1012628).
- ACPI: EC: Fix oops when removing custom query handlers
  (bsc#1012628).
- drm/amd/display: fixed dcn30+ underflow issue (bsc#1012628).
- remoteproc: stm32_rproc: Add mutex protection for workqueue
  (bsc#1012628).
- accel/ivpu: Remove D3hot delay for Meteorlake (bsc#1012628).
- drm/tegra: Avoid potential 32-bit integer overflow
  (bsc#1012628).
- drm/msm/dp: Clean up handling of DP AUX interrupts
  (bsc#1012628).
- ACPICA: Avoid undefined behavior: applying zero offset to null
  pointer (bsc#1012628).
- ACPICA: ACPICA: check null return of ACPI_ALLOCATE_ZEROED in
  acpi_db_display_objects (bsc#1012628).
- arm64: dts: qcom: sdm845-polaris: Drop inexistent properties
  (bsc#1012628).
- arm64: dts: qcom: sm6115-j606f: Add ramoops node (bsc#1012628).
- irqchip/gicv3: Workaround for NVIDIA erratum T241-FABRIC-4
  (bsc#1012628).
- media: ipu3-cio2: support multiple sensors and VCMs with same
  HID (bsc#1012628).
- ACPI: video: Remove desktops without backlight DMI quirks
  (bsc#1012628).
- drm/amd/display: Correct DML calculation to follow HW SPEC
  (bsc#1012628).
- drm/amd: Fix an out of bounds error in BIOS parser
  (bsc#1012628).
- drm/amdgpu: Fix sdma v4 sw fini error (bsc#1012628).
- media: Prefer designated initializers over memset for subdev
  pad ops (bsc#1012628).
- drm/amdgpu: Enable IH retry CAM on GFX9 (bsc#1012628).
- media: mediatek: vcodec: Fix potential array out-of-bounds in
  decoder queue_setup (bsc#1012628).
- platform/x86/amd: pmc: Fix memory leak in
  amd_pmc_stb_debugfs_open_v2() (bsc#1012628).
- hwmon: (nzxt-smart2) add another USB ID (bsc#1012628).
- wifi: ath: Silence memcpy run-time false positive warning
  (bsc#1012628).
- wifi: ath12k: Handle lock during peer_id find (bsc#1012628).
- wifi: ath12k: PCI ops for wakeup/release MHI (bsc#1012628).
- bpf: Annotate data races in bpf_local_storage (bsc#1012628).
- wifi: brcmfmac: pcie: Provide a buffer of random bytes to the
  device (bsc#1012628).
- wifi: brcmfmac: cfg80211: Pass the PMK in binary instead of hex
  (bsc#1012628).
- wifi: brcmfmac: pcie: Add IDs/properties for BCM4387
  (bsc#1012628).
- ext2: Check block size validity during mount (bsc#1012628).
- scsi: lpfc: Prevent lpfc_debugfs_lockstat_write() buffer
  overflow (bsc#1012628).
- scsi: lpfc: Correct used_rpi count when devloss tmo fires with
  no recovery (bsc#1012628).
- wifi: rtw88: fix memory leak in rtw_usb_probe() (bsc#1012628).
- bnxt: avoid overflow in bnxt_get_nvram_directory()
  (bsc#1012628).
- net: pasemi: Fix return type of pasemi_mac_start_tx()
  (bsc#1012628).
- wifi: ath12k: fix memory leak in ath12k_qmi_driver_event_work()
  (bsc#1012628).
- net: Catch invalid index in XPS mapping (bsc#1012628).
- netdev: Enforce index cap in netdev_get_tx_queue (bsc#1012628).
- scsi: target: iscsit: Free cmds before session free
  (bsc#1012628).
- lib: cpu_rmap: Avoid use after free on rmap->obj array entries
  (bsc#1012628).
- scsi: message: mptlan: Fix use after free bug in mptlan_remove()
  due to race condition (bsc#1012628).
- gfs2: Fix inode height consistency check (bsc#1012628).
- scsi: ufs: ufs-pci: Add support for Intel Lunar Lake
  (bsc#1012628).
- scsi: hisi_sas: Grab sas_dev lock when traversing the members
  of sas_dev.list (bsc#1012628).
- ext4: set goal start correctly in ext4_mb_normalize_request
  (bsc#1012628).
- ext4: Fix best extent lstart adjustment logic in
  ext4_mb_new_inode_pa() (bsc#1012628).
- crypto: jitter - permanent and intermittent health errors
  (bsc#1012628).
- f2fs: Fix system crash due to lack of free space in LFS
  (bsc#1012628).
- f2fs: fix to drop all dirty pages during umount() if cp_error
  is set (bsc#1012628).
- f2fs: fix to check readonly condition correctly (bsc#1012628).
- samples/bpf: Fix fout leak in hbm's run_bpf_prog (bsc#1012628).
- bpf: Add preempt_count_{sub,add} into btf id deny list
  (bsc#1012628).
- md: fix soft lockup in status_resync (bsc#1012628).
- net/sched: pass netlink extack to mqprio and taprio offload
  (bsc#1012628).
- wifi: iwlwifi: pcie: fix possible NULL pointer dereference
  (bsc#1012628).
- wifi: iwlwifi: add a new PCI device ID for BZ device
  (bsc#1012628).
- wifi: iwlwifi: pcie: Fix integer overflow in
  iwl_write_to_user_buf (bsc#1012628).
- wifi: iwlwifi: mvm: fix ptk_pn memory leak (bsc#1012628).
- block, bfq: Fix division by zero error on zero wsum
  (bsc#1012628).
- wifi: ath11k: Ignore frags from uninitialized peer in dp
  (bsc#1012628).
- wifi: mt76: mt7921: add Netgear AXE3000 (A8000) support
  (bsc#1012628).
- wifi: iwlwifi: fix iwl_mvm_max_amsdu_size() for MLO
  (bsc#1012628).
- f2fs: relax sanity check if checkpoint is corrupted
  (bsc#1012628).
- null_blk: Always check queue mode setting from configfs
  (bsc#1012628).
- wifi: iwlwifi: dvm: Fix memcpy: detected field-spanning write
  backtrace (bsc#1012628).
- wifi: ath11k: Fix SKB corruption in REO destination ring
  (bsc#1012628).
- wifi: rtw88: Fix memory leak in rtw88_usb (bsc#1012628).
- nbd: fix incomplete validation of ioctl arg (bsc#1012628).
- ipvs: Update width of source for ip_vs_sync_conn_options
  (bsc#1012628).
- Bluetooth: btusb: Add new PID/VID 04ca:3801 for MT7663
  (bsc#1012628).
- Bluetooth: Add new quirk for broken local ext features page 2
  (bsc#1012628).
- Bluetooth: btrtl: add support for the RTL8723CS (bsc#1012628).
- Bluetooth: Improve support for Actions Semi ATS2851 based
  devices (bsc#1012628).
- Bluetooth: btrtl: check for NULL in btrtl_set_quirks()
  (bsc#1012628).
- Bluetooth: btintel: Add LE States quirk support (bsc#1012628).
- Bluetooth: hci_bcm: Fall back to getting bdaddr from EFI if
  not set (bsc#1012628).
- Bluetooth: Add new quirk for broken set random RPA timeout
  for ATS2851 (bsc#1012628).
- Bluetooth: L2CAP: fix "bad unlock balance" in
  l2cap_disconnect_rsp (bsc#1012628).
- Bluetooth: btrtl: Add the support for RTL8851B (bsc#1012628).
- staging: rtl8192e: Replace macro RTL_PCI_DEVICE with PCI_DEVICE
  (bsc#1012628).
- HID: apple: Set the tilde quirk flag on the Geyser 4 and later
  (bsc#1012628).
- iio: imu: st_lsm6dsx: discard samples during filters settling
  time (bsc#1012628).
- staging: axis-fifo: initialize timeouts in init only
  (bsc#1012628).
- xhci: mem: Carefully calculate size for memory allocations
  (bsc#1012628).
- spi: intel-pci: Add support for Meteor Lake-S SPI serial flash
  (bsc#1012628).
- ASoC: amd: yc: Add DMI entries to support HP OMEN 16-n0xxx
  (8A42) (bsc#1012628).
- HID: logitech-hidpp: Don't use the USB serial for USB devices
  (bsc#1012628).
- HID: logitech-hidpp: Reconcile USB and Unifying serials
  (bsc#1012628).
- spi: spi-imx: fix MX51_ECSPI_* macros when cs > 3 (bsc#1012628).
- usb: typec: ucsi: acpi: add quirk for ASUS Zenbook UM325
  (bsc#1012628).
- ALSA: hda: LNL: add HD Audio PCI ID (bsc#1012628).
- ASoC: amd: Add Dell G15 5525 to quirks list (bsc#1012628).
- ASoC: amd: yc: Add ThinkBook 14 G5+ ARP to quirks list for acp6x
  (bsc#1012628).
- ASoC: amd: Add check for acp config flags (bsc#1012628).
- HID: apple: Set the tilde quirk flag on the Geyser 3
  (bsc#1012628).
- HID: Ignore battery for ELAN touchscreen on ROG Flow X13 GV301RA
  (bsc#1012628).
- HID: wacom: generic: Set battery quirk only when we see battery
  data (bsc#1012628).
- usb: typec: tcpm: fix multiple times discover svids error
  (bsc#1012628).
- serial: 8250: Reinit port->pm on port specific driver unbind
  (bsc#1012628).
- mcb-pci: Reallocate memory region to avoid memory overlapping
  (bsc#1012628).
- powerpc: Use of_property_present() for testing DT property
  presence (bsc#1012628).
- sched: Fix KCSAN noinstr violation (bsc#1012628).
- lkdtm/stackleak: Fix noinstr violation (bsc#1012628).
- riscv: Fix EFI stub usage of KASAN instrumented strcmp function
  (bsc#1012628).
- recordmcount: Fix memory leaks in the uwrite function
  (bsc#1012628).
- RDMA/core: Fix multiple -Warray-bounds warnings (bsc#1012628).
- KVM: selftests: Add 'malloc' failure check in vcpu_save_state
  (bsc#1012628).
- iommu/arm-smmu-qcom: Limit the SMR groups to 128 (bsc#1012628).
- fs/ntfs3: Fix NULL pointer dereference in 'ni_write_inode'
  (bsc#1012628).
- fs/ntfs3: Enhance the attribute size check (bsc#1012628).
- fs/ntfs3: Fix NULL dereference in ni_write_inode (bsc#1012628).
- fs/ntfs3: Validate MFT flags before replaying logs
  (bsc#1012628).
- fs/ntfs3: Add length check in indx_get_root (bsc#1012628).
- fs/ntfs3: Fix a possible null-pointer dereference in ni_clear()
  (bsc#1012628).
- clk: tegra20: fix gcc-7 constant overflow warning (bsc#1012628).
- iommu/arm-smmu-v3: Acknowledge pri/event queue overflow if any
  (bsc#1012628).
- iommu/sprd: Release dma buffer to avoid memory leak
  (bsc#1012628).
- power: supply: axp288_charger: Use alt usb-id extcon on some
  x86 android tablets (bsc#1012628).
- Input: xpad - add constants for GIP interface numbers
  (bsc#1012628).
- RDMA/mlx5: Remove pcie_relaxed_ordering_enabled() check for
  RO write (bsc#1012628).
- clk: rockchip: rk3588: make gate linked clocks critical
  (bsc#1012628).
- cifs: missing lock when updating session status (bsc#1012628).
- pinctrl: at91: use devm_kasprintf() to avoid potential leaks
  (part 2) (bsc#1012628).
- soundwire: dmi-quirks: add remapping for Intel 'Rooks County'
  NUC M15 (bsc#1012628).
- phy: st: miphy28lp: use _poll_timeout functions for waits
  (bsc#1012628).
- soundwire: qcom: gracefully handle too many ports in DT
  (bsc#1012628).
- soundwire: bus: Fix unbalanced pm_runtime_put() causing usage
  count underflow (bsc#1012628).
- mfd: intel_soc_pmic_chtwc: Add Lenovo Yoga Book X90F to
  intel_cht_wc_models (bsc#1012628).
- mfd: dln2: Fix memory leak in dln2_probe() (bsc#1012628).
- mfd: intel-lpss: Add Intel Meteor Lake PCH-S LPSS PCI IDs
  (bsc#1012628).
- parisc: Replace regular spinlock with spin_trylock on panic path
  (bsc#1012628).
- xfrm: don't check the default policy if the policy allows the
  packet (bsc#1012628).
- xfrm: release all offloaded policy memory (bsc#1012628).
- xfrm: Fix leak of dev tracker (bsc#1012628).
- Revert "Fix XFRM-I support for nested ESP tunnels"
  (bsc#1012628).
- drm/msm/dp: unregister audio driver during unbind (bsc#1012628).
- drm/msm/dpu: Assign missing writeback log_mask (bsc#1012628).
- drm/msm/dpu: Move non-MDP_TOP INTF_INTR offsets out of hwio
  header (bsc#1012628).
- drm/msm/dpu: Reindent REV_7xxx interrupt masks with tabs
  (bsc#1012628).
- drm/msm/dpu: populate SmartDMA features in hw catalog
  (bsc#1012628).
- drm/msm/dpu: drop smart_dma_rev from dpu_caps (bsc#1012628).
- drm/msm/dpu: Allow variable SSPP_BLK size (bsc#1012628).
- drm/msm/dpu: Allow variable INTF_BLK size (bsc#1012628).
- drm/msm/dpu: move UBWC/memory configuration to separate struct
  (bsc#1012628).
- drm/msm/dpu: split SM8550 catalog entry to the separate file
  (bsc#1012628).
- drm/msm/dpu: Fix PP_BLK_DIPHER -> DITHER typo (bsc#1012628).
- drm/msm/dpu: Remove duplicate register defines from INTF
  (bsc#1012628).
- dt-bindings: display/msm: dsi-controller-main: Document qcom,
  master-dsi and qcom, sync-dual-dsi (bsc#1012628).
- ASoC: fsl_micfil: Fix error handler with pm_runtime_enable
  (bsc#1012628).
- cpupower: Make TSC read per CPU for Mperf monitor (bsc#1012628).
- xfrm: Reject optional tunnel/BEET mode templates in outbound
  policies (bsc#1012628).
- af_key: Reject optional tunnel/BEET mode templates in outbound
  policies (bsc#1012628).
- drm/msm: Fix submit error-path leaks (bsc#1012628).
- selftests: seg6: disable DAD on IPv6 router cfg for
  srv6_end_dt4_l3vpn_test (bsc#1012628).
- selftets: seg6: disable rp_filter by default in
  srv6_end_dt4_l3vpn_test (bsc#1012628).
- devlink: change per-devlink netdev notifier to static one
  (bsc#1012628).
- net: fec: Better handle pm_runtime_get() failing in .remove()
  (bsc#1012628).
- net: phy: dp83867: add w/a for packet errors seen with short
  cables (bsc#1012628).
- ALSA: firewire-digi00x: prevent potential use after free
  (bsc#1012628).
- wifi: mt76: connac: fix stats->tx_bytes calculation
  (bsc#1012628).
- ALSA: hda/realtek: Apply HP B&O top speaker profile to Pavilion
  15 (bsc#1012628).
- ice: Fix undersized tx_flags variable (bsc#1012628).
- sfc: disable RXFCS and RXALL features by default (bsc#1012628).
- vsock: avoid to close connected socket after the timeout
  (bsc#1012628).
- tcp: fix possible sk_priority leak in tcp_v4_send_reset()
  (bsc#1012628).
- media: pvrusb2: fix DVB_CORE dependency (bsc#1012628).
- serial: arc_uart: fix of_iomap leak in `arc_serial_probe`
  (bsc#1012628).
- serial: 8250_bcm7271: balance clk_enable calls (bsc#1012628).
- serial: 8250_bcm7271: fix leak in `brcmuart_probe`
  (bsc#1012628).
- erspan: get the proto with the md version for collect_md
  (bsc#1012628).
- net: dsa: rzn1-a5psw: enable management frames for CPU port
  (bsc#1012628).
- net: dsa: rzn1-a5psw: fix STP states handling (bsc#1012628).
- net: dsa: rzn1-a5psw: disable learning for standalone ports
  (bsc#1012628).
- net: hns3: fix output information incomplete for dumping tx
  queue info with debugfs (bsc#1012628).
- net: hns3: fix sending pfc frames after reset issue
  (bsc#1012628).
- net: hns3: fix reset delay time to avoid configuration timeout
  (bsc#1012628).
- net: hns3: fix reset timeout when enable full VF (bsc#1012628).
- media: netup_unidvb: fix use-after-free at del_timer()
  (bsc#1012628).
- SUNRPC: double free xprt_ctxt while still in use (bsc#1012628).
- SUNRPC: always free ctxt when freeing deferred request
  (bsc#1012628).
- SUNRPC: Fix trace_svc_register() call site (bsc#1012628).
- ASoC: SOF: ipc3-topology: Make sure that only one cmd is sent
  in dai_config (bsc#1012628).
- ASoC: mediatek: mt8186: Fix use-after-free in driver remove path
  (bsc#1012628).
- ASoC: SOF: topology: Fix logic for copying tuples (bsc#1012628).
- drm/exynos: fix g2d_open/close helper function definitions
  (bsc#1012628).
- net: nsh: Use correct mac_offset to unwind gso skb in
  nsh_gso_segment() (bsc#1012628).
- net: fec: remove the xdp_return_frame when lack of tx BDs
  (bsc#1012628).
- virtio_net: Fix error unwinding of XDP initialization
  (bsc#1012628).
- tipc: add tipc_bearer_min_mtu to calculate min mtu
  (bsc#1012628).
- tipc: do not update mtu if msg_max is too small in mtu
  negotiation (bsc#1012628).
- tipc: check the bearer min mtu properly when setting it by
  netlink (bsc#1012628).
- s390/cio: include subchannels without devices also for
  evaluation (bsc#1012628).
- can: dev: fix missing CAN XL support in can_put_echo_skb()
  (bsc#1012628).
- net: bcmgenet: Remove phy_stop() from bcmgenet_netif_stop()
  (bsc#1012628).
- net: bcmgenet: Restore phy_stop() depending upon suspend/close
  (bsc#1012628).
- ice: Fix stats after PF reset (bsc#1012628).
- ice: Fix ice VF reset during iavf initialization (bsc#1012628).
- iavf: send VLAN offloading caps once after VFR (bsc#1012628).
- wifi: cfg80211: Drop entries with invalid BSSIDs in RNR
  (bsc#1012628).
- wifi: mac80211: fortify the spinlock against deadlock by
  interrupt (bsc#1012628).
- wifi: mac80211: Fix puncturing bitmap handling in
  __ieee80211_csa_finalize() (bsc#1012628).
- wifi: mac80211: fix min center freq offset tracing
  (bsc#1012628).
- wifi: mac80211: Abort running color change when stopping the AP
  (bsc#1012628).
- wifi: iwlwifi: mvm: fix cancel_delayed_work_sync() deadlock
  (bsc#1012628).
- wifi: iwlwifi: fw: fix DBGI dump (bsc#1012628).
- wifi: iwlwifi: fix OEM's name in the ppag approved list
  (bsc#1012628).
- wifi: iwlwifi: mvm: fix OEM's name in the tas approved list
  (bsc#1012628).
- wifi: iwlwifi: mvm: don't trust firmware n_channels
  (bsc#1012628).
- scsi: storvsc: Don't pass unused PFNs to Hyper-V host
  (bsc#1012628).
- devlink: Fix crash with CONFIG_NET_NS=n (bsc#1012628).
- tun: Fix memory leak for detached NAPI queue (bsc#1012628).
- cassini: Fix a memory leak in the error handling path of
  cas_init_one() (bsc#1012628).
- net: dsa: mv88e6xxx: Fix mv88e6393x EPC write command offset
  (bsc#1012628).
- igb: fix bit_shift to be in [1..8] range (bsc#1012628).
- vlan: fix a potential uninit-value in vlan_dev_hard_start_xmit()
  (bsc#1012628).
- net: wwan: iosm: fix NULL pointer dereference when removing
  device (bsc#1012628).
- net: pcs: xpcs: fix C73 AN not getting enabled (bsc#1012628).
- net: selftests: Fix optstring (bsc#1012628).
- netfilter: nf_tables: fix nft_trans type confusion
  (bsc#1012628).
- netfilter: nft_set_rbtree: fix null deref on element insertion
  (bsc#1012628).
- bridge: always declare tunnel functions (bsc#1012628).
- ALSA: usb-audio: Add a sample rate workaround for Line6 Pod Go
  (bsc#1012628).
- USB: usbtmc: Fix direction for 0-length ioctl control messages
  (bsc#1012628).
- usb-storage: fix deadlock when a scsi command timeouts more
  than once (bsc#1012628).
- USB: UHCI: adjust zhaoxin UHCI controllers OverCurrent bit value
  (bsc#1012628).
- usb: dwc3: gadget: Improve dwc3_gadget_suspend() and
  dwc3_gadget_resume() (bsc#1012628).
- usb: dwc3: debugfs: Resume dwc3 before accessing registers
  (bsc#1012628).
- usb: gadget: u_ether: Fix host MAC address case (bsc#1012628).
- usb: typec: altmodes/displayport: fix pin_assignment_show
  (bsc#1012628).
- Revert "usb: gadget: udc: core: Prevent redundant calls to
  pullup" (bsc#1012628).
- Revert "usb: gadget: udc: core: Invoke usb_gadget_connect only
  when started" (bsc#1012628).
- xhci-pci: Only run d3cold avoidance quirk for s2idle
  (bsc#1012628).
- xhci: Fix incorrect tracking of free space on transfer rings
  (bsc#1012628).
- ALSA: hda: Fix Oops by 9.1 surround channel names (bsc#1012628).
- ALSA: hda: Add NVIDIA codec IDs a3 through a7 to patch table
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Clevo L140AU (bsc#1012628).
- ALSA: hda/realtek: Add a quirk for HP EliteDesk 805
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for 2nd ASUS GU603 (bsc#1012628).
- ALSA: hda/realtek: Add quirk for HP EliteBook G10 laptops
  (bsc#1012628).
- ALSA: hda/realtek: Fix mute and micmute LEDs for yet another
  HP laptop (bsc#1012628).
- can: j1939: recvmsg(): allow MSG_CMSG_COMPAT flag (bsc#1012628).
- can: isotp: recvmsg(): allow MSG_CMSG_COMPAT flag (bsc#1012628).
- can: kvaser_pciefd: Set CAN_STATE_STOPPED in
  kvaser_pciefd_stop() (bsc#1012628).
- can: kvaser_pciefd: Call request_irq() before enabling
  interrupts (bsc#1012628).
- can: kvaser_pciefd: Empty SRB buffer in probe (bsc#1012628).
- can: kvaser_pciefd: Clear listen-only bit if not explicitly
  requested (bsc#1012628).
- can: kvaser_pciefd: Do not send EFLUSH command on TFD interrupt
  (bsc#1012628).
- can: kvaser_pciefd: Disable interrupts in probe error path
  (bsc#1012628).
- wifi: brcmfmac: Check for probe() id argument being NULL
  (bsc#1012628).
- wifi: rtw88: use work to update rate to avoid RCU warning
  (bsc#1012628).
- wifi: rtw88: correct qsel_to_ep[] type as int (bsc#1012628).
- SMB3: Close all deferred handles of inode in case of handle
  lease break (bsc#1012628).
- SMB3: drop reference to cfile before sending oplock break
  (bsc#1012628).
- ksmbd: smb2: Allow messages padded to 8byte boundary
  (bsc#1012628).
- ksmbd: allocate one more byte for implied bcc[0] (bsc#1012628).
- ksmbd: fix wrong UserName check in session_user (bsc#1012628).
- ksmbd: fix global-out-of-bounds in smb2_find_context_vals
  (bsc#1012628).
- KVM: arm64: Infer the PA offset from IPA in stage-2 map walker
  (bsc#1012628).
- KVM: Fix vcpu_array[0] races (bsc#1012628).
- statfs: enforce statfs[64] structure initialization
  (bsc#1012628).
- maple_tree: make maple state reusable after mas_empty_area()
  (bsc#1012628).
- mm: fix zswap writeback race condition (bsc#1012628).
- perf script: Skip aggregation for stat events (bsc#1012628).
- serial: Add support for Advantech PCI-1611U card (bsc#1012628).
- serial: 8250_exar: Add support for USR298x PCI Modems
  (bsc#1012628).
- serial: qcom-geni: fix enabling deactivated interrupt
  (bsc#1012628).
- thunderbolt: Clear registers properly when auto clear isn't
  in use (bsc#1012628).
- vc_screen: reload load of struct vc_data pointer in vcs_write()
  to avoid UAF (bsc#1012628).
- ceph: force updating the msg pointer in non-split case
  (bsc#1012628).
- drm/amd/pm: fix possible power mode mismatch between driver
  and PMFW (bsc#1012628).
- drm/amdgpu/gmc11: implement get_vbios_fb_size() (bsc#1012628).
- drm/amdgpu/gfx10: Disable gfxoff before disabling powergating
  (bsc#1012628).
- drm/amdgpu/gfx11: Adjust gfxoff before powergating on gfx11
  as well (bsc#1012628).
- drm/amdgpu: refine get gpu clock counter method (bsc#1012628).
- drm/amdgpu/gfx11: update gpu_clock_counter logic (bsc#1012628).
- iommu/arm-smmu-qcom: Fix missing adreno_smmu's (bsc#1012628).
- dt-bindings: ata: ahci-ceva: Cover all 4 iommus entries
  (bsc#1012628).
- powerpc/iommu: DMA address offset is incorrectly calculated
  with 2MB TCEs (bsc#1012628).
- powerpc/iommu: Incorrect DDW Table is referenced for SR-IOV
  device (bsc#1012628).
- tpm/tpm_tis: Disable interrupts for more Lenovo devices
  (bsc#1012628).
- powerpc/64s/radix: Fix soft dirty tracking (bsc#1012628).
- powerpc/bpf: populate extable entries only during the last pass
  (bsc#1012628).
- nfp: fix NFP_NET_MAX_DSCP definition error (bsc#1012628).
- nilfs2: fix use-after-free bug of nilfs_root in
  nilfs_evict_inode() (bsc#1012628).
- s390/dasd: fix command reject error on ESE devices
  (bsc#1012628).
- s390/crypto: use vector instructions only if available for
  ChaCha20 (bsc#1012628).
- s390/qdio: fix do_sqbs() inline assembly constraint
  (bsc#1012628).
- arm64: Also reset KASAN tag if page is not PG_mte_tagged
  (bsc#1012628).
- arm64: mte: Do not set PG_mte_tagged if tags were not
  initialized (bsc#1012628).
- rethook: use preempt_{disable, enable}_notrace in
  rethook_trampoline_handler (bsc#1012628).
- rethook, fprobe: do not trace rethook related functions
  (bsc#1012628).
- remoteproc: imx_dsp_rproc: Fix kernel test robot sparse warning
  (bsc#1012628).
- ARM: 9294/2: vfp: Fix broken softirq handling with
  instrumentation enabled (bsc#1012628).
- ARM: 9297/1: vfp: avoid unbalanced stack on 'success' return
  path (bsc#1012628).
- drm/amd/amdgpu: introduce gc_*_mes_2.bin v2 (bsc#1012628).
- drm/amdgpu: reserve the old gc_11_0_*_mes.bin (bsc#1012628).
- scsi: Revert "scsi: core: Do not increase scsi_device's
  iorequest_cnt if dispatch failed" (bsc#1012628).
- commit c5b4604
* Tue May 23 2023 jslaby@suse.cz
- SUNRPC: Fix encoding of accepted but unsuccessful RPC replies
  (bsc#1210995).
  Update upstream status.
- commit 1ef7149
* Mon May 22 2023 msuchanek@suse.de
- kernel-source: Remove unused macro variant_symbols
- commit 915ac72
* Sun May 21 2023 mkubecek@suse.cz
- Update to 6.4-rc3
- eliminate 1 patch
  - patches.suse/SUNRPC-Fix-encoding-of-rejected-RPCs.patch (29cd2927fb91)
- update configs
  - VFIO_CCW=m (s390x only)
- commit 02bdb8c
* Wed May 17 2023 jslaby@suse.cz
- Linux 6.3.3 (bsc#1012628).
- drm/amd/display: Fix hang when skipping modeset (bsc#1012628).
- s390/mm: fix direct map accounting (bsc#1012628).
- s390/mm: rename POPULATE_ONE2ONE to POPULATE_DIRECT
  (bsc#1012628).
- spi: fsl-cpm: Use 16 bit mode for large transfers with even size
  (bsc#1012628).
- spi: fsl-spi: Re-organise transfer bits_per_word adaptation
  (bsc#1012628).
- x86: fix clear_user_rep_good() exception handling annotation
  (bsc#1012628).
- x86/amd_nb: Add PCI ID for family 19h model 78h (bsc#1012628).
- ext4: fix invalid free tracking in ext4_xattr_move_to_block()
  (bsc#1012628).
- ext4: remove a BUG_ON in ext4_mb_release_group_pa()
  (bsc#1012628).
- ext4: fix lockdep warning when enabling MMP (bsc#1012628).
- ext4: bail out of ext4_xattr_ibody_get() fails for any reason
  (bsc#1012628).
- ext4: add bounds checking in get_max_inline_xattr_value_size()
  (bsc#1012628).
- ext4: fix deadlock when converting an inline directory in
  nojournal mode (bsc#1012628).
- ext4: improve error handling from ext4_dirhash() (bsc#1012628).
- ext4: improve error recovery code paths in __ext4_remount()
  (bsc#1012628).
- ext4: check iomap type only if ext4_iomap_begin() does not fail
  (bsc#1012628).
- ext4: avoid deadlock in fs reclaim with page writeback
  (bsc#1012628).
- ext4: fix data races when using cached status extents
  (bsc#1012628).
- ext4: avoid a potential slab-out-of-bounds in
  ext4_group_desc_csum (bsc#1012628).
- ext4: fix WARNING in mb_find_extent (bsc#1012628).
- locking/rwsem: Add __always_inline annotation to
  __down_read_common() and inlined callers (bsc#1012628).
- perf/x86: Fix missing sample size update on AMD BRS
  (bsc#1012628).
- parisc: Fix encoding of swp_entry due to added SWP_EXCLUSIVE
  flag (bsc#1012628).
- drm/amd/display: Lowering min Z8 residency time (bsc#1012628).
- drm/amd/display: Update minimum stutter residency for DCN314 Z8
  (bsc#1012628).
- drm/amd/display: Add minimum Z8 residency debug option
  (bsc#1012628).
- drm/i915: disable sampler indirect state in bindless heap
  (bsc#1012628).
- drm/i915/mtl: Add Wa_14017856879 (bsc#1012628).
- drm/i915/mtl: Add workarounds Wa_14017066071 and Wa_14017654203
  (bsc#1012628).
- drm/i915: Add _PICK_EVEN_2RANGES() (bsc#1012628).
- drm/amd/display: hpd rx irq not working with eDP interface
  (bsc#1012628).
- drm/amd/display: merge dc_link.h into dc.h and dc_types.h
  (bsc#1012628).
- drm/msm/adreno: adreno_gpu: Use suspend() instead of idle()
  on load error (bsc#1012628).
- Revert "net/sched: flower: Fix wrong handle assignment during
  filter change" (bsc#1012628).
- fs/ntfs3: Refactoring of various minor issues (bsc#1012628).
- HID: wacom: insert timestamp to packed Bluetooth (BT) events
  (bsc#1012628).
- HID: wacom: Set a default resolution for older tablets
  (bsc#1012628).
- firewire: net: fix unexpected release of object for asynchronous
  request packet (bsc#1012628).
- drm/amd/pm: avoid potential UBSAN issue on legacy asics
  (bsc#1012628).
- drm/amdgpu: disable sdma ecc irq only when sdma RAS is enabled
  in suspend (bsc#1012628).
- drm/amdgpu: drop gfx_v11_0_cp_ecc_error_irq_funcs (bsc#1012628).
- drm/amd/pm: parse pp_handle under appropriate conditions
  (bsc#1012628).
- drm/amd/display: Enforce 60us prefetch for 200Mhz DCFCLK modes
  (bsc#1012628).
- drm/amdgpu: Fix vram recover doesn't work after whole GPU reset
  (v2) (bsc#1012628).
- drm/amdgpu: change gfx 11.0.4 external_id range (bsc#1012628).
- drm/amdgpu/jpeg: Remove harvest checking for JPEG3
  (bsc#1012628).
- drm/amdgpu/gfx: disable gfx9 cp_ecc_error_irq only when enabling
  legacy gfx ras (bsc#1012628).
- drm/amdgpu: fix amdgpu_irq_put call trace in gmc_v11_0_hw_fini
  (bsc#1012628).
- drm/amdgpu: fix an amdgpu_irq_put() issue in gmc_v9_0_hw_fini()
  (bsc#1012628).
- drm/amdgpu: fix amdgpu_irq_put call trace in gmc_v10_0_hw_fini
  (bsc#1012628).
- drm/amd/display: Change default Z8 watermark values
  (bsc#1012628).
- drm/amdgpu: drop redundant sched job cleanup when cs is aborted
  (bsc#1012628).
- drm/amd/display: fix flickering caused by S/G mode
  (bsc#1012628).
- drm/amd/display: fix access hdcp_workqueue assert (bsc#1012628).
- drm/amd/display: filter out invalid bits in pipe_fuses
  (bsc#1012628).
- drm/amd/display: Fix 4to1 MPC black screen with DPP RCO
  (bsc#1012628).
- drm/amd/display: Add NULL plane_state check for cursor disable
  logic (bsc#1012628).
- drm/panel: otm8009a: Set backlight parent to panel device
  (bsc#1012628).
- irqchip/loongson-eiointc: Fix registration of syscore_ops
  (bsc#1012628).
- irqchip/loongson-eiointc: Fix incorrect use of
  acpi_get_vec_parent (bsc#1012628).
- irqchip/loongson-eiointc: Fix returned value on parsing MADT
  (bsc#1012628).
- irqchip/loongson-pch-pic: Fix registration of syscore_ops
  (bsc#1012628).
- irqchip/loongson-pch-pic: Fix pch_pic_acpi_init calling
  (bsc#1012628).
- f2fs: fix potential corruption when moving a directory
  (bsc#1012628).
- f2fs: fix null pointer panic in tracepoint in
  __replace_atomic_write_block (bsc#1012628).
- f2fs: remove entire rb_entry sharing (bsc#1012628).
- f2fs: factor out discard_cmd usage from general rb_tree use
  (bsc#1012628).
- f2fs: factor out victim_entry usage from general rb_tree use
  (bsc#1012628).
- drm/dsc: fix drm_edp_dsc_sink_output_bpp() DPCD high byte usage
  (bsc#1012628).
- drm/i915/dsi: Use unconditional msleep() instead of
  intel_dsi_msleep() (bsc#1012628).
- drm/i915: Check pipe source size when using skl+ scalers
  (bsc#1012628).
- drm/msm: fix workqueue leak on bind errors (bsc#1012628).
- drm/msm: fix missing wq allocation error handling (bsc#1012628).
- drm/msm: fix vram leak on bind errors (bsc#1012628).
- drm/msm: fix drm device leak on bind errors (bsc#1012628).
- drm/msm: fix NULL-deref on irq uninstall (bsc#1012628).
- drm/msm: fix NULL-deref on snapshot tear down (bsc#1012628).
- drm/i915/color: Fix typo for Plane CSC indexes (bsc#1012628).
- drm/bridge: lt8912b: Fix DSI Video Mode (bsc#1012628).
- drm/msm/adreno: fix runtime PM imbalance at gpu load
  (bsc#1012628).
- ARM: dts: aspeed: romed8hm3: Fix GPIO polarity of system-fault
  LED (bsc#1012628).
- ARM: dts: s5pv210: correct MIPI CSIS clock name (bsc#1012628).
- ARM: dts: exynos: fix WM8960 clock name in Itop Elite
  (bsc#1012628).
- ARM: dts: aspeed: asrock: Correct firmware flash SPI clocks
  (bsc#1012628).
- sysctl: clarify register_sysctl_init() base directory order
  (bsc#1012628).
- remoteproc: rcar_rproc: Call of_node_put() on iteration error
  (bsc#1012628).
- remoteproc: imx_rproc: Call of_node_put() on iteration error
  (bsc#1012628).
- remoteproc: imx_dsp_rproc: Call of_node_put() on iteration error
  (bsc#1012628).
- remoteproc: st: Call of_node_put() on iteration error
  (bsc#1012628).
- remoteproc: stm32: Call of_node_put() on iteration error
  (bsc#1012628).
- proc_sysctl: enhance documentation (bsc#1012628).
- proc_sysctl: update docs for __register_sysctl_table()
  (bsc#1012628).
- sh: nmi_debug: fix return value of __setup handler
  (bsc#1012628).
- sh: init: use OF_EARLY_FLATTREE for early init (bsc#1012628).
- sh: mcount.S: fix build error when PRINTK is not enabled
  (bsc#1012628).
- sh: math-emu: fix macro redefined warning (bsc#1012628).
- SMB3: force unmount was failing to close deferred close files
  (bsc#1012628).
- smb3: fix problem remounting a share after shutdown
  (bsc#1012628).
- inotify: Avoid reporting event with invalid wd (bsc#1012628).
- platform/x86: thinkpad_acpi: Add profile force ability
  (bsc#1012628).
- platform/x86: touchscreen_dmi: Add info for the Dexp Ursus
  KX210i (bsc#1012628).
- platform/x86: hp-wmi: add micmute to hp_wmi_keymap struct
  (bsc#1012628).
- platform/x86: thinkpad_acpi: Fix platform profiles on T490
  (bsc#1012628).
- platform/x86: touchscreen_dmi: Add upside-down quirk for
  GDIX1002 ts on the Juno Tablet (bsc#1012628).
- platform/x86/intel-uncore-freq: Return error on write frequency
  (bsc#1012628).
- cifs: release leases for deferred close handles when freezing
  (bsc#1012628).
- cifs: fix pcchunk length type in smb2_copychunk_range
  (bsc#1012628).
- btrfs: fix backref walking not returning all inode refs
  (bsc#1012628).
- btrfs: zoned: fix full zone super block reading on ZNS
  (bsc#1012628).
- btrfs: zoned: zone finish data relocation BG with last IO
  (bsc#1012628).
- btrfs: fix space cache inconsistency after error loading it
  from disk (bsc#1012628).
- btrfs: print-tree: parent bytenr must be aligned to sector size
  (bsc#1012628).
- btrfs: make clear_cache mount option to rebuild FST without
  disabling it (bsc#1012628).
- btrfs: zero the buffer before marking it dirty in
  btrfs_redirty_list_add (bsc#1012628).
- btrfs: don't free qgroup space unless specified (bsc#1012628).
- btrfs: fix encoded write i_size corruption with no-holes
  (bsc#1012628).
- btrfs: fix assertion of exclop condition when starting balance
  (bsc#1012628).
- btrfs: properly reject clear_cache and v1 cache for
  block-group-tree (bsc#1012628).
- btrfs: zoned: fix wrong use of bitops API in
  btrfs_ensure_empty_zones (bsc#1012628).
- btrfs: fix btrfs_prev_leaf() to not return the same key twice
  (bsc#1012628).
- x86/retbleed: Fix return thunk alignment (bsc#1012628).
- KVM: x86/mmu: Refresh CR0.WP prior to checking for emulated
  permission faults (bsc#1012628).
- KVM: VMX: Make CR0.WP a guest owned bit (bsc#1012628).
- KVM: x86: Make use of kvm_read_cr*_bits() when testing bits
  (bsc#1012628).
- KVM: x86: Do not unload MMU roots when only toggling CR0.WP
  with TDP enabled (bsc#1012628).
- KVM: x86/mmu: Avoid indirect call for get_cr3 (bsc#1012628).
- perf stat: Separate bperf from bpf_profiler (bsc#1012628).
- perf tracepoint: Fix memory leak in is_valid_tracepoint()
  (bsc#1012628).
- perf symbols: Fix return incorrect build_id size in
  elf_read_build_id() (bsc#1012628).
- crypto: engine - fix crypto_queue backlog handling
  (bsc#1012628).
- crypto: sun8i-ss - Fix a test in sun8i_ss_setup_ivs()
  (bsc#1012628).
- perf cs-etm: Fix timeless decode mode detection (bsc#1012628).
- perf map: Delete two variable initialisations before null
  pointer checks in sort__sym_from_cmp() (bsc#1012628).
- perf pmu: zfree() expects a pointer to a pointer to zero it
  after freeing its contents (bsc#1012628).
- perf symbols: Fix unaligned access in get_x86_64_plt_disp()
  (bsc#1012628).
- perf symbols: Fix use-after-free in get_plt_got_name()
  (bsc#1012628).
- perf vendor events power9: Remove UTF-8 characters from JSON
  files (bsc#1012628).
- perf ftrace: Make system wide the default target for latency
  subcommand (bsc#1012628).
- perf tests record_offcpu.sh: Fix redirection of stderr to stdin
  (bsc#1012628).
- perf vendor events s390: Remove UTF-8 characters from JSON file
  (bsc#1012628).
- perf hist: Improve srcfile sort key performance (really)
  (bsc#1012628).
- perf test: Fix wrong size expectation for 'Setup struct
  perf_event_attr' (bsc#1012628).
- perf script: Fix Python support when no libtraceevent
  (bsc#1012628).
- perf scripts intel-pt-events.py: Fix IPC output for Python 2
  (bsc#1012628).
- perf test: Fix "PMU event table sanity" for NO_JEVENTS=1
  (bsc#1012628).
- perf build: Support python/perf.so testing (bsc#1012628).
- perf lock contention: Fix compiler builtin detection
  (bsc#1012628).
- perf record: Fix "read LOST count failed" msg with sample read
  (bsc#1012628).
- net/sched: flower: fix error handler on replace (bsc#1012628).
- net/sched: flower: fix filter idr initialization (bsc#1012628).
- net: fec: correct the counting of XDP sent frames (bsc#1012628).
- net: enetc: check the index of the SFI rather than the handle
  (bsc#1012628).
- virtio_net: suppress cpu stall when free_unused_bufs
  (bsc#1012628).
- ice: block LAN in case of VF to VF offload (bsc#1012628).
- net: dsa: mt7530: fix network connectivity with multiple CPU
  ports (bsc#1012628).
- net: dsa: mt7530: split-off common parts from mt7531_setup
  (bsc#1012628).
- net: dsa: mt7530: fix corrupt frames using trgmii on 40 MHz
  XTAL MT7621 (bsc#1012628).
- dt-bindings: perf: riscv,pmu: fix property dependencies
  (bsc#1012628).
- KVM: s390: fix race in gmap_make_secure() (bsc#1012628).
- KVM: s390: pv: fix asynchronous teardown for small VMs
  (bsc#1012628).
- ALSA: caiaq: input: Add error handling for unsupported input
  methods in `snd_usb_caiaq_input_init` (bsc#1012628).
- drm/amdgpu: add a missing lock for AMDGPU_SCHED (bsc#1012628).
- ublk: add timeout handler (bsc#1012628).
- i2c: gxp: fix build failure without CONFIG_I2C_SLAVE
  (bsc#1012628).
- netfilter: nf_tables: fix ct untracked match breakage
  (bsc#1012628).
- af_packet: Don't send zero-byte data in packet_sendmsg_spkt()
  (bsc#1012628).
- ionic: catch failure from devlink_alloc (bsc#1012628).
- ethtool: Fix uninitialized number of lanes (bsc#1012628).
- r8152: fix the autosuspend doesn't work (bsc#1012628).
- ionic: remove noise from ethtool rxnfc error msg (bsc#1012628).
- octeontx2-vf: Detach LF resources on probe cleanup
  (bsc#1012628).
- octeontx2-pf: Disable packet I/O for graceful exit
  (bsc#1012628).
- octeontx2-af: Skip PFs if not enabled (bsc#1012628).
- octeontx2-af: Fix issues with NPC field hash extract
  (bsc#1012628).
- octeontx2-af: Update/Fix NPC field hash extract feature
  (bsc#1012628).
- octeontx2-af: Update correct mask to filter IPv4 fragments
  (bsc#1012628).
- octeontx2-af: Add validation for lmac type (bsc#1012628).
- octeontx2-pf: Increase the size of dmac filter flows
  (bsc#1012628).
- octeontx2-af: Fix depth of cam and mem table (bsc#1012628).
- octeontx2-af: Fix start and end bit for scan config
  (bsc#1012628).
- octeontx2-af: Secure APR table update with the lock
  (bsc#1012628).
- selftests: netfilter: fix libmnl pkg-config usage (bsc#1012628).
- netfilter: nf_tables: hit ENOENT on unexisting chain/flowtable
  update with missing attributes (bsc#1012628).
- netfilter: nf_tables: support for adding new devices to an
  existing netdev chain (bsc#1012628).
- netfilter: nf_tables: rename function to destroy hook list
  (bsc#1012628).
- netfilter: nf_tables: extended netlink error reporting for
  netdevice (bsc#1012628).
- drm/i915/mtl: Add the missing CPU transcoder mask in
  intel_device_info (bsc#1012628).
- drm/i915/guc: Actually return an error if GuC version range
  check fails (bsc#1012628).
- drm/i915/guc: More debug print updates - UC firmware
  (bsc#1012628).
- net: ethernet: mtk_eth_soc: drop generic vlan rx offload,
  only use DSA untagging (bsc#1012628).
- arm64: kernel: remove SHF_WRITE|SHF_EXECINSTR from .idmap.text
  (bsc#1012628).
- riscv: compat_syscall_table: Fixup compile warning
  (bsc#1012628).
- rxrpc: Fix timeout of a call that hasn't yet been granted a
  channel (bsc#1012628).
- rxrpc: Make it so that a waiting process can be aborted
  (bsc#1012628).
- rxrpc: Fix hard call timeout units (bsc#1012628).
- sfc: Fix module EEPROM reporting for QSFP modules (bsc#1012628).
- r8152: move setting r8153b_rx_agg_chg_indicate() (bsc#1012628).
- r8152: fix the poor throughput for 2.5G devices (bsc#1012628).
- r8152: fix flow control issue of RTL8156A (bsc#1012628).
- net/sched: act_mirred: Add carrier check (bsc#1012628).
- i2c: tegra: Fix PEC support for SMBUS block read (bsc#1012628).
- RISC-V: mm: Enable huge page support to kernel_page_present()
  function (bsc#1012628).
- watchdog: dw_wdt: Fix the error handling path of
  dw_wdt_drv_probe() (bsc#1012628).
- block: Skip destroyed blkg when restart in blkg_destroy_all()
  (bsc#1012628).
- writeback: fix call of incorrect macro (bsc#1012628).
- net: dsa: mv88e6xxx: add mv88e6321 rsvd2cpu (bsc#1012628).
- net: ipv6: fix skb hash for some RST packets (bsc#1012628).
- selftests: srv6: make srv6_end_dt46_l3vpn_test more robust
  (bsc#1012628).
- sit: update dev->needed_headroom in ipip6_tunnel_bind_dev()
  (bsc#1012628).
- net/sched: cls_api: remove block_cb from driver_list before
  freeing (bsc#1012628).
- tcp: fix skb_copy_ubufs() vs BIG TCP (bsc#1012628).
- net/ncsi: clear Tx enable mode when handling a Config required
  AEN (bsc#1012628).
- octeontx2-pf: mcs: Do not reset PN while updating secy
  (bsc#1012628).
- octeontx2-pf: mcs: Fix shared counters logic (bsc#1012628).
- octeontx2-pf: mcs: Clear stats before freeing resource
  (bsc#1012628).
- octeontx2-pf: mcs: Match macsec ethertype along with DMAC
  (bsc#1012628).
- octeontx2-pf: mcs: Fix NULL pointer dereferences (bsc#1012628).
- octeontx2-af: mcs: Fix MCS block interrupt (bsc#1012628).
- octeontx2-af: mcs: Config parser to skip 8B header
  (bsc#1012628).
- octeontx2-af: mcs: Write TCAM_DATA and TCAM_MASK registers at
  once (bsc#1012628).
- octeonxt2-af: mcs: Fix per port bypass config (bsc#1012628).
- ixgbe: Fix panic during XDP_TX with > 64 CPUs (bsc#1012628).
- net/sched: flower: Fix wrong handle assignment during filter
  change (bsc#1012628).
- rxrpc: Fix potential data race in rxrpc_wait_to_be_connected()
  (bsc#1012628).
- drm/amd/display: Update bounding box values for DCN321
  (bsc#1012628).
- drm/amd/display: Do not clear GPINT register when releasing
  DMUB from reset (bsc#1012628).
- drm/amd/display: Reset OUTBOX0 r/w pointer on DMUB reset
  (bsc#1012628).
- drm/amd/display: Fixes for dcn32_clk_mgr implementation
  (bsc#1012628).
- drm/amd/display: Return error code on DSC atomic check failure
  (bsc#1012628).
- drm/amd/display: Add missing WA and MCLK validation
  (bsc#1012628).
- arm64: Fix label placement in record_mmu_state() (bsc#1012628).
- scsi: qedi: Fix use after free bug in qedi_remove()
  (bsc#1012628).
- scsi: ufs: core: mcq: Fix &hwq->cq_lock deadlock issue
  (bsc#1012628).
- ASoC: Intel: soc-acpi-byt: Fix "WM510205" match no longer
  working (bsc#1012628).
- RDMA/rxe: Extend dbg log messages to err and info (bsc#1012628).
- RDMA/rxe: Change rxe_dbg to rxe_dbg_dev (bsc#1012628).
- fs/ntfs3: Fix null-ptr-deref on inode->i_op in ntfs_lookup()
  (bsc#1012628).
- mtd: spi-nor: spansion: Enable JFFS2 write buffer for Infineon
  s25hx SEMPER flash (bsc#1012628).
- soc: qcom: llcc: Do not create EDAC platform device on SDM845
  (bsc#1012628).
- qcom: llcc/edac: Support polling mode for ECC handling
  (bsc#1012628).
- mtd: spi-nor: spansion: Enable JFFS2 write buffer for Infineon
  s28hx SEMPER flash (bsc#1012628).
- mtd: spi-nor: Add a RWW flag (bsc#1012628).
- crypto: ccp - Clear PSP interrupt status register before
  calling handler (bsc#1012628).
- usb: dwc3: gadget: Execute gadget stop after halting the
  controller (bsc#1012628).
- USB: dwc3: gadget: drop dead hibernation code (bsc#1012628).
- commit 1237d35
* Mon May 15 2023 jslaby@suse.cz
- Linux 6.3.2 (bsc#1012628).
- netfilter: nf_tables: deactivate anonymous set from preparation
  phase (bsc#1012628).
- arch_topology: Remove early cacheinfo error message if -ENOENT
  (bsc#1012628).
- debugobject: Ensure pool refill (again) (bsc#1012628).
- cifs: avoid potential races when handling multiple dfs tcons
  (bsc#1012628).
- cifs: protect access of TCP_Server_Info::{origin,leaf}_fullpath
  (bsc#1012628).
- cifs: fix potential race when tree connecting ipc (bsc#1012628).
- cifs: fix sharing of DFS connections (bsc#1012628).
- cifs: protect session status check in smb2_reconnect()
  (bsc#1012628).
- cifs: fix potential use-after-free bugs in
  TCP_Server_Info::hostname (bsc#1012628).
- io_uring/rsrc: check for nonconsecutive pages (bsc#1012628).
- perf intel-pt: Fix CYC timestamps after standalone CBR
  (bsc#1012628).
- perf auxtrace: Fix address filter entire kernel size
  (bsc#1012628).
- dm: don't lock fs when the map is NULL in process of resume
  (bsc#1012628).
- dm ioctl: fix nested locking in table_clear() to remove deadlock
  concern (bsc#1012628).
- dm flakey: fix a crash with invalid table line (bsc#1012628).
- dm integrity: call kmem_cache_destroy() in dm_integrity_init()
  error path (bsc#1012628).
- dm clone: call kmem_cache_destroy() in dm_clone_init() error
  path (bsc#1012628).
- dm verity: fix error handling for check_at_most_once on FEC
  (bsc#1012628).
- vhost_vdpa: fix unmap process in no-batch mode (bsc#1012628).
- mm/hugetlb: fix uffd-wp during fork() (bsc#1012628).
- mm/mempolicy: correctly update prev when policy is equal on
  mbind (bsc#1012628).
- ia64: fix an addr to taddr in huge_pte_offset() (bsc#1012628).
- s390/dasd: fix hanging blockdevice after request requeue
  (bsc#1012628).
- btrfs: scrub: reject unsupported scrub flags (bsc#1012628).
- scripts/gdb: fix lx-timerlist for Python3 (bsc#1012628).
- afs: Avoid endless loop if file is larger than expected
  (bsc#1012628).
- afs: Fix getattr to report server i_size on dirs, not local size
  (bsc#1012628).
- afs: Fix updating of i_size with dv jump from server
  (bsc#1012628).
- PM: hibernate: Do not get block device exclusively in
  test_resume mode (bsc#1012628).
- PM: hibernate: Turn snapshot_test into global variable
  (bsc#1012628).
- ACPI: PM: Do not turn of unused power resources on the Toshiba
  Click Mini (bsc#1012628).
- hte: tegra-194: Fix off by one in tegra_hte_map_to_line_id()
  (bsc#1012628).
- hte: tegra: fix 'struct of_device_id' build error (bsc#1012628).
- mfd: arizona-spi: Add missing MODULE_DEVICE_TABLE (bsc#1012628).
- mfd: ocelot-spi: Fix unsupported bulk read (bsc#1012628).
- mfd: tqmx86: Correct board names for TQMxE39x (bsc#1012628).
- mfd: tqmx86: Specify IO port register range more precisely
  (bsc#1012628).
- mfd: tqmx86: Do not access I2C_DETECT register through io_base
  (bsc#1012628).
- thermal/drivers/mediatek: Use devm_of_iomap to avoid resource
  leak in mtk_thermal_probe (bsc#1012628).
- pinctrl-bcm2835.c: fix race condition when setting gpio dir
  (bsc#1012628).
- dmaengine: at_xdmac: do not enable all cyclic channels
  (bsc#1012628).
- dmaengine: at_xdmac: restore the content of grws register
  (bsc#1012628).
- dmaengine: at_xdmac: do not resume channels paused by consumers
  (bsc#1012628).
- dmaengine: at_xdmac: fix imbalanced runtime PM reference counter
  (bsc#1012628).
- dmaengine: at_xdmac: disable/enable clock directly on
  suspend/resume (bsc#1012628).
- dmaengine: dw-edma: Fix to enable to issue dma request on DMA
  processing (bsc#1012628).
- dmaengine: dw-edma: Fix to change for continuous transfer
  (bsc#1012628).
- dma: gpi: remove spurious unlock in gpi_ch_init (bsc#1012628).
- phy: ti: j721e-wiz: Fix unreachable code in wiz_mode_select()
  (bsc#1012628).
- phy: tegra: xusb: Add missing tegra_xusb_port_unregister for
  usb2_port and ulpi_port (bsc#1012628).
- soundwire: intel: don't save hw_params for use in prepare
  (bsc#1012628).
- pwm: mtk-disp: Configure double buffering before reading in
  .get_state() (bsc#1012628).
- pwm: mtk-disp: Disable shadow registers before setting backlight
  values (bsc#1012628).
- leds: tca6507: Fix error handling of using
  fwnode_property_read_string (bsc#1012628).
- dmaengine: mv_xor_v2: Fix an error code (bsc#1012628).
- pinctrl: ralink: reintroduce ralink,rt2880-pinmux compatible
  string (bsc#1012628).
- leds: TI_LMU_COMMON: select REGMAP instead of depending on it
  (bsc#1012628).
- pinctrl: renesas: r8a779g0: Fix ERROROUTC function names
  (bsc#1012628).
- pinctrl: renesas: r8a779g0: Fix Group 6/7 pin functions
  (bsc#1012628).
- pinctrl: renesas: r8a779g0: Fix Group 4/5 pin functions
  (bsc#1012628).
- pinctrl: renesas: r8a779f0: Fix tsn1_avtp_pps pin group
  (bsc#1012628).
- pinctrl: renesas: r8a779a0: Remove incorrect AVB[01] pinmux
  configuration (bsc#1012628).
- ext4: fix use-after-free read in ext4_find_extent for bigalloc +
  inline (bsc#1012628).
- ext4: fix i_disksize exceeding i_size problem in paritally
  written case (bsc#1012628).
- rtc: jz4740: Make sure clock provider gets removed
  (bsc#1012628).
- SMB3: Close deferred file handles in case of handle lease break
  (bsc#1012628).
- SMB3: Add missing locks to protect deferred close file list
  (bsc#1012628).
- timekeeping: Fix references to nonexistent ktime_get_fast_ns()
  (bsc#1012628).
- openrisc: Properly store r31 to pt_regs on unhandled exceptions
  (bsc#1012628).
- clocksource/drivers/davinci: Fix memory leak in
  davinci_timer_register when init fails (bsc#1012628).
- RDMA/mlx5: Use correct device num_ports when modify DC
  (bsc#1012628).
- SUNRPC: remove the maximum number of retries in call_bind_status
  (bsc#1012628).
- RDMA/mlx5: Fix flow counter query via DEVX (bsc#1012628).
- RDMA/mlx5: Check pcie_relaxed_ordering_enabled() in UMR
  (bsc#1012628).
- RDMA/rxe: Fix the error "trying to register non-static key in
  rxe_cleanup_task" (bsc#1012628).
- RDMA/rxe: Remove __rxe_do_task() (bsc#1012628).
- RDMA/rxe: Convert tasklet args to queue pairs (bsc#1012628).
- swiotlb: fix debugfs reporting of reserved memory pools
  (bsc#1012628).
- swiotlb: relocate PageHighMem test away from rmem_swiotlb_setup
  (bsc#1012628).
- Input: raspberrypi-ts - fix refcount leak in rpi_ts_probe
  (bsc#1012628).
- clk: qcom: dispcc-qcm2290: Remove inexistent DSI1PHY clk
  (bsc#1012628).
- clk: qcom: gcc-sm8350: fix PCIe PIPE clocks handling
  (bsc#1012628).
- clk: qcom: lpassaudiocc-sc7280: Add required gdsc power domain
  clks in lpass_cc_sc7280_desc (bsc#1012628).
- clk: qcom: lpasscc-sc7280: Skip qdsp6ss clock registration
  (bsc#1012628).
- s390/checksum: always use cksm instruction (bsc#1012628).
- iommu/amd: Set page size bitmap during V2 domain allocation
  (bsc#1012628).
- NFSv4.1: Always send a RECLAIM_COMPLETE after establishing lease
  (bsc#1012628).
- clk: imx: imx8ulp: Fix XBAR_DIVBUS and AD_SLOW clock parents
  (bsc#1012628).
- clk: imx: fracn-gppll: disable hardware select control
  (bsc#1012628).
- clk: imx: fracn-gppll: fix the rate table (bsc#1012628).
- IB/hfi1: Fix bugs with non-PAGE_SIZE-end multi-iovec user SDMA
  requests (bsc#1012628).
- IB/hfi1: Fix SDMA mmu_rb_node not being evicted in LRU order
  (bsc#1012628).
- RDMA/srpt: Add a check for valid 'mad_agent' pointer
  (bsc#1012628).
- RDMA/cm: Trace icm_send_rej event before the cm state is reset
  (bsc#1012628).
- power: supply: rk817: Fix low SOC bugs (bsc#1012628).
- clk: qcom: gcc-sm6115: Mark RCGs shared where applicable
  (bsc#1012628).
- RDMA/siw: Remove namespace check from siw_netdev_event()
  (bsc#1012628).
- clk: add missing of_node_put() in "assigned-clocks" property
  parsing (bsc#1012628).
- power: supply: generic-adc-battery: fix unit scaling
  (bsc#1012628).
- RDMA/rxe: Remove tasklet call from rxe_cq.c (bsc#1012628).
- iommu/mediatek: Set dma_mask for PGTABLE_PA_35_EN (bsc#1012628).
- fs/ntfs3: Fix slab-out-of-bounds read in hdr_delete_de()
  (bsc#1012628).
- fs/ntfs3: Fix OOB read in indx_insert_into_buffer (bsc#1012628).
- fs/ntfs3: Add check for kmemdup (bsc#1012628).
- fs/ntfs3: Fix memory leak if ntfs_read_mft failed (bsc#1012628).
- RDMA/erdma: Use fixed hardware page size (bsc#1012628).
- RDMA/rxe: Replace exists by rxe in rxe.c (bsc#1012628).
- rtc: k3: handle errors while enabling wake irq (bsc#1012628).
- rtc: meson-vrtc: Use ktime_get_real_ts64() to get the current
  time (bsc#1012628).
- RDMA/mlx4: Prevent shift wrapping in set_user_sq_size()
  (bsc#1012628).
- rtc: omap: include header for omap_rtc_power_off_program
  prototype (bsc#1012628).
- workqueue: Fix hung time report of worker pools (bsc#1012628).
- clk: qcom: gcc-qcm2290: Fix up gcc_sdcc2_apps_clk_src
  (bsc#1012628).
- clk: mediatek: clk-pllfh: fix missing of_node_put() in
  fhctl_parse_dt() (bsc#1012628).
- RDMA/rdmavt: Delete unnecessary NULL check (bsc#1012628).
- clk: mediatek: mt8135: Properly use CLK_IS_CRITICAL flag
  (bsc#1012628).
- clk: mediatek: mt7622: Properly use CLK_IS_CRITICAL flag
  (bsc#1012628).
- clk: mediatek: Consistently use GATE_MTK() macro (bsc#1012628).
- clk: mediatek: mt2712: Add error handling to
  clk_mt2712_apmixed_probe() (bsc#1012628).
- RDMA/siw: Fix potential page_array out of range access
  (bsc#1012628).
- IB/hifi1: add a null check of kzalloc_node in
  hfi1_ipoib_txreq_init (bsc#1012628).
- clk: at91: clk-sam9x60-pll: fix return value check
  (bsc#1012628).
- tracing/user_events: Ensure write index cannot be negative
  (bsc#1012628).
- rtla/timerlat: Fix "Previous IRQ" auto analysis' line
  (bsc#1012628).
- rv: Fix addition on an uninitialized variable 'run'
  (bsc#1012628).
- sched/clock: Fix local_clock() before sched_clock_init()
  (bsc#1012628).
- sched/rt: Fix bad task migration for rt tasks (bsc#1012628).
- riscv: Fix ptdump when KASAN is enabled (bsc#1012628).
- Revert "objtool: Support addition to set CFA base"
  (bsc#1012628).
- perf/core: Fix hardlockup failure caused by perf throttle
  (bsc#1012628).
- sched/fair: Fix inaccurate tally of ttwu_move_affine
  (bsc#1012628).
- powerpc/rtas: use memmove for potentially overlapping buffer
  copy (bsc#1012628).
- macintosh: via-pmu-led: requires ATA to be set (bsc#1012628).
- powerpc/sysdev/tsi108: fix resource printk format warnings
  (bsc#1012628).
- powerpc/wii: fix resource printk format warnings (bsc#1012628).
- powerpc/mpc512x: fix resource printk format warning
  (bsc#1012628).
- powerpc/perf: Properly detect mpc7450 family (bsc#1012628).
- macintosh/windfarm_smu_sat: Add missing of_node_put()
  (bsc#1012628).
- selftests/powerpc/pmu: Fix sample field check in the
  mmcra_thresh_marked_sample_test (bsc#1012628).
- fbdev: mmp: Fix deferred clk handling in mmphw_probe()
  (bsc#1012628).
- virtio_ring: don't update event idx on get_buf (bsc#1012628).
- vdpa/mlx5: Avoid losing link state updates (bsc#1012628).
- spmi: Add a check for remove callback when removing a SPMI
  driver (bsc#1012628).
- staging: rtl8192e: Fix W_DISABLE# does not work after stop/start
  (bsc#1012628).
- spi: cadence-quadspi: use macro DEFINE_SIMPLE_DEV_PM_OPS
  (bsc#1012628).
- serial: 8250: Add missing wakeup event reporting (bsc#1012628).
- tty: serial: fsl_lpuart: adjust buffer length to the intended
  size (bsc#1012628).
- firmware: stratix10-svc: Fix an NULL vs IS_ERR() bug in probe
  (bsc#1012628).
- usb: mtu3: fix kernel panic at qmu transfer done irq handler
  (bsc#1012628).
- usb: chipidea: fix missing goto in `ci_hdrc_probe`
  (bsc#1012628).
- usb: gadget: tegra-xudc: Fix crash in vbus_draw (bsc#1012628).
- sh: sq: Fix incorrect element size for allocating bitmap buffer
  (bsc#1012628).
- uapi/linux/const.h: prefer ISO-friendly __typeof__
  (bsc#1012628).
- scripts/gdb: raise error with reduced debugging information
  (bsc#1012628).
- i2c: xiic: xiic_xfer(): Fix runtime PM leak on error path
  (bsc#1012628).
- i2c: cadence: cdns_i2c_master_xfer(): Fix runtime PM leak on
  error path (bsc#1012628).
- spi: cadence-quadspi: fix suspend-resume implementations
  (bsc#1012628).
- drm/panel: novatek-nt35950: Only unregister DSI1 if it exists
  (bsc#1012628).
- PCI/PM: Extend D3hot delay for NVIDIA HDA controllers
  (bsc#1012628).
- ASoC: fsl_mqs: move of_node_put() to the correct location
  (bsc#1012628).
- drm/panel: novatek-nt35950: Improve error handling
  (bsc#1012628).
- coresight: etm_pmu: Set the module field (bsc#1012628).
- cacheinfo: Check cache properties are present in DT
  (bsc#1012628).
- cacheinfo: Check sib_leaf in cache_leaves_are_shared()
  (bsc#1012628).
- HID: amd_sfh: Handle "no sensors" enabled for SFH1.1
  (bsc#1012628).
- HID: amd_sfh: Increase sensor command timeout for SFH1.1
  (bsc#1012628).
- HID: amd_sfh: Correct the stop all command (bsc#1012628).
- HID: amd_sfh: Add support for shutdown operation (bsc#1012628).
- HID: amd_sfh: Fix illuminance value (bsc#1012628).
- HID: amd_sfh: Correct the sensor enable and disable command
  (bsc#1012628).
- HID: amd_sfh: Correct the structure fields (bsc#1012628).
- ASoC: mediatek: common: Fix refcount leak in parse_dai_link_info
  (bsc#1012628).
- scripts/gdb: bail early if there are no generic PD
  (bsc#1012628).
- scripts/gdb: bail early if there are no clocks (bsc#1012628).
- ia64: salinfo: placate defined-but-not-used warning
  (bsc#1012628).
- ia64: mm/contig: fix section mismatch warning/error
  (bsc#1012628).
- PCI/EDR: Clear Device Status after EDR error recovery
  (bsc#1012628).
- of: Fix modalias string generation (bsc#1012628).
- vmci_host: fix a race condition in vmci_host_poll() causing GPF
  (bsc#1012628).
- spi: fsl-spi: Fix CPM/QE mode Litte Endian (bsc#1012628).
- spi: mchp-pci1xxxx: Fix improper implementation of disabling
  chip select lines (bsc#1012628).
- spi: mpc5xxx-psc: Remove unused platform_data (bsc#1012628).
- spi: mchp-pci1xxxx: Fix SPI transactions not working after
  suspend and resume (bsc#1012628).
- spi: mchp-pci1xxxx: Fix length of SPI transactions not set
  properly in driver (bsc#1012628).
- interconnect: qcom: rpm: drop bogus pm domain attach
  (bsc#1012628).
- spi: qup: Don't skip cleanup in remove's error path
  (bsc#1012628).
- dt-bindings: serial: snps-dw-apb-uart: correct number of DMAs
  (bsc#1012628).
- linux/vt_buffer.h: allow either builtin or modular for macros
  (bsc#1012628).
- ASoC: es8316: Handle optional IRQ assignment (bsc#1012628).
- PCI: imx6: Install the fault handler only on compatible match
  (bsc#1012628).
- ASoC: soc-compress: Inherit atomicity from DAI link for Compress
  FE (bsc#1012628).
- usb: gadget: udc: renesas_usb3: Fix use after free bug in
  renesas_usb3_remove due to race condition (bsc#1012628).
- module/decompress: Never use kunmap() for local un-mappings
  (bsc#1012628).
- spi: f_ospi: Add missing spi_mem_default_supports_op() helper
  (bsc#1012628).
- interconnect: qcom: osm-l3: drop unuserd header inclusion
  (bsc#1012628).
- interconnect: qcom: drop obsolete OSM_L3/EPSS defines
  (bsc#1012628).
- spi: imx: Don't skip cleanup in remove's error path
  (bsc#1012628).
- spi: atmel-quadspi: Free resources even if runtime resume
  failed in .remove() (bsc#1012628).
- spi: atmel-quadspi: Don't leak clk enable count in pm resume
  (bsc#1012628).
- serial: 8250_bcm7271: Fix arbitration handling (bsc#1012628).
- spi: Constify spi parameters of chip select APIs (bsc#1012628).
- iio: light: max44009: add missing OF device matching
  (bsc#1012628).
- iommufd/selftest: Catch overflow of uptr and length
  (bsc#1012628).
- fpga: bridge: fix kernel-doc parameter description
  (bsc#1012628).
- serial: stm32: Re-assert RTS/DE GPIO in RS485 mode only if
  more data are transmitted (bsc#1012628).
- usb: dwc3: gadget: Change condition for processing suspend event
  (bsc#1012628).
- usb: host: xhci-rcar: remove leftover quirk handling
  (bsc#1012628).
- pstore: Revert pmsg_lock back to a normal mutex (bsc#1012628).
- drivers: staging: rtl8723bs: Fix locking in
  rtw_scan_timeout_handler() (bsc#1012628).
- drivers: staging: rtl8723bs: Fix locking in
  _rtw_join_timeout_handler() (bsc#1012628).
- ASoC: cs35l41: Only disable internal boost (bsc#1012628).
- ipmi: ASPEED_BT_IPMI_BMC: select REGMAP_MMIO instead of
  depending on it (bsc#1012628).
- tcp/udp: Fix memleaks of sk and zerocopy skbs with TX timestamp
  (bsc#1012628).
- net: amd: Fix link leak when verifying config failed
  (bsc#1012628).
- netlink: Use copy_to_user() for optval in netlink_getsockopt()
  (bsc#1012628).
- Revert "Bluetooth: btsdio: fix use after free bug in
  btsdio_remove due to unfinished work" (bsc#1012628).
- rxrpc: Fix error when reading rxrpc tokens (bsc#1012628).
- ipv4: Fix potential uninit variable access bug in
  __ip_make_skb() (bsc#1012628).
- net/sched: cls_api: Initialize miss_cookie_node when action
  miss is not used (bsc#1012628).
- net/sched: sch_fq: fix integer overflow of "credit"
  (bsc#1012628).
- net: dpaa: Fix uninitialized variable in dpaa_stop()
  (bsc#1012628).
- netfilter: nf_tables: don't write table validation state
  without mutex (bsc#1012628).
- bpf: Don't EFAULT for getsockopt with optval=NULL (bsc#1012628).
- bpf: Fix race between btf_put and btf_idr walk (bsc#1012628).
- net: stmmac:fix system hang when setting up tag_8021q VLAN
  for DSA ports (bsc#1012628).
- Revert "net/mlx5e: Don't use termination table when redundant"
  (bsc#1012628).
- net/mlx5e: Nullify table pointer when failing to create
  (bsc#1012628).
- net/mlx5: Use recovery timeout on sync reset flow (bsc#1012628).
- Revert "net/mlx5: Remove "recovery" arg from mlx5_load_one()
  function" (bsc#1012628).
- net/mlx5e: Fix error flow in representor failing to add vport
  rx rule (bsc#1012628).
- net/mlx5: Release tunnel device after tc update skb
  (bsc#1012628).
- net/mlx5: E-switch, Don't destroy indirect table in split rule
  (bsc#1012628).
- net/mlx5: E-switch, Create per vport table based on devlink
  encap mode (bsc#1012628).
- net/mlx5e: Release the label when replacing existing ct entry
  (bsc#1012628).
- net/mlx5e: Don't clone flow post action attributes second time
  (bsc#1012628).
- ixgbe: Enable setting RSS table to default values (bsc#1012628).
- ixgbe: Allow flow hash to be set via ethtool (bsc#1012628).
- net: libwx: fix memory leak in wx_setup_rx_resources
  (bsc#1012628).
- wifi: iwlwifi: mvm: fix potential memory leak (bsc#1012628).
- wifi: iwlwifi: mvm: support wowlan info notification version 2
  (bsc#1012628).
- wifi: iwlwifi: fw: fix memory leak in debugfs (bsc#1012628).
- netfilter: conntrack: fix wrong ct->timeout value (bsc#1012628).
- wifi: mt76: mt7996: fill txd by host driver (bsc#1012628).
- netfilter: conntrack: restore IPS_CONFIRMED out of
  nf_conntrack_hash_check_insert() (bsc#1012628).
- wifi: iwlwifi: mvm: check firmware response size (bsc#1012628).
- wifi: mt76: connac: fix txd multicast rate setting
  (bsc#1012628).
- wifi: mt76: mt7921e: stop chip reset worker in unregister hook
  (bsc#1012628).
- wifi: mt76: mt7921e: improve reliability of dma reset
  (bsc#1012628).
- wifi: mt76: mt7921: fix missing unwind goto in `mt7921u_probe`
  (bsc#1012628).
- mt76: mt7921: fix kernel panic by accessing unallocated
  eeprom.data (bsc#1012628).
- wifi: mt76: fix 6GHz high channel not be scanned (bsc#1012628).
- wifi: mt76: mt7921e: fix probe timeout after reboot
  (bsc#1012628).
- wifi: mt76: mt7921: use driver flags rather than mac80211
  flags to mcu (bsc#1012628).
- wifi: mt76: mt7996: fix eeprom tx path bitfields (bsc#1012628).
- wifi: mt76: mt7996: fix pointer calculation in ie countdown
  event (bsc#1012628).
- wifi: mt76: mt7996: let non-bufferable MMPDUs use correct hw
  queue (bsc#1012628).
- wifi: mt76: handle failure of vzalloc in mt7615_coredump_work
  (bsc#1012628).
- wifi: mt76: mt7915: rework init flow in mt7915_thermal_init()
  (bsc#1012628).
- wifi: mt76: mt7915: expose device tree match table
  (bsc#1012628).
- wifi: mt76: mt7996: fix radiotap bitfield (bsc#1012628).
- wifi: mt76: mt7915: unlock on error in
  mt7915_thermal_temp_store() (bsc#1012628).
- wifi: mt76: mt7921: fix PCI DMA hang after reboot (bsc#1012628).
- wifi: mt76: mt7921: fix wrong command to set STA channel
  (bsc#1012628).
- wifi: mt76: remove redundent MCU_UNI_CMD_* definitions
  (bsc#1012628).
- wifi: iwlwifi: make the loop for card preparation effective
  (bsc#1012628).
- io_uring/rsrc: use nospec'ed indexes (bsc#1012628).
- jdb2: Don't refuse invalidation of already invalidated buffers
  (bsc#1012628).
- wifi: iwlwifi: fw: move memset before early return
  (bsc#1012628).
- wifi: iwlwifi: mvm: initialize seq variable (bsc#1012628).
- wifi: iwlwifi: yoyo: Fix possible division by zero
  (bsc#1012628).
- wifi: iwlwifi: yoyo: skip dump correctly on hw error
  (bsc#1012628).
- wifi: iwlwifi: mvm: don't drop unencrypted MCAST frames
  (bsc#1012628).
- md/raid10: don't call bio_start_io_acct twice for bio which
  experienced read error (bsc#1012628).
- md/raid10: fix memleak of md thread (bsc#1012628).
- md/raid10: fix memleak for 'conf->bio_split' (bsc#1012628).
- md/raid10: fix leak of 'r10bio->remaining' for recovery
  (bsc#1012628).
- md/raid10: fix task hung in raid10d (bsc#1012628).
- f2fs: fix to check return value of inc_valid_block_count()
  (bsc#1012628).
- f2fs: fix to check return value of f2fs_do_truncate_blocks()
  (bsc#1012628).
- bpf, sockmap: Revert buggy deadlock fix in the sockhash and
  sockmap (bsc#1012628).
- wifi: iwlwifi: mvm: don't set CHECKSUM_COMPLETE for unsupported
  protocols (bsc#1012628).
- wifi: iwlwifi: trans: don't trigger d3 interrupt twice
  (bsc#1012628).
- wifi: iwlwifi: mvm: fix A-MSDU checks (bsc#1012628).
- wifi: iwlwifi: debug: fix crash in __iwl_err() (bsc#1012628).
- blk-mq: don't plug for head insertions in blk_execute_rq_nowait
  (bsc#1012628).
- selftests/bpf: Fix leaked bpf_link in get_stackid_cannot_attach
  (bsc#1012628).
- selftests/bpf: Use read_perf_max_sample_freq() in
  perf_event_stackmap (bsc#1012628).
- nvme-fcloop: fix "inconsistent {IN-HARDIRQ-W} -> {HARDIRQ-ON-W}
  usage" (bsc#1012628).
- nvme: fix async event trace event (bsc#1012628).
- nvmet: fix I/O Command Set specific Identify Controller
  (bsc#1012628).
- nvmet: fix Identify Active Namespace ID list handling
  (bsc#1012628).
- nvmet: fix Identify Controller handling (bsc#1012628).
- nvmet: fix Identify Namespace handling (bsc#1012628).
- nvmet: fix error handling in nvmet_execute_identify_cns_cs_ns()
  (bsc#1012628).
- bpf, sockmap: fix deadlocks in the sockhash and sockmap
  (bsc#1012628).
- wifi: ath11k: fix writing to unintended memory region
  (bsc#1012628).
- net: ethernet: stmmac: dwmac-rk: fix optional phy regulator
  handling (bsc#1012628).
- net: ethernet: stmmac: dwmac-rk: rework optional clock handling
  (bsc#1012628).
- scsi: lpfc: Fix ioremap issues in lpfc_sli4_pci_mem_setup()
  (bsc#1012628).
- bpf/btf: Fix is_int_ptr() (bsc#1012628).
- wifi: iwlwifi: fix duplicate entry in iwl_dev_info_table
  (bsc#1012628).
- f2fs: fix to avoid use-after-free for cached IPU bio
  (bsc#1012628).
- xsk: Fix unaligned descriptor validation (bsc#1012628).
- crypto: drbg - Only fail when jent is unavailable in FIPS mode
  (bsc#1012628).
- bpftool: Fix bug for long instructions in program CFG dumps
  (bsc#1012628).
- selftests/bpf: Wait for receive in cg_storage_multi test
  (bsc#1012628).
- selftests: xsk: Deflakify STATS_RX_DROPPED test (bsc#1012628).
- selftests: xsk: Disable IPv6 on VETH1 (bsc#1012628).
- selftests: xsk: Use correct UMEM size in testapp_invalid_desc
  (bsc#1012628).
- net: qrtr: correct types of trace event parameters
  (bsc#1012628).
- f2fs: fix iostat lock protection (bsc#1012628).
- bpf: Fix struct_meta lookup for bpf_obj_free_fields kfunc call
  (bsc#1012628).
- bpf: factor out fetching basic kfunc metadata (bsc#1012628).
- wifi: rt2x00: Fix memory leak when handling surveys
  (bsc#1012628).
- scsi: hisi_sas: Handle NCQ error when IPTT is valid
  (bsc#1012628).
- wifi: rtlwifi: fix incorrect error codes in
  rtl_debugfs_set_write_reg() (bsc#1012628).
- wifi: rtlwifi: fix incorrect error codes in
  rtl_debugfs_set_write_rfreg() (bsc#1012628).
- crypto: sa2ul - Select CRYPTO_DES (bsc#1012628).
- crypto: caam - Clear some memory in instantiate_rng
  (bsc#1012628).
- f2fs: fix scheduling while atomic in decompression path
  (bsc#1012628).
- f2fs: compress: fix to call f2fs_wait_on_page_writeback()
  in f2fs_write_raw_pages() (bsc#1012628).
- f2fs: apply zone capacity to all zone type (bsc#1012628).
- f2fs: fix uninitialized skipped_gc_rwsem (bsc#1012628).
- f2fs: handle dqget error in f2fs_transfer_project_quota()
  (bsc#1012628).
- testing/vsock: add vsock_perf to gitignore (bsc#1012628).
- net: sunhme: Fix uninitialized return code (bsc#1012628).
- scsi: megaraid: Fix mega_cmd_done() CMDID_INT_CMDS
  (bsc#1012628).
- scsi: target: iscsit: Fix TAS handling during conn cleanup
  (bsc#1012628).
- scsi: target: Fix multiple LUN_RESET handling (bsc#1012628).
- scsi: target: iscsit: Stop/wait on cmds during conn close
  (bsc#1012628).
- scsi: target: iscsit: isert: Alloc per conn cmd counter
  (bsc#1012628).
- scsi: target: Pass in cmd counter to use during cmd setup
  (bsc#1012628).
- scsi: target: Move cmd counter allocation (bsc#1012628).
- scsi: target: Move sess cmd counter to new struct (bsc#1012628).
- bpf: Fix __reg_bound_offset 64->32 var_off subreg propagation
  (bsc#1012628).
- bpf: return long from bpf_map_ops funcs (bsc#1012628).
- netfilter: keep conntrack reference until IPsecv6 policy checks
  are done (bsc#1012628).
- net: dsa: qca8k: remove assignment of an_enabled in
  pcs_get_state() (bsc#1012628).
- libbpf: Fix ld_imm64 copy logic for ksym in light skeleton
  (bsc#1012628).
- net/packet: convert po->auxdata to an atomic flag (bsc#1012628).
- net/packet: convert po->origdev to an atomic flag (bsc#1012628).
- net/packet: annotate accesses to po->xmit (bsc#1012628).
- vlan: partially enable SIOCSHWTSTAMP in container (bsc#1012628).
- net: pcs: xpcs: remove double-read of link state when using AN
  (bsc#1012628).
- bpf: Remove misleading spec_v1 check on var-offset stack read
  (bsc#1012628).
- bpf: Free struct bpf_cpumask in call_rcu handler (bsc#1012628).
- bpf: Only allocate one bpf_mem_cache for bpf_cpumask_ma
  (bsc#1012628).
- selftests/bpf: Fix a fd leak in an error path in
  network_helpers.c (bsc#1012628).
- wifi: ath11k: fix deinitialization of firmware resources
  (bsc#1012628).
- wifi: ath12k: Add missing unwind goto in ath12k_pci_probe()
  (bsc#1012628).
- scm: fix MSG_CTRUNC setting condition for SO_PASSSEC
  (bsc#1012628).
- crypto: qat - fix concurrency issue when device state changes
  (bsc#1012628).
- bpf: fix precision propagation verbose logging (bsc#1012628).
- bpf: take into account liveness when propagating precision
  (bsc#1012628).
- selftests/bpf: Fix flaky fib_lookup test (bsc#1012628).
- selftests/bpf: move SYS() macro into the test_progs.h
  (bsc#1012628).
- selftests/bpf: Fix IMA test (bsc#1012628).
- wifi: rtw88: mac: Return the original error from
  rtw_mac_power_switch() (bsc#1012628).
- wifi: rtw88: mac: Return the original error from
  rtw_pwr_seq_parser() (bsc#1012628).
- libbpf: Fix bpf_xdp_query() in old kernels (bsc#1012628).
- libbpf: Fix arm syscall regs spec in bpf_tracing.h
  (bsc#1012628).
- tools: bpftool: Remove invalid \' json escape (bsc#1012628).
- wifi: ath6kl: reduce WARN to dev_dbg() in callback
  (bsc#1012628).
- wifi: brcmfmac: support CQM RSSI notification with older
  firmware (bsc#1012628).
- wifi: rtl8xxxu: Remove always true condition in
  rtl8xxxu_print_chipinfo (bsc#1012628).
- wifi: ath11k: fix SAC bug on peer addition with sta band
  migration (bsc#1012628).
- wifi: ath5k: fix an off by one check in
  ath5k_eeprom_read_freq_list() (bsc#1012628).
- wifi: ath5k: Use platform_get_irq() to get the interrupt
  (bsc#1012628).
- wifi: ath11k: Use platform_get_irq() to get the interrupt
  (bsc#1012628).
- wifi: ath9k: hif_usb: fix memory leak of remain_skbs
  (bsc#1012628).
- wifi: ath11k: fix return value check in ath11k_ahb_probe()
  (bsc#1012628).
- wifi: ath12k: use kfree_skb() instead of kfree() (bsc#1012628).
- wifi: ath6kl: minor fix for allocation size (bsc#1012628).
- media: ov5670: Fix probe on ACPI (bsc#1012628).
- platform/chrome: cros_typec_switch: Add missing
  fwnode_handle_put() (bsc#1012628).
- hwmon: (pmbus/fsp-3y) Fix functionality bitmask in FSP-3Y
  YM-2151E (bsc#1012628).
- rpmsg: glink: Propagate TX failures in intentless mode as well
  (bsc#1012628).
- cpufreq: use correct unit when verify cur freq (bsc#1012628).
- ACPI: bus: Ensure that notify handlers are not running after
  removal (bsc#1012628).
- tick/common: Align tick period with the HZ tick (bsc#1012628).
- drm/i915: Fix memory leaks in i915 selftests (bsc#1012628).
- drm/i915: Make intel_get_crtc_new_encoder() less oopsy
  (bsc#1012628).
- debugobject: Prevent init race with static objects
  (bsc#1012628).
- media: mediatek: vcodec: add remove function for decoder
  platform driver (bsc#1012628).
- media: mediatek: vcodec: fix decoder disable pm crash
  (bsc#1012628).
- perf/arm-cmn: Fix port detection for CMN-700 (bsc#1012628).
- arm64: kgdb: Set PSTATE.SS to 1 to re-enable single-step
  (bsc#1012628).
- x86/ioapic: Don't return 0 from arch_dynirq_lower_bound()
  (bsc#1012628).
- regulator: stm32-pwr: fix of_iomap leak (bsc#1012628).
- media: venus: dec: Fix capture formats enumeration order
  (bsc#1012628).
- media: venus: dec: Fix handling of the start cmd (bsc#1012628).
- media: rc: gpio-ir-recv: Fix support for wake-up (bsc#1012628).
- drm/amd/display: Fix potential null dereference (bsc#1012628).
- media: hi846: Fix memleak in hi846_init_controls()
  (bsc#1012628).
- media: v4l: async: Return async sub-devices to subnotifier list
  (bsc#1012628).
- media: rcar_fdp1: Fix refcount leak in probe and remove function
  (bsc#1012628).
- media: rcar_fdp1: Convert to platform remove callback returning
  void (bsc#1012628).
- media: vsp1: Replace vb2_is_streaming() with
  vb2_start_streaming_called() (bsc#1012628).
- media: platform: mtk-mdp3: fix potential frame size overflow
  in mdp_try_fmt_mplane() (bsc#1012628).
- media: saa7134: fix use after free bug in saa7134_finidev due
  to race condition (bsc#1012628).
- media: dm1105: Fix use after free bug in dm1105_remove due to
  race condition (bsc#1012628).
- platform/x86/amd: pmc: Move out of BIOS SMN pair for STB init
  (bsc#1012628).
- platform/x86/amd: pmc: Utilize SMN index 0 for driver probe
  (bsc#1012628).
- platform/x86/amd: pmc: Move idlemask check into
  `amd_pmc_idlemask_read` (bsc#1012628).
- platform/x86/amd: pmc: Don't dump data after resume from s0i3
  on picasso (bsc#1012628).
- platform/x86/amd: pmc: Hide SMU version and program attributes
  for Picasso (bsc#1012628).
- platform/x86/amd: pmc: Don't try to read SMU version on Picasso
  (bsc#1012628).
- platform/x86/amd/pmf: Move out of BIOS SMN pair for driver probe
  (bsc#1012628).
- media: rkvdec: fix use after free bug in rkvdec_remove
  (bsc#1012628).
- media: cedrus: fix use after free bug in cedrus_remove due to
  race condition (bsc#1012628).
- media: mediatek: vcodec: change lat thread decode error
  condition (bsc#1012628).
- media: mediatek: vcodec: making sure queue_work successfully
  (bsc#1012628).
- media: mediatek: vcodec: remove unused lat_buf (bsc#1012628).
- media: mediatek: vcodec: add core decode done event
  (bsc#1012628).
- media: mediatek: vcodec: move lat_buf to the top of core list
  (bsc#1012628).
- media: mediatek: vcodec: using each instance lat_buf count
  replace core ready list (bsc#1012628).
- media: mediatek: vcodec: add params to record lat and core
  lat_buf count (bsc#1012628).
- media: mediatek: vcodec: Force capture queue format to MM21
  (bsc#1012628).
- media: mediatek: vcodec: Make MM21 the default capture format
  (bsc#1012628).
- media: mediatek: vcodec: Use 4K frame size when supported by
  stateful decoder (bsc#1012628).
- media: mtk-jpeg: Fixes jpeg enc&dec worker sw flow
  (bsc#1012628).
- media: mtk-jpeg: Fixes jpeghw multi-core judgement
  (bsc#1012628).
- arm64: dts: sdm845: Rename qspi data12 as data23 (bsc#1012628).
- arm64: dts: sc7280: Rename qspi data12 as data23 (bsc#1012628).
- arm64: dts: sc7180: Rename qspi data12 as data23 (bsc#1012628).
- arm64: dts: qcom: msm8994-angler: removed clash with smem_region
  (bsc#1012628).
- arm64: dts: qcom: msm8994-angler: Fix cont_splash_mem mapping
  (bsc#1012628).
- soc: qcom: rpmh-rsc: Support RSC v3 minor versions
  (bsc#1012628).
- x86/apic: Fix atomic update of offset in reserve_eilvt_offset()
  (bsc#1012628).
- thermal/drivers/mediatek/lvts_thermal: Fix sensor 1 interrupt
  status bitmask (bsc#1012628).
- drm/msm/dpu: Fix bit-shifting UB in DPU_HW_VER() macro
  (bsc#1012628).
- Revert "drm/msm: Fix failure paths in msm_drm_init()"
  (bsc#1012628).
- Revert "drm/msm: Add missing check and destroy for
  alloc_ordered_workqueue" (bsc#1012628).
- regulator: core: Avoid lockdep reports when resolving supplies
  (bsc#1012628).
- regulator: core: Consistently set mutex_owner when using
  ww_mutex_lock_slow() (bsc#1012628).
- drm/ttm/pool: Fix ttm_pool_alloc error path (bsc#1012628).
- arm64: dts: rockchip: Assign PLL_PPLL clock rate to 1.1 GHz
  on rk3588s (bsc#1012628).
- drm/i915/pxp: limit drm-errors or warning on firmware API
  failures (bsc#1012628).
- drm/i915/pxp: Invalidate all PXP fw sessions during teardown
  (bsc#1012628).
- arm64: dts: qcom: sc8280xp: correct Soundwire wakeup interrupt
  name (bsc#1012628).
- arm64: dts: qcom: apq8096-db820c: drop unit address from
  PMI8994 regulator (bsc#1012628).
- arm64: dts: qcom: msm8994-msft-lumia-octagon: drop unit address
  from PMI8994 regulator (bsc#1012628).
- arm64: dts: qcom: msm8994-kitakami: drop unit address from
  PMI8994 regulator (bsc#1012628).
- arm64: dts: qcom: msm8998-oneplus-cheeseburger: revert "fix
  backlight pin function" (bsc#1012628).
- arm64: dts: qcom: sc7180-trogdor-pazquel: correct trackpad
  supply (bsc#1012628).
- arm64: dts: qcom: sc7180-trogdor-lazor: correct trackpad supply
  (bsc#1012628).
- arm64: dts: qcom: sc7280-herobrine-villager: correct trackpad
  supply (bsc#1012628).
- gpu: host1x: Fix memory leak of device names (bsc#1012628).
- gpu: host1x: Fix potential double free if IOMMU is disabled
  (bsc#1012628).
- soc: renesas: renesas-soc: Release 'chipid' from ioremap()
  (bsc#1012628).
- soc: bcm: brcmstb: biuctrl: fix of_iomap leak (bsc#1012628).
- mailbox: mpfs: switch to txdone_poll (bsc#1012628).
- drm/mediatek: dp: Change the aux retries times when receiving
  AUX_DEFER (bsc#1012628).
- drm/lima/lima_drv: Add missing unwind goto in lima_pdev_probe()
  (bsc#1012628).
- ACPI: VIOT: Initialize the correct IOMMU fwspec (bsc#1012628).
- arm64: dts: ti: k3-am625-sk: Add ti,vbus-divider property to
  usbss1 (bsc#1012628).
- arm64: dts: mediatek: mt8192-asurada: Fix voltage constraint
  for Vgpu (bsc#1012628).
- cpufreq: qcom-cpufreq-hw: Revert adding cpufreq qos
  (bsc#1012628).
- cpufreq: mediatek: Raise proc and sram max voltage for
  MT7622/7623 (bsc#1012628).
- cpufreq: mediatek: raise proc/sram max voltage for MT8516
  (bsc#1012628).
- cpufreq: mediatek: fix KP caused by handler usage after
  regulator_put/clk_put (bsc#1012628).
- cpufreq: mediatek: fix passing zero to 'PTR_ERR' (bsc#1012628).
- arm64: dts: apple: t8103: Disable unused PCIe ports
  (bsc#1012628).
- ARM: dts: stm32: fix spi1 pin assignment on stm32mp15
  (bsc#1012628).
- perf/amlogic: Fix config1/config2 parsing issue (bsc#1012628).
- perf/arm-cmn: Move overlapping wp_combine field (bsc#1012628).
- firmware: arm_scmi: Fix xfers allocation on Rx channel
  (bsc#1012628).
- ARM: dts: gta04: fix excess dma channel usage (bsc#1012628).
- drm: rcar-du: Fix a NULL vs IS_ERR() bug (bsc#1012628).
- arm64: dts: qcom: sm8450: fix pcie1 gpios properties name
  (bsc#1012628).
- mmc: sdhci-of-esdhc: fix quirk to ignore command inhibit for
  data (bsc#1012628).
- ACPI: processor: Fix evaluating _PDC method when running as
  Xen dom0 (bsc#1012628).
- drm/amd/display/dc/dce60/Makefile: Fix previous attempt to
  silence known override-init warnings (bsc#1012628).
- arm64: dts: qcom: sm8350-microsoft-surface: fix USB dual-role
  mode property (bsc#1012628).
- arm64: dts: qcom: sm8250-xiaomi-elish: fix USB maximum speed
  property (bsc#1012628).
- virt/coco/sev-guest: Double-buffer messages (bsc#1012628).
- drm: msm: adreno: Disable preemption on Adreno 510
  (bsc#1012628).
- drm/msm/adreno: drop bogus pm_runtime_set_active()
  (bsc#1012628).
- ACPI: utils: Fix acpi_evaluate_dsm_typed() redefinition error
  (bsc#1012628).
- arm64: dts: ti: k3-am62a7: Correct L2 cache size to 512KB
  (bsc#1012628).
- arm64: dts: ti: k3-am625: Correct L2 cache size to 512KB
  (bsc#1012628).
- accel: Link to compute accelerator subsystem intro
  (bsc#1012628).
- media: max9286: Free control handler (bsc#1012628).
- drm/bridge: adv7533: Fix adv7533_mode_valid for adv7533 and
  adv7535 (bsc#1012628).
- firmware: qcom_scm: Clear download bit during reboot
  (bsc#1012628).
- media: av7110: prevent underflow in write_ts_to_decoder()
  (bsc#1012628).
- media: amphion: decoder implement display delay enable
  (bsc#1012628).
- media: platform: mtk-mdp3: Add missing check and free for
  ida_alloc (bsc#1012628).
- media: bdisp: Add missing check for create_workqueue
  (bsc#1012628).
- x86/MCE/AMD: Use an u64 for bank_map (bsc#1012628).
- media: v4l: subdev: Make link validation safer (bsc#1012628).
- arm64: dts: qcom: sc8280xp: fix external display power domain
  (bsc#1012628).
- arm64: dts: qcom: msm8916: Fix tsens_mode unit address
  (bsc#1012628).
- arm64: dts: qcom: sm8550: misc style fixes (bsc#1012628).
- arm64: dts: qcom: sm8550: fix qup_spi0_cs node (bsc#1012628).
- ARM: dts: qcom: sdx55: Fix the unit address of PCIe EP node
  (bsc#1012628).
- arm64: dts: qcom: msm8976: Add and provide xo clk to rpmcc
  (bsc#1012628).
- ARM: dts: qcom: ipq8064: Fix the PCI I/O port range
  (bsc#1012628).
- ARM: dts: qcom: ipq4019: Fix the PCI I/O port range
  (bsc#1012628).
- arm64: dts: qcom: sm8350: Fix the PCI I/O port range
  (bsc#1012628).
- arm64: dts: qcom: sm8450: Fix the PCI I/O port range
  (bsc#1012628).
- arm64: dts: qcom: sm8150: Fix the PCI I/O port range
  (bsc#1012628).
- arm64: dts: qcom: sc8280xp: Fix the PCI I/O port range
  (bsc#1012628).
- arm64: dts: qcom: sm8250: Fix the PCI I/O port range
  (bsc#1012628).
- arm64: dts: qcom: msm8996: Fix the PCI I/O port range
  (bsc#1012628).
- arm64: dts: qcom: ipq6018: Fix the PCI I/O port range
  (bsc#1012628).
- arm64: dts: qcom: ipq8074: Fix the PCI I/O port range
  (bsc#1012628).
- arm64: dts: qcom: sm8550: Fix the PCI I/O port range
  (bsc#1012628).
- arm64: dts: qcom: sc7280: Fix the PCI I/O port range
  (bsc#1012628).
- arm64: dts: qcom: msm8998: Fix the PCI I/O port range
  (bsc#1012628).
- arm64: dts: qcom: sdm845: Fix the PCI I/O port range
  (bsc#1012628).
- arm64: dts: qcom: sdm845: correct dynamic power coefficients
  (bsc#1012628).
- arm64: dts: qcom: sc7280: fix EUD port properties (bsc#1012628).
- arm64: dts: qcom: qdu1000: drop incorrect serial properties
  (bsc#1012628).
- soc: canaan: Make K210_SYSCTL depend on CLK_K210 (bsc#1012628).
- arm64: dts: qcom: msm8998: Fix stm-stimulus-base reg name
  (bsc#1012628).
- arm64: dts: qcom: sm8550: Fix PCIe PHYs and controllers nodes
  (bsc#1012628).
- arm64: dts: broadcom: bcmbca: bcm4908: fix procmon nodename
  (bsc#1012628).
- arm64: dts: broadcom: bcmbca: bcm4908: fix LED nodenames
  (bsc#1012628).
- arm64: dts: broadcom: bcmbca: bcm4908: fix NAND interrupt name
  (bsc#1012628).
- arm64: dts: ti: k3-j784s4-*: Add 'ti,sci-dev-id' for NAVSS nodes
  (bsc#1012628).
- arm64: dts: ti: k3-j721e-main: Remove ti,strobe-sel property
  (bsc#1012628).
- arm64: dts: ti: k3-am62a7-sk: Fix DDR size to full 4GB
  (bsc#1012628).
- arm64: dts: ti: k3-am62-main: Fix GPIO numbers in DT
  (bsc#1012628).
- regulator: core: Shorten off-on-delay-us for always-on/boot-on
  by time since booted (bsc#1012628).
- arm64: dts: imx8mp: Drop simple-bus from
  fsl,imx8mp-media-blk-ctrl (bsc#1012628).
- ARM: dts: qcom-apq8064: Fix opp table child name (bsc#1012628).
- EDAC/skx: Fix overflows on the DRAM row address mapping arrays
  (bsc#1012628).
- drm/msm/disp/dpu: check for crtc enable rather than crtc active
  to release shared resources (bsc#1012628).
- drm/mediatek: dp: Only trigger DRM HPD events if bridge is
  attached (bsc#1012628).
- arm64: dts: renesas: r9a07g043: Update IRQ numbers for SSI
  channels (bsc#1012628).
- arm64: dts: renesas: r9a07g054: Update IRQ numbers for SSI
  channels (bsc#1012628).
- arm64: dts: renesas: r9a07g044: Update IRQ numbers for SSI
  channels (bsc#1012628).
- arm64: dts: renesas: r8a774c0: Remove bogus voltages from OPP
  table (bsc#1012628).
- arm64: dts: renesas: r8a77990: Remove bogus voltages from OPP
  table (bsc#1012628).
- soc: ti: pm33xx: Fix refcount leak in am33xx_pm_probe
  (bsc#1012628).
- soc: ti: k3-ringacc: Add try_module_get() to
  k3_dmaring_request_dual_ring() (bsc#1012628).
- tools/x86/kcpuid: Fix avx512bw and avx512lvl fields in
  Fn00000007 (bsc#1012628).
- drm/amdgpu: register a vga_switcheroo client for MacBooks with
  apple-gmux (bsc#1012628).
- arm64: dts: amlogic: meson-g12b-radxa-zero2: fix pwm clock names
  (bsc#1012628).
- drm/probe-helper: Cancel previous job before starting new one
  (bsc#1012628).
- drm/vgem: add missing mutex_destroy (bsc#1012628).
- drm/i915/dg2: Drop one PCI ID (bsc#1012628).
- drm/rockchip: Drop unbalanced obj unref (bsc#1012628).
- accel/ivpu: PM: remove broken ivpu_dbg() statements
  (bsc#1012628).
- erofs: fix potential overflow calculating xattr_isize
  (bsc#1012628).
- erofs: initialize packed inode after root inode is assigned
  (bsc#1012628).
- erofs: stop parsing non-compact HEAD index if clusterofs is
  invalid (bsc#1012628).
- selftests/clone3: fix number of tests in ksft_set_plan
  (bsc#1012628).
- tpm, tpm_tis: Claim locality when interrupts are reenabled on
  resume (bsc#1012628).
- tpm, tpm: Implement usage counter for locality (bsc#1012628).
- tpm, tpm_tis: Claim locality before writing interrupt registers
  (bsc#1012628).
- tpm, tpm_tis: Disable interrupts if tpm_tis_probe_irq() failed
  (bsc#1012628).
- tpm, tpm_tis: Claim locality before writing TPM_INT_ENABLE
  register (bsc#1012628).
- tpm, tpm_tis: Do not skip reset of original interrupt vector
  (bsc#1012628).
- selinux: ensure av_permissions.h is built when needed
  (bsc#1012628).
- selinux: fix Makefile dependencies of flask.h (bsc#1012628).
- ARM: 9293/1: vfp: Pass successful return address via register R3
  (bsc#1012628).
- ARM: 9292/1: vfp: Pass thread_info pointer to vfp_support_entry
  (bsc#1012628).
- selftests/resctrl: Check for return value after write_schemata()
  (bsc#1012628).
- selftests/resctrl: Allow ->setup() to return errors
  (bsc#1012628).
- selftests/resctrl: Move ->setup() call outside of test specific
  branches (bsc#1012628).
- selftests/resctrl: Return NULL if malloc_and_init_memory()
  did not alloc mem (bsc#1012628).
- rcu: Fix missing TICK_DEP_MASK_RCU_EXP dependency check
  (bsc#1012628).
- kunit: fix bug in the order of lines in debugfs logs
  (bsc#1012628).
- clk: rockchip: rk3399: allow clk_cifout to force clk_cifout_src
  to reparent (bsc#1012628).
- clk: microchip: fix potential UAF in auxdev release callback
  (bsc#1012628).
- wifi: rtw89: fix potential race condition between napi_init
  and napi_enable (bsc#1012628).
- wifi: rtw88: rtw8821c: Fix rfe_option field width (bsc#1012628).
- wifi: rtl8xxxu: RTL8192EU always needs full init (bsc#1012628).
- nfp: fix incorrect pointer deference when offloading IPsec
  with bonding (bsc#1012628).
- mailbox: zynqmp: Fix typo in IPI documentation (bsc#1012628).
- mailbox: zynqmp: Fix counts of child nodes (bsc#1012628).
- kcsan: Avoid READ_ONCE() in read_instrumented_memory()
  (bsc#1012628).
- mailbox: zynqmp: Fix IPI isr handling (bsc#1012628).
- drivers: remoteproc: xilinx: Fix carveout names (bsc#1012628).
- mtd: spi-nor: core: Update flash's current address mode when
  changing address mode (bsc#1012628).
- mtd: core: fix error path for nvmem provider (bsc#1012628).
- mtd: core: fix nvmem error reporting (bsc#1012628).
- mtd: core: provide unique name for nvmem device, take two
  (bsc#1012628).
- kasan: hw_tags: avoid invalid virt_to_page() (bsc#1012628).
- md/raid5: Improve performance for sequential IO (bsc#1012628).
- md/raid10: fix null-ptr-deref in raid10_sync_request
  (bsc#1012628).
- drbd: correctly submit flush bio on barrier (bsc#1012628).
- mm: do not reclaim private data from pinned page (bsc#1012628).
- nilfs2: fix infinite loop in nilfs_mdt_get_block()
  (bsc#1012628).
- nilfs2: do not write dirty data after degenerating to read-only
  (bsc#1012628).
- ASoC: codecs: wcd938x: fix accessing regmap on unattached
  devices (bsc#1012628).
- ALSA: hda/realtek: Fix mute and micmute LEDs for an HP laptop
  (bsc#1012628).
- ALSA: hda/realtek: support HP Pavilion Aero 13-be0xxx Mute LED
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ASUS UM3402YAR using CS35L41
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ThinkPad P1 Gen 6
  (bsc#1012628).
- ALSA: usb-audio: Add quirk for Pioneer DDJ-800 (bsc#1012628).
- parisc: Ensure page alignment in flush functions (bsc#1012628).
- parisc: Fix argument pointer in real64_call_asm() (bsc#1012628).
- ASoC: dt-bindings: qcom,lpass-rx-macro: correct minItems for
  clocks (bsc#1012628).
- bus: mhi: host: Range check CHDBOFF and ERDBOFF (bsc#1012628).
- bus: mhi: host: Use mhi_tryset_pm_state() for setting fw error
  state (bsc#1012628).
- bus: mhi: host: Remove duplicate ee check for syserr
  (bsc#1012628).
- cxl/port: Scan single-target ports for decoders (bsc#1012628).
- cxl/hdm: Use 4-byte reads to retrieve HDM decoder base+limit
  (bsc#1012628).
- cxl/hdm: Fail upon detecting 0-sized decoders (bsc#1012628).
- xfs: don't consider future format versions valid (bsc#1012628).
- fs: dlm: fix DLM_IFL_CB_PENDING gets overwritten (bsc#1012628).
- ceph: fix potential use-after-free bug when trimming caps
  (bsc#1012628).
- ubifs: Fix memory leak in do_rename (bsc#1012628).
- ubifs: Free memory for tmpfile name (bsc#1012628).
- ubi: Fix return value overwrite issue in
  try_write_vid_and_data() (bsc#1012628).
- ubifs: Fix memleak when insert_old_idx() failed (bsc#1012628).
- Revert "ubifs: dirty_cow_znode: Fix memleak in error handling
  path" (bsc#1012628).
- RISC-V: Align SBI probe implementation with spec (bsc#1012628).
- iommu/amd: Fix "Guest Virtual APIC Table Root Pointer"
  configuration in IRTE (bsc#1012628).
- drm/amd/pm: re-enable the gfx imu when smu resume (bsc#1012628).
- tracing: Fix permissions for the buffer_percent file
  (bsc#1012628).
- thermal: intel: powerclamp: Fix NULL pointer access issue
  (bsc#1012628).
- riscv: mm: remove redundant parameter of
  create_fdt_early_page_table (bsc#1012628).
- i2c: omap: Fix standard mode false ACK readings (bsc#1012628).
- igc: read before write to SRRCTL register (bsc#1012628).
- ACPI: video: Remove acpi_backlight=video quirk for Lenovo
  ThinkPad W530 (bsc#1012628).
- ksmbd: fix racy issue from smb2 close and logoff with
  multichannel (bsc#1012628).
- ksmbd: destroy expired sessions (bsc#1012628).
- ksmbd: block asynchronous requests when making a delay on
  session setup (bsc#1012628).
- ksmbd: fix racy issue from session setup and logoff
  (bsc#1012628).
- ksmbd: fix deadlock in ksmbd_find_crypto_ctx() (bsc#1012628).
- ksmbd: not allow guest user on multichannel (bsc#1012628).
- ksmbd: fix memleak in session setup (bsc#1012628).
- ksmbd: fix NULL pointer dereference in
  smb2_get_info_filesystem() (bsc#1012628).
- ksmbd: call rcu_barrier() in ksmbd_server_exit() (bsc#1012628).
- ksmbd: fix racy issue under cocurrent smb2 tree disconnect
  (bsc#1012628).
- KVM: x86: Preserve TDP MMU roots until they are explicitly
  invalidated (bsc#1012628).
- KVM: RISC-V: Retry fault if vma_lookup() results become invalid
  (bsc#1012628).
- relayfs: fix out-of-bounds access in relay_file_read
  (bsc#1012628).
- KVM: arm64: vgic: Don't acquire its_lock before config_lock
  (bsc#1012628).
- KVM: arm64: Use config_lock to protect vgic state (bsc#1012628).
- KVM: arm64: Use config_lock to protect data ordered against
  KVM_RUN (bsc#1012628).
- KVM: arm64: Avoid lock inversion when setting the VM register
  width (bsc#1012628).
- KVM: arm64: Avoid vcpu->mutex v. kvm->lock inversion in CPU_ON
  (bsc#1012628).
- KVM: nVMX: Emulate NOPs in L2, and PAUSE if it's not intercepted
  (bsc#1012628).
- KVM: x86/pmu: Disallow legacy LBRs if architectural LBRs are
  available (bsc#1012628).
- cpufreq: qcom-cpufreq-hw: fix double IO unmap and resource
  release on exit (bsc#1012628).
- reiserfs: Add security prefix to xattr name in
  reiserfs_security_write() (bsc#1012628).
- rcu: Avoid stack overflow due to __rcu_irq_enter_check_tick()
  being kprobe-ed (bsc#1012628).
- crypto: ccp - Don't initialize CCP for PSP 0x1649 (bsc#1012628).
- crypto: testmgr - fix RNG performance in fuzz tests
  (bsc#1012628).
- crypto: arm64/aes-neonbs - fix crash with CFI enabled
  (bsc#1012628).
- crypto: safexcel - Cleanup ring IRQ workqueues on load failure
  (bsc#1012628).
- crypto: api - Demote BUG_ON() in crypto_unregister_alg()
  to a WARN_ON() (bsc#1012628).
- ring-buffer: Sync IRQ works before buffer destruction
  (bsc#1012628).
- ring-buffer: Ensure proper resetting of atomic variables in
  ring_buffer_reset_online_cpus (bsc#1012628).
- pinctrl: qcom: lpass-lpi: set output value before enabling
  output (bsc#1012628).
- soundwire: qcom: correct setting ignore bit on v1.5.1
  (bsc#1012628).
- pwm: meson: Fix g12a ao clk81 name (bsc#1012628).
- pwm: meson: Fix axg ao mux parents (bsc#1012628).
- wifi: rtw89: correct 5 MHz mask setting (bsc#1012628).
- wifi: mt76: add missing locking to protect against concurrent
  rx/status calls (bsc#1012628).
- kheaders: Use array declaration instead of char (bsc#1012628).
- iio: addac: stx104: Fix race condition for stx104_write_raw()
  (bsc#1012628).
- iio: addac: stx104: Fix race condition when converting
  analog-to-digital (bsc#1012628).
- ipmi: fix SSIF not responding under certain cond (bsc#1012628).
- ipmi:ssif: Add send_retries increment (bsc#1012628).
- MIPS: fw: Allow firmware to pass a empty env (bsc#1012628).
- fs: fix sysctls.c built (bsc#1012628).
- tick/nohz: Fix cpu_is_hotpluggable() by checking with nohz
  subsystem (bsc#1012628).
- serial: max310x: fix IO data corruption in batched operations
  (bsc#1012628).
- serial: 8250: Fix serial8250_tx_empty() race with DMA Tx
  (bsc#1012628).
- serial: fix TIOCSRS485 locking (bsc#1012628).
- xhci: fix debugfs register accesses while suspended
  (bsc#1012628).
- tty: Prevent writing chars during tcsetattr TCSADRAIN/FLUSH
  (bsc#1012628).
- staging: iio: resolver: ads1210: fix config mode (bsc#1012628).
- blk-crypto: make blk_crypto_evict_key() more robust
  (bsc#1012628).
- blk-crypto: make blk_crypto_evict_key() return void
  (bsc#1012628).
- blk-mq: release crypto keyslot before reporting I/O complete
  (bsc#1012628).
- blk-stat: fix QUEUE_FLAG_STATS clear (bsc#1012628).
- drm/vmwgfx: Fix Legacy Display Unit atomic drm support
  (bsc#1012628).
- media: ov8856: Do not check for for module version
  (bsc#1012628).
- posix-cpu-timers: Implement the missing timer_wait_running
  callback (bsc#1012628).
- tpm: Add !tpm_amd_is_rng_defective() to the hwrng_unregister()
  call site (bsc#1012628).
- hwmon: (adt7475) Use device_property APIs when configuring
  polarity (bsc#1012628).
- hwmon: (k10temp) Check range scale when CUR_TEMP register is
  read-write (bsc#1012628).
- USB: dwc3: fix runtime pm imbalance on unbind (bsc#1012628).
- USB: dwc3: fix runtime pm imbalance on probe errors
  (bsc#1012628).
- usb: dwc3: gadget: Stall and restart EP0 if host is unresponsive
  (bsc#1012628).
- usb: gadget: udc: core: Prevent redundant calls to pullup
  (bsc#1012628).
- usb: gadget: udc: core: Invoke usb_gadget_connect only when
  started (bsc#1012628).
- wifi: rtw88: usb: fix priority queue to endpoint mapping
  (bsc#1012628).
- IMA: allow/fix UML builds (bsc#1012628).
- phy: qcom-qmp-pcie: sc8180x PCIe PHY has 2 lanes (bsc#1012628).
- bus: mhi: host: pci_generic: Revert "Add a secondary AT port
  to Telit FN990" (bsc#1012628).
- PCI: qcom: Fix the incorrect register usage in v2.7.0 config
  (bsc#1012628).
- PCI: pciehp: Fix AB-BA deadlock between reset_lock and
  device_lock (bsc#1012628).
- PCI: kirin: Select REGMAP_MMIO (bsc#1012628).
- powerpc/boot: Fix boot wrapper code generation with
  CONFIG_POWER10_CPU (bsc#1012628).
- ASoC: amd: ps: update the acp clock source (bsc#1012628).
- wifi: mt76: mt7921e: Set memory space enable in PCI_COMMAND
  if unset (bsc#1012628).
- commit bcfb900
* Sun May 14 2023 mkubecek@suse.cz
- Update to 6.4-rc2
- eliminate 1 patch
  - patches.suse/0001-firmware-sysfb-Fix-VESA-format-selection.patch
- commit 679133f
* Fri May 12 2023 tiwai@suse.de
- HID: microsoft: Add rumble support to latest xbox controllers
  (bsc#1211280).
- commit 512d474
* Fri May 12 2023 dmueller@suse.com
- config: align all architectures on CONFIG_HZ=300 (bsc#1196438)
- commit 9b7c645
* Thu May 11 2023 tzimmermann@suse.com
- firmware/sysfb: Fix VESA format selection (bsc#1211119)
- commit 26ec1ca
* Tue May  9 2023 schwab@suse.de
- rpm/constraints.in: Increase disk size constraint for riscv64 to 52GB
- commit 1c1a4cd
* Tue May  9 2023 jslaby@suse.cz
- Revert "Update config files." (bsc#1211166)
  This reverts commit 90a46594a115a4abf9381bd4c327fd875ac0da0b.
  Lockdown is not ready and was disabled in stable. Since this is still
  not resolved in 6.3/6.4-rc, let's disable it in master completely too.
  And let's retry once everything is ready.
- commit 944713a
* Mon May  8 2023 mkubecek@suse.cz
- config: use ARCH_FORCE_MAX_ORDER=8 on ppc64/ppc64le
  Mainline commit 23baf831a32c ("mm, treewide: redefine MAX_ORDER sanely")
  redefined the meaning of MAX_ORDER, and therefore also related
  ARCH_FORCE_MAX_ORDER config option to be one lower than the old value so
  that having ARCH_FORCE_MAX_ORDER=9 with 64KB pages results in build time
  error "Allocator MAX_ORDER exceeds SECTION_SIZE".
  Update the values on ppc64 and ppc64le architectures from 9 to 8 to
  preserve the old behaviour and fix the build error.
- commit 668187d
* Sun May  7 2023 mkubecek@suse.cz
- Update to 6.4-rc1
- drop 14 patches (12 stable, 2 mainline)
  - patches.kernel.org/*
  - patches.suse/ath11k-pci-Add-more-MODULE_FIRMWARE-entries.patch
  - patches.suse/usbtv-usbtv_set_regs-the-pipe-is-output.patch
- refresh
  - patches.suse/add-suse-supported-flag.patch
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/0001-regulator-mt6360-Add-OF-match-table.patch
  - patches.suse/0001-security-lockdown-expose-a-hook-to-lock-the-kernel-down.patch
  - patches.suse/0002-regulator-mt6358-Add-OF-match-table.patch
  - patches.suse/0003-regulator-mt6323-Add-OF-match-table.patch
  - patches.suse/iwlwifi-cfg-Add-missing-MODULE_FIRMWARE-for-pnvm.patch
- disable ARM architectures (need config update)
- new config options
  - Processor type and features
  - ADDRESS_MASKING=y
  - Enable loadable module support
  - MODULE_DEBUG=n
  - Memory Management options
  - DMAPOOL_TEST=n
  - Networking support
  - MAX_SKB_FRAGS=17
  - BT_NXPUART=m
  - File systems
  - XFS_SUPPORT_ASCII_CI=y
  - Security options
  - INTEGRITY_CA_MACHINE_KEYRING=n
  - Kernel hacking
  - PER_VMA_LOCK_STATS=y
  - USER_EVENTS=n
  - FAULT_INJECTION_CONFIGFS=n
  - Generic Driver Options
  - FW_LOADER_DEBUG=y
  - FW_DEVLINK_SYNC_STATE_TIMEOUT=n
  - Block devices
  - BLKDEV_UBLK_LEGACY_OPCODES=y
  - Serial ATA and Parallel ATA drivers (libata)
  - PATA_PARPORT_BPCK6=m
  - Generic Target Core Mod (TCM) and ConfigFS Infrastructure
  - REMOTE_TARGET=m
  - Network device support
  - NET_DSA_MT7530_MDIO=m
  - NET_DSA_MT7530_MMIO=m
  - NET_DSA_QCA8K_LEDS_SUPPORT=y
  - PDS_CORE=m
  - MICROCHIP_T1S_PHY=m
  - NXP_CBTX_PHY=m
  - RTW88_8822BS=m
  - RTW88_8822CS=m
  - RTW88_8821CS=m
  - GPIO Support
  - GPIO_FXL6408=m
  - GPIO_ELKHARTLAKE=m
  - Voltage and Current Regulator Support
  - REGULATOR_RT4803=m
  - REGULATOR_RT5739=m
  - Sound card support
  - SND_SOC_CS35L56_I2C=m
  - SND_SOC_CS35L56_SPI=m
  - SND_SOC_CS35L56_SDW=m
  - SND_SOC_MAX98363=m
  - SND_SOC_RT712_SDCA_DMIC_SDW=m
  - X86 Platform Specific Device Drivers
  - LENOVO_YMC=m
  - INTEL_BYTCRC_PWRSRC=m
  - MSI_EC=m
  - Industrial I/O support
  - TI_ADS1100=n
  - ROHM_BU27034=n
  - NVMEM Support
  - NVMEM_LAYOUT_SL28_VPD=m
  - NVMEM_LAYOUT_ONIE_TLV=m
  - Misc drivers
  - TOUCHSCREEN_NOVATEK_NVT_TS=m
  - PTP_DFL_TOD=m
  - SENSORS_ACBEL_FSG032=m
  - DRM_VIRTIO_GPU_KMS=y
  - DRM_ACCEL_QAIC=m
  - I2C_HID_OF=m
  - LEDS_BD2606MVV=m
  - HYPERV_VTL_MODE=n
  - SOUNDWIRE_AMD=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - MFD_MAX597X=m
  - REGULATOR_MAX597X=m
  - DRM_PANEL_MAGNACHIP_D53E6EA8966=n
  - DRM_PANEL_NOVATEK_NT36523=n
  - DRM_PANEL_SONY_TD4353_JDI=n
  - DRM_SAMSUNG_DSIM=n
  - UCSI_PMIC_GLINK=m
  - COMMON_CLK_SI521XX=m
  - i386
  - CAN_BXCAN=m
  - ppc64le
  - CRYPTO_AES_GCM_P10=m
  - s390x
  - SECRETMEM=y
  - SCSI_IPR=m
  - SCSI_IPR_TRACE=y
  - SCSI_IPR_DUMP=y
  - GCC_PLUGIN_STACKLEAK=n
  - DEBUG_FORCE_FUNCTION_ALIGN_64B=n
  - riscv64
  - SCHED_MC=y
  - RISCV_ISA_SVNAPOT=y
  - RISCV_ISA_ZICBOZ=y
  - RELOCATABLE=y
  - HIBERNATION=y
  - HIBERNATION_SNAPSHOT_DEV=y
  - PM_STD_PARTITION=""
  - PM_AUTOSLEEP=n
  - PM_USERSPACE_AUTOSLEEP=n
  - PM_WAKELOCKS=n
  - FW_CACHE=y
  - DWMAC_STARFIVE=m
  - CAN_BXCAN=m
  - AIRO=m
  - SPI_CADENCE_QUADSPI=m
  - SENSORS_SFCTEMP=m
  - STARFIVE_WATCHDOG=m
  - RZ_MTU3=n
  - SND_SOC_MAX98090=n
  - CLK_STARFIVE_JH7110_SYS=y
  - CLK_STARFIVE_JH7110_AON=m
- commit 5685b1d
* Fri May  5 2023 msuchanek@suse.de
- Remove obsolete rpm spec constructs
  defattr does not need to be specified anymore
  buildroot does not need to be specified anymore
- commit c963185
* Fri May  5 2023 msuchanek@suse.de
- kernel-spec-macros: Fix up obsolete_rebuilds_subpackage to generate
  obsoletes correctly (boo#1172073 bsc#1191731).
  rpm only supports full length release, no provides
- commit c9b5bc4
* Thu May  4 2023 msuchanek@suse.de
- kernel-binary: install expoline.o (boo#1210791 bsc#1211089)
- commit d6c8c20
* Wed May  3 2023 oneukum@suse.com
- usbtv: usbtv_set_regs: the pipe is output (bsc#1209334).
- commit 98c1e01
* Wed May  3 2023 jslaby@suse.cz
- SUNRPC: Fix encoding of rejected RPCs (bsc#1210995).
- commit 9aec45d
* Mon May  1 2023 jslaby@suse.cz
- Linux 6.3.1 (bsc#1012628).
- wifi: brcmfmac: slab-out-of-bounds read in brcmf_get_assoc_ies()
  (bsc#1012628).
- fsverity: reject FS_IOC_ENABLE_VERITY on mode 3 fds
  (bsc#1012628).
- drm/fb-helper: set x/yres_virtual in drm_fb_helper_check_var
  (bsc#1012628).
- fsverity: explicitly check for buffer overflow in
  build_merkle_tree() (bsc#1012628).
- gpiolib: acpi: Add a ignore wakeup quirk for Clevo NL5xNU
  (bsc#1012628).
- bluetooth: Perform careful capability checks in hci_sock_ioctl()
  (bsc#1012628).
- wifi: brcmfmac: add Cypress 43439 SDIO ids (bsc#1012628).
- btrfs: fix uninitialized variable warnings (bsc#1012628).
- USB: serial: option: add UNISOC vendor and TOZED LT70C product
  (bsc#1012628).
- driver core: Don't require dynamic_debug for initcall_debug
  probe timing (bsc#1012628).
- commit 4fd5b5c
* Fri Apr 28 2023 jslaby@suse.cz
- mm/mremap: fix vm_pgoff in vma_merge() case 3 (bsc#1210903).
  Update upstream status.
- commit 602ef9b
* Thu Apr 27 2023 vbabka@suse.cz
- [PATCH for v6.3 regression] mm/mremap: fix vm_pgoff in
  vma_merge() case 3 (bsc#1210903).
- commit 1fc982b
* Thu Apr 27 2023 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and move into sorted section
  - patches.suse/ath11k-pci-Add-more-MODULE_FIRMWARE-entries.patch
- commit 5408aa8
* Thu Apr 27 2023 mkubecek@suse.cz
- update and reenable armv6hl configs
  New values are copied from arvm7hl.
- commit 1d2204b
* Thu Apr 27 2023 mkubecek@suse.cz
- update and reenable armv7hl configs
  Where possible, new values are copied from arm64. The rest is guessed,
  mostly based on existing values of similar config options.
- commit 6bca092
* Thu Apr 27 2023 mkubecek@suse.cz
- update and reenable arm64 configs
  Where possible, new values are copied from x86_64, i386 or riscv64. The
  rest is guessed, mostly based on existing values of similar config options.
- commit 3f00e19
* Wed Apr 26 2023 jslaby@suse.cz
- config.sh: add :LegacyX86
  To pull i586 and build against that.
- commit 723ba5c
* Mon Apr 24 2023 jslaby@suse.cz
- wifi: ath11k: pci: Add more MODULE_FIRMWARE() entries
  (bsc#1209965).
- Refresh
  patches.suse/wifi-ath11k-reduce-the-MHI-timeout-to-20s.patch.
  Update to upstream versions.
- commit 996f7a1
* Sun Apr 23 2023 mkubecek@suse.cz
- Update to 6.3 final
- update configs
- commit 9cc1a40
* Thu Apr 20 2023 jslaby@suse.cz
- Linux 6.2.12 (bsc#1012628).
- nvme-pci: add NVME_QUIRK_BOGUS_NID for T-FORCE Z330 SSD
  (bsc#1012628).
- nvme-pci: mark Lexar NM760 as IGNORE_DEV_SUBNQN (bsc#1012628).
- cifs: fix negotiate context parsing (bsc#1012628).
- i2c: ocores: generate stop condition after timeout in polling
  mode (bsc#1012628).
- x86/rtc: Remove __init for runtime functions (bsc#1012628).
- sched/fair: Fix imbalance overflow (bsc#1012628).
- powerpc/papr_scm: Update the NUMA distance table for the target
  node (bsc#1012628).
- i2c: mchp-pci1xxxx: Update Timing registers (bsc#1012628).
- ubi: Fix deadlock caused by recursively holding work_sem
  (bsc#1012628).
- ubi: Fix failure attaching when vid_hdr offset equals to
  (sub)page size (bsc#1012628).
- selftests: mptcp: userspace pm: uniform verify events
  (bsc#1012628).
- mptcp: fix NULL pointer dereference on fastopen early fallback
  (bsc#1012628).
- mptcp: stricter state check in mptcp_worker (bsc#1012628).
- mptcp: use mptcp_schedule_work instead of open-coding it
  (bsc#1012628).
- drm/amd/pm: correct SMU13.0.7 max shader clock reporting
  (bsc#1012628).
- drm/amd/pm: correct SMU13.0.7 pstate profiling clock settings
  (bsc#1012628).
- cgroup/cpuset: Add cpuset_can_fork() and cpuset_cancel_fork()
  methods (bsc#1012628).
- cgroup/cpuset: Make cpuset_fork() handle CLONE_INTO_CGROUP
  properly (bsc#1012628).
- cgroup/cpuset: Wake up cpuset_attach_wq tasks in
  cpuset_cancel_attach() (bsc#1012628).
- cgroup/cpuset: Fix partition root's cpuset.cpus update bug
  (bsc#1012628).
- cgroup: fix display of forceidle time at root (bsc#1012628).
- x86/PCI: Add quirk for AMD XHCI controller that loses MSI-X
  state in D3hot (bsc#1012628).
- PCI/MSI: Provide missing stub for pci_msix_can_alloc_dyn()
  (bsc#1012628).
- PCI: Fix use-after-free in pci_bus_release_domain_nr()
  (bsc#1012628).
- drm/amd/pm: correct the pcie link state check for SMU13
  (bsc#1012628).
- thermal: intel: Avoid updating unsupported THERM_STATUS_CLEAR
  mask bits (bsc#1012628).
- scsi: ses: Handle enclosure with just a primary component
  gracefully (bsc#1012628).
- net: phy: nxp-c45-tja11xx: fix unsigned long multiplication
  overflow (bsc#1012628).
- net: phy: nxp-c45-tja11xx: add remove callback (bsc#1012628).
- net: sfp: initialize sfp->i2c_block_size at sfp allocation
  (bsc#1012628).
- HID: intel-ish-hid: Fix kernel panic during warm reset
  (bsc#1012628).
- riscv: add icache flush for nommu sigreturn trampoline
  (bsc#1012628).
- ksmbd: avoid out of bounds access in decode_preauth_ctxt()
  (bsc#1012628).
- maple_tree: fix write memory barrier of nodes once dead for
  RCU mode (bsc#1012628).
- tracing: Have tracing_snapshot_instance_cond() write errors
  to the appropriate instance (bsc#1012628).
- tracing: Add trace_array_puts() to write into instance
  (bsc#1012628).
- ACPI: resource: Add Medion S17413 to IRQ override quirk
  (bsc#1012628).
- drm/amdgpu/gfx: set cg flags to enter/exit safe mode
  (bsc#1012628).
- drm/amdgpu: Force signal hw_fences that are embedded in
  non-sched jobs (bsc#1012628).
- drm/amdgpu: add mes resume when do gfx post soft reset
  (bsc#1012628).
- wifi: iwlwifi: mvm: protect TXQ list manipulation (bsc#1012628).
- wifi: iwlwifi: mvm: fix mvmtxq->stopped handling (bsc#1012628).
- nvme: send Identify with CNS 06h only to I/O controllers
  (bsc#1012628).
- asymmetric_keys: log on fatal failures in PE/pkcs7
  (bsc#1012628).
- verify_pefile: relax wrapper length check (bsc#1012628).
- hwmon: (xgene) Fix ioremap and memremap leak (bsc#1012628).
- hwmon: (peci/cputemp) Fix miscalculated DTS for SKX
  (bsc#1012628).
- drm: panel-orientation-quirks: Add quirk for Lenovo Yoga Book
  X90F (bsc#1012628).
- ACPI: video: Add backlight=native DMI quirk for Acer Aspire
  3830TG (bsc#1012628).
- block: ublk_drv: mark device as LIVE before adding disk
  (bsc#1012628).
- efi: sysfb_efi: Add quirk for Lenovo Yoga Book X91F/L
  (bsc#1012628).
- i2c: hisi: Avoid redundant interrupts (bsc#1012628).
- i2c: imx-lpi2c: clean rx/tx buffers upon new message
  (bsc#1012628).
- wifi: mwifiex: mark OF related data as maybe unused
  (bsc#1012628).
- selftests/bpf: Fix progs/find_vma_fail1.c build error
  (bsc#1012628).
- power: supply: axp288_fuel_gauge: Added check for negative
  values (bsc#1012628).
- power: supply: cros_usbpd: reclassify "default case!" as debug
  (bsc#1012628).
- power: supply: rk817: Fix unsigned comparison with less than
  zero (bsc#1012628).
- arm64: dts: qcom: sa8540p-ride: correct name of remoteproc_nsp0
  firmware (bsc#1012628).
- ARM: dts: qcom: apq8026-lg-lenok: add missing reserved memory
  (bsc#1012628).
- ARM: 9290/1: uaccess: Fix KASAN false-positives (bsc#1012628).
- skbuff: Fix a race between coalescing and releasing SKBs
  (bsc#1012628).
- net: macb: fix a memory corruption in extended buffer descriptor
  mode (bsc#1012628).
- selftests: add the missing CONFIG_IP_SCTP in net config
  (bsc#1012628).
- udp6: fix potential access to stale information (bsc#1012628).
- selftests: openvswitch: adjust datapath NL message declaration
  (bsc#1012628).
- RDMA/core: Fix GID entry ref leak when create_ah fails
  (bsc#1012628).
- sctp: fix a potential overflow in sctp_ifwdtsn_skip
  (bsc#1012628).
- net: qrtr: Fix an uninit variable access bug in qrtr_tx_resume()
  (bsc#1012628).
- rtnetlink: Restore RTM_NEW/DELLINK notification behavior
  (bsc#1012628).
- cgroup,freezer: hold cpu_hotplug_lock before freezer_mutex
  (bsc#1012628).
- net: wwan: iosm: Fix error handling path in ipc_pcie_probe()
  (bsc#1012628).
- smc: Fix use-after-free in tcp_write_timer_handler()
  (bsc#1012628).
- qlcnic: check pci_reset_function result (bsc#1012628).
- drm/armada: Fix a potential double free in an error handling
  path (bsc#1012628).
- drm/nouveau/fb: add missing sysmen flush callbacks
  (bsc#1012628).
- Bluetooth: Set ISO Data Path on broadcast sink (bsc#1012628).
- Bluetooth: SCO: Fix possible circular locking dependency
  sco_sock_getsockopt (bsc#1012628).
- Bluetooth: Fix printing errors if LE Connection times out
  (bsc#1012628).
- Bluetooth: hci_conn: Fix not cleaning up on LE Connection
  failure (bsc#1012628).
- net: openvswitch: fix race on port output (bsc#1012628).
- iavf: remove active_cvlans and active_svlans bitmaps
  (bsc#1012628).
- iavf: refactor VLAN filter states (bsc#1012628).
- bonding: fix ns validation on backup slaves (bsc#1012628).
- tcp: restrict net.ipv4.tcp_app_win (bsc#1012628).
- niu: Fix missing unwind goto in niu_alloc_channels()
  (bsc#1012628).
- KVM: arm64: Advertise ID_AA64PFR0_EL1.CSV2/3 to protected VMs
  (bsc#1012628).
- bpf, arm64: Fixed a BTI error on returning to patched function
  (bsc#1012628).
- 9p/xen : Fix use after free bug in xen_9pfs_front_remove due
  to race condition (bsc#1012628).
- dmaengine: apple-admac: Fix 'current_tx' not getting freed
  (bsc#1012628).
- dmaengine: apple-admac: Set src_addr_widths capability
  (bsc#1012628).
- dmaengine: apple-admac: Handle 'global' interrupt flags
  (bsc#1012628).
- LoongArch, bpf: Fix jit to skip speculation barrier opcode
  (bsc#1012628).
- bpf: tcp: Use sock_gen_put instead of sock_put in bpf_iter_tcp
  (bsc#1012628).
- RDMA/cma: Allow UD qp_type to join multicast only (bsc#1012628).
- clk: rs9: Fix suspend/resume (bsc#1012628).
- RDMA/erdma: Defer probing if netdevice can not be found
  (bsc#1012628).
- RDMA/erdma: Inline mtt entries into WQE if supported
  (bsc#1012628).
- RDMA/erdma: Update default EQ depth to 4096 and max_send_wr
  to 8192 (bsc#1012628).
- RDMA/erdma: Fix some typos (bsc#1012628).
- IB/mlx5: Add support for 400G_8X lane speed (bsc#1012628).
- RDMA/irdma: Add ipv4 check to irdma_find_listener()
  (bsc#1012628).
- RDMA/irdma: Increase iWARP CM default rexmit count
  (bsc#1012628).
- RDMA/irdma: Fix memory leak of PBLE objects (bsc#1012628).
- RDMA/irdma: Do not generate SW completions for NOPs
  (bsc#1012628).
- clk: sprd: set max_register according to mapping range
  (bsc#1012628).
- io_uring: complete request via task work in case of
  DEFER_TASKRUN (bsc#1012628).
- drm/i915/dsi: fix DSS CTL register offsets for TGL+
  (bsc#1012628).
- fbcon: set_con2fb_map needs to set con2fb_map! (bsc#1012628).
- fbcon: Fix error paths in set_con2fb_map (bsc#1012628).
- KVM: arm64: PMU: Restore the guest's EL0 event counting after
  migration (bsc#1012628).
- mtd: rawnand: stm32_fmc2: use timings.mode instead of checking
  tRC_min (bsc#1012628).
- mtd: rawnand: stm32_fmc2: remove unsupported EDO mode
  (bsc#1012628).
- mtd: rawnand: meson: fix bitmask for length in command word
  (bsc#1012628).
- mtdblock: tolerate corrected bit-flips (bsc#1012628).
- fbmem: Reject FB_ACTIVATE_KD_TEXT from userspace (bsc#1012628).
- btrfs: fix fast csum implementation detection (bsc#1012628).
- btrfs: restore the thread_pool= behavior in remount for the
  end I/O workqueues (bsc#1012628).
- Bluetooth: hci_conn: Fix possible UAF (bsc#1012628).
- Bluetooth: Free potentially unfreed SCO connection
  (bsc#1012628).
- bluetooth: btbcm: Fix logic error in forming the board name
  (bsc#1012628).
- Bluetooth: Fix race condition in hidp_session_thread
  (bsc#1012628).
- Bluetooth: L2CAP: Fix use-after-free in
  l2cap_disconnect_{req,rsp} (bsc#1012628).
- ALSA: hda/hdmi: disable KAE for Intel DG2 (bsc#1012628).
- ALSA: hda/sigmatel: fix S/PDIF out on Intel D*45* motherboards
  (bsc#1012628).
- ALSA: emu10k1: don't create old pass-through playback device
  on Audigy (bsc#1012628).
- ALSA: firewire-tascam: add missing unwind goto in
  snd_tscm_stream_start_duplex() (bsc#1012628).
- ALSA: hda/realtek: Add quirks for Lenovo Z13/Z16 Gen2
  (bsc#1012628).
- ALSA: hda: patch_realtek: add quirk for Asus N7601ZM
  (bsc#1012628).
- ALSA: i2c/cs8427: fix iec958 mixer control deactivation
  (bsc#1012628).
- ALSA: hda/sigmatel: add pin overrides for Intel DP45SG
  motherboard (bsc#1012628).
- ALSA: emu10k1: fix capture interrupt handler unlinking
  (bsc#1012628).
- drm/i915: Workaround ICL CSC_MODE sticky arming (bsc#1012628).
- drm/amd/display: Pass the right info to drm_dp_remove_payload
  (bsc#1012628).
- Revert "pinctrl: amd: Disable and mask interrupts on resume"
  (bsc#1012628).
- commit eb3255d
* Mon Apr 17 2023 mkoutny@suse.com
- supported.conf: Add a guard for unsupported DVB module(s)
- commit 7a3054e
* Mon Apr 17 2023 mkubecek@suse.cz
- Update to 6.3-rc7
- commit 9e073da
* Fri Apr 14 2023 msuchanek@suse.de
- k-m-s: Drop Linux 2.6 support
- commit 22b2304
* Fri Apr 14 2023 msuchanek@suse.de
- Remove obsolete KMP obsoletes (bsc#1210469).
- commit 7f325c6
* Thu Apr 13 2023 jslaby@suse.cz
- Linux 6.2.11 (bsc#1012628).
- mm: enable maple tree RCU mode by default (bsc#1012628).
- maple_tree: add RCU lock checking to rcu callback functions
  (bsc#1012628).
- maple_tree: add smp_rmb() to dead node detection (bsc#1012628).
- maple_tree: remove extra smp_wmb() from mas_dead_leaves()
  (bsc#1012628).
- maple_tree: fix freeing of nodes in rcu mode (bsc#1012628).
- maple_tree: detect dead nodes in mas_start() (bsc#1012628).
- maple_tree: refine ma_state init from mas_start() (bsc#1012628).
- maple_tree: be more cautious about dead nodes (bsc#1012628).
- maple_tree: fix mas_prev() and mas_find() state handling
  (bsc#1012628).
- maple_tree: fix handle of invalidated state in
  mas_wr_store_setup() (bsc#1012628).
- maple_tree: reduce user error potential (bsc#1012628).
- maple_tree: fix potential rcu issue (bsc#1012628).
- maple_tree: remove GFP_ZERO from kmem_cache_alloc() and
  kmem_cache_alloc_bulk() (bsc#1012628).
- mm: take a page reference when removing device exclusive entries
  (bsc#1012628).
- drm/bridge: lt9611: Fix PLL being unable to lock (bsc#1012628).
- drm/amdgpu: skip psp suspend for IMU enabled ASICs mode2 reset
  (bsc#1012628).
- drm/amdgpu: for S0ix, skip SDMA 5.x+ suspend/resume
  (bsc#1012628).
- drm/amd/display: Clear MST topology if it fails to resume
  (bsc#1012628).
- maple_tree: fix a potential concurrency bug in RCU mode
  (bsc#1012628).
- maple_tree: fix get wrong data_end in mtree_lookup_walk()
  (bsc#1012628).
- mm/hugetlb: fix uffd wr-protection for CoW optimization path
  (bsc#1012628).
- mm/swap: fix swap_info_struct race between swapoff and
  get_swap_pages() (bsc#1012628).
- ring-buffer: Fix race while reader and writer are on the same
  page (bsc#1012628).
- drm/i915: fix race condition UAF in i915_perf_add_config_ioctl
  (bsc#1012628).
- drm/i915: Fix context runtime accounting (bsc#1012628).
- drm/nouveau/disp: Support more modes by checking with lower bpc
  (bsc#1012628).
- drm/panfrost: Fix the panfrost_mmu_map_fault_addr() error path
  (bsc#1012628).
- ublk: read any SQE values upfront (bsc#1012628).
- wifi: mt76: ignore key disable commands (bsc#1012628).
- wifi: mt76: mt7921: fix fw used for offload check for mt7922
  (bsc#1012628).
- mm: vmalloc: avoid warn_alloc noise caused by fatal signal
  (bsc#1012628).
- zsmalloc: document freeable stats (bsc#1012628).
- tracing/synthetic: Make lastcmd_mutex static (bsc#1012628).
- perf/core: Fix the same task check in perf_event_set_output
  (bsc#1012628).
- perf: Optimize perf_pmu_migrate_context() (bsc#1012628).
- block: don't set GD_NEED_PART_SCAN if scan partition failed
  (bsc#1012628).
- block: ublk: make sure that block size is set correctly
  (bsc#1012628).
- cifs: sanitize paths in cifs_update_super_prepath (bsc#1012628).
- nvme: fix discard support without oncs (bsc#1012628).
- scsi: iscsi_tcp: Check that sock is valid before
  iscsi_set_param() (bsc#1012628).
- scsi: qla2xxx: Fix memory leak in qla2x00_probe_one()
  (bsc#1012628).
- io_uring: fix memory leak when removing provided buffers
  (bsc#1012628).
- io_uring: fix return value when removing provided buffers
  (bsc#1012628).
- iio: adc: ad7791: fix IRQ flags (bsc#1012628).
- ASoC: SOF: avoid a NULL dereference with unsupported widgets
  (bsc#1012628).
- ASoC: hdac_hdmi: use set_stream() instead of set_tdm_slots()
  (bsc#1012628).
- iommufd: Do not corrupt the pfn list when doing batch carry
  (bsc#1012628).
- iommufd: Fix unpinning of pages when an access is present
  (bsc#1012628).
- iommufd: Check for uptr overflow (bsc#1012628).
- tracing: Free error logs of tracing instances (bsc#1012628).
- tracing/osnoise: Fix notify new tracing_max_latency
  (bsc#1012628).
- tracing/timerlat: Notify new max thread latency (bsc#1012628).
- tracing/synthetic: Fix races on freeing last_cmd (bsc#1012628).
- net: stmmac: Add queue reset into stmmac_xdp_open() function
  (bsc#1012628).
- ACPI: video: Add acpi_backlight=video quirk for Lenovo ThinkPad
  W530 (bsc#1012628).
- ACPI: video: Add acpi_backlight=video quirk for Apple iMac14,1
  and iMac14,2 (bsc#1012628).
- ACPI: video: Make acpi_backlight=video work independent from
  GPU driver (bsc#1012628).
- ACPI: video: Add auto_detect arg to
  __acpi_video_get_backlight_type() (bsc#1012628).
- can: isotp: isotp_recvmsg(): use sock_recv_cmsgs() to get
  SOCK_RXQ_OVFL infos (bsc#1012628).
- can: isotp: isotp_ops: fix poll() to not report false EPOLLOUT
  events (bsc#1012628).
- can: isotp: fix race between isotp_sendsmg() and isotp_release()
  (bsc#1012628).
- can: j1939: j1939_tp_tx_dat_new(): fix out-of-bounds memory
  access (bsc#1012628).
- fs: drop peer group ids under namespace lock (bsc#1012628).
- ftrace: Fix issue that 'direct->addr' not restored in
  modify_ftrace_direct() (bsc#1012628).
- ftrace: Mark get_lock_parent_ip() __always_inline (bsc#1012628).
- blk-mq: directly poll requests (bsc#1012628).
- counter: 104-quad-8: Fix Synapse action reported for Index
  signals (bsc#1012628).
- counter: 104-quad-8: Fix race condition between FLAG and CNTR
  reads (bsc#1012628).
- coresight-etm4: Fix for() loop drvdata->nr_addr_cmp range bug
  (bsc#1012628).
- coresight: etm4x: Do not access TRCIDR1 for identification
  (bsc#1012628).
- mm: kfence: fix handling discontiguous page (bsc#1012628).
- mm: kfence: fix PG_slab and memcg_data clearing (bsc#1012628).
- KVM: SVM: Flush Hyper-V TLB when required (bsc#1012628).
- KVM: nVMX: Do not report error code when synthesizing VM-Exit
  from Real Mode (bsc#1012628).
- KVM: x86: Clear "has_error_code", not "error_code", for RM
  exception injection (bsc#1012628).
- x86/ACPI/boot: Use FADT version to check support for online
  capable (bsc#1012628).
- x86/acpi/boot: Correct acpi_is_processor_usable() check
  (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs for a HP ProBook
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Clevo X370SNW (bsc#1012628).
- ksmbd: fix slab-out-of-bounds in init_smb2_rsp_hdr
  (bsc#1012628).
- ksmbd: do not call kvmalloc() with __GFP_NORETRY | __GFP_NO_WARN
  (bsc#1012628).
- serial: 8250: Prevent starting up DMA Rx on THRI interrupt
  (bsc#1012628).
- dt-bindings: serial: renesas,scif: Fix 4th IRQ for 4-IRQ SCIFs
  (bsc#1012628).
- fsdax: force clear dirty mark if CoW (bsc#1012628).
- fsdax: unshare: zero destination if srcmap is HOLE or UNWRITTEN
  (bsc#1012628).
- fsdax: dedupe should compare the min of two iters' length
  (bsc#1012628).
- nilfs2: fix sysfs interface lifetime (bsc#1012628).
- nilfs2: fix potential UAF of struct nilfs_sc_info in
  nilfs_segctor_thread() (bsc#1012628).
- tty: serial: fsl_lpuart: fix crash in lpuart_uport_is_active
  (bsc#1012628).
- tty: serial: fsl_lpuart: avoid checking for transfer
  complete when UARTCTRL_SBK is asserted in lpuart32_tx_empty
  (bsc#1012628).
- tty: serial: sh-sci: Fix Rx on RZ/G2L SCI (bsc#1012628).
- tty: serial: sh-sci: Fix transmit end interrupt handler
  (bsc#1012628).
- iio: light: vcnl4000: Fix WARN_ON on uninitialized lock
  (bsc#1012628).
- iio: light: cm32181: Unregister second I2C client if present
  (bsc#1012628).
- iio: buffer: make sure O_NONBLOCK is respected (bsc#1012628).
- iio: buffer: correctly return bytes written in output buffers
  (bsc#1012628).
- iio: accel: kionix-kx022a: Get the timestamp from the driver's
  private data in the trigger_handler (bsc#1012628).
- iio: adc: max11410: fix read_poll_timeout() usage (bsc#1012628).
- iio: dac: cio-dac: Fix max DAC write value check for 12-bit
  (bsc#1012628).
- iio: adc: ti-ads7950: Set `can_sleep` flag for GPIO chip
  (bsc#1012628).
- iio: adc: qcom-spmi-adc5: Fix the channel name (bsc#1012628).
- iio: adis16480: select CONFIG_CRC32 (bsc#1012628).
- drivers: iio: adc: ltc2497: fix LSB shift (bsc#1012628).
- USB: serial: option: add Quectel RM500U-CN modem (bsc#1012628).
- USB: serial: option: add Telit FE990 compositions (bsc#1012628).
- usb: typec: altmodes/displayport: Fix configure initial pin
  assignment (bsc#1012628).
- USB: serial: cp210x: add Silicon Labs IFS-USB-DATACABLE IDs
  (bsc#1012628).
- usb: dwc3: pci: add support for the Intel Meteor Lake-S
  (bsc#1012628).
- usb: cdnsp: Fixes error: uninitialized symbol 'len'
  (bsc#1012628).
- xhci: also avoid the XHCI_ZERO_64B_REGS quirk with a passthrough
  iommu (bsc#1012628).
- xhci: Free the command allocated for setting LPM if we return
  early (bsc#1012628).
- usb: xhci: tegra: fix sleep in atomic call (bsc#1012628).
- Revert "usb: xhci-pci: Set PROBE_PREFER_ASYNCHRONOUS"
  (bsc#1012628).
- PCI/DOE: Fix memory leak with CONFIG_DEBUG_OBJECTS=y
  (bsc#1012628).
- PCI/DOE: Silence WARN splat with CONFIG_DEBUG_OBJECTS=y
  (bsc#1012628).
- cxl/pci: Handle excessive CDAT length (bsc#1012628).
- cxl/pci: Handle truncated CDAT entries (bsc#1012628).
- cxl/pci: Handle truncated CDAT header (bsc#1012628).
- cxl/pci: Fix CDAT retrieval on big endian (bsc#1012628).
- net: stmmac: check fwnode for phy device before scanning for
  phy (bsc#1012628).
- arm64: compat: Work around uninitialized variable warning
  (bsc#1012628).
- gve: Secure enough bytes in the first TX desc for all TCP pkts
  (bsc#1012628).
- netlink: annotate lockless accesses to nlk->max_recvmsg_len
  (bsc#1012628).
- ethtool: reset #lanes when lanes is omitted (bsc#1012628).
- ping: Fix potentail NULL deref for /proc/net/icmp (bsc#1012628).
- raw: Fix NULL deref in raw_get_next() (bsc#1012628).
- raw: use net_hash_mix() in hash function (bsc#1012628).
- ice: Reset FDIR counter in FDIR init stage (bsc#1012628).
- ice: fix wrong fallback logic for FDIR (bsc#1012628).
- NFSD: callback request does not use correct credential for
  AUTH_SYS (bsc#1012628).
- sunrpc: only free unix grouplist after RCU settles
  (bsc#1012628).
- net: stmmac: fix up RX flow hash indirection table when setting
  channels (bsc#1012628).
- net: ethernet: ti: am65-cpsw: Fix mdio cleanup in probe
  (bsc#1012628).
- gpio: davinci: Add irq chip flag to skip set wake (bsc#1012628).
- gpio: davinci: Do not clear the bank intr enable bit in
  save_context (bsc#1012628).
- platform/x86: think-lmi: Clean up display of current_value on
  Thinkstation (bsc#1012628).
- platform/x86: think-lmi: Fix memory leaks when parsing
  ThinkStation WMI strings (bsc#1012628).
- platform/x86: think-lmi: Fix memory leak when showing current
  settings (bsc#1012628).
- ipv6: Fix an uninit variable access bug in __ip6_make_skb()
  (bsc#1012628).
- net: qrtr: Do not do DEL_SERVER broadcast after DEL_CLIENT
  (bsc#1012628).
- drm/i915/huc: Cancel HuC delayed load timer on reset
  (bsc#1012628).
- sctp: check send stream number after wait_for_sndbuf
  (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix remaining throughput regression
  (bsc#1012628).
- net: dsa: mv88e6xxx: Reset mv88e6393x force WD event bit
  (bsc#1012628).
- net: don't let netpoll invoke NAPI if in xmit context
  (bsc#1012628).
- ALSA: hda/hdmi: Preserve the previous PCM device upon
  re-enablement (bsc#1012628).
- icmp: guard against too small mtu (bsc#1012628).
- nfsd: call op_release, even when op_func returns an error
  (bsc#1012628).
- NFSD: Avoid calling OPDESC() with ops->opnum == OP_ILLEGAL
  (bsc#1012628).
- wifi: brcmfmac: Fix SDIO suspend/resume regression
  (bsc#1012628).
- l2tp: generate correct module alias strings (bsc#1012628).
- net: stmmac: remove redundant fixup to support fixed-link mode
  (bsc#1012628).
- net: stmmac: check if MAC needs to attach to a PHY
  (bsc#1012628).
- net: phylink: add phylink_expects_phy() method (bsc#1012628).
- net: qrtr: Fix a refcount bug in qrtr_recvmsg() (bsc#1012628).
- wifi: mac80211: fix invalid drv_sta_pre_rcu_remove calls for
  non-uploaded sta (bsc#1012628).
- wifi: mac80211: fix the size calculation of
  ieee80211_ie_len_eht_cap() (bsc#1012628).
- KVM: s390: pv: fix external interruption loop not always
  detected (bsc#1012628).
- ASoC: codecs: lpass: fix the order or clks turn off during
  suspend (bsc#1012628).
- pwm: meson: Explicitly set .polarity in .get_state()
  (bsc#1012628).
- pwm: sprd: Explicitly set .polarity in .get_state()
  (bsc#1012628).
- pwm: iqs620a: Explicitly set .polarity in .get_state()
  (bsc#1012628).
- pwm: cros-ec: Explicitly set .polarity in .get_state()
  (bsc#1012628).
- pwm: hibvt: Explicitly set .polarity in .get_state()
  (bsc#1012628).
- ASoC: SOF: ipc4: Ensure DSP is in D0I0 during
  sof_ipc4_set_get_data() (bsc#1012628).
- Drivers: vmbus: Check for channel allocation before looking
  up relids (bsc#1012628).
- gpio: GPIO_REGMAP: select REGMAP instead of depending on it
  (bsc#1012628).
- drm/i915: Add a .color_post_update() hook (bsc#1012628).
- drm/i915: Move the DSB setup/cleaup into the color code
  (bsc#1012628).
- dm: fix improper splitting for abnormal bios (bsc#1012628).
- dm: change "unsigned" to "unsigned int" (bsc#1012628).
- dm integrity: Remove bi_sector that's only used by commented
  debug code (bsc#1012628).
- dm cache: Add some documentation to
  dm-cache-background-tracker.h (bsc#1012628).
- commit 19dcda6
* Thu Apr 13 2023 jslaby@suse.cz
- net: wwan: t7xx: do not compile with -Werror (bsc#1209724).
  Update upstream status.
- commit ad61c68
* Thu Apr 13 2023 tiwai@suse.de
- iwlwifi: cfg: Add missing MODULE_FIRMWARE() for *.pnvm
  (bsc#1207553).
- commit 2a07952
* Tue Apr 11 2023 msuchanek@suse.de
- Update patches.kernel.org/6.2.10-153-powerpc-pseries-vas-Ignore-VAS-update-for-DLPA.patch
  (bsc#1012628 bsc#1210216 ltc#202189).
- commit 4e944ba
* Sun Apr  9 2023 mkubecek@suse.cz
- Update to 6.3-rc6
- commit 97dd3d4
* Thu Apr  6 2023 jslaby@suse.cz
- Linux 6.2.10 (bsc#1012628).
- thunderbolt: Limit USB3 bandwidth of certain Intel USB4 host
  routers (bsc#1012628).
- cifs: update ip_addr for ses only for primary chan setup
  (bsc#1012628).
- cifs: prevent data race in cifs_reconnect_tcon() (bsc#1012628).
- cifs: avoid race conditions with parallel reconnects
  (bsc#1012628).
- zonefs: Reorganize code (bsc#1012628).
- zonefs: Simplify IO error handling (bsc#1012628).
- zonefs: Reduce struct zonefs_inode_info size (bsc#1012628).
- zonefs: Separate zone information from inode information
  (bsc#1012628).
- zonefs: Fix error message in zonefs_file_dio_append()
  (bsc#1012628).
- btrfs: rename BTRFS_FS_NO_OVERCOMMIT to
  BTRFS_FS_ACTIVE_ZONE_TRACKING (bsc#1012628).
- btrfs: zoned: count fresh BG region as zone unusable
  (bsc#1012628).
- btrfs: zoned: drop space_info->active_total_bytes (bsc#1012628).
- fsverity: don't drop pagecache at end of FS_IOC_ENABLE_VERITY
  (bsc#1012628).
- cifs: fix missing unload_nls() in smb2_reconnect()
  (bsc#1012628).
- xfrm: Zero padding when dumping algos and encap (bsc#1012628).
- ASoC: codecs: tx-macro: Fix for KASAN: slab-out-of-bounds
  (bsc#1012628).
- ASoC: Intel: avs: max98357a: Explicitly define codec format
  (bsc#1012628).
- ASoC: Intel: avs: da7219: Explicitly define codec format
  (bsc#1012628).
- ASoC: Intel: avs: rt5682: Explicitly define codec format
  (bsc#1012628).
- ASoC: Intel: avs: ssm4567: Remove nau8825 bits (bsc#1012628).
- ASoC: Intel: avs: nau8825: Adjust clock control (bsc#1012628).
- lib: zstd: Backport fix for in-place decompression
  (bsc#1012628).
- zstd: Fix definition of assert() (bsc#1012628).
- ACPI: video: Add backlight=native DMI quirk for Dell Vostro
  15 3535 (bsc#1012628).
- ACPI: x86: Introduce an acpi_quirk_skip_gpio_event_handlers()
  helper (bsc#1012628).
- ACPI: x86: Add skip i2c clients quirk for Acer Iconia One 7
  B1-750 (bsc#1012628).
- ACPI: x86: Add skip i2c clients quirk for Lenovo Yoga Book X90
  (bsc#1012628).
- ASoC: SOF: ipc3: Check for upper size limit for the received
  message (bsc#1012628).
- ASoC: SOF: ipc4-topology: Fix incorrect sample rate print unit
  (bsc#1012628).
- ASoC: SOF: Intel: pci-tng: revert invalid bar size setting
  (bsc#1012628).
- ASoC: SOF: Intel: hda-dsp: harden D0i3 programming sequence
  (bsc#1012628).
- ASoC: SOF: Intel: hda-ctrl: re-add sleep after entering and
  exiting reset (bsc#1012628).
- ASoC: SOF: IPC4: update gain ipc msg definition to align with fw
  (bsc#1012628).
- ASoC: hdmi-codec: only startup/shutdown on supported streams
  (bsc#1012628).
- wifi: mac80211: check basic rates validity (bsc#1012628).
- md: avoid signed overflow in slot_store() (bsc#1012628).
- x86/PVH: obtain VGA console info in Dom0 (bsc#1012628).
- drm/amdkfd: Fix BO offset for multi-VMA page migration
  (bsc#1012628).
- drm/amdkfd: fix a potential double free in pqm_create_queue
  (bsc#1012628).
- drm/amdgpu/vcn: custom video info caps for sriov (bsc#1012628).
- drm/amdkfd: fix potential kgd_mem UAFs (bsc#1012628).
- drm/amd/display: Fix HDCP failing to enable after suspend
  (bsc#1012628).
- net: hsr: Don't log netdev_err message on unknown prp dst node
  (bsc#1012628).
- ALSA: asihpi: check pao in control_message() (bsc#1012628).
- ALSA: hda/ca0132: fixup buffer overrun at tuning_ctl_set()
  (bsc#1012628).
- fbdev: tgafb: Fix potential divide by zero (bsc#1012628).
- ACPI: tools: pfrut: Check if the input of level and type is
  in the right numeric range (bsc#1012628).
- sched_getaffinity: don't assume 'cpumask_size()' is fully
  initialized (bsc#1012628).
- nvme-pci: fixing memory leak in probe teardown path
  (bsc#1012628).
- nvme-pci: add NVME_QUIRK_BOGUS_NID for Lexar NM620
  (bsc#1012628).
- drm/amdkfd: Fixed kfd_process cleanup on module exit
  (bsc#1012628).
- net/mlx5e: Lower maximum allowed MTU in XSK to match XDP
  prerequisites (bsc#1012628).
- fbdev: nvidia: Fix potential divide by zero (bsc#1012628).
- fbdev: intelfb: Fix potential divide by zero (bsc#1012628).
- fbdev: lxfb: Fix potential divide by zero (bsc#1012628).
- fbdev: au1200fb: Fix potential divide by zero (bsc#1012628).
- tools/power turbostat: Fix /dev/cpu_dma_latency warnings
  (bsc#1012628).
- tools/power turbostat: fix decoding of HWP_STATUS (bsc#1012628).
- tracing: Fix wrong return in kprobe_event_gen_test.c
  (bsc#1012628).
- btrfs: fix uninitialized variable warning in
  btrfs_update_block_group (bsc#1012628).
- btrfs: use temporary variable for space_info in
  btrfs_update_block_group (bsc#1012628).
- mtd: rawnand: meson: initialize struct with zeroes
  (bsc#1012628).
- mtd: nand: mxic-ecc: Fix
  mxic_ecc_data_xfer_wait_for_completion() when irq is used
  (bsc#1012628).
- ca8210: Fix unsigned mac_len comparison with zero in
  ca8210_skb_tx() (bsc#1012628).
- riscv/kvm: Fix VM hang in case of timer delta being zero
  (bsc#1012628).
- mips: bmips: BCM6358: disable RAC flush for TP1 (bsc#1012628).
- ALSA: usb-audio: Fix recursive locking at XRUN during syncing
  (bsc#1012628).
- PCI: dwc: Fix PORT_LINK_CONTROL update when CDM check enabled
  (bsc#1012628).
- platform/x86: think-lmi: add missing type attribute
  (bsc#1012628).
- platform/x86: think-lmi: use correct possible_values delimiters
  (bsc#1012628).
- platform/x86: think-lmi: only display possible_values if
  available (bsc#1012628).
- platform/x86: think-lmi: Add possible_values for ThinkStation
  (bsc#1012628).
- platform/surface: aggregator: Add missing fwnode_handle_put()
  (bsc#1012628).
- mtd: rawnand: meson: invalidate cache on polling ECC bit
  (bsc#1012628).
- SUNRPC: fix shutdown of NFS TCP client socket (bsc#1012628).
- sfc: ef10: don't overwrite offload features at NIC reset
  (bsc#1012628).
- scsi: megaraid_sas: Fix crash after a double completion
  (bsc#1012628).
- scsi: mpt3sas: Don't print sense pool info twice (bsc#1012628).
- net: dsa: realtek: fix out-of-bounds access (bsc#1012628).
- ptp_qoriq: fix memory leak in probe() (bsc#1012628).
- net: dsa: microchip: ksz8: fix ksz8_fdb_dump() (bsc#1012628).
- net: dsa: microchip: ksz8: fix ksz8_fdb_dump() to extract all
  1024 entries (bsc#1012628).
- net: dsa: microchip: ksz8: fix offset for the timestamp filed
  (bsc#1012628).
- net: dsa: microchip: ksz8: ksz8_fdb_dump: avoid extracting
  ghost entry from empty dynamic MAC table (bsc#1012628).
- net: dsa: microchip: ksz8863_smi: fix bulk access (bsc#1012628).
- net: dsa: microchip: ksz8: fix MDB configuration with non-zero
  VID (bsc#1012628).
- r8169: fix RTL8168H and RTL8107E rx crc error (bsc#1012628).
- regulator: Handle deferred clk (bsc#1012628).
- net/net_failover: fix txq exceeding warning (bsc#1012628).
- net: stmmac: don't reject VLANs when IFF_PROMISC is set
  (bsc#1012628).
- drm/i915/pmu: Use functions common with sysfs to read actual
  freq (bsc#1012628).
- drm/i915/tc: Fix the ICL PHY ownership check in TC-cold state
  (bsc#1012628).
- drm/i915/perf: Drop wakeref on GuC RC error (bsc#1012628).
- platform/x86/intel/pmc: Alder Lake PCH slp_s0_residency fix
  (bsc#1012628).
- can: bcm: bcm_tx_setup(): fix KMSAN uninit-value in vfs_write
  (bsc#1012628).
- s390/vfio-ap: fix memory leak in vfio_ap device driver
  (bsc#1012628).
- ACPI: bus: Rework system-level device notification handling
  (bsc#1012628).
- loop: LOOP_CONFIGURE: send uevents for partitions (bsc#1012628).
- net: mvpp2: classifier flow fix fragmentation flags
  (bsc#1012628).
- net: mvpp2: parser fix QinQ (bsc#1012628).
- net: mvpp2: parser fix PPPoE (bsc#1012628).
- smsc911x: avoid PHY being resumed when interface is not up
  (bsc#1012628).
- ice: Fix ice_cfg_rdma_fltr() to only update relevant fields
  (bsc#1012628).
- ice: add profile conflict check for AVF FDIR (bsc#1012628).
- ice: fix invalid check for empty list in
  ice_sched_assoc_vsi_to_agg() (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix tx throughput regression with
  direct 1G links (bsc#1012628).
- ALSA: ymfpci: Create card with device-managed
  snd_devm_card_new() (bsc#1012628).
- ALSA: ymfpci: Fix BUG_ON in probe function (bsc#1012628).
- net: wwan: iosm: fixes 7560 modem crash (bsc#1012628).
- net: ipa: compute DMA pool size properly (bsc#1012628).
- bnx2x: use the right build_skb() helper (bsc#1012628).
- i40e: fix registers dump after run ethtool adapter self test
  (bsc#1012628).
- bnxt_en: Fix reporting of test result in ethtool selftest
  (bsc#1012628).
- bnxt_en: Fix typo in PCI id to device description string mapping
  (bsc#1012628).
- bnxt_en: Add missing 200G link speed reporting (bsc#1012628).
- net: dsa: mv88e6xxx: Enable IGMP snooping on user ports only
  (bsc#1012628).
- net: dsa: sync unicast and multicast addresses for VLAN filters
  too (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix flow block refcounting logic
  (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix L2 offloading with DSA untag
  offload (bsc#1012628).
- net: ethernet: mtk_eth_soc: add missing ppe cache flush when
  deleting a flow (bsc#1012628).
- pinctrl: ocelot: Fix alt mode for ocelot (bsc#1012628).
- Input: xpad - fix incorrectly applied patch for
  MAP_PROFILE_BUTTON (bsc#1012628).
- iommu/vt-d: Allow zero SAGAW if second-stage not supported
  (bsc#1012628).
- Revert "venus: firmware: Correct non-pix start and end
  addresses" (bsc#1012628).
- Input: i8042 - add TUXEDO devices to i8042 quirk tables for
  partial fix (bsc#1012628).
- Input: focaltech - use explicitly signed char type
  (bsc#1012628).
- cifs: prevent infinite recursion in CIFSGetDFSRefer()
  (bsc#1012628).
- cifs: fix DFS traversal oops without CONFIG_CIFS_DFS_UPCALL
  (bsc#1012628).
- Input: i8042 - add quirk for Fujitsu Lifebook A574/H
  (bsc#1012628).
- Input: goodix - add Lenovo Yoga Book X90F to nine_bytes_report
  DMI table (bsc#1012628).
- btrfs: fix deadlock when aborting transaction during relocation
  with scrub (bsc#1012628).
- btrfs: fix race between quota disable and quota assign ioctls
  (bsc#1012628).
- btrfs: scan device in non-exclusive mode (bsc#1012628).
- btrfs: ignore fiemap path cache when there are multiple paths
  for a node (bsc#1012628).
- zonefs: Do not propagate iomap_dio_rw() ENOTBLK error to user
  space (bsc#1012628).
- io_uring/poll: clear single/double poll flags on poll arming
  (bsc#1012628).
- io_uring/rsrc: fix rogue rsrc node grabbing (bsc#1012628).
- io_uring: fix poll/netmsg alloc caches (bsc#1012628).
- vmxnet3: use gro callback when UPT is enabled (bsc#1012628).
- zonefs: Always invalidate last cached page on append write
  (bsc#1012628).
- dm: fix __send_duplicate_bios() to always allow for splitting IO
  (bsc#1012628).
- can: j1939: prevent deadlock by moving j1939_sk_errqueue()
  (bsc#1012628).
- xen/netback: don't do grant copy across page boundary
  (bsc#1012628).
- net: phy: dp83869: fix default value for tx-/rx-internal-delay
  (bsc#1012628).
- modpost: Fix processing of CRCs on 32-bit build machines
  (bsc#1012628).
- pinctrl: amd: Disable and mask interrupts on resume
  (bsc#1012628).
- pinctrl: at91-pio4: fix domain name assignment (bsc#1012628).
- platform/x86: ideapad-laptop: Stop sending KEY_TOUCHPAD_TOGGLE
  (bsc#1012628).
- thermal: intel: int340x: processor_thermal: Fix additional
  deadlock (bsc#1012628).
- powerpc: Don't try to copy PPR for task with NULL pt_regs
  (bsc#1012628).
- powerpc/pseries/vas: Ignore VAS update for DLPAR if copy/paste
  is not enabled (bsc#1012628).
- powerpc/64s: Fix __pte_needs_flush() false positive warning
  (bsc#1012628).
- NFSv4: Fix hangs when recovering open state after a server
  reboot (bsc#1012628).
- ALSA: hda/conexant: Partial revert of a quirk for Lenovo
  (bsc#1012628).
- ALSA: usb-audio: Fix regression on detection of Roland VS-100
  (bsc#1012628).
- ALSA: hda/realtek: Add quirks for some Clevo laptops
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Lenovo ZhaoYang CF4620Z
  (bsc#1012628).
- xtensa: fix KASAN report for show_stack (bsc#1012628).
- rcu: Fix rcu_torture_read ftrace event (bsc#1012628).
- dt-bindings: mtd: jedec,spi-nor: Document CPOL/CPHA support
  (bsc#1012628).
- s390/uaccess: add missing earlyclobber annotations to
  __clear_user() (bsc#1012628).
- drm/etnaviv: fix reference leak when mmaping imported buffer
  (bsc#1012628).
- drm/amdgpu: allow more APUs to do mode2 reset when go to S4
  (bsc#1012628).
- drm/amd/display: Add DSC Support for Synaptics Cascaded MST Hub
  (bsc#1012628).
- drm/amd/display: Take FEC Overhead into Timeslot Calculation
  (bsc#1012628).
- drm/i915/gem: Flush lmem contents after construction
  (bsc#1012628).
- drm/i915/dpt: Treat the DPT BO as a framebuffer (bsc#1012628).
- drm/i915: Disable DC states for all commits (bsc#1012628).
- drm/i915: Split icl_color_commit_noarm() from
  skl_color_commit_noarm() (bsc#1012628).
- drm/i915: Move CSC load back into .color_commit_arm() when
  PSR is enabled on skl/glk (bsc#1012628).
- KVM: arm64: PMU: Fix GET_ONE_REG for vPMC regs to return the
  current value (bsc#1012628).
- KVM: arm64: PMU: Don't save PMCR_EL0.{C,P} for the vCPU
  (bsc#1012628).
- KVM: arm64: Retry fault if vma_lookup() results become invalid
  (bsc#1012628).
- KVM: arm64: Disable interrupts while walking userspace PTs
  (bsc#1012628).
- KVM: arm64: Check for kvm_vma_mte_allowed in the critical
  section (bsc#1012628).
- usb: ucsi: Fix ucsi->connector race (bsc#1012628).
- libbpf: Fix BTF-to-C converter's padding logic (bsc#1012628).
- selftests/bpf: Add few corner cases to test padding handling
  of btf_dump (bsc#1012628).
- libbpf: Fix btf_dump's packed struct determination
  (bsc#1012628).
- drm/amdkfd: Get prange->offset after svm_range_vram_node_new
  (bsc#1012628).
- hsr: ratelimit only when errors are printed (bsc#1012628).
- x86/PVH: avoid 32-bit build warning when obtaining VGA console
  info (bsc#1012628).
- Revert "cpuidle, intel_idle: Fix CPUIDLE_FLAG_IRQ_ENABLE
  * again*" (bsc#1012628).
- commit ba7816e
* Tue Apr  4 2023 msuchanek@suse.de
- Define kernel-vanilla as source variant
  The vanilla_only macro is overloaded. It is used for determining if
  there should be two kernel sources built as well as for the purpose of
  determmioning if vanilla kernel should be used for kernel-obs-build.
  While the former can be determined at build time the latter needs to be
  baked into the spec file template. Separate the two while also making
  the latter more generic.
  $build_dtbs is enabled on every single rt and azure branch since 15.3
  when the setting was introduced, gate on the new $obs_build_variant
  setting as well.
- commit 36ba909
* Tue Apr  4 2023 jdelvare@suse.de
- Update config files: disable CONFIG_SENSORS_OCC_P8_I2C and CONFIG_SENSORS_OCC_P9_SBE
  These drivers are intended to run on the BMC of Power systems, not on
  the host, so they are useless in our distribution.
- commit 8dba174
* Tue Apr  4 2023 jslaby@suse.cz
- Refresh
  patches.suse/drm-nouveau-kms-Fix-backlight-registration.patch.
  Update upstream status.
- commit 8db91ce
* Mon Apr  3 2023 tiwai@suse.de
- rpm/constraints.in: increase the disk size for armv6/7 to 24GB
  It grows and the build fails recently on SLE15-SP4/5.
- commit 41ac816
* Mon Apr  3 2023 jslaby@suse.cz
- Refresh
  patches.rpmify/s390-reintroduce-expoline-dependence-to-scripts.patch.
  Update upstream status.
- commit 549d742
* Sun Apr  2 2023 mkubecek@suse.cz
- Update to 6.3-rc5
- eliminate 1 patch
  - patches.rpmify/s390-reintroduce-expoline-dependence-to-scripts.patch (7bb2107e63d8)
- commit e8c15b9
* Sat Apr  1 2023 schwab@suse.de
- rpm/check-for-config-changes: add TOOLCHAIN_NEEDS_* to IGNORED_CONFIGS_RE
  This new form was added in commit e89c2e815e76 ("riscv: Handle
  zicsr/zifencei issues between clang and binutils").
- commit 234baea
* Fri Mar 31 2023 msuchanek@suse.de
- Disable compat options on ppc64le (jsc#PED-3184).
  CONFIG_PPC_TRANSACTIONAL_MEM=n
  CONFIG_COMPAT=n
- commit 427a93d
* Fri Mar 31 2023 tiwai@suse.de
- ath11k: pci: Add more MODULE_FIRMWARE() entries (bsc#1209965).
  [js] update upstream status
- ath11k: pci: Add more MODULE_FIRMWARE() entries (bsc#1209965).
- commit 33c2186
* Fri Mar 31 2023 jslaby@suse.cz
- Update config files.
  (Only oldconfig, RISCV fails.)
- commit f0487ac
* Thu Mar 30 2023 tiwai@suse.de
- wifi: ath11k: reduce the MHI timeout to 20s (bsc#1207948).
- commit 343f603
* Thu Mar 30 2023 jslaby@suse.cz
- Linux 6.2.9 (bsc#1012628).
- interconnect: qcom: osm-l3: fix icc_onecell_data allocation
  (bsc#1012628).
- interconnect: qcom: sm8450: switch to qcom_icc_rpmh_* function
  (bsc#1012628).
- interconnect: qcom: qcm2290: Fix MASTER_SNOC_BIMC_NRT
  (bsc#1012628).
- perf/core: Fix perf_output_begin parameter is incorrectly
  invoked in perf_event_bpf_output (bsc#1012628).
- perf: fix perf_event_context->time (bsc#1012628).
- tracing/hwlat: Replace sched_setaffinity with
  set_cpus_allowed_ptr (bsc#1012628).
- drm/amd/display: fix k1 k2 divider programming for phantom
  streams (bsc#1012628).
- drm/amd/display: Remove OTG DIV register write for Virtual
  signals (bsc#1012628).
- drm/amd/display: Fix DP MST sinks removal issue (bsc#1012628).
- arm64: dts: freescale: imx8-ss-lsio: Fix flexspi clock order
  (bsc#1012628).
- arm64: dts: qcom: sc8280xp: Add label property to vadc channel
  nodes (bsc#1012628).
- arm64: dts: qcom: sm6375: Add missing power-domain-named to CDSP
  (bsc#1012628).
- arm64: dts: qcom: sm8450: correct WSA2 assigned clocks
  (bsc#1012628).
- arm64: dts: qcom: sm8450: Mark UFS controller as cache coherent
  (bsc#1012628).
- power: supply: bq24190: Fix use after free bug in bq24190_remove
  due to race condition (bsc#1012628).
- power: supply: da9150: Fix use after free bug in
  da9150_charger_remove due to race condition (bsc#1012628).
- wifi: mt76: do not run mt76_unregister_device() on unregistered
  hw (bsc#1012628).
- wifi: mt76: connac: do not check WED status for non-mmio devices
  (bsc#1012628).
- efi: earlycon: Reprobe after parsing config tables
  (bsc#1012628).
- arm64: dts: imx8dxl-evk: Disable hibernation mode of AR8031
  for EQOS (bsc#1012628).
- arm64: dts: imx8dxl-evk: Fix eqos phy reset gpio (bsc#1012628).
- ARM: dts: imx6sll: e70k02: fix usbotg1 pinctrl (bsc#1012628).
- ARM: dts: imx6sll: e60k02: fix usbotg1 pinctrl (bsc#1012628).
- ARM: dts: imx6sl: tolino-shine2hd: fix usbotg1 pinctrl
  (bsc#1012628).
- arm64: dts: imx8mn: specify #sound-dai-cells for SAI nodes
  (bsc#1012628).
- arm64: dts: imx93: add missing #address-cells and #size-cells
  to i2c nodes (bsc#1012628).
- NFS: Fix /proc/PID/io read_bytes for buffered reads
  (bsc#1012628).
- NFS: Correct timing for assigning access cache timestamp
  (bsc#1012628).
- xsk: Add missing overflow check in xdp_umem_reg (bsc#1012628).
- iavf: fix inverted Rx hash condition leading to disabled hash
  (bsc#1012628).
- iavf: fix non-tunneled IPv6 UDP packet type and hashing
  (bsc#1012628).
- iavf: do not track VLAN 0 filters (bsc#1012628).
- intel/igbvf: free irq on the error path in igbvf_request_msix()
  (bsc#1012628).
- igbvf: Regard vf reset nack as success (bsc#1012628).
- igc: fix the validation logic for taprio's gate list
  (bsc#1012628).
- i2c: imx-lpi2c: check only for enabled interrupt flags
  (bsc#1012628).
- i2c: mxs: ensure that DMA buffers are safe for DMA
  (bsc#1012628).
- i2c: hisi: Only use the completion interrupt to finish the
  transfer (bsc#1012628).
- scsi: scsi_dh_alua: Fix memleak for 'qdata' in alua_activate()
  (bsc#1012628).
- nfsd: don't replace page in rq_pages if it's a continuation
  of last page (bsc#1012628).
- net: dsa: b53: mmap: fix device tree support (bsc#1012628).
- net: usb: smsc95xx: Limit packet length to skb->len
  (bsc#1012628).
- qed/qed_sriov: guard against NULL derefs from
  qed_iov_get_vf_info (bsc#1012628).
- xirc2ps_cs: Fix use after free bug in xirc2ps_detach
  (bsc#1012628).
- net: phy: Ensure state transitions are processed from phy_stop()
  (bsc#1012628).
- net: mdio: fix owner field for mdio buses registered using
  device-tree (bsc#1012628).
- net: mdio: fix owner field for mdio buses registered using ACPI
  (bsc#1012628).
- net: stmmac: Fix for mismatched host/device DMA address width
  (bsc#1012628).
- thermal/drivers/mellanox: Use generic thermal_zone_get_trip()
  function (bsc#1012628).
- mlxsw: core_thermal: Fix fan speed in maximum cooling state
  (bsc#1012628).
- drm/i915/fbdev: lock the fbdev obj before vma pin (bsc#1012628).
- drm/i915/mtl: Disable MC6 for MTL A step (bsc#1012628).
- drm/i915/guc: Rename GuC register state capture node to be
  more obvious (bsc#1012628).
- drm/i915/guc: Fix missing ecodes (bsc#1012628).
- drm/i915/gt: perform uc late init after probe error injection
  (bsc#1012628).
- drm/i915: Fix format for perf_limit_reasons (bsc#1012628).
- drm/i915: Update vblank timestamping stuff on seamless M/N
  change (bsc#1012628).
- net: dsa: report rx_bytes unadjusted for ETH_HLEN (bsc#1012628).
- net: qcom/emac: Fix use after free bug in emac_remove due to
  race condition (bsc#1012628).
- net: usb: lan78xx: Limit packet length to skb->len
  (bsc#1012628).
- net/ps3_gelic_net: Fix RX sk_buff length (bsc#1012628).
- net/ps3_gelic_net: Use dma_mapping_error (bsc#1012628).
- octeontx2-vf: Add missing free for alloc_percpu (bsc#1012628).
- bootconfig: Fix testcase to increase max node (bsc#1012628).
- keys: Do not cache key in task struct if key is requested from
  kernel thread (bsc#1012628).
- ice: check if VF exists before mode check (bsc#1012628).
- iavf: fix hang on reboot with ice (bsc#1012628).
- i40e: fix flow director packet filter programming (bsc#1012628).
- bpf: Adjust insufficient default bpf_jit_limit (bsc#1012628).
- net/mlx5e: Set uplink rep as NETNS_LOCAL (bsc#1012628).
- net/mlx5e: Block entering switchdev mode with ns inconsistency
  (bsc#1012628).
- net/mlx5: Fix steering rules cleanup (bsc#1012628).
- net/mlx5e: Overcome slow response for first macsec ASO WQE
  (bsc#1012628).
- net/mlx5: Read the TC mapping of all priorities on ETS query
  (bsc#1012628).
- net/mlx5: E-Switch, Fix an Oops in error handling code
  (bsc#1012628).
- net: dsa: tag_brcm: legacy: fix daisy-chained switches
  (bsc#1012628).
- atm: idt77252: fix kmemleak when rmmod idt77252 (bsc#1012628).
- erspan: do not use skb_mac_header() in ndo_start_xmit()
  (bsc#1012628).
- net: mscc: ocelot: fix stats region batching (bsc#1012628).
- net/sonic: use dma_mapping_error() for error check
  (bsc#1012628).
- nvme-tcp: fix nvme_tcp_term_pdu to match spec (bsc#1012628).
- mlxsw: spectrum_fid: Fix incorrect local port type
  (bsc#1012628).
- hvc/xen: prevent concurrent accesses to the shared ring
  (bsc#1012628).
- ksmbd: add low bound validation to FSCTL_SET_ZERO_DATA
  (bsc#1012628).
- ksmbd: add low bound validation to FSCTL_QUERY_ALLOCATED_RANGES
  (bsc#1012628).
- ksmbd: fix possible refcount leak in smb2_open() (bsc#1012628).
- Bluetooth: hci_sync: Resume adv with no RPA when active scan
  (bsc#1012628).
- Bluetooth: hci_core: Detect if an ACL packet is in fact an
  ISO packet (bsc#1012628).
- Bluetooth: btusb: Remove detection of ISO packets over bulk
  (bsc#1012628).
- Bluetooth: ISO: fix timestamped HCI ISO data packet parsing
  (bsc#1012628).
- Bluetooth: Remove "Power-on" check from Mesh feature
  (bsc#1012628).
- gve: Cache link_speed value from device (bsc#1012628).
- net: asix: fix modprobe "sysfs: cannot create duplicate
  filename" (bsc#1012628).
- net: dsa: mt7530: move enabling disabling core clock to
  mt7530_pll_setup() (bsc#1012628).
- net: dsa: mt7530: move lowering TRGMII driving to mt7530_setup()
  (bsc#1012628).
- net: dsa: mt7530: move setting ssc_delta to
  PHY_INTERFACE_MODE_TRGMII case (bsc#1012628).
- net: mdio: thunder: Add missing fwnode_handle_put()
  (bsc#1012628).
- efi/libstub: Use relocated version of kernel's struct
  screen_info (bsc#1012628).
- drm/amd/display: Set dcn32 caps.seamless_odm (bsc#1012628).
- Bluetooth: btqcomsmd: Fix command timeout after setting BD
  address (bsc#1012628).
- Bluetooth: L2CAP: Fix responding with wrong PDU type
  (bsc#1012628).
- Bluetooth: btsdio: fix use after free bug in btsdio_remove
  due to unfinished work (bsc#1012628).
- Bluetooth: mgmt: Fix MGMT add advmon with RSSI command
  (bsc#1012628).
- Bluetooth: HCI: Fix global-out-of-bounds (bsc#1012628).
- platform/chrome: cros_ec_chardev: fix kernel data leak from
  ioctl (bsc#1012628).
- entry: Fix noinstr warning in __enter_from_user_mode()
  (bsc#1012628).
- perf/x86/amd/core: Always clear status for idx (bsc#1012628).
- entry/rcu: Check TIF_RESCHED _after_ delayed RCU wake-up
  (bsc#1012628).
- hwmon: fix potential sensor registration fail if of_node is
  missing (bsc#1012628).
- hwmon (it87): Fix voltage scaling for chips with 10.9mV ADCs
  (bsc#1012628).
- scsi: qla2xxx: Synchronize the IOCB count to be in order
  (bsc#1012628).
- scsi: qla2xxx: Perform lockless command completion in abort path
  (bsc#1012628).
- smb3: lower default deferred close timeout to address perf
  regression (bsc#1012628).
- smb3: fix unusable share after force unmount failure
  (bsc#1012628).
- uas: Add US_FL_NO_REPORT_OPCODES for JMicron JMS583Gen 2
  (bsc#1012628).
- thunderbolt: Use scale field when allocating USB3 bandwidth
  (bsc#1012628).
- thunderbolt: Call tb_check_quirks() after initializing adapters
  (bsc#1012628).
- thunderbolt: Add quirk to disable CLx (bsc#1012628).
- thunderbolt: Fix memory leak in margining (bsc#1012628).
- thunderbolt: Disable interrupt auto clear for rings
  (bsc#1012628).
- thunderbolt: Add missing UNSET_INBOUND_SBTX for retimer access
  (bsc#1012628).
- thunderbolt: Use const qualifier for `ring_interrupt_index`
  (bsc#1012628).
- thunderbolt: Rename shadowed variables bit to interrupt_bit
  and auto_clear_bit (bsc#1012628).
- ASoC: amd: yp: Add OMEN by HP Gaming Laptop 16z-n000 to quirks
  (bsc#1012628).
- ASoC: Intel: sof_rt5682: Add quirk for Rex board with mx98360a
  amplifier (bsc#1012628).
- ASoC: amd: yc: Add DMI entries to support HP OMEN 16-n0xxx
  (8A43) (bsc#1012628).
- ACPI: x86: Drop quirk for HP Elitebook (bsc#1012628).
- ACPI: x86: utils: Add Cezanne to the list for forcing
  StorageD3Enable (bsc#1012628).
- riscv: Bump COMMAND_LINE_SIZE value to 1024 (bsc#1012628).
- drm/cirrus: NULL-check pipe->plane.state->fb in
  cirrus_pipe_update() (bsc#1012628).
- HID: cp2112: Fix driver not registering GPIO IRQ chip as
  threaded (bsc#1012628).
- ca8210: fix mac_len negative array access (bsc#1012628).
- HID: logitech-hidpp: Add support for Logitech MX Master 3S mouse
  (bsc#1012628).
- HID: intel-ish-hid: ipc: Fix potential use-after-free in work
  function (bsc#1012628).
- m68k: mm: Fix systems with memory at end of 32-bit address space
  (bsc#1012628).
- m68k: Only force 030 bus error if PC not in exception table
  (bsc#1012628).
- selftests/bpf: check that modifier resolves after pointer
  (bsc#1012628).
- cpumask: fix incorrect cpumask scanning result checks
  (bsc#1012628).
- scsi: target: iscsi: Fix an error message in iscsi_check_key()
  (bsc#1012628).
- scsi: qla2xxx: Add option to disable FC2 Target support
  (bsc#1012628).
- scsi: hisi_sas: Check devm_add_action() return value
  (bsc#1012628).
- scsi: ufs: core: Add soft dependency on governor_simpleondemand
  (bsc#1012628).
- scsi: lpfc: Check kzalloc() in lpfc_sli4_cgn_params_read()
  (bsc#1012628).
- scsi: lpfc: Avoid usage of list iterator variable after loop
  (bsc#1012628).
- scsi: mpi3mr: Driver unload crashes host when enhanced logging
  is enabled (bsc#1012628).
- scsi: mpi3mr: Wait for diagnostic save during controller init
  (bsc#1012628).
- scsi: mpi3mr: NVMe command size greater than 8K fails
  (bsc#1012628).
- scsi: mpi3mr: Bad drive in topology results kernel crash
  (bsc#1012628).
- scsi: storvsc: Handle BlockSize change in Hyper-V VHD/VHDX file
  (bsc#1012628).
- platform/x86: int3472: Add GPIOs to Surface Go 3 Board data
  (bsc#1012628).
- net: usb: cdc_mbim: avoid altsetting toggling for Telit FE990
  (bsc#1012628).
- net: usb: qmi_wwan: add Telit 0x1080 composition (bsc#1012628).
- drm/amd/display: Update clock table to include highest clock
  setting (bsc#1012628).
- sh: sanitize the flags on sigreturn (bsc#1012628).
- drm/amdgpu: Fix call trace warning and hang when removing
  amdgpu device (bsc#1012628).
- drm/amd: Fix initialization mistake for NBIO 7.3.0
  (bsc#1012628).
- net/sched: act_mirred: better wording on protection against
  excessive stack growth (bsc#1012628).
- act_mirred: use the backlog for nested calls to mirred ingress
  (bsc#1012628).
- cifs: lock chan_lock outside match_session (bsc#1012628).
- cifs: append path to open_enter trace event (bsc#1012628).
- cifs: do not poll server interfaces too regularly (bsc#1012628).
- cifs: empty interface list when server doesn't support query
  interfaces (bsc#1012628).
- cifs: dump pending mids for all channels in DebugData
  (bsc#1012628).
- cifs: print session id while listing open files (bsc#1012628).
- cifs: fix dentry lookups in directory handle cache
  (bsc#1012628).
- x86/mm: Do not shuffle CPU entry areas without KASLR
  (bsc#1012628).
- x86/fpu/xstate: Prevent false-positive warning in
  __copy_xstate_uabi_buf() (bsc#1012628).
- selftests/x86/amx: Add a ptrace test (bsc#1012628).
- scsi: core: Add BLIST_SKIP_VPD_PAGES for SKhynix H28U74301AMR
  (bsc#1012628).
- usb: misc: onboard-hub: add support for Microchip USB2517 USB
  2.0 hub (bsc#1012628).
- usb: dwc2: fix a race, don't power off/on phy for dual-role mode
  (bsc#1012628).
- usb: dwc2: drd: fix inconsistent mode if
  role-switch-default-mode="host" (bsc#1012628).
- usb: dwc2: fix a devres leak in hw_enable upon suspend resume
  (bsc#1012628).
- block/io_uring: pass in issue_flags for uring_cmd task_work
  handling (bsc#1012628).
- usb: gadget: u_audio: don't let userspace block driver unbind
  (bsc#1012628).
- btrfs: zoned: fix btrfs_can_activate_zone() to support DUP
  profile (bsc#1012628).
- Bluetooth: Fix race condition in hci_cmd_sync_clear
  (bsc#1012628).
- efi: sysfb_efi: Fix DMI quirks not working for simpledrm
  (bsc#1012628).
- mm/slab: Fix undefined init_cache_node_node() for NUMA and !SMP
  (bsc#1012628).
- efi/libstub: zboot: Mark zboot EFI application as NX compatible
  (bsc#1012628).
- arm64: efi: Set NX compat flag in PE/COFF header (bsc#1012628).
- fscrypt: destroy keyring after security_sb_delete()
  (bsc#1012628).
- fsverity: Remove WQ_UNBOUND from fsverity read workqueue
  (bsc#1012628).
- lockd: set file_lock start and end when decoding nlm4 testargs
  (bsc#1012628).
- arm64: dts: imx8mm-nitrogen-r2: fix WM8960 clock name
  (bsc#1012628).
- igb: revert rtnl_lock() that causes deadlock (bsc#1012628).
- dm thin: fix deadlock when swapping to thin device
  (bsc#1012628).
- usb: typec: tcpm: fix create duplicate source-capabilities file
  (bsc#1012628).
- usb: typec: tcpm: fix warning when handle discover_identity
  message (bsc#1012628).
- usb: cdns3: Fix issue with using incorrect PCI device function
  (bsc#1012628).
- usb: cdnsp: Fixes issue with redundant Status Stage
  (bsc#1012628).
- usb: cdnsp: changes PCI Device ID to fix conflict with CNDS3
  driver (bsc#1012628).
- usb: chipdea: core: fix return -EINVAL if request role is the
  same with current role (bsc#1012628).
- usb: chipidea: core: fix possible concurrent when switch role
  (bsc#1012628).
- usb: dwc3: gadget: Add 1ms delay after end transfer command
  without IOC (bsc#1012628).
- usb: ucsi: Fix NULL pointer deref in ucsi_connector_change()
  (bsc#1012628).
- usb: ucsi_acpi: Increase the command completion timeout
  (bsc#1012628).
- mm: kfence: fix using kfence_metadata without initialization
  in show_object() (bsc#1012628).
- kfence: avoid passing -g for test (bsc#1012628).
- io_uring/net: avoid sending -ECONNABORTED on repeated connection
  requests (bsc#1012628).
- io_uring/rsrc: fix null-ptr-deref in io_file_bitmap_get()
  (bsc#1012628).
- Revert "kasan: drop skip_kasan_poison variable in
  free_pages_prepare" (bsc#1012628).
- kcsan: avoid passing -g for test (bsc#1012628).
- test_maple_tree: add more testing for mas_empty_area()
  (bsc#1012628).
- maple_tree: fix mas_skip_node() end slot detection
  (bsc#1012628).
- ksmbd: fix wrong signingkey creation when encryption is AES256
  (bsc#1012628).
- ksmbd: set FILE_NAMED_STREAMS attribute in
  FS_ATTRIBUTE_INFORMATION (bsc#1012628).
- ksmbd: don't terminate inactive sessions after a few seconds
  (bsc#1012628).
- ksmbd: return STATUS_NOT_SUPPORTED on unsupported smb2.0 dialect
  (bsc#1012628).
- ksmbd: return unsupported error on smb1 mount (bsc#1012628).
- wifi: mac80211: fix qos on mesh interfaces (bsc#1012628).
- wifi: mac80211: Serialize ieee80211_handle_wake_tx_queue()
  (bsc#1012628).
- nilfs2: fix kernel-infoleak in nilfs_ioctl_wrap_copy()
  (bsc#1012628).
- drm/bridge: lt8912b: return EPROBE_DEFER if bridge is not found
  (bsc#1012628).
- drm/amd/display: fix wrong index used in dccg32_set_dpstreamclk
  (bsc#1012628).
- drm/meson: fix missing component unbind on bind errors
  (bsc#1012628).
- drm/amdgpu/nv: Apply ASPM quirk on Intel ADL + AMD Navi
  (bsc#1012628).
- drm/i915/active: Fix missing debug object activation
  (bsc#1012628).
- drm/i915: Preserve crtc_state->inherited during state clearing
  (bsc#1012628).
- drm/amdgpu: skip ASIC reset for APUs when go to S4
  (bsc#1012628).
- drm/amdgpu: reposition the gpu reset checking for reuse
  (bsc#1012628).
- riscv: mm: Fix incorrect ASID argument when flushing TLB
  (bsc#1012628).
- riscv: Handle zicsr/zifencei issues between clang and binutils
  (bsc#1012628).
- tee: amdtee: fix race condition in amdtee_open_session
  (bsc#1012628).
- firmware: arm_scmi: Fix device node validation for mailbox
  transport (bsc#1012628).
- arm64: dts: qcom: sc8280xp-x13s: mark s11b regulator as
  always-on (bsc#1012628).
- arm64: dts: qcom: sc7280: Mark PCIe controller as cache coherent
  (bsc#1012628).
- arm64: dts: qcom: sm8150: Fix the iommu mask used for PCIe
  controllers (bsc#1012628).
- soc: qcom: llcc: Fix slice configuration values for SC8280XP
  (bsc#1012628).
- mm/ksm: fix race with VMA iteration and mm_struct teardown
  (bsc#1012628).
- bus: imx-weim: fix branch condition evaluates to a garbage value
  (bsc#1012628).
- i2c: xgene-slimpro: Fix out-of-bounds bug in
  xgene_slimpro_i2c_xfer() (bsc#1012628).
- dm stats: check for and propagate alloc_percpu failure
  (bsc#1012628).
- dm crypt: add cond_resched() to dmcrypt_write() (bsc#1012628).
- dm crypt: avoid accessing uninitialized tasklet (bsc#1012628).
- sched/fair: sanitize vruntime of entity being placed
  (bsc#1012628).
- sched/fair: Sanitize vruntime of entity being migrated
  (bsc#1012628).
- commit 7a187a3
* Wed Mar 29 2023 ykaukab@suse.de
- supported.conf: fix typos in module names
- commit cbe8816
* Wed Mar 29 2023 tiwai@suse.de
- Input: alps - fix compatibility with -funsigned-char
  (bsc#1209805).
- commit fb69353
* Wed Mar 29 2023 jslaby@suse.cz
- net/wwan/t7xx: disable Werror (bsc#1209724).
- commit fd61888
* Wed Mar 29 2023 jslaby@suse.cz
- efi/libstub: smbios: Use length member instead of record struct
  size (bsc#1208750).
  Use the patches from upstream to fix the issue.
- commit 94a1030
* Tue Mar 28 2023 tiwai@suse.de
- drm/nouveau/kms: Fix backlight registration (bsc#1209296).
- commit f84ef02
* Tue Mar 28 2023 ykaukab@suse.de
- supported.conf: add missing modules
  Mark most modules as unsupported by default
- commit 994ed9c
* Mon Mar 27 2023 mkubecek@suse.cz
- Update to 6.3-rc4
- eliminate 1 patch
  - patches.suse/arm64-efi-Use-SMBIOS-processor-ID-to-key-off-Altra-q.patch (eb684408f3ea)
- refresh configs
- commit f77c350
* Wed Mar 22 2023 jslaby@suse.cz
- Linux 6.2.8 (bsc#1012628).
- xfrm: Allow transport-mode states with AF_UNSPEC selector
  (bsc#1012628).
- drm/virtio: Pass correct device to dma_sync_sgtable_for_device()
  (bsc#1012628).
- drm/msm/gem: Prevent blocking within shrinker loop
  (bsc#1012628).
- drm/panfrost: Don't sync rpm suspension after mmu flushing
  (bsc#1012628).
- fbdev: chipsfb: Fix error codes in chipsfb_pci_init()
  (bsc#1012628).
- cifs: Move the in_send statistic to __smb_send_rqst()
  (bsc#1012628).
- drm/meson: fix 1px pink line on GXM when scaling video overlay
  (bsc#1012628).
- clk: HI655X: select REGMAP instead of depending on it
  (bsc#1012628).
- selftests: amd-pstate: fix TEST_FILES (bsc#1012628).
- ASoC: SOF: Intel: MTL: Fix the device description (bsc#1012628).
- ASoC: SOF: Intel: HDA: Fix device description (bsc#1012628).
- ASoC: SOF: Intel: SKL: Fix device description (bsc#1012628).
- ASOC: SOF: Intel: pci-tgl: Fix device description (bsc#1012628).
- ASoC: SOF: ipc4-topology: set dmic dai index from copier
  (bsc#1012628).
- docs: Correct missing "d_" prefix for dentry_operations member
  d_weak_revalidate (bsc#1012628).
- scsi: mpt3sas: Fix NULL pointer access in
  mpt3sas_transport_port_add() (bsc#1012628).
- scsi: mpi3mr: Fix throttle_groups memory leak (bsc#1012628).
- scsi: mpi3mr: Fix config page DMA memory leak (bsc#1012628).
- scsi: mpi3mr: Fix mpi3mr_hba_port memory leak in mpi3mr_remove()
  (bsc#1012628).
- scsi: mpi3mr: Fix sas_hba.phy memory leak in mpi3mr_remove()
  (bsc#1012628).
- scsi: mpi3mr: Return proper values for failures in firmware
  init path (bsc#1012628).
- scsi: mpi3mr: Fix memory leaks in mpi3mr_init_ioc()
  (bsc#1012628).
- scsi: mpi3mr: ioctl timeout when disabling/enabling interrupt
  (bsc#1012628).
- scsi: mpi3mr: Fix expander node leak in mpi3mr_remove()
  (bsc#1012628).
- ALSA: hda: Match only Intel devices with CONTROLLER_IN_GPU()
  (bsc#1012628).
- netfilter: nft_nat: correct length for loading protocol
  registers (bsc#1012628).
- netfilter: nft_masq: correct length for loading protocol
  registers (bsc#1012628).
- netfilter: nft_redir: correct length for loading protocol
  registers (bsc#1012628).
- netfilter: nft_redir: correct value of inet type `.maxattrs`
  (bsc#1012628).
- scsi: core: Add BLIST_NO_VPD_SIZE for some VDASD (bsc#1012628).
- scsi: core: Fix a procfs host directory removal regression
  (bsc#1012628).
- ftrace,kcfi: Define ftrace_stub_graph conditionally
  (bsc#1012628).
- tcp: tcp_make_synack() can be called from process context
  (bsc#1012628).
- vdpa/mlx5: should not activate virtq object when suspended
  (bsc#1012628).
- wifi: nl80211: fix NULL-ptr deref in offchan check
  (bsc#1012628).
- wifi: cfg80211: fix MLO connection ownership (bsc#1012628).
- selftests: fix LLVM build for i386 and x86_64 (bsc#1012628).
- nfc: pn533: initialize struct pn533_out_arg properly
  (bsc#1012628).
- ipvlan: Make skb->skb_iif track skb->dev for l3s mode
  (bsc#1012628).
- i40e: Fix kernel crash during reboot when adapter is in recovery
  mode (bsc#1012628).
- vhost-vdpa: free iommu domain after last use during cleanup
  (bsc#1012628).
- vdpa_sim: not reset state in vdpasim_queue_ready (bsc#1012628).
- vdpa_sim: set last_used_idx as last_avail_idx in
  vdpasim_queue_ready (bsc#1012628).
- PCI: s390: Fix use-after-free of PCI resources with per-function
  hotplug (bsc#1012628).
- drm/i915/psr: Use calculated io and fast wake lines
  (bsc#1012628).
- drm/i915/sseu: fix max_subslices array-index-out-of-bounds
  access (bsc#1012628).
- bnxt_en: reset PHC frequency in free-running mode (bsc#1012628).
- net/smc: fix NULL sndbuf_desc in smc_cdc_tx_handler()
  (bsc#1012628).
- qed/qed_dev: guard against a possible division by zero
  (bsc#1012628).
- net: dsa: mt7530: remove now incorrect comment regarding port 5
  (bsc#1012628).
- net: dsa: mt7530: set PLL frequency and trgmii only when trgmii
  is used (bsc#1012628).
- block: do not reverse request order when flushing plug list
  (bsc#1012628).
- loop: Fix use-after-free issues (bsc#1012628).
- blk-mq: fix "bad unlock balance detected" on q->srcu in
  __blk_mq_run_dispatch_ops (bsc#1012628).
- net: tunnels: annotate lockless accesses to dev->needed_headroom
  (bsc#1012628).
- net: phy: smsc: bail out in lan87xx_read_status if
  genphy_read_status fails (bsc#1012628).
- tcp: Fix bind() conflict check for dual-stack wildcard address
  (bsc#1012628).
- nfc: st-nci: Fix use after free bug in ndlc_remove due to race
  condition (bsc#1012628).
- mlxsw: spectrum: Fix incorrect parsing depth after reload
  (bsc#1012628).
- net/smc: fix deadlock triggered by cancel_delayed_work_syn()
  (bsc#1012628).
- net: usb: smsc75xx: Limit packet length to skb->len
  (bsc#1012628).
- net: ethernet: mtk_eth_soc: reset PCS state (bsc#1012628).
- net: ethernet: mtk_eth_soc: only write values if needed
  (bsc#1012628).
- drm/bridge: Fix returned array size name for
  atomic_get_input_bus_fmts kdoc (bsc#1012628).
- block: null_blk: Fix handling of fake timeout request
  (bsc#1012628).
- nvme: fix handling single range discard request (bsc#1012628).
- nvmet: avoid potential UAF in nvmet_req_complete()
  (bsc#1012628).
- block: sunvdc: add check for mdesc_grab() returning NULL
  (bsc#1012628).
- block: count 'ios' and 'sectors' when io is done for bio-based
  device (bsc#1012628).
- net/mlx5e: Fix macsec ASO context alignment (bsc#1012628).
- net/mlx5e: Don't cache tunnel offloads capability (bsc#1012628).
- net/mlx5: Fix setting ec_function bit in MANAGE_PAGES
  (bsc#1012628).
- net/mlx5: Disable eswitch before waiting for VF pages
  (bsc#1012628).
- net/mlx5: E-switch, Fix wrong usage of source port rewrite in
  split rules (bsc#1012628).
- net/mlx5: E-switch, Fix missing set of split_count when forward
  to ovs internal port (bsc#1012628).
- net/mlx5e: Fix cleanup null-ptr deref on encap lock
  (bsc#1012628).
- net/mlx5: Set BREAK_FW_WAIT flag first when removing driver
  (bsc#1012628).
- veth: Fix use after free in XDP_REDIRECT (bsc#1012628).
- ice: xsk: disable txq irq before flushing hw (bsc#1012628).
- net: dsa: don't error out when drivers return ETH_DATA_LEN in
  .port_max_mtu() (bsc#1012628).
- net: dsa: mv88e6xxx: fix max_mtu of 1492 on 6165, 6191, 6220,
  6250, 6290 (bsc#1012628).
- ravb: avoid PHY being resumed when interface is not up
  (bsc#1012628).
- sh_eth: avoid PHY being resumed when interface is not up
  (bsc#1012628).
- ipv4: Fix incorrect table ID in IOCTL path (bsc#1012628).
- net: usb: smsc75xx: Move packet length check to prevent kernel
  panic in skb_pull (bsc#1012628).
- net: atlantic: Fix crash when XDP is enabled but no program
  is loaded (bsc#1012628).
- net/iucv: Fix size of interrupt data (bsc#1012628).
- i825xx: sni_82596: use eth_hw_addr_set() (bsc#1012628).
- selftests: net: devlink_port_split.py: skip test if no suitable
  device available (bsc#1012628).
- qed/qed_mng_tlv: correctly zero out ->min instead of ->hour
  (bsc#1012628).
- net: dsa: microchip: fix RGMII delay configuration on
  KSZ8765/KSZ8794/KSZ8795 (bsc#1012628).
- ethernet: sun: add check for the mdesc_grab() (bsc#1012628).
- net: renesas: rswitch: Rename rings in struct rswitch_gwca_queue
  (bsc#1012628).
- net: renesas: rswitch: Fix the output value of quote from
  rswitch_rx() (bsc#1012628).
- bonding: restore IFF_MASTER/SLAVE flags on bond enslave ether
  type change (bsc#1012628).
- bonding: restore bond's IFF_SLAVE flag if a non-eth dev enslave
  fails (bsc#1012628).
- hwmon: (adt7475) Display smoothing attributes in correct order
  (bsc#1012628).
- hwmon: (adt7475) Fix masking of hysteresis registers
  (bsc#1012628).
- hwmon: (xgene) Fix use after free bug in xgene_hwmon_remove
  due to race condition (bsc#1012628).
- hwmon: (ina3221) return prober error code (bsc#1012628).
- hwmon: (ucd90320) Add minimum delay between bus accesses
  (bsc#1012628).
- hwmon: tmp512: drop of_match_ptr for ID table (bsc#1012628).
- kconfig: Update config changed flag before calling callback
  (bsc#1012628).
- hwmon: (adm1266) Set `can_sleep` flag for GPIO chip
  (bsc#1012628).
- hwmon: (ltc2992) Set `can_sleep` flag for GPIO chip
  (bsc#1012628).
- media: m5mols: fix off-by-one loop termination error
  (bsc#1012628).
- ext4: update s_journal_inum if it changes after journal replay
  (bsc#1012628).
- ext4: fix task hung in ext4_xattr_delete_inode (bsc#1012628).
- drm/amdkfd: Fix an illegal memory access (bsc#1012628).
- net/9p: fix bug in client create for .L (bsc#1012628).
- LoongArch: Only call get_timer_irq() once in
  constant_clockevent_init() (bsc#1012628).
- sh: intc: Avoid spurious sizeof-pointer-div warning
  (bsc#1012628).
- drm/amdgpu: fix ttm_bo calltrace warning in psp_hw_fini
  (bsc#1012628).
- drm/amd/display: fix shift-out-of-bounds in
  CalculateVMAndRowBytes (bsc#1012628).
- ext4: fix possible double unlock when moving a directory
  (bsc#1012628).
- Revert "tty: serial: fsl_lpuart: adjust
  SERIAL_FSL_LPUART_CONSOLE config dependency" (bsc#1012628).
- tty: serial: fsl_lpuart: fix race on RX DMA shutdown
  (bsc#1012628).
- tty: serial: fsl_lpuart: skip waiting for transmission complete
  when UARTCTRL_SBK is asserted (bsc#1012628).
- serial: 8250_em: Fix UART port type (bsc#1012628).
- serial: 8250_fsl: fix handle_irq locking (bsc#1012628).
- serial: 8250: ASPEED_VUART: select REGMAP instead of depending
  on it (bsc#1012628).
- firmware: xilinx: don't make a sleepable memory allocation
  from an atomic context (bsc#1012628).
- memory: tegra: fix interconnect registration race (bsc#1012628).
- memory: tegra20-emc: fix interconnect registration race
  (bsc#1012628).
- memory: tegra124-emc: fix interconnect registration race
  (bsc#1012628).
- memory: tegra30-emc: fix interconnect registration race
  (bsc#1012628).
- drm/ttm: Fix a NULL pointer dereference (bsc#1012628).
- s390/ipl: add missing intersection check to ipl_report handling
  (bsc#1012628).
- interconnect: fix icc_provider_del() error handling
  (bsc#1012628).
- interconnect: fix provider registration API (bsc#1012628).
- interconnect: imx: fix registration race (bsc#1012628).
- interconnect: fix mem leak when freeing nodes (bsc#1012628).
- interconnect: qcom: osm-l3: fix registration race (bsc#1012628).
- interconnect: qcom: rpm: fix probe child-node error handling
  (bsc#1012628).
- interconnect: qcom: rpm: fix registration race (bsc#1012628).
- interconnect: qcom: rpmh: fix probe child-node error handling
  (bsc#1012628).
- interconnect: qcom: rpmh: fix registration race (bsc#1012628).
- interconnect: qcom: msm8974: fix registration race
  (bsc#1012628).
- interconnect: exynos: fix node leak in probe PM QoS error path
  (bsc#1012628).
- interconnect: exynos: fix registration race (bsc#1012628).
- md: select BLOCK_LEGACY_AUTOLOAD (bsc#1012628).
- cifs: generate signkey for the channel that's reconnecting
  (bsc#1012628).
- tracing: Make splice_read available again (bsc#1012628).
- tracing: Do not let histogram values have some modifiers
  (bsc#1012628).
- tracing: Check field value in hist_field_name() (bsc#1012628).
- tracing: Make tracepoint lockdep check actually test something
  (bsc#1012628).
- cifs: Fix smb2_set_path_size() (bsc#1012628).
- cifs: set DFS root session in cifs_get_smb_ses() (bsc#1012628).
- cifs: fix use-after-free bug in refresh_cache_worker()
  (bsc#1012628).
- cifs: return DFS root session id in DebugData (bsc#1012628).
- cifs: use DFS root session instead of tcon ses (bsc#1012628).
- KVM: SVM: Fix a benign off-by-one bug in AVIC physical table
  mask (bsc#1012628).
- KVM: SVM: Modify AVIC GATag to support max number of 512 vCPUs
  (bsc#1012628).
- KVM: nVMX: add missing consistency checks for CR0 and CR4
  (bsc#1012628).
- ALSA: hda: intel-dsp-config: add MTL PCI id (bsc#1012628).
- ALSA: hda/realtek: Fix the speaker output on Samsung Galaxy
  Book2 Pro (bsc#1012628).
- ALSA: hda/realtek: fix speaker, mute/micmute LEDs not work on
  a HP platform (bsc#1012628).
- Revert "riscv: mm: notify remote harts about mmu cache updates"
  (bsc#1012628).
- riscv: asid: Fixup stale TLB entry cause application crash
  (bsc#1012628).
- drm/edid: fix info leak when failing to get panel id
  (bsc#1012628).
- drm/shmem-helper: Remove another errant put in error path
  (bsc#1012628).
- drm/sun4i: fix missing component unbind on bind errors
  (bsc#1012628).
- drm/i915/active: Fix misuse of non-idle barriers as fence
  trackers (bsc#1012628).
- drm/i915/dg2: Add HDMI pixel clock frequencies 267.30 and
  319.89 MHz (bsc#1012628).
- drm/amdgpu: Don't resume IOMMU after incomplete init
  (bsc#1012628).
- drm/amd/pm: Fix sienna cichlid incorrect OD volage after resume
  (bsc#1012628).
- drm/amdgpu/vcn: Disable indirect SRAM on Vangogh broken BIOSes
  (bsc#1012628).
- drm/amd/pm: bump SMU 13.0.4 driver_if header version
  (bsc#1012628).
- drm/amd/display: Do not set DRR on pipe Commit (bsc#1012628).
- drm/amd/display: disconnect MPCC only on OTG change
  (bsc#1012628).
- drm/amd/display: Write to correct dirty_rect (bsc#1012628).
- mptcp: fix possible deadlock in subflow_error_report
  (bsc#1012628).
- mptcp: refactor passive socket initialization (bsc#1012628).
- mptcp: use the workqueue to destroy unaccepted sockets
  (bsc#1012628).
- mptcp: fix UaF in listener shutdown (bsc#1012628).
- mptcp: add ro_after_init for tcp{,v6}_prot_override
  (bsc#1012628).
- mptcp: avoid setting TCP_CLOSE state twice (bsc#1012628).
- mptcp: fix lockdep false positive in
  mptcp_pm_nl_create_listen_socket() (bsc#1012628).
- ftrace: Fix invalid address access in lookup_rec() when index
  is 0 (bsc#1012628).
- ocfs2: fix data corruption after failed write (bsc#1012628).
- nvme-pci: add NVME_QUIRK_BOGUS_NID for Netac NV3000
  (bsc#1012628).
- ice: avoid bonding causing auxiliary plug/unplug under RTNL lock
  (bsc#1012628).
- vp_vdpa: fix the crash in hot unplug with vp_vdpa (bsc#1012628).
- mm/userfaultfd: propagate uffd-wp bit when PTE-mapping the
  huge zeropage (bsc#1012628).
- mm: teach mincore_hugetlb about pte markers (bsc#1012628).
- powerpc/64: Set default CPU in Kconfig (bsc#1012628).
- powerpc/boot: Don't always pass -mcpu=powerpc when building
  32-bit uImage (bsc#1012628).
- mmc: sdhci_am654: lower power-on failed message severity
  (bsc#1012628).
- fbdev: stifb: Provide valid pixelclock and add fb_check_var()
  checks (bsc#1012628).
- trace/hwlat: Do not wipe the contents of per-cpu thread data
  (bsc#1012628).
- trace/hwlat: Do not start per-cpu thread if it is already
  running (bsc#1012628).
- ACPI: PPTT: Fix to avoid sleep in the atomic context when PPTT
  is absent (bsc#1012628).
- net: phy: nxp-c45-tja11xx: fix MII_BASIC_CONFIG_REV bit
  (bsc#1012628).
- fbdev: Fix incorrect page mapping clearance at
  fb_deferred_io_release() (bsc#1012628).
- RISC-V: mm: Support huge page in vmalloc_fault() (bsc#1012628).
- io_uring/msg_ring: let target know allocated index
  (bsc#1012628).
- cpuidle: psci: Iterate backwards over list in psci_pd_remove()
  (bsc#1012628).
- ASoC: Intel: soc-acpi: fix copy-paste issue in topology names
  (bsc#1012628).
- ASoC: qcom: q6prm: fix incorrect clk_root passed to ADSP
  (bsc#1012628).
- x86/mce: Make sure logged MCEs are processed after sysfs update
  (bsc#1012628).
- x86/mm: Fix use of uninitialized buffer in sme_enable()
  (bsc#1012628).
- x86/resctrl: Clear staged_config[] before and after it is used
  (bsc#1012628).
- powerpc: Pass correct CPU reference to assembler (bsc#1012628).
- virt/coco/sev-guest: Check SEV_SNP attribute at probe time
  (bsc#1012628).
- virt/coco/sev-guest: Simplify extended guest request handling
  (bsc#1012628).
- virt/coco/sev-guest: Remove the disable_vmpck label in
  handle_guest_request() (bsc#1012628).
- virt/coco/sev-guest: Carve out the request issuing logic into
  a helper (bsc#1012628).
- virt/coco/sev-guest: Do some code style cleanups (bsc#1012628).
- virt/coco/sev-guest: Convert the sw_exit_info_2 checking to
  a switch-case (bsc#1012628).
- virt/coco/sev-guest: Add throttling awareness (bsc#1012628).
- perf: Fix check before add_event_to_groups() in
  perf_group_detach() (bsc#1012628).
- powerpc: Disable CPU unknown by CLANG when CC_IS_CLANG
  (bsc#1012628).
- powerpc/64: Replace -mcpu=e500mc64 by -mcpu=e5500 (bsc#1012628).
- Update config files.
- commit 221c28f
* Mon Mar 20 2023 msuchanek@suse.de
- Refresh patches.suse/objtool-Check-that-module-init-exit-function-is-an-i.patch.
- commit 0845652
* Mon Mar 20 2023 msuchanek@suse.de
- Refresh patches.suse/powerpc-mm-Fix-false-detection-of-read-faults.patch.
- commit 8c46a8f
* Sun Mar 19 2023 mkubecek@suse.cz
- Update to 6.3-rc3
- eliminate 1 patch
  - patches.suse/powerpc-mm-Fix-false-detection-of-read-faults.patch (f2c7e3562b4c)
- refresh configs
- commit d72bdba
* Fri Mar 17 2023 jslaby@suse.cz
- Linux 6.2.7 (bsc#1012628).
- UML: define RUNTIME_DISCARD_EXIT (bsc#1012628).
- RISC-V: fix taking the text_mutex twice during sifive errata
  patching (bsc#1012628).
- Revert "bpf, test_run: fix &xdp_frame misplacement for
  LIVE_FRAMES" (bsc#1012628).
- filelocks: use mount idmapping for setlease permission check
  (bsc#1012628).
- drm/amd/display: adjust MALL size available for DCN32 and DCN321
  (bsc#1012628).
- drm/amd/display: Allow subvp on vactive pipes that are
  2560x1440@60 (bsc#1012628).
- media: rc: gpio-ir-recv: add remove function (bsc#1012628).
- media: ov5640: Fix analogue gain control (bsc#1012628).
- scripts: handle BrokenPipeError for python scripts
  (bsc#1012628).
- PCI: Add SolidRun vendor ID (bsc#1012628).
- macintosh: windfarm: Use unsigned type for 1-bit bitfields
  (bsc#1012628).
- alpha: fix R_ALPHA_LITERAL reloc for large modules
  (bsc#1012628).
- powerpc/kcsan: Exclude udelay to prevent recursive
  instrumentation (bsc#1012628).
- powerpc/64: Move paca allocation to early_setup() (bsc#1012628).
- powerpc/64: Fix task_cpu in early boot when booting non-zero
  cpuid (bsc#1012628).
- powerpc/bpf/32: Only set a stack frame when necessary
  (bsc#1012628).
- powerpc: Remove __kernel_text_address() in show_instructions()
  (bsc#1012628).
- clk: renesas: rcar-gen3: Disable R-Car H3 ES1.* (bsc#1012628).
- powerpc/iommu: fix memory leak with using debugfs_lookup()
  (bsc#1012628).
- powerpc/64: Don't recurse irq replay (bsc#1012628).
- MIPS: Fix a compilation issue (bsc#1012628).
- tpm/eventlog: Don't abort tpm_read_log on faulty ACPI address
  (bsc#1012628).
- watch_queue: fix IOC_WATCH_QUEUE_SET_SIZE alloc error paths
  (bsc#1012628).
- drm/amdgpu/soc21: Add video cap query support for VCN_4_0_4
  (bsc#1012628).
- drm/amdgpu/soc21: don't expose AV1 if VCN0 is harvested
  (bsc#1012628).
- RISC-V: take text_mutex during alternative patching
  (bsc#1012628).
- ext4: Fix deadlock during directory rename (bsc#1012628).
- drm/amdgpu: fix return value check in kfd (bsc#1012628).
- RISC-V: Don't check text_mutex during stop_machine
  (bsc#1012628).
- riscv: Use READ_ONCE_NOCHECK in imprecise unwinding stack mode
  (bsc#1012628).
- erofs: Revert "erofs: fix kvcalloc() misuse with __GFP_NOFAIL"
  (bsc#1012628).
- af_unix: fix struct pid leaks in OOB support (bsc#1012628).
- net: dsa: mt7530: permit port 5 to work without port 6 on
  MT7621 SoC (bsc#1012628).
- SUNRPC: Fix a server shutdown leak (bsc#1012628).
- octeontx2-af: Unlock contexts in the queue context cache in
  case of fault detection (bsc#1012628).
- net/smc: fix fallback failed while sendmsg with fastopen
  (bsc#1012628).
- ethernet: ice: avoid gcc-9 integer overflow warning
  (bsc#1012628).
- ice: Fix DSCP PFC TLV creation (bsc#1012628).
- NFSD: Protect against filesystem freezing (bsc#1012628).
- block: fix wrong mode for blkdev_put() from
  disk_scan_partitions() (bsc#1012628).
- platform: x86: MLX_PLATFORM: select REGMAP instead of depending
  on it (bsc#1012628).
- platform: mellanox: select REGMAP instead of depending on it
  (bsc#1012628).
- platform/x86: dell-ddv: Fix temperature scaling (bsc#1012628).
- platform/x86: dell-ddv: Return error if buffer is empty
  (bsc#1012628).
- netfilter: conntrack: adopt safer max chain length
  (bsc#1012628).
- scsi: sd: Fix wrong zone_write_granularity value during
  revalidate (bsc#1012628).
- scsi: megaraid_sas: Update max supported LD IDs to 240
  (bsc#1012628).
- net: tls: fix device-offloaded sendpage straddling records
  (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix RX data corruption issue
  (bsc#1012628).
- net: phy: smsc: fix link up detection in forced irq mode
  (bsc#1012628).
- btf: fix resolving BTF_KIND_VAR after ARRAY, STRUCT, UNION,
  PTR (bsc#1012628).
- bpf, test_run: fix &xdp_frame misplacement for LIVE_FRAMES
  (bsc#1012628).
- btrfs: fix extent map logging bit not cleared for split maps
  after dropping range (bsc#1012628).
- m68k: mm: Move initrd phys_to_virt handling after paging_init()
  (bsc#1012628).
- netfilter: tproxy: fix deadlock due to missing BH disable
  (bsc#1012628).
- netfilter: ctnetlink: revert to dumping mark regardless of
  event type (bsc#1012628).
- bnxt_en: Avoid order-5 memory allocation for TPA data
  (bsc#1012628).
- net: phylib: get rid of unnecessary locking (bsc#1012628).
- net: stmmac: add to set device wake up flag when stmmac init
  phy (bsc#1012628).
- drm/msm/dpu: clear DSPP reservations in rm release
  (bsc#1012628).
- drm/msm/disp/dpu: fix sc7280_pp base offset (bsc#1012628).
- drm/msm/dpu: fix clocks settings for msm8998 SSPP blocks
  (bsc#1012628).
- drm/msm/dpu: drop DPU_DIM_LAYER from MIXER_MSM8998_MASK
  (bsc#1012628).
- drm/msm/dpu: correct sm6115 scaler (bsc#1012628).
- drm/msm/dpu: correct sm8250 and sm8350 scaler (bsc#1012628).
- drm/msm/dpu: fix sm6115 and qcm2290 mixer width limits
  (bsc#1012628).
- drm/msm/dpu: fix len of sc7180 ctl blocks (bsc#1012628).
- bpf, sockmap: Fix an infinite loop error when len is 0 in
  tcp_bpf_recvmsg_parser() (bsc#1012628).
- nfp: fix esp-tx-csum-offload doesn't take effect (bsc#1012628).
- nfp: fix incorrectly set csum flag for nfd3 path (bsc#1012628).
- ice: copy last block omitted in ice_get_module_eeprom()
  (bsc#1012628).
- net: caif: Fix use-after-free in cfusbl_device_notify()
  (bsc#1012628).
- net: lan78xx: fix accessing the LAN7800's internal phy specific
  registers from the MAC driver (bsc#1012628).
- perf stat: Fix counting when initial delay configured
  (bsc#1012628).
- net: use indirect calls helpers for sk_exit_memory_pressure()
  (bsc#1012628).
- net: tls: fix possible race condition between
  do_tls_getsockopt_conf() and do_tls_setsockopt_conf()
  (bsc#1012628).
- netfilter: nft_quota: copy content when cloning expression
  (bsc#1012628).
- netfilter: nft_last: copy content when cloning expression
  (bsc#1012628).
- selftests: nft_nat: ensuring the listening side is up before
  starting the client (bsc#1012628).
- net: lan966x: Fix port police support using tc-matchall
  (bsc#1012628).
- ila: do not generate empty messages in
  ila_xlat_nl_cmd_get_mapping() (bsc#1012628).
- drm/msm/dpu: disable features unsupported by QCM2290
  (bsc#1012628).
- tls: rx: fix return value for async crypto (bsc#1012628).
- powerpc: dts: t1040rdb: fix compatible string for Rev A boards
  (bsc#1012628).
- nfc: fdp: add null check of devm_kmalloc_array in
  fdp_nci_i2c_read_device_properties (bsc#1012628).
- bgmac: fix *initial* chip reset to support BCM5358
  (bsc#1012628).
- drm/msm/a5xx: fix context faults during ring switch
  (bsc#1012628).
- drm/msm/a5xx: fix the emptyness check in the preempt code
  (bsc#1012628).
- drm/msm/a5xx: fix highest bank bit for a530 (bsc#1012628).
- drm/msm/a5xx: fix setting of the CP_PREEMPT_ENABLE_LOCAL
  register (bsc#1012628).
- drm/msm: Fix potential invalid ptr free (bsc#1012628).
- drm/nouveau/fb/gp102-: cache scrubber binary on first load
  (bsc#1012628).
- drm/nouveau/kms/nv50: fix nv50_wndw_new_ prototype
  (bsc#1012628).
- ext4: Fix possible corruption when moving a directory
  (bsc#1012628).
- scsi: core: Remove the /proc/scsi/${proc_name} directory earlier
  (bsc#1012628).
- riscv: Add header include guards to insn.h (bsc#1012628).
- block: fix scan partition for exclusively open device again
  (bsc#1012628).
- block: Revert "block: Do not reread partition table on
  exclusively open device" (bsc#1012628).
- drm/i915: Populate encoder->devdata for DSI on icl+
  (bsc#1012628).
- drm/i915: Do panel VBT init early if the VBT declares an
  explicit panel type (bsc#1012628).
- drm/i915: Introduce intel_panel_init_alloc() (bsc#1012628).
- bus: mhi: ep: Change state_lock to mutex (bsc#1012628).
- bus: mhi: ep: Power up/down MHI stack during MHI RESET
  (bsc#1012628).
- udf: Fix off-by-one error when discarding preallocation
  (bsc#1012628).
- KVM: VMX: Do _all_ initialization before exposing /dev/kvm to
  userspace (bsc#1012628).
- KVM: x86: Move guts of kvm_arch_init() to standalone helper
  (bsc#1012628).
- KVM: VMX: Don't bother disabling eVMCS static key on module exit
  (bsc#1012628).
- KVM: VMX: Reset eVMCS controls in VP assist page during hardware
  disabling (bsc#1012628).
- nfc: change order inside nfc_se_io error path (bsc#1012628).
- HID: uhid: Over-ride the default maximum data buffer value
  with our own (bsc#1012628).
- HID: core: Provide new max_buffer_size attribute to over-ride
  the default (bsc#1012628).
- ext4: zero i_disksize when initializing the bootloader inode
  (bsc#1012628).
- ext4: fix WARNING in ext4_update_inline_data (bsc#1012628).
- ext4: move where set the MAY_INLINE_DATA flag is set
  (bsc#1012628).
- ext4: fix another off-by-one fsmap error on 1k block filesystems
  (bsc#1012628).
- ext4: fix RENAME_WHITEOUT handling for inline directories
  (bsc#1012628).
- ext4: fix cgroup writeback accounting with fs-layer encryption
  (bsc#1012628).
- staging: rtl8723bs: Pass correct parameters to
  cfg80211_get_bss() (bsc#1012628).
- staging: rtl8723bs: Fix key-store index handling (bsc#1012628).
- drm/msm/adreno: fix runtime PM imbalance at unbind
  (bsc#1012628).
- drm/connector: print max_requested_bpc in state debugfs
  (bsc#1012628).
- drm/display: Don't block HDR_OUTPUT_METADATA on unknown EOTF
  (bsc#1012628).
- drm/amdgpu: fix error checking in amdgpu_read_mm_registers
  for nv (bsc#1012628).
- drm/amdgpu: fix error checking in amdgpu_read_mm_registers
  for soc21 (bsc#1012628).
- drm/amdgpu: fix error checking in amdgpu_read_mm_registers
  for soc15 (bsc#1012628).
- x86/CPU/AMD: Disable XSAVES on AMD family 0x17 (bsc#1012628).
- thermal: intel: int340x: processor_thermal: Fix deadlock
  (bsc#1012628).
- RISC-V: Stop emitting attributes (bsc#1012628).
- fork: allow CLONE_NEWTIME in clone3 flags (bsc#1012628).
- perf inject: Fix --buildid-all not to eat up MMAP2
  (bsc#1012628).
- erofs: fix wrong kunmap when using LZMA on HIGHMEM platforms
  (bsc#1012628).
- io_uring/uring_cmd: ensure that device supports IOPOLL
  (bsc#1012628).
- btrfs: fix block group item corruption after inserting new
  block group (bsc#1012628).
- btrfs: fix percent calculation for bg reclaim message
  (bsc#1012628).
- btrfs: fix unnecessary increment of read error stat on write
  error (bsc#1012628).
- fs: prevent out-of-bounds array speculation when closing a
  file descriptor (bsc#1012628).
- commit e2e7685
* Thu Mar 16 2023 jslaby@suse.cz
- s390: reintroduce expoline dependence to scripts (s390 expolines
  & fixdep).
- commit a0e8ac4
* Thu Mar 16 2023 shung-hsi.yu@suse.com
- rpm/group-source-files.pl: Fix output difference when / is in location
  While previous attempt to fix group-source-files.pl in 6d651362c38
  "rpm/group-source-files.pl: Deal with {pre,post}fixed / in location"
  breaks the infinite loop, it does not properly address the issue. Having
  prefixed and/or postfixed forward slash still result in different
  output.
  This commit changes the script to use the Perl core module File::Spec
  for proper path manipulation to give consistent output.
- commit 4161bf9
* Tue Mar 14 2023 msuchanek@suse.de
- Require suse-kernel-rpm-scriptlets at all times.
  The kernel packages call scriptlets for each stage, add the dependency
  to make it clear to libzypp that the scriptlets are required.
  There is no special dependency for posttrans, these scriptlets run when
  transactions are resolved. The plain dependency has to be used to
  support posttrans.
- commit 56c4dbe
* Tue Mar 14 2023 msuchanek@suse.de
- Replace mkinitrd dependency with dracut (bsc#1202353).
  Also update mkinitrd refrences in documentation and comments.
- commit e356c9b
* Tue Mar 14 2023 msuchanek@suse.de
- rpm/kernel-obs-build.spec.in: Remove SLE11 cruft
- commit 871eeb4
* Tue Mar 14 2023 mfranc@suse.cz
- Update
  patches.kernel.org/6.2.3-277-rds-rds_rm_zerocopy_callback-correct-order-for-.patch
  (bsc#1012628 bsc#1208601 CVE-2023-1078).
- commit 581e0e0
* Mon Mar 13 2023 mkubecek@suse.cz
- series.conf: whitespace cleanup
- commit af164d0
* Mon Mar 13 2023 jslaby@suse.cz
- Linux 6.2.6 (bsc#1012628).
- staging: rtl8192e: Remove call_usermodehelper starting
  RadioPower.sh (bsc#1012628).
- staging: rtl8192e: Remove function ..dm_check_ac_dc_power
  calling a script (bsc#1012628).
- wifi: cfg80211: Partial revert "wifi: cfg80211: Fix use after
  free for wext" (bsc#1012628).
- tpm: disable hwrng for fTPM on some AMD designs (bsc#1012628).
- commit fa1a4c6
* Mon Mar 13 2023 mkubecek@suse.cz
- Update to 6.3-rc2
- eliminate 1 patch
  - patches.suse/cpumask-fix-incorrect-cpumask-scanning-result-checks.patch
- update configs
  - FEALNX=m (x86, riscv64), =n otherwise (restored from < 6.2-rc1)
- commit 4015adb
* Sat Mar 11 2023 jslaby@suse.cz
- Linux 6.2.5 (bsc#1012628).
- usb: gadget: uvc: fix missing mutex_unlock() if kstrtou8()
  fails (bsc#1012628).
- arm64: efi: Make efi_rt_lock a raw_spinlock (bsc#1012628).
- media: uvcvideo: Fix race condition with usb_kill_urb
  (bsc#1012628).
- drm/i915: Fix system suspend without fbdev being initialized
  (bsc#1012628).
- drm/i915/dp_mst: Fix payload removal during output disabling
  (bsc#1012628).
- drm/display/dp_mst: Handle old/new payload states in
  drm_dp_remove_payload() (bsc#1012628).
- drm/i915/dp_mst: Add the MST topology state for modesetted CRTCs
  (bsc#1012628).
- drm/display/dp_mst: Fix payload addition on a disconnected sink
  (bsc#1012628).
- drm/display/dp_mst: Fix down message handling after a packet
  reception error (bsc#1012628).
- drm/display/dp_mst: Fix down/up message handling after sink
  disconnect (bsc#1012628).
- drm/display/dp_mst: Add drm_atomic_get_old_mst_topology_state()
  (bsc#1012628).
- vDPA/ifcvf: allocate the adapter in dev_add() (bsc#1012628).
- vDPA/ifcvf: manage ifcvf_hw in the mgmt_dev (bsc#1012628).
- vDPA/ifcvf: ifcvf_request_irq works on ifcvf_hw (bsc#1012628).
- vDPA/ifcvf: decouple config/dev IRQ requester and vectors
  allocator from the adapter (bsc#1012628).
- vDPA/ifcvf: decouple vq irq requester from the adapter
  (bsc#1012628).
- vDPA/ifcvf: decouple config IRQ releaser from the adapter
  (bsc#1012628).
- vDPA/ifcvf: decouple vq IRQ releasers from the adapter
  (bsc#1012628).
- vDPA/ifcvf: alloc the mgmt_dev before the adapter (bsc#1012628).
- vDPA/ifcvf: decouple config space ops from the adapter
  (bsc#1012628).
- vDPA/ifcvf: decouple hw features manipulators from the adapter
  (bsc#1012628).
- x86/resctl: fix scheduler confusion with 'current'
  (bsc#1012628).
- net: tls: avoid hanging tasks on the tx_lock (bsc#1012628).
- eth: fealnx: bring back this old driver (bsc#1012628).
- Update config files. (set to pre-6.2 state)
- soundwire: cadence: Drain the RX FIFO after an IO timeout
  (bsc#1012628).
- soundwire: cadence: Remove wasted space in response_buf
  (bsc#1012628).
- RDMA/cma: Distinguish between sockaddr_in and sockaddr_in6 by
  size (bsc#1012628).
- phy: rockchip-typec: Fix unsigned comparison with less than zero
  (bsc#1012628).
- PCI: pciehp: Add Qualcomm quirk for Command Completed erratum
  (bsc#1012628).
- PCI: Add ACS quirk for Wangxun NICs (bsc#1012628).
- PCI: loongson: Add more devices that need MRRS quirk
  (bsc#1012628).
- kernel/fail_function: fix memory leak with using
  debugfs_lookup() (bsc#1012628).
- drivers: base: dd: fix memory leak with using debugfs_lookup()
  (bsc#1012628).
- drivers: base: component: fix memory leak with using
  debugfs_lookup() (bsc#1012628).
- misc: vmw_balloon: fix memory leak with using debugfs_lookup()
  (bsc#1012628).
- tty: pcn_uart: fix memory leak with using debugfs_lookup()
  (bsc#1012628).
- PCI: Distribute available resources for root buses, too
  (bsc#1012628).
- PCI: Take other bus devices into account when distributing
  resources (bsc#1012628).
- PCI: Align extra resources for hotplug bridges properly
  (bsc#1012628).
- usb: gadget: uvc: Make bSourceID read/write (bsc#1012628).
- usb: uvc: Enumerate valid values for color matching
  (bsc#1012628).
- USB: ene_usb6250: Allocate enough memory for full object
  (bsc#1012628).
- usb: host: xhci: mvebu: Iterate over array indexes instead of
  using pointer math (bsc#1012628).
- USB: gadget: pxa27x_udc: fix memory leak with using
  debugfs_lookup() (bsc#1012628).
- USB: gadget: pxa25x_udc: fix memory leak with using
  debugfs_lookup() (bsc#1012628).
- USB: gadget: lpc32xx_udc: fix memory leak with using
  debugfs_lookup() (bsc#1012628).
- USB: gadget: bcm63xx_udc: fix memory leak with using
  debugfs_lookup() (bsc#1012628).
- USB: gadget: gr_udc: fix memory leak with using debugfs_lookup()
  (bsc#1012628).
- USB: isp1362: fix memory leak with using debugfs_lookup()
  (bsc#1012628).
- USB: isp116x: fix memory leak with using debugfs_lookup()
  (bsc#1012628).
- USB: fotg210: fix memory leak with using debugfs_lookup()
  (bsc#1012628).
- USB: sl811: fix memory leak with using debugfs_lookup()
  (bsc#1012628).
- USB: uhci: fix memory leak with using debugfs_lookup()
  (bsc#1012628).
- USB: ULPI: fix memory leak with using debugfs_lookup()
  (bsc#1012628).
- USB: chipidea: fix memory leak with using debugfs_lookup()
  (bsc#1012628).
- USB: dwc3: fix memory leak with using debugfs_lookup()
  (bsc#1012628).
- staging: pi433: fix memory leak with using debugfs_lookup()
  (bsc#1012628).
- PCI: loongson: Prevent LS7A MRRS increases (bsc#1012628).
- PCI/portdrv: Prevent LS7A Bus Master clearing on shutdown
  (bsc#1012628).
- soundwire: bus_type: Avoid lockdep assert in sdw_drv_probe()
  (bsc#1012628).
- media: uvcvideo: Add GUID for BGRA/X 8:8:8:8 (bsc#1012628).
- iio: accel: mma9551_core: Prevent uninitialized variable in
  mma9551_read_config_word() (bsc#1012628).
- iio: accel: mma9551_core: Prevent uninitialized variable in
  mma9551_read_status_word() (bsc#1012628).
- bus: mhi: ep: Fix the debug message for
  MHI_PKT_TYPE_RESET_CHAN_CMD cmd (bsc#1012628).
- tools/iio/iio_utils:fix memory leak (bsc#1012628).
- mei: bus-fixup:upon error print return values of send and
  receive (bsc#1012628).
- serial: sc16is7xx: setup GPIO controller later in probe
  (bsc#1012628).
- tty: serial: fsl_lpuart: disable the CTS when send break signal
  (bsc#1012628).
- tty: fix out-of-bounds access in tty_driver_lookup_tty()
  (bsc#1012628).
- staging: emxx_udc: Add checks for dma_alloc_coherent()
  (bsc#1012628).
- dt-bindings: usb: Add device id for Genesys Logic hub controller
  (bsc#1012628).
- usb: fotg210: List different variants (bsc#1012628).
- cacheinfo: Fix shared_cpu_map to handle shared caches at
  different levels (bsc#1012628).
- USB: fix memory leak with using debugfs_lookup() (bsc#1012628).
- media: uvcvideo: Silence memcpy() run-time false positive
  warnings (bsc#1012628).
- media: uvcvideo: Quirk for autosuspend in Logitech B910 and C910
  (bsc#1012628).
- media: uvcvideo: Handle errors from calls to usb_string
  (bsc#1012628).
- media: uvcvideo: Handle cameras with invalid descriptors
  (bsc#1012628).
- media: uvcvideo: Remove format descriptions (bsc#1012628).
- PCI/ACPI: Account for _S0W of the target bridge in
  acpi_pci_bridge_d3() (bsc#1012628).
- iommu: Remove deferred attach check from __iommu_detach_device()
  (bsc#1012628).
- IB/hfi1: Update RMT size calculation (bsc#1012628).
- mfd: arizona: Use pm_runtime_resume_and_get() to prevent refcnt
  leak (bsc#1012628).
- bootconfig: Increase max nodes of bootconfig from 1024 to 8192
  for DCC support (bsc#1012628).
- firmware/efi sysfb_efi: Add quirk for Lenovo IdeaPad Duet 3
  (bsc#1012628).
- kernel/printk/index.c: fix memory leak with using
  debugfs_lookup() (bsc#1012628).
- tracing: Add NULL checks for buffer in
  ring_buffer_free_read_page() (bsc#1012628).
- cpufreq: apple-soc: Fix an IS_ERR() vs NULL check (bsc#1012628).
- thermal: intel: BXT_PMIC: select REGMAP instead of depending
  on it (bsc#1012628).
- thermal: intel: quark_dts: fix error pointer dereference
  (bsc#1012628).
- ASoC: mediatek: mt8195: add missing initialization
  (bsc#1012628).
- ASoC: zl38060 add gpiolib dependency (bsc#1012628).
- nvme-fabrics: show well known discovery name (bsc#1012628).
- nvme-tcp: don't access released socket during error recovery
  (bsc#1012628).
- nvme: bring back auto-removal of deleted namespaces during
  sequential scan (bsc#1012628).
- ASoC: apple: mca: Improve handling of unavailable DMA channels
  (bsc#1012628).
- ASoC: apple: mca: Fix SERDES reset sequence (bsc#1012628).
- ASoC: apple: mca: Fix final status read on SERDES reset
  (bsc#1012628).
- ASoC: adau7118: don't disable regulators on device unbind
  (bsc#1012628).
- loop: loop_set_status_from_info() check before assignment
  (bsc#1012628).
- io_uring: fix size calculation when registering buf ring
  (bsc#1012628).
- rtc: allow rtc_read_alarm without read_alarm callback
  (bsc#1012628).
- scsi: mpi3mr: Use number of bits to manage bitmap sizes
  (bsc#1012628).
- scsi: mpi3mr: Fix an issue found by KASAN (bsc#1012628).
- scsi: ipr: Work around fortify-string warning (bsc#1012628).
- genirq/ipi: Fix NULL pointer deref in
  irq_data_get_affinity_mask() (bsc#1012628).
- rtc: sun6i: Always export the internal oscillator (bsc#1012628).
- spi: tegra210-quad: Fix iterator outside loop (bsc#1012628).
- vc_screen: modify vcs_size() handling in vcs_read()
  (bsc#1012628).
- tcp: tcp_check_req() can be called from process context
  (bsc#1012628).
- ARM: dts: spear320-hmi: correct STMPE GPIO compatible
  (bsc#1012628).
- ARM: dts: aspeed: p10bmc: Update battery node name
  (bsc#1012628).
- net: dsa: felix: fix internal MDIO controller resource length
  (bsc#1012628).
- net: dsa: seville: ignore mscc-miim read errors from Lynx PCS
  (bsc#1012628).
- net/sched: act_sample: fix action bind logic (bsc#1012628).
- net/sched: act_mpls: fix action bind logic (bsc#1012628).
- net/sched: act_pedit: fix action bind logic (bsc#1012628).
- net/sched: transition act_pedit to rcu and percpu stats
  (bsc#1012628).
- nfc: fix memory leak of se_io context in nfc_genl_se_io
  (bsc#1012628).
- ext4: fix incorrect options show of original mount_opt and
  extend mount_opt2 (bsc#1012628).
- net/mlx5: Geneve, Fix handling of Geneve object id as error code
  (bsc#1012628).
- net/mlx5e: Verify flow_source cap before using it (bsc#1012628).
- net/mlx5: ECPF, wait for VF pages only after disabling host PFs
  (bsc#1012628).
- mlx5: fix possible ptp queue fifo use-after-free (bsc#1012628).
- mlx5: fix skb leak while fifo resync and push (bsc#1012628).
- spi: tegra210-quad: Fix validate combined sequence
  (bsc#1012628).
- 9p/rdma: unmap receive dma buffer in rdma_request()/post_recv()
  (bsc#1012628).
- 9p/xen: fix connection sequence (bsc#1012628).
- 9p/xen: fix version parsing (bsc#1012628).
- net: fix __dev_kfree_skb_any() vs drop monitor (bsc#1012628).
- octeontx2-pf: Use correct struct reference in test condition
  (bsc#1012628).
- sctp: add a refcnt in sctp_stream_priorities to avoid a nested
  loop (bsc#1012628).
- net: sunhme: Fix region request (bsc#1012628).
- octeontx2-pf: Recalculate UDP checksum for ptp 1-step sync
  packet (bsc#1012628).
- drm/i915/xelpmp: Consider GSI offset when doing MCR lookups
  (bsc#1012628).
- ipv6: Add lwtunnel encap size of all siblings in nexthop
  calculation (bsc#1012628).
- drm/i915: move a Kconfig symbol to unbreak the menu presentation
  (bsc#1012628).
- Update config files.
- ptp: vclock: use mutex to fix "sleep on atomic" bug
  (bsc#1012628).
- swiotlb: mark swiotlb_memblock_alloc() as __init (bsc#1012628).
- netfilter: x_tables: fix percpu counter block leak on error
  path when creating new netns (bsc#1012628).
- netfilter: ctnetlink: make event listener tracking global
  (bsc#1012628).
- netfilter: xt_length: use skb len to match in length_mt6
  (bsc#1012628).
- netfilter: ebtables: fix table blob use-after-free
  (bsc#1012628).
- netfilter: ip6t_rpfilter: Fix regression with VRF interfaces
  (bsc#1012628).
- netfilter: conntrack: fix rmmod double-free race (bsc#1012628).
- netfilter: ctnetlink: fix possible refcount leak in
  ctnetlink_create_conntrack() (bsc#1012628).
- watchdog: sbsa_wdog: Make sure the timeout programming is
  within the limits (bsc#1012628).
- watchdog: pcwd_usb: Fix attempting to access uninitialized
  memory (bsc#1012628).
- watchdog: Fix kmemleak in watchdog_cdev_register (bsc#1012628).
- watchdog: at91sam9_wdt: use devm_request_irq to avoid missing
  free_irq() in error path (bsc#1012628).
- watchdog: rzg2l_wdt: Handle TYPE-B reset for RZ/V2M
  (bsc#1012628).
- watchdog: rzg2l_wdt: Issue a reset before we put the PM clocks
  (bsc#1012628).
- f2fs: synchronize atomic write aborts (bsc#1012628).
- um: virt-pci: properly remove PCI device from bus (bsc#1012628).
- um: virtio_uml: move device breaking into workqueue
  (bsc#1012628).
- um: virtio_uml: mark device as unregistered when breaking it
  (bsc#1012628).
- um: virtio_uml: free command if adding to virtqueue failed
  (bsc#1012628).
- x86: um: vdso: Add '%%rcx' and '%%r11' to the syscall clobber list
  (bsc#1012628).
- netfilter: nf_tables: allow to fetch set elements when table
  has an owner (bsc#1012628).
- ext4: don't show commit interval if it is zero (bsc#1012628).
- ext4: use ext4_fc_tl_mem in fast-commit replay path
  (bsc#1012628).
- f2fs: fix to set ipu policy (bsc#1012628).
- f2fs: introduce IS_F2FS_IPU_* macro (bsc#1012628).
- soc: qcom: stats: Populate all subsystem debugfs files
  (bsc#1012628).
- f2fs: fix to update age extent in f2fs_do_zero_range()
  (bsc#1012628).
- f2fs: fix to update age extent correctly during truncation
  (bsc#1012628).
- f2fs: fix to avoid potential memory corruption in
  __update_iostat_latency() (bsc#1012628).
- f2fs: fix to handle F2FS_IOC_START_ATOMIC_REPLACE in
  f2fs_compat_ioctl() (bsc#1012628).
- ubi: ubi_wl_put_peb: Fix infinite loop when wear-leveling work
  failed (bsc#1012628).
- ubi: Fix UAF wear-leveling entry in eraseblk_count_seq_show()
  (bsc#1012628).
- ubi: fastmap: Fix missed fm_anchor PEB in wear-leveling after
  disabling fastmap (bsc#1012628).
- ubifs: ubifs_releasepage: Remove ubifs_assert(0) to valid this
  process (bsc#1012628).
- ubifs: ubifs_writepage: Mark page dirty after writing inode
  failed (bsc#1012628).
- ubifs: dirty_cow_znode: Fix memleak in error handling path
  (bsc#1012628).
- ubifs: Re-statistic cleaned znode count if commit failed
  (bsc#1012628).
- ubi: Fix possible null-ptr-deref in ubi_free_volume()
  (bsc#1012628).
- ubifs: Fix memory leak in alloc_wbufs() (bsc#1012628).
- ubi: Fix unreferenced object reported by kmemleak in
  ubi_resize_volume() (bsc#1012628).
- ubi: Fix use-after-free when volume resizing failed
  (bsc#1012628).
- ubifs: Reserve one leb for each journal head while doing budget
  (bsc#1012628).
- ubifs: do_rename: Fix wrong space budget when target inode's
  nlink > 1 (bsc#1012628).
- ubifs: Fix wrong dirty space budget for dirty inode
  (bsc#1012628).
- ubifs: Rectify space budget for ubifs_xrename() (bsc#1012628).
- ubifs: Rectify space budget for ubifs_symlink() if symlink is
  encrypted (bsc#1012628).
- ubifs: Fix memory leak in ubifs_sysfs_init() (bsc#1012628).
- ubifs: Fix build errors as symbol undefined (bsc#1012628).
- ubi: ensure that VID header offset + VID header size <= alloc,
  size (bsc#1012628).
- um: vector: Fix memory leak in vector_config (bsc#1012628).
- f2fs: fix to abort atomic write only during do_exist()
  (bsc#1012628).
- f2fs: allow set compression option of files without blocks
  (bsc#1012628).
- fs: f2fs: initialize fsdata in pagecache_write() (bsc#1012628).
- f2fs: fix to do sanity check on extent cache correctly
  (bsc#1012628).
- soc: mediatek: mtk-svs: Use pm_runtime_resume_and_get() in
  svs_init01() (bsc#1012628).
- soc: mediatek: mtk-svs: reset svs when svs_resume() fail
  (bsc#1012628).
- soc: mediatek: mtk-svs: restore default voltages when
  svs_init02() fail (bsc#1012628).
- f2fs: clear atomic_write_task in f2fs_abort_atomic_write()
  (bsc#1012628).
- f2fs: introduce trace_f2fs_replace_atomic_write_block
  (bsc#1012628).
- pwm: stm32-lp: fix the check on arr and cmp registers update
  (bsc#1012628).
- pwm: sifive: Always let the first pwm_apply_state succeed
  (bsc#1012628).
- soc: mediatek: mtk-svs: Enable the IRQ later (bsc#1012628).
- memory: renesas-rpc-if: Move resource acquisition to .probe()
  (bsc#1012628).
- memory: renesas-rpc-if: Split-off private data from struct rpcif
  (bsc#1012628).
- soc: qcom: socinfo: Fix soc_id order (bsc#1012628).
- soc: mediatek: mtk-pm-domains: Allow mt8186 ADSP default power
  on (bsc#1012628).
- objtool: Fix memory leak in create_static_call_sections()
  (bsc#1012628).
- f2fs: fix to avoid potential deadlock (bsc#1012628).
- f2fs: don't rely on F2FS_MAP_* in f2fs_iomap_begin
  (bsc#1012628).
- driver: soc: xilinx: fix memory leak in
  xlnx_add_cb_for_notify_event() (bsc#1012628).
- fs/jfs: fix shift exponent db_agl2size negative (bsc#1012628).
- auxdisplay: hd44780: Fix potential memory leak in
  hd44780_remove() (bsc#1012628).
- net/sched: Retire tcindex classifier (bsc#1012628).
- Update config files.
- commit 72ee280
* Sat Mar 11 2023 jslaby@suse.cz
- Linux 6.2.4 (bsc#1012628).
- Revert "blk-cgroup: dropping parent refcount after pd_free_fn()
  is done" (bsc#1012628).
- Revert "blk-cgroup: synchronize pd_free_fn() from
  blkg_free_workfn() and blkcg_deactivate_policy()" (bsc#1012628).
- commit 0532a55
* Sat Mar 11 2023 jslaby@suse.cz
- Update
  patches.kernel.org/6.2.3-264-tap-tap_open-correctly-initialize-socket-uid.patch
  (bsc#1012628 bsc#1208599 CVE-2023-1076).
  Add a CVE reference.
- commit 99340b9
* Fri Mar 10 2023 mkubecek@suse.cz
- series.conf: cleanup
- move an unsortable patch out of sorted section
  patches.suse/powerpc-mm-Fix-false-detection-of-read-faults.patch
- commit 60a3726
* Fri Mar 10 2023 msuchanek@suse.de
- powerpc/mm: Fix false detection of read faults (bsc#1208864).
- commit 6635b6f
* Fri Mar 10 2023 jslaby@suse.cz
- Linux 6.2.3 (bsc#1012628).
- HID: asus: use spinlock to protect concurrent accesses
  (bsc#1012628).
- HID: asus: use spinlock to safely schedule workers
  (bsc#1012628).
- iommu/amd: Fix error handling for pdev_pri_ats_enable()
  (bsc#1012628).
- iommu/amd: Skip attach device domain is same as new domain
  (bsc#1012628).
- iommu/amd: Improve page fault error reporting (bsc#1012628).
- iommu: Attach device group to old domain in error path
  (bsc#1012628).
- powerpc/mm: Rearrange if-else block to avoid clang warning
  (bsc#1012628).
- ata: ahci: Revert "ata: ahci: Add Tiger Lake UP{3,4} AHCI
  controller" (bsc#1012628).
- ARM: OMAP2+: Fix memory leak in realtime_counter_init()
  (bsc#1012628).
- arm64: dts: qcom: qcs404: use symbol names for PCIe resets
  (bsc#1012628).
- arm64: dts: qcom: msm8996-tone: Fix USB taking 6 minutes to
  wake up (bsc#1012628).
- arm64: dts: qcom: sm6115: Fix UFS node (bsc#1012628).
- arm64: dts: qcom: sm6115: Provide xo clk to rpmcc (bsc#1012628).
- arm64: dts: qcom: sm8150-kumano: Panel framebuffer is 2.5k
  instead of 4k (bsc#1012628).
- arm64: dts: qcom: pmi8950: Correct rev_1250v channel label to mv
  (bsc#1012628).
- arm64: dts: qcom: sm6350: Fix up the ramoops node (bsc#1012628).
- arm64: dts: qcom: sdm670-google-sargo: keep pm660 ldo8 on
  (bsc#1012628).
- arm64: dts: qcom: Re-enable resin on MSM8998 and SDM845 boards
  (bsc#1012628).
- arm64: dts: qcom: sm8350-sagami: Configure SLG51000 PMIC on
  PDX215 (bsc#1012628).
- arm64: dts: qcom: sm8350-sagami: Add GPIO line names for PMIC
  GPIOs (bsc#1012628).
- arm64: dts: qcom: sm8350-sagami: Rectify GPIO keys
  (bsc#1012628).
- arm64: dts: qcom: sm6350-lena: Flatten gpio-keys pinctrl state
  (bsc#1012628).
- arm64: dts: qcom: sm6125: Reorder HSUSB PHY clocks to match
  bindings (bsc#1012628).
- arm64: dts: qcom: sm6125-seine: Clean up gpio-keys (volume down)
  (bsc#1012628).
- arm64: dts: imx8m: Align SoC unique ID node unit address
  (bsc#1012628).
- ARM: zynq: Fix refcount leak in zynq_early_slcr_init
  (bsc#1012628).
- fs: dlm: fix return value check in dlm_memory_init()
  (bsc#1012628).
- arm64: dts: mediatek: mt8195: Add power domain to U3PHY1 T-PHY
  (bsc#1012628).
- arm64: dts: mediatek: mt8183: Fix systimer 13 MHz clock
  description (bsc#1012628).
- arm64: dts: mediatek: mt8192: Fix systimer 13 MHz clock
  description (bsc#1012628).
- arm64: dts: mediatek: mt8195: Fix systimer 13 MHz clock
  description (bsc#1012628).
- arm64: dts: mediatek: mt8186: Fix systimer 13 MHz clock
  description (bsc#1012628).
- arm64: dts: qcom: sdm845-db845c: fix audio codec interrupt
  pin name (bsc#1012628).
- arm64: dts: qcom: sdm845-xiaomi-beryllium: fix audio codec
  interrupt pin name (bsc#1012628).
- x86/acpi/boot: Do not register processors that cannot be
  onlined for x2APIC (bsc#1012628).
- arm64: dts: qcom: sc7180: correct SPMI bus address cells
  (bsc#1012628).
- arm64: dts: qcom: sc7280: correct SPMI bus address cells
  (bsc#1012628).
- arm64: dts: qcom: sc8280xp: correct SPMI bus address cells
  (bsc#1012628).
- arm64: dts: qcom: sm8450: correct Soundwire wakeup interrupt
  name (bsc#1012628).
- arm64: dts: qcom: sdm845: make DP node follow the schema
  (bsc#1012628).
- arm64: dts: qcom: msm8996-oneplus-common: drop vdda-supply
  from DSI PHY (bsc#1012628).
- arm64: dts: qcom: sc8280xp: Vote for CX in USB controllers
  (bsc#1012628).
- arm64: dts: meson-gxl: jethub-j80: Fix WiFi MAC address node
  (bsc#1012628).
- arm64: dts: meson-gxl: jethub-j80: Fix Bluetooth MAC node name
  (bsc#1012628).
- arm64: dts: meson-axg: jethub-j1xx: Fix MAC address node names
  (bsc#1012628).
- arm64: dts: meson-gx: Fix Ethernet MAC address unit name
  (bsc#1012628).
- arm64: dts: meson-g12a: Fix internal Ethernet PHY unit name
  (bsc#1012628).
- arm64: dts: meson-gx: Fix the SCPI DVFS node name and unit
  address (bsc#1012628).
- cpuidle, intel_idle: Fix CPUIDLE_FLAG_IRQ_ENABLE *again*
  (bsc#1012628).
- arm64: dts: ti: k3-am62-main: Fix clocks for McSPI
  (bsc#1012628).
- arm64: tegra: Fix duplicate regulator on Jetson TX1
  (bsc#1012628).
- arm64: dts: qcom: msm8992-bullhead: Fix cont_splash_mem size
  (bsc#1012628).
- arm64: dts: qcom: msm8992-bullhead: Disable dfps_data_mem
  (bsc#1012628).
- arm64: dts: qcom: msm8956: use SoC-specific compat for tsens
  (bsc#1012628).
- arm64: dts: qcom: ipq8074: correct USB3 QMP PHY-s clock output
  names (bsc#1012628).
- arm64: dts: qcom: ipq8074: fix Gen2 PCIe QMP PHY (bsc#1012628).
- arm64: dts: qcom: ipq8074: fix Gen3 PCIe QMP PHY (bsc#1012628).
- arm64: dts: qcom: ipq8074: correct Gen2 PCIe ranges
  (bsc#1012628).
- arm64: dts: qcom: ipq8074: fix Gen3 PCIe node (bsc#1012628).
- arm64: dts: qcom: ipq8074: correct PCIe QMP PHY output clock
  names (bsc#1012628).
- arm64: dts: meson: remove CPU opps below 1GHz for G12A boards
  (bsc#1012628).
- ARM: OMAP1: call platform_device_put() in error case in
  omap1_dm_timer_init() (bsc#1012628).
- arm64: dts: mediatek: mt8192: Mark scp_adsp clock as broken
  (bsc#1012628).
- ARM: bcm2835_defconfig: Enable the framebuffer (bsc#1012628).
- ARM: s3c: fix s3c64xx_set_timer_source prototype (bsc#1012628).
- arm64: dts: ti: k3-j7200: Fix wakeup pinmux range (bsc#1012628).
- ARM: dts: exynos: correct wr-active property in Exynos3250
  Rinato (bsc#1012628).
- ARM: imx: Call ida_simple_remove() for ida_simple_get
  (bsc#1012628).
- arm64: dts: amlogic: meson-gx: fix SCPI clock dvfs node name
  (bsc#1012628).
- arm64: dts: amlogic: meson-axg: fix SCPI clock dvfs node name
  (bsc#1012628).
- arm64: dts: amlogic: meson-gx: add missing SCPI sensors
  compatible (bsc#1012628).
- arm64: dts: amlogic: meson-axg-jethome-jethub-j1xx: fix supply
  name of USB controller node (bsc#1012628).
- arm64: dts: amlogic: meson-gxl-s905d-sml5442tw: drop invalid
  clock-names property (bsc#1012628).
- arm64: dts: amlogic: meson-gx: add missing unit address to
  rng node name (bsc#1012628).
- arm64: dts: amlogic: meson-gxl-s905w-jethome-jethub-j80:
  fix invalid rtc node name (bsc#1012628).
- arm64: dts: amlogic: meson-axg-jethome-jethub-j1xx: fix invalid
  rtc node name (bsc#1012628).
- arm64: dts: amlogic: meson-gxl: add missing unit address to
  eth-phy-mux node name (bsc#1012628).
- arm64: dts: amlogic: meson-gx-libretech-pc: fix update button
  name (bsc#1012628).
- arm64: dts: amlogic: meson-sm1-bananapi-m5: fix adc keys node
  names (bsc#1012628).
- arm64: dts: amlogic: meson-gxl-s905d-phicomm-n1: fix led node
  name (bsc#1012628).
- arm64: dts: amlogic: meson-gxbb-kii-pro: fix led node name
  (bsc#1012628).
- arm64: dts: amlogic: meson-g12b-odroid-go-ultra: fix rk818
  pmic properties (bsc#1012628).
- arm64: dts: amlogic: meson-sm1-odroid-hc4: fix active fan
  thermal trip (bsc#1012628).
- locking/rwsem: Disable preemption in all down_read*() and
  up_read() code paths (bsc#1012628).
- arm64: tegra: Mark host1x as dma-coherent on Tegra194/234
  (bsc#1012628).
- arm64: dts: renesas: beacon-renesom: Fix gpio expander reference
  (bsc#1012628).
- arm64: dts: meson: radxa-zero: allow usb otg mode (bsc#1012628).
- arm64: dts: meson: bananapi-m5: switch VDDIO_C pin to OPEN_DRAIN
  (bsc#1012628).
- ARM: dts: sun8i: nanopi-duo2: Fix regulator GPIO reference
  (bsc#1012628).
- ublk_drv: remove nr_aborted_queues from ublk_device
  (bsc#1012628).
- ublk_drv: don't probe partitions if the ubq daemon isn't trusted
  (bsc#1012628).
- ARM: dts: imx7s: correct iomuxc gpr mux controller cells
  (bsc#1012628).
- sbitmap: remove redundant check in __sbitmap_queue_get_batch
  (bsc#1012628).
- sbitmap: correct wake_batch recalculation to avoid potential
  IO hung (bsc#1012628).
- arm64: dts: mt8195: Fix CPU map for single-cluster SoC
  (bsc#1012628).
- arm64: dts: mt8192: Fix CPU map for single-cluster SoC
  (bsc#1012628).
- arm64: dts: mt8186: Fix CPU map for single-cluster SoC
  (bsc#1012628).
- arm64: dts: mediatek: mt7622: Add missing pwm-cells to pwm node
  (bsc#1012628).
- arm64: dts: mediatek: mt8186: Fix watchdog compatible
  (bsc#1012628).
- arm64: dts: mediatek: mt8195: Fix watchdog compatible
  (bsc#1012628).
- arm64: dts: mediatek: mt7986: Fix watchdog compatible
  (bsc#1012628).
- ARM: dts: stm32: Update part number NVMEM description on
  stm32mp131 (bsc#1012628).
- arm64: dts: qcom: sm8450-nagara: Correct firmware paths
  (bsc#1012628).
- blk-mq: avoid sleep in blk_mq_alloc_request_hctx (bsc#1012628).
- blk-mq: remove stale comment for blk_mq_sched_mark_restart_hctx
  (bsc#1012628).
- blk-mq: wait on correct sbitmap_queue in blk_mq_mark_tag_wait
  (bsc#1012628).
- blk-mq: Fix potential io hung for shared sbitmap per tagset
  (bsc#1012628).
- blk-mq: correct stale comment of .get_budget (bsc#1012628).
- arm64: dts: qcom: msm8996: support using GPLL0 as kryocc input
  (bsc#1012628).
- arm64: dts: qcom: msm8996 switch from RPM_SMD_BB_CLK1 to
  RPM_SMD_XO_CLK_SRC (bsc#1012628).
- arm64: dts: qcom: sm8350: drop incorrect cells from serial
  (bsc#1012628).
- arm64: dts: qcom: sm8450: drop incorrect cells from serial
  (bsc#1012628).
- arm64: dts: qcom: msm8992-lg-bullhead: Correct memory overlaps
  with the SMEM and MPSS memory regions (bsc#1012628).
- arm64: dts: qcom: msm8953: correct TLMM gpio-ranges
  (bsc#1012628).
- arm64: dts: qcom: sm6115: correct TLMM gpio-ranges
  (bsc#1012628).
- arm64: dts: qcom: msm8992-lg-bullhead: Enable regulators
  (bsc#1012628).
- s390/dasd: Fix potential memleak in dasd_eckd_init()
  (bsc#1012628).
- io_uring,audit: don't log IORING_OP_MADVISE (bsc#1012628).
- sched/rt: pick_next_rt_entity(): check list_entry (bsc#1012628).
- perf/x86/intel/ds: Fix the conversion from TSC to perf time
  (bsc#1012628).
- x86/perf/zhaoxin: Add stepping check for ZXC (bsc#1012628).
- KEYS: asymmetric: Fix ECDSA use via keyctl uapi (bsc#1012628).
- block: ublk: check IO buffer based on flag need_get_data
  (bsc#1012628).
- arm64: dts: qcom: pmk8350: Use the correct PON compatible
  (bsc#1012628).
- erofs: relinquish volume with mutex held (bsc#1012628).
- block: sync mixed merged request's failfast with 1st bio's
  (bsc#1012628).
- block: Fix io statistics for cgroup in throttle path
  (bsc#1012628).
- block: bio-integrity: Copy flags when bio_integrity_payload
  is cloned (bsc#1012628).
- block: use proper return value from bio_failfast()
  (bsc#1012628).
- wifi: mt76: mt7915: add missing of_node_put() (bsc#1012628).
- wifi: mt76: mt7921s: fix slab-out-of-bounds access in sdio host
  (bsc#1012628).
- wifi: mt76: mt7915: fix mt7915_rate_txpower_get() resource leaks
  (bsc#1012628).
- wifi: mt76: mt7996: fix insecure data handling of
  mt7996_mcu_ie_countdown() (bsc#1012628).
- wifi: mt76: mt7996: fix insecure data handling of
  mt7996_mcu_rx_radar_detected() (bsc#1012628).
- wifi: mt76: mt7996: fix integer handling issue of
  mt7996_rf_regval_set() (bsc#1012628).
- wifi: mt76: mt7915: check return value before accessing
  free_block_num (bsc#1012628).
- wifi: mt76: mt7996: check return value before accessing
  free_block_num (bsc#1012628).
- wifi: mt76: mt7915: drop always true condition of
  __mt7915_reg_addr() (bsc#1012628).
- wifi: mt76: mt7996: drop always true condition of
  __mt7996_reg_addr() (bsc#1012628).
- wifi: mt76: mt7996: fix endianness warning in
  mt7996_mcu_sta_he_tlv (bsc#1012628).
- wifi: mt76: mt76x0: fix oob access in
  mt76x0_phy_get_target_power (bsc#1012628).
- wifi: mt76: mt7996: fix unintended sign extension of
  mt7996_hw_queue_read() (bsc#1012628).
- wifi: mt76: mt7915: fix unintended sign extension of
  mt7915_hw_queue_read() (bsc#1012628).
- wifi: mt76: fix coverity uninit_use_in_call in
  mt76_connac2_reverse_frag0_hdr_trans() (bsc#1012628).
- wifi: mt76: mt7921: resource leaks at
  mt7921_check_offload_capability() (bsc#1012628).
- wifi: rsi: Fix memory leak in rsi_coex_attach() (bsc#1012628).
- wifi: rtlwifi: rtl8821ae: don't call kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- wifi: rtlwifi: rtl8188ee: don't call kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- wifi: rtlwifi: rtl8723be: don't call kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- wifi: iwlegacy: common: don't call dev_kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- wifi: libertas: fix memory leak in lbs_init_adapter()
  (bsc#1012628).
- wifi: rtl8xxxu: Fix assignment to bit field priv->pi_enabled
  (bsc#1012628).
- wifi: rtl8xxxu: Fix assignment to bit field
  priv->cck_agc_report_type (bsc#1012628).
- wifi: rtl8xxxu: don't call dev_kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- wifi: rtw89: 8852c: rfk: correct DACK setting (bsc#1012628).
- wifi: rtw89: 8852c: rfk: correct DPK settings (bsc#1012628).
- wifi: rtlwifi: Fix global-out-of-bounds bug in
  _rtl8812ae_phy_set_txpower_limit() (bsc#1012628).
- libbpf: Fix single-line struct definition output in btf_dump
  (bsc#1012628).
- libbpf: Fix btf__align_of() by taking into account field offsets
  (bsc#1012628).
- wifi: ipw2x00: don't call dev_kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- wifi: ipw2200: fix memory leak in ipw_wdev_init() (bsc#1012628).
- wifi: wilc1000: fix potential memory leak in wilc_mac_xmit()
  (bsc#1012628).
- wifi: wilc1000: add missing unregister_netdev() in
  wilc_netdev_ifc_init() (bsc#1012628).
- wifi: brcmfmac: fix potential memory leak in
  brcmf_netdev_start_xmit() (bsc#1012628).
- wifi: brcmfmac: unmap dma buffer in brcmf_msgbuf_alloc_pktid()
  (bsc#1012628).
- wifi: libertas_tf: don't call kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- wifi: libertas: if_usb: don't call kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- wifi: libertas: main: don't call kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- wifi: libertas: cmdresp: don't call kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- wifi: wl3501_cs: don't call kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- libbpf: Fix invalid return address register in s390
  (bsc#1012628).
- crypto: x86/ghash - fix unaligned access in ghash_setkey()
  (bsc#1012628).
- crypto: ux500 - update debug config after ux500 cryp driver
  removal (bsc#1012628).
- ACPICA: Drop port I/O validation for some regions (bsc#1012628).
- genirq: Fix the return type of kstat_cpu_irqs_sum()
  (bsc#1012628).
- rcu-tasks: Improve comments explaining tasks_rcu_exit_srcu
  purpose (bsc#1012628).
- rcu-tasks: Remove preemption disablement around
  srcu_read_[un]lock() calls (bsc#1012628).
- rcu-tasks: Fix synchronize_rcu_tasks() VS zap_pid_ns_processes()
  (bsc#1012628).
- lib/mpi: Fix buffer overrun when SG is too long (bsc#1012628).
- crypto: ccp - Avoid page allocation failure warning for
  SEV_GET_ID2 (bsc#1012628).
- platform/chrome: cros_ec_typec: Update port DP VDO
  (bsc#1012628).
- ACPICA: nsrepair: handle cases without a return value correctly
  (bsc#1012628).
- libbpf: Fix map creation flags sanitization (bsc#1012628).
- selftests/xsk: print correct payload for packet dump
  (bsc#1012628).
- selftests/xsk: print correct error codes when exiting
  (bsc#1012628).
- arm64/cpufeature: Fix field sign for DIT hwcap detection
  (bsc#1012628).
- arm64/sysreg: Fix errors in 32 bit enumeration values
  (bsc#1012628).
- kselftest/arm64: Fix syscall-abi for systems without 128 bit
  SME (bsc#1012628).
- workqueue: Protects wq_unbound_cpumask with wq_pool_attach_mutex
  (bsc#1012628).
- s390/early: fix sclp_early_sccb variable lifetime (bsc#1012628).
- s390/vfio-ap: fix an error handling path in
  vfio_ap_mdev_probe_queue() (bsc#1012628).
- x86/signal: Fix the value returned by strict_sas_size()
  (bsc#1012628).
- thermal/drivers/tsens: Drop msm8976-specific defines
  (bsc#1012628).
- thermal/drivers/tsens: Sort out msm8976 vs msm8956 data
  (bsc#1012628).
- thermal/drivers/tsens: fix slope values for msm8939
  (bsc#1012628).
- thermal/drivers/tsens: limit num_sensors to 9 for msm8939
  (bsc#1012628).
- wifi: rtw89: fix potential leak in rtw89_append_probe_req_ie()
  (bsc#1012628).
- wifi: rtw89: Add missing check for alloc_workqueue
  (bsc#1012628).
- wifi: rtl8xxxu: Fix memory leaks with RTL8723BU, RTL8192EU
  (bsc#1012628).
- wifi: orinoco: check return value of hermes_write_wordrec()
  (bsc#1012628).
- wifi: rtw88: Use rtw_iterate_vifs() for rtw_vif_watch_dog_iter()
  (bsc#1012628).
- wifi: rtw88: Use non-atomic sta iterator in
  rtw_ra_mask_info_update() (bsc#1012628).
- thermal/drivers/imx_sc_thermal: Fix the loop condition
  (bsc#1012628).
- wifi: ath9k: htc_hst: free skb in ath9k_htc_rx_msg() if there
  is no callback function (bsc#1012628).
- wifi: ath9k: hif_usb: clean up skbs if ath9k_hif_usb_rx_stream()
  fails (bsc#1012628).
- wifi: ath9k: Fix potential stack-out-of-bounds write in
  ath9k_wmi_rsp_callback() (bsc#1012628).
- wifi: ath11k: Fix memory leak in ath11k_peer_rx_frag_setup
  (bsc#1012628).
- wifi: cfg80211: Fix extended KCK key length check in
  nl80211_set_rekey_data() (bsc#1012628).
- ACPI: battery: Fix missing NUL-termination with large strings
  (bsc#1012628).
- selftests/bpf: Fix build errors if CONFIG_NF_CONNTRACK=m
  (bsc#1012628).
- crypto: ccp - Failure on re-initialization due to duplicate
  sysfs filename (bsc#1012628).
- crypto: essiv - Handle EBUSY correctly (bsc#1012628).
- crypto: seqiv - Handle EBUSY correctly (bsc#1012628).
- powercap: fix possible name leak in powercap_register_zone()
  (bsc#1012628).
- bpf: Fix state pruning for STACK_DYNPTR stack slots
  (bsc#1012628).
- bpf: Fix missing var_off check for ARG_PTR_TO_DYNPTR
  (bsc#1012628).
- bpf: Fix partial dynptr stack slot reads/writes (bsc#1012628).
- x86/microcode: Add a parameter to microcode_check() to store
  CPU capabilities (bsc#1012628).
- x86/microcode: Check CPU capabilities after late microcode
  update correctly (bsc#1012628).
- x86/microcode: Adjust late loading result reporting message
  (bsc#1012628).
- net: ethernet: ti: am65-cpsw/cpts: Fix CPTS release action
  (bsc#1012628).
- selftests/bpf: Fix vmtest static compilation error
  (bsc#1012628).
- crypto: xts - Handle EBUSY correctly (bsc#1012628).
- leds: led-class: Add missing put_device() to led_put()
  (bsc#1012628).
- drm/nouveau/disp: Fix nvif_outp_acquire_dp() argument size
  (bsc#1012628).
- s390/bpf: Add expoline to tail calls (bsc#1012628).
- wifi: iwlwifi: mei: fix compilation errors in rfkill()
  (bsc#1012628).
- kselftest/arm64: Fix enumeration of systems without 128 bit SME
  (bsc#1012628).
- can: rcar_canfd: Fix R-Car V3U CAN mode selection (bsc#1012628).
- can: rcar_canfd: Fix R-Car V3U GAFLCFG field accesses
  (bsc#1012628).
- selftests/bpf: Initialize tc in xdp_synproxy (bsc#1012628).
- crypto: ccp - Flush the SEV-ES TMR memory before giving it to
  firmware (bsc#1012628).
- bpftool: profile online CPUs instead of possible (bsc#1012628).
- wifi: mt76: mt7921: fix deadlock in mt7921_abort_roc
  (bsc#1012628).
- wifi: mt76: mt7915: call mt7915_mcu_set_thermal_throttling()
  only after init_work (bsc#1012628).
- wifi: mt76: mt7915: rework mt7915_mcu_set_thermal_throttling
  (bsc#1012628).
- wifi: mt76: mt7915: rework mt7915_thermal_temp_store()
  (bsc#1012628).
- wifi: mt76: mt7921: fix channel switch fail in monitor mode
  (bsc#1012628).
- wifi: mt76: mt7996: fix chainmask calculation in
  mt7996_set_antenna() (bsc#1012628).
- wifi: mt76: mt7996: update register for CFEND_RATE
  (bsc#1012628).
- wifi: mt76: connac: fix POWER_CTRL command name typo
  (bsc#1012628).
- wifi: mt76: mt7921: fix invalid remain_on_channel duration
  (bsc#1012628).
- wifi: mt76: mt7915: fix memory leak in mt7915_mcu_exit
  (bsc#1012628).
- wifi: mt76: mt7996: fix memory leak in mt7996_mcu_exit
  (bsc#1012628).
- wifi: mt76: dma: fix memory leak running mt76_dma_tx_cleanup
  (bsc#1012628).
- wifi: mt76: fix switch default case in
  mt7996_reverse_frag0_hdr_trans (bsc#1012628).
- wifi: mt76: mt7915: fix WED TxS reporting (bsc#1012628).
- wifi: mt76: add memory barrier to SDIO queue kick (bsc#1012628).
- wifi: mt76: mt7921: fix error code of return in mt7921_acpi_read
  (bsc#1012628).
- wifi: mt76: mt7996: rely on mt76_connac2_mac_tx_rate_val
  (bsc#1012628).
- net/mlx5: Enhance debug print in page allocation failure
  (bsc#1012628).
- irqchip: Fix refcount leak in platform_irqchip_probe
  (bsc#1012628).
- irqchip/alpine-msi: Fix refcount leak in
  alpine_msix_init_domains (bsc#1012628).
- irqchip/irq-mvebu-gicp: Fix refcount leak in mvebu_gicp_probe
  (bsc#1012628).
- irqchip/ti-sci: Fix refcount leak in
  ti_sci_intr_irq_domain_probe (bsc#1012628).
- s390/mem_detect: fix detect_memory() error handling
  (bsc#1012628).
- s390/vmem: fix empty page tables cleanup under KASAN
  (bsc#1012628).
- s390/boot: cleanup decompressor header files (bsc#1012628).
- s390/mem_detect: rely on diag260() if sclp_early_get_memsize()
  fails (bsc#1012628).
- s390/boot: fix mem_detect extended area allocation
  (bsc#1012628).
- net: add sock_init_data_uid() (bsc#1012628).
- tun: tun_chr_open(): correctly initialize socket uid
  (bsc#1012628).
- tap: tap_open(): correctly initialize socket uid (bsc#1012628).
- rxrpc: Fix overwaking on call poking (bsc#1012628).
- OPP: fix error checking in opp_migrate_dentry() (bsc#1012628).
- cpufreq: davinci: Fix clk use after free (bsc#1012628).
- Bluetooth: hci_conn: Refactor hci_bind_bis() since it always
  succeeds (bsc#1012628).
- Bluetooth: L2CAP: Fix potential user-after-free (bsc#1012628).
- Bluetooth: hci_qca: get wakeup status from serdev device handle
  (bsc#1012628).
- net: ipa: generic command param fix (bsc#1012628).
- s390: vfio-ap: tighten the NIB validity check (bsc#1012628).
- s390/ap: fix status returned by ap_aqic() (bsc#1012628).
- s390/ap: fix status returned by ap_qact() (bsc#1012628).
- libbpf: Fix alen calculation in libbpf_nla_dump_errormsg()
  (bsc#1012628).
- xen/grant-dma-iommu: Implement a dummy probe_device() callback
  (bsc#1012628).
- rds: rds_rm_zerocopy_callback() correct order for
  list_add_tail() (bsc#1012628).
- crypto: rsa-pkcs1pad - Use akcipher_request_complete
  (bsc#1012628).
- m68k: /proc/hardware should depend on PROC_FS (bsc#1012628).
- RISC-V: time: initialize hrtimer based broadcast clock event
  device (bsc#1012628).
- clocksource/drivers/riscv: Patch riscv_clock_next_event()
  jump before first use (bsc#1012628).
- wifi: iwl3945: Add missing check for
  create_singlethread_workqueue (bsc#1012628).
- wifi: iwl4965: Add missing check for
  create_singlethread_workqueue() (bsc#1012628).
- wifi: brcmfmac: Rename Cypress 89459 to BCM4355 (bsc#1012628).
- wifi: brcmfmac: pcie: Add IDs/properties for BCM4355
  (bsc#1012628).
- wifi: brcmfmac: pcie: Add IDs/properties for BCM4377
  (bsc#1012628).
- wifi: brcmfmac: pcie: Perform correct BCM4364 firmware selection
  (bsc#1012628).
- wifi: mwifiex: fix loop iterator in
  mwifiex_update_ampdu_txwinsize() (bsc#1012628).
- wifi: rtw89: fix parsing offset for MCC C2H (bsc#1012628).
- selftests/bpf: Fix out-of-srctree build (bsc#1012628).
- ACPI: resource: Add IRQ overrides for MAINGEAR Vector Pro 2
  models (bsc#1012628).
- ACPI: resource: Do IRQ override on all TongFang GMxRGxx
  (bsc#1012628).
- crypto: octeontx2 - Fix objects shared between several modules
  (bsc#1012628).
- crypto: crypto4xx - Call dma_unmap_page when done (bsc#1012628).
- vfio/ccw: remove WARN_ON during shutdown (bsc#1012628).
- wifi: mac80211: move color collision detection report in a
  delayed work (bsc#1012628).
- wifi: mac80211: make rate u32 in sta_set_rate_info_rx()
  (bsc#1012628).
- wifi: mac80211: fix non-MLO station association (bsc#1012628).
- wifi: mac80211: Don't translate MLD addresses for multicast
  (bsc#1012628).
- wifi: mac80211: avoid u32_encode_bits() warning (bsc#1012628).
- wifi: mac80211: fix off-by-one link setting (bsc#1012628).
- tools/lib/thermal: Fix thermal_sampling_exit() (bsc#1012628).
- thermal/drivers/hisi: Drop second sensor hi3660 (bsc#1012628).
- selftests/bpf: Fix map_kptr test (bsc#1012628).
- wifi: mac80211: pass 'sta' to ieee80211_rx_data_set_sta()
  (bsc#1012628).
- bpf: Zeroing allocated object from slab in bpf memory allocator
  (bsc#1012628).
- selftests/bpf: Fix xdp_do_redirect on s390x (bsc#1012628).
- can: esd_usb: Move mislocated storage of SJA1000_ECC_SEG bits
  in case of a bus error (bsc#1012628).
- can: esd_usb: Make use of can_change_state() and relocate
  checking skb for NULL (bsc#1012628).
- xsk: check IFF_UP earlier in Tx path (bsc#1012628).
- LoongArch, bpf: Use 4 instructions for function address in JIT
  (bsc#1012628).
- bpf: Fix global subprog context argument resolution logic
  (bsc#1012628).
- irqchip/irq-brcmstb-l2: Set IRQ_LEVEL for level triggered
  interrupts (bsc#1012628).
- irqchip/irq-bcm7120-l2: Set IRQ_LEVEL for level triggered
  interrupts (bsc#1012628).
- net/smc: fix potential panic dues to unprotected
  smc_llc_srv_add_link() (bsc#1012628).
- net/smc: fix application data exception (bsc#1012628).
- selftests/net: Interpret UDP_GRO cmsg data as an int value
  (bsc#1012628).
- l2tp: Avoid possible recursive deadlock in
  l2tp_tunnel_register() (bsc#1012628).
- net: bcmgenet: fix MoCA LED control (bsc#1012628).
- net: lan966x: Fix possible deadlock inside PTP (bsc#1012628).
- net/mlx4_en: Introduce flexible array to silence overflow
  warning (bsc#1012628).
- net/mlx5e: Align IPsec ASO result memory to be as required by
  hardware (bsc#1012628).
- selftest: fib_tests: Always cleanup before exit (bsc#1012628).
- sefltests: netdevsim: wait for devlink instance after netns
  removal (bsc#1012628).
- drm: Fix potential null-ptr-deref due to drmm_mode_config_init()
  (bsc#1012628).
- drm/fourcc: Add missing big-endian XRGB1555 and RGB565 formats
  (bsc#1012628).
- drm/bridge: ti-sn65dsi83: Fix delay after reset deassert to
  match spec (bsc#1012628).
- drm: mxsfb: DRM_IMX_LCDIF should depend on ARCH_MXC
  (bsc#1012628).
- drm: mxsfb: DRM_MXSFB should depend on ARCH_MXS || ARCH_MXC
  (bsc#1012628).
- drm/bridge: megachips: Fix error handling in
  i2c_register_driver() (bsc#1012628).
- drm/vkms: Fix memory leak in vkms_init() (bsc#1012628).
- drm/vkms: Fix null-ptr-deref in vkms_release() (bsc#1012628).
- drm/modes: Use strscpy() to copy command-line mode name
  (bsc#1012628).
- drm/vc4: dpi: Fix format mapping for RGB565 (bsc#1012628).
- drm/bridge: it6505: Guard bridge power in IRQ handler
  (bsc#1012628).
- drm: tidss: Fix pixel format definition (bsc#1012628).
- gpu: ipu-v3: common: Add of_node_put() for reference returned
  by of_graph_get_port_by_id() (bsc#1012628).
- drm/ast: Init iosys_map pointer as I/O memory for damage
  handling (bsc#1012628).
- drm/vc4: drop all currently held locks if deadlock happens
  (bsc#1012628).
- hwmon: (ftsteutates) Fix scaling of measurements (bsc#1012628).
- drm/msm/dpu: check for null return of devm_kzalloc() in
  dpu_writeback_init() (bsc#1012628).
- drm/msm/hdmi: Add missing check for alloc_ordered_workqueue
  (bsc#1012628).
- pinctrl: qcom: pinctrl-msm8976: Correct function names for
  wcss pins (bsc#1012628).
- pinctrl: stm32: Fix refcount leak in stm32_pctrl_get_irq_domain
  (bsc#1012628).
- pinctrl: rockchip: Fix refcount leak in
  rockchip_pinctrl_parse_groups (bsc#1012628).
- drm/vc4: hvs: Configure the HVS COB allocations (bsc#1012628).
- drm/vc4: hvs: Set AXI panic modes (bsc#1012628).
- drm/vc4: hvs: SCALER_DISPBKGND_AUTOHS is only valid on HVS4
  (bsc#1012628).
- drm/vc4: hvs: Correct interrupt masking bit assignment for HVS5
  (bsc#1012628).
- drm/vc4: hvs: Fix colour order for xRGB1555 on HVS5
  (bsc#1012628).
- drm/vc4: hdmi: Correct interlaced timings again (bsc#1012628).
- drm/msm: clean event_thread->worker in case of an error
  (bsc#1012628).
- drm/panel-edp: fix name for IVO product id 854b (bsc#1012628).
- scsi: qla2xxx: Fix exchange oversubscription (bsc#1012628).
- scsi: qla2xxx: Fix exchange oversubscription for management
  commands (bsc#1012628).
- scsi: qla2xxx: edif: Fix clang warning (bsc#1012628).
- ASoC: fsl_sai: initialize is_dsp_mode flag (bsc#1012628).
- drm/bridge: tc358767: Set default CLRSIPO count (bsc#1012628).
- drm/msm/adreno: Fix null ptr access in adreno_gpu_cleanup()
  (bsc#1012628).
- ALSA: hda/ca0132: minor fix for allocation size (bsc#1012628).
- drm/amdgpu: Use the sched from entity for amdgpu_cs trace
  (bsc#1012628).
- drm/msm/gem: Add check for kmalloc (bsc#1012628).
- drm/msm/dpu: Disallow unallocated resources to be returned
  (bsc#1012628).
- drm/bridge: lt9611: fix sleep mode setup (bsc#1012628).
- drm/bridge: lt9611: fix HPD reenablement (bsc#1012628).
- drm/bridge: lt9611: fix polarity programming (bsc#1012628).
- drm/bridge: lt9611: fix programming of video modes
  (bsc#1012628).
- drm/bridge: lt9611: fix clock calculation (bsc#1012628).
- drm/bridge: lt9611: pass a pointer to the of node (bsc#1012628).
- regulator: tps65219: use IS_ERR() to detect an error pointer
  (bsc#1012628).
- drm/mipi-dsi: Fix byte order of 16-bit DCS set/get brightness
  (bsc#1012628).
- drm: exynos: dsi: Fix MIPI_DSI*_NO_* mode flags (bsc#1012628).
- drm/msm/dsi: Allow 2 CTRLs on v2.5.0 (bsc#1012628).
- scsi: ufs: exynos: Fix DMA alignment for PAGE_SIZE != 4096
  (bsc#1012628).
- drm/msm/dpu: sc7180: add missing WB2 clock control
  (bsc#1012628).
- drm/msm: use strscpy instead of strncpy (bsc#1012628).
- drm/msm/dpu: Add check for cstate (bsc#1012628).
- drm/msm/dpu: Add check for pstates (bsc#1012628).
- drm/msm/mdp5: Add check for kzalloc (bsc#1012628).
- habanalabs: bugs fixes in timestamps buff alloc (bsc#1012628).
- pinctrl: bcm2835: Remove of_node_put() in
  bcm2835_of_gpio_ranges_fallback() (bsc#1012628).
- pinctrl: mediatek: Initialize variable pullen and pullup to zero
  (bsc#1012628).
- pinctrl: mediatek: Initialize variable *buf to zero
  (bsc#1012628).
- gpu: host1x: Fix mask for syncpoint increment register
  (bsc#1012628).
- gpu: host1x: Don't skip assigning syncpoints to channels
  (bsc#1012628).
- drm/tegra: firewall: Check for is_addr_reg existence in IMM
  check (bsc#1012628).
- drm/i915/mtl: Add initial gt workarounds (bsc#1012628).
- drm/i915/xehp: GAM registers don't need to be re-applied on
  engine resets (bsc#1012628).
- pinctrl: renesas: rzg2l: Fix configuring the GPIO pins as
  interrupts (bsc#1012628).
- drm/i915/xehp: Annotate a couple more workaround registers as
  MCR (bsc#1012628).
- drm/msm/dpu: set pdpu->is_rt_pipe early in
  dpu_plane_sspp_atomic_update() (bsc#1012628).
- drm/mediatek: dsi: Reduce the time of dsi from LP11 to sending
  cmd (bsc#1012628).
- drm/mediatek: Use NULL instead of 0 for NULL pointer
  (bsc#1012628).
- drm/mediatek: Drop unbalanced obj unref (bsc#1012628).
- drm/mediatek: mtk_drm_crtc: Add checks for devm_kcalloc
  (bsc#1012628).
- drm/mediatek: Clean dangling pointer on bind error path
  (bsc#1012628).
- ASoC: soc-compress.c: fixup private_data on
  snd_soc_new_compress() (bsc#1012628).
- dt-bindings: display: mediatek: Fix the fallback for
  mediatek,mt8186-disp-ccorr (bsc#1012628).
- gpio: pca9570: rename platform_data to chip_data (bsc#1012628).
- gpio: vf610: connect GPIO label to dev name (bsc#1012628).
- ASoC: topology: Properly access value coming from topology file
  (bsc#1012628).
- spi: dw_bt1: fix MUX_MMIO dependencies (bsc#1012628).
- ASoC: mchp-spdifrx: fix controls which rely on rsr register
  (bsc#1012628).
- ASoC: mchp-spdifrx: fix return value in case completion times
  out (bsc#1012628).
- ASoC: mchp-spdifrx: fix controls that works with completion
  mechanism (bsc#1012628).
- ASoC: mchp-spdifrx: disable all interrupts in
  mchp_spdifrx_dai_remove() (bsc#1012628).
- dm: improve shrinker debug names (bsc#1012628).
- regmap: apply reg_base and reg_downshift for single register
  ops (bsc#1012628).
- accel: fix CONFIG_DRM dependencies (bsc#1012628).
- ASoC: rsnd: fixup #endif position (bsc#1012628).
- ASoC: mchp-spdifrx: Fix uninitialized use of mr in
  mchp_spdifrx_hw_params() (bsc#1012628).
- ASoC: dt-bindings: meson: fix gx-card codec node regex
  (bsc#1012628).
- regulator: tps65219: use generic set_bypass() (bsc#1012628).
- hwmon: (asus-ec-sensors) add missing mutex path (bsc#1012628).
- hwmon: (ltc2945) Handle error case in ltc2945_value_store
  (bsc#1012628).
- ALSA: hda: Fix the control element identification for multiple
  codecs (bsc#1012628).
- drm/amdgpu: fix enum odm_combine_mode mismatch (bsc#1012628).
- scsi: mpt3sas: Fix a memory leak (bsc#1012628).
- scsi: aic94xx: Add missing check for dma_map_single()
  (bsc#1012628).
- HID: multitouch: Add quirks for flipped axes (bsc#1012628).
- HID: retain initial quirks set up when creating HID devices
  (bsc#1012628).
- ASoC: qcom: q6apm-lpass-dai: unprepare stream if its already
  prepared (bsc#1012628).
- ASoC: qcom: q6apm-dai: fix race condition while updating the
  position pointer (bsc#1012628).
- ASoC: qcom: q6apm-dai: Add SNDRV_PCM_INFO_BATCH flag
  (bsc#1012628).
- ASoC: codecs: lpass: register mclk after runtime pm
  (bsc#1012628).
- ASoC: codecs: lpass: fix incorrect mclk rate (bsc#1012628).
- drm/amd/display: don't call dc_interrupt_set() for disabled
  crtcs (bsc#1012628).
- HID: logitech-hidpp: Hard-code HID++ 1.0 fast scroll support
  (bsc#1012628).
- spi: bcm63xx-hsspi: Fix multi-bit mode setting (bsc#1012628).
- hwmon: (mlxreg-fan) Return zero speed for broken fan
  (bsc#1012628).
- ASoC: tlv320adcx140: fix 'ti,gpio-config' DT property init
  (bsc#1012628).
- dm: remove flush_scheduled_work() during local_exit()
  (bsc#1012628).
- nfs4trace: fix state manager flag printing (bsc#1012628).
- NFS: fix disabling of swap (bsc#1012628).
- drm/i915/pvc: Implement recommended caching policy
  (bsc#1012628).
- drm/i915/pvc: Annotate two more workaround/tuning registers
  as MCR (bsc#1012628).
- drm/i915: Fix GEN8_MISCCPCTL (bsc#1012628).
- spi: synquacer: Fix timeout handling in
  synquacer_spi_transfer_one() (bsc#1012628).
- ASoC: soc-dapm.h: fixup warning struct snd_pcm_substream not
  declared (bsc#1012628).
- HID: bigben: use spinlock to protect concurrent accesses
  (bsc#1012628).
- HID: bigben_worker() remove unneeded check on report_field
  (bsc#1012628).
- HID: bigben: use spinlock to safely schedule workers
  (bsc#1012628).
- hid: bigben_probe(): validate report count (bsc#1012628).
- ALSA: hda/hdmi: Register with vga_switcheroo on Dual GPU
  Macbooks (bsc#1012628).
- drm/shmem-helper: Fix locking for drm_gem_shmem_get_pages_sgt()
  (bsc#1012628).
- NFSD: enhance inter-server copy cleanup (bsc#1012628).
- NFSD: fix leaked reference count of nfsd4_ssc_umount_item
  (bsc#1012628).
- nfsd: fix race to check ls_layouts (bsc#1012628).
- nfsd: clean up potential nfsd_file refcount leaks in COPY
  codepath (bsc#1012628).
- NFSD: fix problems with cleanup on errors in nfsd4_copy
  (bsc#1012628).
- nfsd: fix courtesy client with deny mode handling in
  nfs4_upgrade_open (bsc#1012628).
- nfsd: don't fsync nfsd_files on last close (bsc#1012628).
- NFSD: copy the whole verifier in nfsd_copy_write_verifier
  (bsc#1012628).
- cifs: Fix lost destroy smbd connection when MR allocate failed
  (bsc#1012628).
- cifs: Fix warning and UAF when destroy the MR list
  (bsc#1012628).
- cifs: use tcon allocation functions even for dummy tcon
  (bsc#1012628).
- gfs2: jdata writepage fix (bsc#1012628).
- perf llvm: Fix inadvertent file creation (bsc#1012628).
- leds: led-core: Fix refcount leak in of_led_get() (bsc#1012628).
- leds: is31fl319x: Wrap mutex_destroy() for
  devm_add_action_or_rest() (bsc#1012628).
- leds: simatic-ipc-leds-gpio: Make sure we have the GPIO
  providing driver (bsc#1012628).
- tools/tracing/rtla: osnoise_hist: use total duration for
  average calculation (bsc#1012628).
- perf inject: Use perf_data__read() for auxtrace (bsc#1012628).
- perf intel-pt: Do not try to queue auxtrace data on pipe
  (bsc#1012628).
- perf stat: Hide invalid uncore event output for aggr mode
  (bsc#1012628).
- perf jevents: Correct bad character encoding (bsc#1012628).
- perf test bpf: Skip test if kernel-debuginfo is not present
  (bsc#1012628).
- perf tools: Fix auto-complete on aarch64 (bsc#1012628).
- perf stat: Avoid merging/aggregating metric counts twice
  (bsc#1012628).
- sparc: allow PM configs for sparc32 COMPILE_TEST (bsc#1012628).
- selftests: find echo binary to use -ne options (bsc#1012628).
- selftests/ftrace: Fix bash specific "==" operator (bsc#1012628).
- selftests: use printf instead of echo -ne (bsc#1012628).
- perf record: Fix segfault with --overwrite and --max-size
  (bsc#1012628).
- printf: fix errname.c list (bsc#1012628).
- perf tests stat_all_metrics: Change true workload to sleep
  workload for system wide check (bsc#1012628).
- objtool: add UACCESS exceptions for __tsan_volatile_read/write
  (bsc#1012628).
- selftests/ftrace: Fix probepoint testcase to ignore __pfx_*
  symbols (bsc#1012628).
- sysctl: fix proc_dobool() usability (bsc#1012628).
- mfd: rk808: Re-add rk808-clkout to RK818 (bsc#1012628).
- mfd: cs5535: Don't build on UML (bsc#1012628).
- mfd: pcf50633-adc: Fix potential memleak in
  pcf50633_adc_async_read() (bsc#1012628).
- dmaengine: idxd: Set traffic class values in GRPCFG on DSA 2.0
  (bsc#1012628).
- RDMA/erdma: Fix refcount leak in erdma_mmap (bsc#1012628).
- dmaengine: HISI_DMA should depend on ARCH_HISI (bsc#1012628).
- RDMA/hns: Fix refcount leak in hns_roce_mmap (bsc#1012628).
- iio: light: tsl2563: Do not hardcode interrupt trigger type
  (bsc#1012628).
- usb: gadget: fusb300_udc: free irq on the error path in
  fusb300_probe() (bsc#1012628).
- i2c: designware: fix i2c_dw_clk_rate() return size to be u32
  (bsc#1012628).
- i2c: qcom-geni: change i2c_master_hub to static (bsc#1012628).
- soundwire: cadence: Don't overflow the command FIFOs
  (bsc#1012628).
- driver core: fix potential null-ptr-deref in device_add()
  (bsc#1012628).
- kobject: Fix slab-out-of-bounds in fill_kobj_path()
  (bsc#1012628).
- alpha/boot/tools/objstrip: fix the check for ELF header
  (bsc#1012628).
- media: uvcvideo: Check for INACTIVE in uvc_ctrl_is_accessible()
  (bsc#1012628).
- media: uvcvideo: Implement mask for V4L2_CTRL_TYPE_MENU
  (bsc#1012628).
- media: uvcvideo: Refactor uvc_ctrl_mappings_uvcXX (bsc#1012628).
- media: uvcvideo: Refactor power_line_frequency_controls_limited
  (bsc#1012628).
- coresight: etm4x: Fix accesses to TRCSEQRSTEVR and TRCSEQSTR
  (bsc#1012628).
- coresight: cti: Prevent negative values of enable count
  (bsc#1012628).
- coresight: cti: Add PM runtime call in enable_store
  (bsc#1012628).
- usb: typec: intel_pmc_mux: Don't leak the ACPI device reference
  count (bsc#1012628).
- PCI/IOV: Enlarge virtfn sysfs name buffer (bsc#1012628).
- PCI: switchtec: Return -EFAULT for copy_to_user() errors
  (bsc#1012628).
- PCI: endpoint: pci-epf-vntb: Add epf_ntb_mw_bar_clear()
  num_mws kernel-doc (bsc#1012628).
- hwtracing: hisi_ptt: Only add the supported devices to the
  filters list (bsc#1012628).
- tty: serial: fsl_lpuart: disable Rx/Tx DMA in
  lpuart32_shutdown() (bsc#1012628).
- tty: serial: fsl_lpuart: clear LPUART Status Register in
  lpuart32_shutdown() (bsc#1012628).
- serial: tegra: Add missing clk_disable_unprepare() in
  tegra_uart_hw_init() (bsc#1012628).
- Revert "char: pcmcia: cm4000_cs: Replace mdelay with
  usleep_range in set_protocol" (bsc#1012628).
- eeprom: idt_89hpesx: Fix error handling in idt_init()
  (bsc#1012628).
- applicom: Fix PCI device refcount leak in applicom_init()
  (bsc#1012628).
- firmware: stratix10-svc: add missing gen_pool_destroy() in
  stratix10_svc_drv_probe() (bsc#1012628).
- firmware: stratix10-svc: fix error handle while alloc/add
  device failed (bsc#1012628).
- VMCI: check context->notify_page after call to
  get_user_pages_fast() to avoid GPF (bsc#1012628).
- mei: pxp: Use correct macros to initialize uuid_le
  (bsc#1012628).
- misc/mei/hdcp: Use correct macros to initialize uuid_le
  (bsc#1012628).
- misc: fastrpc: Fix an error handling path in
  fastrpc_rpmsg_probe() (bsc#1012628).
- iommu/exynos: Fix error handling in exynos_iommu_init()
  (bsc#1012628).
- driver core: fix resource leak in device_add() (bsc#1012628).
- driver core: location: Free struct acpi_pld_info *pld before
  return false (bsc#1012628).
- drivers: base: transport_class: fix possible memory leak
  (bsc#1012628).
- drivers: base: transport_class: fix resource leak when
  transport_add_device() fails (bsc#1012628).
- firmware: dmi-sysfs: Fix null-ptr-deref in
  dmi_sysfs_register_handle (bsc#1012628).
- selftests: iommu: Fix test_cmd_destroy_access() call in
  user_copy (bsc#1012628).
- iommufd: Add three missing structures in ucmd_buffer
  (bsc#1012628).
- fotg210-udc: Add missing completion handler (bsc#1012628).
- dmaengine: dw-edma: Fix missing src/dst address of interleaved
  xfers (bsc#1012628).
- fpga: microchip-spi: move SPI I/O buffers out of stack
  (bsc#1012628).
- fpga: microchip-spi: rewrite status polling in a time measurable
  way (bsc#1012628).
- usb: early: xhci-dbc: Fix a potential out-of-bound memory access
  (bsc#1012628).
- tty: serial: fsl_lpuart: Fix the wrong RXWATER setting for rx
  dma case (bsc#1012628).
- RDMA/cxgb4: add null-ptr-check after ip_dev_find()
  (bsc#1012628).
- usb: musb: mediatek: don't unregister something that wasn't
  registered (bsc#1012628).
- usb: gadget: configfs: Restrict symlink creation is UDC already
  binded (bsc#1012628).
- phy: mediatek: remove temporary variable @mask_ (bsc#1012628).
- PCI: mt7621: Delay phy ports initialization (bsc#1012628).
- iommu/vt-d: Set No Execute Enable bit in PASID table entry
  (bsc#1012628).
- power: supply: remove faulty cooling logic (bsc#1012628).
- RDMA/siw: Fix user page pinning accounting (bsc#1012628).
- RDMA/cxgb4: Fix potential null-ptr-deref in pass_establish()
  (bsc#1012628).
- usb: max-3421: Fix setting of I/O pins (bsc#1012628).
- RDMA/irdma: Cap MSIX used to online CPUs + 1 (bsc#1012628).
- serial: fsl_lpuart: fix RS485 RTS polariy inverse issue
  (bsc#1012628).
- tty: serial: imx: disable Ageing Timer interrupt request irq
  (bsc#1012628).
- driver core: fw_devlink: Add DL_FLAG_CYCLE support to device
  links (bsc#1012628).
- driver core: fw_devlink: Don't purge child fwnode's consumer
  links (bsc#1012628).
- driver core: fw_devlink: Allow marking a fwnode link as being
  part of a cycle (bsc#1012628).
- driver core: fw_devlink: Consolidate device link flag
  computation (bsc#1012628).
- driver core: fw_devlink: Improve check for fwnode with no
  device/driver (bsc#1012628).
- driver core: fw_devlink: Make cycle detection more robust
  (bsc#1012628).
- mtd: mtdpart: Don't create platform device that'll never probe
  (bsc#1012628).
- usb: host: fsl-mph-dr-of: reuse device_set_of_node_from_dev
  (bsc#1012628).
- dmaengine: dw-edma: Fix readq_ch() return value truncation
  (bsc#1012628).
- PCI: Fix dropping valid root bus resources with .end = zero
  (bsc#1012628).
- phy: rockchip-typec: fix tcphy_get_mode error case
  (bsc#1012628).
- PCI: qcom: Fix host-init error handling (bsc#1012628).
- iw_cxgb4: Fix potential NULL dereference in
  c4iw_fill_res_cm_id_entry() (bsc#1012628).
- iommu: Fix error unwind in iommu_group_alloc() (bsc#1012628).
- iommu/amd: Do not identity map v2 capable device when snp is
  enabled (bsc#1012628).
- dmaengine: sf-pdma: pdma_desc memory leak fix (bsc#1012628).
- dmaengine: dw-axi-dmac: Do not dereference NULL structure
  (bsc#1012628).
- dmaengine: ptdma: check for null desc before calling
  pt_cmd_callback (bsc#1012628).
- iommu/vt-d: Fix error handling in sva enable/disable paths
  (bsc#1012628).
- iommu/vt-d: Allow to use flush-queue when first level is default
  (bsc#1012628).
- RDMA/rxe: Cleanup mr_check_range (bsc#1012628).
- RDMA/rxe: Move rxe_map_mr_sg to rxe_mr.c (bsc#1012628).
- RDMA-rxe: Isolate mr code from atomic_reply() (bsc#1012628).
- RDMA-rxe: Isolate mr code from atomic_write_reply()
  (bsc#1012628).
- RDMA/rxe: Cleanup page variables in rxe_mr.c (bsc#1012628).
- RDMA/rxe: Replace rxe_map and rxe_phys_buf by xarray
  (bsc#1012628).
- Subject: RDMA/rxe: Handle zero length rdma (bsc#1012628).
- RDMA/mana_ib: Fix a bug when the PF indicates more entries
  for registering memory on first packet (bsc#1012628).
- RDMA/rxe: Fix missing memory barriers in rxe_queue.h
  (bsc#1012628).
- IB/hfi1: Fix math bugs in hfi1_can_pin_pages() (bsc#1012628).
- IB/hfi1: Fix sdma.h tx->num_descs off-by-one errors
  (bsc#1012628).
- Revert "remoteproc: qcom_q6v5_mss: map/unmap metadata region
  before/after use" (bsc#1012628).
- remoteproc: qcom_q6v5_mss: Use a carveout to authenticate
  modem headers (bsc#1012628).
- media: ti: cal: fix possible memory leak in cal_ctx_create()
  (bsc#1012628).
- media: platform: ti: Add missing check for devm_regulator_get
  (bsc#1012628).
- media: imx: imx7-media-csi: fix missing clk_disable_unprepare()
  in imx7_csi_init() (bsc#1012628).
- powerpc: Remove linker flag from KBUILD_AFLAGS (bsc#1012628).
- s390/vdso: Drop '-shared' from KBUILD_CFLAGS_64 (bsc#1012628).
- builddeb: clean generated package content (bsc#1012628).
- media: max9286: Fix memleak in max9286_v4l2_register()
  (bsc#1012628).
- media: ov2740: Fix memleak in ov2740_init_controls()
  (bsc#1012628).
- media: ov5675: Fix memleak in ov5675_init_controls()
  (bsc#1012628).
- media: i2c: tc358746: fix missing return assignment
  (bsc#1012628).
- media: i2c: tc358746: fix ignoring read error in g_register
  callback (bsc#1012628).
- media: i2c: tc358746: fix possible endianness issue
  (bsc#1012628).
- media: ov5640: Fix soft reset sequence and timings
  (bsc#1012628).
- media: ov5640: Handle delays when no reset_gpio set
  (bsc#1012628).
- media: mc: Get media_device directly from pad (bsc#1012628).
- media: i2c: ov772x: Fix memleak in ov772x_probe() (bsc#1012628).
- media: i2c: imx219: Split common registers from mode tables
  (bsc#1012628).
- media: i2c: imx219: Fix binning for RAW8 capture (bsc#1012628).
- media: platform: mtk-mdp3: Fix return value check in mdp_probe()
  (bsc#1012628).
- media: camss: csiphy-3ph: avoid undefined behavior
  (bsc#1012628).
- media: platform: mtk-mdp3: fix Kconfig dependencies
  (bsc#1012628).
- media: v4l2-jpeg: correct the skip count in
  jpeg_parse_app14_data (bsc#1012628).
- media: v4l2-jpeg: ignore the unknown APP14 marker (bsc#1012628).
- media: hantro: Fix JPEG encoder ENUM_FRMSIZE on RK3399
  (bsc#1012628).
- media: imx-jpeg: Apply clk_bulk api instead of operating
  specific clk (bsc#1012628).
- media: amphion: correct the unspecified color space
  (bsc#1012628).
- media: drivers/media/v4l2-core/v4l2-h264 : add detection of
  null pointers (bsc#1012628).
- media: rc: Fix use-after-free bugs caused by ene_tx_irqsim()
  (bsc#1012628).
- media: atomisp: fix videobuf2 Kconfig depenendency
  (bsc#1012628).
- media: atomisp: Only set default_run_mode on first open of a
  stream/asd (bsc#1012628).
- media: i2c: ov7670: 0 instead of -EINVAL was returned
  (bsc#1012628).
- media: usb: siano: Fix use after free bugs caused by
  do_submit_urb (bsc#1012628).
- media: saa7134: Use video_unregister_device for radio_dev
  (bsc#1012628).
- rpmsg: glink: Avoid infinite loop on intent for missing channel
  (bsc#1012628).
- rpmsg: glink: Release driver_override (bsc#1012628).
- ARM: OMAP2+: omap4-common: Fix refcount leak bug (bsc#1012628).
- arm64: dts: qcom: msm8996: Add additional A2NoC clocks
  (bsc#1012628).
- udf: Define EFSCORRUPTED error code (bsc#1012628).
- context_tracking: Fix noinstr vs KASAN (bsc#1012628).
- exit: Detect and fix irq disabled state in oops (bsc#1012628).
- ARM: dts: exynos: Use Exynos5420 compatible for the MIPI video
  phy (bsc#1012628).
- fs: Use CHECK_DATA_CORRUPTION() when kernel bugs are detected
  (bsc#1012628).
- blk-iocost: fix divide by 0 error in calc_lcoefs()
  (bsc#1012628).
- blk-cgroup: dropping parent refcount after pd_free_fn() is done
  (bsc#1012628).
- blk-cgroup: synchronize pd_free_fn() from blkg_free_workfn()
  and blkcg_deactivate_policy() (bsc#1012628).
- trace/blktrace: fix memory leak with using debugfs_lookup()
  (bsc#1012628).
- btrfs: scrub: improve tree block error reporting (bsc#1012628).
- arm64: zynqmp: Enable hs termination flag for USB dwc3
  controller (bsc#1012628).
- cpuidle, intel_idle: Fix CPUIDLE_FLAG_INIT_XSTATE (bsc#1012628).
- x86/fpu: Don't set TIF_NEED_FPU_LOAD for PF_IO_WORKER threads
  (bsc#1012628).
- cpuidle: drivers: firmware: psci: Dont instrument suspend code
  (bsc#1012628).
- cpuidle: lib/bug: Disable rcu_is_watching() during WARN/BUG
  (bsc#1012628).
- perf/x86/intel/uncore: Add Meteor Lake support (bsc#1012628).
- wifi: ath9k: Fix use-after-free in ath9k_hif_usb_disconnect()
  (bsc#1012628).
- wifi: ath11k: fix monitor mode bringup crash (bsc#1012628).
- wifi: brcmfmac: Fix potential stack-out-of-bounds in
  brcmf_c_preinit_dcmds() (bsc#1012628).
- rcu: Make RCU_LOCKDEP_WARN() avoid early lockdep checks
  (bsc#1012628).
- rcu: Suppress smp_processor_id() complaint in
  synchronize_rcu_expedited_wait() (bsc#1012628).
- srcu: Delegate work to the boot cpu if using SRCU_SIZE_SMALL
  (bsc#1012628).
- rcu-tasks: Make rude RCU-Tasks work well with CPU hotplug
  (bsc#1012628).
- rcu-tasks: Handle queue-shrink/callback-enqueue race condition
  (bsc#1012628).
- wifi: ath11k: debugfs: fix to work with multiple PCI devices
  (bsc#1012628).
- thermal: intel: Fix unsigned comparison with less than zero
  (bsc#1012628).
- timers: Prevent union confusion from unexpected
  restart_syscall() (bsc#1012628).
- x86/bugs: Reset speculation control settings on init
  (bsc#1012628).
- bpftool: Always disable stack protection for BPF objects
  (bsc#1012628).
- wifi: brcmfmac: ensure CLM version is null-terminated to
  prevent stack-out-of-bounds (bsc#1012628).
- wifi: rtw89: fix assignation of TX BD RAM table (bsc#1012628).
- wifi: mt7601u: fix an integer underflow (bsc#1012628).
- inet: fix fast path in __inet_hash_connect() (bsc#1012628).
- ice: restrict PTP HW clock freq adjustments to 100, 000,
  000 PPB (bsc#1012628).
- ice: add missing checks for PF vsi type (bsc#1012628).
- Compiler attributes: GCC cold function alignment workarounds
  (bsc#1012628).
- ACPI: Don't build ACPICA with '-Os' (bsc#1012628).
- bpf, docs: Fix modulo zero, division by zero, overflow, and
  underflow (bsc#1012628).
- thermal: intel: intel_pch: Add support for Wellsburg PCH
  (bsc#1012628).
- clocksource: Suspend the watchdog temporarily when high read
  latency detected (bsc#1012628).
- crypto: hisilicon: Wipe entire pool on error (bsc#1012628).
- net: bcmgenet: Add a check for oversized packets (bsc#1012628).
- m68k: Check syscall_trace_enter() return code (bsc#1012628).
- s390/mm,ptdump: avoid Kasan vs Memcpy Real markers swapping
  (bsc#1012628).
- netfilter: nf_tables: NULL pointer dereference in
  nf_tables_updobj() (bsc#1012628).
- can: isotp: check CAN address family in isotp_bind()
  (bsc#1012628).
- gcc-plugins: drop -std=gnu++11 to fix GCC 13 build
  (bsc#1012628).
- tools/power/x86/intel-speed-select: Add Emerald Rapid quirk
  (bsc#1012628).
- platform/x86: dell-ddv: Add support for interface version 3
  (bsc#1012628).
- wifi: mt76: dma: free rx_head in mt76_dma_rx_cleanup
  (bsc#1012628).
- ACPI: video: Fix Lenovo Ideapad Z570 DMI match (bsc#1012628).
- net/mlx5: fw_tracer: Fix debug print (bsc#1012628).
- coda: Avoid partial allocation of sig_inputArgs (bsc#1012628).
- uaccess: Add minimum bounds check on kernel buffer size
  (bsc#1012628).
- s390/idle: mark arch_cpu_idle() noinstr (bsc#1012628).
- time/debug: Fix memory leak with using debugfs_lookup()
  (bsc#1012628).
- PM: domains: fix memory leak with using debugfs_lookup()
  (bsc#1012628).
- PM: EM: fix memory leak with using debugfs_lookup()
  (bsc#1012628).
- Bluetooth: Fix issue with Actions Semi ATS2851 based devices
  (bsc#1012628).
- Bluetooth: btusb: Add new PID/VID 0489:e0f2 for MT7921
  (bsc#1012628).
- Bluetooth: btusb: Add VID:PID 13d3:3529 for Realtek RTL8821CE
  (bsc#1012628).
- wifi: rtw89: debug: avoid invalid access on RTW89_DBG_SEL_MAC_30
  (bsc#1012628).
- hv_netvsc: Check status in SEND_RNDIS_PKT completion message
  (bsc#1012628).
- s390/kfence: fix page fault reporting (bsc#1012628).
- devlink: Fix TP_STRUCT_entry in trace of devlink health report
  (bsc#1012628).
- scm: add user copy checks to put_cmsg() (bsc#1012628).
- drm: panel-orientation-quirks: Add quirk for Lenovo Yoga Tab
  3 X90F (bsc#1012628).
- drm: panel-orientation-quirks: Add quirk for DynaBook K50
  (bsc#1012628).
- drm/amd/display: Reduce expected sdp bandwidth for dcn321
  (bsc#1012628).
- drm/amd/display: Revert Reduce delay when sink device not able
  to ACK 00340h write (bsc#1012628).
- drm/amd/display: Fix potential null-deref in dm_resume
  (bsc#1012628).
- drm/omap: dsi: Fix excessive stack usage (bsc#1012628).
- HID: Add Mapping for System Microphone Mute (bsc#1012628).
- drm/tiny: ili9486: Do not assume 8-bit only SPI controllers
  (bsc#1012628).
- drm/amd/display: Defer DIG FIFO disable after VID stream enable
  (bsc#1012628).
- drm/radeon: free iio for atombios when driver shutdown
  (bsc#1012628).
- drm/amd: Avoid BUG() for case of SRIOV missing IP version
  (bsc#1012628).
- drm/amdkfd: Page aligned memory reserve size (bsc#1012628).
- scsi: lpfc: Fix use-after-free KFENCE violation during sysfs
  firmware write (bsc#1012628).
- Revert "fbcon: don't lose the console font across generic->chip
  driver switch" (bsc#1012628).
- drm/amd: Avoid ASSERT for some message failures (bsc#1012628).
- drm: amd: display: Fix memory leakage (bsc#1012628).
- drm/amd/display: fix mapping to non-allocated address
  (bsc#1012628).
- HID: uclogic: Add frame type quirk (bsc#1012628).
- HID: uclogic: Add battery quirk (bsc#1012628).
- HID: uclogic: Add support for XP-PEN Deco Pro SW (bsc#1012628).
- HID: uclogic: Add support for XP-PEN Deco Pro MW (bsc#1012628).
- drm/msm/dsi: Add missing check for alloc_ordered_workqueue
  (bsc#1012628).
- drm: rcar-du: Add quirk for H3 ES1.x pclk workaround
  (bsc#1012628).
- drm: rcar-du: Fix setting a reserved bit in DPLLCR
  (bsc#1012628).
- drm/drm_print: correct format problem (bsc#1012628).
- drm/amd/display: Set hvm_enabled flag for S/G mode
  (bsc#1012628).
- drm/client: Test for connectors before sending hotplug event
  (bsc#1012628).
- habanalabs: extend fatal messages to contain PCI info
  (bsc#1012628).
- habanalabs: fix bug in timestamps registration code
  (bsc#1012628).
- docs/scripts/gdb: add necessary make scripts_gdb step
  (bsc#1012628).
- drm/msm/dpu: Add DSC hardware blocks to register snapshot
  (bsc#1012628).
- ASoC: soc-compress: Reposition and add pcm_mutex (bsc#1012628).
- ASoC: kirkwood: Iterate over array indexes instead of using
  pointer math (bsc#1012628).
- regulator: max77802: Bounds check regulator id against opmode
  (bsc#1012628).
- regulator: s5m8767: Bounds check id indexing into arrays
  (bsc#1012628).
- Revert "drm/amdgpu: TA unload messages are not actually sent
  to psp when amdgpu is uninstalled" (bsc#1012628).
- drm/amd/display: fix FCLK pstate change underflow (bsc#1012628).
- gfs2: Improve gfs2_make_fs_rw error handling (bsc#1012628).
- hwmon: (coretemp) Simplify platform device handling
  (bsc#1012628).
- hwmon: (nct6775) Directly call ASUS ACPI WMI method
  (bsc#1012628).
- hwmon: (nct6775) B650/B660/X670 ASUS boards support
  (bsc#1012628).
- pinctrl: at91: use devm_kasprintf() to avoid potential leaks
  (bsc#1012628).
- drm/amd/display: Do not commit pipe when updating DRR
  (bsc#1012628).
- scsi: snic: Fix memory leak with using debugfs_lookup()
  (bsc#1012628).
- scsi: ufs: core: Fix device management cmd timeout flow
  (bsc#1012628).
- HID: logitech-hidpp: Don't restart communication if not
  necessary (bsc#1012628).
- drm/amd/display: Enable P-state validation checks for DCN314
  (bsc#1012628).
- drm: panel-orientation-quirks: Add quirk for Lenovo IdeaPad
  Duet 3 10IGL5 (bsc#1012628).
- drm/amd/display: Disable HUBP/DPP PG on DCN314 for now
  (bsc#1012628).
- drm/amd/display: disable SubVP + DRR to prevent underflow
  (bsc#1012628).
- dm thin: add cond_resched() to various workqueue loops
  (bsc#1012628).
- dm cache: add cond_resched() to various workqueue loops
  (bsc#1012628).
- nfsd: zero out pointers after putting nfsd_files on COPY setup
  error (bsc#1012628).
- nfsd: don't hand out delegation on setuid files being opened
  for write (bsc#1012628).
- cifs: prevent data race in smb2_reconnect() (bsc#1012628).
- drm/i915/mtl: Correct implementation of Wa_18018781329
  (bsc#1012628).
- drm/shmem-helper: Revert accidental non-GPL export
  (bsc#1012628).
- driver core: fw_devlink: Avoid spurious error message
  (bsc#1012628).
- wifi: rtl8xxxu: fixing transmisison failure for rtl8192eu
  (bsc#1012628).
- firmware: coreboot: framebuffer: Ignore reserved pixel color
  bits (bsc#1012628).
- block: don't allow multiple bios for IOCB_NOWAIT issue
  (bsc#1012628).
- block: clear bio->bi_bdev when putting a bio back in the cache
  (bsc#1012628).
- block: be a bit more careful in checking for NULL bdev while
  polling (bsc#1012628).
- rtc: pm8xxx: fix set-alarm race (bsc#1012628).
- ipmi: ipmb: Fix the MODULE_PARM_DESC associated to
  'retry_time_ms' (bsc#1012628).
- ipmi:ssif: resend_msg() cannot fail (bsc#1012628).
- ipmi_ssif: Rename idle state and check (bsc#1012628).
- ipmi:ssif: Add a timer between request retries (bsc#1012628).
- io_uring: Replace 0-length array with flexible array
  (bsc#1012628).
- io_uring: use user visible tail in io_uring_poll()
  (bsc#1012628).
- io_uring: handle TIF_NOTIFY_RESUME when checking for task_work
  (bsc#1012628).
- io_uring: add a conditional reschedule to the IOPOLL cancelation
  loop (bsc#1012628).
- io_uring: add reschedule point to handle_tw_list()
  (bsc#1012628).
- io_uring/rsrc: disallow multi-source reg buffers (bsc#1012628).
- io_uring: remove MSG_NOSIGNAL from recvmsg (bsc#1012628).
- io_uring/poll: allow some retries for poll triggering spuriously
  (bsc#1012628).
- io_uring: fix fget leak when fs don't support nowait buffered
  read (bsc#1012628).
- s390/extmem: return correct segment type in __segment_load()
  (bsc#1012628).
- s390: discard .interp section (bsc#1012628).
- s390/ipl: add DEFINE_GENERIC_LOADPARM() (bsc#1012628).
- s390/ipl: add loadparm parameter to eckd ipl/reipl data
  (bsc#1012628).
- s390/kprobes: fix irq mask clobbering on kprobe reenter from
  post_handler (bsc#1012628).
- s390/kprobes: fix current_kprobe never cleared after kprobes
  reenter (bsc#1012628).
- KVM: s390: disable migration mode when dirty tracking is
  disabled (bsc#1012628).
- cifs: improve checking of DFS links over
  STATUS_OBJECT_NAME_INVALID (bsc#1012628).
- cifs: Fix uninitialized memory read in smb3_qfs_tcon()
  (bsc#1012628).
- cifs: Fix uninitialized memory reads for oparms.mode
  (bsc#1012628).
- cifs: fix mount on old smb servers (bsc#1012628).
- cifs: introduce cifs_io_parms in smb2_async_writev()
  (bsc#1012628).
- cifs: split out smb3_use_rdma_offload() helper (bsc#1012628).
- cifs: don't try to use rdma offload on encrypted connections
  (bsc#1012628).
- cifs: Check the lease context if we actually got a lease
  (bsc#1012628).
- cifs: return a single-use cfid if we did not get a lease
  (bsc#1012628).
- scsi: mpi3mr: Fix missing mrioc->evtack_cmds initialization
  (bsc#1012628).
- scsi: mpi3mr: Fix issues in mpi3mr_get_all_tgt_info()
  (bsc#1012628).
- scsi: mpi3mr: Remove unnecessary memcpy() to alltgt_info->dmi
  (bsc#1012628).
- btrfs: hold block group refcount during async discard
  (bsc#1012628).
- btrfs: sysfs: update fs features directory asynchronously
  (bsc#1012628).
- locking/rwsem: Prevent non-first waiter from spinning in
  down_write() slowpath (bsc#1012628).
- ksmbd: fix wrong data area length for smb2 lock request
  (bsc#1012628).
- ksmbd: do not allow the actual frame length to be smaller than
  the rfc1002 length (bsc#1012628).
- ksmbd: fix possible memory leak in smb2_lock() (bsc#1012628).
- torture: Fix hang during kthread shutdown phase (bsc#1012628).
- ARM: dts: exynos: correct HDMI phy compatible in Exynos4
  (bsc#1012628).
- io_uring: mark task TASK_RUNNING before handling resume/task
  work (bsc#1012628).
- hfs: fix missing hfs_bnode_get() in __hfs_bnode_create
  (bsc#1012628).
- fs: hfsplus: fix UAF issue in hfsplus_put_super (bsc#1012628).
- exfat: fix reporting fs error when reading dir beyond EOF
  (bsc#1012628).
- exfat: fix unexpected EOF while reading dir (bsc#1012628).
- exfat: redefine DIR_DELETED as the bad cluster number
  (bsc#1012628).
- exfat: fix inode->i_blocks for non-512 byte sector size device
  (bsc#1012628).
- fs: dlm: start midcomms before scand (bsc#1012628).
- fs: dlm: fix use after free in midcomms commit (bsc#1012628).
- fs: dlm: be sure to call dlm_send_queue_flush() (bsc#1012628).
- fs: dlm: fix race setting stop tx flag (bsc#1012628).
- fs: dlm: don't set stop rx flag after node reset (bsc#1012628).
- fs: dlm: move sending fin message into state change handling
  (bsc#1012628).
- fs: dlm: send FIN ack back in right cases (bsc#1012628).
- f2fs: fix information leak in f2fs_move_inline_dirents()
  (bsc#1012628).
- f2fs: retry to update the inode page given data corruption
  (bsc#1012628).
- f2fs: fix cgroup writeback accounting with fs-layer encryption
  (bsc#1012628).
- f2fs: fix kernel crash due to null io->bio (bsc#1012628).
- f2fs: Revert "f2fs: truncate blocks in batch in
  __complete_revoke_list()" (bsc#1012628).
- ocfs2: fix defrag path triggering jbd2 ASSERT (bsc#1012628).
- ocfs2: fix non-auto defrag path not working issue (bsc#1012628).
- fs/cramfs/inode.c: initialize file_ra_state (bsc#1012628).
- selftests/landlock: Skip overlayfs tests when not supported
  (bsc#1012628).
- selftests/landlock: Test ptrace as much as possible with Yama
  (bsc#1012628).
- udf: Truncate added extents on failed expansion (bsc#1012628).
- udf: Do not bother merging very long extents (bsc#1012628).
- udf: Do not update file length for failed writes to inline files
  (bsc#1012628).
- udf: Preserve link count of system files (bsc#1012628).
- udf: Detect system inodes linked into directory hierarchy
  (bsc#1012628).
- udf: Fix file corruption when appending just after end of
  preallocated extent (bsc#1012628).
- md: don't update recovery_cp when curr_resync is ACTIVE
  (bsc#1012628).
- KVM: Destroy target device if coalesced MMIO unregistration
  fails (bsc#1012628).
- KVM: VMX: Fix crash due to uninitialized current_vmcs
  (bsc#1012628).
- KVM: Register /dev/kvm as the _very_ last thing during
  initialization (bsc#1012628).
- KVM: x86: Purge "highest ISR" cache when updating APICv state
  (bsc#1012628).
- KVM: x86: Blindly get current x2APIC reg value on "nodecode
  write" traps (bsc#1012628).
- KVM: x86: Don't inhibit APICv/AVIC on xAPIC ID "change" if
  APIC is disabled (bsc#1012628).
- KVM: x86: Don't inhibit APICv/AVIC if xAPIC ID mismatch is
  due to 32-bit ID (bsc#1012628).
- KVM: SVM: Flush the "current" TLB when activating AVIC
  (bsc#1012628).
- KVM: SVM: Process ICR on AVIC IPI delivery failure due to
  invalid target (bsc#1012628).
- KVM: SVM: Don't put/load AVIC when setting virtual APIC mode
  (bsc#1012628).
- KVM: x86: Inject #GP if WRMSR sets reserved bits in APIC
  Self-IPI (bsc#1012628).
- KVM: x86: Inject #GP on x2APIC WRMSR that sets reserved bits
  63:32 (bsc#1012628).
- KVM: SVM: Fix potential overflow in SEV's
  send|receive_update_data() (bsc#1012628).
- KVM: SVM: hyper-v: placate modpost section mismatch error
  (bsc#1012628).
- selftests: x86: Fix incorrect kernel headers search path
  (bsc#1012628).
- x86/virt: Force GIF=1 prior to disabling SVM (for reboot flows)
  (bsc#1012628).
- x86/crash: Disable virt in core NMI crash handler to avoid
  double shootdown (bsc#1012628).
- x86/reboot: Disable virtualization in an emergency if SVM is
  supported (bsc#1012628).
- x86/reboot: Disable SVM, not just VMX, when stopping CPUs
  (bsc#1012628).
- x86/kprobes: Fix __recover_optprobed_insn check optimizing logic
  (bsc#1012628).
- x86/kprobes: Fix arch_check_optimized_kprobe check within
  optimized_kprobe range (bsc#1012628).
- x86/microcode/amd: Remove load_microcode_amd()'s bsp parameter
  (bsc#1012628).
- x86/microcode/AMD: Add a @cpu parameter to the reloading
  functions (bsc#1012628).
- x86/microcode/AMD: Fix mixed steppings support (bsc#1012628).
- x86/speculation: Allow enabling STIBP with legacy IBRS
  (bsc#1012628).
- Documentation/hw-vuln: Document the interaction between IBRS
  and STIBP (bsc#1012628).
- virt/sev-guest: Return -EIO if certificate buffer is not large
  enough (bsc#1012628).
- brd: mark as nowait compatible (bsc#1012628).
- brd: return 0/-error from brd_insert_page() (bsc#1012628).
- brd: check for REQ_NOWAIT and set correct page allocation mask
  (bsc#1012628).
- ima: fix error handling logic when file measurement failed
  (bsc#1012628).
- ima: Align ima_file_mmap() parameters with mmap_file LSM hook
  (bsc#1012628).
- selftests/powerpc: Fix incorrect kernel headers search path
  (bsc#1012628).
- selftests/ftrace: Fix eprobe syntax test case to check filter
  support (bsc#1012628).
- selftests: sched: Fix incorrect kernel headers search path
  (bsc#1012628).
- selftests: core: Fix incorrect kernel headers search path
  (bsc#1012628).
- selftests: pid_namespace: Fix incorrect kernel headers search
  path (bsc#1012628).
- selftests: arm64: Fix incorrect kernel headers search path
  (bsc#1012628).
- selftests: clone3: Fix incorrect kernel headers search path
  (bsc#1012628).
- selftests: pidfd: Fix incorrect kernel headers search path
  (bsc#1012628).
- selftests: membarrier: Fix incorrect kernel headers search path
  (bsc#1012628).
- selftests: kcmp: Fix incorrect kernel headers search path
  (bsc#1012628).
- selftests: media_tests: Fix incorrect kernel headers search path
  (bsc#1012628).
- selftests: gpio: Fix incorrect kernel headers search path
  (bsc#1012628).
- selftests: filesystems: Fix incorrect kernel headers search path
  (bsc#1012628).
- selftests: user_events: Fix incorrect kernel headers search path
  (bsc#1012628).
- selftests: ptp: Fix incorrect kernel headers search path
  (bsc#1012628).
- selftests: sync: Fix incorrect kernel headers search path
  (bsc#1012628).
- selftests: rseq: Fix incorrect kernel headers search path
  (bsc#1012628).
- selftests: move_mount_set_group: Fix incorrect kernel headers
  search path (bsc#1012628).
- selftests: mount_setattr: Fix incorrect kernel headers search
  path (bsc#1012628).
- selftests: perf_events: Fix incorrect kernel headers search path
  (bsc#1012628).
- selftests: ipc: Fix incorrect kernel headers search path
  (bsc#1012628).
- selftests: futex: Fix incorrect kernel headers search path
  (bsc#1012628).
- selftests: drivers: Fix incorrect kernel headers search path
  (bsc#1012628).
- selftests: dmabuf-heaps: Fix incorrect kernel headers search
  path (bsc#1012628).
- selftests: vm: Fix incorrect kernel headers search path
  (bsc#1012628).
- selftests: seccomp: Fix incorrect kernel headers search path
  (bsc#1012628).
- irqdomain: Fix association race (bsc#1012628).
- irqdomain: Fix disassociation race (bsc#1012628).
- irqdomain: Look for existing mapping only once (bsc#1012628).
- irqdomain: Drop bogus fwspec-mapping error handling
  (bsc#1012628).
- irqdomain: Refactor __irq_domain_alloc_irqs() (bsc#1012628).
- irqdomain: Fix mapping-creation race (bsc#1012628).
- irqdomain: Fix domain registration race (bsc#1012628).
- crypto: qat - fix out-of-bounds read (bsc#1012628).
- mm/damon/paddr: fix missing folio_put() (bsc#1012628).
- ALSA: ice1712: Do not left ice->gpio_mutex locked in
  aureon_add_controls() (bsc#1012628).
- ALSA: hda/realtek: Add quirk for HP EliteDesk 800 G6 Tower PC
  (bsc#1012628).
- jbd2: fix data missing when reusing bh which is ready to be
  checkpointed (bsc#1012628).
- ext4: optimize ea_inode block expansion (bsc#1012628).
- ext4: refuse to create ea block when umounted (bsc#1012628).
- cxl/pmem: Fix nvdimm registration races (bsc#1012628).
- Input: exc3000 - properly stop timer on shutdown (bsc#1012628).
- mtd: spi-nor: sfdp: Fix index value for SCCR dwords
  (bsc#1012628).
- mtd: spi-nor: spansion: Consider reserved bits in CFR5 register
  (bsc#1012628).
- mtd: spi-nor: Fix shift-out-of-bounds in spi_nor_set_erase_type
  (bsc#1012628).
- dm: send just one event on resize, not two (bsc#1012628).
- dm: add cond_resched() to dm_wq_work() (bsc#1012628).
- dm: add cond_resched() to dm_wq_requeue_work() (bsc#1012628).
- wifi: rtw88: use RTW_FLAG_POWERON flag to prevent to power
  on/off twice (bsc#1012628).
- wifi: rtl8xxxu: Use a longer retry limit of 48 (bsc#1012628).
- wifi: ath11k: allow system suspend to survive ath11k
  (bsc#1012628).
- wifi: cfg80211: Fix use after free for wext (bsc#1012628).
- wifi: cfg80211: Set SSID if it is not already set (bsc#1012628).
- cpuidle: add ARCH_SUSPEND_POSSIBLE dependencies (bsc#1012628).
- qede: fix interrupt coalescing configuration (bsc#1012628).
- thermal: intel: powerclamp: Fix cur_state for multi package
  system (bsc#1012628).
- dm flakey: fix logic when corrupting a bio (bsc#1012628).
- dm cache: free background tracker's queued work in
  btracker_destroy (bsc#1012628).
- dm flakey: don't corrupt the zero page (bsc#1012628).
- dm flakey: fix a bug with 32-bit highmem systems (bsc#1012628).
- hwmon: (peci/cputemp) Fix off-by-one in coretemp_label
  allocation (bsc#1012628).
- hwmon: (nct6775) Fix incorrect parenthesization in
  nct6775_write_fan_div() (bsc#1012628).
- spi: intel: Check number of chip selects after reading the
  descriptor (bsc#1012628).
- ARM: dts: qcom: sdx65: Add Qcom SMMU-500 as the fallback for
  IOMMU node (bsc#1012628).
- ARM: dts: qcom: sdx55: Add Qcom SMMU-500 as the fallback for
  IOMMU node (bsc#1012628).
- ARM: dts: exynos: correct TMU phandle in Exynos4210
  (bsc#1012628).
- ARM: dts: exynos: correct TMU phandle in Exynos4 (bsc#1012628).
- ARM: dts: exynos: correct TMU phandle in Odroid XU3 family
  (bsc#1012628).
- ARM: dts: exynos: correct TMU phandle in Exynos5250
  (bsc#1012628).
- ARM: dts: exynos: correct TMU phandle in Odroid XU
  (bsc#1012628).
- ARM: dts: exynos: correct TMU phandle in Odroid HC1
  (bsc#1012628).
- arm64: acpi: Fix possible memory leak of ffh_ctxt (bsc#1012628).
- arm64: mm: hugetlb: Disable HUGETLB_PAGE_OPTIMIZE_VMEMMAP
  (bsc#1012628).
- arm64: Reset KASAN tag in copy_highpage with HW tags only
  (bsc#1012628).
- fuse: add inode/permission checks to fileattr_get/fileattr_set
  (bsc#1012628).
- rbd: avoid use-after-free in do_rbd_add() when rbd_dev_create()
  fails (bsc#1012628).
- ceph: update the time stamps and try to drop the suid/sgid
  (bsc#1012628).
- regulator: core: Use ktime_get_boottime() to determine how
  long a regulator was off (bsc#1012628).
- panic: fix the panic_print NMI backtrace setting (bsc#1012628).
- mm/hwpoison: convert TTU_IGNORE_HWPOISON to TTU_HWPOISON
  (bsc#1012628).
- genirq/msi, platform-msi: Ensure that MSI descriptors are
  unreferenced (bsc#1012628).
- genirq/msi: Take the per-device MSI lock before validating
  the control structure (bsc#1012628).
- spi: spi-sn-f-ospi: fix duplicate flag while assigning to
  mode_bits (bsc#1012628).
- alpha: fix FEN fault handling (bsc#1012628).
- dax/kmem: Fix leak of memory-hotplug resources (bsc#1012628).
- mips: fix syscall_get_nr (bsc#1012628).
- media: ipu3-cio2: Fix PM runtime usage_count in driver unbind
  (bsc#1012628).
- remoteproc/mtk_scp: Move clk ops outside send_lock
  (bsc#1012628).
- vfio: Fix NULL pointer dereference caused by uninitialized
  group->iommufd (bsc#1012628).
- docs: gdbmacros: print newest record (bsc#1012628).
- mm: memcontrol: deprecate charge moving (bsc#1012628).
- mm/thp: check and bail out if page in deferred queue already
  (bsc#1012628).
- ktest.pl: Give back console on Ctrt^C on monitor (bsc#1012628).
- kprobes: Fix to handle forcibly unoptimized kprobes on
  freeing_list (bsc#1012628).
- ktest.pl: Fix missing "end_monitor" when machine check fails
  (bsc#1012628).
- ktest.pl: Add RUN_TIMEOUT option with default unlimited
  (bsc#1012628).
- memory tier: release the new_memtier in
  find_create_memory_tier() (bsc#1012628).
- ring-buffer: Handle race between rb_move_tail and rb_check_pages
  (bsc#1012628).
- tools/bootconfig: fix single & used for logical condition
  (bsc#1012628).
- tracing/eprobe: Fix to add filter on eprobe description in
  README file (bsc#1012628).
- iommu/amd: Add a length limitation for the ivrs_acpihid
  command-line parameter (bsc#1012628).
- scsi: aacraid: Allocate cmd_priv with scsicmd (bsc#1012628).
- scsi: qla2xxx: Fix link failure in NPIV environment
  (bsc#1012628).
- scsi: qla2xxx: Check if port is online before sending ELS
  (bsc#1012628).
- scsi: qla2xxx: Fix DMA-API call trace on NVMe LS requests
  (bsc#1012628).
- scsi: qla2xxx: Remove unintended flag clearing (bsc#1012628).
- scsi: qla2xxx: Fix erroneous link down (bsc#1012628).
- scsi: qla2xxx: Remove increment of interface err cnt
  (bsc#1012628).
- scsi: ses: Don't attach if enclosure has no components
  (bsc#1012628).
- scsi: ses: Fix slab-out-of-bounds in
  ses_enclosure_data_process() (bsc#1012628).
- scsi: ses: Fix possible addl_desc_ptr out-of-bounds accesses
  (bsc#1012628).
- scsi: ses: Fix possible desc_ptr out-of-bounds accesses
  (bsc#1012628).
- scsi: ses: Fix slab-out-of-bounds in ses_intf_remove()
  (bsc#1012628).
- RISC-V: add a spin_shadow_stack declaration (bsc#1012628).
- riscv: Avoid enabling interrupts in die() (bsc#1012628).
- riscv: mm: fix regression due to update_mmu_cache change
  (bsc#1012628).
- riscv: jump_label: Fixup unaligned arch_static_branch function
  (bsc#1012628).
- riscv: ftrace: Fixup panic by disabling preemption
  (bsc#1012628).
- riscv, mm: Perform BPF exhandler fixup on page fault
  (bsc#1012628).
- riscv: ftrace: Remove wasted nops for !RISCV_ISA_C
  (bsc#1012628).
- riscv: ftrace: Reduce the detour code size to half
  (bsc#1012628).
- MIPS: DTS: CI20: fix otg power gpio (bsc#1012628).
- PCI/PM: Observe reset delay irrespective of bridge_d3
  (bsc#1012628).
- PCI: Unify delay handling for reset and resume (bsc#1012628).
- PCI: hotplug: Allow marking devices as disconnected during
  bind/unbind (bsc#1012628).
- PCI: Avoid FLR for AMD FCH AHCI adapters (bsc#1012628).
- PCI/DPC: Await readiness of secondary bus after reset
  (bsc#1012628).
- bus: mhi: ep: Only send -ENOTCONN status if client driver is
  available (bsc#1012628).
- bus: mhi: ep: Move chan->lock to the start of processing queued
  ch ring (bsc#1012628).
- bus: mhi: ep: Save channel state locally during suspend and
  resume (bsc#1012628).
- iommufd: Make sure to zero vfio_iommu_type1_info before copying
  to user (bsc#1012628).
- iommufd: Do not add the same hwpt to the ioas->hwpt_list twice
  (bsc#1012628).
- iommu/vt-d: Avoid superfluous IOTLB tracking in lazy mode
  (bsc#1012628).
- iommu/vt-d: Fix PASID directory pointer coherency (bsc#1012628).
- vfio/type1: exclude mdevs from VFIO_UPDATE_VADDR (bsc#1012628).
- vfio/type1: prevent underflow of locked_vm via exec()
  (bsc#1012628).
- vfio/type1: track locked_vm per dma (bsc#1012628).
- vfio/type1: restore locked_vm (bsc#1012628).
- drm/amd: Fix initialization for nbio 7.5.1 (bsc#1012628).
- drm/i915/quirks: Add inverted backlight quirk for HP 14-r206nv
  (bsc#1012628).
- drm/radeon: Fix eDP for single-display iMac11,2 (bsc#1012628).
- drm/i915: Don't use stolen memory for ring buffers with LLC
  (bsc#1012628).
- drm/i915: Don't use BAR mappings for ring buffers with LLC
  (bsc#1012628).
- drm/gud: Fix UBSAN warning (bsc#1012628).
- drm/edid: fix AVI infoframe aspect ratio handling (bsc#1012628).
- drm/edid: fix parsing of 3D modes from HDMI VSDB (bsc#1012628).
- qede: avoid uninitialized entries in coal_entry array
  (bsc#1012628).
- brd: use radix_tree_maybe_preload instead of radix_tree_preload
  (bsc#1012628).
- net: avoid double iput when sock_alloc_file fails (bsc#1012628).
- Update config files.
- commit ef7db20
* Thu Mar  9 2023 jslaby@suse.cz
- Disable lockdown. (bsc#1209006 bsc#1211166)
  This somehow doesn't play good wrt to external modules.
  When all is ready again, we can revert this revert.
- Disable lockdown. (bsc#1209006)
  This somehow doesn't play good wrt to external modules.
  When all is ready again, we can revert this revert.
- commit 77c9b15
* Thu Mar  9 2023 jlee@suse.com
- Update config files.
  Add the following config to x86_64, arm64 and i386.
  CONFIG_IMA_ARCH_POLICY=y
  CONFIG_IMA_SECURE_AND_OR_TRUSTED_BOOT=y
  This config be used to detect secure boot. (bsc#1209006)
- commit 90a4659
* Wed Mar  8 2023 jlee@suse.com
- KEYS: Make use of platform keyring for module signature verify
  (FATE#314508, FATE#316531, bsc#1209006).
- commit 261191e
* Wed Mar  8 2023 msuchanek@suse.de
- Do not sign the vanilla kernel (bsc#1209008).
- commit cee4d89
* Tue Mar  7 2023 shung-hsi.yu@suse.com
- rpm/group-source-files.pl: Deal with {pre,post}fixed / in location
  When the source file location provided with -L is either prefixed or
  postfixed with forward slash, the script get stuck in a infinite loop
  inside calc_dirs() where $path is an empty string.
  user@localhost:/tmp> perl "$HOME/group-source-files.pl" -D devel.files -N nondevel.files -L /usr/src/linux-5.14.21-150500.41/
  ...
  path = /usr/src/linux-5.14.21-150500.41/Documentation/Kconfig
  path = /usr/src/linux-5.14.21-150500.41/Documentation
  path = /usr/src/linux-5.14.21-150500.41
  path = /usr/src
  path = /usr
  path =
  path =
  path =
  ... # Stuck in an infinite loop
  This workarounds the issue by breaking out the loop once path is an
  empty string. For a proper fix we'd want something that
  filesystem-aware, but this workaround should be enough for the rare
  occation that this script is ran manually.
  Link: http://mailman.suse.de/mlarch/SuSE/kernel/2023/kernel.2023.03/msg00024.html
- commit 6d65136
* Tue Mar  7 2023 mkubecek@suse.cz
- cpumask: fix incorrect cpumask scanning result checks
  (https://lkml.iu.edu/hypermail/linux/kernel/2303.0/05801.html).
- commit f6f6da4
* Mon Mar  6 2023 msuchanek@suse.de
- kernel-module-subpackage: Fix expansion with -b parameter (bsc#1208179).
  When -b is specified the script is prefixed with KMP_NEEDS_MKINITRD=1
  which sets the variable for a simple command.
  However, the script is no longer a simple command. Export the variable
  instead.
- commit 152a069
* Mon Mar  6 2023 mkubecek@suse.cz
- Update to 6.3-rc1
- drop 32 patches (30 stable, 2 mainline)
  - patches.kernel.org/*
  - patches.rpmify/bpf_doc-Fix-build-error-with-older-python-versions.patch
  - patches.suse/objtool-Check-that-module-init-exit-function-is-an-i.patch
- refresh
  - patches.suse/add-suse-supported-flag.patch
  - patches.suse/vfs-add-super_operations-get_inode_dev
- disable ARM architectures (need config update)
- new config options
  - General setup
  - BOOT_CONFIG_FORCE=n
  - Memory Management options
  - ZSMALLOC_CHAIN_SIZE=8
  - Networking support
  - AF_RXRPC_INJECT_RX_DELAY=n
  - File systems
  - EROFS_FS_PCPU_KTHREAD=n
  - RPCSEC_GSS_KRB5_ENCTYPES_DES=n
  - RPCSEC_GSS_KRB5_ENCTYPES_AES_SHA1=y
  - RPCSEC_GSS_KRB5_ENCTYPES_CAMELLIA=y
  - RPCSEC_GSS_KRB5_ENCTYPES_AES_SHA2=y
  - Cryptographic API
  - CRYPTO_ARIA_AESNI_AVX2_X86_64=m
  - CRYPTO_ARIA_GFNI_AVX512_X86_64=m
  - Kernel hacking
  - NMI_CHECK_CPU=y
  - RCU_CPU_STALL_CPUTIME=y
  - TEST_DHRY=n
  - Serial ATA and Parallel ATA drivers (libata)
  - PATA_PARPORT renamed from PARIDE
  - PATA_PARPORT_* renamed from PARIDE_*
  - Network device support
  - NET_DSA_MICROCHIP_KSZ_PTP=y
  - NET_DSA_MSCC_OCELOT_EXT=m
  - NCN26000_PHY=m
  - ATH12K=m
  - ATH12K_DEBUG=n
  - ATH12K_TRACING=n
  - Character devices
  - SERIAL_8250_PCI1XXXX=y
  - SERIAL_8250_DFL=m
  - Power supply class support
  - CHARGER_RT9467=m
  - CHARGER_RT9471=m
  - Hardware Monitoring support
  - SENSORS_MC34VR500=m
  - SENSORS_MPQ7932=m
  - SENSORS_MPQ7932_REGULATOR=y
  - SENSORS_TDA38640=m
  - SENSORS_TDA38640_REGULATOR=y
  - Multifunction device drivers
  - MFD_INTEL_M10_BMC_SPI=n
  - MFD_INTEL_M10_BMC_PMCI=n
  - Multimedia support
  - VIDEO_IMX296=m
  - VIDEO_OV8858=m
  - Graphics support
  - DRM_PANEL_AUO_A030JTN01=n
  - DRM_PANEL_ORISETECH_OTA5601A=n
  - BACKLIGHT_KTZ8866=m
  - Compute Acceleration Framework
  - DRM_ACCEL_HABANALABS=m
  - DRM_ACCEL_IVPU=m
  - Sound card support
  - SND_HDA_CTL_DEV_ID=n
  - SND_SOC_AW88395=n
  - SND_SOC_CS42L42_SDW=m
  - SND_SOC_IDT821034=n
  - SND_SOC_PEB2466=n
  - SND_SOC_RT712_SDCA_SDW=m
  - SND_SOC_SMA1303=n
  - HID_SUPPORT=y
  - HID_SUPPORT=y
  - HID_EVISION=m
  - STEAM_FF=y
  - HID_BPF=y
  - I2C_HID=m
  - vDPA drivers
  - MLX5_VDPA_STEERING_DEBUG=n
  - SNET_VDPA=m
  - Industrial I/O support
  - TI_ADS7924=n
  - TI_LMP92064=n
  - MAX5522=n
  - TI_TMAG5273=n
  - Misc devices
  - REGULATOR_MAX20411=m
  - TYPEC_MUX_GPIO_SBU=m
  - XILINX_XDMA=m
  - CROS_EC_UART=m
  - INTEL_TPMI=m
  - INTEL_IOMMU_PERF_EVENTS=y
  - WPCM450_SOC=m
  - DEV_DAX_CXL=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - VIDEO_IMX415=m
  - DRM_PANEL_HIMAX_HX8394=n
  - DRM_PANEL_VISIONOX_VTDR6130=n
  - QCOM_PMIC_GLINK=m
  - BATTERY_QCOM_BATTMGR=m
  - ppc64le / ppc64
  - KCSAN=n
  - s390x
  - FPROBE=y
  - s390x/zfcpdump
  - GLOB_SELFTEST=n
  - riscv64
  - ARCH_SUNXI=y
  - RISCV_ISA_ZBB=y
  - SUN50I_DE2_BUS=n
  - SUNXI_RSB=m
  - MTD_NAND_SUNXI=m
  - AHCI_SUNXI=m
  - NET_VENDOR_ALLWINNER=y
  - SUN4I_EMAC=m
  - DWMAC_SUNXI=m
  - DWMAC_SUN8I=m
  - KEYBOARD_SUN4I_LRADC=m
  - TOUCHSCREEN_SUN4I=m
  - SERIO_SUN4I_PS2=m
  - SERIAL_EARLYCON_SEMIHOST=y
  - HW_RANDOM_JH7110=m
  - I2C_MV64XXX=m
  - SPI_SUN4I=m
  - SPI_SUN6I=m
  - PINCTRL_STARFIVE_JH7110_SYS=m
  - PINCTRL_STARFIVE_JH7110_AON=m
  - PINCTRL_SUN*=y
  - SUN8I_THERMAL=m
  - SUNXI_WATCHDOG=m
  - MFD_SUN4I_GPADC=n
  - MFD_AC100=n
  - MFD_AXP20X_RSB=n
  - MFD_SUN6I_PRCM=n
  - IR_SUNXI=m
  - DRM_SUN4I=n
  - SND_SUN4I_CODEC=m
  - SND_SUN4I_I2S=m
  - SND_SUN4I_SPDIF=m
  - SND_SUN50I_DMIC=m
  - MMC_DW_STARFIVE=m
  - MMC_SUNXI=m
  - RTC_DRV_SUN6I=n
  - DMA_SUN6I=m
  - VIDEO_SUNXI=y
  - VIDEO_SUNXI_CEDRUS=m
  - SUNXI_CCU=m
  - SUN20I_D1_CCU=m
  - SUN20I_D1_R_CCU=m
  - SUN6I_RTC_CCU=m
  - SUN8I_DE2_CCU=m
  - HWSPINLOCK_SUN6I=m
  - SUN6I_MSGBOX=m
  - SUN50I_IOMMU=y
  - JH71XX_PMU=n
  - SUN20I_PPU=n
  - ARM_SUN8I_A33_MBUS_DEVFREQ=m
  - PWM_SUN4I=m
  - PHY_SUN4I_USB=m
  - PHY_SUN6I_MIPI_DPHY=m
  - PHY_SUN9I_USB=m
  - PHY_SUN50I_USB3=m
  - NVMEM_SUNXI_SID=m
  - HUGETLB_PAGE_OPTIMIZE_VMEMMAP_DEFAULT_ON=n
  - CRYPTO_DEV_ALLWINNER=y
  - CRYPTO_DEV_SUN4I_SS=m
  - CRYPTO_DEV_SUN4I_SS_PRNG=y
  - CRYPTO_DEV_SUN4I_SS_DEBUG=n
  - CRYPTO_DEV_SUN8I_CE=m
  - CRYPTO_DEV_SUN8I_CE_DEBUG=n
  - CRYPTO_DEV_SUN8I_CE_HASH=y
  - CRYPTO_DEV_SUN8I_CE_PRNG=y
  - CRYPTO_DEV_SUN8I_CE_TRNG=y
  - CRYPTO_DEV_SUN8I_SS=m
  - CRYPTO_DEV_SUN8I_SS_DEBUG=n
  - CRYPTO_DEV_SUN8I_SS_PRNG=y
  - CRYPTO_DEV_SUN8I_SS_HASH=y
  - USB_MUSB_SUNXI=m
- commit f3bbae4
* Fri Mar  3 2023 jslaby@suse.cz
- Linux 6.2.2 (bsc#1012628).
- USB: core: Don't hold device lock while reading the
  "descriptors" sysfs file (bsc#1012628).
- usb: typec: pd: Remove usb_suspend_supported sysfs from sink
  PDO (bsc#1012628).
- arm64: dts: uniphier: Fix property name in PXs3 USB node
  (bsc#1012628).
- usb: gadget: u_serial: Add null pointer check in gserial_resume
  (bsc#1012628).
- USB: serial: option: add support for VW/Skoda "Carstick LTE"
  (bsc#1012628).
- usb: dwc3: pci: add support for the Intel Meteor Lake-M
  (bsc#1012628).
- wifi: rtw88: usb: drop now unnecessary URB size check
  (bsc#1012628).
- wifi: rtw88: usb: send Zero length packets if necessary
  (bsc#1012628).
- wifi: rtw88: usb: Set qsel correctly (bsc#1012628).
- scripts/tags.sh: fix incompatibility with PCRE2 (bsc#1012628).
- drm/amd/display: Properly reuse completion structure
  (bsc#1012628).
- drm/amd/display: Move DCN314 DOMAIN power control to DMCUB
  (bsc#1012628).
- vc_screen: don't clobber return value in vcs_read (bsc#1012628).
- bpf: bpf_fib_lookup should not return neigh in NUD_FAILED state
  (bsc#1012628).
- crypto: arm64/sm4-gcm - Fix possible crash in GCM cryption
  (bsc#1012628).
- ALSA: hda: cs35l41: Correct error condition handling
  (bsc#1012628).
- commit ec730fa
* Wed Mar  1 2023 jslaby@suse.cz
- Update config files. Disable old pcmcia drivers (bsc#1208780).
- commit 789fdf4
* Wed Mar  1 2023 jslaby@suse.cz
- Update config files. Disable old pcmcia socket drivers (bsc#1208780).
- commit 27af844
* Wed Mar  1 2023 jslaby@suse.cz
- Delete
  patches.suse/char-pcmcia-cm4000_cs-Fix-use-after-free-in-cm4000_f.patch.
- Delete
  patches.suse/char-pcmcia-cm4040_cs-Fix-use-after-free-in-reader_f.patch.
- Delete
  patches.suse/char-pcmcia-scr24x_cs-Fix-use-after-free-in-scr24x_f.patch.
  These drivers are now disabled, so remove the non-upstream patches. See
  bsc#1208775.
- commit 03a39b9
* Wed Mar  1 2023 jslaby@suse.cz
- Update config files. Disable char/pcmcia drivers (bsc#1208775).
- commit a2a5aac
* Wed Mar  1 2023 jslaby@suse.cz
- arm64: efi: Use SMBIOS processor ID to key off Altra quirk
  (bsc#1208750).
- commit 533dcdd
* Tue Feb 28 2023 schwab@suse.de
- config: riscv64: enable SPI_SPIDEV and SPI_SLAVE
- commit 8cad76a
* Mon Feb 27 2023 jslaby@suse.cz
- Linux 6.2.1 (bsc#1012628).
- bpf: add missing header file include (bsc#1012628).
- randstruct: disable Clang 15 support (bsc#1012628).
- ext4: Fix function prototype mismatch for ext4_feat_ktype
  (bsc#1012628).
- platform/x86: nvidia-wmi-ec-backlight: Add force module
  parameter (bsc#1012628).
- platform/x86/amd/pmf: Add depends on CONFIG_POWER_SUPPLY
  (bsc#1012628).
- audit: update the mailing list in MAINTAINERS (bsc#1012628).
- wifi: mwifiex: Add missing compatible string for SD8787
  (bsc#1012628).
- HID: mcp-2221: prevent UAF in delayed work (bsc#1012628).
- x86/static_call: Add support for Jcc tail-calls (bsc#1012628).
- x86/alternatives: Teach text_poke_bp() to patch Jcc.d32
  instructions (bsc#1012628).
- x86/alternatives: Introduce int3_emulate_jcc() (bsc#1012628).
- uaccess: Add speculation barrier to copy_from_user()
  (bsc#1012628).
- commit 15796ef
* Fri Feb 24 2023 msuchanek@suse.de
- Disable PS3 support
  The PS3 hardware cannot be used with up-to-date firmware.
- commit 484fa63
* Fri Feb 24 2023 tzimmermann@suse.com
- uvesafb: Disable fbdev driver (boo#1208662)
  A VESA-based driver. Dropped in favor of generic DRM drivers.
- commit f0d0f1a
* Fri Feb 24 2023 tzimmermann@suse.com
- ocfb: Disable fbdev driver (boo#1208660)
  The OpenCores fbdev driver is for an old homebrew chip design. Probably
  unused.
- commit 00dd263
* Fri Feb 24 2023 tzimmermann@suse.com
- udlfb: Disable fbdev driver (boo#1208658)
  We've long shipped the DRM-based udl driver, which handles the same
  devices.
- commit 8a53173
* Fri Feb 24 2023 tzimmermann@suse.com
- ssd1307fb: Replace with ssd130x (boo#1208656)
  Replace fbdev's ssd1307fb driver with the new DRM-based driver
  ssd130x. Adds support for SPI and Wayland-based userspace.
- commit 1fe1b4c
* Fri Feb 24 2023 tzimmermann@suse.com
- vfb: Disable fbdev driver (boo#1208646)
  The vfb fbdev driver is backed by system memory and only relevant for
  testing. Disable it. There is DRM's vkms, if a software-only driver is
  required.
- commit b1c9331
* Fri Feb 24 2023 tzimmermann@suse.com
- Disable gxt4500 fbdev driver (boo#1208642)
  The gxt4500 driver serves a 20yrs-old graphics hardware for
  IBM RS/6000 system. Probably not in use any longer.
- commit 5313a19
* Tue Feb 21 2023 jslaby@suse.cz
- blacklist.conf: clean up
  Remove the only (5.5) entry. It was needed only years ago.
- commit de1e630
* Mon Feb 20 2023 mkubecek@suse.cz
- Update to 6.2 final
- refresh configs
- commit 28fe266
* Sat Feb 18 2023 jlee@suse.com
- arm64: lock down kernel in secure boot mode (jsc#SLE-15020, bsc#1198101).
- efi: Lock down the kernel at the integrity level if booted in
  secure boot mode (jsc#SLE-9870, bsc#1198101).
- efi: Lock down the kernel if booted in secure boot mode
  (jsc#SLE-9870, bsc#1198101).
- Update config files.
  - The shim for openSUSE Tumbleweed needs to be reviewed by upstream
    and signed by Microsoft. So we need to lockdown kernel on x86_64
    and arm64 because EFI secure boot.
  - We disable CONFIG_LOCK_DOWN_IN_EFI_SECURE_BOOT in other
    architectures.
- efi: Add an EFI_SECURE_BOOT flag to indicate secure boot mode
  (jsc#SLE-9870, bsc#1198101).
- security: lockdown: expose a hook to lock the kernel down
  (jsc#SLE-9870, bsc#1198101).
- commit a7d5b50
* Thu Feb 16 2023 mkoutny@suse.com
- Update config files.
  Disable CONFIG_BLK_CGROUP_IOPRIO.
  io.prio.class is a misdesigned mechanism that doesn't fit well with the
  cgroup (especially v2):
- it's not properly hierarchical
  - cgroup-wise: parent cgroup has no contol over child cgroup
  - task-wise: priority impact outside of a cgroup (i.e. affects
    cousins competition)
- it's not device dependent (device oblivious)
  Disable it in openSUSE Tumbleweed (and future products) so that we don't
  teach users to use it and force ourselves to support it.
- commit 35713cd
* Wed Feb 15 2023 jslaby@suse.cz
- Linux 6.1.12 (bsc#1012628).
- Documentation/hw-vuln: Add documentation for Cross-Thread
  Return Predictions (bsc#1012628).
- KVM: x86: Mitigate the cross-thread return address predictions
  bug (bsc#1012628).
- x86/speculation: Identify processors vulnerable to SMT RSB
  predictions (bsc#1012628).
- drm/i915: Fix VBT DSI DVO port handling (bsc#1012628).
- drm/i915: Initialize the obj flags for shmem objects
  (bsc#1012628).
- drm/i915: Move fd_install after last use of fence (bsc#1012628).
- drm/amd/display: fix cursor offset on rotation 180
  (bsc#1012628).
- drm/amd/display: properly handling AGP aperture in vm setup
  (bsc#1012628).
- drm/amdgpu/smu: skip pptable init under sriov (bsc#1012628).
- drm/amdgpu/fence: Fix oops due to non-matching drm_sched
  init/fini (bsc#1012628).
- drm/amd/pm: bump SMU 13.0.7 driver_if header version
  (bsc#1012628).
- drm/amdgpu: Add unique_id support for GC 11.0.1/2 (bsc#1012628).
- drm/amd/pm: bump SMU 13.0.0 driver_if header version
  (bsc#1012628).
- arm64: efi: Force the use of SetVirtualAddressMap() on eMAG
  and Altra Max machines (bsc#1012628).
- Fix page corruption caused by racy check in __free_pages
  (bsc#1012628).
- arm64: dts: meson-axg: Make mmc host controller interrupts
  level-sensitive (bsc#1012628).
- arm64: dts: meson-g12-common: Make mmc host controller
  interrupts level-sensitive (bsc#1012628).
- arm64: dts: meson-gx: Make mmc host controller interrupts
  level-sensitive (bsc#1012628).
- rtmutex: Ensure that the top waiter is always woken up
  (bsc#1012628).
- tracing: Fix TASK_COMM_LEN in trace event format file
  (bsc#1012628).
- drm/amdgpu: Use the TGID for trace_amdgpu_vm_update_ptes
  (bsc#1012628).
- powerpc/64s/interrupt: Fix interrupt exit race with security
  mitigation switch (bsc#1012628).
- riscv: kprobe: Fixup misaligned load text (bsc#1012628).
- riscv: Fixup race condition on PG_dcache_clean in
  flush_icache_pte (bsc#1012628).
- nvdimm: Support sizeof(struct page) > MAX_STRUCT_PAGE_SIZE
  (bsc#1012628).
- ceph: flush cap releases when the session is flushed
  (bsc#1012628).
- drm/amd/pm: add SMU 13.0.7 missing GetPptLimit message mapping
  (bsc#1012628).
- pinctrl: qcom: sm8450-lpass-lpi: correct swr_rx_data group
  (bsc#1012628).
- clk: ingenic: jz4760: Update M/N/OD calculation algorithm
  (bsc#1012628).
- cxl/region: Fix passthrough-decoder detection (bsc#1012628).
- cxl/region: Fix null pointer dereference for resetting decoder
  (bsc#1012628).
- usb: typec: altmodes/displayport: Fix probe pin assign check
  (bsc#1012628).
- usb: core: add quirk for Alcor Link AK9563 smartcard reader
  (bsc#1012628).
- btrfs: free device in btrfs_close_devices for a single device
  filesystem (bsc#1012628).
- btrfs: simplify update of last_dir_index_offset when logging
  a directory (bsc#1012628).
- selftests: mptcp: stop tests earlier (bsc#1012628).
- selftests: mptcp: allow more slack for slow test-case
  (bsc#1012628).
- mptcp: be careful on subflow status propagation on errors
  (bsc#1012628).
- mptcp: do not wait for bare sockets' timeout (bsc#1012628).
- net: USB: Fix wrong-direction WARNING in plusb.c (bsc#1012628).
- cifs: Fix use-after-free in rdata->read_into_pages()
  (bsc#1012628).
- pinctrl: intel: Restore the pins that used to be in Direct
  IRQ mode (bsc#1012628).
- pinctrl: aspeed: Revert "Force to disable the function's signal"
  (bsc#1012628).
- spi: dw: Fix wrong FIFO level setting for long xfers
  (bsc#1012628).
- pinctrl: single: fix potential NULL dereference (bsc#1012628).
- pinctrl: aspeed: Fix confusing types in return value
  (bsc#1012628).
- pinctrl: mediatek: Fix the drive register definition of some
  Pins (bsc#1012628).
- clk: microchip: mpfs-ccc: Use devm_kasprintf() for allocating
  formatted strings (bsc#1012628).
- ASoC: topology: Return -ENOMEM on memory allocation failure
  (bsc#1012628).
- ASoC: fsl_sai: fix getting version from VERID (bsc#1012628).
- ASoC: tas5805m: add missing page switch (bsc#1012628).
- ASoC: tas5805m: rework to avoid scheduling while atomic
  (bsc#1012628).
- arm64: dts: mediatek: mt8195: Fix vdosys* compatible strings
  (bsc#1012628).
- riscv: stacktrace: Fix missing the first frame (bsc#1012628).
- ALSA: pci: lx6464es: fix a debug loop (bsc#1012628).
- arm64: dts: rockchip: set sdmmc0 speed to sd-uhs-sdr50 on
  rock-3a (bsc#1012628).
- arm64: dts: rockchip: fix input enable pinconf on rk3399
  (bsc#1012628).
- selftests: forwarding: lib: quote the sysctl values
  (bsc#1012628).
- net: mscc: ocelot: fix all IPv6 getting trapped to CPU when
  PTP timestamping is used (bsc#1012628).
- rds: rds_rm_zerocopy_callback() use list_first_entry()
  (bsc#1012628).
- selftests: Fix failing VXLAN VNI filtering test (bsc#1012628).
- txhash: fix sk->sk_txrehash default (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix wrong parameters order in
  __xdp_rxq_info_reg() (bsc#1012628).
- igc: Add ndo_tx_timeout support (bsc#1012628).
- net/mlx5: Serialize module cleanup with reload and remove
  (bsc#1012628).
- net/mlx5: fw_tracer, Zero consumer index when reloading the
  tracer (bsc#1012628).
- net/mlx5: fw_tracer, Clear load bit when freeing string DBs
  buffers (bsc#1012628).
- net/mlx5: Expose SF firmware pages counter (bsc#1012628).
- net/mlx5: Store page counters in a single array (bsc#1012628).
- net/mlx5e: IPoIB, Show unknown speed instead of error
  (bsc#1012628).
- net/mlx5e: Fix crash unsetting rx-vlan-filter in switchdev mode
  (bsc#1012628).
- net/mlx5: Bridge, fix ageing of peer FDB entries (bsc#1012628).
- net/mlx5e: Update rx ring hw mtu upon each rx-fcs flag change
  (bsc#1012628).
- net: mscc: ocelot: fix VCAP filters not matching on MAC with
  "protocol 802.1Q" (bsc#1012628).
- net: dsa: mt7530: don't change PVC_EG_TAG when CPU port becomes
  VLAN-aware (bsc#1012628).
- ice: switch: fix potential memleak in ice_add_adv_recipe()
  (bsc#1012628).
- ice: Fix disabling Rx VLAN filtering with port VLAN enabled
  (bsc#1012628).
- ice: Do not use WQ_MEM_RECLAIM flag for workqueue (bsc#1012628).
- nvidiafb: detect the hardware support before removing console
  (bsc#1012628).
- cpuset: Call set_cpus_allowed_ptr() with appropriate mask for
  task (bsc#1012628).
- drm/virtio: exbuf->fence_fd unmodified on interrupted wait
  (bsc#1012628).
- drm/i915: Don't do the WM0->WM1 copy w/a if WM1 is already
  enabled (bsc#1012628).
- HID: amd_sfh: if no sensors are enabled, clean up (bsc#1012628).
- net: microchip: sparx5: fix PTP init/deinit not checking all
  ports (bsc#1012628).
- uapi: add missing ip/ipv6 header dependencies for linux/stddef.h
  (bsc#1012628).
- cpufreq: qcom-hw: Fix cpufreq_driver->get() for non-LMH systems
  (bsc#1012628).
- ionic: missed doorbell workaround (bsc#1012628).
- ionic: refactor use of ionic_rx_fill() (bsc#1012628).
- ionic: clean interrupt before enabling queue to avoid credit
  race (bsc#1012628).
- net: phy: meson-gxl: use MMD access dummy stubs for GXL,
  internal PHY (bsc#1012628).
- net: macb: Perform zynqmp dynamic configuration only for SGMII
  interface (bsc#1012628).
- bonding: fix error checking in bond_debug_reregister()
  (bsc#1012628).
- net: phylink: move phy_device_free() to correctly release phy
  device (bsc#1012628).
- of: Make OF framebuffer device names unique (bsc#1012628).
- xfrm: fix bug with DSCP copy to v6 from v4 tunnel (bsc#1012628).
- RDMA/usnic: use iommu_map_atomic() under spin_lock()
  (bsc#1012628).
- RDMA/irdma: Fix potential NULL-ptr-dereference (bsc#1012628).
- xfrm: annotate data-race around use_time (bsc#1012628).
- IB/IPoIB: Fix legacy IPoIB due to wrong number of queues
  (bsc#1012628).
- xfrm/compat: prevent potential spectre v1 gadget in
  xfrm_xlate32_attr() (bsc#1012628).
- IB/hfi1: Restore allocated resources on failed copyout
  (bsc#1012628).
- xfrm: compat: change expression for switch in xfrm_xlate64
  (bsc#1012628).
- HID: logitech: Disable hi-res scrolling on USB (bsc#1012628).
- can: j1939: do not wait 250 ms if the same addr was already
  claimed (bsc#1012628).
- of/address: Return an error when no valid dma-ranges are found
  (bsc#1012628).
- tracing: Fix poll() and select() do not work on per_cpu
  trace_pipe and trace_pipe_raw (bsc#1012628).
- Revert "PCI/ASPM: Refactor L1 PM Substates Control Register
  programming" (bsc#1012628).
- Revert "PCI/ASPM: Save L1 PM Substates Capability for
  suspend/resume" (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs don't work for a HP
  platform (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ASUS UM3402 using CS35L41
  (bsc#1012628).
- ALSA: hda/realtek: Enable mute/micmute LEDs on HP Elitebook,
  645 G9 (bsc#1012628).
- ALSA: hda/realtek: Fix the speaker output on Samsung Galaxy
  Book2 Pro 360 (bsc#1012628).
- ALSA: emux: Avoid potential array out-of-bound in
  snd_emux_xg_control() (bsc#1012628).
- ALSA: hda/realtek: Add Positivo N14KP6-TG (bsc#1012628).
- btrfs: zlib: zero-initialize zlib workspace (bsc#1012628).
- btrfs: limit device extents to the device size (bsc#1012628).
- hv_netvsc: Allocate memory in netvsc_dma_map() with GFP_ATOMIC
  (bsc#1012628).
- commit 373f017
* Tue Feb 14 2023 jslaby@suse.cz
- Update
  patches.kernel.org/6.1.5-127-x86-bugs-Flush-IBP-in-ib_prctl_set.patch
  (bsc#1012628 bsc#1207773 CVE-2023-0045).
  Add refereces.
- commit 69a37c0
* Tue Feb 14 2023 jslaby@suse.cz
- Update config files.
  Just run oldconfig.
- commit f33197d
* Tue Feb 14 2023 jslaby@suse.cz
- Update config files. Enable budget-ci module (bsc#1206774)
  Needed for saa7146 support.
- commit 1fa8f94
* Tue Feb 14 2023 jlee@suse.com
- Removed the support of EINJ (bsc#1023051, CVE-2016-3695)
- Update config files.
- supported.conf: removed drivers/acpi/apei/einj support.
- commit c2c7791
* Mon Feb 13 2023 mkubecek@suse.cz
- Update to 6.2-rc8
- commit 3c381aa
* Thu Feb  9 2023 jslaby@suse.cz
- Linux 6.1.11 (bsc#1012628).
- firewire: fix memory leak for payload of request subaction to
  IEC 61883-1 FCP region (bsc#1012628).
- bus: sunxi-rsb: Fix error handling in sunxi_rsb_init()
  (bsc#1012628).
- arm64: dts: imx8m-venice: Remove incorrect 'uart-has-rtscts'
  (bsc#1012628).
- arm64: dts: freescale: imx8dxl: fix sc_pwrkey's property name
  linux,keycode (bsc#1012628).
- ASoC: amd: acp-es8336: Drop reference count of ACPI device
  after use (bsc#1012628).
- ASoC: Intel: bytcht_es8316: Drop reference count of ACPI device
  after use (bsc#1012628).
- ASoC: Intel: bytcr_rt5651: Drop reference count of ACPI device
  after use (bsc#1012628).
- ASoC: Intel: bytcr_rt5640: Drop reference count of ACPI device
  after use (bsc#1012628).
- ASoC: Intel: bytcr_wm5102: Drop reference count of ACPI device
  after use (bsc#1012628).
- ASoC: Intel: sof_es8336: Drop reference count of ACPI device
  after use (bsc#1012628).
- ASoC: Intel: avs: Implement PCI shutdown (bsc#1012628).
- bpf: Fix off-by-one error in bpf_mem_cache_idx() (bsc#1012628).
- bpf: Fix a possible task gone issue with
  bpf_send_signal[_thread]() helpers (bsc#1012628).
- ALSA: hda/via: Avoid potential array out-of-bound in
  add_secret_dac_path() (bsc#1012628).
- bpf: Fix to preserve reg parent/live fields when copying range
  info (bsc#1012628).
- selftests/filesystems: grant executable permission to
  run_fat_tests.sh (bsc#1012628).
- ASoC: SOF: ipc4-mtrace: prevent underflow in
  sof_ipc4_priority_mask_dfs_write() (bsc#1012628).
- bpf: Add missing btf_put to register_btf_id_dtor_kfuncs
  (bsc#1012628).
- media: v4l2-ctrls-api.c: move ctrl->is_new = 1 to the correct
  line (bsc#1012628).
- bpf, sockmap: Check for any of tcp_bpf_prots when cloning a
  listener (bsc#1012628).
- arm64: dts: imx8mm: Fix pad control for UART1_DTE_RX
  (bsc#1012628).
- arm64: dts: imx8mm-verdin: Do not power down eth-phy
  (bsc#1012628).
- drm/vc4: hdmi: make CEC adapter name unique (bsc#1012628).
- drm/ssd130x: Init display before the SSD130X_DISPLAY_ON command
  (bsc#1012628).
- scsi: Revert "scsi: core: map PQ=1, PDT=other values to
  SCSI_SCAN_TARGET_PRESENT" (bsc#1012628).
- bpf: Fix the kernel crash caused by bpf_setsockopt()
  (bsc#1012628).
- ALSA: memalloc: Workaround for Xen PV (bsc#1012628).
- vhost/net: Clear the pending messages when the backend is
  removed (bsc#1012628).
- copy_oldmem_kernel() - WRITE is "data source", not destination
  (bsc#1012628).
- WRITE is "data source", not destination.. (bsc#1012628).
- READ is "data destination", not source.. (bsc#1012628).
- zcore: WRITE is "data source", not destination.. (bsc#1012628).
- memcpy_real(): WRITE is "data source", not
  destination.. (bsc#1012628).
- fix iov_iter_bvec() "direction" argument (bsc#1012628).
- fix 'direction' argument of iov_iter_{init,bvec}()
  (bsc#1012628).
- fix "direction" argument of iov_iter_kvec() (bsc#1012628).
- use less confusing names for iov_iter direction initializers
  (bsc#1012628).
- vhost-scsi: unbreak any layout for response (bsc#1012628).
- ice: Prevent set_channel from changing queues while RDMA active
  (bsc#1012628).
- qede: execute xdp_do_flush() before napi_complete_done()
  (bsc#1012628).
- virtio-net: execute xdp_do_flush() before napi_complete_done()
  (bsc#1012628).
- dpaa_eth: execute xdp_do_flush() before napi_complete_done()
  (bsc#1012628).
- dpaa2-eth: execute xdp_do_flush() before napi_complete_done()
  (bsc#1012628).
- skb: Do mix page pool and page referenced frags in GRO
  (bsc#1012628).
- sfc: correctly advertise tunneled IPv6 segmentation
  (bsc#1012628).
- net: phy: dp83822: Fix null pointer access on DP83825/DP83826
  devices (bsc#1012628).
- net: wwan: t7xx: Fix Runtime PM initialization (bsc#1012628).
- block, bfq: replace 0/1 with false/true in bic apis
  (bsc#1012628).
- block, bfq: fix uaf for bfqq in bic_set_bfqq() (bsc#1012628).
- netrom: Fix use-after-free caused by accept on already connected
  socket (bsc#1012628).
- fscache: Use wait_on_bit() to wait for the freeing of
  relinquished volume (bsc#1012628).
- platform/x86/amd/pmf: update to auto-mode limits only after
  AMT event (bsc#1012628).
- platform/x86/amd/pmf: Add helper routine to update SPS thermals
  (bsc#1012628).
- platform/x86/amd/pmf: Fix to update SPS default pprof thermals
  (bsc#1012628).
- platform/x86/amd/pmf: Add helper routine to check pprof is
  balanced (bsc#1012628).
- platform/x86/amd/pmf: Fix to update SPS thermals when power
  supply change (bsc#1012628).
- platform/x86/amd/pmf: Ensure mutexes are initialized before use
  (bsc#1012628).
- platform/x86: thinkpad_acpi: Fix thinklight LED brightness
  returning 255 (bsc#1012628).
- drm/i915/guc: Fix locking when searching for a hung request
  (bsc#1012628).
- drm/i915: Fix request ref counting during error capture &
  debugfs dump (bsc#1012628).
- drm/i915: Fix up locking around dumping requests lists
  (bsc#1012628).
- drm/i915/adlp: Fix typo for reference clock (bsc#1012628).
- net/tls: tls_is_tx_ready() checked list_entry (bsc#1012628).
- ALSA: firewire-motu: fix unreleased lock warning in hwdep device
  (bsc#1012628).
- netfilter: br_netfilter: disable sabotage_in hook after first
  suppression (bsc#1012628).
- block: ublk: extending queue_size to fix overflow (bsc#1012628).
- kunit: fix kunit_test_init_section_suites(...) (bsc#1012628).
- squashfs: harden sanity check in squashfs_read_xattr_id_table
  (bsc#1012628).
- maple_tree: should get pivots boundary by type (bsc#1012628).
- sctp: do not check hb_timer.expires when resetting hb_timer
  (bsc#1012628).
- net: phy: meson-gxl: Add generic dummy stubs for MMD register
  access (bsc#1012628).
- drm/panel: boe-tv101wum-nl6: Ensure DSI writes succeed during
  disable (bsc#1012628).
- ip/ip6_gre: Fix changing addr gen mode not generating IPv6
  link local address (bsc#1012628).
- ip/ip6_gre: Fix non-point-to-point tunnel not generating IPv6
  link local address (bsc#1012628).
- riscv: kprobe: Fixup kernel panic when probing an illegal
  position (bsc#1012628).
- igc: return an error if the mac type is unknown in
  igc_ptp_systim_to_hwtstamp() (bsc#1012628).
- octeontx2-af: Fix devlink unregister (bsc#1012628).
- can: j1939: fix errant WARN_ON_ONCE in j1939_session_deactivate
  (bsc#1012628).
- can: raw: fix CAN FD frame transmissions over CAN XL devices
  (bsc#1012628).
- can: mcp251xfd: mcp251xfd_ring_set_ringparam(): assign missing
  tx_obj_num_coalesce_irq (bsc#1012628).
- ata: libata: Fix sata_down_spd_limit() when no link speed is
  reported (bsc#1012628).
- selftests: net: udpgso_bench_rx: Fix 'used uninitialized'
  compiler warning (bsc#1012628).
- selftests: net: udpgso_bench_rx/tx: Stop when wrong CLI args
  are provided (bsc#1012628).
- selftests: net: udpgso_bench: Fix racing bug between the rx/tx
  programs (bsc#1012628).
- selftests: net: udpgso_bench_tx: Cater for pending datagrams
  zerocopy benchmarking (bsc#1012628).
- virtio-net: Keep stop() to follow mirror sequence of open()
  (bsc#1012628).
- net: openvswitch: fix flow memory leak in ovs_flow_cmd_new
  (bsc#1012628).
- efi: fix potential NULL deref in efi_mem_reserve_persistent
  (bsc#1012628).
- rtc: sunplus: fix format string for printing resource
  (bsc#1012628).
- certs: Fix build error when PKCS#11 URI contains semicolon
  (bsc#1012628).
- kbuild: modinst: Fix build error when CONFIG_MODULE_SIG_KEY
  is a PKCS#11 URI (bsc#1012628).
- i2c: designware-pci: Add new PCI IDs for AMD NAVI GPU
  (bsc#1012628).
- i2c: mxs: suppress probe-deferral error message (bsc#1012628).
- scsi: target: core: Fix warning on RT kernels (bsc#1012628).
- x86/aperfmperf: Erase stale arch_freq_scale values when
  disabling frequency invariance readings (bsc#1012628).
- perf/x86/intel: Add Emerald Rapids (bsc#1012628).
- perf/x86/intel/cstate: Add Emerald Rapids (bsc#1012628).
- scsi: iscsi_tcp: Fix UAF during logout when accessing the
  shost ipaddress (bsc#1012628).
- scsi: iscsi_tcp: Fix UAF during login when accessing the shost
  ipaddress (bsc#1012628).
- i2c: rk3x: fix a bunch of kernel-doc warnings (bsc#1012628).
- Revert "gfs2: stop using generic_writepages in
  gfs2_ail1_start_one" (bsc#1012628).
- x86/build: Move '-mindirect-branch-cs-prefix' out of GCC-only
  block (bsc#1012628).
- platform/x86: dell-wmi: Add a keymap for KEY_MUTE in type
  0x0010 table (bsc#1012628).
- platform/x86: hp-wmi: Handle Omen Key event (bsc#1012628).
- platform/x86: gigabyte-wmi: add support for B450M DS3H WIFI-CF
  (bsc#1012628).
- platform/x86/amd: pmc: Disable IRQ1 wakeup for RN/CZN
  (bsc#1012628).
- net/x25: Fix to not accept on connected socket (bsc#1012628).
- drm/amd/display: Fix timing not changning when freesync video
  is enabled (bsc#1012628).
- bcache: Silence memcpy() run-time false positive warnings
  (bsc#1012628).
- iio: adc: stm32-dfsdm: fill module aliases (bsc#1012628).
- usb: dwc3: qcom: enable vbus override when in OTG dr-mode
  (bsc#1012628).
- usb: gadget: f_fs: Fix unbalanced spinlock in
  __ffs_ep0_queue_wait (bsc#1012628).
- vc_screen: move load of struct vc_data pointer in vcs_read()
  to avoid UAF (bsc#1012628).
- fbcon: Check font dimension limits (bsc#1012628).
- cgroup/cpuset: Fix wrong check in
  update_parent_subparts_cpumask() (bsc#1012628).
- hv_netvsc: Fix missed pagebuf entries in netvsc_dma_map/unmap()
  (bsc#1012628).
- ARM: dts: imx7d-smegw01: Fix USB host over-current polarity
  (bsc#1012628).
- net: qrtr: free memory on error path in radix_tree_insert()
  (bsc#1012628).
- can: isotp: split tx timer into transmission and timeout
  (bsc#1012628).
- can: isotp: handle wait_event_interruptible() return values
  (bsc#1012628).
- watchdog: diag288_wdt: do not use stack buffers for hardware
  data (bsc#1012628).
- watchdog: diag288_wdt: fix __diag288() inline assembly
  (bsc#1012628).
- ALSA: hda/realtek: Add Acer Predator PH315-54 (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs, speaker don't work
  for a HP platform (bsc#1012628).
- ASoC: codecs: wsa883x: correct playback min/max rates
  (bsc#1012628).
- ASoC: SOF: sof-audio: unprepare when swidget->use_count > 0
  (bsc#1012628).
- ASoC: SOF: sof-audio: skip prepare/unprepare if swidget is NULL
  (bsc#1012628).
- ASoC: SOF: keep prepare/unprepare widgets in sink path
  (bsc#1012628).
- efi: Accept version 2 of memory attributes table (bsc#1012628).
- rtc: efi: Enable SET/GET WAKEUP services as optional
  (bsc#1012628).
- iio: hid: fix the retval in accel_3d_capture_sample
  (bsc#1012628).
- iio: hid: fix the retval in gyro_3d_capture_sample
  (bsc#1012628).
- iio: adc: xilinx-ams: fix devm_krealloc() return value check
  (bsc#1012628).
- iio: adc: berlin2-adc: Add missing of_node_put() in error path
  (bsc#1012628).
- iio: imx8qxp-adc: fix irq flood when call imx8qxp_adc_read_raw()
  (bsc#1012628).
- iio:adc:twl6030: Enable measurements of VUSB, VBAT and others
  (bsc#1012628).
- iio: light: cm32181: Fix PM support on system with 2 I2C
  resources (bsc#1012628).
- iio: imu: fxos8700: fix ACCEL measurement range selection
  (bsc#1012628).
- iio: imu: fxos8700: fix incomplete ACCEL and MAGN channels
  readback (bsc#1012628).
- iio: imu: fxos8700: fix IMU data bits returned to user space
  (bsc#1012628).
- iio: imu: fxos8700: fix map label of channel type to MAGN sensor
  (bsc#1012628).
- iio: imu: fxos8700: fix swapped ACCEL and MAGN channels readback
  (bsc#1012628).
- iio: imu: fxos8700: fix incorrect ODR mode readback
  (bsc#1012628).
- iio: imu: fxos8700: fix failed initialization ODR mode
  assignment (bsc#1012628).
- iio: imu: fxos8700: remove definition FXOS8700_CTRL_ODR_MIN
  (bsc#1012628).
- iio: imu: fxos8700: fix MAGN sensor scale and unit
  (bsc#1012628).
- nvmem: brcm_nvram: Add check for kzalloc (bsc#1012628).
- nvmem: sunxi_sid: Always use 32-bit MMIO reads (bsc#1012628).
- nvmem: qcom-spmi-sdam: fix module autoloading (bsc#1012628).
- parisc: Fix return code of pdc_iodc_print() (bsc#1012628).
- parisc: Replace hardcoded value with PRIV_USER constant in
  ptrace.c (bsc#1012628).
- parisc: Wire up PTRACE_GETREGS/PTRACE_SETREGS for compat case
  (bsc#1012628).
- riscv: disable generation of unwind tables (bsc#1012628).
- Revert "mm: kmemleak: alloc gray object for reserved region
  with direct map" (bsc#1012628).
- mm: multi-gen LRU: fix crash during cgroup migration
  (bsc#1012628).
- mm: hugetlb: proc: check for hugetlb shared PMD in
  /proc/PID/smaps (bsc#1012628).
- mm: memcg: fix NULL pointer in
  mem_cgroup_track_foreign_dirty_slowpath() (bsc#1012628).
- usb: gadget: f_uac2: Fix incorrect increment of bNumEndpoints
  (bsc#1012628).
- usb: typec: ucsi: Don't attempt to resume the ports before
  they exist (bsc#1012628).
- usb: gadget: udc: do not clear gadget driver.bus (bsc#1012628).
- kernel/irq/irqdomain.c: fix memory leak with using
  debugfs_lookup() (bsc#1012628).
- HV: hv_balloon: fix memory leak with using debugfs_lookup()
  (bsc#1012628).
- x86/debug: Fix stack recursion caused by wrongly ordered DR7
  accesses (bsc#1012628).
- fpga: m10bmc-sec: Fix probe rollback (bsc#1012628).
- fpga: stratix10-soc: Fix return value check in
  s10_ops_write_init() (bsc#1012628).
- mm/uffd: fix pte marker when fork() without fork event
  (bsc#1012628).
- mm/swapfile: add cond_resched() in get_swap_pages()
  (bsc#1012628).
- mm/khugepaged: fix ->anon_vma race (bsc#1012628).
- mm/MADV_COLLAPSE: catch !none !huge !bad pmd lookups
  (bsc#1012628).
- highmem: round down the address passed to
  kunmap_flush_on_unmap() (bsc#1012628).
- ia64: fix build error due to switch case label appearing next
  to declaration (bsc#1012628).
- Squashfs: fix handling and sanity checking of xattr_ids count
  (bsc#1012628).
- maple_tree: fix mas_empty_area_rev() lower bound validation
  (bsc#1012628).
- migrate: hugetlb: check for hugetlb shared PMD in node migration
  (bsc#1012628).
- dma-buf: actually set signaling bit for private stub fences
  (bsc#1012628).
- serial: stm32: Merge hard IRQ and threaded IRQ handling into
  single IRQ handler (bsc#1012628).
- drm/i915: Avoid potential vm use-after-free (bsc#1012628).
- drm/i915: Fix potential bit_17 double-free (bsc#1012628).
- drm/amd: Fix initialization for nbio 4.3.0 (bsc#1012628).
- drm/amd/pm: drop unneeded dpm features disablement for SMU
  13.0.4/11 (bsc#1012628).
- drm/amdgpu: update wave data type to 3 for gfx11 (bsc#1012628).
- nvmem: core: initialise nvmem->id early (bsc#1012628).
- nvmem: core: remove nvmem_config wp_gpio (bsc#1012628).
- nvmem: core: fix cleanup after dev_set_name() (bsc#1012628).
- nvmem: core: fix registration vs use race (bsc#1012628).
- nvmem: core: fix device node refcounting (bsc#1012628).
- nvmem: core: fix cell removal on error (bsc#1012628).
- nvmem: core: fix return value (bsc#1012628).
- phy: qcom-qmp-combo: fix runtime suspend (bsc#1012628).
- serial: 8250_dma: Fix DMA Rx completion race (bsc#1012628).
- serial: 8250_dma: Fix DMA Rx rearm race (bsc#1012628).
- platform/x86/amd: pmc: add CONFIG_SERIO dependency
  (bsc#1012628).
- ASoC: SOF: sof-audio: prepare_widgets: Check swidget for NULL
  on sink failure (bsc#1012628).
- iio:adc:twl6030: Enable measurement of VAC (bsc#1012628).
- powerpc/64s/radix: Fix crash with unaligned relocated kernel
  (bsc#1012628).
- powerpc/64s: Fix local irq disable when PMIs are disabled
  (bsc#1012628).
- powerpc/imc-pmu: Revert nest_init_lock to being a mutex
  (bsc#1012628).
- fs/ntfs3: Validate attribute data and valid sizes (bsc#1012628).
- ovl: Use "buf" flexible array for memcpy() destination
  (bsc#1012628).
- f2fs: initialize locks earlier in f2fs_fill_super()
  (bsc#1012628).
- fbdev: smscufx: fix error handling code in ufx_usb_probe
  (bsc#1012628).
- f2fs: fix to do sanity check on i_extra_isize in is_alive()
  (bsc#1012628).
- wifi: brcmfmac: Check the count value of channel spec to
  prevent out-of-bounds reads (bsc#1012628).
- gfs2: Cosmetic gfs2_dinode_{in,out} cleanup (bsc#1012628).
- gfs2: Always check inode size of inline inodes (bsc#1012628).
- bpf: Skip invalid kfunc call in backtrack_insn (bsc#1012628).
- commit 16a4964
* Tue Feb  7 2023 jslaby@suse.cz
- mm, mremap: fix mremap() expanding for vma's with
  vm_ops->close() (bsc#1206359).
  Update to upstream version.
- commit 82ff25b
* Mon Feb  6 2023 jslaby@suse.cz
- Linux 6.1.10 (bsc#1012628).
- net: mctp: purge receive queues on sk destruction (bsc#1012628).
- rust: print: avoid evaluating arguments in `pr_*` macros in
  `unsafe` blocks (bsc#1012628).
- net: fix NULL pointer in skb_segment_list (bsc#1012628).
- gpiolib-acpi: Don't set GPIOs for wakeup in S3 mode
  (bsc#1012628).
- gpiolib: acpi: Add a ignore wakeup quirk for Clevo NL5xRU
  (bsc#1012628).
- nvme-apple: only reset the controller when RTKit is running
  (bsc#1012628).
- cifs: fix return of uninitialized rc in
  dfs_cache_update_tgthint() (bsc#1012628).
- gpiolib: acpi: Allow ignoring wake capability on pins that
  aren't in _AEI (bsc#1012628).
- dmaengine: imx-sdma: Fix a possible memory leak in
  sdma_transfer_init (bsc#1012628).
- HID: playstation: sanity check DualSense calibration data
  (bsc#1012628).
- HID: uclogic: Add support for XP-PEN Deco 01 V2 (bsc#1012628).
- s390: workaround invalid gcc-11 out of bounds read warning
  (bsc#1012628).
- block: fix hctx checks for batch allocation (bsc#1012628).
- ACPI: video: Add backlight=native DMI quirk for Acer Aspire
  4810T (bsc#1012628).
- LoongArch: Get frame info in unwind_start() when regs is not
  available (bsc#1012628).
- blk-cgroup: fix missing pd_online_fn() while activating policy
  (bsc#1012628).
- erofs: clean up parsing of fscache related options
  (bsc#1012628).
- kselftest: Fix error message for unconfigured LLVM builds
  (bsc#1012628).
- ARM: omap1: fix building gpio15xx (bsc#1012628).
- arm64: dts: msm8994-angler: fix the memory map (bsc#1012628).
- mac80211: Fix MLO address translation for multiple bss case
  (bsc#1012628).
- erofs/zmap.c: Fix incorrect offset calculation (bsc#1012628).
- bpf: Skip task with pid=1 in send_signal_common() (bsc#1012628).
- firmware: arm_scmi: Clear stale xfer->hdr.status (bsc#1012628).
- arm64: dts: imx8mq-thor96: fix no-mmc property for SDHCI
  (bsc#1012628).
- arm64: dts: freescale: Fix pca954x i2c-mux node names
  (bsc#1012628).
- ARM: dts: vf610: Fix pca9548 i2c-mux node names (bsc#1012628).
- ARM: dts: imx: Fix pca9547 i2c-mux node name (bsc#1012628).
- commit 2a0570b
* Mon Feb  6 2023 mkubecek@suse.cz
- Update to 6.2-rc7
- commit 225bfb7
* Wed Feb  1 2023 jslaby@suse.cz
- Linux 6.1.9 (bsc#1012628).
- memory: tegra: Remove clients SID override programming
  (bsc#1012628).
- memory: atmel-sdramc: Fix missing clk_disable_unprepare in
  atmel_ramc_probe() (bsc#1012628).
- memory: mvebu-devbus: Fix missing clk_disable_unprepare in
  mvebu_devbus_probe() (bsc#1012628).
- arm64: dts: qcom: sc8280xp: fix primary USB-DP PHY reset
  (bsc#1012628).
- dmaengine: qcom: gpi: Set link_rx bit on GO TRE for rx operation
  (bsc#1012628).
- dmaengine: ti: k3-udma: Do conditional decrement of
  UDMA_CHAN_RT_PEER_BCNT_REG (bsc#1012628).
- soc: imx: imx8mp-blk-ctrl: enable global pixclk with HDMI_TX_PHY
  PD (bsc#1012628).
- arm64: dts: imx8mp-phycore-som: Remove invalid PMIC property
  (bsc#1012628).
- ARM: dts: imx6ul-pico-dwarf: Use 'clock-frequency'
  (bsc#1012628).
- ARM: dts: imx7d-pico: Use 'clock-frequency' (bsc#1012628).
- ARM: dts: imx6qdl-gw560x: Remove incorrect 'uart-has-rtscts'
  (bsc#1012628).
- arm64: dts: verdin-imx8mm: fix dahlia audio playback
  (bsc#1012628).
- arm64: dts: imx8mm-beacon: Fix ecspi2 pinmux (bsc#1012628).
- arm64: dts: verdin-imx8mm: fix dev board audio playback
  (bsc#1012628).
- arm64: dts: imx93-11x11-evk: correct clock and strobe pad
  setting (bsc#1012628).
- ARM: imx: add missing of_node_put() (bsc#1012628).
- soc: imx: imx8mp-blk-ctrl: don't set power device name
  (bsc#1012628).
- arm64: dts: imx8mp: Fix missing GPC Interrupt (bsc#1012628).
- arm64: dts: imx8mp: Fix power-domain typo (bsc#1012628).
- arm64: dts: imx8mp-evk: pcie0-refclk cosmetic cleanup
  (bsc#1012628).
- HID: intel_ish-hid: Add check for ishtp_dma_tx_map
  (bsc#1012628).
- arm64: dts: imx8mm-venice-gw7901: fix USB2 controller OC
  polarity (bsc#1012628).
- soc: imx8m: Fix incorrect check for of_clk_get_by_name()
  (bsc#1012628).
- reset: ti-sci: honor TI_SCI_PROTOCOL setting when not
  COMPILE_TEST (bsc#1012628).
- reset: uniphier-glue: Fix possible null-ptr-deref (bsc#1012628).
- EDAC/highbank: Fix memory leak in highbank_mc_probe()
  (bsc#1012628).
- firmware: arm_scmi: Harden shared memory access in
  fetch_response (bsc#1012628).
- firmware: arm_scmi: Harden shared memory access in
  fetch_notification (bsc#1012628).
- firmware: arm_scmi: Fix virtio channels cleanup on shutdown
  (bsc#1012628).
- interconnect: qcom: msm8996: Provide UFS clocks to A2NoC
  (bsc#1012628).
- interconnect: qcom: msm8996: Fix regmap max_register values
  (bsc#1012628).
- HID: amd_sfh: Fix warning unwind goto (bsc#1012628).
- tomoyo: fix broken dependency on *.conf.default (bsc#1012628).
- RDMA/rxe: Fix inaccurate constants in rxe_type_info
  (bsc#1012628).
- RDMA/rxe: Prevent faulty rkey generation (bsc#1012628).
- erofs: fix kvcalloc() misuse with __GFP_NOFAIL (bsc#1012628).
- arm64: dts: marvell: AC5/AC5X: Fix address for UART1
  (bsc#1012628).
- RDMA/core: Fix ib block iterator counter overflow (bsc#1012628).
- IB/hfi1: Reject a zero-length user expected buffer
  (bsc#1012628).
- IB/hfi1: Reserve user expected TIDs (bsc#1012628).
- IB/hfi1: Fix expected receive setup error exit issues
  (bsc#1012628).
- IB/hfi1: Immediately remove invalid memory from hardware
  (bsc#1012628).
- IB/hfi1: Remove user expected buffer invalidate race
  (bsc#1012628).
- affs: initialize fsdata in affs_truncate() (bsc#1012628).
- PM: AVS: qcom-cpr: Fix an error handling path in cpr_probe()
  (bsc#1012628).
- arm64: dts: qcom: msm8992: Don't use sfpb mutex (bsc#1012628).
- arm64: dts: qcom: msm8992-libra: Fix the memory map
  (bsc#1012628).
- kbuild: export top-level LDFLAGS_vmlinux only to
  scripts/Makefile.vmlinux (bsc#1012628).
- kbuild: fix 'make modules' error when
  CONFIG_DEBUG_INFO_BTF_MODULES=y (bsc#1012628).
- phy: ti: fix Kconfig warning and operator precedence
  (bsc#1012628).
- drm/msm/gpu: Fix potential double-free (bsc#1012628).
- NFSD: fix use-after-free in nfsd4_ssc_setup_dul() (bsc#1012628).
- ARM: dts: at91: sam9x60: fix the ddr clock for sam9x60
  (bsc#1012628).
- drm/vc4: bo: Fix drmm_mutex_init memory hog (bsc#1012628).
- phy: usb: sunplus: Fix potential null-ptr-deref in
  sp_usb_phy_probe() (bsc#1012628).
- bpf: hash map, avoid deadlock with suitable hash mask
  (bsc#1012628).
- amd-xgbe: TX Flow Ctrl Registers are h/w ver dependent
  (bsc#1012628).
- amd-xgbe: Delay AN timeout during KR training (bsc#1012628).
- bpf: Fix pointer-leak due to insufficient speculative store
  bypass mitigation (bsc#1012628).
- drm/vc4: bo: Fix unused variable warning (bsc#1012628).
- phy: rockchip-inno-usb2: Fix missing clk_disable_unprepare()
  in rockchip_usb2phy_power_on() (bsc#1012628).
- net: nfc: Fix use-after-free in local_cleanup() (bsc#1012628).
- net: wan: Add checks for NULL for utdm in undo_uhdlc_init and
  unmap_si_regs (bsc#1012628).
- net: enetc: avoid deadlock in enetc_tx_onestep_tstamp()
  (bsc#1012628).
- net: lan966x: add missing fwnode_handle_put() for ports node
  (bsc#1012628).
- sch_htb: Avoid grafting on htb_destroy_class_offload when
  destroying htb (bsc#1012628).
- gpio: mxc: Protect GPIO irqchip RMW with bgpio spinlock
  (bsc#1012628).
- gpio: mxc: Always set GPIOs used as interrupt source to INPUT
  mode (bsc#1012628).
- wifi: rndis_wlan: Prevent buffer overflow in rndis_query_oid
  (bsc#1012628).
- pinctrl: rockchip: fix reading pull type on rk3568
  (bsc#1012628).
- net: stmmac: Fix queue statistics reading (bsc#1012628).
- net/sched: sch_taprio: fix possible use-after-free
  (bsc#1012628).
- l2tp: convert l2tp_tunnel_list to idr (bsc#1012628).
- l2tp: close all race conditions in l2tp_tunnel_register()
  (bsc#1012628).
- net: usb: sr9700: Handle negative len (bsc#1012628).
- net: mdio: validate parameter addr in mdiobus_get_phy()
  (bsc#1012628).
- HID: check empty report_list in hid_validate_values()
  (bsc#1012628).
- HID: check empty report_list in bigben_probe() (bsc#1012628).
- net: stmmac: fix invalid call to mdiobus_get_phy()
  (bsc#1012628).
- pinctrl: rockchip: fix mux route data for rk3568 (bsc#1012628).
- ARM: dts: stm32: Fix qspi pinctrl phandle for
  stm32mp15xx-dhcor-som (bsc#1012628).
- ARM: dts: stm32: Fix qspi pinctrl phandle for
  stm32mp15xx-dhcom-som (bsc#1012628).
- ARM: dts: stm32: Fix qspi pinctrl phandle for
  stm32mp157c-emstamp-argon (bsc#1012628).
- ARM: dts: stm32: Fix qspi pinctrl phandle for stm32mp151a-prtt1l
  (bsc#1012628).
- HID: revert CHERRY_MOUSE_000C quirk (bsc#1012628).
- block/rnbd-clt: fix wrong max ID in ida_alloc_max (bsc#1012628).
- usb: ucsi: Ensure connector delayed work items are flushed
  (bsc#1012628).
- usb: gadget: f_fs: Prevent race during ffs_ep0_queue_wait
  (bsc#1012628).
- usb: gadget: f_fs: Ensure ep0req is dequeued before free_request
  (bsc#1012628).
- netfilter: conntrack: handle tcp challenge acks during
  connection reuse (bsc#1012628).
- Bluetooth: Fix a buffer overflow in mgmt_mesh_add()
  (bsc#1012628).
- Bluetooth: hci_conn: Fix memory leaks (bsc#1012628).
- Bluetooth: hci_sync: fix memory leak in hci_update_adv_data()
  (bsc#1012628).
- Bluetooth: ISO: Avoid circular locking dependency (bsc#1012628).
- Bluetooth: ISO: Fix possible circular locking dependency
  (bsc#1012628).
- Bluetooth: hci_event: Fix Invalid wait context (bsc#1012628).
- Bluetooth: Fix possible deadlock in rfcomm_sk_state_change
  (bsc#1012628).
- net: ipa: disable ipa interrupt during suspend (bsc#1012628).
- net/mlx5e: Avoid false lock dependency warning on tc_ht even
  more (bsc#1012628).
- net/mlx5: E-switch, Fix setting of reserved fields on
  MODIFY_SCHEDULING_ELEMENT (bsc#1012628).
- net/mlx5e: QoS, Fix wrongfully setting parent_element_id on
  MODIFY_SCHEDULING_ELEMENT (bsc#1012628).
- net/mlx5e: Set decap action based on attr for sample
  (bsc#1012628).
- net/mlx5: E-switch, Fix switchdev mode after devlink reload
  (bsc#1012628).
- net: mlx5: eliminate anonymous module_init & module_exit
  (bsc#1012628).
- drm/panfrost: fix GENERIC_ATOMIC64 dependency (bsc#1012628).
- dmaengine: Fix double increment of client_count in
  dma_chan_get() (bsc#1012628).
- net: macb: fix PTP TX timestamp failure due to packet padding
  (bsc#1012628).
- virtio-net: correctly enable callback during start_xmit
  (bsc#1012628).
- l2tp: prevent lockdep issue in l2tp_tunnel_register()
  (bsc#1012628).
- HID: betop: check shape of output reports (bsc#1012628).
- drm/i915/selftests: Unwind hugepages to drop wakeref on error
  (bsc#1012628).
- cifs: fix potential deadlock in cache_refresh_path()
  (bsc#1012628).
- dmaengine: xilinx_dma: call of_node_put() when breaking out
  of for_each_child_of_node() (bsc#1012628).
- dmaengine: tegra: Fix memory leak in terminate_all()
  (bsc#1012628).
- phy: phy-can-transceiver: Skip warning if no "max-bitrate"
  (bsc#1012628).
- drm/amd/display: fix issues with driver unload (bsc#1012628).
- net: sched: gred: prevent races when adding offloads to stats
  (bsc#1012628).
- nvme-pci: fix timeout request state check (bsc#1012628).
- tcp: avoid the lookup process failing to get sk in ehash table
  (bsc#1012628).
- usb: dwc3: fix extcon dependency (bsc#1012628).
- ptdma: pt_core_execute_cmd() should use spinlock (bsc#1012628).
- device property: fix of node refcount leak in
  fwnode_graph_get_next_endpoint() (bsc#1012628).
- w1: fix deadloop in __w1_remove_master_device() (bsc#1012628).
- w1: fix WARNING after calling w1_process() (bsc#1012628).
- driver core: Fix test_async_probe_init saves device in wrong
  array (bsc#1012628).
- selftests/net: toeplitz: fix race on tpacket_v3 block close
  (bsc#1012628).
- net: dsa: microchip: ksz9477: port map correction in ALU table
  entry register (bsc#1012628).
- thermal: Validate new state in cur_state_store() (bsc#1012628).
- thermal/core: fix error code in
  __thermal_cooling_device_register() (bsc#1012628).
- thermal: core: call put_device() only after device_register()
  fails (bsc#1012628).
- net: stmmac: enable all safety features by default
  (bsc#1012628).
- bnxt: Do not read past the end of test names (bsc#1012628).
- tcp: fix rate_app_limited to default to 1 (bsc#1012628).
- scsi: iscsi: Fix multiple iSCSI session unbind events sent to
  userspace (bsc#1012628).
- ASoC: SOF: pm: Set target state earlier (bsc#1012628).
- ASoC: SOF: pm: Always tear down pipelines before DSP suspend
  (bsc#1012628).
- ASoC: SOF: Add FW state to debugfs (bsc#1012628).
- ASoC: amd: yc: Add Razer Blade 14 2022 into DMI table
  (bsc#1012628).
- spi: cadence: Fix busy cycles calculation (bsc#1012628).
- cpufreq: CPPC: Add u64 casts to avoid overflowing (bsc#1012628).
- cpufreq: Add Tegra234 to cpufreq-dt-platdev blocklist
  (bsc#1012628).
- ASoC: mediatek: mt8186: support rt5682s_max98360 (bsc#1012628).
- ASoC: mediatek: mt8186: Add machine support for max98357a
  (bsc#1012628).
- ASoC: amd: yc: Add ASUS M5402RA into DMI table (bsc#1012628).
- ASoC: support machine driver with max98360 (bsc#1012628).
- kcsan: test: don't put the expect array on the stack
  (bsc#1012628).
- cpufreq: Add SM6375 to cpufreq-dt-platdev blocklist
  (bsc#1012628).
- ASoC: fsl_micfil: Correct the number of steps on SX controls
  (bsc#1012628).
- drm/msm/a6xx: Avoid gx gbit halt during rpm suspend
  (bsc#1012628).
- net: usb: cdc_ether: add support for Thales Cinterion PLS62-W
  modem (bsc#1012628).
- drm: Add orientation quirk for Lenovo ideapad D330-10IGL
  (bsc#1012628).
- s390/debug: add _ASM_S390_ prefix to header guard (bsc#1012628).
- s390: expicitly align _edata and _end symbols on page boundary
  (bsc#1012628).
- xen/pvcalls: free active map buffer on pvcalls_front_free_map
  (bsc#1012628).
- perf/x86/cstate: Add Meteor Lake support (bsc#1012628).
- perf/x86/msr: Add Meteor Lake support (bsc#1012628).
- perf/x86/msr: Add Emerald Rapids (bsc#1012628).
- perf/x86/intel/uncore: Add Emerald Rapids (bsc#1012628).
- nolibc: fix fd_set type (bsc#1012628).
- tools/nolibc: Fix S_ISxxx macros (bsc#1012628).
- tools/nolibc: fix missing includes causing build issues at -O0
  (bsc#1012628).
- tools/nolibc: prevent gcc from making memset() loop over itself
  (bsc#1012628).
- cpufreq: armada-37xx: stop using 0 as NULL pointer
  (bsc#1012628).
- ASoC: fsl_ssi: Rename AC'97 streams to avoid collisions with
  AC'97 CODEC (bsc#1012628).
- ASoC: fsl-asoc-card: Fix naming of AC'97 CODEC widgets
  (bsc#1012628).
- ACPI: resource: Skip IRQ override on Asus Expertbook B2402CBA
  (bsc#1012628).
- drm/amdkfd: Add sync after creating vram bo (bsc#1012628).
- drm/amdkfd: Fix NULL pointer error for GC 11.0.1 on mGPU
  (bsc#1012628).
- cifs: fix potential memory leaks in session setup (bsc#1012628).
- spi: spidev: remove debug messages that access spidev->spi
  without locking (bsc#1012628).
- KVM: s390: interrupt: use READ_ONCE() before cmpxchg()
  (bsc#1012628).
- scsi: hisi_sas: Use abort task set to reset SAS disks when
  discovered (bsc#1012628).
- scsi: hisi_sas: Set a port invalid only if there are no devices
  attached when refreshing port id (bsc#1012628).
- r8152: add vendor/device ID pair for Microsoft Devkit
  (bsc#1012628).
- platform/x86: touchscreen_dmi: Add info for the CSL Panther
  Tab HD (bsc#1012628).
- platform/x86: asus-nb-wmi: Add alternate mapping for KEY_CAMERA
  (bsc#1012628).
- platform/x86: asus-nb-wmi: Add alternate mapping for
  KEY_SCREENLOCK (bsc#1012628).
- platform/x86: asus-wmi: Add quirk wmi_ignore_fan (bsc#1012628).
- platform/x86: asus-wmi: Ignore fan on E410MA (bsc#1012628).
- platform/x86: simatic-ipc: correct name of a model
  (bsc#1012628).
- platform/x86: simatic-ipc: add another model (bsc#1012628).
- lockref: stop doing cpu_relax in the cmpxchg loop (bsc#1012628).
- ata: pata_cs5535: Don't build on UML (bsc#1012628).
- firmware: coreboot: Check size of table entry and use flex-array
  (bsc#1012628).
- btrfs: zoned: enable metadata over-commit for non-ZNS setup
  (bsc#1012628).
- Revert "selftests/bpf: check null propagation only neither
  reg is PTR_TO_BTF_ID" (bsc#1012628).
- arm64: efi: Recover from synchronous exceptions occurring in
  firmware (bsc#1012628).
- arm64: efi: Avoid workqueue to check whether EFI runtime is live
  (bsc#1012628).
- arm64: efi: Account for the EFI runtime stack in stack unwinder
  (bsc#1012628).
- Bluetooth: hci_sync: cancel cmd_timer if hci_open failed
  (bsc#1012628).
- drm/i915: Allow panel fixed modes to have differing sync
  polarities (bsc#1012628).
- drm/i915: Allow alternate fixed modes always for eDP
  (bsc#1012628).
- drm/amdgpu: complete gfxoff allow signal during suspend without
  delay (bsc#1012628).
- io_uring/msg_ring: fix remote queue to disabled ring
  (bsc#1012628).
- wifi: mac80211: Proper mark iTXQs for resumption (bsc#1012628).
- wifi: mac80211: Fix iTXQ AMPDU fragmentation handling
  (bsc#1012628).
- sched/fair: Check if prev_cpu has highest spare cap in feec()
  (bsc#1012628).
- sched/uclamp: Fix a uninitialized variable warnings
  (bsc#1012628).
- vfio/type1: Respect IOMMU reserved regions in
  vfio_test_domain_fgsp() (bsc#1012628).
- scsi: hpsa: Fix allocation size for scsi_host_alloc()
  (bsc#1012628).
- kvm/vfio: Fix potential deadlock on vfio group_lock
  (bsc#1012628).
- nfsd: don't free files unconditionally in
  __nfsd_file_cache_purge (bsc#1012628).
- module: Don't wait for GOING modules (bsc#1012628).
- ftrace: Export ftrace_free_filter() to modules (bsc#1012628).
- tracing: Make sure trace_printk() can output as soon as it
  can be used (bsc#1012628).
- trace_events_hist: add check for return value of
  'create_hist_field' (bsc#1012628).
- ftrace/scripts: Update the instructions for ftrace-bisect.sh
  (bsc#1012628).
- cifs: Fix oops due to uncleared server->smbd_conn in reconnect
  (bsc#1012628).
- ksmbd: add max connections parameter (bsc#1012628).
- ksmbd: do not sign response to session request for guest login
  (bsc#1012628).
- ksmbd: downgrade ndr version error message to debug
  (bsc#1012628).
- ksmbd: limit pdu length size according to connection status
  (bsc#1012628).
- ovl: fix tmpfile leak (bsc#1012628).
- ovl: fail on invalid uid/gid mapping at copy up (bsc#1012628).
- io_uring/net: cache provided buffer group value for multishot
  receives (bsc#1012628).
- KVM: x86/vmx: Do not skip segment attributes if unusable bit
  is set (bsc#1012628).
- KVM: arm64: GICv4.1: Fix race with doorbell on VPE
  activation/deactivation (bsc#1012628).
- scsi: ufs: core: Fix devfreq deadlocks (bsc#1012628).
- riscv: fix -Wundef warning for CONFIG_RISCV_BOOT_SPINWAIT
  (bsc#1012628).
- thermal: intel: int340x: Protect trip temperature from
  concurrent updates (bsc#1012628).
- regulator: dt-bindings: samsung,s2mps14: add lost
  samsung,ext-control-gpios (bsc#1012628).
- ipv6: fix reachability confirmation with proxy_ndp
  (bsc#1012628).
- ARM: 9280/1: mm: fix warning on phys_addr_t to void pointer
  assignment (bsc#1012628).
- EDAC/device: Respect any driver-supplied workqueue polling value
  (bsc#1012628).
- EDAC/qcom: Do not pass llcc_driv_data as edac_device_ctl_info's
  pvt_info (bsc#1012628).
- platform/x86: thinkpad_acpi: Fix profile modes on Intel
  platforms (bsc#1012628).
- drm/display/dp_mst: Correct the kref of port (bsc#1012628).
- drm/amd/pm: add missing AllowIHInterrupt message mapping for
  SMU13.0.0 (bsc#1012628).
- drm/amdgpu: remove unconditional trap enable on add gfx11 queues
  (bsc#1012628).
- drm/amdgpu/display/mst: Fix mst_state->pbn_div and slot count
  assignments (bsc#1012628).
- drm/amdgpu/display/mst: limit payload to be updated one by one
  (bsc#1012628).
- drm/amdgpu/display/mst: update mst_mgr relevant variable when
  long HPD (bsc#1012628).
- io_uring: inline io_req_task_work_add() (bsc#1012628).
- io_uring: inline __io_req_complete_post() (bsc#1012628).
- io_uring: hold locks for io_req_complete_failed (bsc#1012628).
- io_uring: use io_req_task_complete() in timeout (bsc#1012628).
- io_uring: remove io_req_tw_post_queue (bsc#1012628).
- io_uring: inline __io_req_complete_put() (bsc#1012628).
- net: mana: Fix IRQ name - add PCI and queue number
  (bsc#1012628).
- io_uring: always prep_async for drain requests (bsc#1012628).
- i2c: designware: use casting of u64 in clock multiplication
  to avoid overflow (bsc#1012628).
- i2c: designware: Fix unbalanced suspended flag (bsc#1012628).
- drm/drm_vma_manager: Add drm_vma_node_allow_once()
  (bsc#1012628).
- drm/i915: Fix a memory leak with reused mmap_offset
  (bsc#1012628).
- iavf: fix temporary deadlock and failure to set MAC address
  (bsc#1012628).
- iavf: schedule watchdog immediately when changing primary MAC
  (bsc#1012628).
- netlink: prevent potential spectre v1 gadgets (bsc#1012628).
- net: fix UaF in netns ops registration error path (bsc#1012628).
- net: fec: Use page_pool_put_full_page when freeing rx buffers
  (bsc#1012628).
- nvme: simplify transport specific device attribute handling
  (bsc#1012628).
- nvme: consolidate setting the tagset flags (bsc#1012628).
- nvme-fc: fix initialization order (bsc#1012628).
- drm/i915/selftest: fix intel_selftest_modify_policy argument
  types (bsc#1012628).
- ACPI: video: Add backlight=native DMI quirk for HP Pavilion
  g6-1d80nr (bsc#1012628).
- ACPI: video: Add backlight=native DMI quirk for HP EliteBook
  8460p (bsc#1012628).
- ACPI: video: Add backlight=native DMI quirk for Asus U46E
  (bsc#1012628).
- netfilter: nft_set_rbtree: Switch to node list walk for overlap
  detection (bsc#1012628).
- netfilter: nft_set_rbtree: skip elements in transaction from
  garbage collection (bsc#1012628).
- netlink: annotate data races around nlk->portid (bsc#1012628).
- netlink: annotate data races around dst_portid and dst_group
  (bsc#1012628).
- netlink: annotate data races around sk_state (bsc#1012628).
- ipv4: prevent potential spectre v1 gadget in
  ip_metrics_convert() (bsc#1012628).
- ipv4: prevent potential spectre v1 gadget in fib_metrics_match()
  (bsc#1012628).
- net: dsa: microchip: fix probe of I2C-connected KSZ8563
  (bsc#1012628).
- net: ethernet: adi: adin1110: Fix multicast offloading
  (bsc#1012628).
- netfilter: conntrack: fix vtag checks for
  ABORT/SHUTDOWN_COMPLETE (bsc#1012628).
- netrom: Fix use-after-free of a listening socket (bsc#1012628).
- platform/x86: asus-wmi: Fix kbd_dock_devid tablet-switch
  reporting (bsc#1012628).
- platform/x86: apple-gmux: Move port defines to apple-gmux.h
  (bsc#1012628).
- platform/x86: apple-gmux: Add apple_gmux_detect() helper
  (bsc#1012628).
- ACPI: video: Fix apple gmux detection (bsc#1012628).
- tracing/osnoise: Use built-in RCU list checking (bsc#1012628).
- net/sched: sch_taprio: do not schedule in taprio_reset()
  (bsc#1012628).
- sctp: fail if no bound addresses can be used for a given scope
  (bsc#1012628).
- riscv/kprobe: Fix instruction simulation of JALR (bsc#1012628).
- nvme: fix passthrough csi check (bsc#1012628).
- gpio: mxc: Unlock on error path in mxc_flip_edge()
  (bsc#1012628).
- gpio: ep93xx: Fix port F hwirq numbers in handler (bsc#1012628).
- net: ravb: Fix lack of register setting after system resumed
  for Gen3 (bsc#1012628).
- net: ravb: Fix possible hang if RIS2_QFF1 happen (bsc#1012628).
- net: mctp: add an explicit reference from a mctp_sk_key to sock
  (bsc#1012628).
- net: mctp: move expiry timer delete to unhash (bsc#1012628).
- net: mctp: hold key reference when looking up a general key
  (bsc#1012628).
- net: mctp: mark socks as dead on unhash, prevent re-add
  (bsc#1012628).
- thermal: intel: int340x: Add locking to
  int340x_thermal_get_trip_type() (bsc#1012628).
- riscv: Move call to init_cpu_topology() to later initialization
  stage (bsc#1012628).
- net/tg3: resolve deadlock in tg3_reset_task() during EEH
  (bsc#1012628).
- tsnep: Fix TX queue stop/wake for multiple queues (bsc#1012628).
- net: mdio-mux-meson-g12a: force internal PHY off on mux switch
  (bsc#1012628).
- Partially revert "perf/arm-cmn: Optimise DTC counter accesses"
  (bsc#1012628).
- block: ublk: move ublk_chr_class destroying after devices are
  removed (bsc#1012628).
- treewide: fix up files incorrectly marked executable
  (bsc#1012628).
- tools: gpio: fix -c option of gpio-event-mon (bsc#1012628).
- Fix up more non-executable files marked executable
  (bsc#1012628).
- Revert "Input: synaptics - switch touchpad on HP Laptop
  15-da3001TU to RMI mode" (bsc#1012628).
- Input: i8042 - add Clevo PCX0DX to i8042 quirk table
  (bsc#1012628).
- x86/sev: Add SEV-SNP guest feature negotiation support
  (bsc#1012628).
- acpi: Fix suspend with Xen PV (bsc#1012628).
- dt-bindings: riscv: fix underscore requirement for multi-letter
  extensions (bsc#1012628).
- dt-bindings: riscv: fix single letter canonical order
  (bsc#1012628).
- x86/i8259: Mark legacy PIC interrupts with IRQ_LEVEL
  (bsc#1012628).
- dt-bindings: i2c: renesas,rzv2m: Fix SoC specific string
  (bsc#1012628).
- netfilter: conntrack: unify established states for SCTP paths
  (bsc#1012628).
- perf/x86/amd: fix potential integer overflow on shift of a int
  (bsc#1012628).
- amdgpu: fix build on non-DCN platforms (bsc#1012628).
- Update config files.
- commit 79d6a70
* Mon Jan 30 2023 jslaby@suse.cz
- Revert "mm/compaction: fix set skip in fast_find_migrateblock"
  (bsc#1206848).
  Update upstream status.
- commit e426c74
* Mon Jan 30 2023 mkubecek@suse.cz
- Update to 6.2-rc6
- eliminate 1 patch
  - patches.suse/0001-Revert-mm-compaction-fix-set-skip-in-fast_find_migra.patch
- commit 4fa09ed
* Tue Jan 24 2023 tiwai@suse.de
- ACPI: EC: Fix ECDT probe ordering issues (bsc#1207149).
- ACPI: EC: Fix EC address space handler unregistration
  (bsc#1207149).
- ACPICA: Allow address_space_handler Install and _REG execution
  as 2 separate steps (bsc#1207149).
- ACPICA: include/acpi/acpixf.h: Fix indentation (bsc#1207149).
- commit 2d8f09a
* Tue Jan 24 2023 jslaby@suse.cz
- Linux 6.1.8 (bsc#1012628).
- dma-buf: fix dma_buf_export init order v2 (bsc#1012628).
- btrfs: fix trace event name typo for FLUSH_DELAYED_REFS
  (bsc#1012628).
- wifi: iwlwifi: fw: skip PPAG for JF (bsc#1012628).
- pNFS/filelayout: Fix coalescing test for single DS
  (bsc#1012628).
- selftests/bpf: check null propagation only neither reg is
  PTR_TO_BTF_ID (bsc#1012628).
- net: ethernet: marvell: octeontx2: Fix uninitialized variable
  warning (bsc#1012628).
- tools/virtio: initialize spinlocks in vring_test.c
  (bsc#1012628).
- vdpa/mlx5: Return error on vlan ctrl commands if not supported
  (bsc#1012628).
- vdpa/mlx5: Avoid using reslock in event_handler (bsc#1012628).
- vdpa/mlx5: Avoid overwriting CVQ iotlb (bsc#1012628).
- virtio_pci: modify ENOENT to EINVAL (bsc#1012628).
- vduse: Validate vq_num in vduse_validate_config() (bsc#1012628).
- vdpa_sim_net: should not drop the multicast/broadcast packet
  (bsc#1012628).
- net/ethtool/ioctl: return -EOPNOTSUPP if we have no phy stats
  (bsc#1012628).
- r8169: move rtl_wol_enable_rx() and rtl_prepare_power_down()
  (bsc#1012628).
- r8169: fix dmar pte write access is not set error (bsc#1012628).
- bpf: keep a reference to the mm, in case the task is dead
  (bsc#1012628).
- RDMA/srp: Move large values to a new enum for gcc13
  (bsc#1012628).
- selftests: net: fix cmsg_so_mark.sh test hang (bsc#1012628).
- btrfs: always report error in run_one_delayed_ref()
  (bsc#1012628).
- x86/asm: Fix an assembler warning with current binutils
  (bsc#1012628).
- f2fs: let's avoid panic if extent_tree is not created
  (bsc#1012628).
- perf/x86/rapl: Treat Tigerlake like Icelake (bsc#1012628).
- cifs: fix race in assemble_neg_contexts() (bsc#1012628).
- memblock tests: Fix compilation error (bsc#1012628).
- perf/x86/rapl: Add support for Intel Meteor Lake (bsc#1012628).
- perf/x86/rapl: Add support for Intel Emerald Rapids
  (bsc#1012628).
- of: fdt: Honor CONFIG_CMDLINE* even without /chosen node,
  take 2 (bsc#1012628).
- fbdev: omapfb: avoid stack overflow warning (bsc#1012628).
- Bluetooth: hci_sync: Fix use HCI_OP_LE_READ_BUFFER_SIZE_V2
  (bsc#1012628).
- Bluetooth: hci_qca: Fix driver shutdown on closed serdev
  (bsc#1012628).
- wifi: brcmfmac: fix regression for Broadcom PCIe wifi devices
  (bsc#1012628).
- wifi: mac80211: fix MLO + AP_VLAN check (bsc#1012628).
- wifi: mac80211: reset multiple BSSID options in stop_ap()
  (bsc#1012628).
- wifi: mac80211: sdata can be NULL during AMPDU start
  (bsc#1012628).
- nommu: fix memory leak in do_mmap() error path (bsc#1012628).
- nommu: fix do_munmap() error path (bsc#1012628).
- nommu: fix split_vma() map_count error (bsc#1012628).
- proc: fix PIE proc-empty-vm, proc-pid-vm tests (bsc#1012628).
- Add exception protection processing for vd in
  axi_chan_handle_err function (bsc#1012628).
- LoongArch: Add HWCAP_LOONGARCH_CPUCFG to elf_hwcap
  (bsc#1012628).
- zonefs: Detect append writes at invalid locations (bsc#1012628).
- nilfs2: fix general protection fault in nilfs_btree_insert()
  (bsc#1012628).
- mm/shmem: restore SHMEM_HUGE_DENY precedence over MADV_COLLAPSE
  (bsc#1012628).
- hugetlb: unshare some PMDs when splitting VMAs (bsc#1012628).
- mm/khugepaged: fix collapse_pte_mapped_thp() to allow anon_vma
  (bsc#1012628).
- serial: stm32: Merge hard IRQ and threaded IRQ handling into
  single IRQ handler (bsc#1012628).
- Revert "serial: stm32: Merge hard IRQ and threaded IRQ handling
  into single IRQ handler" (bsc#1012628).
- xhci-pci: set the dma max_seg_size (bsc#1012628).
- usb: xhci: Check endpoint is valid before dereferencing it
  (bsc#1012628).
- xhci: Fix null pointer dereference when host dies (bsc#1012628).
- xhci: Add update_hub_device override for PCI xHCI hosts
  (bsc#1012628).
- xhci: Add a flag to disable USB3 lpm on a xhci root port level
  (bsc#1012628).
- usb: acpi: add helper to check port lpm capability using acpi
  _DSM (bsc#1012628).
- xhci: Detect lpm incapable xHC USB3 roothub ports from ACPI
  tables (bsc#1012628).
- prlimit: do_prlimit needs to have a speculation check
  (bsc#1012628).
- USB: serial: option: add Quectel EM05-G (GR) modem
  (bsc#1012628).
- USB: serial: option: add Quectel EM05-G (CS) modem
  (bsc#1012628).
- USB: serial: option: add Quectel EM05-G (RS) modem
  (bsc#1012628).
- USB: serial: option: add Quectel EC200U modem (bsc#1012628).
- USB: serial: option: add Quectel EM05CN (SG) modem
  (bsc#1012628).
- USB: serial: option: add Quectel EM05CN modem (bsc#1012628).
- staging: vchiq_arm: fix enum vchiq_status return types
  (bsc#1012628).
- USB: misc: iowarrior: fix up header size for
  USB_DEVICE_ID_CODEMERCS_IOW100 (bsc#1012628).
- usb: misc: onboard_hub: Invert driver registration order
  (bsc#1012628).
- usb: misc: onboard_hub: Move 'attach' work to the driver
  (bsc#1012628).
- misc: fastrpc: Fix use-after-free and race in fastrpc_map_find
  (bsc#1012628).
- misc: fastrpc: Don't remove map on creater_process and
  device_release (bsc#1012628).
- misc: fastrpc: Fix use-after-free race condition for maps
  (bsc#1012628).
- usb: core: hub: disable autosuspend for TI TUSB8041
  (bsc#1012628).
- comedi: adv_pci1760: Fix PWM instruction handling (bsc#1012628).
- ACPI: PRM: Check whether EFI runtime is available (bsc#1012628).
- mmc: sunxi-mmc: Fix clock refcount imbalance during unbind
  (bsc#1012628).
- mmc: sdhci-esdhc-imx: correct the tuning start tap and step
  setting (bsc#1012628).
- mm/hugetlb: fix PTE marker handling in
  hugetlb_change_protection() (bsc#1012628).
- mm/hugetlb: fix uffd-wp handling for migration entries in
  hugetlb_change_protection() (bsc#1012628).
- mm/hugetlb: pre-allocate pgtable pages for uffd wr-protects
  (bsc#1012628).
- mm/userfaultfd: enable writenotify while userfaultfd-wp is
  enabled for a VMA (bsc#1012628).
- mm/MADV_COLLAPSE: don't expand collapse when vm_end is past
  requested end (bsc#1012628).
- btrfs: add extra error messages to cover non-ENOMEM errors
  from device_add_list() (bsc#1012628).
- btrfs: fix missing error handling when logging directory items
  (bsc#1012628).
- btrfs: fix directory logging due to race with concurrent index
  key deletion (bsc#1012628).
- btrfs: add missing setup of log for full commit at
  add_conflicting_inode() (bsc#1012628).
- btrfs: do not abort transaction on failure to write log tree
  when syncing log (bsc#1012628).
- btrfs: do not abort transaction on failure to update log root
  (bsc#1012628).
- btrfs: fix invalid leaf access due to inline extent during lseek
  (bsc#1012628).
- btrfs: fix race between quota rescan and disable leading to
  NULL pointer deref (bsc#1012628).
- cifs: do not include page data when checking signature
  (bsc#1012628).
- thunderbolt: Disable XDomain lane 1 only in software connection
  manager (bsc#1012628).
- thunderbolt: Use correct function to calculate maximum USB3
  link rate (bsc#1012628).
- thunderbolt: Do not report errors if on-board retimers are found
  (bsc#1012628).
- thunderbolt: Do not call PM runtime functions in
  tb_retimer_scan() (bsc#1012628).
- riscv: dts: sifive: fu740: fix size of pcie 32bit memory
  (bsc#1012628).
- bpf: restore the ebpf program ID for BPF_AUDIT_UNLOAD and
  PERF_BPF_EVENT_PROG_UNLOAD (bsc#1012628).
- tty: serial: qcom-geni-serial: fix slab-out-of-bounds on RX
  FIFO buffer (bsc#1012628).
- tty: fix possible null-ptr-defer in spk_ttyio_release
  (bsc#1012628).
- pktcdvd: check for NULL returna fter calling
  bio_split_to_limits() (bsc#1012628).
- io_uring/poll: don't reissue in case of poll race on multishot
  request (bsc#1012628).
- mptcp: explicitly specify sock family at subflow creation time
  (bsc#1012628).
- mptcp: netlink: respect v4/v6-only sockets (bsc#1012628).
- selftests: mptcp: userspace: validate v4-v6 subflows mix
  (bsc#1012628).
- USB: gadgetfs: Fix race between mounting and unmounting
  (bsc#1012628).
- USB: serial: cp210x: add SCALANCE LPE-9000 device id
  (bsc#1012628).
- usb: cdns3: remove fetched trb from cache before dequeuing
  (bsc#1012628).
- usb: host: ehci-fsl: Fix module alias (bsc#1012628).
- usb: musb: fix error return code in omap2430_probe()
  (bsc#1012628).
- usb: typec: tcpm: Fix altmode re-registration causes sysfs
  create fail (bsc#1012628).
- usb: typec: altmodes/displayport: Add pin assignment helper
  (bsc#1012628).
- usb: typec: altmodes/displayport: Fix pin assignment calculation
  (bsc#1012628).
- usb: gadget: g_webcam: Send color matching descriptor per frame
  (bsc#1012628).
- USB: gadget: Add ID numbers to configfs-gadget driver names
  (bsc#1012628).
- usb: gadget: f_ncm: fix potential NULL ptr deref in
  ncm_bitrate() (bsc#1012628).
- usb-storage: apply IGNORE_UAS only for HIKSEMI MD202 on RTL9210
  (bsc#1012628).
- arm64: dts: imx8mp: correct usb clocks (bsc#1012628).
- dt-bindings: phy: g12a-usb2-phy: fix compatible string
  documentation (bsc#1012628).
- dt-bindings: phy: g12a-usb3-pcie-phy: fix compatible string
  documentation (bsc#1012628).
- serial: pch_uart: Pass correct sg to dma_unmap_sg()
  (bsc#1012628).
- dmaengine: lgm: Move DT parsing after initialization
  (bsc#1012628).
- dmaengine: tegra210-adma: fix global intr clear (bsc#1012628).
- dmaengine: idxd: Let probe fail when workqueue cannot be enabled
  (bsc#1012628).
- dmaengine: idxd: Prevent use after free on completion memory
  (bsc#1012628).
- dmaengine: idxd: Do not call DMX TX callbacks during workqueue
  disable (bsc#1012628).
- serial: amba-pl011: fix high priority character transmission
  in rs486 mode (bsc#1012628).
- serial: atmel: fix incorrect baudrate setup (bsc#1012628).
- serial: exar: Add support for Sealevel 7xxxC serial cards
  (bsc#1012628).
- gsmi: fix null-deref in gsmi_get_variable (bsc#1012628).
- mei: bus: fix unlink on bus in error path (bsc#1012628).
- mei: me: add meteor lake point M DID (bsc#1012628).
- VMCI: Use threaded irqs instead of tasklets (bsc#1012628).
- ARM: dts: qcom: apq8084-ifc6540: fix overriding SDHCI
  (bsc#1012628).
- ARM: omap1: fix !ARCH_OMAP1_ANY link failures (bsc#1012628).
- drm/amdgpu: fix amdgpu_job_free_resources v2 (bsc#1012628).
- drm/amdgpu: allow multipipe policy on ASICs with one MEC
  (bsc#1012628).
- drm/amdgpu: Correct the power calcultion for Renior/Cezanne
  (bsc#1012628).
- drm/i915: re-disable RC6p on Sandy Bridge (bsc#1012628).
- drm/i915/display: Check source height is > 0 (bsc#1012628).
- drm/i915: Allow switching away via vga-switcheroo if
  uninitialized (bsc#1012628).
- drm/i915: Remove unused variable (bsc#1012628).
- drm/amd/display: Fix set scaling doesn's work (bsc#1012628).
- drm/amd/display: Calculate output_color_space after pixel
  encoding adjustment (bsc#1012628).
- drm/amd/display: Fix COLOR_SPACE_YCBCR2020_TYPE matrix
  (bsc#1012628).
- drm/amd/display: disable S/G display on DCN 3.1.5 (bsc#1012628).
- drm/amd/display: disable S/G display on DCN 3.1.4 (bsc#1012628).
- cifs: reduce roundtrips on create/qinfo requests (bsc#1012628).
- fs/ntfs3: Fix attr_punch_hole() null pointer derenference
  (bsc#1012628).
- arm64: efi: Execute runtime services from a dedicated stack
  (bsc#1012628).
- efi: rt-wrapper: Add missing include (bsc#1012628).
- panic: Separate sysctl logic from CONFIG_SMP (bsc#1012628).
- exit: Put an upper limit on how often we can oops (bsc#1012628).
- exit: Expose "oops_count" to sysfs (bsc#1012628).
- exit: Allow oops_limit to be disabled (bsc#1012628).
- panic: Consolidate open-coded panic_on_warn checks
  (bsc#1012628).
- panic: Introduce warn_limit (bsc#1012628).
- panic: Expose "warn_count" to sysfs (bsc#1012628).
- docs: Fix path paste-o for /sys/kernel/warn_count (bsc#1012628).
- exit: Use READ_ONCE() for all oops/warn limit reads
  (bsc#1012628).
- x86/fpu: Use _Alignof to avoid undefined behavior in TYPE_ALIGN
  (bsc#1012628).
- drm/amdgpu/discovery: enable soc21 common for GC 11.0.4
  (bsc#1012628).
- drm/amdgpu/discovery: enable gmc v11 for GC 11.0.4
  (bsc#1012628).
- drm/amdgpu/discovery: enable gfx v11 for GC 11.0.4
  (bsc#1012628).
- drm/amdgpu/discovery: enable mes support for GC v11.0.4
  (bsc#1012628).
- drm/amdgpu: set GC 11.0.4 family (bsc#1012628).
- drm/amdgpu/discovery: set the APU flag for GC 11.0.4
  (bsc#1012628).
- drm/amdgpu: add gfx support for GC 11.0.4 (bsc#1012628).
- drm/amdgpu: add gmc v11 support for GC 11.0.4 (bsc#1012628).
- drm/amdgpu/discovery: add PSP IP v13.0.11 support (bsc#1012628).
- drm/amdgpu/pm: enable swsmu for SMU IP v13.0.11 (bsc#1012628).
- drm/amdgpu: add smu 13 support for smu 13.0.11 (bsc#1012628).
- drm/amdgpu/pm: add GFXOFF control IP version check for SMU IP
  v13.0.11 (bsc#1012628).
- drm/amdgpu/soc21: add mode2 asic reset for SMU IP v13.0.11
  (bsc#1012628).
- drm/amdgpu/pm: use the specific mailbox registers only for
  SMU IP v13.0.4 (bsc#1012628).
- drm/amdgpu/discovery: enable nbio support for NBIO v7.7.1
  (bsc#1012628).
- drm/amdgpu: enable PSP IP v13.0.11 support (bsc#1012628).
- drm/amdgpu: enable GFX IP v11.0.4 CG support (bsc#1012628).
- drm/amdgpu: enable GFX Power Gating for GC IP v11.0.4
  (bsc#1012628).
- drm/amdgpu: enable GFX Clock Gating control for GC IP v11.0.4
  (bsc#1012628).
- drm/amdgpu: add tmz support for GC 11.0.1 (bsc#1012628).
- drm/amdgpu: add tmz support for GC IP v11.0.4 (bsc#1012628).
- drm/amdgpu: correct MEC number for gfx11 APUs (bsc#1012628).
- octeontx2-pf: Avoid use of GFP_KERNEL in atomic context
  (bsc#1012628).
- net/ulp: use consistent error code when blocking ULP
  (bsc#1012628).
- octeontx2-pf: Fix the use of GFP_KERNEL in atomic context on rt
  (bsc#1012628).
- net/mlx5: fix missing mutex_unlock in
  mlx5_fw_fatal_reporter_err_work() (bsc#1012628).
- block: mq-deadline: Rename deadline_is_seq_writes()
  (bsc#1012628).
- Revert "wifi: mac80211: fix memory leak in ieee80211_if_add()"
  (bsc#1012628).
- soc: qcom: apr: Make qcom,protection-domain optional again
  (bsc#1012628).
- commit baebfe0
* Mon Jan 23 2023 jslaby@suse.cz
- Update config files.
  Only run oldconfig. This is a left-over from commit 2ebd33fc0df1 (Update
  config files. Set saa7146 to pre-6.1 state (bsc#1206774)).
- commit 7ea99cf
* Mon Jan 23 2023 jslaby@suse.cz
- btrfs: qgroup: do not warn on record without old_roots populated
  (bsc#1206681).
- commit ab906a1
* Mon Jan 23 2023 jslaby@suse.cz
- Refresh
  patches.suse/v4-wifi-mac80211-fix-initialization-of-rx--link-and-rx--link_sta.patch.
  Update to upstream version.
- commit a02770c
* Sun Jan 22 2023 mkubecek@suse.cz
- objtool: Check that module init/exit function is an indirect
  call target.
- commit 39a491d
* Sun Jan 22 2023 mkubecek@suse.cz
- Update to 6.2-rc5
- refresh configs
- commit e1e1e9c
* Fri Jan 20 2023 jslaby@suse.cz
- Update config files. Set saa7146 to pre-6.1 state (bsc#1206774).
  The driver was moved to staging and disabled by us in 6.1. Now it turned
  out it is actually used. So the driver is getting cleaned up. So enable
  it even when it is in staging, so that users can use it properly.
- commit 2ebd33f
* Fri Jan 20 2023 ddiss@suse.de
- git_sort: add usb-linus branch for gregkh/usb
- commit 9c240f9
* Wed Jan 18 2023 jslaby@suse.cz
- Linux 6.1.7 (bsc#1012628).
- netfilter: nft_payload: incorrect arithmetics when fetching
  VLAN header bits (bsc#1012628).
- ALSA: control-led: use strscpy in set_led_id() (bsc#1012628).
- ALSA: usb-audio: Always initialize fixed_rate in
  snd_usb_find_implicit_fb_sync_format() (bsc#1012628).
- ALSA: hda/realtek - Turn on power early (bsc#1012628).
- ALSA: hda/realtek: Enable mute/micmute LEDs on HP Spectre x360
  13-aw0xxx (bsc#1012628).
- KVM: x86: Do not return host topology information from
  KVM_GET_SUPPORTED_CPUID (bsc#1012628).
- KVM: arm64: Fix S1PTW handling on RO memslots (bsc#1012628).
- efi: fix userspace infinite retry read efivars after EFI
  runtime services page fault (bsc#1012628).
- efi: tpm: Avoid READ_ONCE() for accessing the event log
  (bsc#1012628).
- io_uring/poll: add hash if ready poll request can't complete
  inline (bsc#1012628).
- arm64: mte: Fix double-freeing of the temporary tag storage
  during coredump (bsc#1012628).
- arm64: mte: Avoid the racy walk of the vma list during core dump
  (bsc#1012628).
- arm64: cmpxchg_double*: hazard against entire exchange variable
  (bsc#1012628).
- ACPI: Fix selecting wrong ACPI fwnode for the iGPU on some
  Dell laptops (bsc#1012628).
- net: stmmac: add aux timestamps fifo clearance wait
  (bsc#1012628).
- perf auxtrace: Fix address filter duplicate symbol selection
  (bsc#1012628).
- s390/kexec: fix ipl report address for kdump (bsc#1012628).
- brcmfmac: Prefer DT board type over DMI board type
  (bsc#1012628).
- ASoC: qcom: lpass-cpu: Fix fallback SD line index handling
  (bsc#1012628).
- elfcore: Add a cprm parameter to
  elf_core_extra_{phdrs,data_size} (bsc#1012628).
- cpufreq: amd-pstate: fix kernel hang issue while amd-pstate
  unregistering (bsc#1012628).
- s390/cpum_sf: add READ_ONCE() semantics to compare and swap
  loops (bsc#1012628).
- s390/percpu: add READ_ONCE() to arch_this_cpu_to_op_simple()
  (bsc#1012628).
- drm/virtio: Fix GEM handle creation UAF (bsc#1012628).
- drm/amd/pm/smu13: BACO is supported when it's in BACO state
  (bsc#1012628).
- drm: Optimize drm buddy top-down allocation method
  (bsc#1012628).
- drm/i915/gt: Reset twice (bsc#1012628).
- drm/i915: Reserve enough fence slot for i915_vma_unbind_async
  (bsc#1012628).
- drm/i915: Fix potential context UAFs (bsc#1012628).
- drm/amd: Delay removal of the firmware framebuffer
  (bsc#1012628).
- drm/amdgpu: Fixed bug on error when unloading amdgpu
  (bsc#1012628).
- drm/amd/pm: correct the reference clock for fan speed(rpm)
  calculation (bsc#1012628).
- drm/amd/pm: add the missing mapping for PPT feature on SMU13.0.0
  and 13.0.7 (bsc#1012628).
- drm/amd/display: move remaining FPU code to dml folder
  (bsc#1012628).
- Revert "drm/amdgpu: Revert "drm/amdgpu: getting fan speed pwm
  for vega10 properly"" (bsc#1012628).
- cifs: Fix uninitialized memory read for smb311 posix symlink
  create (bsc#1012628).
- cifs: fix file info setting in cifs_query_path_info()
  (bsc#1012628).
- cifs: fix file info setting in cifs_open_file() (bsc#1012628).
- cifs: do not query ifaces on smb1 mounts (bsc#1012628).
- cifs: fix double free on failed kerberos auth (bsc#1012628).
- io_uring/fdinfo: include locked hash table in fdinfo output
  (bsc#1012628).
- ASoC: rt9120: Make dev PM runtime bind AsoC component PM
  (bsc#1012628).
- ACPI: video: Allow selecting NVidia-WMI-EC or Apple GMUX
  backlight from the cmdline (bsc#1012628).
- platform/x86: dell-privacy: Only register SW_CAMERA_LENS_COVER
  if present (bsc#1012628).
- platform/surface: aggregator: Ignore command messages not
  intended for us (bsc#1012628).
- platform/x86: int3472/discrete: Ensure the clk/power enable
  pins are in output mode (bsc#1012628).
- platform/x86: thinkpad_acpi: Fix profile mode display in AMT
  mode (bsc#1012628).
- platform/x86: asus-wmi: Don't load fan curves without fan
  (bsc#1012628).
- platform/x86: dell-privacy: Fix SW_CAMERA_LENS_COVER reporting
  (bsc#1012628).
- dt-bindings: msm: dsi-controller-main: Fix operating-points-v2
  constraint (bsc#1012628).
- drm/msm: another fix for the headless Adreno GPU (bsc#1012628).
- firmware/psci: Fix MEM_PROTECT_RANGE function numbers
  (bsc#1012628).
- firmware/psci: Don't register with debugfs if PSCI isn't
  available (bsc#1012628).
- drm/msm/adreno: Make adreno quirks not overwrite each other
  (bsc#1012628).
- arm64/signal: Always allocate SVE signal frames on SME only
  systems (bsc#1012628).
- dt-bindings: msm: dsi-controller-main: Fix power-domain
  constraint (bsc#1012628).
- dt-bindings: msm: dsi-controller-main: Fix description of core
  clock (bsc#1012628).
- arm64/signal: Always accept SVE signal frames on SME only
  systems (bsc#1012628).
- arm64/mm: add pud_user_exec() check in
  pud_user_accessible_page() (bsc#1012628).
- dt-bindings: msm: dsi-phy-28nm: Add missing qcom,
  dsi-phy-regulator-ldo-mode (bsc#1012628).
- arm64: ptrace: Use ARM64_SME to guard the SME register
  enumerations (bsc#1012628).
- arm64/mm: fix incorrect file_map_count for invalid pmd
  (bsc#1012628).
- platform/x86: ideapad-laptop: Add Legion 5 15ARH05 DMI id to
  set_fn_lock_led_list[] (bsc#1012628).
- drm/msm/dp: do not complete dp_aux_cmd_fifo_tx() if irq is
  not for aux transfer (bsc#1012628).
- dt-bindings: msm/dsi: Don't require vdds-supply on 10nm PHY
  (bsc#1012628).
- dt-bindings: msm/dsi: Don't require vcca-supply on 14nm PHY
  (bsc#1012628).
- platform/x86: sony-laptop: Don't turn off 0x153 keyboard
  backlight during probe (bsc#1012628).
- ixgbe: fix pci device refcount leak (bsc#1012628).
- ipv6: raw: Deduct extension header length in
  rawv6_push_pending_frames (bsc#1012628).
- iavf/iavf_main: actually log ->src mask when talking about it
  (bsc#1012628).
- drm/i915/gt: Cleanup partial engine discovery failures
  (bsc#1012628).
- usb: ulpi: defer ulpi_register on ulpi_read_id timeout
  (bsc#1012628).
- drm/amd/pm: enable mode1 reset on smu_v13_0_10 (bsc#1012628).
- drm/amd/pm: Enable bad memory page/channel recording support
  for smu v13_0_0 (bsc#1012628).
- drm/amd/pm: enable GPO dynamic control support for SMU13.0.0
  (bsc#1012628).
- drm/amd/pm: enable GPO dynamic control support for SMU13.0.7
  (bsc#1012628).
- drm/amdgpu: add soc21 common ip block support for GC 11.0.4
  (bsc#1012628).
- drm/amdgpu: Enable pg/cg flags on GC11_0_4 for VCN
  (bsc#1012628).
- drm/amdgpu: enable VCN DPG for GC IP v11.0.4 (bsc#1012628).
- mm: Always release pages to the buddy allocator in
  memblock_free_late() (bsc#1012628).
- iommu/iova: Fix alloc iova overflows issue (bsc#1012628).
- iommu/arm-smmu-v3: Don't unregister on shutdown (bsc#1012628).
- iommu/mediatek-v1: Fix an error handling path in
  mtk_iommu_v1_probe() (bsc#1012628).
- iommu/arm-smmu: Don't unregister on shutdown (bsc#1012628).
- iommu/arm-smmu: Report IOMMU_CAP_CACHE_COHERENCY even betterer
  (bsc#1012628).
- sched/core: Fix use-after-free bug in dup_user_cpus_ptr()
  (bsc#1012628).
- netfilter: ipset: Fix overflow before widen in the
  bitmap_ip_create() function (bsc#1012628).
- selftests: netfilter: fix transaction test script timeout
  handling (bsc#1012628).
- powerpc/imc-pmu: Fix use of mutex in IRQs disabled section
  (bsc#1012628).
- x86/boot: Avoid using Intel mnemonics in AT&T syntax asm
  (bsc#1012628).
- EDAC/device: Fix period calculation in
  edac_device_reset_delay_period() (bsc#1012628).
- x86/pat: Fix pat_x_mtrr_type() for MTRR disabled case
  (bsc#1012628).
- x86/resctrl: Fix task CLOSID/RMID update race (bsc#1012628).
- x86/resctrl: Fix event counts regression in reused RMIDs
  (bsc#1012628).
- regulator: da9211: Use irq handler when ready (bsc#1012628).
- scsi: storvsc: Fix swiotlb bounce buffer leak in confidential VM
  (bsc#1012628).
- scsi: mpi3mr: Refer CONFIG_SCSI_MPI3MR in Makefile
  (bsc#1012628).
- scsi: ufs: core: WLUN suspend SSU/enter hibern8 fail recovery
  (bsc#1012628).
- ASoC: Intel: fix sof-nau8825 link failure (bsc#1012628).
- ASoC: Intel: sof_nau8825: support rt1015p speaker amplifier
  (bsc#1012628).
- ASoC: Intel: sof-nau8825: fix module alias overflow
  (bsc#1012628).
- drm/msm/dpu: Fix some kernel-doc comments (bsc#1012628).
- drm/msm/dpu: Fix memory leak in msm_mdss_parse_data_bus_icc_path
  (bsc#1012628).
- ASoC: wm8904: fix wrong outputs volume after power reactivation
  (bsc#1012628).
- mtd: parsers: scpart: fix __udivdi3 undefined on mips
  (bsc#1012628).
- mtd: cfi: allow building spi-intel standalone (bsc#1012628).
- stmmac: dwmac-mediatek: remove the dwmac_fix_mac_speed
  (bsc#1012628).
- tipc: fix unexpected link reset due to discovery messages
  (bsc#1012628).
- NFSD: Pass the target nfsd_file to nfsd_commit() (bsc#1012628).
- NFSD: Revert "NFSD: NFSv4 CLOSE should release an nfsd_file
  immediately" (bsc#1012628).
- NFSD: Add an NFSD_FILE_GC flag to enable nfsd_file garbage
  collection (bsc#1012628).
- nfsd: remove the pages_flushed statistic from filecache
  (bsc#1012628).
- nfsd: reorganize filecache.c (bsc#1012628).
- NFSD: Add an nfsd_file_fsync tracepoint (bsc#1012628).
- nfsd: rework refcounting in filecache (bsc#1012628).
- nfsd: fix handling of cached open files in nfsd4_open codepath
  (bsc#1012628).
- octeontx2-af: Fix LMAC config in cgx_lmac_rx_tx_enable
  (bsc#1012628).
- sched/core: Fix arch_scale_freq_tick() on tickless systems
  (bsc#1012628).
- hvc/xen: lock console list traversal (bsc#1012628).
- nfc: pn533: Wait for out_urb's completion in
  pn533_usb_send_frame() (bsc#1012628).
- gro: avoid checking for a failed search (bsc#1012628).
- gro: take care of DODGY packets (bsc#1012628).
- af_unix: selftest: Fix the size of the parameter to connect()
  (bsc#1012628).
- ASoC: qcom: Fix building APQ8016 machine driver without
  SOUNDWIRE (bsc#1012628).
- tools/nolibc: restore mips branch ordering in the _start block
  (bsc#1012628).
- tools/nolibc: fix the O_* fcntl/open macro definitions for riscv
  (bsc#1012628).
- drm/amdgpu: Fix potential NULL dereference (bsc#1012628).
- ice: Fix potential memory leak in ice_gnss_tty_write()
  (bsc#1012628).
- ice: Add check for kzalloc (bsc#1012628).
- drm/vmwgfx: Write the driver id registers (bsc#1012628).
- drm/vmwgfx: Refactor resource manager's hashtable to use
  linux/hashtable implementation (bsc#1012628).
- drm/vmwgfx: Remove ttm object hashtable (bsc#1012628).
- drm/vmwgfx: Refactor resource validation hashtable to use
  linux/hashtable implementation (bsc#1012628).
- drm/vmwgfx: Refactor ttm reference object hashtable to use
  linux/hashtable (bsc#1012628).
- drm/vmwgfx: Remove vmwgfx_hashtab (bsc#1012628).
- drm/vmwgfx: Remove rcu locks from user resources (bsc#1012628).
- net/sched: act_mpls: Fix warning during failed attribute
  validation (bsc#1012628).
- Revert "r8169: disable detection of chip version 36"
  (bsc#1012628).
- net/mlx5: check attr pointer validity before dereferencing it
  (bsc#1012628).
- net/mlx5e: TC, Keep mod hdr actions after mod hdr alloc
  (bsc#1012628).
- net/mlx5: Fix command stats access after free (bsc#1012628).
- net/mlx5e: Verify dev is present for fix features ndo
  (bsc#1012628).
- net/mlx5e: IPoIB, Block queue count configuration when sub
  interfaces are present (bsc#1012628).
- net/mlx5e: IPoIB, Block PKEY interfaces with less rx queues
  than parent (bsc#1012628).
- net/mlx5e: IPoIB, Fix child PKEY interface stats on rx path
  (bsc#1012628).
- net/mlx5: Fix ptp max frequency adjustment range (bsc#1012628).
- net/mlx5e: Don't support encap rules with gbp option
  (bsc#1012628).
- net/mlx5e: Fix macsec ssci attribute handling in offload path
  (bsc#1012628).
- net/mlx5e: Fix macsec possible null dereference when updating
  MAC security entity (SecY) (bsc#1012628).
- selftests/net: l2_tos_ttl_inherit.sh: Set IPv6 addresses with
  "nodad" (bsc#1012628).
- selftests/net: l2_tos_ttl_inherit.sh: Run tests in their own
  netns (bsc#1012628).
- selftests/net: l2_tos_ttl_inherit.sh: Ensure environment
  cleanup on failure (bsc#1012628).
- octeontx2-pf: Fix resource leakage in VF driver unbind
  (bsc#1012628).
- perf build: Properly guard libbpf includes (bsc#1012628).
- perf kmem: Support legacy tracepoints (bsc#1012628).
- perf kmem: Support field "node" in evsel__process_alloc_event()
  coping with recent tracepoint restructuring (bsc#1012628).
- igc: Fix PPS delta between two synchronized end-points
  (bsc#1012628).
- net: lan966x: check for ptp to be enabled in
  lan966x_ptp_deinit() (bsc#1012628).
- net: hns3: fix wrong use of rss size during VF rss config
  (bsc#1012628).
- bnxt: make sure we return pages to the pool (bsc#1012628).
- platform/surface: aggregator: Add missing call to
  ssam_request_sync_free() (bsc#1012628).
- platform/x86/amd: Fix refcount leak in amd_pmc_probe
  (bsc#1012628).
- ALSA: usb-audio: Fix possible NULL pointer dereference in
  snd_usb_pcm_has_fixed_rate() (bsc#1012628).
- efi: fix NULL-deref in init error path (bsc#1012628).
- io_uring: lock overflowing for IOPOLL (bsc#1012628).
- io_uring/poll: attempt request issue after racy poll wakeup
  (bsc#1012628).
- drm/i915: Fix CFI violations in gt_sysfs (bsc#1012628).
- io_uring/io-wq: free worker if task_work creation is canceled
  (bsc#1012628).
- io_uring/io-wq: only free worker if it was allocated for
  creation (bsc#1012628).
- block: handle bio_split_to_limits() NULL return (bsc#1012628).
- Revert "usb: ulpi: defer ulpi_register on ulpi_read_id timeout"
  (bsc#1012628).
- pinctrl: amd: Add dynamic debugging for active GPIOs
  (bsc#1012628).
- Update config files.
- commit 872045c
* Tue Jan 17 2023 vbabka@suse.cz
- mm, mremap: fix mremap() expanding for vma's with
  vm_ops->close() (bsc#1206359).
- commit e6ff94b
* Tue Jan 17 2023 jslaby@suse.cz
- Refresh
  patches.suse/ALSA-usb-audio-Make-sure-to-stop-endpoints-before-cl.patch.
- Refresh
  patches.suse/ALSA-usb-audio-More-refactoring-of-hw-constraint-rul.patch.
- Refresh
  patches.suse/ALSA-usb-audio-Relax-hw-constraints-for-implicit-fb-.patch.
- Refresh
  patches.suse/Revert-ALSA-usb-audio-Drop-superfluous-interface-set.patch.
- Update
  patches.suse/docs-Fix-the-docs-build-with-Sphinx-6.0.patch
  (sphinx_6.0).
  Update upstream statuses.
- commit ffddea5
* Mon Jan 16 2023 schwab@suse.de
- rpm/mkspec-dtb: add riscv64 dtb-renesas subpackage
- commit 6020754
* Mon Jan 16 2023 msuchanek@suse.de
- Refresh patches.rpmify/bpf_doc-Fix-build-error-with-older-python-versions.patch.
- commit df46e81
* Mon Jan 16 2023 jslaby@suse.cz
- Linux 6.1.6 (bsc#1012628).
- ALSA: hda: cs35l41: Check runtime suspend capability at
  runtime_idle (bsc#1012628).
- ALSA: hda - Enable headset mic on another Dell laptop with
  ALC3254 (bsc#1012628).
- ALSA: hda: cs35l41: Don't return -EINVAL from system
  suspend/resume (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs don't work for a HP
  platform (bsc#1012628).
- ALSA: hda/hdmi: Add a HP device 0x8715 to force connect list
  (bsc#1012628).
- ALSA: pcm: Move rwsem lock inside snd_ctl_elem_read to prevent
  UAF (bsc#1012628).
- net: sched: disallow noqueue for qdisc classes (bsc#1012628).
- gcc: disable -Warray-bounds for gcc-11 too (bsc#1012628).
- Update config files.
- Revert "SUNRPC: Use RMW bitops in single-threaded hot paths"
  (bsc#1012628).
- selftests/vm/pkeys: Add a regression test for setting PKRU
  through ptrace (bsc#1012628).
- x86/fpu: Emulate XRSTOR's behavior if the xfeatures PKRU bit
  is not set (bsc#1012628).
- x86/fpu: Allow PKRU to be (once again) written by ptrace
  (bsc#1012628).
- x86/fpu: Add a pkru argument to copy_uabi_to_xstate()
  (bsc#1012628).
- x86/fpu: Add a pkru argument to
  copy_uabi_from_kernel_to_xstate() (bsc#1012628).
- x86/fpu: Take task_struct* in
  copy_sigframe_from_user_to_xstate() (bsc#1012628).
- parisc: Align parisc MADV_XXX constants with all other
  architectures (bsc#1012628).
- commit 573f4a9
* Sun Jan 15 2023 mkubecek@suse.cz
- Update to 6.2-rc4
- eliminate 2 patches
  - patches.suse/docs-Fix-the-docs-build-with-Sphinx-6.0.patch
  - patches.suse/drm-amdgpu-fix-pipeline-sync-v2.patch
- update configs
  - ARM64_ERRATUM_2645198=y (arm64)
  - SND_SOC_APQ8016_SBC=m (armv7hl/default, value from arm64)
  - SND_SOC_MSM8996=m (armv7hl/default, value from arm64)
  - SND_SOC_SC7180=m (armv7hl/default, value from arm64)
- commit b1ecb39
* Fri Jan 13 2023 vbabka@suse.cz
- Revert "mm/compaction: fix set skip in fast_find_migrateblock"
  (bsc#1206848).
- commit 5049637
* Fri Jan 13 2023 vbabka@suse.cz
- Revert "mm/compaction: fix set skip in fast_find_migrateblock"
  (bsc#1206848).
- commit e99ed0e
* Fri Jan 13 2023 mkubecek@suse.cz
- drm/amdgpu: fix pipeline sync v2
  (https://gitlab.freedesktop.org/drm/amd/-/issues/2323).
- Delete
  patches.suse/Revert-drm-amdgpu-move-explicit-sync-check-into-the-.patch.
- Delete
  patches.suse/Revert-drm-amdgpu-use-scheduler-dependencies-for-CS.patch.
- Delete
  patches.suse/Revert-drm-scheduler-remove-drm_sched_dependency_opt.patch.
  Replace reverts of offending commits by queued upstream fix.
- commit 90ac672
* Thu Jan 12 2023 jslaby@suse.cz
- Linux 6.1.5 (bsc#1012628).
- ARM: renumber bits related to _TIF_WORK_MASK (bsc#1012628).
- btrfs: replace strncpy() with strscpy() (bsc#1012628).
- cifs: fix interface count calculation during refresh
  (bsc#1012628).
- cifs: refcount only the selected iface during interface update
  (bsc#1012628).
- usb: dwc3: gadget: Ignore End Transfer delay on teardown
  (bsc#1012628).
- btrfs: fix off-by-one in delalloc search during lseek
  (bsc#1012628).
- btrfs: fix compat_ro checks against remount (bsc#1012628).
- perf probe: Use dwarf_attr_integrate as generic DWARF attr
  accessor (bsc#1012628).
- perf probe: Fix to get the DW_AT_decl_file and DW_AT_call_file
  as unsinged data (bsc#1012628).
- phy: qcom-qmp-combo: fix broken power on (bsc#1012628).
- btrfs: fix an error handling path in btrfs_defrag_leaves()
  (bsc#1012628).
- SUNRPC: ensure the matching upcall is in-flight upon downcall
  (bsc#1012628).
- wifi: ath9k: use proper statements in conditionals
  (bsc#1012628).
- bpf: pull before calling skb_postpull_rcsum() (bsc#1012628).
- drm/panfrost: Fix GEM handle creation ref-counting
  (bsc#1012628).
- netfilter: nf_tables: consolidate set description (bsc#1012628).
- netfilter: nf_tables: add function to create set stateful
  expressions (bsc#1012628).
- netfilter: nf_tables: perform type checking for existing sets
  (bsc#1012628).
- ice: xsk: do not use xdp_return_frame() on tx_buf->raw_buf
  (bsc#1012628).
- net: vrf: determine the dst using the original ifindex for
  multicast (bsc#1012628).
- vmxnet3: correctly report csum_level for encapsulated packet
  (bsc#1012628).
- mptcp: fix deadlock in fastopen error path (bsc#1012628).
- mptcp: fix lockdep false positive (bsc#1012628).
- netfilter: nf_tables: honor set timeout and garbage collection
  updates (bsc#1012628).
- bonding: fix lockdep splat in bond_miimon_commit()
  (bsc#1012628).
- net: lan966x: Fix configuration of the PCS (bsc#1012628).
- veth: Fix race with AF_XDP exposing old or uninitialized
  descriptors (bsc#1012628).
- nfsd: shut down the NFSv4 state objects before the filecache
  (bsc#1012628).
- net: hns3: add interrupts re-initialization while doing VF FLR
  (bsc#1012628).
- net: hns3: fix miss L3E checking for rx packet (bsc#1012628).
- net: hns3: fix VF promisc mode not update when mac table full
  (bsc#1012628).
- net: sched: fix memory leak in tcindex_set_parms (bsc#1012628).
- qlcnic: prevent ->dcb use-after-free on qlcnic_dcb_enable()
  failure (bsc#1012628).
- net: dsa: mv88e6xxx: depend on PTP conditionally (bsc#1012628).
- nfc: Fix potential resource leaks (bsc#1012628).
- bnxt_en: Simplify bnxt_xdp_buff_init() (bsc#1012628).
- bnxt_en: Fix XDP RX path (bsc#1012628).
- bnxt_en: Fix first buffer size calculations for XDP multi-buffer
  (bsc#1012628).
- bnxt_en: Fix HDS and jumbo thresholds for RX packets
  (bsc#1012628).
- vdpa/mlx5: Fix rule forwarding VLAN to TIR (bsc#1012628).
- vdpa/mlx5: Fix wrong mac address deletion (bsc#1012628).
- vdpa_sim: fix possible memory leak in vdpasim_net_init()
  and vdpasim_blk_init() (bsc#1012628).
- vhost/vsock: Fix error handling in vhost_vsock_init()
  (bsc#1012628).
- vringh: fix range used in iotlb_translate() (bsc#1012628).
- vhost: fix range used in translate_desc() (bsc#1012628).
- vhost-vdpa: fix an iotlb memory leak (bsc#1012628).
- vdpa_sim: fix vringh initialization in vdpasim_queue_ready()
  (bsc#1012628).
- virtio-crypto: fix memory leak in
  virtio_crypto_alg_skcipher_close_session() (bsc#1012628).
- vdpa/vp_vdpa: fix kfree a wrong pointer in vp_vdpa_remove
  (bsc#1012628).
- vdpasim: fix memory leak when freeing IOTLBs (bsc#1012628).
- net/mlx5: E-Switch, properly handle ingress tagged packets on
  VST (bsc#1012628).
- net/mlx5: Add forgotten cleanup calls into mlx5_init_once()
  error path (bsc#1012628).
- net/mlx5: Fix io_eq_size and event_eq_size params validation
  (bsc#1012628).
- net/mlx5: Avoid recovery in probe flows (bsc#1012628).
- net/mlx5: Fix RoCE setting at HCA level (bsc#1012628).
- net/mlx5e: IPoIB, Don't allow CQE compression to be turned on
  by default (bsc#1012628).
- net/mlx5e: Fix RX reporter for XSK RQs (bsc#1012628).
- net/mlx5e: CT: Fix ct debugfs folder name (bsc#1012628).
- net/mlx5e: Always clear dest encap in neigh-update-del
  (bsc#1012628).
- net/mlx5e: Fix hw mtu initializing at XDP SQ allocation
  (bsc#1012628).
- net/mlx5e: Set geneve_tlv_option_0_exist when matching on
  geneve option (bsc#1012628).
- net/mlx5: Lag, fix failure to cancel delayed bond work
  (bsc#1012628).
- bpf: Always use maximal size for copy_array() (bsc#1012628).
- net: hns3: refine the handling for VF heartbeat (bsc#1012628).
- net: amd-xgbe: add missed tasklet_kill (bsc#1012628).
- net: ena: Fix toeplitz initial hash value (bsc#1012628).
- net: ena: Don't register memory info on XDP exchange
  (bsc#1012628).
- net: ena: Account for the number of processed bytes in XDP
  (bsc#1012628).
- net: ena: Use bitmask to indicate packet redirection
  (bsc#1012628).
- net: ena: Fix rx_copybreak value update (bsc#1012628).
- net: ena: Set default value for RX interrupt moderation
  (bsc#1012628).
- net: ena: Update NUMA TPH hint register upon NUMA node update
  (bsc#1012628).
- net: phy: xgmiitorgmii: Fix refcount leak in xgmiitorgmii_probe
  (bsc#1012628).
- gpio: pca953x: avoid to use uninitialized value pinctrl
  (bsc#1012628).
- RDMA/mlx5: Fix mlx5_ib_get_hw_stats when used for device
  (bsc#1012628).
- RDMA/mlx5: Fix validation of max_rd_atomic caps for DC
  (bsc#1012628).
- selftests: net: fix cleanup_v6() for arp_ndisc_evict_nocarrier
  (bsc#1012628).
- selftests: net: return non-zero for failures reported in
  arp_ndisc_evict_nocarrier (bsc#1012628).
- drm/meson: Reduce the FIFO lines held when AFBC is not used
  (bsc#1012628).
- filelock: new helper: vfs_inode_has_locks (bsc#1012628).
- ceph: switch to vfs_inode_has_locks() to fix file lock bug
  (bsc#1012628).
- gpio: sifive: Fix refcount leak in sifive_gpio_probe
  (bsc#1012628).
- net: sched: atm: dont intepret cls results when asked to drop
  (bsc#1012628).
- net: sched: cbq: dont intepret cls results when asked to drop
  (bsc#1012628).
- vxlan: Fix memory leaks in error path (bsc#1012628).
- net: sparx5: Fix reading of the MAC address (bsc#1012628).
- netfilter: ipset: fix hash:net,port,net hang with /0 subnet
  (bsc#1012628).
- netfilter: ipset: Rework long task execution when
  adding/deleting entries (bsc#1012628).
- drm/virtio: Fix memory leak in virtio_gpu_object_create()
  (bsc#1012628).
- perf tools: Fix resources leak in perf_data__open_dir()
  (bsc#1012628).
- drm/imx: ipuv3-plane: Fix overlay plane width (bsc#1012628).
- fs/ntfs3: don't hold ni_lock when calling truncate_setsize()
  (bsc#1012628).
- drivers/net/bonding/bond_3ad: return when there's no aggregator
  (bsc#1012628).
- octeontx2-pf: Fix lmtst ID used in aura free (bsc#1012628).
- usb: rndis_host: Secure rndis_query check against int overflow
  (bsc#1012628).
- perf lock contention: Fix core dump related to not finding the
  "__sched_text_end" symbol on s/390 (bsc#1012628).
- perf stat: Fix handling of unsupported cgroup events when
  using BPF counters (bsc#1012628).
- perf stat: Fix handling of --for-each-cgroup with --bpf-counters
  to match non BPF mode (bsc#1012628).
- drm/i915: unpin on error in intel_vgpu_shadow_mm_pin()
  (bsc#1012628).
- drm/i915/gvt: fix double free bug in split_2MB_gtt_entry
  (bsc#1012628).
- ublk: honor IO_URING_F_NONBLOCK for handling control command
  (bsc#1012628).
- qed: allow sleep in qed_mcp_trace_dump() (bsc#1012628).
- net/ulp: prevent ULP without clone op from entering the LISTEN
  status (bsc#1012628).
- caif: fix memory leak in cfctrl_linkup_request() (bsc#1012628).
- udf: Fix extension of the last extent in the file (bsc#1012628).
- usb: dwc3: xilinx: include linux/gpio/consumer.h (bsc#1012628).
- hfs/hfsplus: avoid WARN_ON() for sanity check, use proper
  error handling (bsc#1012628).
- ASoC: SOF: Revert: "core: unregister clients and machine
  drivers in .shutdown" (bsc#1012628).
- 9p/client: fix data race on req->status (bsc#1012628).
- ASoC: Intel: bytcr_rt5640: Add quirk for the Advantech MICA-071
  tablet (bsc#1012628).
- ASoC: SOF: mediatek: initialize panic_info to zero
  (bsc#1012628).
- drm/amdgpu: Fix size validation for non-exclusive domains (v4)
  (bsc#1012628).
- drm/amdkfd: Fix kfd_process_device_init_vm error handling
  (bsc#1012628).
- drm/amdkfd: Fix double release compute pasid (bsc#1012628).
- io_uring/cancel: re-grab ctx mutex after finishing wait
  (bsc#1012628).
- nvme: fix multipath crash caused by flush request when blktrace
  is enabled (bsc#1012628).
- ACPI: video: Allow GPU drivers to report no panels
  (bsc#1012628).
- drm/amd/display: Report to ACPI video if no panels were found
  (bsc#1012628).
- ACPI: video: Don't enable fallback path for creating ACPI
  backlight by default (bsc#1012628).
- io_uring: check for valid register opcode earlier (bsc#1012628).
- kunit: alloc_string_stream_fragment error handling bug fix
  (bsc#1012628).
- nvmet: use NVME_CMD_EFFECTS_CSUPP instead of open coding it
  (bsc#1012628).
- nvme: also return I/O command effects from nvme_command_effects
  (bsc#1012628).
- ASoC: SOF: Intel: pci-tgl: unblock S5 entry if DMA stop has
  failed" (bsc#1012628).
- x86/kexec: Fix double-free of elf header buffer (bsc#1012628).
- x86/bugs: Flush IBP in ib_prctl_set() (bsc#1012628).
- nfsd: fix handling of readdir in v4root vs. mount upcall timeout
  (bsc#1012628).
- fbdev: matroxfb: G200eW: Increase max memory from 1 MB to 16 MB
  (bsc#1012628).
- bpf: Fix panic due to wrong pageattr of im->image (bsc#1012628).
- Revert "drm/amd/display: Enable Freesync Video Mode by default"
  (bsc#1012628).
- Revert "net: dsa: qca8k: cache lo and hi for mdio write"
  (bsc#1012628).
- net: dsa: qca8k: fix wrong length value for mgmt eth packet
  (bsc#1012628).
- net: dsa: tag_qca: fix wrong MGMT_DATA2 size (bsc#1012628).
- block: don't allow splitting of a REQ_NOWAIT bio (bsc#1012628).
- io_uring: pin context while queueing deferred tw (bsc#1012628).
- io_uring: fix CQ waiting timeout handling (bsc#1012628).
- tpm: Allow system suspend to continue when TPM suspend fails
  (bsc#1012628).
- vhost_vdpa: fix the crash in unmap a large memory (bsc#1012628).
- thermal: int340x: Add missing attribute for data rate base
  (bsc#1012628).
- riscv: uaccess: fix type of 0 variable on error in get_user()
  (bsc#1012628).
- riscv, kprobes: Stricter c.jr/c.jalr decoding (bsc#1012628).
- of/fdt: run soc memory setup when early_init_dt_scan_memory
  fails (bsc#1012628).
- drm/plane-helper: Add the missing declaration of
  drm_atomic_state (bsc#1012628).
- drm/amdkfd: Fix kernel warning during topology setup
  (bsc#1012628).
- drm/i915/gvt: fix gvt debugfs destroy (bsc#1012628).
- drm/i915/gvt: fix vgpu debugfs clean in remove (bsc#1012628).
- virtio-blk: use a helper to handle request queuing errors
  (bsc#1012628).
- virtio_blk: Fix signedness bug in virtblk_prep_rq()
  (bsc#1012628).
- drm/amd/display: Add check for DET fetch latency hiding for
  dcn32 (bsc#1012628).
- drm/amd/display: Uninitialized variables causing 4k60 UCLK to
  stay at DPM1 and not DPM0 (bsc#1012628).
- btrfs: handle case when repair happens with dev-replace
  (bsc#1012628).
- ksmbd: fix infinite loop in ksmbd_conn_handler_loop()
  (bsc#1012628).
- ksmbd: send proper error response in smb2_tree_connect()
  (bsc#1012628).
- ksmbd: check nt_len to be at least CIFS_ENCPWD_SIZE in
  ksmbd_decode_ntlmssp_auth_blob (bsc#1012628).
- drm/i915/dsi: add support for ICL+ native MIPI GPIO sequence
  (bsc#1012628).
- drm/i915/dsi: fix MIPI_BKLT_EN_1 native GPIO index
  (bsc#1012628).
- efi: random: combine bootloader provided RNG seed with RNG
  protocol output (bsc#1012628).
- wifi: ath11k: Send PME message during wakeup from D3cold
  (bsc#1012628).
- commit 0fb77d6
* Mon Jan  9 2023 svarbanov@suse.de
- Update armv7 to 6.2.0-rc3
- update configs
- re-enable armv7
- commit e578e47
* Mon Jan  9 2023 svarbanov@suse.de
- Update arm64 to 6.2.0-rc3
- update configs
- re-enable arm64
- commit 72fe5c3
* Mon Jan  9 2023 svarbanov@suse.de
- Update armv6 to 6.2.0-rc3
- update configs
- reenable armv6
- commit ed1892b
* Mon Jan  9 2023 jslaby@suse.cz
- docs: Fix the docs build with Sphinx 6.0 (sphinx_6.0-staging_E).
- commit 4b9b43c
* Mon Jan  9 2023 jslaby@suse.cz
- Linux 6.1.4 (bsc#1012628).
- drm/amdgpu: skip MES for S0ix as well since it's part of GFX
  (bsc#1012628).
- drm/amdgpu: skip mes self test after s0i3 resume for MES IP
  v11.0 (bsc#1012628).
- media: stv0288: use explicitly signed char (bsc#1012628).
- cxl/region: Fix memdev reuse check (bsc#1012628).
- arm64: dts: qcom: sc8280xp: fix UFS DMA coherency (bsc#1012628).
- arm64: Prohibit instrumentation on arch_stack_walk()
  (bsc#1012628).
- soc: qcom: Select REMAP_MMIO for LLCC driver (bsc#1012628).
- soc: qcom: Select REMAP_MMIO for ICC_BWMON driver (bsc#1012628).
- kest.pl: Fix grub2 menu handling for rebooting (bsc#1012628).
- ktest.pl minconfig: Unset configs instead of just removing them
  (bsc#1012628).
- jbd2: use the correct print format (bsc#1012628).
- perf/x86/intel/uncore: Disable I/O stacks to PMU mapping on
  ICX-D (bsc#1012628).
- perf/x86/intel/uncore: Clear attr_update properly (bsc#1012628).
- arm64: dts: qcom: sdm845-db845c: correct SPI2 pins drive
  strength (bsc#1012628).
- arm64: dts: qcom: sc8280xp: fix UFS reference clocks
  (bsc#1012628).
- mmc: sdhci-sprd: Disable CLK_AUTO when the clock is less than
  400K (bsc#1012628).
- phy: qcom-qmp-combo: fix out-of-bounds clock access
  (bsc#1012628).
- drm/amd/pm: update SMU13.0.0 reported maximum shader clock
  (bsc#1012628).
- drm/amd/pm: correct SMU13.0.0 pstate profiling clock settings
  (bsc#1012628).
- btrfs: fix uninitialized parent in insert_state (bsc#1012628).
- btrfs: fix extent map use-after-free when handling missing
  device in read_one_chunk (bsc#1012628).
- btrfs: fix resolving backrefs for inline extent followed by
  prealloc (bsc#1012628).
- ARM: ux500: do not directly dereference __iomem (bsc#1012628).
- arm64: dts: qcom: sdm850-samsung-w737: correct I2C12 pins
  drive strength (bsc#1012628).
- random: use rejection sampling for uniform bounded random
  integers (bsc#1012628).
- x86/fpu/xstate: Fix XSTATE_WARN_ON() to emit relevant
  diagnostics (bsc#1012628).
- arm64: dts: qcom: sdm850-lenovo-yoga-c630: correct I2C12 pins
  drive strength (bsc#1012628).
- cxl/region: Fix missing probe failure (bsc#1012628).
- EDAC/mc_sysfs: Increase legacy channel support to 12
  (bsc#1012628).
- selftests: Use optional USERCFLAGS and USERLDFLAGS
  (bsc#1012628).
- x86/MCE/AMD: Clear DFR errors found in THR handler
  (bsc#1012628).
- random: add helpers for random numbers with given floor or range
  (bsc#1012628).
- PM/devfreq: governor: Add a private governor_data for governor
  (bsc#1012628).
- cpufreq: Init completion before kobject_init_and_add()
  (bsc#1012628).
- ext2: unbugger ext2_empty_dir() (bsc#1012628).
- media: s5p-mfc: Fix to handle reference queue during finishing
  (bsc#1012628).
- media: s5p-mfc: Clear workbit to handle error condition
  (bsc#1012628).
- media: s5p-mfc: Fix in register read and write for H264
  (bsc#1012628).
- bpf: Resolve fext program type when checking map compatibility
  (bsc#1012628).
- ALSA: patch_realtek: Fix Dell Inspiron Plus 16 (bsc#1012628).
- ALSA: hda/realtek: Apply dual codec fixup for Dell Latitude
  laptops (bsc#1012628).
- platform/x86: thinkpad_acpi: Fix max_brightness of thinklight
  (bsc#1012628).
- platform/x86: ideapad-laptop: Revert "check for touchpad
  support in _CFG" (bsc#1012628).
- platform/x86: ideapad-laptop: Add new _CFG bit numbers for
  future use (bsc#1012628).
- platform/x86: ideapad-laptop: support for more special keys
  in WMI (bsc#1012628).
- ACPI: video: Simplify __acpi_video_get_backlight_type()
  (bsc#1012628).
- ACPI: video: Prefer native over vendor (bsc#1012628).
- platform/x86: ideapad-laptop: Refactor
  ideapad_sync_touchpad_state() (bsc#1012628).
- platform/x86: ideapad-laptop: Do not send KEY_TOUCHPAD* events
  on probe / resume (bsc#1012628).
- platform/x86: ideapad-laptop: Only toggle ps2 aux port on/off
  on select models (bsc#1012628).
- platform/x86: ideapad-laptop: Send KEY_TOUCHPAD_TOGGLE on some
  models (bsc#1012628).
- platform/x86: ideapad-laptop: Stop writing VPCCMD_W_TOUCHPAD
  at probe time (bsc#1012628).
- platform/x86: intel-uncore-freq: add Emerald Rapids support
  (bsc#1012628).
- ALSA: hda/cirrus: Add extra 10 ms delay to allow PLL settle
  and lock (bsc#1012628).
- platform/x86: x86-android-tablets: Add Medion Lifetab S10346
  data (bsc#1012628).
- platform/x86: x86-android-tablets: Add Lenovo Yoga Tab 3
  (YT3-X90F) charger + fuel-gauge data (bsc#1012628).
- platform/x86: x86-android-tablets: Add Advantech MICA-071
  extra button (bsc#1012628).
- HID: Ignore HP Envy x360 eu0009nv stylus battery (bsc#1012628).
- ALSA: usb-audio: Add new quirk FIXED_RATE for JBL Quantum810
  Wireless (bsc#1012628).
- fs: dlm: fix sock release if listen fails (bsc#1012628).
- fs: dlm: retry accept() until -EAGAIN or error returns
  (bsc#1012628).
- mptcp: netlink: fix some error return code (bsc#1012628).
- mptcp: remove MPTCP 'ifdef' in TCP SYN cookies (bsc#1012628).
- mptcp: dedicated request sock for subflow in v6 (bsc#1012628).
- mptcp: use proper req destructor for IPv6 (bsc#1012628).
- dm cache: Fix ABBA deadlock between shrink_slab and
  dm_cache_metadata_abort (bsc#1012628).
- dm thin: Fix ABBA deadlock between shrink_slab and
  dm_pool_abort_metadata (bsc#1012628).
- dm thin: Use last transaction's pmd->root when commit failed
  (bsc#1012628).
- dm thin: resume even if in FAIL mode (bsc#1012628).
- dm thin: Fix UAF in run_timer_softirq() (bsc#1012628).
- dm integrity: Fix UAF in dm_integrity_dtr() (bsc#1012628).
- dm clone: Fix UAF in clone_dtr() (bsc#1012628).
- dm cache: Fix UAF in destroy() (bsc#1012628).
- dm cache: set needs_check flag after aborting metadata
  (bsc#1012628).
- ata: ahci: fix enum constants for gcc-13 (bsc#1012628).
- PCI/DOE: Fix maximum data object length miscalculation
  (bsc#1012628).
- tracing/hist: Fix out-of-bound write on
  'action_data.var_ref_idx' (bsc#1012628).
- perf/core: Call LSM hook after copying perf_event_attr
  (bsc#1012628).
- xtensa: add __umulsidi3 helper (bsc#1012628).
- of/kexec: Fix reading 32-bit "linux,initrd-{start,end}" values
  (bsc#1012628).
- ima: Fix hash dependency to correct algorithm (bsc#1012628).
- KVM: VMX: Resume guest immediately when injecting #GP on ECREATE
  (bsc#1012628).
- KVM: nVMX: Inject #GP, not #UD, if "generic" VMXON CR0/CR4
  check fails (bsc#1012628).
- KVM: x86: fix APICv/x2AVIC disabled when vm reboot by itself
  (bsc#1012628).
- KVM: nVMX: Properly expose ENABLE_USR_WAIT_PAUSE control to L1
  (bsc#1012628).
- x86/microcode/intel: Do not retry microcode reloading on the
  APs (bsc#1012628).
- ftrace/x86: Add back ftrace_expected for ftrace bug reports
  (bsc#1012628).
- x86/kprobes: Fix kprobes instruction boudary check with
  CONFIG_RETHUNK (bsc#1012628).
- x86/kprobes: Fix optprobe optimization check with CONFIG_RETHUNK
  (bsc#1012628).
- tracing: Fix race where eprobes can be called before the event
  (bsc#1012628).
- powerpc/ftrace: fix syscall tracing on PPC64_ELF_ABI_V1
  (bsc#1012628).
- tracing: Fix complicated dependency of CONFIG_TRACER_MAX_TRACE
  (bsc#1012628).
- tracing/hist: Fix wrong return value in parse_action_params()
  (bsc#1012628).
- tracing/probes: Handle system names with hyphens (bsc#1012628).
- tracing: Fix issue of missing one synthetic field (bsc#1012628).
- tracing: Fix infinite loop in tracing_read_pipe on overflowed
  print_trace_line (bsc#1012628).
- staging: media: tegra-video: fix chan->mipi value on error
  (bsc#1012628).
- staging: media: tegra-video: fix device_node use after free
  (bsc#1012628).
- arm64: dts: mediatek: mt8195-demo: fix the memory size of node
  secmon (bsc#1012628).
- ARM: 9256/1: NWFPE: avoid compiler-generated __aeabi_uldivmod
  (bsc#1012628).
- media: dvb-core: Fix double free in dvb_register_device()
  (bsc#1012628).
- cifs: fix confusing debug message (bsc#1012628).
- cifs: fix missing display of three mount options (bsc#1012628).
- cifs: set correct tcon status after initial tree connect
  (bsc#1012628).
- cifs: set correct ipc status after initial tree connect
  (bsc#1012628).
- cifs: set correct status of tcon ipc when reconnecting
  (bsc#1012628).
- ravb: Fix "failed to switch device to config mode" message
  during unbind (bsc#1012628).
- rtc: ds1347: fix value written to century register
  (bsc#1012628).
- drm/amdgpu: fix mmhub register base coding error (bsc#1012628).
- block: mq-deadline: Fix dd_finish_request() for zoned devices
  (bsc#1012628).
- block: mq-deadline: Do not break sequential write streams to
  zoned HDDs (bsc#1012628).
- md/bitmap: Fix bitmap chunk size overflow issues (bsc#1012628).
- efi: Add iMac Pro 2017 to uefi skip cert quirk (bsc#1012628).
- wifi: wilc1000: sdio: fix module autoloading (bsc#1012628).
- ASoC: jz4740-i2s: Handle independent FIFO flush bits
  (bsc#1012628).
- ipu3-imgu: Fix NULL pointer dereference in
  imgu_subdev_set_selection() (bsc#1012628).
- ipmi: fix long wait in unload when IPMI disconnect
  (bsc#1012628).
- mtd: spi-nor: Check for zero erase size in
  spi_nor_find_best_erase_type() (bsc#1012628).
- ima: Fix a potential NULL pointer access in
  ima_restore_measurement_list (bsc#1012628).
- ipmi: fix use after free in _ipmi_destroy_user() (bsc#1012628).
- mtd: spi-nor: gigadevice: gd25q256: replace
  gd25q256_default_init with gd25q256_post_bfpt (bsc#1012628).
- ima: Fix memory leak in __ima_inode_hash() (bsc#1012628).
- um: virt-pci: Avoid GCC non-NULL warning (bsc#1012628).
- crypto: ccree,hisilicon - Fix dependencies to correct algorithm
  (bsc#1012628).
- PCI: Fix pci_device_is_present() for VFs by checking PF
  (bsc#1012628).
- PCI/sysfs: Fix double free in error path (bsc#1012628).
- RISC-V: kexec: Fix memory leak of fdt buffer (bsc#1012628).
- riscv: Fixup compile error with !MMU (bsc#1012628).
- RISC-V: kexec: Fix memory leak of elf header buffer
  (bsc#1012628).
- riscv: stacktrace: Fixup ftrace_graph_ret_addr retp argument
  (bsc#1012628).
- riscv: mm: notify remote harts about mmu cache updates
  (bsc#1012628).
- crypto: n2 - add missing hash statesize (bsc#1012628).
- crypto: ccp - Add support for TEE for PCI ID 0x14CA
  (bsc#1012628).
- driver core: Fix bus_type.match() error handling in
  __driver_attach() (bsc#1012628).
- bus: mhi: host: Fix race between channel preparation and M0
  event (bsc#1012628).
- phy: qcom-qmp-combo: fix sdm845 reset (bsc#1012628).
- phy: qcom-qmp-combo: fix sc8180x reset (bsc#1012628).
- iommu/amd: Fix ivrs_acpihid cmdline parsing code (bsc#1012628).
- iommu/amd: Fix ill-formed ivrs_ioapic, ivrs_hpet and
  ivrs_acpihid options (bsc#1012628).
- test_kprobes: Fix implicit declaration error of test_kprobes
  (bsc#1012628).
- hugetlb: really allocate vma lock for all sharable vmas
  (bsc#1012628).
- remoteproc: imx_dsp_rproc: Add mutex protection for workqueue
  (bsc#1012628).
- remoteproc: core: Do pm_relax when in RPROC_OFFLINE state
  (bsc#1012628).
- remoteproc: imx_rproc: Correct i.MX93 DRAM mapping
  (bsc#1012628).
- parisc: led: Fix potential null-ptr-deref in start_task()
  (bsc#1012628).
- parisc: Drop locking in pdc console code (bsc#1012628).
- parisc: Fix locking in pdc_iodc_print() firmware call
  (bsc#1012628).
- parisc: Add missing FORCE prerequisites in Makefile
  (bsc#1012628).
- parisc: Drop duplicate kgdb_pdc console (bsc#1012628).
- parisc: Drop PMD_SHIFT from calculation in pgtable.h
  (bsc#1012628).
- device_cgroup: Roll back to original exceptions after copy
  failure (bsc#1012628).
- drm/connector: send hotplug uevent on connector cleanup
  (bsc#1012628).
- drm/vmwgfx: Validate the box size for the snooped cursor
  (bsc#1012628).
- drm/mgag200: Fix PLL setup for G200_SE_A rev >=4 (bsc#1012628).
- drm/etnaviv: move idle mapping reaping into separate function
  (bsc#1012628).
- drm/i915/dsi: fix VBT send packet port selection for dual link
  DSI (bsc#1012628).
- drm/ingenic: Fix missing platform_driver_unregister() call in
  ingenic_drm_init() (bsc#1012628).
- drm/etnaviv: reap idle mapping if it doesn't match the softpin
  address (bsc#1012628).
- ext4: silence the warning when evicting inode with
  dioread_nolock (bsc#1012628).
- ext4: add inode table check in __ext4_get_inode_loc to aovid
  possible infinite loop (bsc#1012628).
- ext4: remove trailing newline from ext4_msg() message
  (bsc#1012628).
- ext4: correct inconsistent error msg in nojournal mode
  (bsc#1012628).
- fs: ext4: initialize fsdata in pagecache_write() (bsc#1012628).
- ext4: fix use-after-free in ext4_orphan_cleanup (bsc#1012628).
- ext4: fix undefined behavior in bit shift for
  ext4_check_flag_values (bsc#1012628).
- ext4: add EXT4_IGET_BAD flag to prevent unexpected bad inode
  (bsc#1012628).
- ext4: add helper to check quota inums (bsc#1012628).
- ext4: fix bug_on in __es_tree_search caused by bad quota inode
  (bsc#1012628).
- ext4: fix reserved cluster accounting in __es_remove_extent()
  (bsc#1012628).
- ext4: journal_path mount options should follow links
  (bsc#1012628).
- ext4: check and assert if marking an no_delete evicting inode
  dirty (bsc#1012628).
- ext4: fix bug_on in __es_tree_search caused by bad boot loader
  inode (bsc#1012628).
- ext4: don't allow journal inode to have encrypt flag
  (bsc#1012628).
- ext4: disable fast-commit of encrypted dir operations
  (bsc#1012628).
- ext4: fix leaking uninitialized memory in fast-commit journal
  (bsc#1012628).
- ext4: don't set up encryption key during jbd2 transaction
  (bsc#1012628).
- ext4: add missing validation of fast-commit record lengths
  (bsc#1012628).
- ext4: fix unaligned memory access in ext4_fc_reserve_space()
  (bsc#1012628).
- ext4: fix off-by-one errors in fast-commit block filling
  (bsc#1012628).
- ext4: fix uninititialized value in 'ext4_evict_inode'
  (bsc#1012628).
- ext4: init quota for 'old.inode' in 'ext4_rename' (bsc#1012628).
- ext4: don't fail GETFSUUID when the caller provides a long
  buffer (bsc#1012628).
- ext4: fix delayed allocation bug in ext4_clu_mapped for bigalloc
  + inline (bsc#1012628).
- ext4: fix corruption when online resizing a 1K bigalloc fs
  (bsc#1012628).
- ext4: fix error code return to user-space in ext4_get_branch()
  (bsc#1012628).
- ext4: fix bad checksum after online resize (bsc#1012628).
- ext4: dont return EINVAL from GETFSUUID when reporting UUID
  length (bsc#1012628).
- ext4: fix corrupt backup group descriptors after online resize
  (bsc#1012628).
- ext4: avoid BUG_ON when creating xattrs (bsc#1012628).
- ext4: fix deadlock due to mbcache entry corruption
  (bsc#1012628).
- ext4: fix kernel BUG in 'ext4_write_inline_data_end()'
  (bsc#1012628).
- ext4: fix inode leak in ext4_xattr_inode_create() on an error
  path (bsc#1012628).
- ext4: initialize quota before expanding inode in setproject
  ioctl (bsc#1012628).
- ext4: avoid unaccounted block allocation when expanding inode
  (bsc#1012628).
- ext4: allocate extended attribute value in vmalloc area
  (bsc#1012628).
- drm/i915/ttm: consider CCS for backup objects (bsc#1012628).
- drm/amd/display: Add DCN314 display SG Support (bsc#1012628).
- drm/amdgpu: handle polaris10/11 overlap asics (v2)
  (bsc#1012628).
- drm/amdgpu: make display pinning more flexible (v2)
  (bsc#1012628).
- drm/i915: improve the catch-all evict to handle lock contention
  (bsc#1012628).
- drm/i915/migrate: Account for the reserved_space (bsc#1012628).
- drm/amd/pm: add missing SMU13.0.0 mm_dpm feature mapping
  (bsc#1012628).
- drm/amd/pm: add missing SMU13.0.7 mm_dpm feature mapping
  (bsc#1012628).
- drm/amd/pm: bump SMU13.0.0 driver_if header to version 0x34
  (bsc#1012628).
- drm/amd/pm: correct the fan speed retrieving in PWM for some
  SMU13 asics (bsc#1012628).
- commit 9fd04e2
* Sun Jan  8 2023 mkubecek@suse.cz
- Revert "drm/amdgpu: move explicit sync check into the CS"
  (https://gitlab.freedesktop.org/drm/amd/-/issues/2323).
- Revert "drm/amdgpu: use scheduler dependencies for CS"
  (https://gitlab.freedesktop.org/drm/amd/-/issues/2323).
- Revert "drm/scheduler: remove drm_sched_dependency_optimized"
  (https://gitlab.freedesktop.org/drm/amd/-/issues/2323).
- commit 13b3e26
* Sun Jan  8 2023 mkubecek@suse.cz
- Update to 6.2-rc3
- eliminate 1 patch
  - patches.suse/tcp-Add-TIME_WAIT-sockets-in-bhash2.patch
- refresh
  - patches.suse/add-suse-supported-flag.patch
- update configs
  - CDROM_PKTCDVD=m (restored, except s390x)
  - CDROM_PKTCDVD_BUFFERS=8 (restored, except s390x)
  - CDROM_PKTCDVD_WCACHE=y (restored, except s390x)
- commit 8fc2af0
* Fri Jan  6 2023 jeffm@suse.com
- rpm/kernel-binary.spec.in: Add Enhances and Supplements tags to in-tree KMPs
  This makes in-tree KMPs more consistent with externally built KMPs and
  silences several rpmlint warnings.
- commit 02b7735
* Fri Jan  6 2023 mkubecek@suse.cz
- rpm/check-for-config-changes: add OBJTOOL and FTRACE_MCOUNT_USE_*
  Dummy gcc pretends to support -mrecord-mcount option but actual gcc on
  ppc64le does not. Therefore ppc64le builds of 6.2-rc1 and later in OBS
  enable FTRACE_MCOUNT_USE_OBJTOOL and OBJTOOL config options, resulting in
  check failure.
  As we already have FTRACE_MCOUNT_USE_CC and FTRACE_MCOUNT_USE_RECORDMCOUNT
  in the exception list, replace them with a general pattern. And add OBJTOOL
  as well.
- commit 887416f
* Fri Jan  6 2023 msuchanek@suse.de
- bpf_doc: Fix build error with older python versions
  (TypeError: '_sre.SRE_Match' object is not subscriptable).
- commit 37f7888
* Thu Jan  5 2023 jeffm@suse.com
- supported-flag: fix build failures with SUSE_KERNEL_SUPPORTED=y
  Upstream commit 425937381ec (kbuild: re-run modpost when it is updated)
  added an expectation that the MODPOST variable would only point to the
  modpost executable and moved arguments to the modpost-args variable.
  Also removed some legacy stuff, like the assumption that MODVERDIR would
  exist (and then later creating it and using it) when the only two
  places we ever care about Module.supported being located are the directory
  in which an external module is being built and the current directory.
- commit 2e19141
* Thu Jan  5 2023 jeffm@suse.com
- config: Added product codes to suse_version.h for comparison
  Refreshed
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch.
- commit 3dffbad
* Thu Jan  5 2023 jeffm@suse.com
- config: Added support for ALP releases in product identifiers
- Refresh patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch.
- commit 1b2e183
* Thu Jan  5 2023 tiwai@suse.de
- Revert "ALSA: usb-audio: Drop superfluous interface setup at
  parsing" (bsc#1206766).
- ALSA: usb-audio: More refactoring of hw constraint rules
  (bsc#1206766).
- ALSA: usb-audio: Relax hw constraints for implicit fb sync
  (bsc#1206766).
- ALSA: usb-audio: Make sure to stop endpoints before closing EPs
  (bsc#1206766).
- commit 80a4df2
* Wed Jan  4 2023 jslaby@suse.cz
- Linux 6.1.3 (bsc#1012628).
- eventpoll: add EPOLL_URING_WAKE poll wakeup flag (bsc#1012628).
- eventfd: provide a eventfd_signal_mask() helper (bsc#1012628).
- io_uring: pass in EPOLL_URING_WAKE for eventfd signaling and
  wakeups (bsc#1012628).
- nvme-pci: fix doorbell buffer value endianness (bsc#1012628).
- nvme-pci: fix mempool alloc size (bsc#1012628).
- nvme-pci: fix page size checks (bsc#1012628).
- ACPI: resource: do IRQ override on XMG Core 15 (bsc#1012628).
- ACPI: resource: do IRQ override on Lenovo 14ALC7 (bsc#1012628).
- ACPI: resource: Add Asus ExpertBook B2502 to Asus quirks
  (bsc#1012628).
- ACPI: video: Fix Apple GMUX backlight detection (bsc#1012628).
- block, bfq: fix uaf for bfqq in bfq_exit_icq_bfqq (bsc#1012628).
- ata: ahci: Fix PCS quirk application for suspend (bsc#1012628).
- nvme: fix the NVME_CMD_EFFECTS_CSE_MASK definition
  (bsc#1012628).
- nvmet: don't defer passthrough commands with trivial effects
  to the workqueue (bsc#1012628).
- fs/ntfs3: Validate BOOT record_size (bsc#1012628).
- fs/ntfs3: Add overflow check for attribute size (bsc#1012628).
- fs/ntfs3: Validate data run offset (bsc#1012628).
- fs/ntfs3: Add null pointer check to attr_load_runs_vcn
  (bsc#1012628).
- fs/ntfs3: Fix memory leak on ntfs_fill_super() error path
  (bsc#1012628).
- fs/ntfs3: Add null pointer check for inode operations
  (bsc#1012628).
- fs/ntfs3: Validate attribute name offset (bsc#1012628).
- fs/ntfs3: Validate buffer length while parsing index
  (bsc#1012628).
- fs/ntfs3: Validate resident attribute name (bsc#1012628).
- fs/ntfs3: Fix slab-out-of-bounds read in run_unpack
  (bsc#1012628).
- soundwire: dmi-quirks: add quirk variant for LAPBC710 NUC15
  (bsc#1012628).
- phy: sun4i-usb: Introduce port2 SIDDQ quirk (bsc#1012628).
- phy: sun4i-usb: Add support for the H616 USB PHY (bsc#1012628).
- fs/ntfs3: Validate index root when initialize NTFS security
  (bsc#1012628).
- fs/ntfs3: Use __GFP_NOWARN allocation at wnd_init()
  (bsc#1012628).
- fs/ntfs3: Use __GFP_NOWARN allocation at ntfs_fill_super()
  (bsc#1012628).
- fs/ntfs3: Delete duplicate condition in ntfs_read_mft()
  (bsc#1012628).
- fs/ntfs3: Fix slab-out-of-bounds in r_page (bsc#1012628).
- objtool: Fix SEGFAULT (bsc#1012628).
- iommu/mediatek: Fix crash on isr after kexec() (bsc#1012628).
- powerpc/rtas: avoid device tree lookups in rtas_os_term()
  (bsc#1012628).
- powerpc/rtas: avoid scheduling in rtas_os_term() (bsc#1012628).
- rtc: msc313: Fix function prototype mismatch in
  msc313_rtc_probe() (bsc#1012628).
- kprobes: kretprobe events missing on 2-core KVM guest
  (bsc#1012628).
- HID: multitouch: fix Asus ExpertBook P2 P2451FA trackpoint
  (bsc#1012628).
- HID: plantronics: Additional PIDs for double volume key presses
  quirk (bsc#1012628).
- futex: Fix futex_waitv() hrtimer debug object leak on kcalloc
  error (bsc#1012628).
- rtmutex: Add acquire semantics for rtmutex lock acquisition
  slow path (bsc#1012628).
- mm/mempolicy: fix memory leak in set_mempolicy_home_node system
  call (bsc#1012628).
- kmsan: export kmsan_handle_urb (bsc#1012628).
- kmsan: include linux/vmalloc.h (bsc#1012628).
- pstore: Properly assign mem_type property (bsc#1012628).
- pstore/zone: Use GFP_ATOMIC to allocate zone buffer
  (bsc#1012628).
- hfsplus: fix bug causing custom uid and gid being unable to
  be assigned with mount (bsc#1012628).
- ACPI: x86: s2idle: Force AMD GUID/_REV 2 on HP Elitebook 865
  (bsc#1012628).
- ACPI: x86: s2idle: Stop using AMD specific codepath for
  Rembrandt+ (bsc#1012628).
- binfmt: Fix error return code in load_elf_fdpic_binary()
  (bsc#1012628).
- ovl: Use ovl mounter's fsuid and fsgid in ovl_link()
  (bsc#1012628).
- ovl: update ->f_iocb_flags when ovl_change_flags() modifies
  - >f_flags (bsc#1012628).
- ALSA: line6: correct midi status byte when receiving data from
  podxt (bsc#1012628).
- ALSA: line6: fix stack overflow in line6_midi_transmit
  (bsc#1012628).
- pnode: terminate at peers of source (bsc#1012628).
- mfd: mt6360: Add bounds checking in Regmap read/write call-backs
  (bsc#1012628).
- md: fix a crash in mempool_free (bsc#1012628).
- mm, compaction: fix fast_isolate_around() to stay within
  boundaries (bsc#1012628).
- f2fs: should put a page when checking the summary info
  (bsc#1012628).
- f2fs: allow to read node block after shutdown (bsc#1012628).
- block: Do not reread partition table on exclusively open device
  (bsc#1012628).
- mmc: vub300: fix warning - do not call blocking ops when
  !TASK_RUNNING (bsc#1012628).
- tpm: acpi: Call acpi_put_table() to fix memory leak
  (bsc#1012628).
- tpm: tpm_crb: Add the missed acpi_put_table() to fix memory leak
  (bsc#1012628).
- tpm: tpm_tis: Add the missed acpi_put_table() to fix memory leak
  (bsc#1012628).
- SUNRPC: Don't leak netobj memory when gss_read_proxy_verf()
  fails (bsc#1012628).
- kcsan: Instrument memcpy/memset/memmove with newer Clang
  (bsc#1012628).
- commit a5315fb
* Mon Jan  2 2023 tiwai@suse.de
- Enable Qualcomm soundwire stuff on armv7hl/default (bsc#1206782)
- commit fe2e154
* Mon Jan  2 2023 jslaby@suse.cz
- mm, mremap: fix mremap() expanding vma with addr inside vma
  (bsc#1206359).
  Update upstream status.
- commit 05f50ad
* Mon Jan  2 2023 jslaby@suse.cz
- Refresh patches.suse/tcp-Add-TIME_WAIT-sockets-in-bhash2.patch.
  Update upstream status.
- commit c14f878
* Mon Jan  2 2023 msuchanek@suse.de
- ppc64: Swap out FB_OF for OFDRM (boo#1193476)
  FB_OF=n
  AGP=n
  OFDRM=y
  DRM=y
  This disables support for the Apple UniNorth AGP bridge.
  yast does not support installing on Apple hardware anyway.
- commit eebb76b
* Mon Jan  2 2023 schwab@suse.de
- config: riscv64: disable CONFIG_IPMMU_VMSA
  This is an ARM-only driver.
- commit dc8fbaa
* Mon Jan  2 2023 mkubecek@suse.cz
- Update to 6.2-rc2
- refresh
  - patches.suse/add-suse-supported-flag.patch
- commit 8e1570b
* Sun Jan  1 2023 jslaby@suse.cz
- Linux 6.1.2 (bsc#1012628).
- MIPS: DTS: CI20: fix reset line polarity of the ethernet
  controller (bsc#1012628).
- usb: musb: remove extra check in musb_gadget_vbus_draw
  (bsc#1012628).
- arm64: dts: renesas: r8a779g0: Fix HSCIF0 "brg_int" clock
  (bsc#1012628).
- arm64: dts: qcom: ipq6018-cp01-c1: use BLSPI1 pins
  (bsc#1012628).
- arm64: dts: qcom: sm8250-sony-xperia-edo: fix touchscreen
  bias-disable (bsc#1012628).
- arm64: dts: qcom: sdm845-xiaomi-polaris: fix codec pin conf name
  (bsc#1012628).
- arm64: dts: qcom: msm8996: Add MSM8996 Pro support
  (bsc#1012628).
- arm64: dts: qcom: msm8996: fix supported-hw in cpufreq OPP
  tables (bsc#1012628).
- arm64: dts: qcom: msm8996: fix GPU OPP table (bsc#1012628).
- ARM: dts: qcom: apq8064: fix coresight compatible (bsc#1012628).
- arm64: dts: qcom: sdm630: fix UART1 pin bias (bsc#1012628).
- arm64: dts: qcom: sdm845-cheza: fix AP suspend pin bias
  (bsc#1012628).
- arm64: dts: qcom: msm8916: Drop MSS fallback compatible
  (bsc#1012628).
- arm64: dts: fsd: fix drive strength macros as per FSD HW UM
  (bsc#1012628).
- arm64: dts: fsd: fix drive strength values as per FSD HW UM
  (bsc#1012628).
- memory: renesas-rpc-if: Clear HS bit during hardware
  initialization (bsc#1012628).
- objtool, kcsan: Add volatile read/write instrumentation to
  whitelist (bsc#1012628).
- ARM: dts: stm32: Drop stm32mp15xc.dtsi from Avenger96
  (bsc#1012628).
- ARM: dts: stm32: Fix AV96 WLAN regulator gpio property
  (bsc#1012628).
- drivers: soc: ti: knav_qmss_queue: Mark knav_acc_firmwares as
  static (bsc#1012628).
- firmware: ti_sci: Fix polled mode during system suspend
  (bsc#1012628).
- riscv: dts: microchip: fix memory node unit address for icicle
  (bsc#1012628).
- arm64: dts: qcom: pm660: Use unique ADC5_VCOIN address in node
  name (bsc#1012628).
- arm64: dts: qcom: sm8250: correct LPASS pin pull down
  (bsc#1012628).
- arm64: dts: qcom: sc7180-trogdor-homestar: fully configure
  secondary I2S pins (bsc#1012628).
- soc: qcom: llcc: make irq truly optional (bsc#1012628).
- arm64: dts: qcom: sm8150: fix UFS PHY registers (bsc#1012628).
- arm64: dts: qcom: sm8250: fix UFS PHY registers (bsc#1012628).
- arm64: dts: qcom: sm8350: fix UFS PHY registers (bsc#1012628).
- arm64: dts: qcom: sm8450: fix UFS PHY registers (bsc#1012628).
- arm64: dts: qcom: msm8996: fix sound card reset line polarity
  (bsc#1012628).
- arm64: dts: qcom: sm8250-mtp: fix reset line polarity
  (bsc#1012628).
- arm64: dts: qcom: sc7280: fix codec reset line polarity for
  CRD 3.0/3.1 (bsc#1012628).
- arm64: dts: qcom: sc7280: fix codec reset line polarity for
  CRD 1.0/2.0 (bsc#1012628).
- arm64: dts: qcom: sm8250: drop bogus DP PHY clock (bsc#1012628).
- arm64: dts: qcom: sm6350: drop bogus DP PHY clock (bsc#1012628).
- soc: qcom: apr: Add check for idr_alloc and
  of_property_read_string_index (bsc#1012628).
- arm64: dts: qcom: pm6350: Include header for KEY_POWER
  (bsc#1012628).
- arm64: dts: qcom: sm6125: fix SDHCI CQE reg names (bsc#1012628).
- arm64: dts: renesas: r8a779f0: Fix HSCIF "brg_int" clock
  (bsc#1012628).
- arm64: dts: renesas: r8a779f0: Fix SCIF "brg_int" clock
  (bsc#1012628).
- arm64: dts: renesas: r9a09g011: Fix unit address format error
  (bsc#1012628).
- arm64: dts: renesas: r9a09g011: Fix I2C SoC specific strings
  (bsc#1012628).
- dt-bindings: pwm: fix microchip corePWM's pwm-cells
  (bsc#1012628).
- soc: sifive: ccache: fix missing iounmap() in error path in
  sifive_ccache_init() (bsc#1012628).
- soc: sifive: ccache: fix missing free_irq() in error path in
  sifive_ccache_init() (bsc#1012628).
- soc: sifive: ccache: fix missing of_node_put() in
  sifive_ccache_init() (bsc#1012628).
- arm64: dts: mt7986: fix trng node name (bsc#1012628).
- soc/tegra: cbb: Use correct master_id mask for CBB NOC in
  Tegra194 (bsc#1012628).
- soc/tegra: cbb: Update slave maps for Tegra234 (bsc#1012628).
- soc/tegra: cbb: Add checks for potential out of bound errors
  (bsc#1012628).
- soc/tegra: cbb: Check firewall before enabling error reporting
  (bsc#1012628).
- arm64: dts: qcom: sc7280: Mark all Qualcomm reference boards
  as LTE (bsc#1012628).
- arm: dts: spear600: Fix clcd interrupt (bsc#1012628).
- riscv: dts: microchip: fix the icicle's #pwm-cells
  (bsc#1012628).
- soc: ti: knav_qmss_queue: Fix PM disable depth imbalance in
  knav_queue_probe (bsc#1012628).
- soc: ti: smartreflex: Fix PM disable depth imbalance in
  omap_sr_probe (bsc#1012628).
- arm64: mm: kfence: only handle translation faults (bsc#1012628).
- perf: arm_dsu: Fix hotplug callback leak in dsu_pmu_init()
  (bsc#1012628).
- drivers: perf: marvell_cn10k: Fix hotplug callback leak in
  tad_pmu_init() (bsc#1012628).
- perf/arm_dmc620: Fix hotplug callback leak in dmc620_pmu_init()
  (bsc#1012628).
- perf/smmuv3: Fix hotplug callback leak in arm_smmu_pmu_init()
  (bsc#1012628).
- arm64: dts: ti: k3-am65-main: Drop dma-coherent in crypto node
  (bsc#1012628).
- arm64: dts: ti: k3-j721e-main: Drop dma-coherent in crypto node
  (bsc#1012628).
- arm64: dts: ti: k3-j7200-mcu-wakeup: Drop dma-coherent in
  crypto node (bsc#1012628).
- arm64: dts: ti: k3-j721s2: Fix the interrupt ranges property
  for main & wkup gpio intr (bsc#1012628).
- riscv: dts: microchip: remove pcie node from the sev kit
  (bsc#1012628).
- ARM: dts: nuvoton: Remove bogus unit addresses from
  fixed-partition nodes (bsc#1012628).
- arm64: dts: mediatek: mt8195: Fix CPUs capacity-dmips-mhz
  (bsc#1012628).
- arm64: dts: mt7896a: Fix unit_address_vs_reg warning for
  oscillator (bsc#1012628).
- arm64: dts: mt6779: Fix devicetree build warnings (bsc#1012628).
- arm64: dts: mt2712e: Fix unit_address_vs_reg warning for
  oscillators (bsc#1012628).
- arm64: dts: mt2712e: Fix unit address for pinctrl node
  (bsc#1012628).
- arm64: dts: mt2712-evb: Fix vproc fixed regulators unit names
  (bsc#1012628).
- arm64: dts: mt2712-evb: Fix usb vbus regulators unit names
  (bsc#1012628).
- arm64: dts: mediatek: pumpkin-common: Fix devicetree warnings
  (bsc#1012628).
- arm64: dts: mediatek: mt6797: Fix 26M oscillator unit name
  (bsc#1012628).
- arm64: tegra: Fix Prefetchable aperture ranges of Tegra234
  PCIe controllers (bsc#1012628).
- arm64: tegra: Fix non-prefetchable aperture of PCIe C3
  controller (bsc#1012628).
- arm64: dts: mt7986: move wed_pcie node (bsc#1012628).
- ARM: dts: dove: Fix assigned-addresses for every PCIe Root Port
  (bsc#1012628).
- ARM: dts: armada-370: Fix assigned-addresses for every PCIe
  Root Port (bsc#1012628).
- ARM: dts: armada-xp: Fix assigned-addresses for every PCIe
  Root Port (bsc#1012628).
- ARM: dts: armada-375: Fix assigned-addresses for every PCIe
  Root Port (bsc#1012628).
- ARM: dts: armada-38x: Fix assigned-addresses for every PCIe
  Root Port (bsc#1012628).
- ARM: dts: armada-39x: Fix assigned-addresses for every PCIe
  Root Port (bsc#1012628).
- ARM: dts: turris-omnia: Add ethernet aliases (bsc#1012628).
- ARM: dts: turris-omnia: Add switch port 6 node (bsc#1012628).
- arm64: dts: armada-3720-turris-mox: Add missing interrupt for
  RTC (bsc#1012628).
- soc: apple: sart: Stop casting function pointer signatures
  (bsc#1012628).
- soc: apple: rtkit: Stop casting function pointer signatures
  (bsc#1012628).
- drivers/perf: hisi: Fix some event id for hisi-pcie-pmu
  (bsc#1012628).
- seccomp: Move copy_seccomp() to no failure path (bsc#1012628).
- pstore/ram: Fix error return code in ramoops_probe()
  (bsc#1012628).
- ARM: mmp: fix timer_read delay (bsc#1012628).
- pstore: Avoid kcore oops by vmap()ing with VM_IOREMAP
  (bsc#1012628).
- arch: arm64: apple: t8103: Use standard "iommu" node name
  (bsc#1012628).
- tpm: tis_i2c: Fix sanity check interrupt enable mask
  (bsc#1012628).
- tpm: Add flag to use default cancellation policy (bsc#1012628).
- tpm/tpm_ftpm_tee: Fix error handling in ftpm_mod_init()
  (bsc#1012628).
- tpm/tpm_crb: Fix error message in __crb_relinquish_locality()
  (bsc#1012628).
- ovl: remove privs in ovl_copyfile() (bsc#1012628).
- ovl: remove privs in ovl_fallocate() (bsc#1012628).
- sched/uclamp: Fix relationship between uclamp and migration
  margin (bsc#1012628).
- sched/uclamp: Make task_fits_capacity() use util_fits_cpu()
  (bsc#1012628).
- sched/uclamp: Fix fits_capacity() check in feec() (bsc#1012628).
- sched/uclamp: Make select_idle_capacity() use util_fits_cpu()
  (bsc#1012628).
- sched/uclamp: Make asym_fits_capacity() use util_fits_cpu()
  (bsc#1012628).
- sched/uclamp: Make cpu_overutilized() use util_fits_cpu()
  (bsc#1012628).
- sched/uclamp: Cater for uclamp in find_energy_efficient_cpu()'s
  early exit condition (bsc#1012628).
- cpuidle: dt: Return the correct numbers of parsed idle states
  (bsc#1012628).
- alpha: fix TIF_NOTIFY_SIGNAL handling (bsc#1012628).
- alpha: fix syscall entry in !AUDUT_SYSCALL case (bsc#1012628).
- sched/psi: Fix possible missing or delayed pending event
  (bsc#1012628).
- x86/sgx: Reduce delay and interference of enclave release
  (bsc#1012628).
- PM: hibernate: Fix mistake in kerneldoc comment (bsc#1012628).
- fs: don't audit the capability check in simple_xattr_list()
  (bsc#1012628).
- cpufreq: qcom-hw: Fix memory leak in qcom_cpufreq_hw_read_lut()
  (bsc#1012628).
- x86/split_lock: Add sysctl to control the misery mode
  (bsc#1012628).
- ACPI: irq: Fix some kernel-doc issues (bsc#1012628).
- selftests/ftrace: event_triggers: wait longer for
  test_event_enable (bsc#1012628).
- perf: Fix possible memleak in pmu_dev_alloc() (bsc#1012628).
- lib/debugobjects: fix stat count and optimize
  debug_objects_mem_init (bsc#1012628).
- platform/x86: huawei-wmi: fix return value calculation
  (bsc#1012628).
- timerqueue: Use rb_entry_safe() in timerqueue_getnext()
  (bsc#1012628).
- proc: fixup uptime selftest (bsc#1012628).
- lib/fonts: fix undefined behavior in bit shift for
  get_default_font (bsc#1012628).
- ocfs2: fix memory leak in ocfs2_stack_glue_init() (bsc#1012628).
- selftests: cgroup: fix unsigned comparison with less than zero
  (bsc#1012628).
- cpufreq: qcom-hw: Fix the frequency returned by
  cpufreq_driver->get() (bsc#1012628).
- MIPS: vpe-mt: fix possible memory leak while module exiting
  (bsc#1012628).
- MIPS: vpe-cmp: fix possible memory leak while module exiting
  (bsc#1012628).
- selftests/efivarfs: Add checking of the test return value
  (bsc#1012628).
- PNP: fix name memory leak in pnp_alloc_dev() (bsc#1012628).
- mailbox: pcc: Reset pcc_chan_count to zero in case of PCC
  probe failure (bsc#1012628).
- ACPI: pfr_telemetry: use ACPI_FREE() to free acpi_object
  (bsc#1012628).
- ACPI: pfr_update: use ACPI_FREE() to free acpi_object
  (bsc#1012628).
- perf/x86/intel/uncore: Fix reference count leak in
  sad_cfg_iio_topology() (bsc#1012628).
- perf/x86/intel/uncore: Fix reference count leak in
  hswep_has_limit_sbox() (bsc#1012628).
- perf/x86/intel/uncore: Fix reference count leak in
  snr_uncore_mmio_map() (bsc#1012628).
- perf/x86/intel/uncore: Fix reference count leak in
  __uncore_imc_init_box() (bsc#1012628).
- platform/chrome: cros_usbpd_notify: Fix error handling in
  cros_usbpd_notify_init() (bsc#1012628).
- thermal: core: fix some possible name leaks in error paths
  (bsc#1012628).
- irqchip/loongson-pch-pic: Fix translate callback for DT path
  (bsc#1012628).
- irqchip: gic-pm: Use pm_runtime_resume_and_get() in gic_probe()
  (bsc#1012628).
- irqchip/wpcm450: Fix memory leak in wpcm450_aic_of_init()
  (bsc#1012628).
- irqchip/loongson-liointc: Fix improper error handling in
  liointc_init() (bsc#1012628).
- EDAC/i10nm: fix refcount leak in pci_get_dev_wrapper()
  (bsc#1012628).
- NFSD: Finish converting the NFSv2 GETACL result encoder
  (bsc#1012628).
- NFSD: Finish converting the NFSv3 GETACL result encoder
  (bsc#1012628).
- nfsd: don't call nfsd_file_put from client states seqfile
  display (bsc#1012628).
- genirq/irqdesc: Don't try to remove non-existing sysfs files
  (bsc#1012628).
- cpufreq: amd_freq_sensitivity: Add missing pci_dev_put()
  (bsc#1012628).
- libfs: add DEFINE_SIMPLE_ATTRIBUTE_SIGNED for signed value
  (bsc#1012628).
- lib/notifier-error-inject: fix error when writing -errno to
  debugfs file (bsc#1012628).
- debugfs: fix error when writing negative value to atomic_t
  debugfs file (bsc#1012628).
- ocfs2: fix memory leak in ocfs2_mount_volume() (bsc#1012628).
- rapidio: fix possible name leaks when rio_add_device() fails
  (bsc#1012628).
- rapidio: rio: fix possible name leak in rio_register_mport()
  (bsc#1012628).
- clocksource/drivers/sh_cmt: Access registers according to spec
  (bsc#1012628).
- futex: Resend potentially swallowed owner death notification
  (bsc#1012628).
- cpu/hotplug: Make target_store() a nop when target == state
  (bsc#1012628).
- cpu/hotplug: Do not bail-out in DYING/STARTING sections
  (bsc#1012628).
- clocksource/drivers/timer-ti-dm: Fix warning for
  omap_timer_match (bsc#1012628).
- clocksource/drivers/timer-ti-dm: Fix missing
  clk_disable_unprepare in dmtimer_systimer_init_clock()
  (bsc#1012628).
- ACPICA: Fix use-after-free in
  acpi_ut_copy_ipackage_to_ipackage() (bsc#1012628).
- uprobes/x86: Allow to probe a NOP instruction with 0x66 prefix
  (bsc#1012628).
- x86/xen: Fix memory leak in xen_smp_intr_init{_pv}()
  (bsc#1012628).
- x86/xen: Fix memory leak in xen_init_lock_cpu() (bsc#1012628).
- xen/privcmd: Fix a possible warning in
  privcmd_ioctl_mmap_resource() (bsc#1012628).
- PM: runtime: Do not call __rpm_callback() from rpm_idle()
  (bsc#1012628).
- erofs: check the uniqueness of fsid in shared domain in advance
  (bsc#1012628).
- erofs: Fix pcluster memleak when its block address is zero
  (bsc#1012628).
- erofs: fix missing unmap if z_erofs_get_extent_compressedlen()
  fails (bsc#1012628).
- erofs: validate the extent length for uncompressed pclusters
  (bsc#1012628).
- platform/chrome: cros_ec_typec: zero out stale pointers
  (bsc#1012628).
- platform/x86: mxm-wmi: fix memleak in mxm_wmi_call_mx[ds|mx]()
  (bsc#1012628).
- platform/x86: intel_scu_ipc: fix possible name leak in
  __intel_scu_ipc_register() (bsc#1012628).
- MIPS: BCM63xx: Add check for NULL for clk in clk_enable
  (bsc#1012628).
- MIPS: OCTEON: warn only once if deprecated link status is
  being used (bsc#1012628).
- lockd: set other missing fields when unlocking files
  (bsc#1012628).
- nfsd: return error if nfs4_setacl fails (bsc#1012628).
- NFSD: pass range end to vfs_fsync_range() instead of count
  (bsc#1012628).
- fs: sysv: Fix sysv_nblocks() returns wrong value (bsc#1012628).
- rapidio: fix possible UAF when kfifo_alloc() fails
  (bsc#1012628).
- eventfd: change int to __u64 in eventfd_signal() ifndef
  CONFIG_EVENTFD (bsc#1012628).
- relay: fix type mismatch when allocating memory in
  relay_create_buf() (bsc#1012628).
- hfs: Fix OOB Write in hfs_asc2mac (bsc#1012628).
- rapidio: devices: fix missing put_device in mport_cdev_open
  (bsc#1012628).
- ipc: fix memory leak in init_mqueue_fs() (bsc#1012628).
- platform/mellanox: mlxbf-pmc: Fix event typo (bsc#1012628).
- selftests/bpf: Add missing bpf_iter_vma_offset__destroy call
  (bsc#1012628).
- wifi: fix multi-link element subelement iteration (bsc#1012628).
- wifi: mac80211: mlme: fix null-ptr deref on failed assoc
  (bsc#1012628).
- wifi: mac80211: check link ID in auth/assoc continuation
  (bsc#1012628).
- wifi: mac80211: fix ifdef symbol name (bsc#1012628).
- drm/atomic-helper: Don't allocate new plane state in CRTC check
  (bsc#1012628).
- wifi: ath9k: hif_usb: fix memory leak of urbs in
  ath9k_hif_usb_dealloc_tx_urbs() (bsc#1012628).
- wifi: ath9k: hif_usb: Fix use-after-free in
  ath9k_hif_usb_reg_in_cb() (bsc#1012628).
- wifi: rtl8xxxu: Fix reading the vendor of combo chips
  (bsc#1012628).
- wifi: ath11k: fix firmware assert during bandwidth change for
  peer sta (bsc#1012628).
- drm/bridge: adv7533: remove dynamic lane switching from adv7533
  bridge (bsc#1012628).
- libbpf: Fix use-after-free in btf_dump_name_dups (bsc#1012628).
- libbpf: Fix memory leak in parse_usdt_arg() (bsc#1012628).
- selftests/bpf: Fix memory leak caused by not destroying skeleton
  (bsc#1012628).
- selftest/bpf: Fix memory leak in kprobe_multi_test
  (bsc#1012628).
- selftests/bpf: Fix error failure of case
  test_xdp_adjust_tail_grow (bsc#1012628).
- selftest/bpf: Fix error usage of ASSERT_OK in xdp_adjust_tail.c
  (bsc#1012628).
- libbpf: Use elf_getshdrnum() instead of e_shnum (bsc#1012628).
- libbpf: Deal with section with no data gracefully (bsc#1012628).
- libbpf: Fix null-pointer dereference in find_prog_by_sec_insn()
  (bsc#1012628).
- drm: lcdif: Switch to limited range for RGB to YUV conversion
  (bsc#1012628).
- ata: libata: fix NCQ autosense logic (bsc#1012628).
- pinctrl: ocelot: add missing destroy_workqueue() in error path
  in ocelot_pinctrl_probe() (bsc#1012628).
- ASoC: Intel: avs: Fix DMA mask assignment (bsc#1012628).
- ASoC: Intel: avs: Fix potential RX buffer overflow
  (bsc#1012628).
- ipmi: kcs: Poll OBF briefly to reduce OBE latency (bsc#1012628).
- drm/amdgpu: Revert "drm/amdgpu: getting fan speed pwm for
  vega10 properly" (bsc#1012628).
- drm/amdgpu/powerplay/psm: Fix memory leak in power state init
  (bsc#1012628).
- net: ethernet: adi: adin1110: Fix SPI transfers (bsc#1012628).
- samples/bpf: Fix map iteration in xdp1_user (bsc#1012628).
- samples/bpf: Fix MAC address swapping in xdp2_kern
  (bsc#1012628).
- selftests/bpf: fix missing BPF object files (bsc#1012628).
- drm/bridge: it6505: Initialize AUX channel in it6505_i2c_probe
  (bsc#1012628).
- Input: iqs7222 - protect against undefined slider size
  (bsc#1012628).
- media: v4l2-ctrls: Fix off-by-one error in integer menu control
  check (bsc#1012628).
- media: coda: jpeg: Add check for kmalloc (bsc#1012628).
- media: amphion: reset instance if it's aborted before codec
  header parsed (bsc#1012628).
- media: adv748x: afe: Select input port when initializing AFE
  (bsc#1012628).
- media: v4l2-ioctl.c: Unify YCbCr/YUV terms in format
  descriptions (bsc#1012628).
- media: cedrus: hevc: Fix offset adjustments (bsc#1012628).
- media: mediatek: vcodec: fix h264 cavlc bitstream fail
  (bsc#1012628).
- drm/i915/guc: Limit scheduling properties to avoid overflow
  (bsc#1012628).
- drm/i915: Fix compute pre-emption w/a to apply to compute
  engines (bsc#1012628).
- media: i2c: hi846: Fix memory leak in hi846_parse_dt()
  (bsc#1012628).
- media: i2c: ad5820: Fix error path (bsc#1012628).
- venus: pm_helpers: Fix error check in vcodec_domains_get()
  (bsc#1012628).
- soreuseport: Fix socket selection for SO_INCOMING_CPU
  (bsc#1012628).
- media: i2c: ov5648: Free V4L2 fwnode data on unbind
  (bsc#1012628).
- media: exynos4-is: don't rely on the v4l2_async_subdev internals
  (bsc#1012628).
- libbpf: Btf dedup identical struct test needs check for nested
  structs/arrays (bsc#1012628).
- can: kvaser_usb: kvaser_usb_leaf: Get capabilities from device
  (bsc#1012628).
- can: kvaser_usb: kvaser_usb_leaf:
  Rename {leaf,usbcan}_cmd_error_event to
  {leaf,usbcan}_cmd_can_error_event (bsc#1012628).
- can: kvaser_usb: kvaser_usb_leaf: Handle CMD_ERROR_EVENT
  (bsc#1012628).
- can: kvaser_usb_leaf: Set Warning state even without bus errors
  (bsc#1012628).
- can: kvaser_usb_leaf: Fix improved state not being reported
  (bsc#1012628).
- can: kvaser_usb_leaf: Fix wrong CAN state after stopping
  (bsc#1012628).
- can: kvaser_usb_leaf: Fix bogus restart events (bsc#1012628).
- can: kvaser_usb: Add struct kvaser_usb_busparams (bsc#1012628).
- can: kvaser_usb: Compare requested bittiming parameters with
  actual parameters in do_set_{,data}_bittiming (bsc#1012628).
- clk: renesas: r8a779f0: Fix SD0H clock name (bsc#1012628).
- clk: renesas: r8a779a0: Fix SD0H clock name (bsc#1012628).
- ASoC: dt-bindings: rt5682: Set sound-dai-cells to 1
  (bsc#1012628).
- drm/i915/guc: Add error-capture init warnings when needed
  (bsc#1012628).
- drm/i915/guc: Fix GuC error capture sizing estimation and
  reporting (bsc#1012628).
- dw9768: Enable low-power probe on ACPI (bsc#1012628).
- drm/amd/display: wait for vblank during pipe programming
  (bsc#1012628).
- drm/rockchip: lvds: fix PM usage counter unbalance in poweron
  (bsc#1012628).
- drm/i915: Handle all GTs on driver (un)load paths (bsc#1012628).
- drm/i915: Refactor ttm ghost obj detection (bsc#1012628).
- drm/i915: Encapsulate lmem rpm stuff in intel_runtime_pm
  (bsc#1012628).
- drm/i915/dgfx: Grab wakeref at i915_ttm_unmap_virtual
  (bsc#1012628).
- clk: renesas: r9a06g032: Repair grave increment error
  (bsc#1012628).
- drm: lcdif: change burst size to 256B (bsc#1012628).
- drm/panel/panel-sitronix-st7701: Fix RTNI calculation
  (bsc#1012628).
- spi: Update reference to struct spi_controller (bsc#1012628).
- drm/panel/panel-sitronix-st7701: Remove panel on DSI attach
  failure (bsc#1012628).
- drm/ttm: fix undefined behavior in bit shift for
  TTM_TT_FLAG_PRIV_POPULATED (bsc#1012628).
- drm/msm/mdp5: stop overriding drvdata (bsc#1012628).
- ima: Handle -ESTALE returned by ima_filter_rule_match()
  (bsc#1012628).
- drm/msm/hdmi: use devres helper for runtime PM management
  (bsc#1012628).
- bpf: Clobber stack slot when writing over spilled PTR_TO_BTF_ID
  (bsc#1012628).
- bpf: Fix slot type check in check_stack_write_var_off
  (bsc#1012628).
- drm/msm/dpu1: Account for DSC's bits_per_pixel having 4
  fractional bits (bsc#1012628).
- drm/msm/dsi: Remove useless math in DSC calculations
  (bsc#1012628).
- drm/msm/dsi: Remove repeated calculation of slice_per_intf
  (bsc#1012628).
- drm/msm/dsi: Use DIV_ROUND_UP instead of conditional increment
  on modulo (bsc#1012628).
- drm/msm/dsi: Reuse earlier computed dsc->slice_chunk_size
  (bsc#1012628).
- drm/msm/dsi: Appropriately set dsc->mux_word_size based on bpc
  (bsc#1012628).
- drm/msm/dsi: Migrate to drm_dsc_compute_rc_parameters()
  (bsc#1012628).
- drm/msm/dsi: Account for DSC's bits_per_pixel having 4
  fractional bits (bsc#1012628).
- drm/msm/dsi: Disallow 8 BPC DSC configuration for alternative
  BPC values (bsc#1012628).
- drm/msm/dsi: Prevent signed BPG offsets from bleeding into
  adjacent bits (bsc#1012628).
- media: platform: mtk-mdp3: fix error handling in mdp_cmdq_send()
  (bsc#1012628).
- media: platform: mtk-mdp3: fix error handling about components
  clock_on (bsc#1012628).
- media: platform: mtk-mdp3: fix error handling in mdp_probe()
  (bsc#1012628).
- media: rkvdec: Add required padding (bsc#1012628).
- media: vivid: fix compose size exceed boundary (bsc#1012628).
- media: platform: exynos4-is: fix return value check in
  fimc_md_probe() (bsc#1012628).
- bpf: propagate precision in ALU/ALU64 operations (bsc#1012628).
- bpf: propagate precision across all frames, not just the last
  one (bsc#1012628).
- clk: qcom: gcc-ipq806x: use parent_data for the last remaining
  entry (bsc#1012628).
- clk: qcom: dispcc-sm6350: Add CLK_OPS_PARENT_ENABLE to
  pixel&byte src (bsc#1012628).
- clk: qcom: gcc-sm8250: Use retention mode for USB GDSCs
  (bsc#1012628).
- mtd: Fix device name leak when register device failed in
  add_mtd_device() (bsc#1012628).
- mtd: core: fix possible resource leak in init_mtd()
  (bsc#1012628).
- Input: joystick - fix Kconfig warning for JOYSTICK_ADC
  (bsc#1012628).
- wifi: rsi: Fix handling of 802.3 EAPOL frames sent via control
  port (bsc#1012628).
- media: camss: Clean up received buffers on failed start of
  streaming (bsc#1012628).
- media: camss: Do not attach an already attached power domain
  on MSM8916 platform (bsc#1012628).
- clk: renesas: r8a779f0: Fix HSCIF parent clocks (bsc#1012628).
- clk: renesas: r8a779f0: Fix SCIF parent clocks (bsc#1012628).
- virt/sev-guest: Add a MODULE_ALIAS (bsc#1012628).
- net, proc: Provide PROC_FS=n fallback for
  proc_create_net_single_write() (bsc#1012628).
- rxrpc: Fix ack.bufferSize to be 0 when generating an ack
  (bsc#1012628).
- drm: lcdif: Set and enable FIFO Panic threshold (bsc#1012628).
- wifi: rtw89: use u32_encode_bits() to fill MAC quota value
  (bsc#1012628).
- drm: rcar-du: Drop leftovers dependencies from Kconfig
  (bsc#1012628).
- regmap-irq: Use the new num_config_regs property in
  regmap_add_irq_chip_fwnode (bsc#1012628).
- drbd: use blk_queue_max_discard_sectors helper (bsc#1012628).
- bfq: fix waker_bfqq inconsistency crash (bsc#1012628).
- drm/radeon: Add the missed acpi_put_table() to fix memory leak
  (bsc#1012628).
- dt-bindings: pinctrl: update uart/mmc bindings for MT7986 SoC
  (bsc#1012628).
- pinctrl: mediatek: fix the pinconf register offset of some pins
  (bsc#1012628).
- wifi: iwlwifi: mei: make sure ownership confirmed message is
  sent (bsc#1012628).
- wifi: iwlwifi: mei: don't send SAP commands if AMT is disabled
  (bsc#1012628).
- wifi: iwlwifi: mei: fix tx DHCP packet for devices with new
  Tx API (bsc#1012628).
- wifi: iwlwifi: mei: avoid blocking sap messages handling due
  to rtnl lock (bsc#1012628).
- wifi: iwlwifi: mei: fix potential NULL-ptr deref after clone
  (bsc#1012628).
- module: Fix NULL vs IS_ERR checking for module_get_next_page
  (bsc#1012628).
- ASoC: codecs: wsa883x: Use proper shutdown GPIO polarity
  (bsc#1012628).
- ASoC: codecs: wsa883x: use correct header file (bsc#1012628).
- selftests/bpf: Fix xdp_synproxy compilation failure in 32-bit
  arch (bsc#1012628).
- selftests/bpf: Fix incorrect ASSERT in the tcp_hdr_options test
  (bsc#1012628).
- drm/mediatek: Modify dpi power on/off sequence (bsc#1012628).
- ASoC: pxa: fix null-pointer dereference in filter()
  (bsc#1012628).
- nvmet: only allocate a single slab for bvecs (bsc#1012628).
- regulator: core: fix unbalanced of node refcount in
  regulator_dev_lookup() (bsc#1012628).
- amdgpu/pm: prevent array underflow in
  vega20_odn_edit_dpm_table() (bsc#1012628).
- nvme: return err on nvme_init_non_mdts_limits fail
  (bsc#1012628).
- wifi: rtw89: Fix some error handling path in
  rtw89_core_sta_assoc() (bsc#1012628).
- regulator: qcom-rpmh: Fix PMR735a S3 regulator spec
  (bsc#1012628).
- drm/fourcc: Fix vsub/hsub for Q410 and Q401 (bsc#1012628).
- ALSA: memalloc: Allocate more contiguous pages for fallback case
  (bsc#1012628).
- integrity: Fix memory leakage in keyring allocation error path
  (bsc#1012628).
- ima: Fix misuse of dereference of pointer in
  template_desc_init_fields() (bsc#1012628).
- block: clear ->slave_dir when dropping the main slave_dir
  reference (bsc#1012628).
- dm: cleanup open_table_device (bsc#1012628).
- dm: cleanup close_table_device (bsc#1012628).
- dm: make sure create and remove dm device won't race with open
  and close table (bsc#1012628).
- dm: track per-add_disk holder relations in DM (bsc#1012628).
- selftests/bpf: fix memory leak of lsm_cgroup (bsc#1012628).
- wifi: ath10k: Fix return value in ath10k_pci_init()
  (bsc#1012628).
- drm/msm/a6xx: Fix speed-bin detection vs probe-defer
  (bsc#1012628).
- mtd: lpddr2_nvm: Fix possible null-ptr-deref (bsc#1012628).
- Input: elants_i2c - properly handle the reset GPIO when power
  is off (bsc#1012628).
- ASoC: amd: acp: Fix possible UAF in acp_dma_open (bsc#1012628).
- net: ethernet: mtk_eth_soc: do not overwrite mtu configuration
  running reset routine (bsc#1012628).
- media: amphion: add lock around vdec_g_fmt (bsc#1012628).
- media: amphion: apply vb2_queue_error instead of setting
  manually (bsc#1012628).
- media: vidtv: Fix use-after-free in vidtv_bridge_dvb_init()
  (bsc#1012628).
- media: solo6x10: fix possible memory leak in solo_sysfs_init()
  (bsc#1012628).
- media: platform: exynos4-is: Fix error handling in
  fimc_md_init() (bsc#1012628).
- media: amphion: Fix error handling in vpu_driver_init()
  (bsc#1012628).
- media: videobuf-dma-contig: use dma_mmap_coherent (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix RSTCTRL_PPE{0,1} definitions
  (bsc#1012628).
- udp: Clean up some functions (bsc#1012628).
- net: Return errno in sk->sk_prot->get_port() (bsc#1012628).
- mtd: spi-nor: hide jedec_id sysfs attribute if not present
  (bsc#1012628).
- mtd: spi-nor: Fix the number of bytes for the dummy cycles
  (bsc#1012628).
- clk: imx93: correct the flexspi1 clock setting (bsc#1012628).
- bpf: Pin the start cgroup in cgroup_iter_seq_init()
  (bsc#1012628).
- HID: i2c: let RMI devices decide what constitutes wakeup event
  (bsc#1012628).
- clk: imx93: unmap anatop base in error handling path
  (bsc#1012628).
- clk: imx93: correct enet clock (bsc#1012628).
- bpf: Move skb->len == 0 checks into __bpf_redirect
  (bsc#1012628).
- HID: hid-sensor-custom: set fixed size for custom attributes
  (bsc#1012628).
- clk: imx: imxrt1050: fix IMXRT1050_CLK_LCDIF_APB offsets
  (bsc#1012628).
- pinctrl: k210: call of_node_put() (bsc#1012628).
- wifi: rtw89: fix physts IE page check (bsc#1012628).
- ASoC: Intel: Skylake: Fix Kconfig dependency (bsc#1012628).
- ASoC: Intel: avs: Lock substream before snd_pcm_stop()
  (bsc#1012628).
- ALSA: pcm: fix undefined behavior in bit shift for
  SNDRV_PCM_RATE_KNOT (bsc#1012628).
- ALSA: seq: fix undefined behavior in bit shift for
  SNDRV_SEQ_FILTER_USE_EVENT (bsc#1012628).
- regulator: core: use kfree_const() to free space conditionally
  (bsc#1012628).
- clk: rockchip: Fix memory leak in rockchip_clk_register_pll()
  (bsc#1012628).
- drm/amdgpu: fix pci device refcount leak (bsc#1012628).
- drm/i915/guc: make default_lists const data (bsc#1012628).
- selftests/bpf: Make sure zero-len skbs aren't redirectable
  (bsc#1012628).
- selftests/bpf: Mount debugfs in setns_by_fd (bsc#1012628).
- bonding: fix link recovery in mode 2 when updelay is nonzero
  (bsc#1012628).
- clk: microchip: check for null return of devm_kzalloc()
  (bsc#1012628).
- mtd: core: Fix refcount error in del_mtd_device() (bsc#1012628).
- mtd: maps: pxa2xx-flash: fix memory leak in probe (bsc#1012628).
- drbd: remove call to memset before free
  device/resource/connection (bsc#1012628).
- drbd: destroy workqueue when drbd device was freed
  (bsc#1012628).
- ASoC: qcom: Add checks for devm_kcalloc (bsc#1012628).
- ASoC: qcom: cleanup and fix dependency of QCOM_COMMON
  (bsc#1012628).
- ASoC: mediatek: mt8186: Correct I2S shared clocks (bsc#1012628).
- media: vimc: Fix wrong function called when vimc_init() fails
  (bsc#1012628).
- media: imon: fix a race condition in send_packet()
  (bsc#1012628).
- media: imx: imx7-media-csi: Clear BIT_MIPI_DOUBLE_CMPNT for
  <16b formats (bsc#1012628).
- media: mt9p031: Drop bogus v4l2_subdev_get_try_crop() call
  from mt9p031_init_cfg() (bsc#1012628).
- clk: imx8mn: rename vpu_pll to m7_alt_pll (bsc#1012628).
- clk: imx: replace osc_hdmi with dummy (bsc#1012628).
- clk: imx: rename video_pll1 to video_pll (bsc#1012628).
- clk: imx8mn: fix imx8mn_sai2_sels clocks list (bsc#1012628).
- clk: imx8mn: fix imx8mn_enet_phy_sels clocks list (bsc#1012628).
- pinctrl: pinconf-generic: add missing of_node_put()
  (bsc#1012628).
- media: dvb-core: Fix ignored return value in
  dvb_register_frontend() (bsc#1012628).
- media: dvb-usb: az6027: fix null-ptr-deref in az6027_i2c_xfer()
  (bsc#1012628).
- x86/boot: Skip realmode init code when running as Xen PV guest
  (bsc#1012628).
- media: sun6i-mipi-csi2: Require both pads to be connected for
  streaming (bsc#1012628).
- media: sun8i-a83t-mipi-csi2: Require both pads to be connected
  for streaming (bsc#1012628).
- media: sun6i-mipi-csi2: Register async subdev with no sensor
  attached (bsc#1012628).
- media: sun8i-a83t-mipi-csi2: Register async subdev with no
  sensor attached (bsc#1012628).
- media: amphion: try to wakeup vpu core to avoid failure
  (bsc#1012628).
- media: amphion: cancel vpu before release instance
  (bsc#1012628).
- media: amphion: lock and check m2m_ctx in event handler
  (bsc#1012628).
- media: mediatek: vcodec: Fix getting NULL pointer for dst buffer
  (bsc#1012628).
- media: mediatek: vcodec: Fix h264 set lat buffer error
  (bsc#1012628).
- media: mediatek: vcodec: Setting lat buf to lat_list when lat
  decode error (bsc#1012628).
- media: mediatek: vcodec: Core thread depends on core_list
  (bsc#1012628).
- media: s5p-mfc: Add variant data for MFC v7 hardware for Exynos
  3250 SoC (bsc#1012628).
- drm/tegra: Add missing clk_disable_unprepare() in
  tegra_dc_probe() (bsc#1012628).
- ASoC: dt-bindings: wcd9335: fix reset line polarity in example
  (bsc#1012628).
- ASoC: mediatek: mtk-btcvsd: Add checks for write and read of
  mtk_btcvsd_snd (bsc#1012628).
- drm/msm/mdp5: fix reading hw revision on db410c platform
  (bsc#1012628).
- NFSv4.2: Clear FATTR4_WORD2_SECURITY_LABEL when done decoding
  (bsc#1012628).
- NFSv4.2: Always decode the security label (bsc#1012628).
- NFSv4.2: Fix a memory stomp in decode_attr_security_label
  (bsc#1012628).
- NFSv4.2: Fix initialisation of struct nfs4_label (bsc#1012628).
- NFSv4: Fix a credential leak in _nfs4_discover_trunking()
  (bsc#1012628).
- NFSv4: Fix a deadlock between nfs4_open_recover_helper()
  and delegreturn (bsc#1012628).
- NFS: Fix an Oops in nfs_d_automount() (bsc#1012628).
- ALSA: asihpi: fix missing pci_disable_device() (bsc#1012628).
- wifi: plfxlc: fix potential memory leak in
  __lf_x_usb_enable_rx() (bsc#1012628).
- wifi: rtl8xxxu: Fix use after rcu_read_unlock in
  rtl8xxxu_bss_info_changed (bsc#1012628).
- wifi: iwlwifi: mvm: fix double free on tx path (bsc#1012628).
- ASoC: mediatek: mt8173: Enable IRQ when pdata is ready
  (bsc#1012628).
- clk: mediatek: fix dependency of MT7986 ADC clocks
  (bsc#1012628).
- drm/amd/pm/smu11: BACO is supported when it's in BACO state
  (bsc#1012628).
- amdgpu/nv.c: Corrected typo in the video capabilities resolution
  (bsc#1012628).
- drm/radeon: Fix PCI device refcount leak in
  radeon_atrm_get_bios() (bsc#1012628).
- drm/amdgpu: Fix PCI device refcount leak in
  amdgpu_atrm_get_bios() (bsc#1012628).
- drm/amdkfd: Fix memory leakage (bsc#1012628).
- drm/i915/bios: fix a memory leak in generate_lfp_data_ptrs
  (bsc#1012628).
- ASoC: pcm512x: Fix PM disable depth imbalance in pcm512x_probe
  (bsc#1012628).
- clk: visconti: Fix memory leak in visconti_register_pll()
  (bsc#1012628).
- netfilter: conntrack: set icmpv6 redirects as RELATED
  (bsc#1012628).
- Input: wistron_btns - disable on UML (bsc#1012628).
- bpf, sockmap: Fix repeated calls to sock_put() when msg has
  more_data (bsc#1012628).
- bpf, sockmap: Fix missing BPF_F_INGRESS flag when using
  apply_bytes (bsc#1012628).
- bpf, sockmap: Fix data loss caused by using apply_bytes on
  ingress redirect (bsc#1012628).
- bonding: uninitialized variable in bond_miimon_inspect()
  (bsc#1012628).
- spi: spidev: mask SPI_CS_HIGH in SPI_IOC_RD_MODE (bsc#1012628).
- wifi: nl80211: Add checks for nla_nest_start() in
  nl80211_send_iface() (bsc#1012628).
- wifi: mac80211: fix memory leak in ieee80211_if_add()
  (bsc#1012628).
- wifi: mac80211: fix maybe-unused warning (bsc#1012628).
- wifi: cfg80211: Fix not unregister reg_pdev when
  load_builtin_regdb_keys() fails (bsc#1012628).
- wifi: mt76: mt7921: fix antenna signal are way off in monitor
  mode (bsc#1012628).
- wifi: mt76: mt7915: fix mt7915_mac_set_timing() (bsc#1012628).
- wifi: mt76: mt7915: fix reporting of TX AGGR histogram
  (bsc#1012628).
- wifi: mt76: mt7921: fix reporting of TX AGGR histogram
  (bsc#1012628).
- wifi: mt76: mt7915: rework eeprom tx paths and streams init
  (bsc#1012628).
- wifi: mt76: mt7915: Fix chainmask calculation on mt7915 DBDC
  (bsc#1012628).
- wifi: mt76: mt7921: fix wrong power after multiple SAR set
  (bsc#1012628).
- wifi: mt76: fix coverity overrun-call in mt76_get_txpower()
  (bsc#1012628).
- wifi: mt76: mt7921: Add missing __packed annotation of struct
  mt7921_clc (bsc#1012628).
- wifi: mt76: do not send firmware FW_FEATURE_NON_DL region
  (bsc#1012628).
- mt76: mt7915: Fix PCI device refcount leak in
  mt7915_pci_init_hif2() (bsc#1012628).
- regulator: core: fix module refcount leak in set_supply()
  (bsc#1012628).
- clk: qcom: lpass-sc7280: Fix pm_runtime usage (bsc#1012628).
- clk: qcom: lpass-sc7180: Fix pm_runtime usage (bsc#1012628).
- clk: qcom: clk-krait: fix wrong div2 functions (bsc#1012628).
- Revert "net: hsr: use hlist_head instead of list_head for mac
  addresses" (bsc#1012628).
- hsr: Add a rcu-read lock to hsr_forward_skb() (bsc#1012628).
- hsr: Avoid double remove of a node (bsc#1012628).
- hsr: Disable netpoll (bsc#1012628).
- hsr: Synchronize sending frames to have always incremented
  outgoing seq nr (bsc#1012628).
- hsr: Synchronize sequence number updates (bsc#1012628).
- configfs: fix possible memory leak in configfs_create_dir()
  (bsc#1012628).
- regulator: core: fix resource leak in regulator_register()
  (bsc#1012628).
- hwmon: (jc42) Convert register access and caching to
  regmap/regcache (bsc#1012628).
- hwmon: (jc42) Restore the min/max/critical temperatures on
  resume (bsc#1012628).
- bpf: Add dummy type reference to nf_conn___init to fix type
  deduplication (bsc#1012628).
- bpf, sockmap: fix race in sock_map_free() (bsc#1012628).
- ALSA: pcm: Set missing stop_operating flag at undoing trigger
  start (bsc#1012628).
- media: saa7164: fix missing pci_disable_device() (bsc#1012628).
- media: ov5640: set correct default link frequency (bsc#1012628).
- ALSA: mts64: fix possible null-ptr-defer in snd_mts64_interrupt
  (bsc#1012628).
- pinctrl: thunderbay: fix possible memory leak in
  thunderbay_build_functions() (bsc#1012628).
- xprtrdma: Fix regbuf data not freed in rpcrdma_req_create()
  (bsc#1012628).
- SUNRPC: Fix missing release socket in rpc_sockname()
  (bsc#1012628).
- NFSv4.2: Set the correct size scratch buffer for decoding
  READ_PLUS (bsc#1012628).
- NFS: Allow very small rsize & wsize again (bsc#1012628).
- NFSv4.x: Fail client initialisation if state manager thread
  can't run (bsc#1012628).
- riscv, bpf: Emit fixed-length instructions for BPF_PSEUDO_FUNC
  (bsc#1012628).
- bpftool: Fix memory leak in do_build_table_cb (bsc#1012628).
- hwmon: (emc2305) fix unable to probe emc2301/2/3 (bsc#1012628).
- hwmon: (emc2305) fix pwm never being able to set lower
  (bsc#1012628).
- mmc: alcor: fix return value check of mmc_add_host()
  (bsc#1012628).
- mmc: moxart: fix return value check of mmc_add_host()
  (bsc#1012628).
- mmc: mxcmmc: fix return value check of mmc_add_host()
  (bsc#1012628).
- mmc: pxamci: fix return value check of mmc_add_host()
  (bsc#1012628).
- mmc: rtsx_pci: fix return value check of mmc_add_host()
  (bsc#1012628).
- mmc: rtsx_usb_sdmmc: fix return value check of mmc_add_host()
  (bsc#1012628).
- mmc: toshsd: fix return value check of mmc_add_host()
  (bsc#1012628).
- mmc: vub300: fix return value check of mmc_add_host()
  (bsc#1012628).
- mmc: wmt-sdmmc: fix return value check of mmc_add_host()
  (bsc#1012628).
- mmc: litex_mmc: ensure `host->irq == 0` if polling
  (bsc#1012628).
- mmc: atmel-mci: fix return value check of mmc_add_host()
  (bsc#1012628).
- mmc: omap_hsmmc: fix return value check of mmc_add_host()
  (bsc#1012628).
- mmc: meson-gx: fix return value check of mmc_add_host()
  (bsc#1012628).
- mmc: via-sdmmc: fix return value check of mmc_add_host()
  (bsc#1012628).
- mmc: wbsd: fix return value check of mmc_add_host()
  (bsc#1012628).
- mmc: mmci: fix return value check of mmc_add_host()
  (bsc#1012628).
- mmc: renesas_sdhi: alway populate SCC pointer (bsc#1012628).
- memstick/ms_block: Add check for alloc_ordered_workqueue
  (bsc#1012628).
- mmc: core: Normalize the error handling branch in
  sd_read_ext_regs() (bsc#1012628).
- nvme: pass nr_maps explicitly to nvme_alloc_io_tag_set
  (bsc#1012628).
- regulator: qcom-labibb: Fix missing of_node_put() in
  qcom_labibb_regulator_probe() (bsc#1012628).
- media: c8sectpfe: Add of_node_put() when breaking out of loop
  (bsc#1012628).
- media: coda: Add check for dcoda_iram_alloc (bsc#1012628).
- media: coda: Add check for kmalloc (bsc#1012628).
- media: staging: stkwebcam: Restore MEDIA_{USB,CAMERA}_SUPPORT
  dependencies (bsc#1012628).
- clk: samsung: Fix memory leak in _samsung_clk_register_pll()
  (bsc#1012628).
- spi: spi-gpio: Don't set MOSI as an input if not 3WIRE mode
  (bsc#1012628).
- wifi: rtl8xxxu: Add __packed to struct rtl8723bu_c2h
  (bsc#1012628).
- wifi: rtl8xxxu: Fix the channel width reporting (bsc#1012628).
- wifi: brcmfmac: Fix error return code in
  brcmf_sdio_download_firmware() (bsc#1012628).
- blktrace: Fix output non-blktrace event when blk_classic option
  enabled (bsc#1012628).
- bpf: Do not zero-extend kfunc return values (bsc#1012628).
- clk: socfpga: Fix memory leak in socfpga_gate_init()
  (bsc#1012628).
- net: vmw_vsock: vmci: Check memcpy_from_msg() (bsc#1012628).
- net: defxx: Fix missing err handling in dfx_init()
  (bsc#1012628).
- net: stmmac: selftests: fix potential memleak in
  stmmac_test_arpoffload() (bsc#1012628).
- net: stmmac: fix possible memory leak in stmmac_dvr_probe()
  (bsc#1012628).
- drivers: net: qlcnic: Fix potential memory leak in
  qlcnic_sriov_init() (bsc#1012628).
- ipvs: use u64_stats_t for the per-cpu counters (bsc#1012628).
- of: overlay: fix null pointer dereferencing in
  find_dup_cset_node_entry() and find_dup_cset_prop()
  (bsc#1012628).
- ethernet: s2io: don't call dev_kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- net: farsync: Fix kmemleak when rmmods farsync (bsc#1012628).
- net/tunnel: wait until all sk_user_data reader finish before
  releasing the sock (bsc#1012628).
- net: apple: mace: don't call dev_kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- net: apple: bmac: don't call dev_kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- net: emaclite: don't call dev_kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- net: ethernet: dnet: don't call dev_kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- hamradio: don't call dev_kfree_skb() under spin_lock_irqsave()
  (bsc#1012628).
- net: amd: lance: don't call dev_kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- net: setsockopt: fix IPV6_UNICAST_IF option for connected
  sockets (bsc#1012628).
- af_unix: call proto_unregister() in the error path in
  af_unix_init() (bsc#1012628).
- net: amd-xgbe: Fix logic around active and passive cables
  (bsc#1012628).
- net: amd-xgbe: Check only the minimum speed for active/passive
  cables (bsc#1012628).
- can: tcan4x5x: Remove invalid write in clear_interrupts
  (bsc#1012628).
- can: m_can: Call the RAM init directly from m_can_chip_config
  (bsc#1012628).
- can: tcan4x5x: Fix use of register error status mask
  (bsc#1012628).
- net: ethernet: ti: am65-cpsw: Fix PM runtime leakage in
  am65_cpsw_nuss_ndo_slave_open() (bsc#1012628).
- net: lan9303: Fix read error execution path (bsc#1012628).
- ntb_netdev: Use dev_kfree_skb_any() in interrupt context
  (bsc#1012628).
- sctp: sysctl: make extra pointers netns aware (bsc#1012628).
- Bluetooth: hci_core: fix error handling in hci_register_dev()
  (bsc#1012628).
- Bluetooth: MGMT: Fix error report for ADD_EXT_ADV_PARAMS
  (bsc#1012628).
- Bluetooth: Fix EALREADY and ELOOP cases in bt_status()
  (bsc#1012628).
- Bluetooth: hci_conn: Fix crash on hci_create_cis_sync
  (bsc#1012628).
- Bluetooth: btintel: Fix missing free skb in
  btintel_setup_combined() (bsc#1012628).
- Bluetooth: btusb: don't call kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- Bluetooth: hci_qca: don't call kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- Bluetooth: hci_ll: don't call kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- Bluetooth: hci_h5: don't call kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- Bluetooth: hci_bcsp: don't call kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- Bluetooth: hci_core: don't call kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- Bluetooth: RFCOMM: don't call kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- octeontx2-af: cn10k: mcs: Fix a resource leak in the probe
  and remove functions (bsc#1012628).
- stmmac: fix potential division by 0 (bsc#1012628).
- i40e: Fix the inability to attach XDP program on downed
  interface (bsc#1012628).
- net: dsa: tag_8021q: avoid leaking ctx on
  dsa_tag_8021q_register() error path (bsc#1012628).
- apparmor: fix a memleak in multi_transaction_new()
  (bsc#1012628).
- apparmor: fix lockdep warning when removing a namespace
  (bsc#1012628).
- apparmor: Fix abi check to include v8 abi (bsc#1012628).
- apparmor: Fix regression in stacking due to label flags
  (bsc#1012628).
- crypto: hisilicon/qm - fix incorrect parameters usage
  (bsc#1012628).
- crypto: hisilicon/qm - re-enable communicate interrupt before
  notifying PF (bsc#1012628).
- crypto: sun8i-ss - use dma_addr instead u32 (bsc#1012628).
- crypto: nitrox - avoid double free on error path in
  nitrox_sriov_init() (bsc#1012628).
- crypto: tcrypt - fix return value for multiple subtests
  (bsc#1012628).
- scsi: core: Fix a race between scsi_done() and scsi_timeout()
  (bsc#1012628).
- apparmor: Use pointer to struct aa_label for lbs_cred
  (bsc#1012628).
- PCI: dwc: Fix n_fts[] array overrun (bsc#1012628).
- RDMA/core: Fix order of nldev_exit call (bsc#1012628).
- PCI: pci-epf-test: Register notifier if only core_init_notifier
  is enabled (bsc#1012628).
- f2fs: Fix the race condition of resize flag between resizefs
  (bsc#1012628).
- crypto: rockchip - do not do custom power management
  (bsc#1012628).
- crypto: rockchip - do not store mode globally (bsc#1012628).
- crypto: rockchip - add fallback for cipher (bsc#1012628).
- crypto: rockchip - add fallback for ahash (bsc#1012628).
- crypto: rockchip - better handle cipher key (bsc#1012628).
- crypto: rockchip - remove non-aligned handling (bsc#1012628).
- crypto: rockchip - rework by using crypto_engine (bsc#1012628).
- apparmor: Fix memleak in alloc_ns() (bsc#1012628).
- fortify: Do not cast to "unsigned char" (bsc#1012628).
- f2fs: fix to invalidate dcc->f2fs_issue_discard in error path
  (bsc#1012628).
- f2fs: fix gc mode when gc_urgent_high_remaining is 1
  (bsc#1012628).
- f2fs: fix normal discard process (bsc#1012628).
- f2fs: allow to set compression for inlined file (bsc#1012628).
- f2fs: fix the assign logic of iocb (bsc#1012628).
- f2fs: fix to destroy sbi->post_read_wq in error path of
  f2fs_fill_super() (bsc#1012628).
- RDMA/irdma: Report the correct link speed (bsc#1012628).
- scsi: qla2xxx: Fix set-but-not-used variable warnings
  (bsc#1012628).
- RDMA/siw: Fix immediate work request flush to completion queue
  (bsc#1012628).
- IB/mad: Don't call to function that might sleep while in atomic
  context (bsc#1012628).
- PCI: vmd: Disable MSI remapping after suspend (bsc#1012628).
- PCI: imx6: Initialize PHY before deasserting core reset
  (bsc#1012628).
- f2fs: fix to avoid accessing uninitialized spinlock
  (bsc#1012628).
- RDMA/restrack: Release MR restrack when delete (bsc#1012628).
- RDMA/core: Make sure "ib_port" is valid when access sysfs node
  (bsc#1012628).
- RDMA/nldev: Return "-EAGAIN" if the cm_id isn't from expected
  port (bsc#1012628).
- RDMA/siw: Set defined status for work completion with undefined
  status (bsc#1012628).
- RDMA/irdma: Fix inline for multiple SGE's (bsc#1012628).
- RDMA/irdma: Fix RQ completion opcode (bsc#1012628).
- RDMA/irdma: Do not request 2-level PBLEs for CQ alloc
  (bsc#1012628).
- scsi: scsi_debug: Fix a warning in resp_write_scat()
  (bsc#1012628).
- crypto: ccree - Remove debugfs when platform_driver_register
  failed (bsc#1012628).
- crypto: cryptd - Use request context instead of stack for
  sub-request (bsc#1012628).
- crypto: hisilicon/qm - add missing pci_dev_put() in q_num_set()
  (bsc#1012628).
- RDMA/rxe: Fix mr->map double free (bsc#1012628).
- RDMA/hns: Fix ext_sge num error when post send (bsc#1012628).
- RDMA/hns: Fix incorrect sge nums calculation (bsc#1012628).
- PCI: Check for alloc failure in pci_request_irq() (bsc#1012628).
- RDMA/hfi: Decrease PCI device reference count in error path
  (bsc#1012628).
- crypto: ccree - Make cc_debugfs_global_fini() available for
  module init function (bsc#1012628).
- RDMA/irdma: Initialize net_type before checking it
  (bsc#1012628).
- RDMA/hns: fix memory leak in hns_roce_alloc_mr() (bsc#1012628).
- RDMA/rxe: Fix NULL-ptr-deref in rxe_qp_do_cleanup() when socket
  create failed (bsc#1012628).
- dt-bindings: imx6q-pcie: Fix clock names for imx6sx and imx8mq
  (bsc#1012628).
- dt-bindings: visconti-pcie: Fix interrupts array max constraints
  (bsc#1012628).
- PCI: endpoint: pci-epf-vntb: Fix call pci_epc_mem_free_addr()
  in error path (bsc#1012628).
- scsi: hpsa: Fix possible memory leak in hpsa_init_one()
  (bsc#1012628).
- crypto: tcrypt - Fix multibuffer skcipher speed test mem leak
  (bsc#1012628).
- padata: Always leave BHs disabled when running ->parallel()
  (bsc#1012628).
- padata: Fix list iterator in padata_do_serial() (bsc#1012628).
- crypto: x86/aegis128 - fix possible crash with CFI enabled
  (bsc#1012628).
- crypto: x86/aria - fix crash with CFI enabled (bsc#1012628).
- crypto: x86/sha1 - fix possible crash with CFI enabled
  (bsc#1012628).
- crypto: x86/sha256 - fix possible crash with CFI enabled
  (bsc#1012628).
- crypto: x86/sha512 - fix possible crash with CFI enabled
  (bsc#1012628).
- crypto: x86/sm3 - fix possible crash with CFI enabled
  (bsc#1012628).
- crypto: x86/sm4 - fix crash with CFI enabled (bsc#1012628).
- crypto: arm64/sm3 - add NEON assembly implementation
  (bsc#1012628).
- crypto: arm64/sm3 - fix possible crash with CFI enabled
  (bsc#1012628).
- crypto: hisilicon/qm - fix 'QM_XEQ_DEPTH_CAP' mask value
  (bsc#1012628).
- scsi: mpt3sas: Fix possible resource leaks in
  mpt3sas_transport_port_add() (bsc#1012628).
- scsi: hpsa: Fix error handling in hpsa_add_sas_host()
  (bsc#1012628).
- scsi: hpsa: Fix possible memory leak in hpsa_add_sas_device()
  (bsc#1012628).
- scsi: efct: Fix possible memleak in efct_device_init()
  (bsc#1012628).
- scsi: scsi_debug: Fix a warning in resp_verify() (bsc#1012628).
- scsi: scsi_debug: Fix a warning in resp_report_zones()
  (bsc#1012628).
- scsi: fcoe: Fix possible name leak when device_register()
  fails (bsc#1012628).
- scsi: scsi_debug: Fix possible name leak in
  sdebug_add_host_helper() (bsc#1012628).
- scsi: ipr: Fix WARNING in ipr_init() (bsc#1012628).
- scsi: fcoe: Fix transport not deattached when fcoe_if_init()
  fails (bsc#1012628).
- scsi: snic: Fix possible UAF in snic_tgt_create() (bsc#1012628).
- scsi: ufs: core: Fix the polling implementation (bsc#1012628).
- RDMA/nldev: Add checks for nla_nest_start() in
  fill_stat_counter_qps() (bsc#1012628).
- f2fs: set zstd compress level correctly (bsc#1012628).
- f2fs: fix to enable compress for newly created file if extension
  matches (bsc#1012628).
- f2fs: avoid victim selection from previous victim section
  (bsc#1012628).
- RDMA/nldev: Fix failure to send large messages (bsc#1012628).
- crypto: qat - fix error return code in adf_probe (bsc#1012628).
- crypto: amlogic - Remove kcalloc without check (bsc#1012628).
- crypto: omap-sham - Use pm_runtime_resume_and_get() in
  omap_sham_probe() (bsc#1012628).
- riscv/mm: add arch hook arch_clear_hugepage_flags (bsc#1012628).
- RDMA: Disable IB HW for UML (bsc#1012628).
- RDMA/hfi1: Fix error return code in parse_platform_config()
  (bsc#1012628).
- RDMA/srp: Fix error return code in srp_parse_options()
  (bsc#1012628).
- PCI: vmd: Fix secondary bus reset for Intel bridges
  (bsc#1012628).
- orangefs: Fix sysfs not cleanup when dev init failed
  (bsc#1012628).
- RDMA/hns: Fix the gid problem caused by free mr (bsc#1012628).
- RDMA/hns: Fix AH attr queried by query_qp (bsc#1012628).
- RDMA/hns: Fix PBL page MTR find (bsc#1012628).
- RDMA/hns: Fix page size cap from firmware (bsc#1012628).
- RDMA/hns: Fix error code of CMD (bsc#1012628).
- RDMA/hns: Fix XRC caps on HIP08 (bsc#1012628).
- RISC-V: Fix unannoted hardirqs-on in return to userspace
  slow-path (bsc#1012628).
- RISC-V: Fix MEMREMAP_WB for systems with Svpbmt (bsc#1012628).
- riscv: Fix crash during early errata patching (bsc#1012628).
- crypto: img-hash - Fix variable dereferenced before check
  'hdev->req' (bsc#1012628).
- hwrng: amd - Fix PCI device refcount leak (bsc#1012628).
- hwrng: geode - Fix PCI device refcount leak (bsc#1012628).
- IB/IPoIB: Fix queue count inconsistency for PKEY child
  interfaces (bsc#1012628).
- RISC-V: Align the shadow stack (bsc#1012628).
- f2fs: fix iostat parameter for discard (bsc#1012628).
- riscv: Fix P4D_SHIFT definition for 3-level page table mode
  (bsc#1012628).
- drivers: dio: fix possible memory leak in dio_init()
  (bsc#1012628).
- serial: tegra: Read DMA status before terminating (bsc#1012628).
- serial: 8250_bcm7271: Fix error handling in brcmuart_init()
  (bsc#1012628).
- drivers: staging: r8188eu: Fix sleep-in-atomic-context bug in
  rtw_join_timeout_handler (bsc#1012628).
- class: fix possible memory leak in __class_register()
  (bsc#1012628).
- vfio: platform: Do not pass return buffer to ACPI _RST method
  (bsc#1012628).
- vfio/iova_bitmap: Fix PAGE_SIZE unaligned bitmaps (bsc#1012628).
- uio: uio_dmem_genirq: Fix missing unlock in irq configuration
  (bsc#1012628).
- uio: uio_dmem_genirq: Fix deadlock between irq config and
  handling (bsc#1012628).
- usb: fotg210-udc: Fix ages old endianness issues (bsc#1012628).
- interconnect: qcom: sc7180: fix dropped const of qcom_icc_bcm
  (bsc#1012628).
- staging: vme_user: Fix possible UAF in tsi148_dma_list_add
  (bsc#1012628).
- usb: typec: Check for ops->exit instead of ops->enter in
  altmode_exit (bsc#1012628).
- usb: typec: tcpci: fix of node refcount leak in
  tcpci_register_port() (bsc#1012628).
- usb: typec: tipd: Cleanup resources if devm_tps6598_psy_register
  fails (bsc#1012628).
- usb: typec: tipd: Fix spurious fwnode_handle_put in error path
  (bsc#1012628).
- usb: typec: tipd: Fix typec_unregister_port error paths
  (bsc#1012628).
- usb: musb: omap2430: Fix probe regression for missing resources
  (bsc#1012628).
- extcon: usbc-tusb320: Update state on probe even if no IRQ
  pending (bsc#1012628).
- USB: gadget: Fix use-after-free during usb config switch
  (bsc#1012628).
- serial: amba-pl011: avoid SBSA UART accessing DMACR register
  (bsc#1012628).
- serial: pl011: Do not clear RX FIFO & RX interrupt in unthrottle
  (bsc#1012628).
- serial: stm32: move dma_request_chan() before
  clk_prepare_enable() (bsc#1012628).
- serial: pch: Fix PCI device refcount leak in pch_request_dma()
  (bsc#1012628).
- serial: altera_uart: fix locking in polling mode (bsc#1012628).
- serial: sunsab: Fix error handling in sunsab_init()
  (bsc#1012628).
- habanalabs: fix return value check in
  hl_fw_get_sec_attest_data() (bsc#1012628).
- test_firmware: fix memory leak in test_firmware_init()
  (bsc#1012628).
- misc: ocxl: fix possible name leak in ocxl_file_register_afu()
  (bsc#1012628).
- ocxl: fix pci device refcount leak when calling get_function_0()
  (bsc#1012628).
- misc: tifm: fix possible memory leak in tifm_7xx1_switch_media()
  (bsc#1012628).
- firmware: raspberrypi: fix possible memory leak in
  rpi_firmware_probe() (bsc#1012628).
- cxl: fix possible null-ptr-deref in cxl_guest_init_afu|adapter()
  (bsc#1012628).
- cxl: fix possible null-ptr-deref in cxl_pci_init_afu|adapter()
  (bsc#1012628).
- iio: temperature: ltc2983: make bulk write buffer DMA-safe
  (bsc#1012628).
- iio: adis: add '__adis_enable_irq()' implementation
  (bsc#1012628).
- counter: stm32-lptimer-cnt: fix the check on arr and cmp
  registers update (bsc#1012628).
- coresight: trbe: remove cpuhp instance node before remove
  cpuhp state (bsc#1012628).
- coresight: cti: Fix null pointer error on CTI init before ETM
  (bsc#1012628).
- tracing/user_events: Fix call print_fmt leak (bsc#1012628).
- usb: roles: fix of node refcount leak in
  usb_role_switch_is_parent() (bsc#1012628).
- usb: core: hcd: Fix return value check in
  usb_hcd_setup_local_mem() (bsc#1012628).
- usb: gadget: f_hid: fix f_hidg lifetime vs cdev (bsc#1012628).
- usb: gadget: f_hid: fix refcount leak on error path
  (bsc#1012628).
- drivers: mcb: fix resource leak in mcb_probe() (bsc#1012628).
- mcb: mcb-parse: fix error handing in chameleon_parse_gdd()
  (bsc#1012628).
- chardev: fix error handling in cdev_device_add() (bsc#1012628).
- vfio/iova_bitmap: refactor iova_bitmap_set() to better handle
  page boundaries (bsc#1012628).
- i2c: pxa-pci: fix missing pci_disable_device() on error in
  ce4100_i2c_probe (bsc#1012628).
- staging: rtl8192u: Fix use after free in ieee80211_rx()
  (bsc#1012628).
- staging: rtl8192e: Fix potential use-after-free in
  rtllib_rx_Monitor() (bsc#1012628).
- vme: Fix error not catched in fake_init() (bsc#1012628).
- gpiolib: cdev: fix NULL-pointer dereferences (bsc#1012628).
- gpiolib: protect the GPIO device against being dropped while
  in use by user-space (bsc#1012628).
- i2c: mux: reg: check return value after calling
  platform_get_resource() (bsc#1012628).
- i2c: ismt: Fix an out-of-bounds bug in ismt_access()
  (bsc#1012628).
- usb: storage: Add check for kcalloc (bsc#1012628).
- usb: typec: wusb3801: fix fwnode refcount leak in
  wusb3801_probe() (bsc#1012628).
- tracing/hist: Fix issue of losting command info in error_log
  (bsc#1012628).
- ksmbd: Fix resource leak in ksmbd_session_rpc_open()
  (bsc#1012628).
- samples: vfio-mdev: Fix missing pci_disable_device() in
  mdpy_fb_probe() (bsc#1012628).
- thermal/drivers/imx8mm_thermal: Validate temperature range
  (bsc#1012628).
- thermal/drivers/k3_j72xx_bandgap: Fix the debug print message
  (bsc#1012628).
- thermal/of: Fix memory leak on thermal_of_zone_register()
  failure (bsc#1012628).
- thermal/drivers/qcom/temp-alarm: Fix inaccurate warning for gen2
  (bsc#1012628).
- thermal/drivers/qcom/lmh: Fix irq handler return value
  (bsc#1012628).
- fbdev: ssd1307fb: Drop optional dependency (bsc#1012628).
- fbdev: pm2fb: fix missing pci_disable_device() (bsc#1012628).
- fbdev: via: Fix error in via_core_init() (bsc#1012628).
- fbdev: vermilion: decrease reference count in error path
  (bsc#1012628).
- fbdev: ep93xx-fb: Add missing clk_disable_unprepare in
  ep93xxfb_probe() (bsc#1012628).
- fbdev: geode: don't build on UML (bsc#1012628).
- fbdev: uvesafb: don't build on UML (bsc#1012628).
- fbdev: uvesafb: Fixes an error handling path in uvesafb_probe()
  (bsc#1012628).
- led: qcom-lpg: Fix sleeping in atomic (bsc#1012628).
- perf tools: Fix "kernel lock contention analysis" test by not
  printing warnings in quiet mode (bsc#1012628).
- perf stat: Use evsel__is_hybrid() more (bsc#1012628).
- perf stat: Move common code in print_metric_headers()
  (bsc#1012628).
- HSI: omap_ssi_core: fix unbalanced pm_runtime_disable()
  (bsc#1012628).
- HSI: omap_ssi_core: fix possible memory leak in ssi_probe()
  (bsc#1012628).
- power: supply: fix residue sysfs file in error handle route
  of __power_supply_register() (bsc#1012628).
- watchdog: iTCO_wdt: Set NO_REBOOT if the watchdog is not
  already running (bsc#1012628).
- perf trace: Return error if a system call doesn't exist
  (bsc#1012628).
- perf trace: Use macro RAW_SYSCALL_ARGS_NUM to replace number
  (bsc#1012628).
- perf trace: Handle failure when trace point folder is missed
  (bsc#1012628).
- perf symbol: correction while adjusting symbol (bsc#1012628).
- power: supply: z2_battery: Fix possible memleak in
  z2_batt_probe() (bsc#1012628).
- power: supply: cw2015: Fix potential null-ptr-deref in
  cw_bat_probe() (bsc#1012628).
- HSI: omap_ssi_core: Fix error handling in ssi_init()
  (bsc#1012628).
- power: supply: ab8500: Fix error handling in
  ab8500_charger_init() (bsc#1012628).
- power: supply: Fix refcount leak in rk817_charger_probe
  (bsc#1012628).
- power: supply: bq25890: Factor out regulator registration code
  (bsc#1012628).
- power: supply: bq25890: Convert to i2c's .probe_new()
  (bsc#1012628).
- power: supply: bq25890: Ensure pump_express_work is cancelled
  on remove (bsc#1012628).
- perf branch: Fix interpretation of branch records (bsc#1012628).
- power: supply: fix null pointer dereferencing in
  power_supply_get_battery_info (bsc#1012628).
- gfs2: Partially revert gfs2_inode_lookup change (bsc#1012628).
- leds: is31fl319x: Fix setting current limit for is31fl319{0,1,3}
  (bsc#1012628).
- perf off_cpu: Fix a typo in BTF tracepoint name, it should be
  'btf_trace_sched_switch' (bsc#1012628).
- ftrace: Allow WITH_ARGS flavour of graph tracer with shadow
  call stack (bsc#1012628).
- perf stat: Do not delay the workload with --delay (bsc#1012628).
- RDMA/siw: Fix pointer cast warning (bsc#1012628).
- fs/ntfs3: Avoid UBSAN error on true_sectors_per_clst()
  (bsc#1012628).
- fs/ntfs3: Harden against integer overflows (bsc#1012628).
- phy: marvell: phy-mvebu-a3700-comphy: Reset COMPHY registers
  before USB 3.0 power on (bsc#1012628).
- phy: qcom-qmp-pcie: drop bogus register update (bsc#1012628).
- dmaengine: idxd: Make max batch size attributes in sysfs
  invisible for Intel IAA (bsc#1012628).
- dmaengine: apple-admac: Allocate cache SRAM to channels
  (bsc#1012628).
- remoteproc: core: Auto select rproc-virtio device id
  (bsc#1012628).
- phy: qcom-qmp-pcie: drop power-down delay config (bsc#1012628).
- phy: qcom-qmp-pcie: replace power-down delay (bsc#1012628).
- phy: qcom-qmp-pcie: fix sc8180x initialisation (bsc#1012628).
- phy: qcom-qmp-pcie: fix ipq8074-gen3 initialisation
  (bsc#1012628).
- phy: qcom-qmp-pcie: fix ipq6018 initialisation (bsc#1012628).
- phy: qcom-qmp-usb: clean up power-down handling (bsc#1012628).
- phy: qcom-qmp-usb: drop sc8280xp power-down delay (bsc#1012628).
- phy: qcom-qmp-usb: drop power-down delay config (bsc#1012628).
- phy: qcom-qmp-usb: clean up status polling (bsc#1012628).
- phy: qcom-qmp-usb: drop start and pwrdn-ctrl abstraction
  (bsc#1012628).
- phy: qcom-qmp-usb: correct registers layout for IPQ8074 USB3
  PHY (bsc#1012628).
- iommu/s390: Fix duplicate domain attachments (bsc#1012628).
- iommu/sun50i: Fix reset release (bsc#1012628).
- iommu/sun50i: Consider all fault sources for reset
  (bsc#1012628).
- iommu/sun50i: Fix R/W permission check (bsc#1012628).
- iommu/sun50i: Fix flush size (bsc#1012628).
- iommu/sun50i: Implement .iotlb_sync_map (bsc#1012628).
- iommu/rockchip: fix permission bits in page table entries v2
  (bsc#1012628).
- dmaengine: idxd: Make read buffer sysfs attributes invisible
  for Intel IAA (bsc#1012628).
- phy: qcom-qmp-usb: fix sc8280xp PCS_USB offset (bsc#1012628).
- phy: usb: s2 WoL wakeup_count not incremented for USB->Eth
  devices (bsc#1012628).
- phy: usb: Use slow clock for wake enabled suspend (bsc#1012628).
- phy: usb: Fix clock imbalance for suspend/resume (bsc#1012628).
- include/uapi/linux/swab: Fix potentially missing __always_inline
  (bsc#1012628).
- pwm: tegra: Improve required rate calculation (bsc#1012628).
- pwm: tegra: Ensure the clock rate is not less than needed
  (bsc#1012628).
- phy: qcom-qmp-pcie: split register tables into common and
  extra parts (bsc#1012628).
- phy: qcom-qmp-pcie: split pcs_misc init cfg for ipq8074 pcs
  table (bsc#1012628).
- phy: qcom-qmp-pcie: support separate tables for EP mode
  (bsc#1012628).
- phy: qcom-qmp-pcie: Support SM8450 PCIe1 PHY in EP mode
  (bsc#1012628).
- phy: qcom-qmp-pcie: Fix high latency with 4x2 PHY when ASPM
  is enabled (bsc#1012628).
- phy: qcom-qmp-pcie: Fix sm8450_qmp_gen4x2_pcie_pcs_tbl[]
  register names (bsc#1012628).
- fs/ntfs3: Fix slab-out-of-bounds read in ntfs_trim_fs
  (bsc#1012628).
- dmaengine: idxd: Fix crc_val field for completion record
  (bsc#1012628).
- rtc: rzn1: Check return value in rzn1_rtc_probe (bsc#1012628).
- rtc: class: Fix potential memleak in devm_rtc_allocate_device()
  (bsc#1012628).
- rtc: pcf2127: Convert to .probe_new() (bsc#1012628).
- rtc: cmos: Call cmos_wake_setup() from cmos_do_probe()
  (bsc#1012628).
- rtc: cmos: Call rtc_wake_setup() from cmos_do_probe()
  (bsc#1012628).
- rtc: cmos: Eliminate forward declarations of some functions
  (bsc#1012628).
- rtc: cmos: Rename ACPI-related functions (bsc#1012628).
- rtc: cmos: Disable ACPI RTC event on removal (bsc#1012628).
- rtc: snvs: Allow a time difference on clock register read
  (bsc#1012628).
- rtc: pcf85063: Fix reading alarm (bsc#1012628).
- iommu/mediatek: Check return value after calling
  platform_get_resource() (bsc#1012628).
- iommu: Avoid races around device probe (bsc#1012628).
- iommu/amd: Fix pci device refcount leak in ppr_notifier()
  (bsc#1012628).
- iommu/fsl_pamu: Fix resource leak in fsl_pamu_probe()
  (bsc#1012628).
- macintosh: fix possible memory leak in macio_add_one_device()
  (bsc#1012628).
- macintosh/macio-adb: check the return value of ioremap()
  (bsc#1012628).
- powerpc/52xx: Fix a resource leak in an error handling path
  (bsc#1012628).
- cxl: Fix refcount leak in cxl_calc_capp_routing (bsc#1012628).
- powerpc/xmon: Fix -Wswitch-unreachable warning in bpt_cmds
  (bsc#1012628).
- powerpc/xive: add missing iounmap() in error path in
  xive_spapr_populate_irq_data() (bsc#1012628).
- powerpc/pseries: fix the object owners enum value in plpks
  driver (bsc#1012628).
- powerpc/pseries: Fix the H_CALL error code in PLPKS driver
  (bsc#1012628).
- powerpc/pseries: Return -EIO instead of -EINTR for H_ABORTED
  error (bsc#1012628).
- powerpc/pseries: fix plpks_read_var() code for different
  consumers (bsc#1012628).
- kprobes: Fix check for probe enabled in kill_kprobe()
  (bsc#1012628).
- powerpc: dts: turris1x.dts: Add channel labels for temperature
  sensor (bsc#1012628).
- powerpc/perf: callchain validate kernel stack pointer bounds
  (bsc#1012628).
- powerpc/83xx/mpc832x_rdb: call platform_device_put() in error
  case in of_fsl_spi_probe() (bsc#1012628).
- powerpc/hv-gpci: Fix hv_gpci event list (bsc#1012628).
- selftests/powerpc: Fix resource leaks (bsc#1012628).
- iommu/mediatek: Add platform_device_put for recovering the
  device refcnt (bsc#1012628).
- iommu/mediatek: Use component_match_add (bsc#1012628).
- iommu/mediatek: Add error path for loop of mm_dts_parse
  (bsc#1012628).
- iommu/mediatek: Validate number of phandles associated with
  "mediatek,larbs" (bsc#1012628).
- iommu/sun50i: Remove IOMMU_DOMAIN_IDENTITY (bsc#1012628).
- pwm: sifive: Call pwm_sifive_update_clock() while mutex is held
  (bsc#1012628).
- pwm: mtk-disp: Fix the parameters calculated by the enabled
  flag of disp_pwm (bsc#1012628).
- pwm: mediatek: always use bus clock for PWM on MT7622
  (bsc#1012628).
- RISC-V: KVM: Fix reg_val check in
  kvm_riscv_vcpu_set_reg_config() (bsc#1012628).
- remoteproc: sysmon: fix memory leak in qcom_add_sysmon_subdev()
  (bsc#1012628).
- remoteproc: qcom: q6v5: Fix potential null-ptr-deref in
  q6v5_wcss_init_mmio() (bsc#1012628).
- remoteproc: qcom_q6v5_pas: disable wakeup on probe fail or
  remove (bsc#1012628).
- remoteproc: qcom_q6v5_pas: detach power domains on remove
  (bsc#1012628).
- remoteproc: qcom_q6v5_pas: Fix missing of_node_put() in
  adsp_alloc_memory_region() (bsc#1012628).
- remoteproc: qcom: q6v5: Fix missing clk_disable_unprepare()
  in q6v5_wcss_qcs404_power_on() (bsc#1012628).
- powerpc/pseries/eeh: use correct API for error log size
  (bsc#1012628).
- dt-bindings: mfd: qcom,spmi-pmic: Drop PWM reg dependency
  (bsc#1012628).
- mfd: axp20x: Do not sleep in the power off handler
  (bsc#1012628).
- mfd: bd957x: Fix Kconfig dependency on REGMAP_IRQ (bsc#1012628).
- mfd: qcom_rpm: Fix an error handling path in qcom_rpm_probe()
  (bsc#1012628).
- mfd: pm8008: Fix return value check in pm8008_probe()
  (bsc#1012628).
- netfilter: flowtable: really fix NAT IPv6 offload (bsc#1012628).
- rtc: st-lpc: Add missing clk_disable_unprepare in st_rtc_probe()
  (bsc#1012628).
- rtc: pic32: Move devm_rtc_allocate_device earlier in
  pic32_rtc_probe() (bsc#1012628).
- rtc: pcf85063: fix pcf85063_clkout_control (bsc#1012628).
- iommu/mediatek: Fix forever loop in error handling
  (bsc#1012628).
- nfsd: under NFSv4.1, fix double svc_xprt_put on rpc_create
  failure (bsc#1012628).
- net: macsec: fix net device access prior to holding a lock
  (bsc#1012628).
- bonding: add missed __rcu annotation for curr_active_slave
  (bsc#1012628).
- bonding: do failover when high prio link up (bsc#1012628).
- mISDN: hfcsusb: don't call dev_kfree_skb/kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- mISDN: hfcpci: don't call dev_kfree_skb/kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- mISDN: hfcmulti: don't call dev_kfree_skb/kfree_skb() under
  spin_lock_irqsave() (bsc#1012628).
- block, bfq: fix possible uaf for 'bfqq->bic' (bsc#1012628).
- selftests/bpf: Select CONFIG_FUNCTION_ERROR_INJECTION
  (bsc#1012628).
- bpf: prevent leak of lsm program after failed attach
  (bsc#1012628).
- media: v4l2-ctrls-api.c: add back dropped ctrl->is_new = 1
  (bsc#1012628).
- net: enetc: avoid buffer leaks on xdp_do_redirect() failure
  (bsc#1012628).
- nfc: pn533: Clear nfc_target before being used (bsc#1012628).
- unix: Fix race in SOCK_SEQPACKET's unix_dgram_sendmsg()
  (bsc#1012628).
- r6040: Fix kmemleak in probe and remove (bsc#1012628).
- net: dsa: mv88e6xxx: avoid reg_lock deadlock in
  mv88e6xxx_setup_port() (bsc#1012628).
- igc: Enhance Qbv scheduling by using first flag bit
  (bsc#1012628).
- igc: Use strict cycles for Qbv scheduling (bsc#1012628).
- igc: Add checking for basetime less than zero (bsc#1012628).
- igc: allow BaseTime 0 enrollment for Qbv (bsc#1012628).
- igc: recalculate Qbv end_time by considering cycle time
  (bsc#1012628).
- igc: Set Qbv start_time and end_time to end_time if not being
  configured in GCL (bsc#1012628).
- rtc: mxc_v2: Add missing clk_disable_unprepare() (bsc#1012628).
- devlink: hold region lock when flushing snapshots (bsc#1012628).
- selftests: devlink: fix the fd redirect in dummy_reporter_test
  (bsc#1012628).
- openvswitch: Fix flow lookup to use unmasked key (bsc#1012628).
- soc: mediatek: pm-domains: Fix the power glitch issue
  (bsc#1012628).
- arm64: dts: mt8183: Fix Mali GPU clock (bsc#1012628).
- devlink: protect devlink dump by the instance lock
  (bsc#1012628).
- skbuff: Account for tail adjustment during pull operations
  (bsc#1012628).
- mailbox: mpfs: read the system controller's status
  (bsc#1012628).
- mailbox: arm_mhuv2: Fix return value check in mhuv2_probe()
  (bsc#1012628).
- mailbox: zynq-ipi: fix error handling while device_register()
  fails (bsc#1012628).
- net_sched: reject TCF_EM_SIMPLE case for complex ematch module
  (bsc#1012628).
- rxrpc: Fix missing unlock in rxrpc_do_sendmsg() (bsc#1012628).
- myri10ge: Fix an error handling path in myri10ge_probe()
  (bsc#1012628).
- net: stream: purge sk_error_queue in sk_stream_kill_queues()
  (bsc#1012628).
- mctp: serial: Fix starting value for frame check sequence
  (bsc#1012628).
- cifs: don't leak -ENOMEM in smb2_open_file() (bsc#1012628).
- net: dsa: microchip: remove IRQF_TRIGGER_FALLING in
  request_threaded_irq (bsc#1012628).
- mctp: Remove device type check at unregister (bsc#1012628).
- HID: amd_sfh: Add missing check for dma_alloc_coherent
  (bsc#1012628).
- net: fec: check the return value of build_skb() (bsc#1012628).
- rcu: Fix __this_cpu_read() lockdep warning in
  rcu_force_quiescent_state() (bsc#1012628).
- arm64: make is_ttbrX_addr() noinstr-safe (bsc#1012628).
- ARM: dts: aspeed: rainier,everest: Move reserved memory regions
  (bsc#1012628).
- video: hyperv_fb: Avoid taking busy spinlock on panic path
  (bsc#1012628).
- x86/hyperv: Remove unregister syscore call from Hyper-V cleanup
  (bsc#1012628).
- binfmt_misc: fix shift-out-of-bounds in check_special_flags
  (bsc#1012628).
- arm64: dts: qcom: sm8450: disable SDHCI SDR104/SDR50 on all
  boards (bsc#1012628).
- arm64: dts: qcom: sm6350: Add apps_smmu with streamID to SDHCI
  1/2 nodes (bsc#1012628).
- fs: jfs: fix shift-out-of-bounds in dbAllocAG (bsc#1012628).
- udf: Avoid double brelse() in udf_rename() (bsc#1012628).
- jfs: Fix fortify moan in symlink (bsc#1012628).
- fs: jfs: fix shift-out-of-bounds in dbDiscardAG (bsc#1012628).
- ACPI: processor: idle: Check acpi_fetch_acpi_dev() return value
  (bsc#1012628).
- ACPI: EC: Add quirk for the HP Pavilion Gaming 15-cx0041ur
  (bsc#1012628).
- ACPICA: Fix error code path in acpi_ds_call_control_method()
  (bsc#1012628).
- thermal/core: Ensure that thermal device is registered in
  thermal_zone_get_temp (bsc#1012628).
- ACPI: video: Change GIGABYTE GB-BXBT-2807 quirk to force_none
  (bsc#1012628).
- ACPI: video: Change Sony Vaio VPCEH3U1E quirk to force_native
  (bsc#1012628).
- ACPI: video: Add force_vendor quirk for Sony Vaio PCG-FRV35
  (bsc#1012628).
- ACPI: video: Add force_native quirk for Sony Vaio VPCY11S1E
  (bsc#1012628).
- nilfs2: fix shift-out-of-bounds/overflow in
  nilfs_sb2_bad_offset() (bsc#1012628).
- nilfs2: fix shift-out-of-bounds due to too large exponent of
  block size (bsc#1012628).
- acct: fix potential integer overflow in encode_comp_t()
  (bsc#1012628).
- x86/apic: Handle no CONFIG_X86_X2APIC on systems with x2APIC
  enabled by BIOS (bsc#1012628).
- ACPI: x86: Add skip i2c clients quirk for Lenovo Yoga Tab 3 Pro
  (YT3-X90F) (bsc#1012628).
- btrfs: do not panic if we can't allocate a prealloc extent state
  (bsc#1012628).
- ACPI: x86: Add skip i2c clients quirk for Medion Lifetab S10346
  (bsc#1012628).
- hfs: fix OOB Read in __hfs_brec_find (bsc#1012628).
- drm/etnaviv: add missing quirks for GC300 (bsc#1012628).
- media: imx-jpeg: Disable useless interrupt to avoid kernel panic
  (bsc#1012628).
- brcmfmac: return error when getting invalid max_flowrings from
  dongle (bsc#1012628).
- wifi: ath9k: verify the expected usb_endpoints are present
  (bsc#1012628).
- wifi: ar5523: Fix use-after-free on ar5523_cmd() timed out
  (bsc#1012628).
- ASoC: codecs: rt298: Add quirk for KBL-R RVP platform
  (bsc#1012628).
- ASoC: Intel: avs: Add quirk for KBL-R RVP platform
  (bsc#1012628).
- ipmi: fix memleak when unload ipmi driver (bsc#1012628).
- wifi: ath10k: Delay the unmapping of the buffer (bsc#1012628).
- openvswitch: Use kmalloc_size_roundup() to match ksize() usage
  (bsc#1012628).
- bnx2: Use kmalloc_size_roundup() to match ksize() usage
  (bsc#1012628).
- drm/amd/display: skip commit minimal transition state
  (bsc#1012628).
- drm/amd/display: prevent memory leak (bsc#1012628).
- drm/edid: add a quirk for two LG monitors to get them to work
  on 10bpc (bsc#1012628).
- Revert "drm/amd/display: Limit max DSC target bpp for specific
  monitors" (bsc#1012628).
- drm/rockchip: use pm_runtime_resume_and_get() instead of
  pm_runtime_get_sync() (bsc#1012628).
- blk-mq: avoid double ->queue_rq() because of early timeout
  (bsc#1012628).
- HID: apple: fix key translations where multiple quirks attempt
  to translate the same key (bsc#1012628).
- HID: apple: enable APPLE_ISO_TILDE_QUIRK for the keyboards of
  Macs with the T2 chip (bsc#1012628).
- wifi: ath11k: Fix qmi_msg_handler data structure initialization
  (bsc#1012628).
- qed (gcc13): use u16 for fid to be big enough (bsc#1012628).
- drm/meson: Fix return type of meson_encoder_cvbs_mode_valid()
  (bsc#1012628).
- bpf: make sure skb->len != 0 when redirecting to a tunneling
  device (bsc#1012628).
- net: ethernet: ti: Fix return type of netcp_ndo_start_xmit()
  (bsc#1012628).
- hamradio: baycom_epp: Fix return type of baycom_send_packet()
  (bsc#1012628).
- wifi: brcmfmac: Fix potential shift-out-of-bounds in
  brcmf_fw_alloc_request() (bsc#1012628).
- wifi: brcmfmac: Fix potential NULL pointer dereference in
  'brcmf_c_preinit_dcmds()' (bsc#1012628).
- HID: input: do not query XP-PEN Deco LW battery (bsc#1012628).
- HID: uclogic: Add support for XP-PEN Deco LW (bsc#1012628).
- igb: Do not free q_vector unless new one was allocated
  (bsc#1012628).
- drm/amdgpu: Fix type of second parameter in trans_msg() callback
  (bsc#1012628).
- drm/amdgpu: Fix type of second parameter in odn_edit_dpm_table()
  callback (bsc#1012628).
- s390/ctcm: Fix return type of ctc{mp,}m_tx() (bsc#1012628).
- s390/netiucv: Fix return type of netiucv_tx() (bsc#1012628).
- s390/lcs: Fix return type of lcs_start_xmit() (bsc#1012628).
- drm/amd/display: Use min transition for SubVP into MPO
  (bsc#1012628).
- drm/amd/display: Disable DRR actions during state commit
  (bsc#1012628).
- drm/msm: Use drm_mode_copy() (bsc#1012628).
- drm/rockchip: Use drm_mode_copy() (bsc#1012628).
- drm/sti: Use drm_mode_copy() (bsc#1012628).
- drm/mediatek: Fix return type of mtk_hdmi_bridge_mode_valid()
  (bsc#1012628).
- drivers/md/md-bitmap: check the return value of
  md_bitmap_get_counter() (bsc#1012628).
- md/raid0, raid10: Don't set discard sectors for request queue
  (bsc#1012628).
- md/raid1: stop mdx_raid1 thread when raid1 array run failed
  (bsc#1012628).
- drm/amd/display: Workaround to increase phantom pipe vactive
  in pipesplit (bsc#1012628).
- drm/amd/display: fix array index out of bound error in bios
  parser (bsc#1012628).
- nvme-auth: don't override ctrl keys before validation
  (bsc#1012628).
- net: add atomic_long_t to net_device_stats fields (bsc#1012628).
- ipv6/sit: use DEV_STATS_INC() to avoid data-races (bsc#1012628).
- mrp: introduce active flags to prevent UAF when applicant uninit
  (bsc#1012628).
- net: ethernet: mtk_eth_soc: drop packets to WDMA if the ring
  is full (bsc#1012628).
- bpf/verifier: Use kmalloc_size_roundup() to match ksize()
  usage (bsc#1012628).
- ppp: associate skb with a device at tx (bsc#1012628).
- drm/amd/display: Fix display corruption w/ VSR enable
  (bsc#1012628).
- bpf: Fix a BTF_ID_LIST bug with CONFIG_DEBUG_INFO_BTF not set
  (bsc#1012628).
- bpf: Prevent decl_tag from being referenced in func_proto arg
  (bsc#1012628).
- ethtool: avoiding integer overflow in ethtool_phys_id()
  (bsc#1012628).
- media: dvb-frontends: fix leak of memory fw (bsc#1012628).
- media: dvbdev: adopts refcnt to avoid UAF (bsc#1012628).
- media: dvb-usb: fix memory leak in dvb_usb_adapter_init()
  (bsc#1012628).
- media: mediatek: vcodec: Can't set dst buffer to done when
  lat decode error (bsc#1012628).
- blk-mq: fix possible memleak when register 'hctx' failed
  (bsc#1012628).
- ALSA: usb-audio: Add quirk for Tascam Model 12 (bsc#1012628).
- drm/amdgpu: Fix potential double free and null pointer
  dereference (bsc#1012628).
- drm/amd/display: Use the largest vready_offset in pipe group
  (bsc#1012628).
- drm/amd/display: Fix DTBCLK disable requests and SRC_SEL
  programming (bsc#1012628).
- ASoC: amd: yc: Add Xiaomi Redmi Book Pro 14 2022 into DMI table
  (bsc#1012628).
- libbpf: Avoid enum forward-declarations in public API in C++
  mode (bsc#1012628).
- regulator: core: fix use_count leakage when handling boot-on
  (bsc#1012628).
- wifi: mt76: do not run mt76u_status_worker if the device is
  not running (bsc#1012628).
- hwmon: (nct6775) add ASUS CROSSHAIR VIII/TUF/ProArt B550M
  (bsc#1012628).
- selftests/bpf: Fix conflicts with built-in functions in
  bpf_iter_ksym (bsc#1012628).
- nfs: fix possible null-ptr-deref when parsing param
  (bsc#1012628).
- mmc: f-sdh30: Add quirks for broken timeout clock capability
  (bsc#1012628).
- mmc: renesas_sdhi: add quirk for broken register layout
  (bsc#1012628).
- mmc: renesas_sdhi: better reset from HS400 mode (bsc#1012628).
- mmc: sdhci-tegra: Issue CMD and DAT resets together
  (bsc#1012628).
- media: si470x: Fix use-after-free in si470x_int_in_callback()
  (bsc#1012628).
- clk: st: Fix memory leak in st_of_quadfs_setup() (bsc#1012628).
- regulator: core: Use different devices for resource allocation
  and DT lookup (bsc#1012628).
- ice: synchronize the misc IRQ when tearing down Tx tracker
  (bsc#1012628).
- Bluetooth: hci_bcm: Add CYW4373A0 support (bsc#1012628).
- Bluetooth: Add quirk to disable extended scanning (bsc#1012628).
- Bluetooth: Add quirk to disable MWS Transport Configuration
  (bsc#1012628).
- regulator: core: Fix resolve supply lookup issue (bsc#1012628).
- crypto: hisilicon/hpre - fix resource leak in remove process
  (bsc#1012628).
- scsi: lpfc: Fix hard lockup when reading the rx_monitor from
  debugfs (bsc#1012628).
- scsi: ufs: Reduce the START STOP UNIT timeout (bsc#1012628).
- crypto: hisilicon/qm - increase the memory of local variables
  (bsc#1012628).
- Revert "PCI: Clear PCI_STATUS when setting up device"
  (bsc#1012628).
- scsi: elx: libefc: Fix second parameter type in state callbacks
  (bsc#1012628).
- hugetlbfs: fix null-ptr-deref in hugetlbfs_parse_param()
  (bsc#1012628).
- scsi: smartpqi: Add new controller PCI IDs (bsc#1012628).
- scsi: smartpqi: Correct device removal for multi-actuator
  devices (bsc#1012628).
- drm/fsl-dcu: Fix return type of
  fsl_dcu_drm_connector_mode_valid() (bsc#1012628).
- drm/sti: Fix return type of
  sti_{dvo,hda,hdmi}_connector_mode_valid() (bsc#1012628).
- scsi: target: iscsi: Fix a race condition between login_work
  and the login thread (bsc#1012628).
- orangefs: Fix kmemleak in orangefs_prepare_debugfs_help_string()
  (bsc#1012628).
- orangefs: Fix kmemleak in orangefs_sysfs_init() (bsc#1012628).
- orangefs: Fix kmemleak in orangefs_{kernel,client}_debug_init()
  (bsc#1012628).
- hwmon: (jc42) Fix missing unlock on error in jc42_write()
  (bsc#1012628).
- ASoC: sof_es8336: fix possible use-after-free in
  sof_es8336_remove() (bsc#1012628).
- ASoC: Intel: Skylake: Fix driver hang during shutdown
  (bsc#1012628).
- ASoC: mediatek: mt8173-rt5650-rt5514: fix refcount leak in
  mt8173_rt5650_rt5514_dev_probe() (bsc#1012628).
- ASoC: audio-graph-card: fix refcount leak of cpu_ep in
  __graph_for_each_link() (bsc#1012628).
- ASoC: rockchip: pdm: Add missing clk_disable_unprepare()
  in rockchip_pdm_runtime_resume() (bsc#1012628).
- ASoC: mediatek: mt8183: fix refcount leak in
  mt8183_mt6358_ts3a227_max98357_dev_probe() (bsc#1012628).
- ALSA: hda/hdmi: fix i915 silent stream programming flow
  (bsc#1012628).
- ALSA: hda/hdmi: set default audio parameters for KAE
  silent-stream (bsc#1012628).
- ALSA: hda/hdmi: fix stream-id config keep-alive for rt suspend
  (bsc#1012628).
- ASoC: wm8994: Fix potential deadlock (bsc#1012628).
- ASoC: rockchip: spdif: Add missing clk_disable_unprepare()
  in rk_spdif_runtime_resume() (bsc#1012628).
- ASoC: rt5670: Remove unbalanced pm_runtime_put() (bsc#1012628).
- drm/i915/display: Don't disable DDI/Transcoder when setting
  phy test pattern (bsc#1012628).
- LoadPin: Ignore the "contents" argument of the LSM hooks
  (bsc#1012628).
- lkdtm: cfi: Make PAC test work with GCC 7 and 8 (bsc#1012628).
- pstore: Switch pmsg_lock to an rt_mutex to avoid priority
  inversion (bsc#1012628).
- drm/amd/pm: avoid large variable on kernel stack (bsc#1012628).
- perf debug: Set debug_peo_args and redirect_to_stderr variable
  to correct values in perf_quiet_option() (bsc#1012628).
- perf tools: Make quiet mode consistent between tools
  (bsc#1012628).
- perf probe: Check -v and -q options in the right place
  (bsc#1012628).
- MIPS: ralink: mt7621: avoid to init common ralink reset
  controller (bsc#1012628).
- perf test: Fix "all PMU test" to skip parametrized events
  (bsc#1012628).
- afs: Fix lost servers_outstanding count (bsc#1012628).
- cfi: Fix CFI failure with KASAN (bsc#1012628).
- pstore: Make sure CONFIG_PSTORE_PMSG selects CONFIG_RT_MUTEXES
  (bsc#1012628).
- ima: Simplify ima_lsm_copy_rule (bsc#1012628).
- Input: iqs7222 - drop unused device node references
  (bsc#1012628).
- Input: iqs7222 - report malformed properties (bsc#1012628).
- Input: iqs7222 - add support for IQS7222A v1.13+ (bsc#1012628).
- dt-bindings: input: iqs7222: Reduce 'linux,code' to optional
  (bsc#1012628).
- dt-bindings: input: iqs7222: Correct minimum slider size
  (bsc#1012628).
- dt-bindings: input: iqs7222: Add support for IQS7222A v1.13+
  (bsc#1012628).
- ALSA: usb-audio: Workaround for XRUN at prepare (bsc#1012628).
- ALSA: usb-audio: add the quirk for KT0206 device (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Lenovo TianYi510Pro-14IOB
  (bsc#1012628).
- ALSA: hda/hdmi: Add HP Device 0x8711 to force connect list
  (bsc#1012628).
- HID: logitech-hidpp: Guard FF init code against non-USB devices
  (bsc#1012628).
- usb: cdnsp: fix lack of ZLP for ep0 (bsc#1012628).
- usb: xhci-mtk: fix leakage of shared hcd when fail to set
  wakeup irq (bsc#1012628).
- arm64: dts: qcom: sm6350: fix USB-DP PHY registers
  (bsc#1012628).
- arm64: dts: qcom: sm8250: fix USB-DP PHY registers
  (bsc#1012628).
- dt-bindings: clocks: imx8mp: Add ID for usb suspend clock
  (bsc#1012628).
- clk: imx: imx8mp: add shared clk gate for usb suspend clk
  (bsc#1012628).
- usb: dwc3: Fix race between dwc3_set_mode and __dwc3_set_mode
  (bsc#1012628).
- usb: dwc3: core: defer probe on ulpi_read_id timeout
  (bsc#1012628).
- usb: dwc3: qcom: Fix memory leak in dwc3_qcom_interconnect_init
  (bsc#1012628).
- xhci: Prevent infinite loop in transaction errors recovery
  for streams (bsc#1012628).
- HID: wacom: Ensure bootloader PID is usable in hidraw mode
  (bsc#1012628).
- HID: mcp2221: don't connect hidraw (bsc#1012628).
- loop: Fix the max_loop commandline argument treatment when it
  is set to 0 (bsc#1012628).
- 9p: set req refcount to zero to avoid uninitialized usage
  (bsc#1012628).
- security: Restrict CONFIG_ZERO_CALL_USED_REGS to gcc or clang >
  15.0.6 (bsc#1012628).
- reiserfs: Add missing calls to reiserfs_security_free()
  (bsc#1012628).
- iio: fix memory leak in iio_device_register_eventset()
  (bsc#1012628).
- iio: adc: ad_sigma_delta: do not use internal iio_dev lock
  (bsc#1012628).
- iio: adc128s052: add proper .data members in adc128_of_match
  table (bsc#1012628).
- iio: addac: ad74413r: fix integer promotion bug in
  ad74413_get_input_current_offset() (bsc#1012628).
- regulator: core: fix deadlock on regulator enable (bsc#1012628).
- spi: fsl_spi: Don't change speed while chipselect is active
  (bsc#1012628).
- floppy: Fix memory leak in do_floppy_init() (bsc#1012628).
- gcov: add support for checksum field (bsc#1012628).
- test_maple_tree: add test for mas_spanning_rebalance() on
  insufficient data (bsc#1012628).
- maple_tree: fix mas_spanning_rebalance() on insufficient data
  (bsc#1012628).
- fbdev: fbcon: release buffer when fbcon_do_set_font() failed
  (bsc#1012628).
- ovl: fix use inode directly in rcu-walk mode (bsc#1012628).
- btrfs: do not BUG_ON() on ENOMEM when dropping extent items
  for a range (bsc#1012628).
- mm/gup: disallow FOLL_FORCE|FOLL_WRITE on hugetlb mappings
  (bsc#1012628).
- scsi: qla2xxx: Fix crash when I/O abort times out (bsc#1012628).
- blk-iolatency: Fix memory leak on add_disk() failures
  (bsc#1012628).
- io_uring/net: introduce IORING_SEND_ZC_REPORT_USAGE flag
  (bsc#1012628).
- io_uring: add completion locking for iopoll (bsc#1012628).
- io_uring: dont remove file from msg_ring reqs (bsc#1012628).
- io_uring: improve io_double_lock_ctx fail handling
  (bsc#1012628).
- io_uring/net: fix cleanup after recycle (bsc#1012628).
- io_uring: protect cq_timeouts with timeout_lock (bsc#1012628).
- io_uring: remove iopoll spinlock (bsc#1012628).
- net: stmmac: fix errno when create_singlethread_workqueue()
  fails (bsc#1012628).
- media: dvbdev: fix build warning due to comments (bsc#1012628).
- media: dvbdev: fix refcnt bug (bsc#1012628).
- drm/amd/display: revert Disable DRR actions during state commit
  (bsc#1012628).
- mfd: qcom_rpm: Use devm_of_platform_populate() to simplify code
  (bsc#1012628).
- pwm: tegra: Fix 32 bit build (bsc#1012628).
- Update config files.
- commit 7fea150
* Sun Jan  1 2023 tiwai@suse.de
- ALSA: hda/hdmi: Static PCM mapping again with AMD HDMI codecs
  (bsc#1206759).
- commit 8a7bf0c
* Fri Dec 30 2022 tiwai@suse.de
- wifi: mac80211: fix initialization of rx->link and rx->link_sta
  (bsc#1206683).
- commit 081acb5
* Mon Dec 26 2022 mkubecek@suse.cz
- Update to 6.2-rc1
- drop 32 patches (25 stable, 7 mainline)
  - patches.kernel.org/*
  - patches.suse/NFSD-fix-use-after-free-in-__nfs42_ssc_open.patch
  - patches.suse/char-xillybus-Fix-trivial-bug-with-mutex.patch
  - patches.suse/char-xillybus-Prevent-use-after-free-due-to-race-con.patch
  - patches.suse/io_uring-net-ensure-compat-import-handlers-clear-fre.patch
  - patches.suse/media-dvb-core-Fix-UAF-due-to-refcount-races-at-rele.patch
  - patches.suse/misc-sgi-gru-fix-use-after-free-error-in-gru_set_con.patch
  - patches.suse/mm-mremap-fix-mremap-expanding-vma-with-addr-inside-.patch
- refresh
  - patches.suse/Input-elan_i2c-Add-deny-list-for-Lenovo-Yoga-Slim-7.patch
  - patches.suse/add-suse-supported-flag.patch
  - patches.suse/crasher.patch
  - patches.suse/vfs-add-super_operations-get_inode_dev
- disable ARM architectures (need config update)
- new config options
  - General setup
  - RCU_LAZY=n
  - KALLSYMS_SELFTEST=n
  - Processor type and features
  - EFI_HANDOVER_PROTOCOL=y
  - Mitigations for speculative execution vulnerabilities
  - CALL_DEPTH_TRACKING=y
  - CALL_THUNKS_DEBUG=n
  - Power management and ACPI options
  - ACPI_FFH=y
  - Virtualization
  - KVM_SMM=y
  - Memory Management options
  - SLOB_DEPRECATED=n
  - SLUB_TINY=n
  - Networking support
  - BT_LE_L2CAP_ECRED=y
  - BT_HCIBTUSB_POLL_SYNC=y
  - BT_HCIBCM4377=m
  - RXPERF=m
  - File systems
  - SQUASHFS_CHOICE_DECOMP_BY_MOUNT=y
  - NFSD_V2=n
  - Kernel hacking
  - DEBUG_INFO_COMPRESSED_NONE=y
  - DEBUG_INFO_COMPRESSED_ZLIB=n
  - DEBUG_CGROUP_REF=n
  - FAULT_INJECTION_STACKTRACE_FILTER=n
  - Network device support
  - NFP_NET_IPSEC=y
  - MT7996E=m
  - RTW88_8822BU=m
  - RTW88_8822CU=m
  - RTW88_8723DU=m
  - RTW88_8821CU=m
  - RTW89_8852BE=m
  - Input device support
  - TOUCHSCREEN_CYTTSP5=m
  - TOUCHSCREEN_HYNITRON_CSTXXX=m
  - TOUCHSCREEN_HIMAX_HX83112B=m
  - Hardware Monitoring support
  - SENSORS_OCC_P8_I2C=m
  - SENSORS_OXP=m
  - Multimedia support
  - VIDEO_OV08X40=m
  - VIDEO_OV4689=m
  - VIDEO_TC358746=m
  - Graphics support
  - DRM_I915_PREEMPT_TIMEOUT_COMPUTE=7500
  - DRM_ACCEL=y
  - DRM_ACCEL=y
  - Sound card support
  - SND_SOC_INTEL_AVS_MACH_MAX98927=m
  - SND_SOC_INTEL_AVS_MACH_PROBE=m
  - SND_SOC_WM8961=n
  - X86 Platform Specific Device Drivers
  - DELL_WMI_DDV=m
  - X86_PLATFORM_DRIVERS_HP=y
  - INTEL_IFS=m
  - Industrial I/O support
  - IIO_KX022A_SPI=n
  - IIO_KX022A_I2C=n
  - AD4130=n
  - MAX11410=n
  - AD74115=n
  - ADF4377=n
  - MAX30208=m
  - Misc devices
  - CXL_REGION_INVALIDATION_TEST=n
  - ZRAM_MULTI_COMP=y
  - LEGACY_TIOCSTI=n
  - SPI_PCI1XXXX=n
  - GPIO_LATCH=m
  - ADVANTECH_EC_WDT=m
  - MFD_SMPRO=n
  - REGULATOR_RT6190=m
  - MANA_INFINIBAND=m
  - TDX_GUEST_DRIVER=m
  - CROS_HPS_I2C=m
  - IOMMUFD=n
  - NVDIMM_SECURITY_TEST=n
  - FPGA_MGR_LATTICE_SYSCONFIG_SPI=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - SPI_SN_F_OSPI=n
  - MFD_TPS65219=n
  - VIDEO_ST_VGXY61=m
  - DRM_PANEL_JADARD_JD9365DA_H3=n
  - DRM_PANEL_NEWVISION_NV3051D=n
  - i386
  - SND_SOC_RT1318_SDW=n
  - ppc64le / ppc64
  - SSIF_IPMI_BMC=m
  - SENSORS_OCC_P9_SBE=m
  - DRM_OFDRM=m
  - ppc64
  - PPC64_BIG_ENDIAN_ELF_ABI_V2=y
  - s390x
  - VCAP=y
  - HUGETLB_PAGE_OPTIMIZE_VMEMMAP_DEFAULT_ON=n
  - riscv64
  - ARCH_RENESAS=y
  - ERRATA_THEAD_PMU=y
  - CPU_FREQ=y
  - CPU_FREQ_STAT=y (arm64)
  - CPU_FREQ_DEFAULT_GOV_ONDEMAND=y (arm64)
  - CPU_FREQ_GOV_POWERSAVE=m
  - CPU_FREQ_GOV_USERSPACE=m
  - CPU_FREQ_GOV_CONSERVATIVE=m
  - CPU_FREQ_GOV_SCHEDUTIL=y
  - CPUFREQ_DT=m
  - PCIE_RCAR_HOST=y
  - PCIE_RCAR_EP=y
  - MTD_NAND_RENESAS=m
  - SCSI_LPFC=m
  - SCSI_LPFC_DEBUG_FS=n
  - SATA_RCAR=m
  - SH_ETH=m
  - RAVB=m
  - RENESAS_ETHER_SWITCH=m
  - CAN_RCAR=m
  - CAN_RCAR_CANFD=m
  - SERIAL_8250_EM=y
  - SERIAL_SH_SCI=n
  - I2C_RIIC=m
  - I2C_RZV2M=m
  - I2C_SH_MOBILE=m
  - I2C_RCAR=m
  - I2C_SLAVE_EEPROM=m
  - I2C_SLAVE_TESTUNIT=n
  - SPI_RSPI=m
  - SPI_SH_MSIOF=m
  - SPI_SH_HSPI=m
  - GPIO_RCAR=m
  - CPU_FREQ_THERMAL=y
  - RCAR_THERMAL=m
  - RCAR_GEN3_THERMAL=m
  - RZG2L_THERMAL=m
  - RENESAS_WDT=m
  - RENESAS_RZAWDT=m
  - RENESAS_RZN1WDT=m
  - RENESAS_RZG2LWDT=m
  - DRM_RZG2L_MIPI_DSI=n
  - FB_SH_MOBILE_LCDC=n
  - SND_SOC_SH4_FSI=n
  - SND_SOC_RCAR=n
  - MMC_SDHI=m
  - MMC_SDHI_SYS_DMAC=m
  - MMC_SH_MMCIF=m
  - SCSI_UFS_RENESAS=m
  - RTC_DRV_SH=m
  - RCAR_DMAC=m
  - RENESAS_USB_DMAC=m
  - CLK_RCAR_USB2_CLOCK_SEL=y
  - RENESAS_OSTM=y
  - IPMMU_VMSA=y
  - ARCH_R9A07G043=y
  - RENESAS_RPCIF=m
  - RZG2L_ADC=n
  - PWM_RCAR=m
  - PWM_RENESAS_TPU=m
  - RESET_RZG2L_USBPHY_CTRL=m
  - PHY_R8A779F0_ETHERNET_SERDES=m
  - PHY_RCAR_GEN2=m
  - PHY_RCAR_GEN3_PCIE=m
  - PHY_RCAR_GEN3_USB2=m
  - PHY_RCAR_GEN3_USB3=m
  - FPROBE=y
  - UCLAMP_TASK=n
  - ENERGY_MODEL=y
  - MCTP_TRANSPORT_I2C=m
  - INPUT_IBM_PANEL=m
  - IPMI_IPMB=m
  - SSIF_IPMI_BMC=m
  - IPMB_DEVICE_INTERFACE=m
  - SPI_RPCIF=m
  - THERMAL_GOV_POWER_ALLOCATOR=n
  - SND_SOC_RZ=n
  - RZ_DMAC=m
  - IOMMU_IO_PGTABLE_LPAE_SELFTEST=n
  - DTPM_CPU=y
  - DTPM_DEVFREQ=y
- commit 769d7ad
* Thu Dec 22 2022 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and move into sorted section:
  - patches.suse/io_uring-net-ensure-compat-import-handlers-clear-fre.patch
- commit a76dc2b
* Thu Dec 22 2022 jslaby@suse.cz
- Linux 6.1.1 (bsc#1012628).
- KEYS: encrypted: fix key instantiation with user-provided data
  (bsc#1012628).
- cifs: fix oops during encryption (bsc#1012628).
- usb: dwc3: pci: Update PCIe device ID for USB3 controller on
  CPU sub-system for Raptor Lake (bsc#1012628).
- usb: typec: ucsi: Resume in separate work (bsc#1012628).
- igb: Initialize mailbox message for VF reset (bsc#1012628).
- staging: r8188eu: fix led register settings (bsc#1012628).
- xhci: Apply XHCI_RESET_TO_DEFAULT quirk to ADL-N (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs for a HP ProBook
  (bsc#1012628).
- USB: serial: f81534: fix division by zero on line-speed change
  (bsc#1012628).
- USB: serial: f81232: fix division by zero on line-speed change
  (bsc#1012628).
- USB: serial: cp210x: add Kamstrup RF sniffer PIDs (bsc#1012628).
- USB: serial: option: add Quectel EM05-G modem (bsc#1012628).
- usb: gadget: uvc: Prevent buffer overflow in setup handler
  (bsc#1012628).
- udf: Fix extending file within last block (bsc#1012628).
- udf: Do not bother looking for prealloc extents if i_lenExtents
  matches i_size (bsc#1012628).
- udf: Fix preallocation discarding at indirect extent boundary
  (bsc#1012628).
- udf: Discard preallocation before extending file with a hole
  (bsc#1012628).
- irqchip/ls-extirq: Fix endianness detection (bsc#1012628).
- mips: ralink: mt7621: do not use kzalloc too early
  (bsc#1012628).
- mips: ralink: mt7621: soc queries and tests as functions
  (bsc#1012628).
- mips: ralink: mt7621: define MT7621_SYSC_BASE with __iomem
  (bsc#1012628).
- PCI: mt7621: Add sentinel to quirks table (bsc#1012628).
- libbpf: Fix uninitialized warning in btf_dump_dump_type_data
  (bsc#1012628).
- x86/vdso: Conditionally export __vdso_sgx_enter_enclave()
  (bsc#1012628).
- commit 181a470
* Wed Dec 21 2022 mkoutny@suse.com
- Add Tegra repository to git_sort.
- commit 69abba1
* Wed Dec 21 2022 jslaby@suse.cz
- tcp: Add TIME_WAIT sockets in bhash2 (bsc#1206466).
- commit d8defbe
* Wed Dec 21 2022 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  - patches.suse/NFSD-fix-use-after-free-in-__nfs42_ssc_open.patch
- commit bf66071
* Tue Dec 20 2022 jslaby@suse.cz
- io_uring/net: ensure compat import handlers clear free_iov
  (bsc#1206509).
- commit 747fc96
* Mon Dec 19 2022 neilb@suse.de
- NFSD: fix use-after-free in __nfs42_ssc_open() (bsc#1206209
  CVE-2022-4379).
- commit 338ca73
* Fri Dec 16 2022 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  - patches.suse/char-xillybus-Fix-trivial-bug-with-mutex.patch
  - patches.suse/char-xillybus-Prevent-use-after-free-due-to-race-con.patch
  - patches.suse/media-dvb-core-Fix-UAF-due-to-refcount-races-at-rele.patch
  - patches.suse/misc-sgi-gru-fix-use-after-free-error-in-gru_set_con.patch
- commit 7f1864f
* Fri Dec 16 2022 vbabka@suse.cz
- mm, mremap: fix mremap() expanding vma with addr inside vma (bsc#1206359).
- Delete
  patches.suse/Revert-mm-add-merging-after-mremap-resize.patch.
- commit 3440c9c
* Fri Dec 16 2022 vbabka@suse.cz
- mm, mremap: fix mremap() expanding vma with addr inside
  vma (bsc#1206359).
- commit b61d296
* Thu Dec 15 2022 jslaby@suse.cz
- Revert "mm: add merging after mremap resize" (bsc#1206335).
- commit 52313a4
* Mon Dec 12 2022 jslaby@suse.cz
- series.conf: remove stale comment
- commit ab17686
* Mon Dec 12 2022 jslaby@suse.cz
- Refresh patches.suse/Bluetooth-L2CAP-Fix-u8-overflow.patch.
- Refresh patches.suse/can-slcan-fix-freed-work-crash.patch.
  Update upstream status.
- commit a6c4f4e
* Mon Dec 12 2022 mkubecek@suse.cz
- Update to 6.1 final
- refresh configs (headers only)
- commit d1335c0
* Fri Dec  9 2022 jslaby@suse.cz
- Delete
  patches.suse/Input-synaptics-retry-query-upon-error.patch.
  The patch is not needed (bsc#1194086 comment 50).
- commit d03b675
* Fri Dec  9 2022 jslaby@suse.cz
- Delete patches.suse/iwlwifi-module-firmware-ucode-fix.patch.
  Not needed anymore. kernel-firmware contains -72s since 06dbfbc74388
  released in 20221109 already.
- commit e1d0837
* Fri Dec  9 2022 jslaby@suse.cz
- Delete
  patches.suse/drm-sched-Fix-kernel-NULL-pointer-dereference-error.patch.
  This can be dropped thanks to commit bafaf67c42f4 (Revert "drm/sched:
  Use parent fence instead of finished") in v6.1-rc1.
- commit 15d1c2b
* Fri Dec  9 2022 jslaby@suse.cz
- Refresh
  patches.suse/media-dvb-core-Fix-UAF-due-to-refcount-races-at-rele.patch.
  Update upstream status.
- commit d504053
* Fri Dec  9 2022 jslaby@suse.cz
- Delete patches.suse/dm-mpath-no-partitions-feature. (bsc#1189976)
- commit e544c6d
* Fri Dec  9 2022 jslaby@suse.cz
- Refresh
  patches.suse/misc-sgi-gru-fix-use-after-free-error-in-gru_set_con.patch.
  Update to final version and update upstream status.
- commit dd048d9
* Fri Dec  9 2022 jslaby@suse.cz
- Delete patches.suse/suse-hv-guest-os-id.patch. (bsc#1189965)
- commit de46b50
* Fri Dec  9 2022 jslaby@suse.cz
- Delete patches.suse/dm-mpath-leastpending-path-update. (bsc#1189962)
- commit fb9bee7
* Fri Dec  9 2022 jslaby@suse.cz
- Delete patches.suse/dm-table-switch-to-readonly. (bsc#1189963)
- commit 3a71c4d
* Fri Dec  9 2022 jslaby@suse.cz
- Delete patches.suse/kbd-ignore-gfx.patch. (bsc#1189975)
- commit 900ecbb
* Thu Dec  8 2022 jeffm@suse.com
- Revert "config: update CONFIG_LSM defaults"
  This reverts commit a05e86cb8200d8cf785b866375a4c9d06c09ab47.
  Commit 0a20128a486 (Revert "config: Enable BPF LSM" (bsc#1197746))
  indicates this needs more specific testing before merging.
- commit 7453fbc
* Thu Dec  8 2022 jeffm@suse.com
- config: update CONFIG_LSM defaults (bsc#1205603).
  CONFIG_LSM determines what the default order of LSM usage is.  The
  default order is set based on whether AppArmor or SELinux is preferred
  in the config (we still prefer AppArmor).  The default set has changed
  over time and we haven't updated it, leading to things like bpf LSMs
  not working out of the box.
  This change just updates CONFIG_LSM to what the default would be now.
- config: update CONFIG_LSM defaults
  CONFIG_LSM determines what the default order of LSM usage is.  The
  default order is set based on whether AppArmor or SELinux is preferred
  in the config (we still prefer AppArmor).  The default set has changed
  over time and we haven't updated it, leading to things like bpf LSMs
  not working out of the box.
  This change just updates CONFIG_LSM to what the default would be now.
- commit 720c383
* Thu Dec  8 2022 jslaby@suse.cz
- Linux 6.0.12 (bsc#1012628).
- btrfs: qgroup: fix sleep from invalid context bug in
  btrfs_qgroup_inherit() (bsc#1012628).
- drm/amdgpu: move setting the job resources (bsc#1012628).
- drm/amdgpu: cleanup error handling in amdgpu_cs_parser_bos
  (bsc#1012628).
- drm/amdgpu: fix userptr HMM range handling v2 (bsc#1012628).
- drm/amd/pm: add smu_v13_0_10 driver if version (bsc#1012628).
- drm/amd/pm: update driver-if header for smu_v13_0_10
  (bsc#1012628).
- drm/amd/pm: update driver if header for smu_13_0_7
  (bsc#1012628).
- clk: samsung: exynos7885: Correct "div4" clock parents
  (bsc#1012628).
- clk: qcom: gdsc: add missing error handling (bsc#1012628).
- clk: qcom: gdsc: Remove direct runtime PM calls (bsc#1012628).
- iio: health: afe4403: Fix oob read in afe4403_read_raw
  (bsc#1012628).
- iio: health: afe4404: Fix oob read in afe4404_[read|write]_raw
  (bsc#1012628).
- iio: light: rpr0521: add missing Kconfig dependencies
  (bsc#1012628).
- libbpf: Use correct return pointer in attach_raw_tp
  (bsc#1012628).
- bpf, perf: Use subprog name when reporting subprog ksymbol
  (bsc#1012628).
- scripts/faddr2line: Fix regression in name resolution on ppc64le
  (bsc#1012628).
- ARM: at91: rm9200: fix usb device clock id (bsc#1012628).
- libbpf: Handle size overflow for ringbuf mmap (bsc#1012628).
- hwmon: (ltc2947) fix temperature scaling (bsc#1012628).
- hwmon: (ina3221) Fix shunt sum critical calculation
  (bsc#1012628).
- hwmon: (i5500_temp) fix missing pci_disable_device()
  (bsc#1012628).
- hwmon: (ibmpex) Fix possible UAF when ibmpex_register_bmc()
  fails (bsc#1012628).
- clocksource/drivers/arm_arch_timer: Fix XGene-1 TVAL register
  math error (bsc#1012628).
- bpf: Do not copy spin lock field from user in bpf_selem_alloc
  (bsc#1012628).
- nvmem: rmem: Fix return value check in rmem_read()
  (bsc#1012628).
- of: property: decrement node refcount in
  of_fwnode_get_reference_args() (bsc#1012628).
- clk: qcom: gcc-sc8280xp: add cxo as parent for three ufs ref
  clks (bsc#1012628).
- ixgbevf: Fix resource leak in ixgbevf_init_module()
  (bsc#1012628).
- i40e: Fix error handling in i40e_init_module() (bsc#1012628).
- fm10k: Fix error handling in fm10k_init_module() (bsc#1012628).
- iavf: Fix error handling in iavf_init_module() (bsc#1012628).
- e100: Fix possible use after free in e100_xmit_prepare
  (bsc#1012628).
- net/mlx5: DR, Fix uninitialized var warning (bsc#1012628).
- net/mlx5: E-switch, Destroy legacy fdb table when needed
  (bsc#1012628).
- net/mlx5: E-switch, Fix duplicate lag creation (bsc#1012628).
- net/mlx5: Fix uninitialized variable bug in outlen_write()
  (bsc#1012628).
- net/mlx5e: Fix use-after-free when reverting termination table
  (bsc#1012628).
- can: sja1000_isa: sja1000_isa_probe(): add missing
  free_sja1000dev() (bsc#1012628).
- can: cc770: cc770_isa_probe(): add missing free_cc770dev()
  (bsc#1012628).
- can: etas_es58x: es58x_init_netdev(): free netdev when
  register_candev() (bsc#1012628).
- can: m_can: pci: add missing m_can_class_free_dev() in
  probe/remove methods (bsc#1012628).
- can: m_can: Add check for devm_clk_get (bsc#1012628).
- vfs: fix copy_file_range() averts filesystem freeze protection
  (bsc#1012628).
- qlcnic: fix sleep-in-atomic-context bugs caused by msleep
  (bsc#1012628).
- aquantia: Do not purge addresses when setting the number of
  rings (bsc#1012628).
- wifi: cfg80211: fix buffer overflow in elem comparison
  (bsc#1012628).
- wifi: cfg80211: don't allow multi-BSSID in S1G (bsc#1012628).
- wifi: mac8021: fix possible oob access in
  ieee80211_get_rate_duration (bsc#1012628).
- net: phy: fix null-ptr-deref while probe() failed (bsc#1012628).
- net: ethernet: ti: am65-cpsw: fix error handling in
  am65_cpsw_nuss_probe() (bsc#1012628).
- net: net_netdev: Fix error handling in ntb_netdev_init_module()
  (bsc#1012628).
- net/9p: Fix a potential socket leak in p9_socket_open
  (bsc#1012628).
- net: ethernet: nixge: fix NULL dereference (bsc#1012628).
- net: wwan: iosm: fix kernel test robot reported error
  (bsc#1012628).
- net: wwan: iosm: fix dma_alloc_coherent incompatible pointer
  type (bsc#1012628).
- net: wwan: iosm: fix crash in peek throughput test
  (bsc#1012628).
- net: wwan: iosm: fix incorrect skb length (bsc#1012628).
- dsa: lan9303: Correct stat name (bsc#1012628).
- mptcp: don't orphan ssk in mptcp_close() (bsc#1012628).
- mptcp: fix sleep in atomic at close time (bsc#1012628).
- tipc: re-fetch skb cb after tipc_msg_validate (bsc#1012628).
- net: hsr: Fix potential use-after-free (bsc#1012628).
- net: mdiobus: fix unbalanced node reference count (bsc#1012628).
- afs: Fix fileserver probe RTT handling (bsc#1012628).
- net: tun: Fix use-after-free in tun_detach() (bsc#1012628).
- net/mlx5: Lag, Fix for loop when checking lag (bsc#1012628).
- packet: do not set TP_STATUS_CSUM_VALID on CHECKSUM_COMPLETE
  (bsc#1012628).
- sctp: fix memory leak in sctp_stream_outq_migrate()
  (bsc#1012628).
- net: ethernet: renesas: ravb: Fix promiscuous mode after system
  resumed (bsc#1012628).
- afs: Fix server->active leak in afs_put_server (bsc#1012628).
- hwmon: (coretemp) Check for null before removing sysfs attrs
  (bsc#1012628).
- hwmon: (coretemp) fix pci device refcount leak in nv1a_ram_new()
  (bsc#1012628).
- hwmon: (asus-ec-sensors) Add checks for devm_kcalloc
  (bsc#1012628).
- riscv: vdso: fix section overlapping under some conditions
  (bsc#1012628).
- riscv: mm: Proper page permissions after initmem free
  (bsc#1012628).
- ALSA: dice: fix regression for Lexicon I-ONIX FW810S
  (bsc#1012628).
- can: can327: can327_feed_frame_to_netdev(): fix potential skb
  leak when netdev is down (bsc#1012628).
- error-injection: Add prompt for function error injection
  (bsc#1012628).
- tools/vm/slabinfo-gnuplot: use "grep -E" instead of "egrep"
  (bsc#1012628).
- nilfs2: fix NULL pointer dereference in
  nilfs_palloc_commit_free_entry() (bsc#1012628).
- pinctrl: intel: Save and restore pins in "direct IRQ" mode
  (bsc#1012628).
- v4l2: don't fall back to follow_pfn() if pin_user_pages_fast()
  fails (bsc#1012628).
- mm: migrate: fix THP's mapcount on isolation (bsc#1012628).
- net: stmmac: Set MAC's flow control register to reflect current
  settings (bsc#1012628).
- mmc: mmc_test: Fix removal of debugfs file (bsc#1012628).
- mmc: mtk-sd: Fix missing clk_disable_unprepare in
  msdc_of_clock_parse() (bsc#1012628).
- mmc: core: Fix ambiguous TRIM and DISCARD arg (bsc#1012628).
- mmc: sdhci-esdhc-imx: correct CQHCI exit halt state check
  (bsc#1012628).
- mmc: sdhci-sprd: Fix no reset data and command after voltage
  switch (bsc#1012628).
- mmc: sdhci: Fix voltage switch delay (bsc#1012628).
- Kconfig.debug: provide a little extra FRAME_WARN leeway when
  KASAN is enabled (bsc#1012628).
- drm/amdgpu: temporarily disable broken Clang builds due to
  blown stack-frame (bsc#1012628).
- drm/amdgpu: enable Vangogh VCN indirect sram mode (bsc#1012628).
- drm/i915: Fix negative value passed as remaining time
  (bsc#1012628).
- drm/i915: Never return 0 if not all requests retired
  (bsc#1012628).
- tracing/osnoise: Fix duration type (bsc#1012628).
- tracing: Fix race where histograms can be called before the
  event (bsc#1012628).
- tracing: Free buffers when a used dynamic event is removed
  (bsc#1012628).
- ASoC: ops: Fix bounds check for _sx controls (bsc#1012628).
- ASoC: tlv320adc3xxx: Fix build error for implicit function
  declaration (bsc#1012628).
- pinctrl: single: Fix potential division by zero (bsc#1012628).
- riscv: Sync efi page table's kernel mappings before switching
  (bsc#1012628).
- riscv: fix race when vmap stack overflow (bsc#1012628).
- riscv: kexec: Fixup irq controller broken in kexec crash path
  (bsc#1012628).
- nvme: fix SRCU protection of nvme_ns_head list (bsc#1012628).
- iommu/vt-d: Fix PCI device refcount leak in has_external_pci()
  (bsc#1012628).
- iommu/vt-d: Fix PCI device refcount leak in
  dmar_dev_scope_init() (bsc#1012628).
- ipv4: Handle attempt to delete multipath route when fib_info
  contains an nh reference (bsc#1012628).
- ipv4: Fix route deletion when nexthop info is not specified
  (bsc#1012628).
- mm/damon: introduce struct damos_access_pattern (bsc#1012628).
- mm/damon/sysfs: fix wrong empty schemes assumption under online
  tuning in damon_sysfs_set_schemes() (bsc#1012628).
- i2c: Restore initial power state if probe fails (bsc#1012628).
- i2c: npcm7xx: Fix error handling in npcm_i2c_init()
  (bsc#1012628).
- i2c: qcom-geni: fix error return code in geni_i2c_gpi_xfer
  (bsc#1012628).
- i2c: imx: Only DMA messages with I2C_M_DMA_SAFE flag set
  (bsc#1012628).
- ACPI: HMAT: remove unnecessary variable initialization
  (bsc#1012628).
- ACPI: HMAT: Fix initiator registration for single-initiator
  systems (bsc#1012628).
- Revert "clocksource/drivers/riscv: Events are stopped during
  CPU suspend" (bsc#1012628).
- char: tpm: Protect tpm_pm_suspend with locks (bsc#1012628).
- Input: raydium_ts_i2c - fix memory leak in raydium_i2c_send()
  (bsc#1012628).
- powerpc/bpf/32: Fix Oops on tail call tests (bsc#1012628).
- ipc/sem: Fix dangling sem_array access in semtimedop race
  (bsc#1012628).
- proc: avoid integer type confusion in get_proc_long
  (bsc#1012628).
- proc: proc_skip_spaces() shouldn't think it is working on C
  strings (bsc#1012628).
- commit 523a283
* Wed Dec  7 2022 jslaby@suse.cz
- x86/bugs: Make sure MSR_SPEC_CTRL is updated properly upon
  resume from S3 (bsc#1206037).
- commit b072b1c
* Mon Dec  5 2022 mkubecek@suse.cz
- Update to 6.1-rc8
- commit 6ba05d3
* Sat Dec  3 2022 jslaby@suse.cz
- Linux 6.0.11 (bsc#1012628).
- binder: validate alloc->mm in ->mmap() handler (bsc#1012628).
- ceph: Use kcalloc for allocating multiple elements
  (bsc#1012628).
- ceph: fix NULL pointer dereference for req->r_session
  (bsc#1012628).
- wifi: mac80211: fix memory free error when registering wiphy
  fail (bsc#1012628).
- wifi: cfg80211: Fix bitrates overflow issue (bsc#1012628).
- wifi: mac80211_hwsim: fix debugfs attribute ps with rc table
  support (bsc#1012628).
- spi: tegra210-quad: Don't initialise DMA if not supported
  (bsc#1012628).
- riscv: dts: sifive unleashed: Add PWM controlled LEDs
  (bsc#1012628).
- audit: fix undefined behavior in bit shift for AUDIT_BIT
  (bsc#1012628).
- wifi: airo: do not assign -1 to unsigned char (bsc#1012628).
- wifi: mac80211: Fix ack frame idr leak when mesh has no route
  (bsc#1012628).
- selftests/net: don't tests batched TCP io_uring zc
  (bsc#1012628).
- wifi: ath11k: Fix QCN9074 firmware boot on x86 (bsc#1012628).
- s390/zcrypt: fix warning about field-spanning write
  (bsc#1012628).
- spi: stm32: fix stm32_spi_prepare_mbr() that halves spi clk
  for every run (bsc#1012628).
- selftests/bpf: Add verifier test for release_reference()
  (bsc#1012628).
- selftests/net: give more time to udpgro bg processes to complete
  startup (bsc#1012628).
- Revert "net: macsec: report real_dev features when HW offloading
  is enabled" (bsc#1012628).
- ACPI: video: Add backlight=native DMI quirk for Dell G15 5515
  (bsc#1012628).
- platform/x86: ideapad-laptop: Disable touchpad_switch
  (bsc#1012628).
- platform/x86: touchscreen_dmi: Add info for the RCA Cambio
  W101 v2 2-in-1 (bsc#1012628).
- platform/x86/intel/pmt: Sapphire Rapids PMT errata fix
  (bsc#1012628).
- platform/x86/intel/hid: Add some ACPI device IDs (bsc#1012628).
- scsi: ibmvfc: Avoid path failures during live migration
  (bsc#1012628).
- scsi: scsi_debug: Make the READ CAPACITY response compliant
  with ZBC (bsc#1012628).
- drm: panel-orientation-quirks: Add quirk for Nanote UMPC-01
  (bsc#1012628).
- drm: panel-orientation-quirks: Add quirk for Acer Switch V 10
  (SW5-017) (bsc#1012628).
- block, bfq: fix null pointer dereference in bfq_bio_bfqg()
  (bsc#1012628).
- s390: always build relocatable kernel (bsc#1012628).
- arm64/syscall: Include asm/ptrace.h in syscall_wrapper header
  (bsc#1012628).
- nvme: quiet user passthrough command errors (bsc#1012628).
- nvmet: fix memory leak in nvmet_subsys_attr_model_store_locked
  (bsc#1012628).
- net: wwan: iosm: fix kernel test robot reported errors
  (bsc#1012628).
- drm/amd/display: Zeromem mypipe heap struct before using it
  (bsc#1012628).
- drm/amd/display: Fix FCLK deviation and tool compile issues
  (bsc#1012628).
- drm/amd/display: Fix gpio port mapping issue (bsc#1012628).
- Revert "drm/amdgpu: Revert "drm/amdgpu: getting fan speed pwm
  for vega10 properly"" (bsc#1012628).
- drm/amdgpu: Drop eviction lock when allocating PT BO
  (bsc#1012628).
- drm/amd/display: only fill dirty rectangles when PSR is enabled
  (bsc#1012628).
- ALSA: usb-audio: add quirk to fix Hamedal C20 disconnect issue
  (bsc#1012628).
- RISC-V: vdso: Do not add missing symbols to version section
  in linker script (bsc#1012628).
- MIPS: pic32: treat port as signed integer (bsc#1012628).
- io_uring/poll: lockdep annote io_poll_req_insert_locked
  (bsc#1012628).
- xfrm: fix "disable_policy" on ipv4 early demux (bsc#1012628).
- arm64: dts: rockchip: fix quartz64-a bluetooth configuration
  (bsc#1012628).
- xfrm: replay: Fix ESN wrap around for GSO (bsc#1012628).
- af_key: Fix send_acquire race with pfkey_register (bsc#1012628).
- power: supply: ip5xxx: Fix integer overflow in current_now
  calculation (bsc#1012628).
- power: supply: ab8500: Defer thermal zone probe (bsc#1012628).
- ARM: dts: am335x-pcm-953: Define fixed regulators in root node
  (bsc#1012628).
- ASoC: hdac_hda: fix hda pcm buffer overflow issue (bsc#1012628).
- ASoC: sgtl5000: Reset the CHIP_CLK_CTRL reg on remove
  (bsc#1012628).
- ASoC: soc-pcm: Don't zero TDM masks in __soc_pcm_open()
  (bsc#1012628).
- x86/hyperv: Restore VP assist page after cpu offlining/onlining
  (bsc#1012628).
- scsi: storvsc: Fix handling of srb_status and capacity change
  events (bsc#1012628).
- PCI: hv: Only reuse existing IRTE allocation for Multi-MSI
  (bsc#1012628).
- arm64: dts: rockchip: Fix Pine64 Quartz4-B PMIC interrupt
  (bsc#1012628).
- ASoC: max98373: Add checks for devm_kcalloc (bsc#1012628).
- regulator: core: fix kobject release warning and memory leak
  in regulator_register() (bsc#1012628).
- regulator: rt5759: fix OOB in validate_desc() (bsc#1012628).
- spi: dw-dma: decrease reference count in dw_spi_dma_init_mfld()
  (bsc#1012628).
- regulator: core: fix UAF in destroy_regulator() (bsc#1012628).
- bus: sunxi-rsb: Remove the shutdown callback (bsc#1012628).
- bus: sunxi-rsb: Support atomic transfers (bsc#1012628).
- tee: optee: fix possible memory leak in optee_register_device()
  (bsc#1012628).
- spi: tegra210-quad: Fix duplicate resource error (bsc#1012628).
- ARM: dts: at91: sam9g20ek: enable udc vbus gpio pinctrl
  (bsc#1012628).
- selftests: mptcp: gives slow test-case more time (bsc#1012628).
- selftests: mptcp: run mptcp_sockopt from a new netns
  (bsc#1012628).
- selftests: mptcp: fix mibit vs mbit mix up (bsc#1012628).
- net: liquidio: simplify if expression (bsc#1012628).
- net: neigh: decrement the family specific qlen (bsc#1012628).
- ipvlan: hold lower dev to avoid possible use-after-free
  (bsc#1012628).
- rxrpc: Fix race between conn bundle lookup and bundle removal
  [ZDI-CAN-15975] (bsc#1012628).
- net: dsa: sja1105: disallow C45 transactions on the BASE-TX
  MDIO bus (bsc#1012628).
- nfc/nci: fix race with opening and closing (bsc#1012628).
- net: pch_gbe: fix potential memleak in pch_gbe_tx_queue()
  (bsc#1012628).
- 9p/fd: fix issue of list_del corruption in p9_fd_cancel()
  (bsc#1012628).
- netfilter: conntrack: Fix data-races around ct mark
  (bsc#1012628).
- netfilter: nf_tables: do not set up extensions for end interval
  (bsc#1012628).
- iavf: Fix a crash during reset task (bsc#1012628).
- iavf: Do not restart Tx queues after reset task failure
  (bsc#1012628).
- iavf: remove INITIAL_MAC_SET to allow gARP to work properly
  (bsc#1012628).
- iavf: Fix race condition between iavf_shutdown and iavf_remove
  (bsc#1012628).
- ARM: mxs: fix memory leak in mxs_machine_init() (bsc#1012628).
- ARM: dts: imx6q-prti6q: Fix ref/tcxo-clock-frequency properties
  (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix error handling in mtk_open()
  (bsc#1012628).
- net/mlx4: Check retval of mlx4_bitmap_init (bsc#1012628).
- net: mvpp2: fix possible invalid pointer dereference
  (bsc#1012628).
- net/qla3xxx: fix potential memleak in ql3xxx_send()
  (bsc#1012628).
- octeontx2-af: debugsfs: fix pci device refcount leak
  (bsc#1012628).
- net: pch_gbe: fix pci device refcount leak while module exiting
  (bsc#1012628).
- nfp: fill splittable of devlink_port_attrs correctly
  (bsc#1012628).
- nfp: add port from netdev validation for EEPROM access
  (bsc#1012628).
- bonding: fix ICMPv6 header handling when receiving IPv6 messages
  (bsc#1012628).
- macsec: Fix invalid error code set (bsc#1012628).
- drm/i915: Fix warn in intel_display_power_*_domain() functions
  (bsc#1012628).
- Drivers: hv: vmbus: fix double free in the error path of
  vmbus_add_channel_work() (bsc#1012628).
- Drivers: hv: vmbus: fix possible memory leak in
  vmbus_device_register() (bsc#1012628).
- netfilter: ipset: regression in ip_set_hash_ip.c (bsc#1012628).
- net/mlx5: Do not query pci info while pci disabled
  (bsc#1012628).
- net/mlx5: Fix FW tracer timestamp calculation (bsc#1012628).
- net/mlx5: SF: Fix probing active SFs during driver probe phase
  (bsc#1012628).
- net/mlx5: cmdif, Print info on any firmware cmd failure to
  tracepoint (bsc#1012628).
- net/mlx5: Fix handling of entry refcount when command is not
  issued to FW (bsc#1012628).
- net/mlx5: E-Switch, Set correctly vport destination
  (bsc#1012628).
- net/mlx5: Fix sync reset event handler error flow (bsc#1012628).
- net/mlx5e: Offload rule only when all encaps are valid
  (bsc#1012628).
- net: phy: at803x: fix error return code in at803x_probe()
  (bsc#1012628).
- tipc: set con sock in tipc_conn_alloc (bsc#1012628).
- tipc: add an extra conn_get in tipc_conn_alloc (bsc#1012628).
- tipc: check skb_linearize() return value in tipc_disc_rcv()
  (bsc#1012628).
- zonefs: Fix race between modprobe and mount (bsc#1012628).
- xfrm: Fix oops in __xfrm_state_delete() (bsc#1012628).
- xfrm: Fix ignored return value in xfrm6_init() (bsc#1012628).
- net: wwan: iosm: use ACPI_FREE() but not kfree() in
  ipc_pcie_read_bios_cfg() (bsc#1012628).
- sfc: fix potential memleak in __ef100_hard_start_xmit()
  (bsc#1012628).
- net: sparx5: fix error handling in sparx5_port_open()
  (bsc#1012628).
- net: sched: allow act_ct to be built without NF_NAT
  (bsc#1012628).
- NFC: nci: fix memory leak in nci_rx_data_packet() (bsc#1012628).
- regulator: twl6030: re-add TWL6032_SUBCLASS (bsc#1012628).
- bnx2x: fix pci device refcount leak in
  bnx2x_vf_is_pcie_pending() (bsc#1012628).
- dma-buf: fix racing conflict of dma_heap_add() (bsc#1012628).
- tsnep: Fix rotten packets (bsc#1012628).
- cpufreq: amd-pstate: change amd-pstate driver to be built-in
  type (bsc#1012628).
- netfilter: ipset: restore allowing 64 clashing elements in
  hash:net,iface (bsc#1012628).
- netfilter: flowtable_offload: add missing locking (bsc#1012628).
- fs: do not update freeing inode i_io_list (bsc#1012628).
- blk-mq: fix queue reference leak on blk_mq_alloc_disk_for_queue
  failure (bsc#1012628).
- test_kprobes: fix implicit declaration error of test_kprobes
  (bsc#1012628).
- dccp/tcp: Reset saddr on failure after inet6?_hash_connect()
  (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix potential memory leak in
  mtk_rx_alloc() (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix resource leak in error path
  (bsc#1012628).
- ipv4: Fix error return code in fib_table_insert() (bsc#1012628).
- arcnet: fix potential memory leak in com20020_probe()
  (bsc#1012628).
- net: dm9051: Fix missing dev_kfree_skb() in dm9051_loop_rx()
  (bsc#1012628).
- net/cdc_ncm: Fix multicast RX support for CDC NCM devices with
  ZLP (bsc#1012628).
- s390/ap: fix memory leak in ap_init_qci_info() (bsc#1012628).
- s390/dasd: fix no record found for raw_track_access
  (bsc#1012628).
- fscache: fix OOB Read in __fscache_acquire_volume (bsc#1012628).
- nfc: st-nci: fix incorrect validating logic in EVT_TRANSACTION
  (bsc#1012628).
- nfc: st-nci: fix memory leaks in EVT_TRANSACTION (bsc#1012628).
- nfc: st-nci: fix incorrect sizing calculations in
  EVT_TRANSACTION (bsc#1012628).
- net: marvell: prestera: add missing unregister_netdev() in
  prestera_port_create() (bsc#1012628).
- net: enetc: cache accesses to &priv->si->hw (bsc#1012628).
- net: enetc: preserve TX ring priority across reconfiguration
  (bsc#1012628).
- octeontx2-pf: Add check for devm_kcalloc (bsc#1012628).
- net: wwan: t7xx: Fix the ACPI memory leak (bsc#1012628).
- virtio_net: Fix probe failed when modprobe virtio_net
  (bsc#1012628).
- octeontx2-af: Fix reference count issue in rvu_sdp_init()
  (bsc#1012628).
- net: thunderx: Fix the ACPI memory leak (bsc#1012628).
- s390/crashdump: fix TOD programmable field size (bsc#1012628).
- io_uring/filetable: fix file reference underflow (bsc#1012628).
- io_uring/poll: fix poll_refs race with cancelation
  (bsc#1012628).
- lib/vdso: use "grep -E" instead of "egrep" (bsc#1012628).
- can: gs_usb: remove dma allocations (bsc#1012628).
- usb: dwc3: exynos: Fix remove() function (bsc#1012628).
- usb: cdnsp: Fix issue with Clear Feature Halt Endpoint
  (bsc#1012628).
- usb: cdnsp: fix issue with ZLP - added TD_SIZE = 1
  (bsc#1012628).
- dma-buf: Use dma_fence_unwrap_for_each when importing fences
  (bsc#1012628).
- cifs: fix missing unlock in cifs_file_copychunk_range()
  (bsc#1012628).
- cifs: Use after free in debug code (bsc#1012628).
- ext4: fix use-after-free in ext4_ext_shift_extents
  (bsc#1012628).
- arm64: dts: rockchip: lower rk3399-puma-haikou SD controller
  clock frequency (bsc#1012628).
- iio: adc: aspeed: Remove the trim valid dts property
  (bsc#1012628).
- iio: light: apds9960: fix wrong register for gesture gain
  (bsc#1012628).
- iio: core: Fix entry not deleted when
  iio_register_sw_trigger_type() fails (bsc#1012628).
- iio: accel: bma400: Fix memory leak in bma400_get_steps_reg()
  (bsc#1012628).
- dt-bindings: iio: adc: Remove the property
  "aspeed,trim-data-valid" (bsc#1012628).
- mm/damon/sysfs-schemes: skip stats update if the scheme
  directory is removed (bsc#1012628).
- virt/sev-guest: Prevent IV reuse in the SNP guest driver
  (bsc#1012628).
- cpufreq: amd-pstate: cpufreq: amd-pstate: reset MSR_AMD_PERF_CTL
  register at init (bsc#1012628).
- zonefs: Fix active zone accounting (bsc#1012628).
- bus: ixp4xx: Don't touch bit 7 on IXP42x (bsc#1012628).
- spi: spi-imx: Fix spi_bus_clk if requested clock is higher
  than input clock (bsc#1012628).
- spi: spi-imx: spi_imx_transfer_one(): check for DMA transfer
  first (bsc#1012628).
- init/Kconfig: fix CC_HAS_ASM_GOTO_TIED_OUTPUT test with dash
  (bsc#1012628).
- NFSD: Fix reads with a non-zero offset that don't end on a
  page boundary (bsc#1012628).
- nios2: add FORCE for vmlinuz.gz (bsc#1012628).
- drm/amdgpu: Enable SA software trap (bsc#1012628).
- drm/amdkfd: update GFX11 CWSR trap handler (bsc#1012628).
- drm/amd/display: Added debug option for forcing subvp num ways
  (bsc#1012628).
- drm/amd/display: Add debug option for allocating extra way
  for cursor (bsc#1012628).
- drm/amd/display: Update MALL SS NumWays calculation
  (bsc#1012628).
- drm/amd/display: Fix calculation for cursor CAB allocation
  (bsc#1012628).
- usb: dwc3: gadget: conditionally remove requests (bsc#1012628).
- usb: dwc3: gadget: Return -ESHUTDOWN on ep disable
  (bsc#1012628).
- usb: dwc3: gadget: Clear ep descriptor last (bsc#1012628).
- io_uring: cmpxchg for poll arm refs release (bsc#1012628).
- io_uring: make poll refs more robust (bsc#1012628).
- io_uring: clear TIF_NOTIFY_SIGNAL if set and task_work not
  available (bsc#1012628).
- nilfs2: fix nilfs_sufile_mark_dirty() not set segment usage
  as dirty (bsc#1012628).
- gcov: clang: fix the buffer overflow issue (bsc#1012628).
- mm/cgroup/reclaim: fix dirty pages throttling on cgroup v1
  (bsc#1012628).
- mm: vmscan: fix extreme overreclaim and swap floods
  (bsc#1012628).
- fpga: m10bmc-sec: Fix kconfig dependencies (bsc#1012628).
- KVM: x86/mmu: Fix race condition in direct_page_fault
  (bsc#1012628).
- KVM: x86/xen: Only do in-kernel acceleration of hypercalls
  for guest CPL0 (bsc#1012628).
- KVM: x86/xen: Validate port number in SCHEDOP_poll
  (bsc#1012628).
- drm/i915/gvt: Get reference to KVM iff attachment to VM is
  successful (bsc#1012628).
- KVM: x86: nSVM: leave nested mode on vCPU free (bsc#1012628).
- KVM: x86: forcibly leave nested mode on vCPU reset
  (bsc#1012628).
- KVM: x86: nSVM: harden svm_free_nested against freeing vmcb02
  while still in use (bsc#1012628).
- KVM: x86: add kvm_leave_nested (bsc#1012628).
- KVM: x86: remove exit_int_info warning in svm_handle_exit
  (bsc#1012628).
- KVM: Update gfn_to_pfn_cache khva when it moves within the
  same page (bsc#1012628).
- x86/tsx: Add a feature bit for TSX control MSR support
  (bsc#1012628).
- x86/pm: Add enumeration check before spec MSRs save/restore
  setup (bsc#1012628).
- x86/ioremap: Fix page aligned size calculation in
  __ioremap_caller() (bsc#1012628).
- mm: fix unexpected changes to {failslab|fail_page_alloc}.attr
  (bsc#1012628).
- mm: correctly charge compressed memory to its memcg
  (bsc#1012628).
- LoongArch: Clear FPU/SIMD thread info flags for kernel thread
  (bsc#1012628).
- LoongArch: Set _PAGE_DIRTY only if _PAGE_WRITE is set in
  {pmd,pte}_mkdirty() (bsc#1012628).
- Input: synaptics - switch touchpad on HP Laptop 15-da3001TU
  to RMI mode (bsc#1012628).
- ASoC: amd: yc: Add Alienware m17 R5 AMD into DMI table
  (bsc#1012628).
- ASoC: Intel: bytcht_es8316: Add quirk for the Nanote UMPC-01
  (bsc#1012628).
- ASoC: Intel: soc-acpi: add ES83x6 support to IceLake
  (bsc#1012628).
- tools: iio: iio_generic_buffer: Fix read size (bsc#1012628).
- ASoC: hda: intel-dsp-config: add ES83x6 quirk for IceLake
  (bsc#1012628).
- ASoC: SOF: ipc3-topology: use old pipeline teardown flow with
  SOF2.1 and older (bsc#1012628).
- serial: 8250: 8250_omap: Avoid RS485 RTS glitch on
  - >set_termios() (bsc#1012628).
- Revert "tty: n_gsm: avoid call of sleeping functions from
  atomic context" (bsc#1012628).
- Revert "tty: n_gsm: replace kicktimer with delayed_work"
  (bsc#1012628).
- Input: goodix - try resetting the controller when no config
  is set (bsc#1012628).
- bpf: Convert BPF_DISPATCHER to use static_call() (not ftrace)
  (bsc#1012628).
- ASoC: sof_es8336: reduce pop noise on speaker (bsc#1012628).
- Input: soc_button_array - add use_low_level_irq module parameter
  (bsc#1012628).
- Input: soc_button_array - add Acer Switch V 10 to
  dmi_use_low_level_irq[] (bsc#1012628).
- pinctrl: qcom: sc8280xp: Rectify UFS reset pins (bsc#1012628).
- ASoC: stm32: dfsdm: manage cb buffers cleanup (bsc#1012628).
- xen-pciback: Allow setting PCI_MSIX_FLAGS_MASKALL too
  (bsc#1012628).
- xen/platform-pci: add missing free_irq() in error path
  (bsc#1012628).
- platform/x86: thinkpad_acpi: Enable s2idle quirk for 21A1
  machine type (bsc#1012628).
- platform/x86: asus-wmi: add missing pci_dev_put() in
  asus_wmi_set_xusb2pr() (bsc#1012628).
- platform/x86: acer-wmi: Enable SW_TABLET_MODE on Switch V 10
  (SW5-017) (bsc#1012628).
- platform/surface: aggregator_registry: Add support for Surface
  Pro 9 (bsc#1012628).
- drm/amd/display: use uclk pstate latency for fw assisted mclk
  validation dcn32 (bsc#1012628).
- drm/amdgpu: disable BACO support on more cards (bsc#1012628).
- drm/amdkfd: Fix a memory limit issue (bsc#1012628).
- zonefs: fix zone report size in __zonefs_io_error()
  (bsc#1012628).
- platform/surface: aggregator_registry: Add support for Surface
  Laptop 5 (bsc#1012628).
- platform/x86: hp-wmi: Ignore Smart Experience App event
  (bsc#1012628).
- platform/x86: ideapad-laptop: Fix interrupt storm on fn-lock
  toggle on some Yoga laptops (bsc#1012628).
- platform/x86: ideapad-laptop: Add module parameters to match
  DMI quirk tables (bsc#1012628).
- tcp: configurable source port perturb table size (bsc#1012628).
- block: make blk_set_default_limits() private (bsc#1012628).
- dm-integrity: set dma_alignment limit in io_hints (bsc#1012628).
- dm-log-writes: set dma_alignment limit in io_hints
  (bsc#1012628).
- net: usb: qmi_wwan: add Telit 0x103a composition (bsc#1012628).
- scsi: mpi3mr: Suppress command reply debug prints (bsc#1012628).
- scsi: iscsi: Fix possible memory leak when device_register()
  failed (bsc#1012628).
- gpu: host1x: Avoid trying to use GART on Tegra20 (bsc#1012628).
- dm integrity: flush the journal on suspend (bsc#1012628).
- dm integrity: clear the journal on suspend (bsc#1012628).
- fuse: lock inode unconditionally in fuse_fallocate()
  (bsc#1012628).
- wifi: wilc1000: validate pairwise and authentication suite
  offsets (bsc#1012628).
- wifi: wilc1000: validate length of
  IEEE80211_P2P_ATTR_OPER_CHANNEL attribute (bsc#1012628).
- wifi: wilc1000: validate length of
  IEEE80211_P2P_ATTR_CHANNEL_LIST attribute (bsc#1012628).
- wifi: wilc1000: validate number of channels (bsc#1012628).
- btrfs: free btrfs_path before copying root refs to userspace
  (bsc#1012628).
- btrfs: free btrfs_path before copying inodes to userspace
  (bsc#1012628).
- btrfs: free btrfs_path before copying fspath to userspace
  (bsc#1012628).
- btrfs: free btrfs_path before copying subvol info to userspace
  (bsc#1012628).
- btrfs: zoned: fix missing endianness conversion in
  sb_write_pointer (bsc#1012628).
- btrfs: use kvcalloc in btrfs_get_dev_zone_info (bsc#1012628).
- btrfs: sysfs: normalize the error handling branch in
  btrfs_init_sysfs() (bsc#1012628).
- btrfs: do not modify log tree while holding a leaf from fs
  tree locked (bsc#1012628).
- drm/i915/ttm: never purge busy objects (bsc#1012628).
- drm/display/dp_mst: Fix drm_dp_mst_add_affected_dsc_crtcs()
  return code (bsc#1012628).
- drm/amd/dc/dce120: Fix audio register mapping, stop triggering
  KASAN (bsc#1012628).
- drm/amd/display: No display after resume from WB/CB
  (bsc#1012628).
- drm/amdgpu/psp: don't free PSP buffers on suspend (bsc#1012628).
- drm/amdgpu: Enable Aldebaran devices to report CU Occupancy
  (bsc#1012628).
- drm/amd/amdgpu: reserve vm invalidation engine for firmware
  (bsc#1012628).
- drm/amd/display: Update soc bounding box for dcn32/dcn321
  (bsc#1012628).
- drm/amdgpu: always register an MMU notifier for userptr
  (bsc#1012628).
- drm/amdgpu: Partially revert "drm/amdgpu: update
  drm_display_info correctly when the edid is read" (bsc#1012628).
- drm/i915: fix TLB invalidation for Gen12 video and compute
  engines (bsc#1012628).
- bpf: Add explicit cast to 'void *' for __BPF_DISPATCHER_UPDATE()
  (bsc#1012628).
- Update config files.
- commit d8f98b5
* Thu Dec  1 2022 jslaby@suse.cz
- can: slcan: fix freed work crash (bsc#1205597).
- commit 1004618
* Thu Dec  1 2022 jslaby@suse.cz
- Refresh
  patches.suse/Input-i8042-Apply-probe-defer-to-more-ASUS-ZenBook-m.patch.
  Update upstream status.
- commit 692368a
* Wed Nov 30 2022 nstange@suse.de
- Add support for enabling livepatching related packages on -RT (jsc#PED-1706)
- commit 9d41244
* Wed Nov 30 2022 jslaby@suse.cz
- char: xillybus: Fix trivial bug with mutex (bsc#1205764
  CVE-2022-45888).
- char: xillybus: Prevent use-after-free due to race condition
  (bsc#1205764 CVE-2022-45888).
- char: xillybus: Fix trivial bug with mutex (bsc#1205764
  CVE-2022-45888).
- char: xillybus: Prevent use-after-free due to race condition
  (bsc#1205764 CVE-2022-45888).
- commit 8ba91a0
* Tue Nov 29 2022 afaerber@suse.com
- config: arm64: Fix Freescale LPUART dependency (boo#1204063)
  Commit 8d7f37c61a07 inserted CONFIG_SERIAL_FSL_LPUART_CONSOLE=y
  but forgot to change CONFIG_SERIAL_FSL_LPUART=m to =y as dependency,
  as the upstream Kconfig appears to be missing it for this driver.
- commit d33b52e
* Tue Nov 29 2022 jslaby@suse.cz
- Refresh
  patches.suse/ALSA-usb-audio-Remove-redundant-workaround-for-Rolan.patch.
  Update upstream status.
- commit ce72954
* Mon Nov 28 2022 tiwai@suse.de
- Refresh patches.suse/misc-sgi-gru-fix-use-after-free-error-in-gru_set_con.patch (CVE-2022-3424 bsc#1204166)
  Taken from v10 patch in char-misc subsystem tree
- commit f73b1d5
* Mon Nov 28 2022 tiwai@suse.de
- Bluetooth: L2CAP: Fix u8 overflow (CVE-2022-45934 bsc#1205796).
- commit e554413
* Mon Nov 28 2022 mkubecek@suse.cz
- Update to 6.1-rc7
- update configs
  - x86: X86_AMD_PSTATE=y (was "m")
- commit bd1d686
* Sat Nov 26 2022 jslaby@suse.cz
- Linux 6.0.10 (bsc#1012628).
- mtd: rawnand: qcom: handle ret from parse with codeword_fixup
  (bsc#1012628).
- drm/msm/gpu: Fix crash during system suspend after unbind
  (bsc#1012628).
- spi: tegra210-quad: Fix combined sequence (bsc#1012628).
- ASoC: wm5102: Revert "ASoC: wm5102: Fix PM disable depth
  imbalance in wm5102_probe" (bsc#1012628).
- ASoC: wm5110: Revert "ASoC: wm5110: Fix PM disable depth
  imbalance in wm5110_probe" (bsc#1012628).
- ASoC: wm8997: Revert "ASoC: wm8997: Fix PM disable depth
  imbalance in wm8997_probe" (bsc#1012628).
- ASoC: mt6660: Keep the pm_runtime enables before component
  stuff in mt6660_i2c_probe (bsc#1012628).
- ASoC: rt5682s: Fix the TDM Tx settings (bsc#1012628).
- ASoC: rt1019: Fix the TDM settings (bsc#1012628).
- ASoC: wm8962: Add an event handler for TEMP_HP and TEMP_SPK
  (bsc#1012628).
- spi: intel: Fix the offset to get the 64K erase opcode
  (bsc#1012628).
- ASoC: codecs: jz4725b: add missed Line In power control bit
  (bsc#1012628).
- ASoC: codecs: jz4725b: fix reported volume for Master ctl
  (bsc#1012628).
- ASoC: codecs: jz4725b: use right control for Capture Volume
  (bsc#1012628).
- ASoC: codecs: jz4725b: fix capture selector naming
  (bsc#1012628).
- ASoC: Intel: sof_sdw: add quirk variant for LAPBC710 NUC15
  (bsc#1012628).
- selftests/futex: fix build for clang (bsc#1012628).
- selftests/intel_pstate: fix build for ARCH=x86_64 (bsc#1012628).
- selftests/kexec: fix build for ARCH=x86_64 (bsc#1012628).
- ASoC: Intel: sof_rt5682: Add quirk for Rex board (bsc#1012628).
- ASoC: rt1308-sdw: add the default value of some registers
  (bsc#1012628).
- ASoC: amd: yc: Adding Lenovo ThinkBook 14 Gen 4+ ARA and Lenovo
  ThinkBook 16 Gen 4+ ARA to the Quirks List (bsc#1012628).
- ASoC: amd: yc: Add Lenovo Thinkbook 14+ 2022 21D0 to quirks
  table (bsc#1012628).
- drm/amdgpu: Adjust MES polling timeout for sriov (bsc#1012628).
- platform/x86: thinkpad_acpi: Fix reporting a non present second
  fan on some models (bsc#1012628).
- platform/x86/intel: pmc/core: Add Raptor Lake support to pmc
  core driver (bsc#1012628).
- drm/amd/display: Remove wrong pipe control lock (bsc#1012628).
- drm/amd/display: Don't return false if no stream (bsc#1012628).
- drm/scheduler: fix fence ref counting (bsc#1012628).
- ACPI: scan: Add LATT2021 to acpi_ignore_dep_ids[] (bsc#1012628).
- cxl/mbox: Add a check on input payload size (bsc#1012628).
- RDMA/efa: Add EFA 0xefa2 PCI ID (bsc#1012628).
- btrfs: raid56: properly handle the error when unable to find
  the missing stripe (bsc#1012628).
- NFSv4: Retry LOCK on OLD_STATEID during delegation return
  (bsc#1012628).
- SUNRPC: Fix crasher in gss_unwrap_resp_integ() (bsc#1012628).
- ACPI: x86: Add another system to quirk list for forcing
  StorageD3Enable (bsc#1012628).
- drm/rockchip: vop2: fix null pointer in plane_atomic_disable
  (bsc#1012628).
- drm/rockchip: vop2: disable planes when disabling the crtc
  (bsc#1012628).
- ksefltests: pidfd: Fix wait_states: Test terminated by timeout
  (bsc#1012628).
- powerpc/64e: Fix amdgpu build on Book3E w/o AltiVec
  (bsc#1012628).
- block: blk_add_rq_to_plug(): clear stale 'last' after flush
  (bsc#1012628).
- firmware: arm_scmi: Cleanup the core driver removal callback
  (bsc#1012628).
- firmware: arm_scmi: Make tx_prepare time out eventually
  (bsc#1012628).
- i2c: tegra: Allocate DMA memory for DMA engine (bsc#1012628).
- i2c: i801: add lis3lv02d's I2C address for Vostro 5568
  (bsc#1012628).
- drm/imx: imx-tve: Fix return type of
  imx_tve_connector_mode_valid (bsc#1012628).
- btrfs: remove pointless and double ulist frees in error paths
  of qgroup tests (bsc#1012628).
- drm/amd/display: Ignore Cable ID Feature (bsc#1012628).
- drm/amd/display: Enable timing sync on DCN32 (bsc#1012628).
- drm/amdgpu: set fb_modifiers_not_supported in vkms
  (bsc#1012628).
- drm/amd: Fail the suspend if resources can't be evicted
  (bsc#1012628).
- drm/amd/display: Fix DCN32 DSC delay calculation (bsc#1012628).
- drm/amd/display: Use forced DSC bpp in DML (bsc#1012628).
- drm/amd/display: Round up DST_after_scaler to nearest int
  (bsc#1012628).
- drm/amd/display: Investigate tool reported FCLK P-state
  deviations (bsc#1012628).
- Bluetooth: L2CAP: Fix l2cap_global_chan_by_psm (bsc#1012628).
- cxl/pmem: Use size_add() against integer overflow (bsc#1012628).
- x86/cpu: Add several Intel server CPU model numbers
  (bsc#1012628).
- tools/testing/cxl: Fix some error exits (bsc#1012628).
- cifs: always iterate smb sessions using primary channel
  (bsc#1012628).
- ASoC: codecs: jz4725b: Fix spelling mistake "Sourc" -> "Source",
  "Routee" -> "Route" (bsc#1012628).
- arm64/mm: fold check for KFENCE into can_set_direct_map()
  (bsc#1012628).
- arm64: fix rodata=full again (bsc#1012628).
- hugetlb: rename remove_huge_page to
  hugetlb_delete_from_page_cache (bsc#1012628).
- hugetlbfs: don't delete error page from pagecache (bsc#1012628).
- KVM: SVM: remove dead field from struct svm_cpu_data
  (bsc#1012628).
- KVM: SVM: do not allocate struct svm_cpu_data dynamically
  (bsc#1012628).
- KVM: SVM: restore host save area from assembly (bsc#1012628).
- KVM: SVM: move MSR_IA32_SPEC_CTRL save/restore to assembly
  (bsc#1012628).
- arm64: dts: qcom: ipq8074: correct APCS register space size
  (bsc#1012628).
- arm64: dts: qcom: sa8155p-adp: Specify which LDO modes are
  allowed (bsc#1012628).
- arm64: dts: qcom: sa8295p-adp: Specify which LDO modes are
  allowed (bsc#1012628).
- arm64: dts: qcom: sc8280xp-crd: Specify which LDO modes are
  allowed (bsc#1012628).
- arm64: dts: qcom: sm8150-xperia-kumano: Specify which LDO
  modes are allowed (bsc#1012628).
- arm64: dts: qcom: sm8250-xperia-edo: Specify which LDO modes
  are allowed (bsc#1012628).
- arm64: dts: qcom: sm8350-hdk: Specify which LDO modes are
  allowed (bsc#1012628).
- arm64: dts: qcom: sc8280xp: fix ufs_card_phy ref clock
  (bsc#1012628).
- arm64: dts: qcom: sc8280xp: correct ref clock for ufs_mem_phy
  (bsc#1012628).
- arm64: dts: qcom: sc8280xp: fix USB0 PHY PCS_MISC registers
  (bsc#1012628).
- arm64: dts: qcom: sc8280xp: fix USB1 PHY RX1 registers
  (bsc#1012628).
- arm64: dts: qcom: sc8280xp: fix USB PHY PCS registers
  (bsc#1012628).
- arm64: dts: qcom: sc8280xp: drop broken DP PHY nodes
  (bsc#1012628).
- arm64: dts: qcom: sc8280xp: fix UFS PHY serdes size
  (bsc#1012628).
- arm64: dts: qcom: sc7280: Add the reset reg for lpass audiocc
  on SC7280 (bsc#1012628).
- spi: stm32: Print summary 'callbacks suppressed' message
  (bsc#1012628).
- ARM: dts: at91: sama7g5: fix signal name of pin PB2
  (bsc#1012628).
- ASoC: core: Fix use-after-free in snd_soc_exit() (bsc#1012628).
- ASoC: fsl_asrc fsl_esai fsl_sai: allow CONFIG_PM=N
  (bsc#1012628).
- arm64: dts: qcom: sm8250: Disable the not yet supported cluster
  idle state (bsc#1012628).
- ASoC: tas2770: Fix set_tdm_slot in case of single slot
  (bsc#1012628).
- ASoC: tas2764: Fix set_tdm_slot in case of single slot
  (bsc#1012628).
- ASoC: tas2780: Fix set_tdm_slot in case of single slot
  (bsc#1012628).
- ARM: at91: pm: avoid soft resetting AC DLL (bsc#1012628).
- serial: 8250: omap: Fix missing PM runtime calls for
  omap8250_set_mctrl() (bsc#1012628).
- serial: 8250_omap: remove wait loop from Errata i202 workaround
  (bsc#1012628).
- serial: 8250: omap: Fix unpaired pm_runtime_put_sync() in
  omap8250_remove() (bsc#1012628).
- serial: 8250: omap: Flush PM QOS work on remove (bsc#1012628).
- tty: serial: fsl_lpuart: don't break the on-going transfer
  when global reset (bsc#1012628).
- serial: imx: Add missing .thaw_noirq hook (bsc#1012628).
- tty: n_gsm: fix sleep-in-atomic-context bug in gsm_control_send
  (bsc#1012628).
- ASoC: rt5514: fix legacy dai naming (bsc#1012628).
- ASoC: rt5677: fix legacy dai naming (bsc#1012628).
- bpf, test_run: Fix alignment problem in bpf_prog_test_run_skb()
  (bsc#1012628).
- bnxt_en: refactor bnxt_cancel_reservations() (bsc#1012628).
- bnxt_en: fix the handling of PCIE-AER (bsc#1012628).
- ASoC: soc-utils: Remove __exit for snd_soc_util_exit()
  (bsc#1012628).
- pinctrl: rockchip: list all pins in a possible mux route for
  PX30 (bsc#1012628).
- mtd: onenand: omap2: add dependency on GPMC (bsc#1012628).
- scsi: scsi_transport_sas: Fix error handling in sas_phy_add()
  (bsc#1012628).
- sctp: remove the unnecessary sinfo_stream check in
  sctp_prsctp_prune_unsent (bsc#1012628).
- sctp: clear out_curr if all frag chunks of current msg are
  pruned (bsc#1012628).
- erofs: clean up .read_folio() and .readahead() in fscache mode
  (bsc#1012628).
- erofs: get correct count for unmapped range in fscache mode
  (bsc#1012628).
- block: sed-opal: kmalloc the cmd/resp buffers (bsc#1012628).
- nfsd: put the export reference in nfsd4_verify_deleg_dentry
  (bsc#1012628).
- bpf: Fix memory leaks in __check_func_call (bsc#1012628).
- io_uring: calculate CQEs from the user visible value
  (bsc#1012628).
- pinctrl: mediatek: common-v2: Fix bias-disable for
  PULL_PU_PD_RSEL_TYPE (bsc#1012628).
- arm64: Fix bit-shifting UB in the MIDR_CPU_MODEL() macro
  (bsc#1012628).
- nvmet: fix a memory leak (bsc#1012628).
- siox: fix possible memory leak in siox_device_add()
  (bsc#1012628).
- parport_pc: Avoid FIFO port location truncation (bsc#1012628).
- selftests/bpf: Fix casting error when cross-compiling
  test_verifier for 32-bit platforms (bsc#1012628).
- selftests/bpf: Fix test_progs compilation failure in 32-bit arch
  (bsc#1012628).
- pinctrl: devicetree: fix null pointer dereferencing in
  pinctrl_dt_to_map (bsc#1012628).
- drm/vc4: kms: Fix IS_ERR() vs NULL check for vc4_kms
  (bsc#1012628).
- drm/panel: simple: set bpc field for logic technologies displays
  (bsc#1012628).
- drm/drv: Fix potential memory leak in drm_dev_init()
  (bsc#1012628).
- drm: Fix potential null-ptr-deref in drm_vblank_destroy_worker()
  (bsc#1012628).
- arm64: dts: imx8mm-tqma8mqml-mba8mx: Fix USB DR (bsc#1012628).
- ARM: dts: imx7: Fix NAND controller size-cells (bsc#1012628).
- arm64: dts: imx8mm: Fix NAND controller size-cells
  (bsc#1012628).
- erofs: put metabuf in error path in fscache mode (bsc#1012628).
- arm64: dts: imx8mn: Fix NAND controller size-cells
  (bsc#1012628).
- arm64: dts: imx93-pinfunc: drop execution permission
  (bsc#1012628).
- ata: libata-transport: fix double ata_host_put() in
  ata_tport_add() (bsc#1012628).
- ata: libata-transport: fix error handling in ata_tport_add()
  (bsc#1012628).
- ata: libata-transport: fix error handling in ata_tlink_add()
  (bsc#1012628).
- ata: libata-transport: fix error handling in ata_tdev_add()
  (bsc#1012628).
- nfp: change eeprom length to max length enumerators
  (bsc#1012628).
- MIPS: fix duplicate definitions for exported symbols
  (bsc#1012628).
- MIPS: Loongson64: Add WARN_ON on kexec related kmalloc failed
  (bsc#1012628).
- io_uring/poll: fix double poll req->flags races (bsc#1012628).
- cifs: Fix connections leak when tlink setup failed
  (bsc#1012628).
- bpf: Initialize same number of free nodes for each pcpu_freelist
  (bsc#1012628).
- ata: libata-core: do not issue non-internal commands once EH
  is pending (bsc#1012628).
- net: bgmac: Drop free_netdev() from bgmac_enet_remove()
  (bsc#1012628).
- mISDN: fix possible memory leak in mISDN_dsp_element_register()
  (bsc#1012628).
- net: hinic: Fix error handling in hinic_module_init()
  (bsc#1012628).
- net: phy: dp83867: Fix SGMII FIFO depth for non OF devices
  (bsc#1012628).
- net: stmmac: ensure tx function is not running in
  stmmac_xdp_release() (bsc#1012628).
- mctp i2c: don't count unused / invalid keys for flow release
  (bsc#1012628).
- soc: imx8m: Enable OCOTP clock before reading the register
  (bsc#1012628).
- net: liquidio: release resources when liquidio driver open
  failed (bsc#1012628).
- mISDN: fix misuse of put_device() in mISDN_register_device()
  (bsc#1012628).
- net: macvlan: Use built-in RCU list checking (bsc#1012628).
- net: caif: fix double disconnect client in chnl_net_open()
  (bsc#1012628).
- bnxt_en: Remove debugfs when pci_register_driver failed
  (bsc#1012628).
- octeon_ep: delete unnecessary napi rollback under set_queues_err
  in octep_open() (bsc#1012628).
- octeon_ep: ensure octep_get_link_status() successfully before
  octep_link_up() (bsc#1012628).
- octeon_ep: fix potential memory leak in octep_device_setup()
  (bsc#1012628).
- octeon_ep: ensure get mac address successfully before
  eth_hw_addr_set() (bsc#1012628).
- drm/lima: Fix opp clkname setting in case of missing regulator
  (bsc#1012628).
- net: mhi: Fix memory leak in mhi_net_dellink() (bsc#1012628).
- net: dsa: make dsa_master_ioctl() see through
  port_hwtstamp_get() shims (bsc#1012628).
- xen/pcpu: fix possible memory leak in register_pcpu()
  (bsc#1012628).
- erofs: fix missing xas_retry() in fscache mode (bsc#1012628).
- mlxsw: Avoid warnings when not offloaded FDB entry with IPv6
  is removed (bsc#1012628).
- net: ionic: Fix error handling in ionic_init_module()
  (bsc#1012628).
- kcm: close race conditions on sk_receive_queue (bsc#1012628).
- net: ena: Fix error handling in ena_init() (bsc#1012628).
- net: hns3: fix incorrect hw rss hash type of rx packet
  (bsc#1012628).
- net: hns3: fix return value check bug of rx copybreak
  (bsc#1012628).
- net: hns3: fix setting incorrect phy link ksettings for firmware
  in resetting process (bsc#1012628).
- bridge: switchdev: Fix memory leaks when changing VLAN protocol
  (bsc#1012628).
- drbd: use after free in drbd_create_device() (bsc#1012628).
- platform/x86/intel: pmc: Don't unconditionally attach Intel
  PMC when virtualized (bsc#1012628).
- platform/surface: aggregator: Do not check for repeated
  unsequenced packets (bsc#1012628).
- netfs: Fix missing xas_retry() calls in xarray iteration
  (bsc#1012628).
- netfs: Fix dodgy maths (bsc#1012628).
- cifs: add check for returning value of SMB2_close_init
  (bsc#1012628).
- net: ag71xx: call phylink_disconnect_phy if ag71xx_hw_enable()
  fail in ag71xx_open() (bsc#1012628).
- net/x25: Fix skb leak in x25_lapb_receive_frame() (bsc#1012628).
- net: dsa: don't leak tagger-owned storage on switch driver
  unbind (bsc#1012628).
- nvmet: fix a memory leak in nvmet_auth_set_key (bsc#1012628).
- cifs: Fix wrong return value checking when GETFLAGS
  (bsc#1012628).
- net: lan966x: Fix potential null-ptr-deref in
  lan966x_stats_init() (bsc#1012628).
- net: microchip: sparx5: Fix potential null-ptr-deref in
  sparx_stats_init() and sparx5_start() (bsc#1012628).
- net: thunderbolt: Fix error handling in tbnet_init()
  (bsc#1012628).
- s390: avoid using global register for current_stack_pointer
  (bsc#1012628).
- cifs: add check for returning value of SMB2_set_info_init
  (bsc#1012628).
- netdevsim: Fix memory leak of nsim_dev->fa_cookie (bsc#1012628).
- block: make dma_alignment a stacking queue_limit (bsc#1012628).
- dm-crypt: provide dma_alignment limit in io_hints (bsc#1012628).
- ftrace: Fix the possible incorrect kernel message (bsc#1012628).
- ftrace: Optimize the allocation for mcount entries
  (bsc#1012628).
- ftrace: Fix null pointer dereference in ftrace_add_mod()
  (bsc#1012628).
- ring_buffer: Do not deactivate non-existant pages (bsc#1012628).
- tracing: Fix memory leak in tracing_read_pipe() (bsc#1012628).
- tracing/ring-buffer: Have polling block on watermark
  (bsc#1012628).
- tracing: Fix memory leak in test_gen_synth_cmd() and
  test_empty_synth_event() (bsc#1012628).
- tracing: Fix wild-memory-access in register_synth_event()
  (bsc#1012628).
- tracing: Fix race where eprobes can be called before the event
  (bsc#1012628).
- tracing: kprobe: Fix potential null-ptr-deref on
  trace_event_file in kprobe_event_gen_test_exit() (bsc#1012628).
- tracing: kprobe: Fix potential null-ptr-deref on trace_array
  in kprobe_event_gen_test_exit() (bsc#1012628).
- rethook: fix a potential memleak in rethook_alloc()
  (bsc#1012628).
- platform/x86/amd: pmc: Remove more CONFIG_DEBUG_FS checks
  (bsc#1012628).
- platform/x86/amd: pmc: Add new ACPI ID AMDI0009 (bsc#1012628).
- drm/amd/pm: enable runpm support over BACO for SMU13.0.7
  (bsc#1012628).
- drm/amd/pm: enable runpm support over BACO for SMU13.0.0
  (bsc#1012628).
- drm/amd/pm: fix SMU13 runpm hang due to unintentional workaround
  (bsc#1012628).
- drm/display: Don't assume dual mode adaptors support i2c
  sub-addressing (bsc#1012628).
- drm/amd/display: Fix invalid DPIA AUX reply causing system hang
  (bsc#1012628).
- drm/amd/display: Add HUBP surface flip interrupt handler
  (bsc#1012628).
- drm/amd/display: Fix access timeout to DPIA AUX at boot time
  (bsc#1012628).
- drm/amd/display: Support parsing VRAM info v3.0 from VBIOS
  (bsc#1012628).
- drm/amd/display: Fix optc2_configure warning on dcn314
  (bsc#1012628).
- drm/amd/display: don't enable DRM CRTC degamma property for DCE
  (bsc#1012628).
- drm/amd/display: Fix prefetch calculations for dcn32
  (bsc#1012628).
- ALSA: usb-audio: Drop snd_BUG_ON() from
  snd_usbmidi_output_open() (bsc#1012628).
- Revert "usb: dwc3: disable USB core PHY management"
  (bsc#1012628).
- usb: dwc3: Do not get extcon device when usb-role-switch is used
  (bsc#1012628).
- io_uring: update res mask in io_poll_check_events (bsc#1012628).
- nvme-pci: add NVME_QUIRK_BOGUS_NID for Micron Nitro
  (bsc#1012628).
- nvme-pci: add NVME_QUIRK_BOGUS_NID for Netac NV7000
  (bsc#1012628).
- slimbus: qcom-ngd: Fix build error when
  CONFIG_SLIM_QCOM_NGD_CTRL=y && CONFIG_QCOM_RPROC_COMMON=m
  (bsc#1012628).
- slimbus: stream: correct presence rate frequencies
  (bsc#1012628).
- speakup: fix a segfault caused by switching consoles
  (bsc#1012628).
- speakup: replace utils' u_char with unsigned char (bsc#1012628).
- USB: bcma: Make GPIO explicitly optional (bsc#1012628).
- USB: serial: option: add Sierra Wireless EM9191 (bsc#1012628).
- USB: serial: option: remove old LARA-R6 PID (bsc#1012628).
- USB: serial: option: add u-blox LARA-R6 00B modem (bsc#1012628).
- USB: serial: option: add u-blox LARA-L6 modem (bsc#1012628).
- USB: serial: option: add Fibocom FM160 0x0111 composition
  (bsc#1012628).
- usb: add NO_LPM quirk for Realforce 87U Keyboard (bsc#1012628).
- usb: chipidea: fix deadlock in ci_otg_del_timer (bsc#1012628).
- usb: cdns3: host: fix endless superspeed hub port reset
  (bsc#1012628).
- usb: typec: mux: Enter safe mode only when pins need to be
  reconfigured (bsc#1012628).
- usb: typec: tipd: Prevent uninitialized event{1,2} in IRQ
  handler (bsc#1012628).
- iio: accel: bma400: Ensure VDDIO is enable defore reading the
  chip ID (bsc#1012628).
- iio: adc: at91_adc: fix possible memory leak in
  at91_adc_allocate_trigger() (bsc#1012628).
- iio: trigger: sysfs: fix possible memory leak in
  iio_sysfs_trig_init() (bsc#1012628).
- iio: adc: mp2629: fix wrong comparison of channel (bsc#1012628).
- iio: adc: mp2629: fix potential array out of bound access
  (bsc#1012628).
- iio: pressure: ms5611: fixed value compensation bug
  (bsc#1012628).
- iio: pressure: ms5611: changed hardcoded SPI speed to value
  limited (bsc#1012628).
- dm bufio: Fix missing decrement of no_sleep_enabled if
  dm_bufio_client_create failed (bsc#1012628).
- dm ioctl: fix misbehavior if list_versions races with module
  loading (bsc#1012628).
- serial: 8250: Fall back to non-DMA Rx if IIR_RDI occurs
  (bsc#1012628).
- serial: 8250: Flush DMA Rx on RLSI (bsc#1012628).
- serial: 8250_lpss: Configure DMA also w/o DMA filter
  (bsc#1012628).
- serial: 8250_lpss: Use 16B DMA burst with Elkhart Lake
  (bsc#1012628).
- io_uring: fix tw losing poll events (bsc#1012628).
- io_uring: fix multishot accept request leaks (bsc#1012628).
- io_uring: fix multishot recv request leaks (bsc#1012628).
- io_uring: disallow self-propelled ring polling (bsc#1012628).
- ceph: avoid putting the realm twice when decoding snaps fails
  (bsc#1012628).
- Input: iforce - invert valid length check when fetching device
  IDs (bsc#1012628).
- maccess: Fix writing offset in case of fault in
  strncpy_from_kernel_nofault() (bsc#1012628).
- net: phy: marvell: add sleep time after enabling the loopback
  bit (bsc#1012628).
- scsi: zfcp: Fix double free of FSF request when qdio send fails
  (bsc#1012628).
- iommu/vt-d: Preset Access bit for IOVA in FL non-leaf paging
  entries (bsc#1012628).
- iommu/vt-d: Set SRE bit only when hardware has SRS cap
  (bsc#1012628).
- firmware: coreboot: Register bus in module init (bsc#1012628).
- mmc: core: properly select voltage range without power cycle
  (bsc#1012628).
- mmc: sdhci-pci-o2micro: fix card detect fail issue caused by
  CD# debounce timeout (bsc#1012628).
- mmc: sdhci-pci: Fix possible memory leak caused by missing
  pci_dev_put() (bsc#1012628).
- docs: update mediator contact information in CoC doc
  (bsc#1012628).
- docs/driver-api/miscellaneous: Remove kernel-doc of
  serial_core.c (bsc#1012628).
- s390/dcssblk: fix deadlock when adding a DCSS (bsc#1012628).
- misc/vmw_vmci: fix an infoleak in
  vmci_host_do_receive_datagram() (bsc#1012628).
- blk-cgroup: properly pin the parent in blkcg_css_online
  (bsc#1012628).
- x86/sgx: Add overflow check in sgx_validate_offset_length()
  (bsc#1012628).
- x86/fpu: Drop fpregs lock before inheriting FPU permissions
  (bsc#1012628).
- perf/x86/amd/uncore: Fix memory leak for events array
  (bsc#1012628).
- perf/x86/intel/pt: Fix sampling using single range output
  (bsc#1012628).
- nvme: restrict management ioctls to admin (bsc#1012628).
- nvme: ensure subsystem reset is single threaded (bsc#1012628).
- ASoC: SOF: topology: No need to assign core ID if token parsing
  failed (bsc#1012628).
- perf: Improve missing SIGTRAP checking (bsc#1012628).
- vfio: Rename vfio_ioctl_check_extension() (bsc#1012628).
- vfio: Split the register_device ops call into functions
  (bsc#1012628).
- perf/x86/amd: Fix crash due to race between amd_pmu_enable_all,
  perf NMI and throttling (bsc#1012628).
- ring-buffer: Include dropped pages in counting dirty patches
  (bsc#1012628).
- tracing: Fix warning on variable 'struct trace_array'
  (bsc#1012628).
- net: usb: smsc95xx: fix external PHY reset (bsc#1012628).
- net: use struct_group to copy ip/ipv6 header addresses
  (bsc#1012628).
- scsi: target: tcm_loop: Fix possible name leak in
  tcm_loop_setup_hba_bus() (bsc#1012628).
- scsi: scsi_debug: Fix possible UAF in sdebug_add_host_helper()
  (bsc#1012628).
- kprobes: Skip clearing aggrprobe's post_handler in
  kprobe-on-ftrace case (bsc#1012628).
- tracing: Fix potential null-pointer-access of entry in list
  'tr->err_log' (bsc#1012628).
- arm64/mm: fix incorrect file_map_count for non-leaf pmd/pud
  (bsc#1012628).
- Input: i8042 - fix leaking of platform device on module removal
  (bsc#1012628).
- macvlan: enforce a consistent minimal mtu (bsc#1012628).
- tcp: cdg: allow tcp_cdg_release() to be called multiple times
  (bsc#1012628).
- kcm: avoid potential race in kcm_tx_work (bsc#1012628).
- KVM: x86/xen: Fix eventfd error handling in
  kvm_xen_eventfd_assign() (bsc#1012628).
- 9p: trans_fd/p9_conn_cancel: drop client lock earlier
  (bsc#1012628).
- gfs2: Check sb_bsize_shift after reading superblock
  (bsc#1012628).
- gfs2: Switch from strlcpy to strscpy (bsc#1012628).
- 9p/trans_fd: always use O_NONBLOCK read/write (bsc#1012628).
- netlink: Bounds-check struct nlmsgerr creation (bsc#1012628).
- wifi: wext: use flex array destination for memcpy()
  (bsc#1012628).
- rseq: Use pr_warn_once() when deprecated/unknown ABI flags
  are encountered (bsc#1012628).
- mm: fs: initialize fsdata passed to write_begin/write_end
  interface (bsc#1012628).
- net/9p: use a dedicated spinlock for trans_fd (bsc#1012628).
- bpf: Prevent bpf program recursion for raw tracepoint probes
  (bsc#1012628).
- ntfs: fix use-after-free in ntfs_attr_find() (bsc#1012628).
- ntfs: fix out-of-bounds read in ntfs_attr_find() (bsc#1012628).
- ntfs: check overflow when iterating ATTR_RECORDs (bsc#1012628).
- commit 582305b
* Thu Nov 24 2022 mbrugger@suse.com
- scripts/git_sort/git_sort.py: Add arm-soc for-next tree.
- commit 011aefb
* Wed Nov 23 2022 mbrugger@suse.com
- arm64: Update config files.
  Enable configs for tegra234 serial console to work.
- commit 64cc6c4
* Wed Nov 23 2022 dmueller@suse.com
- config.conf: enable armv6/armv7hl configs
- armv6/7hl: Update config files.
- commit 93e7e5c
* Mon Nov 21 2022 mkubecek@suse.cz
- Update to 6.1-rc6
- eliminate 1 patch
  - patches.suse/Input-i8042-Apply-probe-defer-to-more-ASUS-ZenBook-m.patch
- update configs
  - INET_TABLE_PERTURB_ORDER=16 (default, previous value)
- commit 4c01546
* Thu Nov 17 2022 tiwai@suse.de
- soundwire: intel: Initialize clock stop timeout (bsc#1205507).
- commit 699b9c2
* Wed Nov 16 2022 jslaby@suse.cz
- Update
  patches.kernel.org/6.0.9-191-x86-cpu-Restore-AMD-s-DE_CFG-MSR-after-resume.patch
  (bsc#1012628 bsc#1205473).
  Add a bsc #.
- commit 3e12b42
* Wed Nov 16 2022 jslaby@suse.cz
- Linux 6.0.9 (bsc#1012628).
- thunderbolt: Add DP OUT resource when DP tunnel is discovered
  (bsc#1012628).
- drm/i915/gvt: Add missing vfio_unregister_group_dev() call
  (bsc#1012628).
- m68k: Rework BI_VIRT_RNG_SEED as BI_RNG_SEED (bsc#1012628).
- KVM: debugfs: Return retval of simple_attr_open() if it fails
  (bsc#1012628).
- drm/i915: Allow more varied alternate fixed modes for panels
  (bsc#1012628).
- drm/i915: Simplify intel_panel_add_edid_alt_fixed_modes()
  (bsc#1012628).
- drm/i915/sdvo: Grab mode_config.mutex during LVDS init to
  avoid WARNs (bsc#1012628).
- drm/amd/display: Acquire FCLK DPM levels on DCN32 (bsc#1012628).
- drm/amd/display: Limit dcn32 to 1950Mhz display clock
  (bsc#1012628).
- drm/amd/display: Set memclk levels to be at least 1 for dcn32
  (bsc#1012628).
- drm/amdkfd: handle CPU fault on COW mapping (bsc#1012628).
- drm/amdkfd: Fix NULL pointer dereference in svm_migrate_to_ram()
  (bsc#1012628).
- cxl/region: Recycle region ids (bsc#1012628).
- HID: wacom: Fix logic used for 3rd barrel switch emulation
  (bsc#1012628).
- hwspinlock: qcom: correct MMIO max register for newer SoCs
  (bsc#1012628).
- phy: stm32: fix an error code in probe (bsc#1012628).
- wifi: cfg80211: silence a sparse RCU warning (bsc#1012628).
- wifi: cfg80211: fix memory leak in query_regdb_file()
  (bsc#1012628).
- soundwire: qcom: reinit broadcast completion (bsc#1012628).
- soundwire: qcom: check for outanding writes before doing a read
  (bsc#1012628).
- ALSA: arm: pxa: pxa2xx-ac97-lib: fix return value check of
  platform_get_irq() (bsc#1012628).
- spi: mediatek: Fix package division error (bsc#1012628).
- bpf, verifier: Fix memory leak in array reallocation for stack
  state (bsc#1012628).
- bpf, sockmap: Fix the sk->sk_forward_alloc warning of
  sk_stream_kill_queues (bsc#1012628).
- wifi: mac80211: fix general-protection-fault in
  ieee80211_subif_start_xmit() (bsc#1012628).
- wifi: mac80211: Set TWT Information Frame Disabled bit as 1
  (bsc#1012628).
- bpftool: Fix NULL pointer dereference when pin {PROG, MAP,
  LINK} without FILE (bsc#1012628).
- HID: hyperv: fix possible memory leak in mousevsc_probe()
  (bsc#1012628).
- drm/vc4: hdmi: Fix HSM clock too low on Pi4 (bsc#1012628).
- bpf, sock_map: Move cancel_work_sync() out of sock lock
  (bsc#1012628).
- PCI: hv: Fix the definition of vector in hv_compose_msi_msg()
  (bsc#1012628).
- bpf: Add helper macro bpf_for_each_reg_in_vstate (bsc#1012628).
- bpf: Fix wrong reg type conversion in release_reference()
  (bsc#1012628).
- net: gso: fix panic on frag_list with mixed head alloc types
  (bsc#1012628).
- macsec: delete new rxsc when offload fails (bsc#1012628).
- macsec: fix secy->n_rx_sc accounting (bsc#1012628).
- macsec: fix detection of RXSCs when toggling offloading
  (bsc#1012628).
- macsec: clear encryption keys from the stack after setting up
  offload (bsc#1012628).
- octeontx2-pf: NIX TX overwrites SQ_CTX_HW_S[SQ_INT]
  (bsc#1012628).
- net: tun: Fix memory leaks of napi_get_frags (bsc#1012628).
- bnxt_en: Fix possible crash in bnxt_hwrm_set_coal()
  (bsc#1012628).
- bnxt_en: fix potentially incorrect return value for
  ndo_rx_flow_steer (bsc#1012628).
- net: fman: Unregister ethernet device on removal (bsc#1012628).
- capabilities: fix undefined behavior in bit shift for
  CAP_TO_MASK (bsc#1012628).
- phy: ralink: mt7621-pci: add sentinel to quirks table
  (bsc#1012628).
- KVM: s390: pv: don't allow userspace to set the clock under PV
  (bsc#1012628).
- KVM: s390: pci: Fix allocation size of aift kzdev elements
  (bsc#1012628).
- net: lapbether: fix issue of dev reference count leakage in
  lapbeth_device_event() (bsc#1012628).
- hamradio: fix issue of dev reference count leakage in
  bpq_device_event() (bsc#1012628).
- net: wwan: iosm: fix memory leak in ipc_wwan_dellink
  (bsc#1012628).
- net: wwan: mhi: fix memory leak in mhi_mbim_dellink
  (bsc#1012628).
- drm/vc4: Fix missing platform_unregister_drivers() call in
  vc4_drm_register() (bsc#1012628).
- tcp: prohibit TCP_REPAIR_OPTIONS if data was already sent
  (bsc#1012628).
- platform/x86: p2sb: Don't fail if unknown CPU is found
  (bsc#1012628).
- ipv6: addrlabel: fix infoleak when sending struct ifaddrlblmsg
  to network (bsc#1012628).
- can: af_can: fix NULL pointer dereference in can_rx_register()
  (bsc#1012628).
- drm/i915/psr: Send update also on invalidate (bsc#1012628).
- drm/i915: Do not set cache_dirty for DGFX (bsc#1012628).
- net: stmmac: dwmac-meson8b: fix
  meson8b_devm_clk_prepare_enable() (bsc#1012628).
- dt-bindings: net: tsnep: Fix typo on generic nvmem property
  (bsc#1012628).
- net: broadcom: Fix BCMGENET Kconfig (bsc#1012628).
- tipc: fix the msg->req tlv len check in
  tipc_nl_compat_name_table_dump_header (bsc#1012628).
- dmaengine: pxa_dma: use platform_get_irq_optional (bsc#1012628).
- dmanegine: idxd: reformat opcap output to match bitmap_parse()
  input (bsc#1012628).
- dmaengine: idxd: Fix max batch size for Intel IAA (bsc#1012628).
- dmaengine: idxd: fix RO device state error after been
  disabled/reset (bsc#1012628).
- dmaengine: apple-admac: Fix grabbing of channels in of_xlate
  (bsc#1012628).
- dmaengine: mv_xor_v2: Fix a resource leak in mv_xor_v2_remove()
  (bsc#1012628).
- dmaengine: ti: k3-udma-glue: fix memory leak when register
  device fail (bsc#1012628).
- dmaengine: stm32-dma: fix potential race between pause and
  resume (bsc#1012628).
- net: lapbether: fix issue of invalid opcode in lapbeth_open()
  (bsc#1012628).
- net: ethernet: mtk-star-emac: disable napi when connect and
  start PHY failed in mtk_star_enable() (bsc#1012628).
- octeontx2-pf: Fix SQE threshold checking (bsc#1012628).
- drivers: net: xgene: disable napi when register irq failed in
  xgene_enet_open() (bsc#1012628).
- perf stat: Fix crash with --per-node --metric-only in CSV mode
  (bsc#1012628).
- perf stat: Fix printing os->prefix in CSV metrics output
  (bsc#1012628).
- perf test: Fix skipping branch stack sampling test
  (bsc#1012628).
- perf tools: Add the include/perf/ directory to .gitignore
  (bsc#1012628).
- netfilter: nfnetlink: fix potential dead lock in
  nfnetlink_rcv_msg() (bsc#1012628).
- netfilter: Cleanup nft_net->module_list from
  nf_tables_exit_net() (bsc#1012628).
- net: marvell: prestera: fix memory leak in
  prestera_rxtx_switch_init() (bsc#1012628).
- net: tun: call napi_schedule_prep() to ensure we own a napi
  (bsc#1012628).
- net: nixge: disable napi when enable interrupts failed in
  nixge_open() (bsc#1012628).
- net: wwan: iosm: fix memory leak in ipc_pcie_read_bios_cfg
  (bsc#1012628).
- net: wwan: iosm: fix invalid mux header type (bsc#1012628).
- net/mlx5: Bridge, verify LAG state when adding bond to bridge
  (bsc#1012628).
- net/mlx5: Allow async trigger completion execution on single
  CPU systems (bsc#1012628).
- net/mlx5: E-switch, Set to legacy mode if failed to change
  switchdev mode (bsc#1012628).
- net/mlx5: fw_reset: Don't try to load device in case PCI isn't
  working (bsc#1012628).
- net/mlx5e: Add missing sanity checks for max TX WQE size
  (bsc#1012628).
- net/mlx5e: Fix tc acts array not to be dependent on enum order
  (bsc#1012628).
- net/mlx5e: TC, Fix wrong rejection of packet-per-second policing
  (bsc#1012628).
- net/mlx5e: E-Switch, Fix comparing termination table instance
  (bsc#1012628).
- ice: Fix spurious interrupt during removal of trusted VF
  (bsc#1012628).
- iavf: Fix VF driver counting VLAN 0 filters (bsc#1012628).
- net: cpsw: disable napi in cpsw_ndo_open() (bsc#1012628).
- net: cxgb3_main: disable napi when bind qsets failed in
  cxgb_up() (bsc#1012628).
- stmmac: intel: Update PCH PTP clock rate from 200MHz to 204.8MHz
  (bsc#1012628).
- mctp: Fix an error handling path in mctp_init() (bsc#1012628).
- cxgb4vf: shut down the adapter when t4vf_update_port_info()
  failed in cxgb4vf_open() (bsc#1012628).
- stmmac: dwmac-loongson: fix missing pci_disable_msi() while
  module exiting (bsc#1012628).
- stmmac: dwmac-loongson: fix missing pci_disable_device()
  in loongson_dwmac_probe() (bsc#1012628).
- stmmac: dwmac-loongson: fix missing of_node_put() while module
  exiting (bsc#1012628).
- net: phy: mscc: macsec: clear encryption keys when freeing a
  flow (bsc#1012628).
- net: atlantic: macsec: clear encryption keys from the stack
  (bsc#1012628).
- ethernet: s2io: disable napi when start nic failed in
  s2io_card_up() (bsc#1012628).
- net: mv643xx_eth: disable napi when init rxq or txq failed in
  mv643xx_eth_open() (bsc#1012628).
- ALSA: memalloc: Don't fall back for SG-buffer with IOMMU
  (bsc#1012628).
- ethernet: tundra: free irq when alloc ring failed in
  tsi108_open() (bsc#1012628).
- net: macvlan: fix memory leaks of macvlan_common_newlink
  (bsc#1012628).
- riscv: process: fix kernel info leakage (bsc#1012628).
- riscv: vdso: fix build with llvm (bsc#1012628).
- riscv: fix reserved memory setup (bsc#1012628).
- eth: sp7021: drop free_netdev() from spl2sw_init_netdev()
  (bsc#1012628).
- arm64: efi: Fix handling of misaligned runtime regions and
  drop warning (bsc#1012628).
- MIPS: jump_label: Fix compat branch range check (bsc#1012628).
- drm/amdgpu: Fix the lpfn checking condition in drm buddy
  (bsc#1012628).
- mmc: cqhci: Provide helper for resetting both SDHCI and CQHCI
  (bsc#1012628).
- mmc: sdhci-of-arasan: Fix SDHCI_RESET_ALL for CQHCI
  (bsc#1012628).
- mmc: sdhci-brcmstb: Fix SDHCI_RESET_ALL for CQHCI (bsc#1012628).
- mmc: sdhci_am654: Fix SDHCI_RESET_ALL for CQHCI (bsc#1012628).
- mmc: sdhci-tegra: Fix SDHCI_RESET_ALL for CQHCI (bsc#1012628).
- mmc: sdhci-esdhc-imx: use the correct host caps for
  MMC_CAP_8_BIT_DATA (bsc#1012628).
- ALSA: hda/hdmi - enable runtime pm for more AMD display audio
  (bsc#1012628).
- ALSA: hda/ca0132: add quirk for EVGA Z390 DARK (bsc#1012628).
- ALSA: hda: fix potential memleak in 'add_widget_node'
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ASUS Zenbook using CS35L41
  (bsc#1012628).
- ALSA: hda/realtek: Add Positivo C6300 model quirk (bsc#1012628).
- ALSA: usb-audio: Add quirk entry for M-Audio Micro
  (bsc#1012628).
- ALSA: usb-audio: Add DSD support for Accuphase DAC-60
  (bsc#1012628).
- vmlinux.lds.h: Fix placement of '.data..decrypted' section
  (bsc#1012628).
- ata: libata-scsi: fix SYNCHRONIZE CACHE (16) command failure
  (bsc#1012628).
- nilfs2: fix deadlock in nilfs_count_free_blocks() (bsc#1012628).
- nilfs2: fix use-after-free bug of ns_writer on remount
  (bsc#1012628).
- drm/i915/dmabuf: fix sg_table handling in map_dma_buf
  (bsc#1012628).
- drm/amd/display: Fix reg timeout in enc314_enable_fifo
  (bsc#1012628).
- drm/amd/pm: update SMU IP v13.0.4 msg interface header
  (bsc#1012628).
- drm/amd/display: Update SR watermarks for DCN314 (bsc#1012628).
- drm/amdgpu: workaround for TLB seq race (bsc#1012628).
- drm/amdgpu: disable BACO on special BEIGE_GOBY card
  (bsc#1012628).
- drm/amdkfd: Fix error handling in criu_checkpoint (bsc#1012628).
- drm/amdkfd: Fix error handling in kfd_criu_restore_events
  (bsc#1012628).
- platform/x86: hp_wmi: Fix rfkill causing soft blocked wifi
  (bsc#1012628).
- wifi: ath11k: avoid deadlock during regulatory update in
  ath11k_regd_update() (bsc#1012628).
- btrfs: fix match incorrectly in dev_args_match_device
  (bsc#1012628).
- btrfs: selftests: fix wrong error check in
  btrfs_free_dummy_root() (bsc#1012628).
- btrfs: zoned: clone zoned device info when cloning a device
  (bsc#1012628).
- btrfs: zoned: initialize device's zone info for seeding
  (bsc#1012628).
- io_uring: check for rollover of buffer ID when providing buffers
  (bsc#1012628).
- phy: qcom-qmp-combo: fix NULL-deref on runtime resume
  (bsc#1012628).
- net: ethernet: ti: am65-cpsw: Fix segmentation fault at module
  unload (bsc#1012628).
- mms: sdhci-esdhc-imx: Fix SDHCI_RESET_ALL for CQHCI
  (bsc#1012628).
- udf: Fix a slab-out-of-bounds write bug in udf_find_entry()
  (bsc#1012628).
- spi: intel: Use correct mask for flash and protected regions
  (bsc#1012628).
- arch/x86/mm/hugetlbpage.c: pud_huge() returns 0 when using
  2-level paging (bsc#1012628).
- mm: hugetlb_vmemmap: include missing linux/moduleparam.h
  (bsc#1012628).
- dmaengine: idxd: Do not enable user type Work Queue without
  Shared Virtual Addressing (bsc#1012628).
- mm/damon/dbgfs: check if rm_contexts input is for a real context
  (bsc#1012628).
- mm/memremap.c: map FS_DAX device memory as decrypted
  (bsc#1012628).
- mm/shmem: use page_mapping() to detect page cache for uffd
  continue (bsc#1012628).
- can: j1939: j1939_send_one(): fix missing CAN header
  initialization (bsc#1012628).
- can: isotp: fix tx state handling for echo tx processing
  (bsc#1012628).
- can: rcar_canfd: Add missing ECC error checks for channels 2-7
  (bsc#1012628).
- KVM: x86/mmu: Block all page faults during kvm_zap_gfn_range()
  (bsc#1012628).
- KVM: x86/pmu: Do not speculatively query Intel GP PMCs that
  don't exist yet (bsc#1012628).
- KVM: x86: use a separate asm-offsets.c file (bsc#1012628).
- KVM: SVM: replace regs argument of __svm_vcpu_run() with
  vcpu_svm (bsc#1012628).
- KVM: SVM: adjust register allocation for __svm_vcpu_run()
  (bsc#1012628).
- KVM: SVM: Only dump VMSA to klog at KERN_DEBUG level
  (bsc#1012628).
- KVM: SVM: retrieve VMCB from assembly (bsc#1012628).
- KVM: SVM: move guest vmsave/vmload back to assembly
  (bsc#1012628).
- can: dev: fix skb drop check (bsc#1012628).
- dmaengine: at_hdmac: Fix at_lli struct definition (bsc#1012628).
- dmaengine: at_hdmac: Don't start transactions at tx_submit level
  (bsc#1012628).
- dmaengine: at_hdmac: Start transfer for cyclic channels in
  issue_pending (bsc#1012628).
- dmaengine: at_hdmac: Fix premature completion of desc in
  issue_pending (bsc#1012628).
- dmaengine: at_hdmac: Do not call the complete callback on
  device_terminate_all (bsc#1012628).
- dmaengine: at_hdmac: Protect atchan->status with the channel
  lock (bsc#1012628).
- dmaengine: at_hdmac: Fix concurrency problems by removing
  atc_complete_all() (bsc#1012628).
- dmaengine: at_hdmac: Fix concurrency over descriptor
  (bsc#1012628).
- dmaengine: at_hdmac: Free the memset buf without holding the
  chan lock (bsc#1012628).
- dmaengine: at_hdmac: Fix concurrency over the active list
  (bsc#1012628).
- dmaengine: at_hdmac: Fix descriptor handling when issuing it
  to hardware (bsc#1012628).
- dmaengine: at_hdmac: Fix completion of unissued descriptor in
  case of errors (bsc#1012628).
- dmaengine: at_hdmac: Don't allow CPU to reorder channel enable
  (bsc#1012628).
- dmaengine: at_hdmac: Fix impossible condition (bsc#1012628).
- dmaengine: at_hdmac: Check return code of
  dma_async_device_register (bsc#1012628).
- drm/amdkfd: Migrate in CPU page fault use current mm
  (bsc#1012628).
- ALSA: memalloc: Try dma_alloc_noncontiguous() at first
  (bsc#1012628).
- x86/cpu: Restore AMD's DE_CFG MSR after resume (bsc#1012628).
- commit 9c9388f
* Tue Nov 15 2022 tiwai@suse.de
- ALSA: hda/realtek: Fix the speaker output on Samsung Galaxy
  Book Pro 360 (bsc#1205100).
- ALSA: hda/realtek: fix speakers for Samsung Galaxy Book Pro
  (bsc#1205100).
- commit 218191a
* Tue Nov 15 2022 msuchanek@suse.de
- Update config files (bsc#1205447).
  INTEGRITY_MACHINE_KEYRING=y
  IMA_KEYRINGS_PERMIT_SIGNED_BY_BUILTIN_OR_SECONDARY=n
- commit bbfbe90
* Mon Nov 14 2022 mkubecek@suse.cz
- Update to 6.1-rc5
- update configs
  - CONFIG_DRM_RCAR_USE_MIPI_DSI=n (y on arm64, like DRM_RCAR_MIPI_DSI)
  - IOSM=n (except x86)
  - TEST_MAPLE_TREE=n
  - s390x/zfcpdump: RANDOMIZE_BASE=n
- commit 4b98107
* Fri Nov 11 2022 jslaby@suse.cz
- Linux 6.0.8 (bsc#1012628).
- usb: dwc3: gadget: Force sending delayed status during soft
  disconnect (bsc#1012628).
- usb: dwc3: gadget: Don't delay End Transfer on delayed_status
  (bsc#1012628).
- RDMA/cma: Use output interface for net_dev check (bsc#1012628).
- IB/hfi1: Correctly move list in sc_disable() (bsc#1012628).
- RDMA/hns: Disable local invalidate operation (bsc#1012628).
- RDMA/hns: Fix NULL pointer problem in free_mr_init()
  (bsc#1012628).
- docs/process/howto: Replace C89 with C11 (bsc#1012628).
- RDMA/rxe: Fix mr leak in RESPST_ERR_RNR (bsc#1012628).
- NFSv4: Fix a potential state reclaim deadlock (bsc#1012628).
- NFSv4.1: Handle RECLAIM_COMPLETE trunking errors (bsc#1012628).
- NFSv4.1: We must always send RECLAIM_COMPLETE after a reboot
  (bsc#1012628).
- SUNRPC: Fix null-ptr-deref when xps sysfs alloc failed
  (bsc#1012628).
- NFSv4.2: Fixup CLONE dest file size for zero-length count
  (bsc#1012628).
- nfs4: Fix kmemleak when allocate slot failed (bsc#1012628).
- net: dsa: Fix possible memory leaks in dsa_loop_init()
  (bsc#1012628).
- RDMA/core: Fix null-ptr-deref in ib_core_cleanup()
  (bsc#1012628).
- RDMA/qedr: clean up work queue on failure in
  qedr_alloc_resources() (bsc#1012628).
- tools/nolibc: Fix missing strlen() definition and infinite
  loop with gcc-12 (bsc#1012628).
- net: dsa: fall back to default tagger if we can't load the
  one from DT (bsc#1012628).
- nfc: fdp: Fix potential memory leak in fdp_nci_send()
  (bsc#1012628).
- nfc: nxp-nci: Fix potential memory leak in nxp_nci_send()
  (bsc#1012628).
- nfc: s3fwrn5: Fix potential memory leak in s3fwrn5_nci_send()
  (bsc#1012628).
- nfc: nfcmrvl: Fix potential memory leak in
  nfcmrvl_i2c_nci_send() (bsc#1012628).
- net: fec: fix improper use of NETDEV_TX_BUSY (bsc#1012628).
- ata: pata_legacy: fix pdc20230_set_piomode() (bsc#1012628).
- ata: palmld: fix return value check in palmld_pata_probe()
  (bsc#1012628).
- net: sched: Fix use after free in red_enqueue() (bsc#1012628).
- net: tun: fix bugs for oversize packet when napi frags enabled
  (bsc#1012628).
- netfilter: nf_tables: netlink notifier might race to release
  objects (bsc#1012628).
- netfilter: nf_tables: release flow rule object from commit path
  (bsc#1012628).
- sfc: Fix an error handling path in efx_pci_probe()
  (bsc#1012628).
- nfsd: fix nfsd_file_unhash_and_dispose (bsc#1012628).
- nfsd: fix net-namespace logic in __nfsd_file_cache_purge
  (bsc#1012628).
- net: lan966x: Fix the MTU calculation (bsc#1012628).
- net: lan966x: Adjust maximum frame size when vlan is
  enabled/disabled (bsc#1012628).
- net: lan966x: Fix FDMA when MTU is changed (bsc#1012628).
- net: lan966x: Fix unmapping of received frames using FDMA
  (bsc#1012628).
- ipvs: use explicitly signed chars (bsc#1012628).
- ipvs: fix WARNING in __ip_vs_cleanup_batch() (bsc#1012628).
- ipvs: fix WARNING in ip_vs_app_net_cleanup() (bsc#1012628).
- rose: Fix NULL pointer dereference in rose_send_frame()
  (bsc#1012628).
- mISDN: fix possible memory leak in mISDN_register_device()
  (bsc#1012628).
- isdn: mISDN: netjet: fix wrong check of device registration
  (bsc#1012628).
- btrfs: fix inode list leak during backref walking at
  resolve_indirect_refs() (bsc#1012628).
- btrfs: fix inode list leak during backref walking at
  find_parent_nodes() (bsc#1012628).
- btrfs: fix ulist leaks in error paths of qgroup self tests
  (bsc#1012628).
- netfilter: ipset: enforce documented limit to prevent allocating
  huge memory (bsc#1012628).
- Bluetooth: L2CAP: Fix use-after-free caused by
  l2cap_reassemble_sdu (bsc#1012628).
- Bluetooth: hci_conn: Fix CIS connection dst_type handling
  (bsc#1012628).
- Bluetooth: virtio_bt: Use skb_put to set length (bsc#1012628).
- Bluetooth: L2CAP: Fix memory leak in vhci_write (bsc#1012628).
- Bluetooth: hci_conn: Fix not restoring ISO buffer count on
  disconnect (bsc#1012628).
- net: mdio: fix undefined behavior in bit shift for
  __mdiobus_register (bsc#1012628).
- ibmvnic: Free rwi on reset success (bsc#1012628).
- stmmac: dwmac-loongson: fix invalid mdio_node (bsc#1012628).
- net/smc: Fix possible leaked pernet namespace in smc_init()
  (bsc#1012628).
- net, neigh: Fix null-ptr-deref in neigh_table_clear()
  (bsc#1012628).
- bridge: Fix flushing of dynamic FDB entries (bsc#1012628).
- ipv6: fix WARNING in ip6_route_net_exit_late() (bsc#1012628).
- vsock: fix possible infinite sleep in
  vsock_connectible_wait_data() (bsc#1012628).
- iio: adc: stm32-adc: fix channel sampling time init
  (bsc#1012628).
- media: rkisp1: Fix source pad format configuration
  (bsc#1012628).
- media: rkisp1: Don't pass the quantization to
  rkisp1_csm_config() (bsc#1012628).
- media: rkisp1: Initialize color space on resizer sink and
  source pads (bsc#1012628).
- media: rkisp1: Use correct macro for gradient registers
  (bsc#1012628).
- media: rkisp1: Zero v4l2_subdev_format fields in when validating
  links (bsc#1012628).
- media: s5p_cec: limit msg.len to CEC_MAX_MSG_SIZE (bsc#1012628).
- media: cros-ec-cec: limit msg.len to CEC_MAX_MSG_SIZE
  (bsc#1012628).
- media: dvb-frontends/drxk: initialize err to 0 (bsc#1012628).
- media: platform: cros-ec: Add Kuldax to the match table
  (bsc#1012628).
- media: meson: vdec: fix possible refcount leak in vdec_probe()
  (bsc#1012628).
- media: hantro: Store HEVC bit depth in context (bsc#1012628).
- media: hantro: HEVC: Fix auxilary buffer size calculation
  (bsc#1012628).
- media: hantro: HEVC: Fix chroma offset computation
  (bsc#1012628).
- media: v4l: subdev: Fail graciously when getting try data for
  NULL state (bsc#1012628).
- drm/vc4: hdmi: Check the HSM rate at runtime_resume
  (bsc#1012628).
- ACPI: APEI: Fix integer overflow in ghes_estatus_pool_init()
  (bsc#1012628).
- hwrng: bcm2835 - use hwrng_msleep() instead of cpu_relax()
  (bsc#1012628).
- io_uring: don't iopoll from io_ring_ctx_wait_and_kill()
  (bsc#1012628).
- scsi: core: Restrict legal sdev_state transitions via sysfs
  (bsc#1012628).
- HID: saitek: add madcatz variant of MMO7 mouse device ID
  (bsc#1012628).
- drm/amdgpu: set vm_update_mode=0 as default for Sienna Cichlid
  in SRIOV case (bsc#1012628).
- drm/amd/pm: skip loading pptable from driver on secure board
  for smu_v13_0_10 (bsc#1012628).
- drm/amdkfd: Fix type of reset_type parameter in hqd_destroy()
  callback (bsc#1012628).
- drm/amdgpu: Program GC registers through RLCG interface in
  gfx_v11/gmc_v11 (bsc#1012628).
- drm/amdgpu: dequeue mes scheduler during fini (bsc#1012628).
- nvme-pci: disable write zeroes on various Kingston SSD
  (bsc#1012628).
- i2c: xiic: Add platform module alias (bsc#1012628).
- bio: safeguard REQ_ALLOC_CACHE bio put (bsc#1012628).
- clk: rs9: Fix I2C accessors (bsc#1012628).
- arm64: dts: imx8mm: Enable CPLD_Dn pull down resistor on
  MX8Menlo (bsc#1012628).
- efi/tpm: Pass correct address to memblock_reserve (bsc#1012628).
- clk: renesas: r8a779g0: Fix HSCIF parent clocks (bsc#1012628).
- clk: qcom: Update the force mem core bit for GPU clocks
  (bsc#1012628).
- arm64: dts: verdin-imx8mp: fix ctrl_sleep_moci (bsc#1012628).
- arm64: dts: imx8mm: remove otg1/2 power domain dependency on
  hsio (bsc#1012628).
- arm64: dts: imx8mm: correct usb power domains (bsc#1012628).
- arm64: dts: imx8mn: remove otg1 power domain dependency on hsio
  (bsc#1012628).
- arm64: dts: imx8mn: Correct the usb power domain (bsc#1012628).
- ARM: dts: imx6qdl-gw59{10,13}: fix user pushbutton GPIO offset
  (bsc#1012628).
- arm64: dts: imx8: correct clock order (bsc#1012628).
- arm64: dts: imx93: add gpio clk (bsc#1012628).
- arm64: dts: imx93: correct gpio-ranges (bsc#1012628).
- arm64: dts: lx2160a: specify clock frequencies for the MDIO
  controllers (bsc#1012628).
- arm64: dts: ls1088a: specify clock frequencies for the MDIO
  controllers (bsc#1012628).
- arm64: dts: ls208xa: specify clock frequencies for the MDIO
  controllers (bsc#1012628).
- drm/rockchip: dw_hdmi: filter regulator -EPROBE_DEFER error
  messages (bsc#1012628).
- drm/rockchip: fix fbdev on non-IOMMU devices (bsc#1012628).
- drm/i915: stop abusing swiotlb_max_segment (bsc#1012628).
- ublk_drv: return flag of UBLK_F_URING_CMD_COMP_IN_TASK in case
  of module (bsc#1012628).
- block: Fix possible memory leak for rq_wb on add_disk failure
  (bsc#1012628).
- blk-mq: Fix kmemleak in blk_mq_init_allocated_queue
  (bsc#1012628).
- ARM: dts: ux500: Add trips to battery thermal zones
  (bsc#1012628).
- firmware: arm_scmi: Suppress the driver's bind attributes
  (bsc#1012628).
- firmware: arm_scmi: Make Rx chan_setup fail on memory errors
  (bsc#1012628).
- firmware: arm_scmi: Fix devres allocation device in virtio
  transport (bsc#1012628).
- firmware: arm_scmi: Fix deferred_tx_wq release on error paths
  (bsc#1012628).
- arm64: dts: juno: Add thermal critical trip points
  (bsc#1012628).
- i2c: piix4: Fix adapter not be removed in piix4_remove()
  (bsc#1012628).
- Bluetooth: L2CAP: Fix accepting connection request for invalid
  SPSM (bsc#1012628).
- Bluetooth: L2CAP: Fix attempting to access uninitialized memory
  (bsc#1012628).
- fscrypt: stop using keyrings subsystem for fscrypt_master_key
  (bsc#1012628).
- fscrypt: fix keyring memory leak on mount failure (bsc#1012628).
- clk: renesas: r8a779g0: Add SASYNCPER clocks (bsc#1012628).
- btrfs: fix lost file sync on direct IO write with nowait and
  dsync iocb (bsc#1012628).
- btrfs: fix tree mod log mishandling of reallocated nodes
  (bsc#1012628).
- btrfs: fix type of parameter generation in btrfs_get_dentry
  (bsc#1012628).
- btrfs: don't use btrfs_chunk::sub_stripes from disk
  (bsc#1012628).
- btrfs: fix a memory allocation failure test in
  btrfs_submit_direct (bsc#1012628).
- ACPI: NUMA: Add CXL CFMWS 'nodes' to the possible nodes set
  (bsc#1012628).
- cxl/pmem: Fix cxl_pmem_region and cxl_memdev leak (bsc#1012628).
- cxl/region: Fix decoder allocation crash (bsc#1012628).
- cxl/region: Fix region HPA ordering validation (bsc#1012628).
- cxl/region: Fix cxl_region leak, cleanup targets at region
  delete (bsc#1012628).
- cxl/region: Fix 'distance' calculation with passthrough ports
  (bsc#1012628).
- ftrace: Fix use-after-free for dynamic ftrace_ops (bsc#1012628).
- tracing/fprobe: Fix to check whether fprobe is registered
  correctly (bsc#1012628).
- fprobe: Check rethook_alloc() return in rethook initialization
  (bsc#1012628).
- tracing: kprobe: Fix memory leak in
  test_gen_kprobe/kretprobe_cmd() (bsc#1012628).
- kprobe: reverse kp->flags when arm_kprobe failed (bsc#1012628).
- tools/nolibc/string: Fix memcmp() implementation (bsc#1012628).
- tracing/histogram: Update document for KEYS_MAX size
  (bsc#1012628).
- capabilities: fix potential memleak on error path from
  vfs_getxattr_alloc() (bsc#1012628).
- fuse: add file_modified() to fallocate (bsc#1012628).
- fuse: fix readdir cache race (bsc#1012628).
- selftests/landlock: Build without static libraries
  (bsc#1012628).
- efi: random: reduce seed size to 32 bytes (bsc#1012628).
- efi: random: Use 'ACPI reclaim' memory for random seed
  (bsc#1012628).
- efi: efivars: Fix variable writes with unsupported
  query_variable_store() (bsc#1012628).
- net/ulp: remove SOCK_SUPPORT_ZC from tls sockets (bsc#1012628).
- arm64: entry: avoid kprobe recursion (bsc#1012628).
- ARM: dts: imx6dl-yapp4: Do not allow PM to switch PU regulator
  off on Q/QP (bsc#1012628).
- perf/x86/intel: Fix pebs event constraints for ICL
  (bsc#1012628).
- perf/x86/intel: Add Cooper Lake stepping to isolation_ucodes[]
  (bsc#1012628).
- perf/x86/intel: Fix pebs event constraints for SPR
  (bsc#1012628).
- net: remove SOCK_SUPPORT_ZC from sockmap (bsc#1012628).
- net: also flag accepted sockets supporting msghdr originated
  zerocopy (bsc#1012628).
- parisc: Make 8250_gsc driver dependend on CONFIG_PARISC
  (bsc#1012628).
- parisc: Export iosapic_serial_irq() symbol for serial port
  driver (bsc#1012628).
- parisc: Avoid printing the hardware path twice (bsc#1012628).
- ext4: fix warning in 'ext4_da_release_space' (bsc#1012628).
- ext4: fix BUG_ON() when directory entry has invalid rec_len
  (bsc#1012628).
- ext4: update the backup superblock's at the end of the online
  resize (bsc#1012628).
- x86/tdx: Prepare for using "INFO" call for a second purpose
  (bsc#1012628).
- x86/tdx: Panic on bad configs that #VE on "private" memory
  access (bsc#1012628).
- x86/syscall: Include asm/ptrace.h in syscall_wrapper header
  (bsc#1012628).
- KVM: x86: Mask off reserved bits in CPUID.80000006H
  (bsc#1012628).
- KVM: x86: Mask off reserved bits in CPUID.8000001AH
  (bsc#1012628).
- KVM: x86: Mask off reserved bits in CPUID.80000008H
  (bsc#1012628).
- KVM: x86: Mask off reserved bits in CPUID.80000001H
  (bsc#1012628).
- KVM: x86: Mask off reserved bits in CPUID.8000001FH
  (bsc#1012628).
- KVM: VMX: Advertise PMU LBRs if and only if perf supports LBRs
  (bsc#1012628).
- KVM: VMX: Fold vmx_supported_debugctl() into
  vcpu_supported_debugctl() (bsc#1012628).
- KVM: VMX: Ignore guest CPUID for host userspace writes to
  DEBUGCTL (bsc#1012628).
- KVM: VMX: fully disable SGX if SECONDARY_EXEC_ENCLS_EXITING
  unavailable (bsc#1012628).
- KVM: Initialize gfn_to_pfn_cache locks in dedicated helper
  (bsc#1012628).
- KVM: Reject attempts to consume or refresh inactive
  gfn_to_pfn_cache (bsc#1012628).
- KVM: arm64: Fix bad dereference on MTE-enabled systems
  (bsc#1012628).
- KVM: arm64: Fix SMPRI_EL1/TPIDR2_EL0 trapping on VHE
  (bsc#1012628).
- KVM: x86: smm: number of GPRs in the SMRAM image depends on
  the image format (bsc#1012628).
- KVM: x86: emulator: em_sysexit should update ctxt->mode
  (bsc#1012628).
- KVM: x86: emulator: update the emulation mode after CR0 write
  (bsc#1012628).
- ext4,f2fs: fix readahead of verity data (bsc#1012628).
- cifs: fix regression in very old smb1 mounts (bsc#1012628).
- drm/rockchip: dsi: Clean up 'usage_mode' when failing to attach
  (bsc#1012628).
- drm/rockchip: dsi: Force synchronous probe (bsc#1012628).
- drm/amdgpu: disable GFXOFF during compute for GFX11
  (bsc#1012628).
- drm/amd/display: Update latencies on DCN321 (bsc#1012628).
- drm/amd/display: Update DSC capabilitie for DCN314
  (bsc#1012628).
- drm/i915/sdvo: Filter out invalid outputs more sensibly
  (bsc#1012628).
- drm/i915/sdvo: Setup DDC fully before output init (bsc#1012628).
- commit 1579d93
* Thu Nov 10 2022 tzimmermann@suse.de
- Disable sysfb before creating simple-framebuffer (bsc#1204315)
- commit 85b6c0f
* Wed Nov  9 2022 jslaby@suse.cz
- Refresh
  patches.suse/Bluetooth-L2CAP-fix-use-after-free-in-l2cap_conn_del.patch.
  Update upstream status.
- commit 9a7c768
* Wed Nov  9 2022 tiwai@suse.de
- Delete synaptics touchpad workaround patch (bsc#1194086)
  This was confirmed to be superfluous now
- commit 4ff425d
* Wed Nov  9 2022 jlee@suse.com
- Update config files for enabling CONFIG_SECONDARY_TRUSTED_KEYRING
  In some architectures, e.g. ppc64, riscv64, x86_64, we have enabled the
  CONFIG_SECONDARY_TRUSTED_KEYRING and children kernel config. But we didn't
  enable it in other architectures.
  In the future, the CONFIG_SECONDARY_TRUSTED_KEYRING will be used with
  IMA in different architectures. So let's enable it in Tumbleweed in
  all architectures to align with SLE/Leap. Then user can use it for
  preparing IMA functions with secondary trusted keyring. (bsc#1203739)
- commit 86a9f2f
* Tue Nov  8 2022 tiwai@suse.de
- Move upstreamed tracing patch into sorted section
- commit de51707
* Tue Nov  8 2022 tiwai@suse.de
- ALSA: usb-audio: Remove redundant workaround for Roland quirk
  (bsc#1205111).
- ALSA: usb-audio: Yet more regression for for the delayed card
  registration (bsc#1205111).
- commit 0d318d5
* Tue Nov  8 2022 jslaby@suse.cz
- rpm/check-for-config-changes: add TOOLCHAIN_HAS_* to IGNORED_CONFIGS_RE
  This new form was added in commit b8c86872d1dc (riscv: fix detection of
  toolchain Zicbom support).
- commit e9f2ba6
* Mon Nov  7 2022 ludwig.nussel@suse.de
- Add suse-kernel-rpm-scriptlets to kmp buildreqs (boo#1205149)
- commit 888e01e
* Mon Nov  7 2022 mkubecek@suse.cz
- Update to 6.1-rc4
- commit 3056fb1
* Fri Nov  4 2022 jslaby@suse.cz
- Update config files.
- commit bd8c959
* Fri Nov  4 2022 jslaby@suse.cz
- Linux 6.0.7 (bsc#1012628).
- platform/x86/amd: pmc: remove CONFIG_DEBUG_FS checks
  (bsc#1012628).
- can: j1939: transport: j1939_session_skb_drop_old():
  spin_unlock_irqrestore() before kfree_skb() (bsc#1012628).
- can: kvaser_usb: Fix possible completions during init_completion
  (bsc#1012628).
- can: rcar_canfd: rcar_canfd_handle_global_receive(): fix IRQ
  storm on global FIFO receive (bsc#1012628).
- can: rcar_canfd: fix channel specific IRQ handling for RZ/G2L
  (bsc#1012628).
- ALSA: Use del_timer_sync() before freeing timer (bsc#1012628).
- ALSA: usb-audio: Add quirks for M-Audio Fast Track C400/600
  (bsc#1012628).
- ALSA: control: add snd_ctl_rename() (bsc#1012628).
- ALSA: hda/realtek: Use snd_ctl_rename() to rename a control
  (bsc#1012628).
- ALSA: emu10k1: Use snd_ctl_rename() to rename a control
  (bsc#1012628).
- ALSA: ac97: Use snd_ctl_rename() to rename a control
  (bsc#1012628).
- ALSA: usb-audio: Use snd_ctl_rename() to rename a control
  (bsc#1012628).
- ALSA: ca0106: Use snd_ctl_rename() to rename a control
  (bsc#1012628).
- ALSA: au88x0: use explicitly signed char (bsc#1012628).
- ALSA: rme9652: use explicitly signed char (bsc#1012628).
- USB: add RESET_RESUME quirk for NVIDIA Jetson devices in RCM
  (bsc#1012628).
- usb: gadget: uvc: limit isoc_sg to super speed gadgets
  (bsc#1012628).
- Revert "usb: gadget: uvc: limit isoc_sg to super speed gadgets"
  (bsc#1012628).
- usb: gadget: uvc: fix dropped frame after missed isoc
  (bsc#1012628).
- usb: gadget: uvc: fix sg handling in error case (bsc#1012628).
- usb: gadget: uvc: fix sg handling during video encode
  (bsc#1012628).
- usb: gadget: aspeed: Fix probe regression (bsc#1012628).
- usb: dwc3: gadget: Stop processing more requests on IMI
  (bsc#1012628).
- usb: dwc3: gadget: Don't set IMI for no_interrupt (bsc#1012628).
- usb: dwc3: gadget: Force sending delayed status during soft
  disconnect (bsc#1012628).
- usb: dwc3: gadget: Don't delay End Transfer on delayed_status
  (bsc#1012628).
- usb: typec: ucsi: Check the connection on resume (bsc#1012628).
- usb: typec: ucsi: acpi: Implement resume callback (bsc#1012628).
- usb: dwc3: st: Rely on child's compatible instead of name
  (bsc#1012628).
- usb: dwc3: Don't switch OTG -> peripheral if extcon is present
  (bsc#1012628).
- usb: bdc: change state when port disconnected (bsc#1012628).
- usb: xhci: add XHCI_SPURIOUS_SUCCESS to ASM1042 despite being
  a V0.96 controller (bsc#1012628).
- mtd: rawnand: tegra: Fix PM disable depth imbalance in probe
  (bsc#1012628).
- mtd: spi-nor: core: Ignore -ENOTSUPP in spi_nor_init()
  (bsc#1012628).
- mtd: parsers: bcm47xxpart: Fix halfblock reads (bsc#1012628).
- mtd: rawnand: marvell: Use correct logic for nand-keep-config
  (bsc#1012628).
- squashfs: fix read regression introduced in readahead code
  (bsc#1012628).
- squashfs: fix extending readahead beyond end of file
  (bsc#1012628).
- squashfs: fix buffer release race condition in readahead code
  (bsc#1012628).
- xhci: Add quirk to reset host back to default state at shutdown
  (bsc#1012628).
- xhci-pci: Set runtime PM as default policy on all xHC 1.2 or
  later devices (bsc#1012628).
- xhci: Remove device endpoints from bandwidth list when freeing
  the device (bsc#1012628).
- tools: iio: iio_utils: fix digit calculation (bsc#1012628).
- iio: light: tsl2583: Fix module unloading (bsc#1012628).
- iio: temperature: ltc2983: allocate iio channels once
  (bsc#1012628).
- iio: adxl372: Fix unsafe buffer attributes (bsc#1012628).
- iio: adxl367: Fix unsafe buffer attributes (bsc#1012628).
- fbdev: stifb: Fall back to cfb_fillrect() on 32-bit HCRX cards
  (bsc#1012628).
- fbdev: smscufx: Fix several use-after-free bugs (bsc#1012628).
- cpufreq: intel_pstate: Read all MSRs on the target CPU
  (bsc#1012628).
- cpufreq: intel_pstate: hybrid: Use known scaling factor for
  P-cores (bsc#1012628).
- fs/binfmt_elf: Fix memory leak in load_elf_binary()
  (bsc#1012628).
- exec: Copy oldsighand->action under spin-lock (bsc#1012628).
- mac802154: Fix LQI recording (bsc#1012628).
- scsi: qla2xxx: Use transport-defined speed mask for
  supported_speeds (bsc#1012628).
- drm/i915: Extend Wa_1607297627 to Alderlake-P (bsc#1012628).
- drm/amdgpu: Remove ATC L2 access for MMHUB 2.1.x (bsc#1012628).
- drm/amdgpu: disallow gfxoff until GC IP blocks complete s2idle
  resume (bsc#1012628).
- drm/amdgpu: fix pstate setting issue (bsc#1012628).
- drm/amd/display: Revert logic for plane modifiers (bsc#1012628).
- drm/amdkfd: update gfx1037 Lx cache setting (bsc#1012628).
- drm/amdkfd: correct the cache info for gfx1036 (bsc#1012628).
- drm/msm: fix use-after-free on probe deferral (bsc#1012628).
- drm/msm/dsi: fix memory corruption with too many bridges
  (bsc#1012628).
- drm/msm/hdmi: fix memory corruption with too many bridges
  (bsc#1012628).
- drm/msm/hdmi: fix IRQ lifetime (bsc#1012628).
- drm/msm/dp: fix memory corruption with too many bridges
  (bsc#1012628).
- drm/msm/dp: fix aux-bus EP lifetime (bsc#1012628).
- drm/msm/dp: fix IRQ lifetime (bsc#1012628).
- drm/msm/dp: fix bridge lifetime (bsc#1012628).
- crypto: x86/polyval - Fix crashes when keys are not 16-byte
  aligned (bsc#1012628).
- random: use arch_get_random*_early() in random_init()
  (bsc#1012628).
- coresight: cti: Fix hang in cti_disable_hw() (bsc#1012628).
- mmc: sdhci_am654: 'select', not 'depends' REGMAP_MMIO
  (bsc#1012628).
- mmc: block: Remove error check of hw_reset on reset
  (bsc#1012628).
- mmc: queue: Cancel recovery work on cleanup (bsc#1012628).
- mmc: core: Fix kernel panic when remove non-standard SDIO card
  (bsc#1012628).
- mmc: core: Fix WRITE_ZEROES CQE handling (bsc#1012628).
- mmc: sdhci-pci-core: Disable ES for ASUS BIOS on Jasper Lake
  (bsc#1012628).
- mmc: sdhci-esdhc-imx: Propagate ESDHC_FLAG_HS400* only on 8bit
  bus (bsc#1012628).
- counter: microchip-tcb-capture: Handle Signal1 read and Synapse
  (bsc#1012628).
- counter: 104-quad-8: Fix race getting function mode and
  direction (bsc#1012628).
- mm/uffd: fix vma check on userfault for wp (bsc#1012628).
- mm: migrate: fix return value if all subpages of THPs are
  migrated successfully (bsc#1012628).
- mm,madvise,hugetlb: fix unexpected data loss with MADV_DONTNEED
  on hugetlbfs (bsc#1012628).
- mm/kmemleak: prevent soft lockup in kmemleak_scan()'s object
  iteration loops (bsc#1012628).
- mm/huge_memory: do not clobber swp_entry_t during THP split
  (bsc#1012628).
- mm: prep_compound_tail() clear page->private (bsc#1012628).
- kernfs: fix use-after-free in __kernfs_remove (bsc#1012628).
- Revert "dt-bindings: pinctrl-zynqmp: Add output-enable
  configuration" (bsc#1012628).
- pinctrl: Ingenic: JZ4755 bug fixes (bsc#1012628).
- Revert "pinctrl: pinctrl-zynqmp: Add support for output-enable
  and bias-high-impedance" (bsc#1012628).
- ARC: mm: fix leakage of memory allocated for PTE (bsc#1012628).
- perf auxtrace: Fix address filter symbol name match for modules
  (bsc#1012628).
- s390/boot: add secure boot trailer (bsc#1012628).
- s390/cio: fix out-of-bounds access on cio_ignore free
  (bsc#1012628).
- s390/uaccess: add missing EX_TABLE entries to __clear_user()
  (bsc#1012628).
- s390/futex: add missing EX_TABLE entry to __futex_atomic_op()
  (bsc#1012628).
- s390/pci: add missing EX_TABLE entries to
  __pcistg_mio_inuser()/__pcilg_mio_inuser() (bsc#1012628).
- ethtool: eeprom: fix null-deref on genl_info in dump
  (bsc#1012628).
- fbdev/core: Avoid uninitialized read in
  aperture_remove_conflicting_pci_device() (bsc#1012628).
- ACPI: PCC: Fix unintentional integer overflow (bsc#1012628).
- powerpc/64s/interrupt: Fix clear of PACA_IRQS_HARD_DIS when
  returning to soft-masked context (bsc#1012628).
- net: ieee802154: fix error return code in dgram_bind()
  (bsc#1012628).
- media: amphion: release m2m ctx when releasing vpu instance
  (bsc#1012628).
- media: v4l2: Fix v4l2_i2c_subdev_set_name function documentation
  (bsc#1012628).
- media: ar0521: fix error return code in ar0521_power_on()
  (bsc#1012628).
- media: ar0521: Fix return value check in writing initial
  registers (bsc#1012628).
- media: ov8865: Fix an error handling path in ov8865_probe()
  (bsc#1012628).
- media: sun6i-mipi-csi2: Depend on PHY_SUN6I_MIPI_DPHY
  (bsc#1012628).
- media: atomisp: prevent integer overflow in
  sh_css_set_black_frame() (bsc#1012628).
- media: sunxi: Fix some error handling path of
  sun8i_a83t_mipi_csi2_probe() (bsc#1012628).
- media: sunxi: Fix some error handling path of
  sun6i_mipi_csi2_probe() (bsc#1012628).
- media: sun6i-mipi-csi2: Add a Kconfig dependency on
  RESET_CONTROLLER (bsc#1012628).
- media: sun8i-a83t-mipi-csi2: Add a Kconfig dependency on
  RESET_CONTROLLER (bsc#1012628).
- media: sun6i-csi: Add a Kconfig dependency on RESET_CONTROLLER
  (bsc#1012628).
- media: sun4i-csi: Add a Kconfig dependency on RESET_CONTROLLER
  (bsc#1012628).
- media: sun8i-di: Add a Kconfig dependency on RESET_CONTROLLER
  (bsc#1012628).
- media: sun8i-rotate: Add a Kconfig dependency on
  RESET_CONTROLLER (bsc#1012628).
- media: cedrus: Add a Kconfig dependency on RESET_CONTROLLER
  (bsc#1012628).
- drm/msm/a6xx: Replace kcalloc() with kvzalloc() (bsc#1012628).
- drm/msm/dp: add atomic_check to bridge ops (bsc#1012628).
- drm/msm: Fix return type of mdp4_lvds_connector_mode_valid
  (bsc#1012628).
- drm/msm/dp: cleared DP_DOWNSPREAD_CTRL register before start
  link training (bsc#1012628).
- ASoC: codec: tlv320adc3xxx: add GPIOLIB dependency
  (bsc#1012628).
- KVM: selftests: Fix number of pages for memory slot in
  memslot_modification_stress_test (bsc#1012628).
- ASoC: qcom: lpass-cpu: mark HDMI TX registers as volatile
  (bsc#1012628).
- drm/msm/a6xx: Fix kvzalloc vs state_kcalloc usage (bsc#1012628).
- erofs: fix illegal unmapped accesses in
  z_erofs_fill_inode_lazy() (bsc#1012628).
- erofs: fix up inplace decompression success rate (bsc#1012628).
- pinctrl: qcom: Avoid glitching lines when we first mux to output
  (bsc#1012628).
- spi: qup: support using GPIO as chip select line (bsc#1012628).
- x86/fpu: Configure init_fpstate attributes orderly
  (bsc#1012628).
- x86/fpu: Fix the init_fpstate size check with the actual size
  (bsc#1012628).
- x86/fpu: Exclude dynamic states from init_fpstate (bsc#1012628).
- perf: Fix missing SIGTRAPs (bsc#1012628).
- sched/core: Fix comparison in sched_group_cookie_match()
  (bsc#1012628).
- bpf: prevent decl_tag from being referenced in func_proto
  (bsc#1012628).
- arc: iounmap() arg is volatile (bsc#1012628).
- mtd: core: add missing of_node_get() in dynamic partitions code
  (bsc#1012628).
- mtd: rawnand: intel: Remove unused nand_pa member from
  ebu_nand_cs (bsc#1012628).
- mtd: rawnand: intel: Use devm_platform_ioremap_resource_byname()
  (bsc#1012628).
- mtd: rawnand: intel: Add missing of_node_put() in
  ebu_nand_probe() (bsc#1012628).
- pinctrl: ocelot: Fix incorrect trigger of the interrupt
  (bsc#1012628).
- ASoC: codecs: tlv320adc3xxx: Wrap adc3xxx_i2c_remove() in
  __exit_p() (bsc#1012628).
- ASoC: SOF: Intel: pci-mtl: fix firmware name (bsc#1012628).
- selftests/ftrace: fix dynamic_events dependency check
  (bsc#1012628).
- spi: aspeed: Fix window offset of CE1 (bsc#1012628).
- ASoC: qcom: lpass-cpu: Mark HDMI TX parity register as volatile
  (bsc#1012628).
- ASoC: Intel: common: add ACPI matching tables for Raptor Lake
  (bsc#1012628).
- ASoC: SOF: Intel: pci-tgl: use RPL specific firmware definitions
  (bsc#1012628).
- ASoC: SOF: Intel: pci-tgl: fix ADL-N descriptor (bsc#1012628).
- ALSA: ac97: fix possible memory leak in snd_ac97_dev_register()
  (bsc#1012628).
- perf/x86/intel/lbr: Use setup_clear_cpu_cap() instead of
  clear_cpu_cap() (bsc#1012628).
- rcu: Keep synchronize_rcu() from enabling irqs in early boot
  (bsc#1012628).
- tipc: fix a null-ptr-deref in tipc_topsrv_accept (bsc#1012628).
- net: netsec: fix error handling in netsec_register_mdio()
  (bsc#1012628).
- net: lan966x: Fix the rx drop counter (bsc#1012628).
- selftests: net: Fix cross-tree inclusion of scripts
  (bsc#1012628).
- selftests: net: Fix netdev name mismatch in cleanup
  (bsc#1012628).
- net: hinic: fix incorrect assignment issue in
  hinic_set_interrupt_cfg() (bsc#1012628).
- net: hinic: fix memory leak when reading function table
  (bsc#1012628).
- net: hinic: fix the issue of CMDQ memory leaks (bsc#1012628).
- net: hinic: fix the issue of double release MBOX callback of VF
  (bsc#1012628).
- net: macb: Specify PHY PM management done by MAC (bsc#1012628).
- nfc: virtual_ncidev: Fix memory leak in virtual_nci_send()
  (bsc#1012628).
- RISC-V: KVM: Provide UAPI for Zicbom block size (bsc#1012628).
- RISC-V: Fix compilation without RISCV_ISA_ZICBOM (bsc#1012628).
- RISC-V: KVM: Fix kvm_riscv_vcpu_timer_pending() for Sstc
  (bsc#1012628).
- x86/unwind/orc: Fix unreliable stack dump with gcov
  (bsc#1012628).
- drm/bridge: ps8640: Add back the 50 ms mystery delay after HPD
  (bsc#1012628).
- x86/fpu: Fix copy_xstate_to_uabi() to copy init states correctly
  (bsc#1012628).
- amd-xgbe: Yellow carp devices do not need rrc (bsc#1012628).
- amd-xgbe: fix the SFP compliance codes check for DAC cables
  (bsc#1012628).
- amd-xgbe: add the bit rate quirk for Molex cables (bsc#1012628).
- drm/i915/dgfx: Keep PCI autosuspend control 'on' by default
  on all dGPU (bsc#1012628).
- drm/i915/dp: Reset frl trained flag before restarting FRL
  training (bsc#1012628).
- atlantic: fix deadlock at aq_nic_stop (bsc#1012628).
- kcm: annotate data-races around kcm->rx_psock (bsc#1012628).
- kcm: annotate data-races around kcm->rx_wait (bsc#1012628).
- net: fix UAF issue in nfqnl_nf_hook_drop() when ops_init()
  failed (bsc#1012628).
- net: lantiq_etop: don't free skb when returning NETDEV_TX_BUSY
  (bsc#1012628).
- tcp: fix a signed-integer-overflow bug in tcp_add_backlog()
  (bsc#1012628).
- tcp: fix indefinite deferral of RTO with SACK reneging
  (bsc#1012628).
- net-memcg: avoid stalls when under memory pressure
  (bsc#1012628).
- drm/amdkfd: Fix memory leak in kfd_mem_dmamap_userptr()
  (bsc#1012628).
- net: lan966x: Stop replacing tx dcbs and dcbs_buf when changing
  MTU (bsc#1012628).
- mptcp: set msk local address earlier (bsc#1012628).
- can: mscan: mpc5xxx: mpc5xxx_can_probe(): add missing
  put_clock() in error path (bsc#1012628).
- can: mcp251x: mcp251x_can_probe(): add missing
  unregister_candev() in error path (bsc#1012628).
- PM: hibernate: Allow hybrid sleep to work with s2idle
  (bsc#1012628).
- media: vivid: s_fbuf: add more sanity checks (bsc#1012628).
- media: vivid: dev->bitmap_cap wasn't freed in all cases
  (bsc#1012628).
- media: v4l2-dv-timings: add sanity checks for blanking values
  (bsc#1012628).
- media: videodev2.h: V4L2_DV_BT_BLANKING_HEIGHT should check
  'interlaced' (bsc#1012628).
- media: vivid: set num_in/outputs to 0 if not supported
  (bsc#1012628).
- perf vendor events power10: Fix hv-24x7 metric events
  (bsc#1012628).
- perf list: Fix PMU name pai_crypto in perf list on s390
  (bsc#1012628).
- ipv6: ensure sane device mtu in tunnels (bsc#1012628).
- i40e: Fix ethtool rx-flow-hash setting for X722 (bsc#1012628).
- i40e: Fix VF hang when reset is triggered on another VF
  (bsc#1012628).
- i40e: Fix flow-type by setting GL_HASH_INSET registers
  (bsc#1012628).
- net: ksz884x: fix missing pci_disable_device() on error in
  pcidev_init() (bsc#1012628).
- riscv: jump_label: mark arguments as const to satisfy asm
  constraints (bsc#1012628).
- PM: domains: Fix handling of unavailable/disabled idle states
  (bsc#1012628).
- perf vendor events arm64: Fix incorrect Hisi hip08 L3 metrics
  (bsc#1012628).
- net: fec: limit register access on i.MX6UL (bsc#1012628).
- net: ethernet: ave: Fix MAC to be in charge of PHY PM
  (bsc#1012628).
- ALSA: aoa: i2sbus: fix possible memory leak in i2sbus_add_dev()
  (bsc#1012628).
- ALSA: aoa: Fix I2S device accounting (bsc#1012628).
- openvswitch: switch from WARN to pr_warn (bsc#1012628).
- net: ehea: fix possible memory leak in ehea_register_port()
  (bsc#1012628).
- net: bcmsysport: Indicate MAC is in charge of PHY PM
  (bsc#1012628).
- nh: fix scope used to find saddr when adding non gw nh
  (bsc#1012628).
- net: broadcom: bcm4908_enet: update TX stats after actual
  transmission (bsc#1012628).
- netdevsim: fix memory leak in nsim_bus_dev_new() (bsc#1012628).
- netdevsim: fix memory leak in nsim_drv_probe() when
  nsim_dev_resources_register() failed (bsc#1012628).
- netdevsim: remove dir in nsim_dev_debugfs_init() when creating
  ports dir failed (bsc#1012628).
- net/mlx5e: Do not increment ESN when updating IPsec ESN state
  (bsc#1012628).
- net/mlx5: Wait for firmware to enable CRS before
  pci_restore_state (bsc#1012628).
- net/mlx5: DR, Fix matcher disconnect error flow (bsc#1012628).
- net/mlx5e: Extend SKB room check to include PTP-SQ
  (bsc#1012628).
- net/mlx5e: Update restore chain id for slow path packets
  (bsc#1012628).
- net/mlx5: ASO, Create the ASO SQ with the correct timestamp
  format (bsc#1012628).
- net/mlx5: Fix possible use-after-free in async command interface
  (bsc#1012628).
- net/mlx5e: TC, Reject forwarding from internal port to internal
  port (bsc#1012628).
- net/mlx5: Update fw fatal reporter state on PCI handlers
  successful recover (bsc#1012628).
- net/mlx5: Fix crash during sync firmware reset (bsc#1012628).
- net: do not sense pfmemalloc status in skb_append_pagefrags()
  (bsc#1012628).
- kcm: do not sense pfmemalloc status in kcm_sendpage()
  (bsc#1012628).
- net: enetc: survive memory pressure without crashing
  (bsc#1012628).
- riscv: mm: add missing memcpy in kasan_init (bsc#1012628).
- riscv: fix detection of toolchain Zicbom support (bsc#1012628).
- riscv: fix detection of toolchain Zihintpause support
  (bsc#1012628).
- arm64: Add AMPERE1 to the Spectre-BHB affected list
  (bsc#1012628).
- tcp/udp: Fix memory leak in ipv6_renew_options() (bsc#1012628).
- commit 94ab6c8
* Wed Nov  2 2022 tiwai@suse.de
- wifi: brcmfmac: Fix potential buffer overflow in
  brcmf_fweh_event_worker() (CVE-2022-3628 bsc#1204868).
- commit a020866
* Wed Nov  2 2022 tiwai@suse.de
- Drop the previous sound fix for Dell Dock (bsc#1204719)
  The patch turned out to be superfluous, the fix should be on pipewire
  instead.
- commit a7f641a
* Wed Nov  2 2022 tiwai@suse.de
- ALSA: usb-audio: Fix regression with Dell Dock jack detection
  (bsc#1204719).
- commit 286383c
* Wed Nov  2 2022 jslaby@suse.cz
- KVM: x86: emulator: update the emulation mode after rsm
  (bsc#1200616).
- KVM: x86: emulator: introduce emulator_recalc_and_set_mode
  (bsc#1200616).
- commit 28a19ee
* Wed Nov  2 2022 jslaby@suse.cz
- char: pcmcia: cm4040_cs: Fix use-after-free in reader_fops
  (bsc#1204922 CVE-2022-44033).
- commit d6c5191
* Wed Nov  2 2022 tiwai@suse.de
- ring-buffer: Check for NULL cpu_buffer in
  ring_buffer_wake_waiters() (bsc#1204705).
- commit 57f1f7d
* Tue Nov  1 2022 jslaby@suse.cz
- Refresh patches.suse/drm-amdgpu-Fix-for-BO-move-issue.patch.
  Update upstream status.
- commit 30b9c27
* Tue Nov  1 2022 jslaby@suse.cz
- char: pcmcia: scr24x_cs: Fix use-after-free in scr24x_fops
  (bsc#1204901 CVE-2022-44034).
- char: pcmcia: cm4000_cs: Fix use-after-free in cm4000_fops
  (bsc#1204894 CVE-2022-44032).
- char: pcmcia: scr24x_cs: Fix use-after-free in scr24x_fops
  (bsc#1204901 CVE-2022-44034).
- char: pcmcia: cm4000_cs: Fix use-after-free in cm4000_fops
  (bsc#1204894 CVE-2022-44032).
- commit 1e6f02d
* Tue Nov  1 2022 jslaby@suse.cz
- Refresh
  patches.suse/ACPI-resource-do-IRQ-override-on-LENOVO-IdeaPad.patch.
- Refresh
  patches.suse/ALSA-hda-realtek-Add-another-HP-ZBook-G9-model-quirk.patch.
- Refresh
  patches.suse/ALSA-hda-realtek-Add-quirk-for-ASUS-Zenbook-using-CS.patch.
  Update upstream status.
- commit eaa1897
* Mon Oct 31 2022 mkubecek@suse.cz
- Update to 6.1-rc3
- eliminate 1 patch
  - patches.suse/scsi-mpi3mr-select-CONFIG_SCSI_SAS_ATTRS.patch
- refresh configs
- commit 6cba764
* Sun Oct 30 2022 jslaby@suse.cz
- Linux 6.0.6 (bsc#1012628).
- mm: /proc/pid/smaps_rollup: fix no vma's null-deref
  (bsc#1012628).
- ACPI: video: Force backlight native for more TongFang devices
  (bsc#1012628).
- ext4: fix potential out of bound read in ext4_fc_replay_scan()
  (bsc#1012628).
- ext4: factor out ext4_fc_get_tl() (bsc#1012628).
- ext4: introduce EXT4_FC_TAG_BASE_LEN helper (bsc#1012628).
- io_uring: don't gate task_work run on TIF_NOTIFY_SIGNAL
  (bsc#1012628).
- wifi: mt76: mt7921e: fix random fw download fail (bsc#1012628).
- iommu/vt-d: Clean up si_domain in the init_dmars() error path
  (bsc#1012628).
- iommu/vt-d: Allow NVS regions in arch_rmrr_sanity_check()
  (bsc#1012628).
- rv/dot2c: Make automaton definition static (bsc#1012628).
- drbd: only clone bio if we have a backing device (bsc#1012628).
- net: phy: dp83822: disable MDI crossover status change interrupt
  (bsc#1012628).
- net: sched: fix race condition in qdisc_graft() (bsc#1012628).
- net: hns: fix possible memory leak in hnae_ae_register()
  (bsc#1012628).
- wwan_hwsim: fix possible memory leak in wwan_hwsim_dev_new()
  (bsc#1012628).
- sfc: include vport_id in filter spec hash and equal()
  (bsc#1012628).
- io_uring/msg_ring: Fix NULL pointer dereference in
  io_msg_send_fd() (bsc#1012628).
- net: Fix return value of qdisc ingress handling on success
  (bsc#1012628).
- net: sched: sfb: fix null pointer access issue when sfb_init()
  fails (bsc#1012628).
- net: sched: delete duplicate cleanup of backlog and qlen
  (bsc#1012628).
- net: sched: cake: fix null pointer access issue when cake_init()
  fails (bsc#1012628).
- nvmet: fix workqueue MEM_RECLAIM flushing dependency
  (bsc#1012628).
- nvme-hwmon: kmalloc the NVME SMART log buffer (bsc#1012628).
- nvme-hwmon: consistently ignore errors from nvme_hwmon_init
  (bsc#1012628).
- netfilter: nf_tables: relax NFTA_SET_ELEM_KEY_END set flags
  requirements (bsc#1012628).
- netfilter: rpfilter/fib: Set ->flowic_uid correctly for user
  namespaces (bsc#1012628).
- netfilter: rpfilter/fib: Populate flowic_l3mdev field
  (bsc#1012628).
- ionic: catch NULL pointer issue on reconfig (bsc#1012628).
- net: hsr: avoid possible NULL deref in skb_clone()
  (bsc#1012628).
- bnxt_en: fix memory leak in bnxt_nvm_test() (bsc#1012628).
- drm/amd/display: Increase frame size limit for
  display_mode_vba_util_32.o (bsc#1012628).
- dm: remove unnecessary assignment statement in alloc_dev()
  (bsc#1012628).
- cifs: Fix memory leak when build ntlmssp negotiate blob failed
  (bsc#1012628).
- cifs: Fix xid leak in cifs_ses_add_channel() (bsc#1012628).
- cifs: Fix xid leak in cifs_flock() (bsc#1012628).
- cifs: Fix xid leak in cifs_copy_file_range() (bsc#1012628).
- cifs: Fix xid leak in cifs_create() (bsc#1012628).
- ip6mr: fix UAF issue in ip6mr_sk_done() when addrconf_init_net()
  failed (bsc#1012628).
- udp: Update reuse->has_conns under reuseport_lock (bsc#1012628).
- scsi: lpfc: Fix memory leak in lpfc_create_port() (bsc#1012628).
- net: ethernet: mtk_eth_wed: add missing of_node_put()
  (bsc#1012628).
- net: ethernet: mtk_eth_wed: add missing put_device() in
  mtk_wed_add_hw() (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix possible memory leak in
  mtk_probe() (bsc#1012628).
- io_uring/rw: remove leftover debug statement (bsc#1012628).
- blk-mq: fix null pointer dereference in
  blk_mq_clear_rq_mapping() (bsc#1012628).
- erofs: shouldn't churn the mapping page for duplicated copies
  (bsc#1012628).
- skmsg: pass gfp argument to alloc_sk_msg() (bsc#1012628).
- net: stmmac: Enable mac_managed_pm phylink config (bsc#1012628).
- net: phylink: add mac_managed_pm in phylink_config structure
  (bsc#1012628).
- net/smc: Fix an error code in smc_lgr_create() (bsc#1012628).
- net: phy: dp83867: Extend RX strap quirk for SGMII mode
  (bsc#1012628).
- net/atm: fix proc_mpc_write incorrect return value
  (bsc#1012628).
- sfc: Change VF mac via PF as first preference if available
  (bsc#1012628).
- HID: magicmouse: Do not set BTN_MOUSE on double report
  (bsc#1012628).
- tls: strp: make sure the TCP skbs do not have overlapping data
  (bsc#1012628).
- i40e: Fix DMA mappings leak (bsc#1012628).
- net: dsa: qca8k: fix ethtool autocast mib for big-endian systems
  (bsc#1012628).
- net: dsa: qca8k: fix inband mgmt for big-endian systems
  (bsc#1012628).
- tipc: fix an information leak in tipc_topsrv_kern_subscr
  (bsc#1012628).
- tipc: Fix recognition of trial period (bsc#1012628).
- ACPI: extlog: Handle multiple records (bsc#1012628).
- drm/vc4: hdmi: Enforce the minimum rate at runtime_resume
  (bsc#1012628).
- drm/vc4: Add module dependency on hdmi-codec (bsc#1012628).
- btrfs: fix processing of delayed tree block refs during backref
  walking (bsc#1012628).
- btrfs: fix processing of delayed data refs during backref
  walking (bsc#1012628).
- dm bufio: use the acquire memory barrier when testing for
  B_READING (bsc#1012628).
- platform/x86/amd: pmc: Read SMU version during suspend on
  Cezanne systems (bsc#1012628).
- x86/topology: Fix duplicated core ID within a package
  (bsc#1012628).
- x86/topology: Fix multiple packages shown on a single-package
  system (bsc#1012628).
- x86/Kconfig: Drop check for -mabi=ms for CONFIG_EFI_STUB
  (bsc#1012628).
- media: venus: Fix NV12 decoder buffer discovery on
  HFI_VERSION_1XX (bsc#1012628).
- media: venus: dec: Handle the case where find_format fails
  (bsc#1012628).
- media: mceusb: set timeout to at least timeout provided
  (bsc#1012628).
- media: ipu3-imgu: Fix NULL pointer dereference in active
  selection access (bsc#1012628).
- KVM: arm64: vgic: Fix exit condition in scan_its_table()
  (bsc#1012628).
- KVM: x86: Add compat handler for KVM_X86_SET_MSR_FILTER
  (bsc#1012628).
- KVM: x86: Copy filter arg outside kvm_vm_ioctl_set_msr_filter()
  (bsc#1012628).
- kvm: Add support for arch compat vm ioctls (bsc#1012628).
- mm,hugetlb: take hugetlb_lock before decrementing
  h->resv_huge_pages (bsc#1012628).
- drm/amdgpu: fix sdma doorbell init ordering on APUs
  (bsc#1012628).
- cpufreq: qcom: fix memory leak in error path (bsc#1012628).
- x86/resctrl: Fix min_cbm_bits for AMD (bsc#1012628).
- ata: ahci: Match EM_MAX_SLOTS with SATA_PMP_MAX_PORTS
  (bsc#1012628).
- ata: ahci-imx: Fix MODULE_ALIAS (bsc#1012628).
- hwmon/coretemp: Handle large core ID value (bsc#1012628).
- x86/microcode/AMD: Apply the patch early on every logical thread
  (bsc#1012628).
- cpufreq: tegra194: Fix module loading (bsc#1012628).
- i2c: qcom-cci: Fix ordering of pm_runtime_xx and i2c_add_adapter
  (bsc#1012628).
- cpufreq: qcom: fix writes in read-only memory region
  (bsc#1012628).
- selinux: enable use of both GFP_KERNEL and GFP_ATOMIC in
  convert_context() (bsc#1012628).
- smb3: interface count displayed incorrectly (bsc#1012628).
- ocfs2: fix BUG when iput after ocfs2_mknod fails (bsc#1012628).
- ocfs2: clear dinode links count in case of error (bsc#1012628).
- video/aperture: Call sysfb_disable() before removing PCI devices
  (bsc#1012628).
- commit ba5b066
* Wed Oct 26 2022 jslaby@suse.cz
- Linux 6.0.5 (bsc#1012628).
- Revert "btrfs: call __btrfs_remove_free_space_cache_locked on
  cache load failure" (bsc#1012628).
- clk: tegra: Fix Tegra PWM parent clock (bsc#1012628).
- commit 7359656
* Wed Oct 26 2022 jslaby@suse.cz
- Linux 6.0.4 (bsc#1012628).
- Revert "ALSA: hda: Fix page fault in snd_hda_codec_shutdown()"
  (bsc#1012628).
- fbdev/core: Remove remove_conflicting_pci_framebuffers()
  (bsc#1012628).
- io-wq: Fix memory leak in worker creation (bsc#1012628).
- gcov: support GCC 12.1 and newer compilers (bsc#1012628).
- efi: ssdt: Don't free memory if ACPI table was loaded
  successfully (bsc#1012628).
- efi: efivars: Fix variable writes without query_variable_store()
  (bsc#1012628).
- dm clone: Fix typo in block_device format specifier
  (bsc#1012628).
- drm/amd/pm: update SMU IP v13.0.4 driver interface version
  (bsc#1012628).
- drm/amd/pm: fulfill SMU13.0.0 cstate control interface
  (bsc#1012628).
- drm/amd/pm: disable cstate feature for gpu reset scenario
  (bsc#1012628).
- drm/amd/pm: add SMU IP v13.0.4 IF version define to V7
  (bsc#1012628).
- drm/amd/pm: fulfill SMU13.0.7 cstate control interface
  (bsc#1012628).
- net: flag sockets supporting msghdr originated zerocopy
  (bsc#1012628).
- HID: playstation: add initial DualSense Edge controller support
  (bsc#1012628).
- HID: playstation: stop DualSense output work on remove
  (bsc#1012628).
- io_uring/net: fail zc send when unsupported by socket
  (bsc#1012628).
- thermal: intel_powerclamp: Use first online CPU as control_cpu
  (bsc#1012628).
- pinctrl: amd: change dev_warn to dev_dbg for additional feature
  support (bsc#1012628).
- drm/i915/bios: Use hardcoded fp_timing size for generating
  LFP data pointers (bsc#1012628).
- drm/i915/bios: Validate fp_timing terminator presence
  (bsc#1012628).
- commit 12375d5
* Wed Oct 26 2022 mbrugger@suse.com
- arm64: Update config files. (bsc#1203558)
  Enable Renesas serial console and earlycon.
- commit 6516615
* Tue Oct 25 2022 tiwai@suse.de
- Revert "ALSA: hda: Fix page fault in snd_hda_codec_shutdown()"
  (bsc#1204679).
- commit df34d12
* Mon Oct 24 2022 tiwai@suse.de
- Bluetooth: L2CAP: fix use-after-free in l2cap_conn_del()
  (CVE-2022-3640 bsc#1204619).
- commit c41533c
* Mon Oct 24 2022 mkubecek@suse.cz
- Update to 6.1-rc2
- commit 796d87f
* Sat Oct 22 2022 tiwai@suse.de
- ALSA: hda/realtek: Add another HP ZBook G9 model quirks
  (bsc#1203699).
- commit a4522e2
* Sat Oct 22 2022 jslaby@suse.cz
- Linux 6.0.3 (bsc#1012628).
- arm64: dts: qcom: sc8280xp-pmics: Remove reg entry & use
  correct node name for pmc8280c_lpg node (bsc#1012628).
- Kconfig.debug: add toolchain checks for
  DEBUG_INFO_DWARF_TOOLCHAIN_DEFAULT (bsc#1012628).
- Kconfig.debug: simplify the dependency of DEBUG_INFO_DWARF4/5
  (bsc#1012628).
- io_uring/rw: ensure kiocb_end_write() is always called
  (bsc#1012628).
- io_uring: fix fdinfo sqe offsets calculation (bsc#1012628).
- drm/amd/display: Fix build breakage with CONFIG_DEBUG_FS=n
  (bsc#1012628).
- powerpc/64s/interrupt: Fix lost interrupts when returning to
  soft-masked context (bsc#1012628).
- net/ieee802154: don't warn zero-sized raw_sendmsg()
  (bsc#1012628).
- Revert "net/ieee802154: reject zero-sized raw_sendmsg()"
  (bsc#1012628).
- Revert "drm/amd/display: correct hostvm flag" (bsc#1012628).
- net: ethernet: ti: davinci_mdio: fix build for mdio bitbang uses
  (bsc#1012628).
- blk-wbt: fix that 'rwb->wc' is always set to 1 in wbt_init()
  (bsc#1012628).
- ALSA: usb-audio: Fix last interface check for registration
  (bsc#1012628).
- net: ieee802154: return -EINVAL for unknown addr type
  (bsc#1012628).
- mm: hugetlb: fix UAF in hugetlb_handle_userfault (bsc#1012628).
- io_uring/net: fix notif cqe reordering (bsc#1012628).
- io_uring/net: don't skip notifs for failed requests
  (bsc#1012628).
- io_uring/net: rename io_sendzc() (bsc#1012628).
- io_uring/net: don't lose partial send_zc on fail (bsc#1012628).
- io_uring/net: use io_sr_msg for sendzc (bsc#1012628).
- io_uring/net: refactor io_sr_msg types (bsc#1012628).
- perf intel-pt: Fix system_wide dummy event for hybrid
  (bsc#1012628).
- perf intel-pt: Fix segfault in intel_pt_print_info() with uClibc
  (bsc#1012628).
- perf: Skip and warn on unknown format 'configN' attrs
  (bsc#1012628).
- clk: bcm2835: Round UART input clock up (bsc#1012628).
- usb: typec: ucsi: Don't warn on probe deferral (bsc#1012628).
- dmaengine: dw-edma: Remove runtime PM support (bsc#1012628).
- fsi: master-ast-cf: Fix missing of_node_put in
  fsi_master_acf_probe (bsc#1012628).
- fsi: occ: Prevent use after free (bsc#1012628).
- hwmon (occ): Retry for checksum failure (bsc#1012628).
- blk-mq: use quiesced elevator switch when reinitializing queues
  (bsc#1012628).
- usb: idmouse: fix an uninit-value in idmouse_open (bsc#1012628).
- nvmet-tcp: add bounds check on Transfer Tag (bsc#1012628).
- nvme: copy firmware_rev on each init (bsc#1012628).
- nvme: handle effects after freeing the request (bsc#1012628).
- ext2: Use kvmalloc() for group descriptor array (bsc#1012628).
- scsi: tracing: Fix compile error in trace_array calls when
  TRACING is disabled (bsc#1012628).
- staging: rtl8723bs: fix a potential memory leak in
  rtw_init_cmd_priv() (bsc#1012628).
- staging: rtl8723bs: fix potential memory leak in
  rtw_init_drv_sw() (bsc#1012628).
- io_uring: fix CQE reordering (bsc#1012628).
- Revert "usb: storage: Add quirk for Samsung Fit flash"
  (bsc#1012628).
- usb: dwc3: core: Enable GUCTL1 bit 10 for fixing termination
  error after resume bug (bsc#1012628).
- arm64: dts: imx8mp: Add snps,gfladj-refclk-lpm-sel quirk to
  USB nodes (bsc#1012628).
- usb: dwc3: core: add gfladj_refclk_lpm_sel quirk (bsc#1012628).
- usb: musb: Fix musb_gadget.c rxstate overflow bug (bsc#1012628).
- usb: host: xhci: Fix potential memory leak in
  xhci_alloc_stream_info() (bsc#1012628).
- md/raid5: Wait for MD_SB_CHANGE_PENDING in raid5d (bsc#1012628).
- HID: nintendo: check analog user calibration for plausibility
  (bsc#1012628).
- HSI: ssi_protocol: fix potential resource leak in ssip_pn_open()
  (bsc#1012628).
- HID: roccat: Fix use-after-free in roccat_read() (bsc#1012628).
- soundwire: intel: fix error handling on dai registration issues
  (bsc#1012628).
- soundwire: cadence: Don't overwrite msg->buf during write
  commands (bsc#1012628).
- bcache: fix set_at_max_writeback_rate() for multiple attached
  devices (bsc#1012628).
- ata: libahci_platform: Sanity check the DT child nodes number
  (bsc#1012628).
- blk-throttle: prevent overflow while calculating wait time
  (bsc#1012628).
- staging: vt6655: fix potential memory leak (bsc#1012628).
- power: supply: adp5061: fix out-of-bounds read in
  adp5061_get_chg_type() (bsc#1012628).
- usb: gadget: uvc: increase worker prio to WQ_HIGHPRI
  (bsc#1012628).
- iommu/arm-smmu-v3: Make default domain type of HiSilicon PTT
  device to identity (bsc#1012628).
- nbd: Fix hung when signal interrupts nbd_start_device_ioctl()
  (bsc#1012628).
- scsi: 3w-9xxx: Avoid disabling device if failing to enable it
  (bsc#1012628).
- dmaengine: ti: k3-udma: Reset UDMA_CHAN_RT byte counters to
  prevent overflow (bsc#1012628).
- scsi: lpfc: Fix null ndlp ptr dereference in abnormal exit
  path for GFT_ID (bsc#1012628).
- usb: host: xhci-plat: suspend/resume clks for brcm
  (bsc#1012628).
- usb: host: xhci-plat: suspend and resume clocks (bsc#1012628).
- RDMA/rxe: Delete error messages triggered by incoming Read
  requests (bsc#1012628).
- clk: zynqmp: pll: rectify rate rounding in zynqmp_pll_round_rate
  (bsc#1012628).
- media: platform: fix some double free in meson-ge2d and mtk-jpeg
  and s5p-mfc (bsc#1012628).
- media: cx88: Fix a null-ptr-deref bug in buffer_prepare()
  (bsc#1012628).
- clk: zynqmp: Fix stack-out-of-bounds in strncpy` (bsc#1012628).
- ARM: 9242/1: kasan: Only map modules if CONFIG_KASAN_VMALLOC=n
  (bsc#1012628).
- ARM: 9234/1: stacktrace: Avoid duplicate saving of exception
  PC value (bsc#1012628).
- ARM: 9233/1: stacktrace: Skip frame pointer boundary check
  for call_with_stack() (bsc#1012628).
- btrfs: call __btrfs_remove_free_space_cache_locked on cache
  load failure (bsc#1012628).
- btrfs: don't print information about space cache or tree every
  remount (bsc#1012628).
- btrfs: scrub: try to fix super block errors (bsc#1012628).
- btrfs: scrub: properly report super block errors in system log
  (bsc#1012628).
- btrfs: dump extra info if one free space cache has more bitmaps
  than it should (bsc#1012628).
- ARM: orion: fix include path (bsc#1012628).
- arm64: dts: imx8mq-librem5: Add bq25895 as max17055's power
  supply (bsc#1012628).
- arm64: dts: imx8mm-kontron: Use the VSELECT signal to switch
  SD card IO voltage (bsc#1012628).
- kselftest/arm64: Fix validatation termination record after
  EXTRA_CONTEXT (bsc#1012628).
- ARM: dts: imx6sx-udoo-neo: don't use multiple blank lines
  (bsc#1012628).
- ARM: dts: imx6sl: use tabs for code indent (bsc#1012628).
- ARM: dts: imx6sx: add missing properties for sram (bsc#1012628).
- ARM: dts: imx6sll: add missing properties for sram
  (bsc#1012628).
- ARM: dts: imx6sl: add missing properties for sram (bsc#1012628).
- ARM: dts: imx6qp: add missing properties for sram (bsc#1012628).
- ARM: dts: imx6dl: add missing properties for sram (bsc#1012628).
- ARM: dts: imx6q: add missing properties for sram (bsc#1012628).
- arm64: dts: qcom: sc7280-idp: correct ADC channel node name
  and unit address (bsc#1012628).
- ARM: dts: imx7d-sdb: config the max pressure for tsc2046
  (bsc#1012628).
- ARM: dts: imx6: delete interrupts property if
  interrupts-extended is set (bsc#1012628).
- drm/amdkfd: Fix UBSAN shift-out-of-bounds warning (bsc#1012628).
- drm/amd/display: polling vid stream status in hpo dp blank
  (bsc#1012628).
- drm/amd/display: Remove interface for periodic interrupt 1
  (bsc#1012628).
- drm/dp: Don't rewrite link config when setting phy test pattern
  (bsc#1012628).
- mmc: sdhci-msm: add compatible string check for sdm670
  (bsc#1012628).
- drm/meson: remove drm bridges at aggregate driver unbind time
  (bsc#1012628).
- drm/meson: explicitly remove aggregate driver at module unload
  time (bsc#1012628).
- drm/meson: reorder driver deinit sequence to fix use-after-free
  bug (bsc#1012628).
- ASoC: amd: yc: Add Lenovo Yoga Slim 7 Pro X to quirks table
  (bsc#1012628).
- ASoC: amd: yc: Add ASUS UM5302TA into DMI table (bsc#1012628).
- drm/amdgpu: fix initial connector audio value (bsc#1012628).
- drm/amd/display: correct hostvm flag (bsc#1012628).
- drm/amd/display: Fix urgent latency override for DCN32/DCN321
  (bsc#1012628).
- drm/amdgpu: SDMA update use unlocked iterator (bsc#1012628).
- ASoC: SOF: add quirk to override topology mclk_id (bsc#1012628).
- ASoC: sunxi: sun4i-codec: set debugfs_prefix for CPU DAI
  component (bsc#1012628).
- ASoC: SOF: pci: Change DMI match info to support all Chrome
  platforms (bsc#1012628).
- ALSA: intel-dspconfig: add ES8336 support for AlderLake-PS
  (bsc#1012628).
- platform/x86: msi-laptop: Change DMI match / alias strings to
  fix module autoloading (bsc#1012628).
- platform/x86: hp-wmi: Setting thermal profile fails with 0x06
  (bsc#1012628).
- platform/chrome: cros_ec: Notify the PM of wake events during
  resume (bsc#1012628).
- drm: panel-orientation-quirks: Add quirk for Aya Neo Air
  (bsc#1012628).
- drm: panel-orientation-quirks: Add quirk for Anbernic Win600
  (bsc#1012628).
- drm/vc4: vec: Fix timings for VEC modes (bsc#1012628).
- ALSA: usb-audio: Register card at the last interface
  (bsc#1012628).
- drm/admgpu: Skip CG/PG on SOC21 under SRIOV VF (bsc#1012628).
- drm/amdgpu: Skip the program of MMMC_VM_AGP_* in SRIOV on
  MMHUB v3_0_0 (bsc#1012628).
- drm/amd/display: Fix variable dereferenced before check
  (bsc#1012628).
- drm: bridge: dw_hdmi: only trigger hotplug event on link change
  (bsc#1012628).
- drm/amd: fix potential memory leak (bsc#1012628).
- platform/x86: pmc_atom: Improve quirk message to be less cryptic
  (bsc#1012628).
- udmabuf: Set ubuf->sg = NULL if the creation of sg table fails
  (bsc#1012628).
- ALSA: usb-audio: Add quirk to enable Avid Mbox 3 support
  (bsc#1012628).
- ALSA: hda: Fix page fault in snd_hda_codec_shutdown()
  (bsc#1012628).
- drm/amd/display: fix overflow on MIN_I64 definition
  (bsc#1012628).
- gpu: lontium-lt9611: Fix NULL pointer dereference in
  lt9611_connector_init() (bsc#1012628).
- drm/komeda: Fix handling of atomic commits in the
  atomic_commit_tail hook (bsc#1012628).
- drm: Prevent drm_copy_field() to attempt copying a NULL pointer
  (bsc#1012628).
- drm: Use size_t type for len variable in drm_copy_field()
  (bsc#1012628).
- drm/nouveau/nouveau_bo: fix potential memory leak in
  nouveau_bo_alloc() (bsc#1012628).
- r8152: Rate limit overflow messages (bsc#1012628).
- i2c: designware-pci: Group AMD NAVI quirk parts together
  (bsc#1012628).
- libbpf: Fix overrun in netlink attribute iteration
  (bsc#1012628).
- net: sched: cls_u32: Avoid memcpy() false-positive warning
  (bsc#1012628).
- Bluetooth: L2CAP: Fix user-after-free (bsc#1012628).
- bpf: use bpf_prog_pack for bpf_dispatcher (bsc#1012628).
- bpf: Adjust kprobe_multi entry_ip for CONFIG_X86_KERNEL_IBT
  (bsc#1012628).
- net: If sock is dead don't access sock's sk_wq in
  sk_stream_wait_memory (bsc#1012628).
- hwmon: (sht4x) do not overflow clamping operation on 32-bit
  platforms (bsc#1012628).
- wifi: rt2x00: correctly set BBP register 86 for MT7620
  (bsc#1012628).
- wifi: rt2x00: set SoC wmac clock register (bsc#1012628).
- wifi: rt2x00: set VGC gain for both chains of MT7620
  (bsc#1012628).
- wifi: rt2x00: set correct TX_SW_CFG1 MAC register for MT7620
  (bsc#1012628).
- wifi: rt2x00: don't run Rt5592 IQ calibration on MT7620
  (bsc#1012628).
- can: bcm: check the result of can_send() in bcm_can_tx()
  (bsc#1012628).
- selftests/bpf: Free the allocated resources after test case
  succeeds (bsc#1012628).
- bnxt_en: replace reset with config timestamps (bsc#1012628).
- Bluetooth: hci_event: Make sure ISO events don't affect non-ISO
  connections (bsc#1012628).
- Bluetooth: hci_sysfs: Fix attempting to call device_add multiple
  times (bsc#1012628).
- Bluetooth: L2CAP: initialize delayed works at
  l2cap_chan_create() (bsc#1012628).
- wifi: rtw89: fix rx filter after scan (bsc#1012628).
- wifi: rtw89: free unused skb to prevent memory leak
  (bsc#1012628).
- wifi: mt76: mt7921: reset msta->airtime_ac while clearing up
  hw value (bsc#1012628).
- wifi: ath11k: mhi: fix potential memory leak in
  ath11k_mhi_register() (bsc#1012628).
- regulator: core: Prevent integer underflow (bsc#1012628).
- Bluetooth: btintel: Mark Intel controller to support LE_STATES
  quirk (bsc#1012628).
- wifi: brcmfmac: fix use-after-free bug in
  brcmf_netdev_start_xmit() (bsc#1012628).
- iavf: Fix race between iavf_close and iavf_reset_task
  (bsc#1012628).
- net: ftmac100: fix endianness-related issues from 'sparse'
  (bsc#1012628).
- rtw89: ser: leave lps with mutex (bsc#1012628).
- wifi: ath11k: Register shutdown handler for WCN6750
  (bsc#1012628).
- xfrm: Update ipcomp_scratches with NULL when freed
  (bsc#1012628).
- net-next: Fix IP_UNICAST_IF option behavior for connected
  sockets (bsc#1012628).
- net: axienet: Switch to 64-bit RX/TX statistics (bsc#1012628).
- x86/apic: Don't disable x2APIC if locked (bsc#1012628).
- thunderbolt: Add back Intel Falcon Ridge end-to-end flow
  control workaround (bsc#1012628).
- wifi: ath9k: avoid uninit memory read in ath9k_htc_rx_msg()
  (bsc#1012628).
- x86/mce: Retrieve poison range from hardware (bsc#1012628).
- wifi: mac80211: accept STA changes without link changes
  (bsc#1012628).
- micrel: ksz8851: fixes struct pointer issue (bsc#1012628).
- tcp: annotate data-race around tcp_md5sig_pool_populated
  (bsc#1012628).
- openvswitch: Fix overreporting of drops in dropwatch
  (bsc#1012628).
- openvswitch: Fix double reporting of drops in dropwatch
  (bsc#1012628).
- net: ethernet: ti: davinci_mdio: Add workaround for errata i2329
  (bsc#1012628).
- bpftool: Clear errno after libcap's checks (bsc#1012628).
- wifi: brcmfmac: fix invalid address access when enabling SCAN
  log level (bsc#1012628).
- libbpf: Do not require executable permission for shared
  libraries (bsc#1012628).
- libbpf: Ensure functions with always_inline attribute are inline
  (bsc#1012628).
- NFSD: fix use-after-free on source server when doing
  inter-server copy (bsc#1012628).
- NFSD: Return nfserr_serverfault if splice_ok but buf->pages
  have data (bsc#1012628).
- x86/entry: Work around Clang __bdos() bug (bsc#1012628).
- ACPI: x86: Add a quirk for Dell Inspiron 14 2-in-1 for
  StorageD3Enable (bsc#1012628).
- ARM: decompressor: Include .data.rel.ro.local (bsc#1012628).
- thermal: intel_powerclamp: Use get_cpu() instead of
  smp_processor_id() to avoid crash (bsc#1012628).
- powercap: intel_rapl: fix UBSAN shift-out-of-bounds issue
  (bsc#1012628).
- MIPS: BCM47XX: Cast memcmp() of function to (void *)
  (bsc#1012628).
- cpufreq: intel_pstate: Add Tigerlake support in no-HWP mode
  (bsc#1012628).
- ACPI: tables: FPDT: Don't call acpi_os_map_memory() on invalid
  phys address (bsc#1012628).
- fortify: Fix __compiletime_strlen() under UBSAN_BOUNDS_LOCAL
  (bsc#1012628).
- ACPI: video: Add Toshiba Satellite/Portege Z830 quirk
  (bsc#1012628).
- cpufreq: amd_pstate: fix wrong lowest perf fetch (bsc#1012628).
- rcu-tasks: Ensure RCU Tasks Trace loops have quiescent states
  (bsc#1012628).
- rcu-tasks: Convert RCU_LOCKDEP_WARN() to WARN_ONCE()
  (bsc#1012628).
- rcu: Back off upon fill_page_cache_func() allocation failure
  (bsc#1012628).
- rcu: Avoid triggering strict-GP irq-work when RCU is idle
  (bsc#1012628).
- fs: dlm: fix race in lowcomms (bsc#1012628).
- module: tracking: Keep a record of tainted unloaded modules only
  (bsc#1012628).
- ARM/dma-mapping: don't override ->dma_coherent when set from
  a bus notifier (bsc#1012628).
- selftest: tpm2: Add Client.__del__() to close /dev/tpm* handle
  (bsc#1012628).
- tools/power turbostat: Use standard Energy Unit for SPR Dram
  RAPL domain (bsc#1012628).
- f2fs: fix to account FS_CP_DATA_IO correctly (bsc#1012628).
- f2fs: fix race condition on setting FI_NO_EXTENT flag
  (bsc#1012628).
- ACPI: APEI: do not add task_work to kernel thread to avoid
  memory leak (bsc#1012628).
- thermal/drivers/qcom/tsens-v0_1: Fix MSM8939 fourth sensor hw_id
  (bsc#1012628).
- random: schedule jitter credit for next jiffy, not in two
  jiffies (bsc#1012628).
- crypto: cavium - prevent integer overflow loading firmware
  (bsc#1012628).
- crypto: marvell/octeontx - prevent integer overflows
  (bsc#1012628).
- kbuild: rpm-pkg: fix breakage when V=1 is used (bsc#1012628).
- linux/export: use inline assembler to populate symbol CRCs
  (bsc#1012628).
- kbuild: remove the target in signal traps when interrupted
  (bsc#1012628).
- ftrace: Fix recursive locking direct_mutex in
  ftrace_modify_direct_caller (bsc#1012628).
- tracing/osnoise: Fix possible recursive locking in
  stop_per_cpu_kthreads (bsc#1012628).
- tracing: kprobe: Make gen test module work in arm and riscv
  (bsc#1012628).
- tracing: kprobe: Fix kprobe event gen test module on exit
  (bsc#1012628).
- iommu/iova: Fix module config properly (bsc#1012628).
- cifs: return correct error in ->calc_signature() (bsc#1012628).
- clocksource/drivers/timer-gxp: Add missing error handling in
  gxp_timer_probe (bsc#1012628).
- clocksource/drivers/arm_arch_timer: Fix handling of ARM erratum
  858921 (bsc#1012628).
- crypto: qat - fix DMA transfer direction (bsc#1012628).
- crypto: inside-secure - Change swab to swab32 (bsc#1012628).
- crypto: ccp - Release dma channels before dmaengine unrgister
  (bsc#1012628).
- crypto: akcipher - default implementation for setting a private
  key (bsc#1012628).
- iommu/omap: Fix buffer overflow in debugfs (bsc#1012628).
- cgroup/cpuset: Enable update_tasks_cpumask() on top_cpuset
  (bsc#1012628).
- crypto: hisilicon/qm - fix missing put dfx access (bsc#1012628).
- crypto: qat - fix default value of WDT timer (bsc#1012628).
- hwrng: imx-rngc - Moving IRQ handler registering after
  imx_rngc_irq_mask_clear() (bsc#1012628).
- hwrng: imx-rngc - use devm_clk_get_enabled (bsc#1012628).
- cgroup: Honor caller's cgroup NS when resolving path
  (bsc#1012628).
- crypto: ccp - Fail the PSP initialization when writing psp
  data file failed (bsc#1012628).
- hwrng: arm-smccc-trng - fix NO_ENTROPY handling (bsc#1012628).
- crypto: hisilicon/zip - fix mismatch in get/set sgl_sge_nr
  (bsc#1012628).
- crypto: sahara - don't sleep when in softirq (bsc#1012628).
- powerpc/pseries/vas: Pass hw_cpu_id to node associativity HCALL
  (bsc#1012628).
- powerpc/kprobes: Fix null pointer reference in
  arch_prepare_kprobe() (bsc#1012628).
- powerpc: Fix SPE Power ISA properties for e500v1 platforms
  (bsc#1012628).
- powerpc/64/interrupt: Fix return to masked context after
  hard-mask irq becomes pending (bsc#1012628).
- powerpc/64: mark irqs hard disabled in boot paca (bsc#1012628).
- powerpc/64/interrupt: Fix false warning in context tracking
  due to idle state (bsc#1012628).
- powerpc/64s: Fix GENERIC_CPU build flags for PPC970 / G5
  (bsc#1012628).
- x86/hyperv: Fix 'struct hv_enlightened_vmcs' definition
  (bsc#1012628).
- powerpc: Fix fallocate and fadvise64_64 compat parameter
  combination (bsc#1012628).
- powerpc: dts: turris1x.dts: Fix labels in DSA cpu port nodes
  (bsc#1012628).
- powerpc: dts: turris1x.dts: Fix NOR partitions labels
  (bsc#1012628).
- cpuidle: riscv-sbi: Fix CPU_PM_CPU_IDLE_ENTER_xyz() macro usage
  (bsc#1012628).
- powerpc/powernv: add missing of_node_put() in
  opal_export_attrs() (bsc#1012628).
- powerpc/pci_dn: Add missing of_node_put() (bsc#1012628).
- powerpc/sysdev/fsl_msi: Add missing of_node_put() (bsc#1012628).
- powerpc/math_emu/efp: Include module.h (bsc#1012628).
- powerpc/configs: Properly enable PAPR_SCM in pseries_defconfig
  (bsc#1012628).
- ipc: mqueue: fix possible memory leak in init_mqueue_fs()
  (bsc#1012628).
- mailbox: bcm-ferxrm-mailbox: Fix error check for dma_map_sg
  (bsc#1012628).
- mailbox: mpfs: account for mbox offsets while sending
  (bsc#1012628).
- mailbox: mpfs: fix handling of the reg property (bsc#1012628).
- mailbox: imx: fix RST channel support (bsc#1012628).
- clk: ast2600: BCLK comes from EPLL (bsc#1012628).
- clk: ti: dra7-atl: Fix reference leak in of_dra7_atl_clk_probe
  (bsc#1012628).
- clk: ti: Balance of_node_get() calls for of_find_node_by_name()
  (bsc#1012628).
- clk: imx: scu: fix memleak on platform_device_add() fails
  (bsc#1012628).
- clk: imx8mp: tune the order of enet_qos_root_clk (bsc#1012628).
- clk: bcm2835: fix bcm2835_clock_rate_from_divisor declaration
  (bsc#1012628).
- clk: bcm2835: Make peripheral PLLC critical (bsc#1012628).
- clk: baikal-t1: Add SATA internal ref clock buffer
  (bsc#1012628).
- clk: baikal-t1: Add shared xGMAC ref/ptp clocks internal parent
  (bsc#1012628).
- clk: baikal-t1: Fix invalid xGMAC PTP clock divider
  (bsc#1012628).
- clk: vc5: Fix 5P49V6901 outputs disabling when enabling FOD
  (bsc#1012628).
- spmi: pmic-arb: correct duplicate APID to PPID mapping logic
  (bsc#1012628).
- usb: mtu3: fix failed runtime suspend in host only mode
  (bsc#1012628).
- HID: amd_sfh: Handle condition of "no sensors" for SFH1.1
  (bsc#1012628).
- dmaengine: ioat: stop mod_timer from resurrecting deleted
  timer in __cleanup() (bsc#1012628).
- io_uring/rw: defer fsnotify calls to task context (bsc#1012628).
- clk: mediatek: Migrate remaining clk_unregister_*() to
  clk_hw_unregister_*() (bsc#1012628).
- clk: mediatek: fix unregister function in
  mtk_clk_register_dividers cleanup (bsc#1012628).
- clk: mediatek: clk-mt8195-mfg: Reparent mfg_bg3d and propagate
  rate changes (bsc#1012628).
- clk: mediatek: mt8183: mfgcfg: Propagate rate changes to parent
  (bsc#1012628).
- mfd: da9061: Fix Failed to set Two-Wire Bus Mode (bsc#1012628).
- mfd: sm501: Add check for platform_driver_register()
  (bsc#1012628).
- mfd: fsl-imx25: Fix check for platform_get_irq() errors
  (bsc#1012628).
- mfd: lp8788: Fix an error handling path in lp8788_irq_init()
  and lp8788_irq_init() (bsc#1012628).
- mfd: lp8788: Fix an error handling path in lp8788_probe()
  (bsc#1012628).
- mfd: fsl-imx25: Fix an error handling path in
  mx25_tsadc_setup_irq() (bsc#1012628).
- mfd: intel_soc_pmic: Fix an error handling path in
  intel_soc_pmic_i2c_probe() (bsc#1012628).
- fsi: core: Check error number after calling ida_simple_get
  (bsc#1012628).
- RDMA/rxe: Fix resize_finish() in rxe_queue.c (bsc#1012628).
- RDMA/rxe: Set pd early in mr alloc routines (bsc#1012628).
- nvmet-auth: don't try to cancel a non-initialized work_struct
  (bsc#1012628).
- clk: qcom: gcc-sm6115: Override default Alpha PLL regs
  (bsc#1012628).
- clk: qcom: apss-ipq6018: mark apcs_alias0_core_clk as critical
  (bsc#1012628).
- scsi: iscsi: iscsi_tcp: Fix null-ptr-deref while calling
  getpeername() (bsc#1012628).
- scsi: pm8001: Fix running_req for internal abort commands
  (bsc#1012628).
- scsi: libsas: Fix use-after-free bug in smp_execute_task_sg()
  (bsc#1012628).
- serial: 8250: Fix restoring termios speed after suspend
  (bsc#1012628).
- firmware: google: Test spinlock on panic path to avoid lockups
  (bsc#1012628).
- slimbus: qcom-ngd: Add error handling in
  of_qcom_slim_ngd_register (bsc#1012628).
- staging: vt6655: fix some erroneous memory clean-up loops
  (bsc#1012628).
- phy: qualcomm: call clk_disable_unprepare in the error handling
  (bsc#1012628).
- tty: serial: fsl_lpuart: disable dma rx/tx use flags in
  lpuart_dma_shutdown (bsc#1012628).
- serial: 8250: Toggle IER bits on only after irq has been set up
  (bsc#1012628).
- drivers: serial: jsm: fix some leaks in probe (bsc#1012628).
- usb: dwc3: core: fix some leaks in probe (bsc#1012628).
- usb: typec: anx7411: Use of_get_child_by_name() instead of
  of_find_node_by_name() (bsc#1012628).
- usb: gadget: function: fix dangling pnp_string in f_printer.c
  (bsc#1012628).
- xhci: Don't show warning for reinit on known broken suspend
  (bsc#1012628).
- IB: Set IOVA/LENGTH on IB_MR in core/uverbs layers
  (bsc#1012628).
- RDMA/cm: Use SLID in the work completion as the DLID in
  responder side (bsc#1012628).
- md: Remove extra mddev_get() in md_seq_start() (bsc#1012628).
- md/raid5: Remove unnecessary bio_put() in raid5_read_one_chunk()
  (bsc#1012628).
- md/raid5: Ensure stripe_fill happens on non-read IO with journal
  (bsc#1012628).
- md: Replace snprintf with scnprintf (bsc#1012628).
- io_uring/fdinfo: fix sqe dumping for IORING_SETUP_SQE128
  (bsc#1012628).
- eventfd: guard wake_up in eventfd fs calls as well
  (bsc#1012628).
- block: Fix the enum blk_eh_timer_return documentation
  (bsc#1012628).
- mtd: rawnand: meson: fix bit map use in meson_nfc_ecc_correct()
  (bsc#1012628).
- ata: fix ata_id_has_dipm() (bsc#1012628).
- ata: fix ata_id_has_ncq_autosense() (bsc#1012628).
- ata: fix ata_id_has_devslp() (bsc#1012628).
- ata: fix ata_id_sense_reporting_enabled() and
  ata_id_has_sense_reporting() (bsc#1012628).
- RDMA/siw: Fix QP destroy to wait for all references dropped
  (bsc#1012628).
- RDMA/siw: Always consume all skbuf data in sk_data_ready()
  upcall (bsc#1012628).
- RDMA/srp: Fix srp_abort() (bsc#1012628).
- RDMA/irdma: Validate udata inlen and outlen (bsc#1012628).
- RDMA/irdma: Align AE id codes to correct flush code and event
  (bsc#1012628).
- mtd: rawnand: fsl_elbc: Fix none ECC mode (bsc#1012628).
- mtd: rawnand: intel: Remove undocumented compatible string
  (bsc#1012628).
- mtd: rawnand: intel: Read the chip-select line from the correct
  OF node (bsc#1012628).
- phy: phy-mtk-tphy: fix the phy type setting issue (bsc#1012628).
- phy: amlogic: phy-meson-axg-mipi-pcie-analog: Hold reference
  returned by of_get_parent() (bsc#1012628).
- phy: qcom-qmp-usb: disable runtime PM on unbind (bsc#1012628).
- remoteproc: Harden rproc_handle_vdev() against integer overflow
  (bsc#1012628).
- mtd: devices: docg3: check the return value of devm_ioremap()
  in the probe (bsc#1012628).
- scsi: lpfc: Fix various issues reported by tools (bsc#1012628).
- clk: qcom: sm6115: Select QCOM_GDSC (bsc#1012628).
- dyndbg: drop EXPORTed dynamic_debug_exec_queries (bsc#1012628).
- dyndbg: let query-modname override actual module name
  (bsc#1012628).
- dyndbg: fix module.dyndbg handling (bsc#1012628).
- dyndbg: fix static_branch manipulation (bsc#1012628).
- usb: gadget: f_fs: stricter integer overflow checks
  (bsc#1012628).
- iio: Use per-device lockdep class for mlock (bsc#1012628).
- dmaengine: hisilicon: Add multi-thread support for a DMA channel
  (bsc#1012628).
- dmaengine: hisilicon: Fix CQ head update (bsc#1012628).
- dmaengine: hisilicon: Disable channels when unregister hisi_dma
  (bsc#1012628).
- dmaengine: idxd: avoid deadlock in process_misc_interrupts()
  (bsc#1012628).
- phy: rockchip-inno-usb2: Return zero after otg sync
  (bsc#1012628).
- fpga: prevent integer overflow in dfl_feature_ioctl_set_irq()
  (bsc#1012628).
- fpga: dfl-pci: Add IDs for Intel N6000, N6001 and C6100 cards
  (bsc#1012628).
- misc: ocxl: fix possible refcount leak in afu_ioctl()
  (bsc#1012628).
- clk: mediatek: mt8195-infra_ao: Set pwrmcu clocks as critical
  (bsc#1012628).
- clk: mediatek: clk-mt8195-vdo1: Reparent and set rate on
  vdo1_dpintf's parent (bsc#1012628).
- clk: mediatek: clk-mt8195-vdo0: Set rate on
  vdo0_dp_intf0_dp_intf's parent (bsc#1012628).
- RDMA/rxe: Fix the error caused by qp->sk (bsc#1012628).
- RDMA/rxe: Fix "kernel NULL pointer dereference" error
  (bsc#1012628).
- media: xilinx: vipp: Fix refcount leak in xvip_graph_dma_init
  (bsc#1012628).
- media: uvcvideo: Use entity get_cur in uvc_ctrl_set
  (bsc#1012628).
- media: uvcvideo: Fix memory leak in uvc_gpio_parse
  (bsc#1012628).
- media: meson: vdec: add missing clk_disable_unprepare on error
  in vdec_hevc_start() (bsc#1012628).
- media: amphion: fix a bug that vpu core may not resume after
  suspend (bsc#1012628).
- media: amphion: don't change the colorspace reported by decoder
  (bsc#1012628).
- media: amphion: adjust the encoder's value range of gop size
  (bsc#1012628).
- media: amphion: insert picture startcode after seek for vc1g
  format (bsc#1012628).
- media: mediatek: vcodec: Skip non CBR bitrate mode
  (bsc#1012628).
- tty: xilinx_uartps: Fix the ignore_status (bsc#1012628).
- tty: xilinx_uartps: Check clk_enable return value (bsc#1012628).
- media: airspy: fix memory leak in airspy probe (bsc#1012628).
- media: exynos4-is: fimc-is: Add of_node_put() when breaking
  out of loop (bsc#1012628).
- clk: qcom: gcc-sdm660: Use floor ops for SDCC1 clock
  (bsc#1012628).
- HSI: omap_ssi_port: Fix dma_map_sg error check (bsc#1012628).
- HSI: omap_ssi: Fix refcount leak in ssi_probe (bsc#1012628).
- HID: uclogic: Fix warning in uclogic_rdesc_template_apply
  (bsc#1012628).
- HID: uclogic: Add missing suffix for digitalizers (bsc#1012628).
- clk: samsung: exynosautov9: correct register offsets of
  peric0/c1 (bsc#1012628).
- clk: tegra20: Fix refcount leak in tegra20_clock_init
  (bsc#1012628).
- clk: tegra: Fix refcount leak in tegra114_clock_init
  (bsc#1012628).
- clk: tegra: Fix refcount leak in tegra210_clock_init
  (bsc#1012628).
- coresight: docs: Fix a broken reference (bsc#1012628).
- clk: sprd: Hold reference returned by of_get_parent()
  (bsc#1012628).
- clk: berlin: Add of_node_put() for of_get_parent()
  (bsc#1012628).
- clk: qoriq: Hold reference returned by of_get_parent()
  (bsc#1012628).
- clk: oxnas: Hold reference returned by of_get_parent()
  (bsc#1012628).
- clk: st: Hold reference returned by of_get_parent()
  (bsc#1012628).
- clk: meson: Hold reference returned by of_get_parent()
  (bsc#1012628).
- usb: common: debug: Check non-standard control requests
  (bsc#1012628).
- usb: common: usb-conn-gpio: Simplify some error message
  (bsc#1012628).
- RDMA/mlx5: Don't compare mkey tags in DEVX indirect mkey
  (bsc#1012628).
- iio: magnetometer: yas530: Change data type of hard_offsets
  to signed (bsc#1012628).
- iio: ABI: Fix wrong format of differential capacitance channel
  ABI (bsc#1012628).
- iio: inkern: fix return value in
  devm_of_iio_channel_get_by_name() (bsc#1012628).
- iio: inkern: only release the device node when done with it
  (bsc#1012628).
- iio: adc: at91-sama5d2_adc: disable/prepare buffer on
  suspend/resume (bsc#1012628).
- iio: adc: at91-sama5d2_adc: lock around oversampling and sample
  freq (bsc#1012628).
- iio: adc: at91-sama5d2_adc: check return status for pressure
  and touch (bsc#1012628).
- iio: adc: at91-sama5d2_adc: fix AT91_SAMA5D2_MR_TRACKTIM_MAX
  (bsc#1012628).
- selftests/cpu-hotplug: Reserve one cpu online at least
  (bsc#1012628).
- selftests/cpu-hotplug: Delete fault injection related code
  (bsc#1012628).
- selftests/cpu-hotplug: Use return instead of exit (bsc#1012628).
- iomap: iomap: fix memory corruption when recording errors
  during writeback (bsc#1012628).
- ARM: dts: exynos: fix polarity of VBUS GPIO of Origen
  (bsc#1012628).
- arm64: dts: exynos: fix polarity of "enable" line of NFC chip
  in TM2 (bsc#1012628).
- arm64: ftrace: fix module PLTs with mcount (bsc#1012628).
- ext4: don't run ext4lazyinit for read-only filesystems
  (bsc#1012628).
- ext4: continue to expand file system when the target size
  doesn't reach (bsc#1012628).
- ARM: Drop CMDLINE_* dependency on ATAGS (bsc#1012628).
- ARM: dts: exynos: correct s5k6a3 reset polarity on Midas family
  (bsc#1012628).
- arm64: dts: ti: k3-j7200: fix main pinmux range (bsc#1012628).
- arm64: dts: qcom: sm8450: fix UFS PHY serdes size (bsc#1012628).
- arm64: dts: qcom: ipq8074: fix PCIe PHY serdes size
  (bsc#1012628).
- soc/tegra: fuse: Drop Kconfig dependency on TEGRA20_APB_DMA
  (bsc#1012628).
- soc/tegra: fuse: Add missing of_node_put() in tegra_init_fuse()
  (bsc#1012628).
- arm64: dts: qcom: sm8350-sagami: correct TS pin property
  (bsc#1012628).
- ia64: export memory_add_physaddr_to_nid to fix cxl build error
  (bsc#1012628).
- arm64: dts: marvell: 98dx25xx: use correct property for i2c
  gpios (bsc#1012628).
- ARM: dts: kirkwood: lsxl: remove first ethernet port
  (bsc#1012628).
- ARM: dts: kirkwood: lsxl: fix serial line (bsc#1012628).
- ARM: dts: turris-omnia: Fix mpp26 pin name and comment
  (bsc#1012628).
- arm64: dts: qcom: sc7180-trogdor: Keep pm6150_adc enabled for TZ
  (bsc#1012628).
- arm64: dts: qcom: pm8350c: Drop PWM reg declaration
  (bsc#1012628).
- arm64: dts: qcom: sa8295p-adp: disallow regulator mode switches
  (bsc#1012628).
- arm64: dts: qcom: sc8280xp-lenovo-thinkpad-x13s: disallow
  regulator mode switches (bsc#1012628).
- arm64: dts: qcom: sc8280xp-crd: disallow regulator mode switches
  (bsc#1012628).
- arm64: dts: qcom: sc7280: Update lpasscore node (bsc#1012628).
- arm64: dts: qcom: sc7280: Cleanup the lpasscc node
  (bsc#1012628).
- arm64: dts: qcom: sdm845-xiaomi-polaris: Fix sde_dsi_active
  pinctrl (bsc#1012628).
- dt-bindings: clock: exynosautov9: correct clock numbering of
  peric0/c1 (bsc#1012628).
- arm64: dts: renesas: r9a07g043: Fix SCI{Rx,Tx} interrupt types
  (bsc#1012628).
- arm64: dts: renesas: r9a07g054: Fix SCI{Rx,Tx} interrupt types
  (bsc#1012628).
- arm64: dts: renesas: r9a07g044: Fix SCI{Rx,Tx} interrupt types
  (bsc#1012628).
- ARM: dts: imx6qdl-kontron-samx6i: hook up DDC i2c bus
  (bsc#1012628).
- soc: qcom: smem_state: Add refcounting for the 'state->of_node'
  (bsc#1012628).
- soc: qcom: smsm: Fix refcount leak bugs in qcom_smsm_probe()
  (bsc#1012628).
- locks: fix TOCTOU race when granting write lease (bsc#1012628).
- memory: of: Fix refcount leak bug in of_lpddr3_get_ddr_timings()
  (bsc#1012628).
- memory: of: Fix refcount leak bug in of_get_ddr_timings()
  (bsc#1012628).
- memory: pl353-smc: Fix refcount leak bug in pl353_smc_probe()
  (bsc#1012628).
- ALSA: hda/hdmi: Don't skip notification handling during PM
  operation (bsc#1012628).
- ASoC: rockchip: i2s: use regmap_read_poll_timeout_atomic to
  poll I2S_CLR (bsc#1012628).
- ASoC: mt6660: Fix PM disable depth imbalance in mt6660_i2c_probe
  (bsc#1012628).
- ASoC: wm5102: Fix PM disable depth imbalance in wm5102_probe
  (bsc#1012628).
- ASoC: wm5110: Fix PM disable depth imbalance in wm5110_probe
  (bsc#1012628).
- ASoC: wm8997: Fix PM disable depth imbalance in wm8997_probe
  (bsc#1012628).
- ASoC: wcd-mbhc-v2: Revert "ASoC: wcd-mbhc-v2: use
  pm_runtime_resume_and_get()" (bsc#1012628).
- ASoC: stm: Fix PM disable depth imbalance in stm32_i2s_probe
  (bsc#1012628).
- ASoC: stm32: spdifrx: Fix PM disable depth imbalance in
  stm32_spdifrx_probe (bsc#1012628).
- ASoC: stm32: dfsdm: Fix PM disable depth imbalance in
  stm32_adfsdm_probe (bsc#1012628).
- mmc: wmt-sdmmc: Fix an error handling path in wmt_mci_probe()
  (bsc#1012628).
- ALSA: dmaengine: increment buffer pointer atomically
  (bsc#1012628).
- ASoC: da7219: Fix an error handling path in
  da7219_register_dai_clks() (bsc#1012628).
- ASoC: codecs: tx-macro: fix kcontrol put (bsc#1012628).
- virtio-gpu: fix shift wrapping bug in
  virtio_gpu_fence_event_create() (bsc#1012628).
- drm/vmwgfx: Fix memory leak in vmw_mksstat_add_ioctl()
  (bsc#1012628).
- ASoC: SOF: ipc4-topology: Free the ida when IPC fails in
  sof_ipc4_widget_setup() (bsc#1012628).
- ALSA: usb-audio: Properly refcounting clock rate (bsc#1012628).
- ALSA: hda/hdmi: Fix the converter allocation for the silent
  stream (bsc#1012628).
- ALSA: hda/hdmi: change type for the 'assigned' variable
  (bsc#1012628).
- drm/msm/dp: correct 1.62G link rate at
  dp_catalog_ctrl_config_msa() (bsc#1012628).
- drm/msm/dpu: index dpu_kms->hw_vbif using vbif_idx
  (bsc#1012628).
- drm/msm: lookup the ICC paths in both mdp5/dpu and mdss devices
  (bsc#1012628).
- ASoC: eureka-tlv320: Hold reference returned from of_find_xxx
  API (bsc#1012628).
- mmc: au1xmmc: Fix an error handling path in au1xmmc_probe()
  (bsc#1012628).
- ASoC: rockchip: i2s: use regmap_read_poll_timeout to poll
  I2S_CLR (bsc#1012628).
- drm/amdgpu: Fix memory leak in hpd_rx_irq_create_workqueue()
  (bsc#1012628).
- drm/omap: dss: Fix refcount leak bugs (bsc#1012628).
- ASoC: SOF: mediatek: mt8195: Import namespace
  SND_SOC_SOF_MTK_COMMON (bsc#1012628).
- ASoC: mediatek: mt8195-mt6359: Properly register sound card
  for SOF (bsc#1012628).
- drm/bochs: fix blanking (bsc#1012628).
- drm/virtio: set fb_modifiers_not_supported (bsc#1012628).
- ALSA: hda: beep: Simplify keep-power-at-enable behavior
  (bsc#1012628).
- ASoC: wm_adsp: Handle optional legacy support (bsc#1012628).
- ASoC: rsnd: Add check for rsnd_mod_power_on (bsc#1012628).
- drm/bridge: it6505: Fix the order of DP_SET_POWER commands
  (bsc#1012628).
- drm/bridge: megachips: Fix a null pointer dereference bug
  (bsc#1012628).
- drm/amdgpu: add missing pci_disable_device() in
  amdgpu_pmops_runtime_resume() (bsc#1012628).
- platform/chrome: cros_ec_typec: Correct alt mode index
  (bsc#1012628).
- platform/chrome: cros_ec_typec: Add bit offset for DP VDO
  (bsc#1012628).
- drm: fix drm_mipi_dbi build errors (bsc#1012628).
- drm/panel: use 'select' for Ili9341 panel driver helpers
  (bsc#1012628).
- platform/x86: msi-laptop: Fix resource cleanup (bsc#1012628).
- platform/x86: msi-laptop: Fix old-ec check for backlight
  registering (bsc#1012628).
- ASoC: tas2764: Fix mute/unmute (bsc#1012628).
- ASoC: tas2764: Drop conflicting set_bias_level power setting
  (bsc#1012628).
- ASoC: tas2764: Allow mono streams (bsc#1012628).
- ASoC: soc-pcm.c: call __soc_pcm_close() in soc_pcm_close()
  (bsc#1012628).
- drm/virtio: Fix same-context optimization (bsc#1012628).
- drm/i915/dg2: Bump up CDCLK for DG2 (bsc#1012628).
- platform/chrome: fix memory corruption in ioctl (bsc#1012628).
- platform/chrome: fix double-free in chromeos_laptop_prepare()
  (bsc#1012628).
- drm/msm: Make .remove and .shutdown HW shutdown consistent
  (bsc#1012628).
- ASoC: amd: acp: add missing platform_device_unregister()
  in acp_pci_probe() (bsc#1012628).
- ASoC: mt6359: fix tests for platform_get_irq() failure
  (bsc#1012628).
- drm:pl111: Add of_node_put() when breaking out of
  for_each_available_child_of_node() (bsc#1012628).
- drm/dp_mst: fix drm_dp_dpcd_read return value checks
  (bsc#1012628).
- drm/format-helper: Fix test on big endian architectures
  (bsc#1012628).
- drm/bridge: parade-ps8640: Fix regulator supply order
  (bsc#1012628).
- drm/bridge: tc358767: Add of_node_put() when breaking out of
  loop (bsc#1012628).
- drm/bridge: anx7625: Fix refcount bug in anx7625_parse_dt()
  (bsc#1012628).
- drm/virtio: Correct drm_gem_shmem_get_sg_table() error handling
  (bsc#1012628).
- video/aperture: Disable and unregister sysfb devices via
  aperture helpers (bsc#1012628).
- drm/bridge: it6505: Power on downstream device in .atomic_enable
  (bsc#1012628).
- drm/vc4: drv: Call component_unbind_all() (bsc#1012628).
- drm/mipi-dsi: Detach devices when removing the host
  (bsc#1012628).
- drm/bridge: Avoid uninitialized variable warning (bsc#1012628).
- drm: bridge: adv7511: unregister cec i2c device after cec
  adapter (bsc#1012628).
- drm: bridge: adv7511: fix CEC power down control register offset
  (bsc#1012628).
- net: mvpp2: fix mvpp2 debugfs leak (bsc#1012628).
- once: add DO_ONCE_SLOW() for sleepable contexts (bsc#1012628).
- net/ieee802154: reject zero-sized raw_sendmsg() (bsc#1012628).
- net: wwan: iosm: Call mutex_init before locking it
  (bsc#1012628).
- eth: sp7021: fix use after free bug in
  spl2sw_nvmem_get_mac_address (bsc#1012628).
- bnx2x: fix potential memory leak in bnx2x_tpa_stop()
  (bsc#1012628).
- eth: lan743x: reject extts for non-pci11x1x devices
  (bsc#1012628).
- net: prestera: acl: Add check for kmemdup (bsc#1012628).
- af_unix: Fix memory leaks of the whole sk due to OOB skb
  (bsc#1012628).
- net: rds: don't hold sock lock when cancelling work from
  rds_tcp_reset_callbacks() (bsc#1012628).
- hwmon: (pmbus/mp2888) Fix sensors readouts for MPS Multi-phase
  mp2888 controller (bsc#1012628).
- Bluetooth: hci_sync: Fix not indicating power state
  (bsc#1012628).
- spi: Ensure that sg_table won't be used after being freed
  (bsc#1012628).
- tcp: fix tcp_cwnd_validate() to not forget is_cwnd_limited
  (bsc#1012628).
- sctp: handle the error returned from
  sctp_auth_asoc_init_active_key (bsc#1012628).
- mISDN: fix use-after-free bugs in l1oip timer handlers
  (bsc#1012628).
- eth: alx: take rtnl_lock on resume (bsc#1012628).
- vhost/vsock: Use kvmalloc/kvfree for larger packets
  (bsc#1012628).
- wifi: rtl8xxxu: Fix AIFS written to REG_EDCA_*_PARAM
  (bsc#1012628).
- wifi: rtl8xxxu: gen2: Enable 40 MHz channel width (bsc#1012628).
- Bluetooth: Prevent double register of suspend (bsc#1012628).
- spi: s3c64xx: Fix large transfers with DMA (bsc#1012628).
- netfilter: nft_fib: Fix for rpath check with VRF devices
  (bsc#1012628).
- xfrm: Reinject transport-mode packets through workqueue
  (bsc#1012628).
- Bluetooth: hci_core: Fix not handling link timeouts propertly
  (bsc#1012628).
- i2c: mlxbf: support lock mechanism (bsc#1012628).
- libbpf: Don't require full struct enum64 in UAPI headers
  (bsc#1012628).
- cw1200: fix incorrect check to determine if no element is
  found in list (bsc#1012628).
- skmsg: Schedule psock work if the cached skb exists on the psock
  (bsc#1012628).
- spi/omap100k:Fix PM disable depth imbalance in
  omap1_spi100k_probe (bsc#1012628).
- spi: dw: Fix PM disable depth imbalance in dw_spi_bt1_probe
  (bsc#1012628).
- spi: cadence-quadspi: Fix PM disable depth imbalance in
  cqspi_probe (bsc#1012628).
- x86/cpu: Include the header of init_ia32_feat_ctl()'s prototype
  (bsc#1012628).
- wifi: ath11k: fix peer addition/deletion error on sta band
  migration (bsc#1012628).
- libbpf: restore memory layout of bpf_object_open_opts
  (bsc#1012628).
- x86/microcode/AMD: Track patch allocation size explicitly
  (bsc#1012628).
- mips: dts: ralink: mt7621: fix external phy on GB-PC2
  (bsc#1012628).
- wifi: ath11k: fix number of VHT beamformee spatial streams
  (bsc#1012628).
- wifi: ath11k: fix failed to find the peer with peer_id 0 when
  disconnected (bsc#1012628).
- mwifiex: fix sleep in atomic context bugs caused by
  dev_coredumpv (bsc#1012628).
- flow_dissector: Do not count vlan tags inside tunnel payload
  (bsc#1012628).
- selftests/bpf: Adapt cgroup effective query uapi change
  (bsc#1012628).
- bpftool: Fix wrong cgroup attach flags being assigned to
  effective progs (bsc#1012628).
- bpf, cgroup: Reject prog_attach_flags array when effective query
  (bsc#1012628).
- netfilter: conntrack: revisit the gc initial rescheduling bias
  (bsc#1012628).
- netfilter: conntrack: fix the gc rescheduling delay
  (bsc#1012628).
- libbpf: Fix NULL pointer exception in API
  btf_dump__dump_type_data (bsc#1012628).
- Bluetooth: hci_{ldisc,serdev}: check percpu_init_rwsem()
  failure (bsc#1012628).
- wifi: ath11k: Include STA_KEEPALIVE_ARP_RESPONSE TLV header
  by default (bsc#1012628).
- libbpf: Fix crash if SEC("freplace") programs don't have
  attach_prog_fd set (bsc#1012628).
- bpf: Ensure correct locking around vulnerable function
  find_vpid() (bsc#1012628).
- net: fs_enet: Fix wrong check in do_pd_setup (bsc#1012628).
- Bluetooth: RFCOMM: Fix possible deadlock on socket
  shutdown/release (bsc#1012628).
- wifi: mt76: mt7921e: fix rmmod crash in driver reload test
  (bsc#1012628).
- wifi: mt76: mt7915: do not check state before configuring
  implicit beamform (bsc#1012628).
- wifi: mt76: fix uninitialized pointer in mt7921_mac_fill_rx
  (bsc#1012628).
- wifi: mt76: mt7915: fix mcs value in ht mode (bsc#1012628).
- wifi: mt76: mt7921: fix the firmware version report
  (bsc#1012628).
- wifi: mt76: mt7921: add mt7921_mutex_acquire at
  mt7921_sta_set_decap_offload (bsc#1012628).
- wifi: mt76: mt7921: add mt7921_mutex_acquire at mt7921_[start,
  stop]_ap (bsc#1012628).
- wifi: mt76: connac: fix possible unaligned access in
  mt76_connac_mcu_add_nested_tlv (bsc#1012628).
- wifi: mt76: mt7915: fix possible unaligned access in
  mt7915_mac_add_twt_setup (bsc#1012628).
- wifi: mt76: mt7615: add mt7615_mutex_acquire/release in
  mt7615_sta_set_decap_offload (bsc#1012628).
- wifi: mt76: sdio: fix transmitting packet hangs (bsc#1012628).
- wifi: mt76: mt7921: fix use after free in mt7921_acpi_read()
  (bsc#1012628).
- wifi: mt76: mt7915: fix an uninitialized variable bug
  (bsc#1012628).
- wifi: mt76: sdio: poll sta stat when device transmits data
  (bsc#1012628).
- wifi: mt76: sdio: fix the deadlock caused by sdio->stat_work
  (bsc#1012628).
- wifi: mt76: mt7921u: fix race issue between reset and
  suspend/resume (bsc#1012628).
- wifi: mt76: mt7921s: fix race issue between reset and
  suspend/resume (bsc#1012628).
- wifi: mt76: mt7921e: fix race issue between reset and
  suspend/resume (bsc#1012628).
- Bluetooth: avoid hci_dev_test_and_set_flag() in mgmt_init_hdev()
  (bsc#1012628).
- wifi: rtl8xxxu: Remove copy-paste leftover in
  gen2_update_rate_mask (bsc#1012628).
- wifi: rtl8xxxu: gen2: Fix mistake in path B IQ calibration
  (bsc#1012628).
- bpf: btf: fix truncated last_member_type_id in
  btf_struct_resolve (bsc#1012628).
- spi: meson-spicc: do not rely on busy flag in pow2 clk ops
  (bsc#1012628).
- wifi: rtl8xxxu: Fix skb misuse in TX queue selection
  (bsc#1012628).
- spi: qup: add missing clk_disable_unprepare on error in
  spi_qup_pm_resume_runtime() (bsc#1012628).
- spi: qup: add missing clk_disable_unprepare on error in
  spi_qup_resume() (bsc#1012628).
- wifi: mac80211: mlme: assign link address correctly
  (bsc#1012628).
- selftests/xsk: Avoid use-after-free on ctx (bsc#1012628).
- wifi: rtw88: add missing destroy_workqueue() on error path in
  rtw_core_init() (bsc#1012628).
- wifi: wfx: prevent underflow in wfx_send_pds() (bsc#1012628).
- wifi: rtl8xxxu: tighten bounds checking in rtl8xxxu_read_efuse()
  (bsc#1012628).
- wifi: rtw89: pci: correct TX resource checking in low power mode
  (bsc#1012628).
- wifi: rtw89: pci: fix interrupt stuck after leaving low power
  mode (bsc#1012628).
- bpf: Only add BTF IDs for socket security hooks when
  CONFIG_SECURITY_NETWORK is on (bsc#1012628).
- Bluetooth: btusb: mediatek: fix WMT failure during runtime
  suspend (bsc#1012628).
- bpf: Use this_cpu_{inc_return|dec} for prog->active
  (bsc#1012628).
- bpf: Use this_cpu_{inc|dec|inc_return} for bpf_task_storage_busy
  (bsc#1012628).
- wifi: ath11k: Fix incorrect QMI message ID mappings
  (bsc#1012628).
- bpf: Propagate error from htab_lock_bucket() to userspace
  (bsc#1012628).
- bpf: Disable preemption when increasing per-cpu map_locked
  (bsc#1012628).
- selftests/xsk: Add missing close() on netns fd (bsc#1012628).
- xsk: Fix backpressure mechanism on Tx (bsc#1012628).
- x86/resctrl: Fix to restore to original value when re-enabling
  hardware prefetch register (bsc#1012628).
- spi: mt7621: Fix an error message in mt7621_spi_probe()
  (bsc#1012628).
- esp: choose the correct inner protocol for GSO on inter address
  family tunnels (bsc#1012628).
- audit: free audit_proctitle only on task exit (bsc#1012628).
- audit: explicitly check audit_context->context enum value
  (bsc#1012628).
- ice: set tx_tstamps when creating new Tx rings via ethtool
  (bsc#1012628).
- bpftool: Fix a wrong type cast in btf_dumper_int (bsc#1012628).
- wifi: mac80211: allow bw change during channel switch in mesh
  (bsc#1012628).
- wifi: mac80211_hwsim: fix link change handling (bsc#1012628).
- wifi: mac80211: mlme: don't add empty EML capabilities
  (bsc#1012628).
- wifi: mac80211: fix use-after-free (bsc#1012628).
- wifi: cfg80211: get correct AP link chandef (bsc#1012628).
- wifi: mac80211: properly set old_links when removing a link
  (bsc#1012628).
- bpf: Fix reference state management for synchronous callbacks
  (bsc#1012628).
- net: prestera: cache port state for non-phylink ports too
  (bsc#1012628).
- tsnep: Fix TSNEP_INFO_TX_TIME register define (bsc#1012628).
- leds: lm3601x: Don't use mutex after it was destroyed
  (bsc#1012628).
- bpf: Fix ref_obj_id for dynptr data slices in verifier
  (bsc#1012628).
- bpf: Cleanup check_refcount_ok (bsc#1012628).
- wifi: ath10k: add peer map clean up for peer delete in
  ath10k_sta_state() (bsc#1012628).
- wifi: ath10k: Set tx credit to one for WCN3990 snoc based
  devices (bsc#1012628).
- wifi: rtlwifi: 8192de: correct checking of IQK reload
  (bsc#1012628).
- libbpf: Initialize err in probe_map_create (bsc#1012628).
- m68k: Process bootinfo records before saving them (bsc#1012628).
- x86/paravirt: add extra clobbers with ZERO_CALL_USED_REGS
  enabled (bsc#1012628).
- NFSD: Fix handling of oversized NFSv4 COMPOUND requests
  (bsc#1012628).
- NFSD: Protect against send buffer overflow in NFSv2 READDIR
  (bsc#1012628).
- SUNRPC: Fix svcxdr_init_encode's buflen calculation
  (bsc#1012628).
- SUNRPC: Fix svcxdr_init_decode's end-of-buffer calculation
  (bsc#1012628).
- nfsd: Fix a memory leak in an error handling path (bsc#1012628).
- objtool: Preserve special st_shndx indexes in elf_update_symbol
  (bsc#1012628).
- ACPI: PCC: Fix Tx acknowledge in the PCC address space handler
  (bsc#1012628).
- ACPI: PCC: replace wait_for_completion() (bsc#1012628).
- ACPI: PCC: Release resources on address space setup failure path
  (bsc#1012628).
- ARM: 9247/1: mm: set readonly for MT_MEMORY_RO with ARM_LPAE
  (bsc#1012628).
- ARM: 9244/1: dump: Fix wrong pg_level in walk_pmd()
  (bsc#1012628).
- ARM: 9243/1: riscpc: Unbreak the build (bsc#1012628).
- erofs: use kill_anon_super() to kill super in fscache mode
  (bsc#1012628).
- erofs: fix order >= MAX_ORDER warning due to crafted negative
  i_size (bsc#1012628).
- MIPS: SGI-IP27: Fix platform-device leak in
  bridge_platform_create() (bsc#1012628).
- MIPS: SGI-IP30: Fix platform-device leak in
  bridge_platform_create() (bsc#1012628).
- sh: machvec: Use char[] for section boundaries (bsc#1012628).
- cpufreq: amd-pstate: Fix initial highest_perf value
  (bsc#1012628).
- thermal: cpufreq_cooling: Check the policy first in
  cpufreq_cooling_register() (bsc#1012628).
- acl: return EOPNOTSUPP in posix_acl_fix_xattr_common()
  (bsc#1012628).
- ntfs3: rework xattr handlers and switch to POSIX ACL VFS helpers
  (bsc#1012628).
- userfaultfd: open userfaultfds with O_RDONLY (bsc#1012628).
- ima: fix blocking of security.ima xattrs of unsupported
  algorithms (bsc#1012628).
- selinux: use "grep -E" instead of "egrep" (bsc#1012628).
- smb3: must initialize two ACL struct fields to zero
  (bsc#1012628).
- drm/amdgpu: Enable F32_WPTR_POLL_ENABLE in mqd (bsc#1012628).
- drm/amdgpu: Enable VCN PG on GC11_0_1 (bsc#1012628).
- drm/amd/display: explicitly disable psr_feature_enable
  appropriately (bsc#1012628).
- drm/amd/display: Add HUBP surface flip interrupt handler
  (bsc#1012628).
- drm/amd/display: Fix vblank refcount in vrr transition
  (bsc#1012628).
- drm/amd/display: Enable 2 to 1 ODM policy if supported
  (bsc#1012628).
- drm/amd/display: Enable dpia support for dcn314 (bsc#1012628).
- drm/amd/display: Validate DSC After Enable All New CRTCs
  (bsc#1012628).
- drm/amd/display: zeromem mypipe heap struct before using it
  (bsc#1012628).
- drm/amd/display: Update PMFW z-state interface for DCN314
  (bsc#1012628).
- drm/amd/display: Fix watermark calculation (bsc#1012628).
- drm/i915: Fix display problems after resume (bsc#1012628).
- drm/i915: Fix watermark calculations for DG2 CCS+CC modifier
  (bsc#1012628).
- drm/i915: Fix watermark calculations for DG2 CCS modifiers
  (bsc#1012628).
- drm/i915: Fix watermark calculations for gen12+ CCS+CC modifier
  (bsc#1012628).
- drm/i915: Fix watermark calculations for gen12+ MC CCS modifier
  (bsc#1012628).
- drm/i915: Fix watermark calculations for gen12+ RC CCS modifier
  (bsc#1012628).
- drm/i915/guc: Fix revocation of non-persistent contexts
  (bsc#1012628).
- drm/i915/gt: Use i915_vm_put on ppgtt_create error paths
  (bsc#1012628).
- drm/nouveau: fix a use-after-free in
  nouveau_gem_prime_import_sg_table() (bsc#1012628).
- drm/nouveau/kms/nv140-: Disable interlacing (bsc#1012628).
- staging: greybus: audio_helper: remove unused and wrong debugfs
  usage (bsc#1012628).
- KVM: VMX: Drop bits 31:16 when shoving exception error code
  into VMCS (bsc#1012628).
- KVM: x86: Treat #DBs from the emulator as fault-like (code
  and DR7.GD=1) (bsc#1012628).
- KVM: nVMX: Don't propagate vmcs12's PERF_GLOBAL_CTRL settings
  to vmcs02 (bsc#1012628).
- KVM: nVMX: Unconditionally purge queued/injected events on
  nested "exit" (bsc#1012628).
- KVM: x86/emulator: Fix handing of POP SS to correctly set
  interruptibility (bsc#1012628).
- blk-wbt: call rq_qos_add() after wb_normal is initialized
  (bsc#1012628).
- blk-throttle: fix that io throttle can only work for single bio
  (bsc#1012628).
- media: cedrus: Fix endless loop in cedrus_h265_skip_bits()
  (bsc#1012628).
- media: cedrus: Set the platform driver data earlier
  (bsc#1012628).
- media: cedrus: Fix watchdog race condition (bsc#1012628).
- efi: libstub: drop pointless get_memory_map() call
  (bsc#1012628).
- thunderbolt: Explicitly enable lane adapter hotplug events at
  startup (bsc#1012628).
- rpmsg: char: Avoid double destroy of default endpoint
  (bsc#1012628).
- tracing: Fix reading strings from synthetic events
  (bsc#1012628).
- tracing: Add "(fault)" name injection to kernel probes
  (bsc#1012628).
- tracing: Move duplicate code of trace_kprobe/eprobe.c into
  header (bsc#1012628).
- tracing: Do not free snapshot if tracer is on cmdline
  (bsc#1012628).
- tracing: Add ioctl() to force ring buffer waiters to wake up
  (bsc#1012628).
- tracing: Wake up waiters when tracing is disabled (bsc#1012628).
- tracing: Wake up ring buffer waiters on closing of the file
  (bsc#1012628).
- tracing: Disable interrupt or preemption before acquiring
  arch_spinlock_t (bsc#1012628).
- tracing/eprobe: Fix alloc event dir failed when event name no
  set (bsc#1012628).
- ring-buffer: Fix race between reset page and reading page
  (bsc#1012628).
- ring-buffer: Add ring_buffer_wake_waiters() (bsc#1012628).
- ring-buffer: Check pending waiters when doing wake ups as well
  (bsc#1012628).
- ring-buffer: Have the shortest_full queue be the shortest not
  longest (bsc#1012628).
- ring-buffer: Allow splice to read previous partially read pages
  (bsc#1012628).
- ftrace: Still disable enabled records marked as disabled
  (bsc#1012628).
- ftrace: Properly unset FTRACE_HASH_FL_MOD (bsc#1012628).
- livepatch: fix race between fork and KLP transition
  (bsc#1012628).
- ext4: update 'state->fc_regions_size' after successful memory
  allocation (bsc#1012628).
- ext4: fix potential memory leak in ext4_fc_record_regions()
  (bsc#1012628).
- ext4: fix potential memory leak in
  ext4_fc_record_modified_inode() (bsc#1012628).
- ext4: fix miss release buffer head in ext4_fc_write_inode
  (bsc#1012628).
- ext4: fix dir corruption when ext4_dx_add_entry() fails
  (bsc#1012628).
- ext4: fix i_version handling in ext4 (bsc#1012628).
- ext4: place buffer head allocation before handle start
  (bsc#1012628).
- ext4: ext4_read_bh_lock() should submit IO if the buffer isn't
  uptodate (bsc#1012628).
- ext4: unconditionally enable the i_version counter
  (bsc#1012628).
- ext4: don't increase iversion counter for ea_inodes
  (bsc#1012628).
- ext4: fix check for block being out of directory size
  (bsc#1012628).
- ext4: make ext4_lazyinit_thread freezable (bsc#1012628).
- ext4: fix null-ptr-deref in ext4_write_info (bsc#1012628).
- ext4: avoid crash when inline data creation follows DIO write
  (bsc#1012628).
- ext2: Add sanity checks for group and filesystem size
  (bsc#1012628).
- jbd2: add miss release buffer head in fc_do_one_pass()
  (bsc#1012628).
- jbd2: fix potential use-after-free in jbd2_fc_wait_bufs
  (bsc#1012628).
- jbd2: fix potential buffer head reference count leak
  (bsc#1012628).
- jbd2: wake up journal waiters in FIFO order, not LIFO
  (bsc#1012628).
- f2fs: allow direct read for zoned device (bsc#1012628).
- f2fs: fix to do sanity check on summary info (bsc#1012628).
- f2fs: fix to do sanity check on destination blkaddr during
  recovery (bsc#1012628).
- f2fs: increase the limit for reserve_root (bsc#1012628).
- f2fs: flush pending checkpoints when freezing super
  (bsc#1012628).
- f2fs: complete checkpoints during remount (bsc#1012628).
- f2fs: fix wrong continue condition in GC (bsc#1012628).
- btrfs: set generation before calling btrfs_clean_tree_block
  in btrfs_init_new_buffer (bsc#1012628).
- btrfs: fix missed extent on fsync after dropping extent maps
  (bsc#1012628).
- btrfs: fix race between quota enable and quota rescan ioctl
  (bsc#1012628).
- btrfs: enhance unsupported compat RO flags handling
  (bsc#1012628).
- btrfs: fix alignment of VMA for memory mapped files on THP
  (bsc#1012628).
- fs: record I_DIRTY_TIME even if inode already has I_DIRTY_INODE
  (bsc#1012628).
- ksmbd: Fix user namespace mapping (bsc#1012628).
- ksmbd: Fix wrong return value and message length check in
  smb2_ioctl() (bsc#1012628).
- ksmbd: fix endless loop when encryption for response fails
  (bsc#1012628).
- ksmbd: fix incorrect handling of iterate_dir (bsc#1012628).
- smb3: do not log confusing message when server returns no
  network interfaces (bsc#1012628).
- hwrng: core - let sleep be interrupted when unregistering hwrng
  (bsc#1012628).
- fbdev: smscufx: Fix use-after-free in ufx_ops_open()
  (bsc#1012628).
- pinctrl: rockchip: add pinmux_ops.gpio_set_direction callback
  (bsc#1012628).
- gpio: rockchip: request GPIO mux to pinctrl when setting
  direction (bsc#1012628).
- scsi: qedf: Populate sysfs attributes for vport (bsc#1012628).
- scsi: lpfc: Rework MIB Rx Monitor debug info logic
  (bsc#1012628).
- slimbus: qcom-ngd: cleanup in probe error path (bsc#1012628).
- slimbus: qcom-ngd: use correct error in message of
  pdr_add_lookup() failure (bsc#1012628).
- powerpc/boot: Explicitly disable usage of SPE instructions
  (bsc#1012628).
- powerpc/Kconfig: Fix non existing CONFIG_PPC_FSL_BOOKE
  (bsc#1012628).
- powercap: intel_rapl: Use standard Energy Unit for SPR Dram
  RAPL domain (bsc#1012628).
- LoadPin: Fix Kconfig doc about format of file with verity
  digests (bsc#1012628).
- cpufreq: qcom-cpufreq-hw: Fix uninitialized throttled_freq
  warning (bsc#1012628).
- NFSD: Protect against send buffer overflow in NFSv3 READ
  (bsc#1012628).
- NFSD: Protect against send buffer overflow in NFSv2 READ
  (bsc#1012628).
- NFSD: Protect against send buffer overflow in NFSv3 READDIR
  (bsc#1012628).
- serial: 8250: Request full 16550A feature probing for OxSemi
  PCIe devices (bsc#1012628).
- serial: 8250: Let drivers request full 16550A feature probing
  (bsc#1012628).
- serial: ar933x: Deassert Transmit Enable on ->rs485_config()
  (bsc#1012628).
- serial: Deassert Transmit Enable on probe in driver-specific
  way (bsc#1012628).
- serial: stm32: Deassert Transmit Enable on ->rs485_config()
  (bsc#1012628).
- serial: cpm_uart: Don't request IRQ too early for console port
  (bsc#1012628).
- PCI: Sanitise firmware BAR assignments behind a PCI-PCI bridge
  (bsc#1012628).
- xen/gntdev: Accommodate VMA splitting (bsc#1012628).
- xen/gntdev: Prevent leaking grants (bsc#1012628).
- mm/mmap: undo ->mmap() when arch_validate_flags() fails
  (bsc#1012628).
- mm/uffd: fix warning without PTE_MARKER_UFFD_WP compiled in
  (bsc#1012628).
- mm/damon: validate if the pmd entry is present before accessing
  (bsc#1012628).
- mm/hugetlb: fix races when looking up a CONT-PTE/PMD size
  hugetlb page (bsc#1012628).
- clocksource/drivers/arm_arch_timer: Fix CNTPCT_LO and CNTVCT_LO
  value (bsc#1012628).
- arm64: mte: Avoid setting PG_mte_tagged if no tags cleared or
  restored (bsc#1012628).
- arm64: mte: move register initialization to C (bsc#1012628).
- drm/udl: Restore display mode on resume (bsc#1012628).
- drm/virtio: Use appropriate atomic state in
  virtio_gpu_plane_cleanup_fb() (bsc#1012628).
- drm/virtio: Unlock reservations on dma_resv_reserve_fences()
  error (bsc#1012628).
- drm/virtio: Unlock reservations on
  virtio_gpu_object_shmem_init() error (bsc#1012628).
- drm/virtio: Check whether transferred 2D BO is shmem
  (bsc#1012628).
- dmaengine: qcom-adm: fix wrong calling convention for
  prep_slave_sg (bsc#1012628).
- dmaengine: qcom-adm: fix wrong sizeof config in slave_config
  (bsc#1012628).
- dmaengine: mxs: use platform_driver_register (bsc#1012628).
- dm: verity-loadpin: Only trust verity targets with enforcement
  (bsc#1012628).
- Revert "drm/amdgpu: use dirty framebuffer helper" (bsc#1012628).
- nvme-multipath: fix possible hang in live ns resize with ANA
  access (bsc#1012628).
- nvmem: core: Fix memleak in nvmem_register() (bsc#1012628).
- UM: cpuinfo: Fix a warning for CONFIG_CPUMASK_OFFSTACK
  (bsc#1012628).
- riscv: Pass -mno-relax only on lld < 15.0.0 (bsc#1012628).
- riscv: always honor the CONFIG_CMDLINE_FORCE when parsing dtb
  (bsc#1012628).
- riscv: Make VM_WRITE imply VM_READ (bsc#1012628).
- riscv: Allow PROT_WRITE-only mmap() (bsc#1012628).
- riscv: vdso: fix NULL deference in vdso_join_timens() when vfork
  (bsc#1012628).
- parisc: Fix userspace graphics card breakage due to pgtable
  special bit (bsc#1012628).
- parisc: fbdev/stifb: Align graphics memory size to 4MB
  (bsc#1012628).
- RISC-V: Make port I/O string accessors actually work
  (bsc#1012628).
- RISC-V: Re-enable counter access from userspace (bsc#1012628).
- riscv: topology: fix default topology reporting (bsc#1012628).
- arm64: topology: move store_cpu_topology() to shared code
  (bsc#1012628).
- regulator: qcom_rpm: Fix circular deferral regression
  (bsc#1012628).
- net: thunderbolt: Enable DMA paths only after rings are enabled
  (bsc#1012628).
- hwmon: (gsc-hwmon) Call of_node_get() before of_find_xxx API
  (bsc#1012628).
- ASoC: wcd934x: fix order of Slimbus unprepare/disable
  (bsc#1012628).
- ASoC: wcd9335: fix order of Slimbus unprepare/disable
  (bsc#1012628).
- arm64: dts: qcom: sdm845-mtp: correct ADC settle time
  (bsc#1012628).
- platform/chrome: cros_ec_proto: Update version on GET_NEXT_EVENT
  failure (bsc#1012628).
- quota: Check next/prev free block number after reading from
  quota file (bsc#1012628).
- HID: multitouch: Add memory barriers (bsc#1012628).
- mbcache: Avoid nesting of cache->c_list_lock under bit locks
  (bsc#1012628).
- btf: Export bpf_dynptr definition (bsc#1012628).
- fs: dlm: fix invalid derefence of sb_lvbptr (bsc#1012628).
- fs: dlm: handle -EBUSY first in lock arg validation
  (bsc#1012628).
- fs: dlm: fix race between test_bit() and queue_work()
  (bsc#1012628).
- i2c: designware: Fix handling of real but unexpected device
  interrupts (bsc#1012628).
- mmc: sdhci-sprd: Fix minimum clock limit (bsc#1012628).
- mmc: sdhci-tegra: Use actual clock rate for SW tuning correction
  (bsc#1012628).
- mmc: renesas_sdhi: Fix rounding errors (bsc#1012628).
- can: kvaser_usb_leaf: Fix CAN state after restart (bsc#1012628).
- can: kvaser_usb_leaf: Fix TX queue out of sync after restart
  (bsc#1012628).
- can: kvaser_usb_leaf: Fix overread with an invalid command
  (bsc#1012628).
- can: kvaser_usb: Fix use of uninitialized completion
  (bsc#1012628).
- mmc: core: Add SD card quirk for broken discard (bsc#1012628).
- usb: add quirks for Lenovo OneLink+ Dock (bsc#1012628).
- usb: gadget: uvc: Fix argument to sizeof() in
  uvc_register_video() (bsc#1012628).
- xhci: dbc: Fix memory leak in xhci_alloc_dbc() (bsc#1012628).
- iio: pressure: dps310: Reset chip after timeout (bsc#1012628).
- iio: pressure: dps310: Refactor startup procedure (bsc#1012628).
- iio: adc: ad7923: fix channel readings for some variants
  (bsc#1012628).
- iio: ltc2497: Fix reading conversion results (bsc#1012628).
- iio: dac: ad5593r: Fix i2c read protocol requirements
  (bsc#1012628).
- cifs: Fix the error length of VALIDATE_NEGOTIATE_INFO message
  (bsc#1012628).
- cifs: destage dirty pages before re-reading them for cache=none
  (bsc#1012628).
- hv_netvsc: Fix race between VF offering and VF association
  message from host (bsc#1012628).
- io_uring: correct pinned_vm accounting (bsc#1012628).
- io_uring/af_unix: defer registered files gc to io_uring release
  (bsc#1012628).
- io_uring/net: handle -EINPROGRESS correct for IORING_OP_CONNECT
  (bsc#1012628).
- io_uring: limit registration w/ SINGLE_ISSUER (bsc#1012628).
- io_uring/net: don't update msg_name if not provided
  (bsc#1012628).
- io_uring/net: fix fast_iov assignment in io_setup_async_msg()
  (bsc#1012628).
- io_uring/rw: don't lose short results on io_setup_async_rw()
  (bsc#1012628).
- io_uring/rw: fix unexpected link breakage (bsc#1012628).
- io_uring/net: don't lose partial send/recv on fail
  (bsc#1012628).
- io_uring/rw: don't lose partial IO result on fail (bsc#1012628).
- io_uring: add custom opcode hooks on fail (bsc#1012628).
- mtd: rawnand: atmel: Unmap streaming DMA mappings (bsc#1012628).
- ALSA: hda/realtek: Add Intel Reference SSID to support headset
  keys (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ASUS GV601R laptop
  (bsc#1012628).
- ALSA: hda/realtek: Correct pin configs for ASUS G533Z
  (bsc#1012628).
- ALSA: hda/realtek: remove ALC289_FIXUP_DUAL_SPK for Dell 5530
  (bsc#1012628).
- ALSA: usb-audio: Fix NULL dererence at error path (bsc#1012628).
- ALSA: usb-audio: Fix potential memory leaks (bsc#1012628).
- ALSA: rawmidi: Drop register_mutex in snd_rawmidi_free()
  (bsc#1012628).
- ALSA: oss: Fix potential deadlock at unregistration
  (bsc#1012628).
- commit beade21
* Fri Oct 21 2022 tiwai@suse.de
- ALSA: hda/realtek: Add quirk for ASUS Zenbook using CS35L41
  (bsc#1203922).
- commit fc9be74
* Fri Oct 21 2022 jslaby@suse.cz
- Refresh patches.suse/drm-amdgpu-Fix-for-BO-move-issue.patch.
  Update upstream status.
- commit 48205db
* Thu Oct 20 2022 tiwai@suse.de
- drm/amdgpu: Fix for BO move issue (bsc#1204160).
- commit b9e3808
* Thu Oct 20 2022 tiwai@suse.de
- drm/amdgpu: Fix VRAM BO swap issue (bsc#1204160).
- commit 51f20d5
* Wed Oct 19 2022 jslaby@suse.cz
- lib/Kconfig.debug: Add check for non-constant .{s,u}leb128
  support to DWARF5 (bsc#1012628).
- Update config files.
- hid: topre: Add driver fixing report descriptor (bsc#1012628).
- Update config files.
- arm64: errata: Add Cortex-A55 to the repeat tlbi list
  (bsc#1012628).
- Update config files.
- commit f78cd12
* Mon Oct 17 2022 mkubecek@suse.cz
- update submitted patch
- update to v2 and rename
  - patches.suse/scsi-mpi3mr-add-explicit-dependency-on-CONFIG_SCSI_S.patch
  - > patches.suse/scsi-mpi3mr-select-CONFIG_SCSI_SAS_ATTRS.patch
- update config/x86_64/kvmsmall
  - SCSI_SAS_ATTRS=m (new dependency in 6.1-rc1)
- commit d8f9c79
* Mon Oct 17 2022 dmueller@suse.com
- config.conf: Reenable arm64
- Update config files (arm64). copy 6.1-rc1  from x86_64, enable
  all new SOC erratas, enable all new modules.
- commit 8d7f37c
* Mon Oct 17 2022 mkubecek@suse.cz
- scsi: mpi3mr: add explicit dependency on CONFIG_SCSI_SAS_ATTRS.
  Fix x86_64/kvmsmall build failure.
- commit 2fa879f
* Mon Oct 17 2022 schwab@suse.de
- rpm/check-for-config-changes: loosen pattern for AS_HAS_*
  This is needed to handle CONFIG_AS_HAS_NON_CONST_LEB128.
- commit bdc0bf7
* Mon Oct 17 2022 mkubecek@suse.cz
- Update to 6.1-rc1
- eliminate 21 patches (18 stable, 3 mainline)
  - patches.suse/ALSA-hda-realtek-Add-quirk-for-HP-Zbook-Firefly-14-G.patch
  - patches.suse/ALSA-hda-realtek-More-robust-component-matching-for-.patch
  - patches.suse/watchdog-wdat_wdt-fix-min-max-timer-value.patch
- disable
  - patches.suse/suse-hv-guest-os-id.patch (bsc#1189965)
- refresh
  - patches.suse/Input-i8042-Apply-probe-defer-to-more-ASUS-ZenBook-m.patch
  - patches.suse/add-suse-supported-flag.patch
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
- add DRM crash fix
  - patches.suse/drm-sched-Fix-kernel-NULL-pointer-dereference-error.patch
- disable ARM architectures (need config update)
- new config options
  - Processor type and features
  - XEN_PV_MSR_SAFE=y
  - Power management and ACPI options
  - X86_AMD_PSTATE_UT=n
  - General architecture-dependent options
  - CFI_CLANG=n
  - Memory Management options
  - LRU_GEN=y
  - LRU_GEN_ENABLED=n
  - LRU_GEN_STATS=n
  - Cryptographic API
  - CRYPTO_ARIA_AESNI_AVX_X86_64=m
  - Library routines
  - FORCE_NR_CPUS=n
  - Kernel hacking
  - DEBUG_MAPLE_TREE=n
  - TEST_DYNAMIC_DEBUG=n
  - Network device support
  - NGBE=m
  - NET_VENDOR_ADI=y
  - ADIN1110=m
  - MLX5_EN_MACSEC=y
  - PSE_CONTROLLER=y
  - PSE_REGULATOR=m
  - Input device support
  - KEYBOARD_PINEPHONE=m
  - TOUCHSCREEN_COLIBRI_VF50=m
  - Hardware Monitoring support
  - SENSORS_MAX31760=m
  - SENSORS_TPS546D24=m
  - SENSORS_EMC2305=m
  - Multifunction device drivers
  - MFD_MT6370=n
  - MFD_OCELOT=n
  - MFD_SY7636A=n
  - MFD_RT5120=n
  - Graphics support
  - DRM_USE_DYNAMIC_DEBUG=y
  - Sound card support
  - SND_SOC_AMD_PS=m
  - SND_SOC_AMD_PS_MACH=m
  - SND_SOC_SOF_AMD_REMBRANDT=m
  - SND_SOC_SOF_SKYLAKE=m
  - SND_SOC_SOF_KABYLAKE=m
  - SND_SOC_CS42L83=n
  - SND_SOC_SRC4XXX_I2C=n
  - HID support
  - HID_VRC2=m
  - HID_PXRC=m
  - HID_TOPRE=m
  - Industrial I/O support
  - MSA311=n
  - MAX11205=n
  - RICHTEK_RTQ6056=n
  - BOSCH_BNO055_SERIAL=n
  - BOSCH_BNO055_I2C=n
  - LTRF216A=n
  - Misc devices
  - GP_PCI1XXXX=m
  - AHCI_DWC=m
  - SERIAL_FSL_LPUART_CONSOLE=y
  - I2C_PCI1XXXX=m
  - SPI_MICROCHIP_CORE_QSPI=m
  - PINCTRL_CY8C95X0=m
  - EXAR_WDT=m
  - STAGING_MEDIA_DEPRECATED=n
  - CROS_TYPEC_SWITCH=m
  - AMD_PMF=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - PATA_OF_PLATFORM=m
  - COMMON_CLK_VC7=m
  - NVMEM_U_BOOT_ENV=m
  - ppc64le / ppc64
  - ARCH_FORCE_MAX_ORDER=9 (default)
  - INPUT_IBM_PANEL=m
  - KFENCE=y
  - KFENCE_SAMPLE_INTERVAL=0
  - KFENCE_NUM_OBJECTS=255
  - KFENCE_DEFERRABLE=n
  - KFENCE_STATIC_KEYS=y
  - KFENCE_STRESS_TEST_FAULTS=0
  - riscv64
  - EFI_ZBOOT=n
  - PINCTRL_STARFIVE_JH7100=m
  - CHARGER_RK817=m
  - SND_SOC_ES8326=m
  - SIFIVE_CCACHE=y
  - RESET_POLARFIRE_SOC=y
- commit 79462df
* Mon Oct 17 2022 jslaby@suse.cz
- Update
  patches.kernel.org/6.0.2-022-wifi-cfg80211-mac80211-reject-bad-MBSSID-elemen.patch
  (bsc#1012628 bsc#1203770 CVE-2022-41674).
- Update
  patches.kernel.org/6.0.2-023-wifi-mac80211-fix-MBSSID-parsing-use-after-free.patch
  (bsc#1012628 bsc#1204051 CVE-2022-42719).
- Update
  patches.kernel.org/6.0.2-025-wifi-cfg80211-fix-BSS-refcounting-bugs.patch
  (bsc#1012628 bsc#1204059 CVE-2022-42720).
- Update
  patches.kernel.org/6.0.2-026-wifi-cfg80211-avoid-nontransmitted-BSS-list-cor.patch
  (bsc#1012628 bsc#1204060 CVE-2022-42721).
- Update
  patches.kernel.org/6.0.2-028-wifi-mac80211-fix-crash-in-beacon-protection-fo.patch
  (bsc#1012628 bsc#1204125 CVE-2022-42722).
  Add CVE references.
- commit af756fb
* Sun Oct 16 2022 jslaby@suse.cz
- Linux 6.0.2 (bsc#1012628).
- nilfs2: fix NULL pointer dereference at
  nilfs_bmap_lookup_at_level() (bsc#1012628).
- nilfs2: fix use-after-free bug of struct nilfs_root
  (bsc#1012628).
- nilfs2: fix leak of nilfs_root in case of writer thread creation
  failure (bsc#1012628).
- nilfs2: replace WARN_ONs by nilfs_error for checkpoint
  acquisition failure (bsc#1012628).
- nvme-pci: set min_align_mask before calculating max_hw_sectors
  (bsc#1012628).
- random: restore O_NONBLOCK support (bsc#1012628).
- random: clamp credited irq bits to maximum mixed (bsc#1012628).
- ALSA: hda: Fix position reporting on Poulsbo (bsc#1012628).
- efi: Correct Macmini DMI match in uefi cert quirk (bsc#1012628).
- scsi: qla2xxx: Revert "scsi: qla2xxx: Fix response queue
  handler reading stale packets" (bsc#1012628).
- scsi: qla2xxx: Fix response queue handler reading stale packets
  (bsc#1012628).
- scsi: stex: Properly zero out the passthrough command structure
  (bsc#1012628).
- USB: serial: qcserial: add new usb-id for Dell branded EM7455
  (bsc#1012628).
- Revert "USB: fixup for merge issue with "usb: dwc3: Don't
  switch OTG -> peripheral if extcon is present"" (bsc#1012628).
- Revert "usb: dwc3: Don't switch OTG -> peripheral if extcon
  is present" (bsc#1012628).
- Revert "powerpc/rtas: Implement reentrant rtas call"
  (bsc#1012628).
- Revert "crypto: qat - reduce size of mapped region"
  (bsc#1012628).
- random: avoid reading two cache lines on irq randomness
  (bsc#1012628).
- random: use expired timer rather than wq for mixing fast pool
  (bsc#1012628).
- wifi: cfg80211: fix u8 overflow in
  cfg80211_update_notlisted_nontrans() (bsc#1012628).
- wifi: cfg80211/mac80211: reject bad MBSSID elements
  (bsc#1012628).
- wifi: mac80211: fix MBSSID parsing use-after-free (bsc#1012628).
- wifi: cfg80211: ensure length byte is present before access
  (bsc#1012628).
- wifi: cfg80211: fix BSS refcounting bugs (bsc#1012628).
- wifi: cfg80211: avoid nontransmitted BSS list corruption
  (bsc#1012628).
- wifi: mac80211_hwsim: avoid mac80211 warning on bad rate
  (bsc#1012628).
- wifi: mac80211: fix crash in beacon protection for P2P-device
  (bsc#1012628).
- wifi: cfg80211: update hidden BSSes to avoid WARN_ON
  (bsc#1012628).
- mctp: prevent double key removal and unref (bsc#1012628).
- Input: xpad - add supported devices as contributed on github
  (bsc#1012628).
- Input: xpad - fix wireless 360 controller breaking after suspend
  (bsc#1012628).
- misc: pci_endpoint_test: Aggregate params checking for xfer
  (bsc#1012628).
- misc: pci_endpoint_test: Fix
  pci_endpoint_test_{copy,write,read}() panic (bsc#1012628).
- commit 7fb6561
* Fri Oct 14 2022 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and move into sorted section:
  - patches.suse/watchdog-wdat_wdt-fix-min-max-timer-value.patch
- commit 64a2b58
* Fri Oct 14 2022 jslaby@suse.cz
- Refresh
  patches.suse/ACPI-resource-Add-ASUS-model-S5402ZA-to-quirks.patch.
- Refresh
  patches.suse/ACPI-resource-Skip-IRQ-override-on-Asus-Vivobook-K34.patch.
  Update upstream status. They were merged already.
- commit 098c340
* Fri Oct 14 2022 jslaby@suse.cz
- ACPI: resource: do IRQ override on LENOVO IdeaPad (bsc#1203794).
- ACPI: resource: Add ASUS model S5402ZA to quirks (bsc#1203794).
- ACPI: resource: Skip IRQ override on Asus Vivobook
  K3402ZA/K3502ZA (bsc#1203794).
- commit c7a2f55
* Wed Oct 12 2022 jslaby@suse.cz
- Linux 6.0.1 (bsc#1012628).
- xsk: Inherit need_wakeup flag for shared sockets (bsc#1012628).
- fs: fix UAF/GPF bug in nilfs_mdt_destroy (bsc#1012628).
- sparc: Unbreak the build (bsc#1012628).
- Makefile.extrawarn: Move -Wcast-function-type-strict to W=1
  (bsc#1012628).
- hardening: Remove Clang's enable flag for
  - ftrivial-auto-var-init=zero (bsc#1012628).
- docs: update mediator information in CoC docs (bsc#1012628).
- hwmon: (aquacomputer_d5next) Fix Quadro fan speed offsets
  (bsc#1012628).
- usb: mon: make mmapped memory read only (bsc#1012628).
- USB: serial: ftdi_sio: fix 300 bps rate for SIO (bsc#1012628).
- gpiolib: acpi: Add support to ignore programming an interrupt
  (bsc#1012628).
- gpiolib: acpi: Add a quirk for Asus UM325UAZ (bsc#1012628).
- RISC-V: Print SSTC in canonical order (bsc#1012628).
- bpf: Gate dynptr API behind CAP_BPF (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix state in __mtk_foe_entry_clear
  (bsc#1012628).
- bpf: Fix resetting logic for unreferenced kptrs (bsc#1012628).
- Bluetooth: use hdev->workqueue when queuing
  hdev->{cmd,ncmd}_timer works (bsc#1012628).
- Update config files.
- commit 0c45fd2
* Mon Oct 10 2022 tiwai@suse.de
- misc: sgi-gru: fix use-after-free error in
  gru_set_context_option, gru_fault and gru_handle_user_call_os
  (CVE-2022-3424 bsc#1204166).
- commit cf55d04
* Fri Oct  7 2022 mkubecek@suse.cz
- series.conf: cleanup
- move upstreamed patches to sorted section:
  - patches.suse/ALSA-hda-realtek-Add-quirk-for-HP-Zbook-Firefly-14-G.patch
  - patches.suse/ALSA-hda-realtek-More-robust-component-matching-for-.patch
- commit e926c4b
* Thu Oct  6 2022 jslaby@suse.cz
- fix coredump breakage (coredump fix).
- commit 97b0626
* Wed Oct  5 2022 msuchanek@suse.de
- Revert "constraints: increase disk space for all architectures"
  (bsc#1203693).
  This reverts commit 43a9011f904bc7328d38dc340f5e71aecb6b19ca.
- commit 3d33373
* Tue Oct  4 2022 tiwai@suse.de
- ALSA: hda/realtek: More robust component matching for CS35L41
  (bsc#1203699).
- ALSA: hda/realtek: Add quirk for HP Zbook Firefly 14 G9 model
  (bsc#1203699).
- commit 25aa080
* Mon Oct  3 2022 jslaby@suse.cz
- Refresh
  patches.suse/vduse-prevent-uninitialized-memory-accesses.patch.
  Update upstream status.
- commit 39efccd
* Sun Oct  2 2022 mkubecek@suse.cz
- Update to 6.0 final
- eliminate 1 patch
  - patches.suse/vduse-prevent-uninitialized-memory-accesses.patch
- refresh configs (headers only)
- commit a7dafe3
* Wed Sep 28 2022 jslaby@suse.cz
- Linux 5.19.12 (bsc#1012628).
- drm/i915: Extract intel_edp_fixup_vbt_bpp() (bsc#1012628).
- drm/i915/pps: Split pps_init_delays() into distinct parts
  (bsc#1012628).
- drm/i915/bios: Split parse_driver_features() into two parts
  (bsc#1012628).
- drm/i915/bios: Split VBT parsing to global vs. panel specific
  parts (bsc#1012628).
- drm/i915/bios: Split VBT data into per-panel vs. global parts
  (bsc#1012628).
- drm/i915/dsi: filter invalid backlight and CABC ports
  (bsc#1012628).
- drm/i915/dsi: fix dual-link DSI backlight and CABC ports for
  display 11+ (bsc#1012628).
- smb3: Move the flush out of smb2_copychunk_range() into its
  callers (bsc#1012628).
- smb3: fix temporary data corruption in collapse range
  (bsc#1012628).
- smb3: fix temporary data corruption in insert range
  (bsc#1012628).
- usb: add quirks for Lenovo OneLink+ Dock (bsc#1012628).
- usb: gadget: udc-xilinx: replace memcpy with memcpy_toio
  (bsc#1012628).
- smb3: use filemap_write_and_wait_range instead of
  filemap_write_and_wait (bsc#1012628).
- Revert "usb: add quirks for Lenovo OneLink+ Dock" (bsc#1012628).
- Revert "usb: gadget: udc-xilinx: replace memcpy with
  memcpy_toio" (bsc#1012628).
- xfrm: fix XFRMA_LASTUSED comment (bsc#1012628).
- block: remove QUEUE_FLAG_DEAD (bsc#1012628).
- block: stop setting the nomerges flags in blk_cleanup_queue
  (bsc#1012628).
- block: simplify disk shutdown (bsc#1012628).
- scsi: core: Fix a use-after-free (bsc#1012628).
- drivers/base: Fix unsigned comparison to -1 in
  CPUMAP_FILE_MAX_BYTES (bsc#1012628).
- USB: core: Fix RST error in hub.c (bsc#1012628).
- USB: serial: option: add Quectel BG95 0x0203 composition
  (bsc#1012628).
- USB: serial: option: add Quectel RM520N (bsc#1012628).
- Revert "ALSA: usb-audio: Split endpoint setups for hw_params
  and prepare" (bsc#1012628).
- ALSA: core: Fix double-free at snd_card_new() (bsc#1012628).
- ALSA: hda/tegra: set depop delay for tegra (bsc#1012628).
- ALSA: hda: Fix hang at HD-audio codec unbinding due to refcount
  saturation (bsc#1012628).
- ALSA: hda: Fix Nvidia dp infoframe (bsc#1012628).
- ALSA: hda: add Intel 5 Series / 3400 PCI DID (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Huawei WRT-WX9 (bsc#1012628).
- ALSA: hda/realtek: Enable 4-speaker output Dell Precision 5570
  laptop (bsc#1012628).
- ALSA: hda/realtek: Re-arrange quirk table entries (bsc#1012628).
- ALSA: hda/realtek: Add pincfg for ASUS G513 HP jack
  (bsc#1012628).
- ALSA: hda/realtek: Add pincfg for ASUS G533Z HP jack
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ASUS GA503R laptop
  (bsc#1012628).
- ALSA: hda/realtek: Enable 4-speaker output Dell Precision 5530
  laptop (bsc#1012628).
- ALSA: hda/realtek: Add a quirk for HP OMEN 16 (8902) mute LED
  (bsc#1012628).
- iommu/vt-d: Check correct capability for sagaw determination
  (bsc#1012628).
- exfat: fix overflow for large capacity partition (bsc#1012628).
- btrfs: fix hang during unmount when stopping block group
  reclaim worker (bsc#1012628).
- btrfs: fix hang during unmount when stopping a space reclaim
  worker (bsc#1012628).
- btrfs: zoned: wait for extent buffer IOs before finishing a zone
  (bsc#1012628).
- libperf evlist: Fix polling of system-wide events (bsc#1012628).
- media: flexcop-usb: fix endpoint type check (bsc#1012628).
- usb: dwc3: core: leave default DMA if the controller does not
  support 64-bit DMA (bsc#1012628).
- thunderbolt: Add support for Intel Maple Ridge single port
  controller (bsc#1012628).
- efi: x86: Wipe setup_data on pure EFI boot (bsc#1012628).
- efi: libstub: check Shim mode using MokSBStateRT (bsc#1012628).
- wifi: mt76: fix reading current per-tid starting sequence
  number for aggregation (bsc#1012628).
- gpio: mockup: fix NULL pointer dereference when removing debugfs
  (bsc#1012628).
- gpio: mockup: Fix potential resource leakage when register a
  chip (bsc#1012628).
- gpiolib: cdev: Set lineevent_state::irq after IRQ register
  successfully (bsc#1012628).
- riscv: fix a nasty sigreturn bug.. (bsc#1012628).
- riscv: fix RISCV_ISA_SVPBMT kconfig dependency warning
  (bsc#1012628).
- drm/i915/gem: Flush contexts on driver release (bsc#1012628).
- drm/i915/gem: Really move i915_gem_context.link under ref
  protection (bsc#1012628).
- xen/xenbus: fix xenbus_setup_ring() (bsc#1012628).
- kasan: call kasan_malloc() from __kmalloc_*track_caller()
  (bsc#1012628).
- can: flexcan: flexcan_mailbox_read() fix return value for drop =
  true (bsc#1012628).
- net: mana: Add rmb after checking owner bits (bsc#1012628).
- mm/slub: fix to return errno if kmalloc() fails (bsc#1012628).
- mm: slub: fix flush_cpu_slab()/__free_slab() invocations in
  task context (bsc#1012628).
- KVM: x86: Reinstate kvm_vcpu_arch.guest_supported_xcr0
  (bsc#1012628).
- KVM: x86: Always enable legacy FP/SSE in allowed user XFEATURES
  (bsc#1012628).
- KVM: x86: Inject #UD on emulated XSETBV if XSAVES isn't enabled
  (bsc#1012628).
- perf/arm-cmn: Add more bits to child node address offset field
  (bsc#1012628).
- arm64: topology: fix possible overflow in amu_fie_setup()
  (bsc#1012628).
- vmlinux.lds.h: CFI: Reduce alignment of jump-table to function
  alignment (bsc#1012628).
- batman-adv: Fix hang up with small MTU hard-interface
  (bsc#1012628).
- firmware: arm_scmi: Harden accesses to the reset domains
  (bsc#1012628).
- firmware: arm_scmi: Fix the asynchronous reset requests
  (bsc#1012628).
- arm64: dts: rockchip: Lower sd speed on quartz64-b
  (bsc#1012628).
- arm64: dts: rockchip: Pull up wlan wake# on Gru-Bob
  (bsc#1012628).
- arm64: dts: rockchip: Fix typo in lisense text for PX30.Core
  (bsc#1012628).
- drm/mediatek: dsi: Add atomic {destroy,duplicate}_state,
  reset callbacks (bsc#1012628).
- arm64: dts: imx8mm: Reverse CPLD_Dn GPIO label mapping on
  MX8Menlo (bsc#1012628).
- arm64: dts: rockchip: Set RK3399-Gru PCLK_EDP to 24 MHz
  (bsc#1012628).
- arm64: dts: imx8mn: remove GPU power domain reset (bsc#1012628).
- arm64: dts: imx8ulp: add #reset-cells for pcc (bsc#1012628).
- dmaengine: ti: k3-udma-private: Fix refcount leak bug in
  of_xudma_dev_get() (bsc#1012628).
- arm64: dts: rockchip: fix property for usb2 phy supply on
  rock-3a (bsc#1012628).
- arm64: dts: rockchip: fix property for usb2 phy supply on
  rk3568-evb1-v10 (bsc#1012628).
- arm64: dts: rockchip: Remove 'enable-active-low' from
  rk3399-puma (bsc#1012628).
- arm64: dts: rockchip: Remove 'enable-active-low' from
  rk3566-quartz64-a (bsc#1012628).
- arm64: dts: imx8mm-verdin: extend pmic voltages (bsc#1012628).
- netfilter: nf_conntrack_sip: fix ct_sip_walk_headers
  (bsc#1012628).
- netfilter: nf_conntrack_irc: Tighten matching on DCC message
  (bsc#1012628).
- netfilter: nfnetlink_osf: fix possible bogus match in
  nf_osf_find() (bsc#1012628).
- ice: Don't double unplug aux on peer initiated reset
  (bsc#1012628).
- ice: Fix crash by keep old cfg when update TCs more than queues
  (bsc#1012628).
- iavf: Fix cached head and tail value for iavf_get_tx_pending
  (bsc#1012628).
- ipvlan: Fix out-of-bound bugs caused by unset skb->mac_header
  (bsc#1012628).
- net: core: fix flow symmetric hash (bsc#1012628).
- wifi: iwlwifi: Mark IWLMEI as broken (bsc#1012628).
- arm64: dts: tqma8mqml: Include phy-imx8-pcie.h header
  (bsc#1012628).
- drm/mediatek: Fix wrong dither settings (bsc#1012628).
- arm64: dts: imx8mp-venice-gw74xx: fix CAN STBY polarity
  (bsc#1012628).
- arm64: dts: imx8mp-venice-gw74xx: fix ksz9477 cpu port
  (bsc#1012628).
- ARM: dts: lan966x: Fix the interrupt number for internal PHYs
  (bsc#1012628).
- net: phy: aquantia: wait for the suspend/resume operations to
  finish (bsc#1012628).
- arm64: dts: imx8mp-venice-gw74xx: fix port/phy validation
  (bsc#1012628).
- scsi: qla2xxx: Fix memory leak in __qlt_24xx_handle_abts()
  (bsc#1012628).
- scsi: mpt3sas: Fix return value check of dma_get_required_mask()
  (bsc#1012628).
- net: bonding: Share lacpdu_mcast_addr definition (bsc#1012628).
- net: bonding: Unsync device addresses on ndo_stop (bsc#1012628).
- net: team: Unsync device addresses on ndo_stop (bsc#1012628).
- drm/panel: simple: Fix innolux_g121i1_l01 bus_format
  (bsc#1012628).
- mm/slab_common: fix possible double free of kmem_cache
  (bsc#1012628).
- MIPS: lantiq: export clk_get_io() for lantiq_wdt.ko
  (bsc#1012628).
- MIPS: Loongson32: Fix PHY-mode being left unspecified
  (bsc#1012628).
- um: fix default console kernel parameter (bsc#1012628).
- iavf: Fix bad page state (bsc#1012628).
- mlxbf_gige: clear MDIO gateway lock after read (bsc#1012628).
- iavf: Fix set max MTU size with port VLAN and jumbo frames
  (bsc#1012628).
- i40e: Fix VF set max MTU size (bsc#1012628).
- i40e: Fix set max_tx_rate when it is lower than 1 Mbps
  (bsc#1012628).
- netdevsim: Fix hwstats debugfs file permissions (bsc#1012628).
- sfc: fix TX channel offset when using legacy interrupts
  (bsc#1012628).
- sfc: fix null pointer dereference in efx_hard_start_xmit
  (bsc#1012628).
- bnxt_en: fix flags to check for supported fw version
  (bsc#1012628).
- gve: Fix GFP flags when allocing pages (bsc#1012628).
- drm/hisilicon: Add depends on MMU (bsc#1012628).
- of: mdio: Add of_node_put() when breaking out of for_each_xx
  (bsc#1012628).
- net: ipa: properly limit modem routing table use (bsc#1012628).
- sfc/siena: fix TX channel offset when using legacy interrupts
  (bsc#1012628).
- sfc/siena: fix null pointer dereference in efx_hard_start_xmit
  (bsc#1012628).
- wireguard: ratelimiter: disable timings test by default
  (bsc#1012628).
- wireguard: netlink: avoid variable-sized memcpy on sockaddr
  (bsc#1012628).
- net: enetc: move enetc_set_psfp() out of the common
  enetc_set_features() (bsc#1012628).
- net: enetc: deny offload of tc-based TSN features on VF
  interfaces (bsc#1012628).
- ipv6: Fix crash when IPv6 is administratively disabled
  (bsc#1012628).
- net/sched: taprio: avoid disabling offload when it was never
  enabled (bsc#1012628).
- net/sched: taprio: make qdisc_leaf() see the per-netdev-queue
  pfifo child qdiscs (bsc#1012628).
- ice: config netdev tc before setting queues number
  (bsc#1012628).
- ice: Fix interface being down after reset with
  link-down-on-close flag on (bsc#1012628).
- netfilter: nf_tables: fix nft_counters_enabled underflow at
  nf_tables_addchain() (bsc#1012628).
- netfilter: nf_tables: fix percpu memory leak at
  nf_tables_addchain() (bsc#1012628).
- netfilter: ebtables: fix memory leak when blob is malformed
  (bsc#1012628).
- netfilter: nf_ct_ftp: fix deadlock when nat rewrite is needed
  (bsc#1012628).
- net: ravb: Fix PHY state warning splat during system resume
  (bsc#1012628).
- net: sh_eth: Fix PHY state warning splat during system resume
  (bsc#1012628).
- gpio: tqmx86: fix uninitialized variable girq (bsc#1012628).
- can: gs_usb: gs_can_open(): fix race dev->can.state condition
  (bsc#1012628).
- perf stat: Fix BPF program section name (bsc#1012628).
- perf stat: Fix cpu map index in bperf cgroup code (bsc#1012628).
- perf jit: Include program header in ELF files (bsc#1012628).
- perf kcore_copy: Do not check /proc/modules is unchanged
  (bsc#1012628).
- perf tools: Honor namespace when synthesizing build-ids
  (bsc#1012628).
- drm/mediatek: dsi: Move mtk_dsi_stop() call back to
  mtk_dsi_poweroff() (bsc#1012628).
- ice: Fix ice_xdp_xmit() when XDP TX queue number is not
  sufficient (bsc#1012628).
- net/smc: Stop the CLC flow if no link to map buffers on
  (bsc#1012628).
- net: phy: micrel: fix shared interrupt on LAN8814 (bsc#1012628).
- bonding: fix NULL deref in bond_rr_gen_slave_id (bsc#1012628).
- net: sunhme: Fix packet reception for len < RX_COPY_THRESHOLD
  (bsc#1012628).
- net: sched: fix possible refcount leak in tc_new_tfilter()
  (bsc#1012628).
- bnxt: prevent skb UAF after handing over to PTP worker
  (bsc#1012628).
- selftests: forwarding: add shebang for sch_red.sh (bsc#1012628).
- io_uring: ensure that cached task references are always put
  on exit (bsc#1012628).
- serial: fsl_lpuart: Reset prior to registration (bsc#1012628).
- serial: Create uart_xmit_advance() (bsc#1012628).
- serial: tegra: Use uart_xmit_advance(), fixes icount.tx
  accounting (bsc#1012628).
- serial: tegra-tcu: Use uart_xmit_advance(), fixes icount.tx
  accounting (bsc#1012628).
- cgroup: cgroup_get_from_id() must check the looked-up kn is
  a directory (bsc#1012628).
- phy: marvell: phy-mvebu-a3700-comphy: Remove broken reset
  support (bsc#1012628).
- s390/dasd: fix Oops in dasd_alias_get_start_dev due to missing
  pavgroup (bsc#1012628).
- drm/i915/display: Fix handling of enable_psr parameter
  (bsc#1012628).
- blk-mq: fix error handling in __blk_mq_alloc_disk (bsc#1012628).
- block: call blk_mq_exit_queue from disk_release for never
  added disks (bsc#1012628).
- block: Do not call blk_put_queue() if gendisk allocation fails
  (bsc#1012628).
- Drivers: hv: Never allocate anything besides framebuffer from
  framebuffer memory region (bsc#1012628).
- drm/gma500: Fix BUG: sleeping function called from invalid
  context errors (bsc#1012628).
- drm/gma500: Fix WARN_ON(lock->magic != lock) error
  (bsc#1012628).
- drm/gma500: Fix (vblank) IRQs not working after suspend/resume
  (bsc#1012628).
- gpio: ixp4xx: Make irqchip immutable (bsc#1012628).
- drm/amd/pm: disable BACO entry/exit completely on several
  sienna cichlid cards (bsc#1012628).
- drm/amdgpu: use dirty framebuffer helper (bsc#1012628).
- drm/amdgpu: change the alignment size of TMR BO to 1M
  (bsc#1012628).
- drm/amdgpu: add HDP remap functionality to nbio 7.7
  (bsc#1012628).
- drm/amdgpu: Skip reset error status for psp v13_0_0
  (bsc#1012628).
- drm/amd/display: Limit user regamma to a valid value
  (bsc#1012628).
- drm/amd/display: Reduce number of arguments of dml31's
  CalculateWatermarksAndDRAMSpeedChangeSupport() (bsc#1012628).
- drm/amd/display: Reduce number of arguments of dml31's
  CalculateFlipSchedule() (bsc#1012628).
- drm/amd/display: Mark dml30's UseMinimumDCFCLK() as noinline
  for stack usage (bsc#1012628).
- drm/rockchip: Fix return type of cdn_dp_connector_mode_valid
  (bsc#1012628).
- gpio: mt7621: Make the irqchip immutable (bsc#1012628).
- pmem: fix a name collision (bsc#1012628).
- fsdax: Fix infinite loop in dax_iomap_rw() (bsc#1012628).
- workqueue: don't skip lockdep work dependency in
  cancel_work_sync() (bsc#1012628).
- i2c: imx: If pm_runtime_get_sync() returned 1 device access
  is possible (bsc#1012628).
- i2c: mlxbf: incorrect base address passed during io write
  (bsc#1012628).
- i2c: mlxbf: prevent stack overflow in
  mlxbf_i2c_smbus_start_transaction() (bsc#1012628).
- i2c: mlxbf: Fix frequency calculation (bsc#1012628).
- i2c: mux: harden i2c_mux_alloc() against integer overflows
  (bsc#1012628).
- drm/amdgpu: don't register a dirty callback for non-atomic
  (bsc#1012628).
- certs: make system keyring depend on built-in x509 parser
  (bsc#1012628).
- Makefile.debug: set -g unconditional on CONFIG_DEBUG_INFO_SPLIT
  (bsc#1012628).
- Makefile.debug: re-enable debug info for .S files (bsc#1012628).
- devdax: Fix soft-reservation memory description (bsc#1012628).
- ext4: fix bug in extents parsing when eh_entries == 0 and
  eh_depth > 0 (bsc#1012628).
- ext4: limit the number of retries after discarding
  preallocations blocks (bsc#1012628).
- ext4: make mballoc try target group first even with
  mb_optimize_scan (bsc#1012628).
- ext4: avoid unnecessary spreading of allocations among groups
  (bsc#1012628).
- ext4: use locality group preallocation for small closed files
  (bsc#1012628).
- ext4: use buckets for cr 1 block scan instead of rbtree
  (bsc#1012628).
- ext4: fixup possible uninitialized variable access in
  ext4_mb_choose_next_group_cr1() (bsc#1012628).
- ext4: make directory inode spreading reflect flexbg size
  (bsc#1012628).
- Update config files.
- commit 95fa5b8
* Tue Sep 27 2022 ykaukab@suse.de
- constraints: increase disk space for all architectures
  References: bsc#1203693
  aarch64 is already suffering. SLE15-SP5 x86_64 stats show that it is
  very close to the limit.
- commit 43a9011
* Tue Sep 27 2022 dmueller@suse.com
- ACPI: processor idle: Practically limit "Dummy wait" workaround
  to old Intel systems (bsc#1203767).
- commit 2d94a9f
* Tue Sep 27 2022 jslaby@suse.cz
- Refresh
  patches.suse/Revert-block-freeze-the-queue-earlier-in-del_gendisk.patch.
  Update to upstream version.
- commit b4b8524
* Sun Sep 25 2022 mkubecek@suse.cz
- Update to 6.0-rc7
- refresh configs
- commit 74aafe0
* Fri Sep 23 2022 jslaby@suse.cz
- Linux 5.19.11 (bsc#1012628).
- of: fdt: fix off-by-one error in unflatten_dt_nodes()
  (bsc#1012628).
- pinctrl: qcom: sc8180x: Fix gpio_wakeirq_map (bsc#1012628).
- pinctrl: qcom: sc8180x: Fix wrong pin numbers (bsc#1012628).
- pinctrl: rockchip: Enhance support for IRQ_TYPE_EDGE_BOTH
  (bsc#1012628).
- pinctrl: sunxi: Fix name for A100 R_PIO (bsc#1012628).
- SUNRPC: Fix call completion races with call_decode()
  (bsc#1012628).
- NFSv4: Turn off open-by-filehandle and NFS re-export for NFSv4.0
  (bsc#1012628).
- gpio: mpc8xxx: Fix support for IRQ_TYPE_LEVEL_LOW flow_type
  in mpc85xx (bsc#1012628).
- NFSv4.2: Update mode bits after ALLOCATE and DEALLOCATE
  (bsc#1012628).
- Revert "SUNRPC: Remove unreachable error condition"
  (bsc#1012628).
- drm/panel-edp: Fix delays for Innolux N116BCA-EA1 (bsc#1012628).
- drm/meson: Correct OSD1 global alpha value (bsc#1012628).
- drm/meson: Fix OSD1 RGB to YCbCr coefficient (bsc#1012628).
- drm/rockchip: vop2: Fix eDP/HDMI sync polarities (bsc#1012628).
- drm/i915/vdsc: Set VDSC PIC_HEIGHT before using for DP DSC
  (bsc#1012628).
- drm/i915/guc: Don't update engine busyness stats too frequently
  (bsc#1012628).
- drm/i915/guc: Cancel GuC engine busyness worker synchronously
  (bsc#1012628).
- block: blk_queue_enter() / __bio_queue_enter() must return
  - EAGAIN for nowait (bsc#1012628).
- parisc: ccio-dma: Add missing iounmap in error path in
  ccio_probe() (bsc#1012628).
- of/device: Fix up of_dma_configure_id() stub (bsc#1012628).
- io_uring/msg_ring: check file type before putting (bsc#1012628).
- cifs: revalidate mapping when doing direct writes (bsc#1012628).
- cifs: don't send down the destination address to sendmsg for
  a SOCK_STREAM (bsc#1012628).
- cifs: always initialize struct msghdr smb_msg completely
  (bsc#1012628).
- blk-lib: fix blkdev_issue_secure_erase (bsc#1012628).
- parisc: Allow CONFIG_64BIT with ARCH=parisc (bsc#1012628).
- tools/include/uapi: Fix <asm/errno.h> for parisc and xtensa
  (bsc#1012628).
- drm/i915/gt: Fix perf limit reasons bit positions (bsc#1012628).
- drm/i915: Set correct domains values at _i915_vma_move_to_active
  (bsc#1012628).
- drm/amdgpu: make sure to init common IP before gmc
  (bsc#1012628).
- drm/amdgpu: Don't enable LTR if not supported (bsc#1012628).
- drm/amdgpu: move nbio ih_doorbell_range() into ih code for vega
  (bsc#1012628).
- drm/amdgpu: move nbio sdma_doorbell_range() into sdma code
  for vega (bsc#1012628).
- net: Find dst with sk's xfrm policy not ctl_sk (bsc#1012628).
- dt-bindings: apple,aic: Fix required item "apple,fiq-index"
  in affinity description (bsc#1012628).
- cgroup: Add missing cpus_read_lock() to cgroup_attach_task_all()
  (bsc#1012628).
- ALSA: hda/sigmatel: Keep power up while beep is enabled
  (bsc#1012628).
- ALSA: hda/sigmatel: Fix unused variable warning for beep power
  change (bsc#1012628).
- commit b35e71f
* Fri Sep 23 2022 dmueller@suse.com
- config(arm*): disable CONFIG_PM_AUTOSLEEP and CONFIG_PM_WAKELOCKS (bsc#1189677)
- commit 1c0b96b
* Thu Sep 22 2022 dmueller@suse.com
- config.conf: reenable armv6hl configs
- commit cd71399
* Thu Sep 22 2022 jslaby@suse.cz
- Refresh
  patches.suse/Revert-iommu-vt-d-Fix-possible-recursive-locking-in-.patch.
  Update upstream status.
- commit a267615
* Wed Sep 21 2022 tiwai@suse.de
- media: dvb-core: Fix UAF due to refcount races at releasing
  (CVE-2022-41218 bsc#1202960).
- commit 66556c1
* Wed Sep 21 2022 dmueller@suse.com
- arm64: enable CONFIG_ARCH_RENESAS (bsc#1203558)
  Also compile everything as modules that isn't debug
  or deprecated that was previously disabled by the
  global RENESAS disablement.
- commit b1f13b9
* Wed Sep 21 2022 dmueller@suse.com
- config.conf: Reenable arm64 configs
- Update config files, taken from 6.0-rc1 update from x86_64,
  enabling all new erratas, enabling all new modules
- commit 9b3cde4
* Wed Sep 21 2022 jslaby@suse.cz
- Revert "iommu/vt-d: Fix possible recursive locking in
  intel_iommu_init()" (iommu bug).
- commit 9392b7d
* Tue Sep 20 2022 jslaby@suse.cz
- Linux 5.19.10 (bsc#1012628).
- Input: goodix - add compatible string for GT1158 (bsc#1012628).
- RDMA/irdma: Use s/g array in post send only when its valid
  (bsc#1012628).
- gpio: 104-idio-16: Make irq_chip immutable (bsc#1012628).
- gpio: 104-dio-48e: Make irq_chip immutable (bsc#1012628).
- LoongArch: Fix arch_remove_memory() undefined build error
  (bsc#1012628).
- LoongArch: Fix section mismatch due to acpi_os_ioremap()
  (bsc#1012628).
- platform/x86: asus-wmi: Increase FAN_CURVE_BUF_LEN to 32
  (bsc#1012628).
- usb: storage: Add ASUS <0x0b05:0x1932> to IGNORE_UAS
  (bsc#1012628).
- platform/x86: acer-wmi: Acer Aspire One AOD270/Packard Bell
  Dot keymap fixes (bsc#1012628).
- perf/arm_pmu_platform: fix tests for platform_get_irq() failure
  (bsc#1012628).
- net: dsa: hellcreek: Print warning only once (bsc#1012628).
- drm/amd/amdgpu: skip ucode loading if ucode_size == 0
  (bsc#1012628).
- nvmet-tcp: fix unhandled tcp states in nvmet_tcp_state_change()
  (bsc#1012628).
- nvme-pci: add NVME_QUIRK_BOGUS_NID for Lexar NM610
  (bsc#1012628).
- drm/amd/pm: use vbios carried pptable for all SMU13.0.7 SKUs
  (bsc#1012628).
- drm/amdgpu: disable FRU access on special SIENNA CICHLID card
  (bsc#1012628).
- Input: iforce - add support for Boeder Force Feedback Wheel
  (bsc#1012628).
- ieee802154: cc2520: add rc code in cc2520_tx() (bsc#1012628).
- gpio: mockup: remove gpio debugfs when remove device
  (bsc#1012628).
- r8152: add PID for the Lenovo OneLink+ Dock (bsc#1012628).
- tg3: Disable tg3 device on system reboot to avoid triggering
  AER (bsc#1012628).
- Bluetooth: MGMT: Fix Get Device Flags (bsc#1012628).
- hid: intel-ish-hid: ishtp: Fix ishtp client sending disordered
  message (bsc#1012628).
- HID: ishtp-hid-clientHID: ishtp-hid-client: Fix comment typo
  (bsc#1012628).
- dt-bindings: iio: gyroscope: bosch,bmg160: correct number of
  pins (bsc#1012628).
- kvm: x86: mmu: Always flush TLBs when enabling dirty logging
  (bsc#1012628).
- peci: cpu: Fix use-after-free in adev_release() (bsc#1012628).
- drm/msm/rd: Fix FIFO-full deadlock (bsc#1012628).
- platform/surface: aggregator_registry: Add support for Surface
  Laptop Go 2 (bsc#1012628).
- Input: goodix - add support for GT1158 (bsc#1012628).
- ACPI: resource: skip IRQ override on AMD Zen platforms
  (bsc#1012628).
- RDMA/mlx5: Fix UMR cleanup on error flow of driver init
  (bsc#1012628).
- RDMA/mlx5: Add a umr recovery flow (bsc#1012628).
- RDMA/mlx5: Rely on RoCE fw cap instead of devlink when setting
  profile (bsc#1012628).
- net/mlx5: Use software VHCA id when it's supported
  (bsc#1012628).
- net/mlx5: Introduce ifc bits for using software vhca id
  (bsc#1012628).
- iommu/vt-d: Fix kdump kernels boot failure with scalable mode
  (bsc#1012628).
- commit 28d7d4c
* Sun Sep 18 2022 mkubecek@suse.cz
- Update to 6.0-rc6
- commit 2132e28
* Thu Sep 15 2022 jslaby@suse.cz
- Linux 5.19.9 (bsc#1012628).
- efi: libstub: Disable struct randomization (bsc#1012628).
- efi: capsule-loader: Fix use-after-free in efi_capsule_write
  (bsc#1012628).
- wifi: iwlegacy: 4965: corrected fix for potential off-by-one
  overflow in il4965_rs_fill_link_cmd() (bsc#1012628).
- fs: only do a memory barrier for the first set_buffer_uptodate()
  (bsc#1012628).
- soc: fsl: select FSL_GUTS driver for DPIO (bsc#1012628).
- Revert "mm: kmemleak: take a full lowmem check in
  kmemleak_*_phys()" (bsc#1012628).
- scsi: qla2xxx: Disable ATIO interrupt coalesce for quad port
  ISP27XX (bsc#1012628).
- scsi: core: Allow the ALUA transitioning state enough time
  (bsc#1012628).
- scsi: megaraid_sas: Fix double kfree() (bsc#1012628).
- drm/gem: Fix GEM handle release errors (bsc#1012628).
- drm/amdgpu: Move psp_xgmi_terminate call from
  amdgpu_xgmi_remove_device to psp_hw_fini (bsc#1012628).
- drm/amdgpu: fix hive reference leak when adding xgmi device
  (bsc#1012628).
- drm/amdgpu: Check num_gfx_rings for gfx v9_0 rb setup
  (bsc#1012628).
- drm/amdgpu: Remove the additional kfd pre reset call for sriov
  (bsc#1012628).
- drm/radeon: add a force flush to delay work when radeon
  (bsc#1012628).
- scsi: ufs: core: Reduce the power mode change timeout
  (bsc#1012628).
- Revert "parisc: Show error if wrong 32/64-bit compiler is
  being used" (bsc#1012628).
- parisc: ccio-dma: Handle kmalloc failure in
  ccio_init_resources() (bsc#1012628).
- parisc: Add runtime check to prevent PA2.0 kernels on PA1.x
  machines (bsc#1012628).
- arm64: errata: add detection for AMEVCNTR01 incrementing
  incorrectly (bsc#1012628).
- netfilter: conntrack: work around exceeded receive window
  (bsc#1012628).
- thermal/int340x_thermal: handle data_vault when the value is
  ZERO_SIZE_PTR (bsc#1012628).
- cpufreq: check only freq_table in __resolve_freq()
  (bsc#1012628).
- net/core/skbuff: Check the return value of skb_copy_bits()
  (bsc#1012628).
- md: Flush workqueue md_rdev_misc_wq in md_alloc() (bsc#1012628).
- fbdev: omapfb: Fix tests for platform_get_irq() failure
  (bsc#1012628).
- fbdev: fbcon: Destroy mutex on freeing struct fb_info
  (bsc#1012628).
- fbdev: chipsfb: Add missing pci_disable_device() in
  chipsfb_pci_init() (bsc#1012628).
- x86/sev: Mark snp_abort() noreturn (bsc#1012628).
- drm/amdgpu: add sdma instance check for gfx11 CGCG
  (bsc#1012628).
- drm/amdgpu: mmVM_L2_CNTL3 register not initialized correctly
  (bsc#1012628).
- ALSA: pcm: oss: Fix race at SNDCTL_DSP_SYNC (bsc#1012628).
- ALSA: emu10k1: Fix out of bounds access in
  snd_emu10k1_pcm_channel_alloc() (bsc#1012628).
- ALSA: hda: Once again fix regression of page allocations with
  IOMMU (bsc#1012628).
- ALSA: aloop: Fix random zeros in capture data when using
  jiffies timer (bsc#1012628).
- ALSA: usb-audio: Split endpoint setups for hw_params and prepare
  (bsc#1012628).
- ALSA: usb-audio: Clear fixed clock rate at closing EP
  (bsc#1012628).
- ALSA: usb-audio: Fix an out-of-bounds bug in
  __snd_usb_parse_audio_interface() (bsc#1012628).
- tracefs: Only clobber mode/uid/gid on remount if asked
  (bsc#1012628).
- tracing: hold caller_addr to hardirq_{enable,disable}_ip
  (bsc#1012628).
- tracing: Fix to check event_mutex is held while accessing
  trigger list (bsc#1012628).
- btrfs: zoned: set pseudo max append zone limit in zone emulation
  mode (bsc#1012628).
- btrfs: zoned: fix API misuse of zone finish waiting
  (bsc#1012628).
- vfio/type1: Unpin zero pages (bsc#1012628).
- kprobes: Prohibit probes in gate area (bsc#1012628).
- perf: RISC-V: fix access beyond allocated array (bsc#1012628).
- debugfs: add debugfs_lookup_and_remove() (bsc#1012628).
- sched/debug: fix dentry leak in update_sched_domain_debugfs
  (bsc#1012628).
- drm/amd/display: fix memory leak when using debugfs_lookup()
  (bsc#1012628).
- driver core: fix driver_set_override() issue with empty strings
  (bsc#1012628).
- nvmet: fix a use-after-free (bsc#1012628).
- drm/i915/bios: Copy the whole MIPI sequence block (bsc#1012628).
- drm/i915/slpc: Let's fix the PCODE min freq table setup for SLPC
  (bsc#1012628).
- drm/i915: Implement WaEdpLinkRateDataReload (bsc#1012628).
- scsi: mpt3sas: Fix use-after-free warning (bsc#1012628).
- scsi: lpfc: Add missing destroy_workqueue() in error path
  (bsc#1012628).
- cgroup: Elide write-locking threadgroup_rwsem when updating
  csses on an empty subtree (bsc#1012628).
- cgroup: Fix threadgroup_rwsem <-> cpus_read_lock() deadlock
  (bsc#1012628).
- cifs: remove useless parameter 'is_fsctl' from SMB2_ioctl()
  (bsc#1012628).
- smb3: missing inode locks in zero range (bsc#1012628).
- spi: bitbang: Fix lsb-first Rx (bsc#1012628).
- ASoC: cs42l42: Only report button state if there was a button
  interrupt (bsc#1012628).
- Revert "soc: imx: imx8m-blk-ctrl: set power device name"
  (bsc#1012628).
- arm64: dts: imx8mm-verdin: update CAN clock to 40MHz
  (bsc#1012628).
- arm64: dts: imx8mm-verdin: use level interrupt for mcp251xfd
  (bsc#1012628).
- ASoC: qcom: sm8250: add missing module owner (bsc#1012628).
- regmap: spi: Reserve space for register address/padding
  (bsc#1012628).
- arm64: dts: imx8mp-venice-gw74xx: fix sai2 pin settings
  (bsc#1012628).
- arm64: dts: imx8mq-tqma8mq: Remove superfluous interrupt-names
  (bsc#1012628).
- RDMA/rtrs-clt: Use the right sg_cnt after ib_dma_map_sg
  (bsc#1012628).
- RDMA/rtrs-srv: Pass the correct number of entries for dma
  mapped SGL (bsc#1012628).
- ARM: dts: imx6qdl-vicut1.dtsi: Fix node name backlight_led
  (bsc#1012628).
- ARM: dts: imx6qdl-kontron-samx6i: remove duplicated node
  (bsc#1012628).
- ARM: dts: imx6qdl-kontron-samx6i: fix spi-flash compatible
  (bsc#1012628).
- arm64: dts: ls1028a-qds-65bb: don't use in-band autoneg for
  2500base-x (bsc#1012628).
- soc: imx: gpcv2: Assert reset before ungating clock
  (bsc#1012628).
- arm64: dts: verdin-imx8mm: add otg2 pd to usbphy (bsc#1012628).
- arm64: dts: imx8mm-venice-gw7901: fix port/phy validation
  (bsc#1012628).
- arm64: dts: freescale: verdin-imx8mm: fix atmel_mxt_ts reset
  polarity (bsc#1012628).
- arm64: dts: freescale: verdin-imx8mp: fix atmel_mxt_ts reset
  polarity (bsc#1012628).
- regulator: core: Clean up on enable failure (bsc#1012628).
- ASoC: SOF: Kconfig: Make IPC_FLOOD_TEST depend on SND_SOC_SOF
  (bsc#1012628).
- ASoC: SOF: Kconfig: Make IPC_MESSAGE_INJECTOR depend on
  SND_SOC_SOF (bsc#1012628).
- tee: fix compiler warning in tee_shm_register() (bsc#1012628).
- RDMA/irdma: Fix drain SQ hang with no completion (bsc#1012628).
- arm64: dts: renesas: r8a779g0: Fix HSCIF0 interrupt number
  (bsc#1012628).
- RDMA/cma: Fix arguments order in net device validation
  (bsc#1012628).
- soc: brcmstb: pm-arm: Fix refcount leak and __iomem leak bugs
  (bsc#1012628).
- RDMA/hns: Fix supported page size (bsc#1012628).
- RDMA/hns: Fix wrong fixed value of qp->rq.wqe_shift
  (bsc#1012628).
- RDMA/hns: Remove the num_qpc_timer variable (bsc#1012628).
- wifi: wilc1000: fix DMA on stack objects (bsc#1012628).
- ARM: at91: pm: fix self-refresh for sama7g5 (bsc#1012628).
- ARM: at91: pm: fix DDR recalibration when resuming from backup
  and self-refresh (bsc#1012628).
- ARM: dts: at91: sama5d27_wlsom1: specify proper regulator
  output ranges (bsc#1012628).
- ARM: dts: at91: sama5d2_icp: specify proper regulator output
  ranges (bsc#1012628).
- ARM: dts: at91: sama7g5ek: specify proper regulator output
  ranges (bsc#1012628).
- ARM: dts: at91: sama5d27_wlsom1: don't keep ldo2 enabled all
  the time (bsc#1012628).
- ARM: dts: at91: sama5d2_icp: don't keep vdd_other enabled all
  the time (bsc#1012628).
- netfilter: br_netfilter: Drop dst references before setting
  (bsc#1012628).
- netfilter: nf_tables: clean up hook list when offload flags
  check fails (bsc#1012628).
- riscv: dts: microchip: use an mpfs specific l2 compatible
  (bsc#1012628).
- netfilter: nf_conntrack_irc: Fix forged IP logic (bsc#1012628).
- RDMA/srp: Set scmnd->result only when scmnd is not NULL
  (bsc#1012628).
- ALSA: usb-audio: Inform the delayed registration more properly
  (bsc#1012628).
- ALSA: usb-audio: Register card again for iface over
  delayed_register option (bsc#1012628).
- rxrpc: Fix ICMP/ICMP6 error handling (bsc#1012628).
- rxrpc: Fix an insufficiently large sglist in
  rxkad_verify_packet_2() (bsc#1012628).
- afs: Use the operation issue time instead of the reply time
  for callbacks (bsc#1012628).
- kunit: fix assert_type for comparison macros (bsc#1012628).
- Revert "net: phy: meson-gxl: improve link-up behavior"
  (bsc#1012628).
- sch_sfb: Don't assume the skb is still around after enqueueing
  to child (bsc#1012628).
- tipc: fix shift wrapping bug in map_get() (bsc#1012628).
- net: introduce __skb_fill_page_desc_noacc (bsc#1012628).
- tcp: TX zerocopy should not sense pfmemalloc status
  (bsc#1012628).
- ice: Fix DMA mappings leak (bsc#1012628).
- ice: use bitmap_free instead of devm_kfree (bsc#1012628).
- i40e: Fix kernel crash during module removal (bsc#1012628).
- iavf: Detach device during reset task (bsc#1012628).
- xen-netback: only remove 'hotplug-status' when the vif is
  actually destroyed (bsc#1012628).
- block: don't add partitions if GD_SUPPRESS_PART_SCAN is set
  (bsc#1012628).
- RDMA/siw: Pass a pointer to virt_to_page() (bsc#1012628).
- bonding: use unspecified address if no available link local
  address (bsc#1012628).
- bonding: add all node mcast address when slave up (bsc#1012628).
- ipv6: sr: fix out-of-bounds read when setting HMAC data
  (bsc#1012628).
- IB/core: Fix a nested dead lock as part of ODP flow
  (bsc#1012628).
- RDMA/mlx5: Set local port to one when accessing counters
  (bsc#1012628).
- btrfs: zoned: fix mounting with conventional zones
  (bsc#1012628).
- erofs: fix error return code in erofs_fscache_{meta_,}read_folio
  (bsc#1012628).
- erofs: fix pcluster use-after-free on UP platforms
  (bsc#1012628).
- nvme-tcp: fix UAF when detecting digest errors (bsc#1012628).
- nvme-tcp: fix regression that causes sporadic requests to time
  out (bsc#1012628).
- tcp: fix early ETIMEDOUT after spurious non-SACK RTO
  (bsc#1012628).
- btrfs: fix the max chunk size and stripe length calculation
  (bsc#1012628).
- nvmet: fix mar and mor off-by-one errors (bsc#1012628).
- RDMA/irdma: Report the correct max cqes from query device
  (bsc#1012628).
- RDMA/irdma: Return error on MR deregister CQP failure
  (bsc#1012628).
- RDMA/irdma: Return correct WC error for bind operation failure
  (bsc#1012628).
- RDMA/irdma: Report RNR NAK generation in device caps
  (bsc#1012628).
- net: dsa: felix: disable cut-through forwarding for frames
  oversized for tc-taprio (bsc#1012628).
- net: dsa: felix: access QSYS_TAG_CONFIG under tas_lock in
  vsc9959_sched_speed_set (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix typo in __mtk_foe_entry_clear
  (bsc#1012628).
- net: ethernet: mtk_eth_soc: check max allowed hash in
  mtk_ppe_check_skb (bsc#1012628).
- net/smc: Fix possible access to freed memory in link clear
  (bsc#1012628).
- io_uring: recycle kbuf recycle on tw requeue (bsc#1012628).
- net: phy: lan87xx: change interrupt src of link_up to comm_ready
  (bsc#1012628).
- sch_sfb: Also store skb len before calling child enqueue
  (bsc#1012628).
- libperf evlist: Fix per-thread mmaps for multi-threaded targets
  (bsc#1012628).
- perf dlfilter dlfilter-show-cycles: Fix types for print format
  (bsc#1012628).
- perf script: Fix Cannot print 'iregs' field for hybrid systems
  (bsc#1012628).
- perf record: Fix synthesis failure warnings (bsc#1012628).
- hwmon: (tps23861) fix byte order in resistance register
  (bsc#1012628).
- ASoC: mchp-spdiftx: remove references to mchp_i2s_caps
  (bsc#1012628).
- ASoC: mchp-spdiftx: Fix clang -Wbitfield-constant-conversion
  (bsc#1012628).
- lsm,io_uring: add LSM hooks for the new uring_cmd file op
  (bsc#1012628).
- selinux: implement the security_uring_cmd() LSM hook
  (bsc#1012628).
- Smack: Provide read control for io_uring_cmd (bsc#1012628).
- MIPS: loongson32: ls1c: Fix hang during startup (bsc#1012628).
- kbuild: disable header exports for UML in a straightforward way
  (bsc#1012628).
- i40e: Refactor tc mqprio checks (bsc#1012628).
- i40e: Fix ADQ rate limiting for PF (bsc#1012628).
- net: bonding: replace dev_trans_start() with the jiffies of
  the last ARP/NS (bsc#1012628).
- bonding: accept unsolicited NA message (bsc#1012628).
- swiotlb: avoid potential left shift overflow (bsc#1012628).
- iommu/amd: use full 64-bit value in build_completion_wait()
  (bsc#1012628).
- s390/boot: fix absolute zero lowcore corruption on boot
  (bsc#1012628).
- time64.h: consolidate uses of PSEC_PER_NSEC (bsc#1012628).
- net: dsa: felix: tc-taprio intervals smaller than MTU should
  send at least one packet (bsc#1012628).
- hwmon: (mr75203) fix VM sensor allocation when "intel,vm-map"
  not defined (bsc#1012628).
- hwmon: (mr75203) update pvt->v_num and vm_num to the actual
  number of used sensors (bsc#1012628).
- hwmon: (mr75203) fix voltage equation for negative source input
  (bsc#1012628).
- hwmon: (mr75203) fix multi-channel voltage reading
  (bsc#1012628).
- hwmon: (mr75203) enable polling for all VM channels
  (bsc#1012628).
- iommu/vt-d: Fix possible recursive locking in intel_iommu_init()
  (bsc#1012628).
- perf evlist: Always use arch_evlist__add_default_attrs()
  (bsc#1012628).
- perf stat: Fix L2 Topdown metrics disappear for raw events
  (bsc#1012628).
- Revert "arm64: kasan: Revert "arm64: mte: reset the page tag
  in page->flags"" (bsc#1012628).
- hwmon: (asus-ec-sensors) add support for Strix Z690-a D4
  (bsc#1012628).
- hwmon: (asus-ec-sensors) add support for Maximus XI Hero
  (bsc#1012628).
- hwmon: (asus-ec-sensors) add missing sensors for X570-I GAMING
  (bsc#1012628).
- hwmon: (asus-ec-sensors) add definitions for ROG ZENITH II
  EXTREME (bsc#1012628).
- hwmon: (asus-ec-sensors) autoload module via DMI data
  (bsc#1012628).
- arm64/bti: Disable in kernel BTI when cross section thunks
  are broken (bsc#1012628).
- iommu/vt-d: Correctly calculate sagaw value of IOMMU
  (bsc#1012628).
- iommu/virtio: Fix interaction with VFIO (bsc#1012628).
- Update config files.
- commit 0312ea1
* Mon Sep 12 2022 jdelvare@suse.de
- watchdog: wdat_wdt: Set the min and max timeout values properly
  (bsc#1194023).
- commit a5f18a6
* Mon Sep 12 2022 tiwai@suse.de
- iommu: Fix false ownership failure on AMD systems with PASID
  activated (bsc#1202492).
- commit c4990ab
* Mon Sep 12 2022 tiwai@suse.de
- Drop temporary workaround patch for HD-audio IOMMU bug (bsc#1202492)
  The proper upstream fix will be merged instead
- commit 23d9d61
* Sun Sep 11 2022 mkubecek@suse.cz
- Update to 6.0-rc5
- eliminate 5 patches:
  - patches.suse/ASoC-nau8540-Implement-hw-constraint-for-rates.patch
  - patches.suse/ASoC-nau8821-Implement-hw-constraint-for-rates.patch
  - patches.suse/ASoC-nau8824-Fix-semaphore-unbalance-at-error-paths.patch
  - patches.suse/ASoC-nau8824-Implement-hw-constraint-for-rates.patch
  - patches.suse/ASoC-nau8825-Implement-hw-constraint-for-rates.patch
- refresh configs
- commit f7dcc92
* Thu Sep  8 2022 jslaby@suse.cz
- Linux 5.19.8 (bsc#1012628).
- drm/msm/dp: make eDP panel as the first connected connector
  (bsc#1012628).
- drm/msm/dsi: fix the inconsistent indenting (bsc#1012628).
- drm/msm/dpu: populate wb or intf before reset_intf_cfg
  (bsc#1012628).
- drm/msm/dp: delete DP_RECOVERED_CLOCK_OUT_EN to fix tps4
  (bsc#1012628).
- drm/msm/dsi: Fix number of regulators for msm8996_dsi_cfg
  (bsc#1012628).
- drm/msm/dsi: Fix number of regulators for SDM660 (bsc#1012628).
- platform/x86: pmc_atom: Fix SLP_TYPx bitfield mask
  (bsc#1012628).
- platform/x86: x86-android-tablets: Fix broken touchscreen on
  Chuwi Hi8 with Windows BIOS (bsc#1012628).
- xsk: Fix corrupted packets for XDP_SHARED_UMEM (bsc#1012628).
- drm/msm/gpu: Drop qos request if devm_devfreq_add_device()
  fails (bsc#1012628).
- peci: aspeed: fix error check return value of platform_get_irq()
  (bsc#1012628).
- iio: adc: mcp3911: make use of the sign bit (bsc#1012628).
- skmsg: Fix wrong last sg check in sk_msg_recvmsg()
  (bsc#1012628).
- bpf: Restrict bpf_sys_bpf to CAP_PERFMON (bsc#1012628).
- ip_tunnel: Respect tunnel key's "flow_flags" in IP tunnels
  (bsc#1012628).
- bpf, cgroup: Fix kernel BUG in purge_effective_progs
  (bsc#1012628).
- drm/i915/gvt: Fix Comet Lake (bsc#1012628).
- ieee802154/adf7242: defer destroy_workqueue call (bsc#1012628).
- bpf: Fix a data-race around bpf_jit_limit (bsc#1012628).
- drm/i915/ttm: fix CCS handling (bsc#1012628).
- drm/i915/display: avoid warnings when registering dual panel
  backlight (bsc#1012628).
- ALSA: hda: intel-nhlt: Correct the handling of fmt_config
  flexible array (bsc#1012628).
- wifi: cfg80211: debugfs: fix return type in ht40allow_map_read()
  (bsc#1012628).
- xhci: Fix null pointer dereference in remove if xHC has only
  one roothub (bsc#1012628).
- Revert "xhci: turn off port power in shutdown" (bsc#1012628).
- bpf: Allow helpers to accept pointers with a fixed size
  (bsc#1012628).
- bpf: Tidy up verifier check_func_arg() (bsc#1012628).
- bpf: Do mark_chain_precision for ARG_CONST_ALLOC_SIZE_OR_ZERO
  (bsc#1012628).
- Bluetooth: hci_event: Fix vendor (unknown) opcode status
  handling (bsc#1012628).
- Bluetooth: hci_sync: Fix suspend performance regression
  (bsc#1012628).
- Bluetooth: hci_event: Fix checking conn for le_conn_complete_evt
  (bsc#1012628).
- Bluetooth: hci_sync: hold hdev->lock when cleanup hci_conn
  (bsc#1012628).
- net: sparx5: fix handling uneven length packets in manual
  extraction (bsc#1012628).
- net: smsc911x: Stop and start PHY during suspend and resume
  (bsc#1012628).
- openvswitch: fix memory leak at failed datapath creation
  (bsc#1012628).
- nfp: flower: fix ingress police using matchall filter
  (bsc#1012628).
- net: dsa: xrs700x: Use irqsave variant for u64 stats update
  (bsc#1012628).
- drm/i915: fix null pointer dereference (bsc#1012628).
- net: sched: tbf: don't call qdisc_put() while holding tree lock
  (bsc#1012628).
- net/sched: fix netdevice reference leaks in
  attach_default_qdiscs() (bsc#1012628).
- net: phy: micrel: Make the GPIO to be non-exclusive
  (bsc#1012628).
- net: lan966x: improve error handle in
  lan966x_fdma_rx_get_frame() (bsc#1012628).
- ethernet: rocker: fix sleep in atomic context bug in
  neigh_timer_handler (bsc#1012628).
- cachefiles: fix error return code in cachefiles_ondemand_copen()
  (bsc#1012628).
- cachefiles: make on-demand request distribution fairer
  (bsc#1012628).
- mlxbf_gige: compute MDIO period based on i1clk (bsc#1012628).
- kcm: fix strp_init() order and cleanup (bsc#1012628).
- sch_cake: Return __NET_XMIT_STOLEN when consuming enqueued skb
  (bsc#1012628).
- tcp: annotate data-race around challenge_timestamp
  (bsc#1012628).
- Revert "sch_cake: Return __NET_XMIT_STOLEN when consuming
  enqueued skb" (bsc#1012628).
- net/smc: Remove redundant refcount increase (bsc#1012628).
- soundwire: qcom: fix device status array range (bsc#1012628).
- mm/slab_common: Deleting kobject in kmem_cache_destroy()
  without holding slab_mutex/cpu_hotplug_lock (bsc#1012628).
- platform/mellanox: mlxreg-lc: Fix coverity warning
  (bsc#1012628).
- platform/mellanox: mlxreg-lc: Fix locking issue (bsc#1012628).
- serial: fsl_lpuart: RS485 RTS polariy is inverse (bsc#1012628).
- tty: serial: atmel: Preserve previous USART mode if RS485
  disabled (bsc#1012628).
- staging: rtl8712: fix use after free bugs (bsc#1012628).
- staging: r8188eu: Add Rosewill USB-N150 Nano to device tables
  (bsc#1012628).
- staging: r8188eu: add firmware dependency (bsc#1012628).
- Revert "powerpc: Remove unused FW_FEATURE_NATIVE references"
  (bsc#1012628).
- powerpc: align syscall table for ppc32 (bsc#1012628).
- powerpc/rtas: Fix RTAS MSR[HV] handling for Cell (bsc#1012628).
- vt: Clear selection before changing the font (bsc#1012628).
- musb: fix USB_MUSB_TUSB6010 dependency (bsc#1012628).
- tty: serial: lpuart: disable flow control while waiting for
  the transmit engine to complete (bsc#1012628).
- Input: iforce - wake up after clearing IFORCE_XMIT_RUNNING flag
  (bsc#1012628).
- iio: light: cm3605: Fix an error handling path in cm3605_probe()
  (bsc#1012628).
- iio: ad7292: Prevent regulator double disable (bsc#1012628).
- iio: adc: mcp3911: correct "microchip,device-addr" property
  (bsc#1012628).
- iio: adc: mcp3911: use correct formula for AD conversion
  (bsc#1012628).
- misc: fastrpc: fix memory corruption on probe (bsc#1012628).
- misc: fastrpc: fix memory corruption on open (bsc#1012628).
- firmware_loader: Fix use-after-free during unregister
  (bsc#1012628).
- firmware_loader: Fix memory leak in firmware upload
  (bsc#1012628).
- USB: serial: ftdi_sio: add Omron CS1W-CIF31 device id
  (bsc#1012628).
- landlock: Fix file reparenting without explicit
  LANDLOCK_ACCESS_FS_REFER (bsc#1012628).
- mmc: core: Fix UHS-I SD 1.8V workaround branch (bsc#1012628).
- mmc: core: Fix inconsistent sd3_bus_mode at UHS-I SD voltage
  switch failure (bsc#1012628).
- binder: fix UAF of ref->proc caused by race condition
  (bsc#1012628).
- binder: fix alloc->vma_vm_mm null-ptr dereference (bsc#1012628).
- cifs: fix small mempool leak in SMB2_negotiate() (bsc#1012628).
- KVM: VMX: Heed the 'msr' argument in msr_write_intercepted()
  (bsc#1012628).
- riscv: kvm: move extern sbi_ext declarations to a header
  (bsc#1012628).
- clk: ti: Fix missing of_node_get() ti_find_clock_provider()
  (bsc#1012628).
- drm/i915/reg: Fix spelling mistake "Unsupport" -> "Unsupported"
  (bsc#1012628).
- clk: core: Honor CLK_OPS_PARENT_ENABLE for clk gate ops
  (bsc#1012628).
- Revert "clk: core: Honor CLK_OPS_PARENT_ENABLE for clk gate ops"
  (bsc#1012628).
- clk: core: Fix runtime PM sequence in clk_core_unprepare()
  (bsc#1012628).
- Input: rk805-pwrkey - fix module autoloading (bsc#1012628).
- powerpc/papr_scm: Fix nvdimm event mappings (bsc#1012628).
- clk: bcm: rpi: Fix error handling of raspberrypi_fw_get_rate
  (bsc#1012628).
- clk: bcm: rpi: Prevent out-of-bounds access (bsc#1012628).
- clk: bcm: rpi: Add missing newline (bsc#1012628).
- hwmon: (gpio-fan) Fix array out of bounds access (bsc#1012628).
- gpio: pca953x: Add mutex_lock for regcache sync in PM
  (bsc#1012628).
- gpio: realtek-otto: switch to 32-bit I/O (bsc#1012628).
- KVM: x86: Mask off unsupported and unknown bits of
  IA32_ARCH_CAPABILITIES (bsc#1012628).
- powerpc/papr_scm: Ensure rc is always initialized in
  papr_scm_pmu_register() (bsc#1012628).
- xen/grants: prevent integer overflow in gnttab_dma_alloc_pages()
  (bsc#1012628).
- mm: pagewalk: Fix race between unmap and page walker
  (bsc#1012628).
- xen-blkback: Advertise feature-persistent as user requested
  (bsc#1012628).
- xen-blkfront: Advertise feature-persistent as user requested
  (bsc#1012628).
- xen-blkfront: Cache feature_persistent value before
  advertisement (bsc#1012628).
- thunderbolt: Use the actual buffer in tb_async_error()
  (bsc#1012628).
- thunderbolt: Check router generation before connecting xHCI
  (bsc#1012628).
- usb: dwc3: pci: Add support for Intel Raptor Lake (bsc#1012628).
- media: mceusb: Use new usb_control_msg_*() routines
  (bsc#1012628).
- xhci: Add grace period after xHC start to prevent premature
  runtime suspend (bsc#1012628).
- usb: dwc3: disable USB core PHY management (bsc#1012628).
- usb: dwc3: gadget: Avoid duplicate requests to enable Run/Stop
  (bsc#1012628).
- usb: dwc3: fix PHY disable sequence (bsc#1012628).
- USB: serial: ch341: fix lost character on LCR updates
  (bsc#1012628).
- USB: serial: ch341: fix disabled rx timer on older devices
  (bsc#1012628).
- USB: serial: cp210x: add Decagon UCA device id (bsc#1012628).
- USB: serial: option: add support for OPPO R11 diag port
  (bsc#1012628).
- USB: serial: option: add Quectel EM060K modem (bsc#1012628).
- USB: serial: option: add support for Cinterion MV32-WA/WB
  RmNet mode (bsc#1012628).
- usb: typec: altmodes/displayport: correct pin assignment for
  UFP receptacles (bsc#1012628).
- usb: typec: intel_pmc_mux: Add new ACPI ID for Meteor Lake
  IOM device (bsc#1012628).
- usb: typec: tcpm: Return ENOTSUPP for power supply prop writes
  (bsc#1012628).
- usb: dwc2: fix wrong order of phy_power_on and phy_init
  (bsc#1012628).
- usb: cdns3: fix issue with rearming ISO OUT endpoint
  (bsc#1012628).
- usb: cdns3: fix incorrect handling TRB_SMM flag for ISOC
  transfer (bsc#1012628).
- USB: cdc-acm: Add Icom PMR F3400 support (0c26:0020)
  (bsc#1012628).
- usb-storage: Add ignore-residue quirk for NXP PN7462AU
  (bsc#1012628).
- s390/hugetlb: fix prepare_hugepage_range() check for 2 GB
  hugepages (bsc#1012628).
- s390: fix nospec table alignments (bsc#1012628).
- USB: core: Prevent nested device-reset calls (bsc#1012628).
- usb: xhci-mtk: relax TT periodic bandwidth allocation
  (bsc#1012628).
- usb: xhci-mtk: fix bandwidth release issue (bsc#1012628).
- usb: gadget: f_uac2: fix superspeed transfer (bsc#1012628).
- usb: gadget: mass_storage: Fix cdrom data transfers on MAC-OS
  (bsc#1012628).
- USB: gadget: Fix obscure lockdep violation for udc_mutex
  (bsc#1012628).
- dma-buf/dma-resv: check if the new fence is really later
  (bsc#1012628).
- arm64/kexec: Fix missing extra range for crashkres_low
  (bsc#1012628).
- driver core: Don't probe devices after bus_type.match() probe
  deferral (bsc#1012628).
- wifi: mac80211: Don't finalize CSA in IBSS mode if state is
  disconnected (bsc#1012628).
- wifi: mac80211: Fix UAF in ieee80211_scan_rx() (bsc#1012628).
- ip: fix triggering of 'icmp redirect' (bsc#1012628).
- net: Use u64_stats_fetch_begin_irq() for stats fetch
  (bsc#1012628).
- net: mac802154: Fix a condition in the receive path
  (bsc#1012628).
- ALSA: memalloc: Revive x86-specific WC page allocations again
  (bsc#1012628).
- ALSA: hda/realtek: Add speaker AMP init for Samsung laptops
  with ALC298 (bsc#1012628).
- ALSA: seq: oss: Fix data-race for max_midi_devs access
  (bsc#1012628).
- ALSA: seq: Fix data-race at module auto-loading (bsc#1012628).
- drm/i915/backlight: Disable pps power hook for aux based
  backlight (bsc#1012628).
- drm/i915/guc: clear stalled request after a reset (bsc#1012628).
- drm/i915/glk: ECS Liva Q2 needs GLK HDMI port timing quirk
  (bsc#1012628).
- drm/i915: Skip wm/ddb readout for disabled pipes (bsc#1012628).
- tty: n_gsm: add sanity check for gsm->receive in
  gsm_receive_buf() (bsc#1012628).
- tty: n_gsm: initialize more members at gsm_alloc_mux()
  (bsc#1012628).
- tty: n_gsm: replace kicktimer with delayed_work (bsc#1012628).
- tty: n_gsm: avoid call of sleeping functions from atomic context
  (bsc#1012628).
- commit 0330383
* Thu Sep  8 2022 jslaby@suse.cz
- Refresh
  patches.suse/Revert-usb-typec-ucsi-add-a-common-function-ucsi_unr.patch.
  Update upstream info.
- commit 9b6c180
* Wed Sep  7 2022 jslaby@suse.cz
- Revert "Revert "btrfs: check if root is readonly while setting security" (bsc#1203114)
  This reverts commit 2b3da4915c03713f32e48582d3a1130238586489.
  iWe can revert it as microos-tools are fixed now:
  https://build.opensuse.org/request/show/1001364
- commit 9291084
* Tue Sep  6 2022 tiwai@suse.de
- vduse: prevent uninitialized memory accesses (CVE-2022-2308
  bsc#1202573).
- commit 70d9c50
* Mon Sep  5 2022 jslaby@suse.cz
- Refresh
  patches.kernel.org/5.19.5-001-kbuild-dummy-tools-avoid-tmpdir-leak-in-dummy-.patch.
  Make it really create the file. Sometimes, quilt is confused.
- commit 11a0be1
* Mon Sep  5 2022 jslaby@suse.cz
- Revert "btrfs: check if root is readonly while setting security
  xattr" (bsc#1203114).
- commit 2b3da49
* Mon Sep  5 2022 jslaby@suse.cz
- Linux 5.19.7 (bsc#1012628).
- arm64: cacheinfo: Fix incorrect assignment of signed error
  value to unsigned fw_level (bsc#1012628).
- net: neigh: don't call kfree_skb() under spin_lock_irqsave()
  (bsc#1012628).
- net/af_packet: check len when min_header_len equals to 0
  (bsc#1012628).
- android: binder: fix lockdep check on clearing vma
  (bsc#1012628).
- btrfs: tree-checker: check for overlapping extent items
  (bsc#1012628).
- btrfs: fix lockdep splat with reloc root extent buffers
  (bsc#1012628).
- btrfs: move lockdep class helpers to locking.c (bsc#1012628).
- ALSA: hda/cs8409: Support new Dolphin Variants (bsc#1012628).
- platform/x86: serial-multi-instantiate: Add CLSA0101 Laptop
  (bsc#1012628).
- testing: selftests: nft_flowtable.sh: use random netns names
  (bsc#1012628).
- netfilter: conntrack: NF_CONNTRACK_PROCFS should no longer
  default to y (bsc#1012628).
- drm/amdgpu: Fix interrupt handling on ih_soft ring
  (bsc#1012628).
- drm/amdgpu: Add secure display TA load for Renoir (bsc#1012628).
- drm/amdgpu: Add decode_iv_ts helper for ih_v6 block
  (bsc#1012628).
- drm/amd/display: avoid doing vm_init multiple time
  (bsc#1012628).
- drm/amd/display: Fix plug/unplug external monitor will hang
  while playback MPO video (bsc#1012628).
- drm/amdgpu: Increase tlb flush timeout for sriov (bsc#1012628).
- drm/amd/display: Fix pixel clock programming (bsc#1012628).
- drm/amd/pm: add missing ->fini_xxxx interfaces for some SMU13
  asics (bsc#1012628).
- drm/amd/pm: add missing ->fini_microcode interface for Sienna
  Cichlid (bsc#1012628).
- drm/amdgpu: disable 3DCGCG/CGLS temporarily due to stability
  issue (bsc#1012628).
- ksmbd: don't remove dos attribute xattr on O_TRUNC open
  (bsc#1012628).
- s390/hypfs: avoid error message under KVM (bsc#1012628).
- ALSA: hda/realtek: Add quirks for ASUS Zenbooks using CS35L41
  (bsc#1012628).
- neigh: fix possible DoS due to net iface start/stop loop
  (bsc#1012628).
- net: lan966x: fix checking for return value of
  platform_get_irq_byname() (bsc#1012628).
- ksmbd: return STATUS_BAD_NETWORK_NAME error status if share
  is not configured (bsc#1012628).
- drm/amd/pm: Fix a potential gpu_metrics_table memory leak
  (bsc#1012628).
- drm/amdkfd: Handle restart of kfd_ioctl_wait_events
  (bsc#1012628).
- drm/amd/pm: skip pptable override for smu_v13_0_7 (bsc#1012628).
- drm/amd/display: Fix TDR eDP and USB4 display light up issue
  (bsc#1012628).
- drm/amd/display: clear optc underflow before turn off odm clock
  (bsc#1012628).
- drm/amd/display: For stereo keep "FLIP_ANY_FRAME" (bsc#1012628).
- drm/amd/display: Fix HDMI VSIF V3 incorrect issue (bsc#1012628).
- drm/amd/display: Avoid MPC infinite loop (bsc#1012628).
- drm/amd/display: Device flash garbage before get in OS
  (bsc#1012628).
- drm/amd/display: Add a missing register field for HPO DP stream
  encoder (bsc#1012628).
- rtla: Fix tracer name (bsc#1012628).
- ASoC: rt5640: Fix the JD voltage dropping issue (bsc#1012628).
- ASoC: sh: rz-ssi: Improve error handling in rz_ssi_probe()
  error path (bsc#1012628).
- fs/ntfs3: Fix work with fragmented xattr (bsc#1012628).
- mmc: sdhci-of-dwcmshc: Re-enable support for the BlueField-3
  SoC (bsc#1012628).
- mmc: sdhci-of-dwcmshc: rename rk3568 to rk35xx (bsc#1012628).
- mmc: sdhci-of-dwcmshc: add reset call back for rockchip Socs
  (bsc#1012628).
- mmc: mtk-sd: Clear interrupts when cqe off/disable
  (bsc#1012628).
- HID: intel-ish-hid: ipc: Add Meteor Lake PCI device ID
  (bsc#1012628).
- HID: thrustmaster: Add sparco wheel and fix array length
  (bsc#1012628).
- HID: nintendo: fix rumble worker null pointer deref
  (bsc#1012628).
- HID: asus: ROG NKey: Ignore portion of 0x5a report
  (bsc#1012628).
- HID: Add Apple Touchbar on T2 Macs in hid_have_special_driver
  list (bsc#1012628).
- HID: AMD_SFH: Add a DMI quirk entry for Chromebooks
  (bsc#1012628).
- HID: add Lenovo Yoga C630 battery quirk (bsc#1012628).
- HID: input: fix uclogic tablets (bsc#1012628).
- ALSA: usb-audio: Add quirk for LH Labs Geek Out HD Audio 1V5
  (bsc#1012628).
- mm/rmap: Fix anon_vma->degree ambiguity leading to double-reuse
  (bsc#1012628).
- bpf: Don't redirect packets with invalid pkt_len (bsc#1012628).
- ftrace: Fix NULL pointer dereference in is_ftrace_trampoline
  when ftrace is dead (bsc#1012628).
- fbdev: fb_pm2fb: Avoid potential divide by zero error
  (bsc#1012628).
- net: fix refcount bug in sk_psock_get (2) (bsc#1012628).
- HID: hidraw: fix memory leak in hidraw_release() (bsc#1012628).
- USB: gadget: Fix use-after-free Read in usb_udc_uevent()
  (bsc#1012628).
- media: pvrusb2: fix memory leak in pvr_probe (bsc#1012628).
- udmabuf: Set the DMA mask for the udmabuf device (v2)
  (bsc#1012628).
- HID: steam: Prevent NULL pointer dereference in
  steam_{recv,send}_report (bsc#1012628).
- Revert "PCI/portdrv: Don't disable AER reporting in
  get_port_device_capability()" (bsc#1012628).
- Bluetooth: L2CAP: Fix build errors in some archs (bsc#1012628).
- arm64: errata: Add Cortex-A510 to the repeat tlbi list
  (bsc#1012628).
- Update config files.
  Set CONFIG_ARM64_ERRATUM_2441009=y as per default.
- docs: kerneldoc-preamble: Test xeCJK.sty before loading
  (bsc#1012628).
- crypto: lib - remove unneeded selection of XOR_BLOCKS
  (bsc#1012628).
- firmware: tegra: bpmp: Do only aligned access to IPC memory area
  (bsc#1012628).
- drm/vc4: hdmi: Depends on CONFIG_PM (bsc#1012628).
- drm/vc4: hdmi: Rework power up (bsc#1012628).
- commit 6d5067d
* Sun Sep  4 2022 mkubecek@suse.cz
- Update to 6.0-rc4
- refresh configs
- commit c26d0f0
* Thu Sep  1 2022 jslaby@suse.cz
- rpm/kernel-source.spec.in: simplify finding of broken symlinks
  "find -xtype l" will report them, so use that to make the search a bit
  faster (without using shell).
- commit 13bbc51
* Thu Sep  1 2022 jslaby@suse.cz
- Linux 5.19.6 (bsc#1012628).
- NFS: Fix another fsync() issue after a server reboot
  (bsc#1012628).
- audit: fix potential double free on error path from
  fsnotify_add_inode_mark (bsc#1012628).
- cgroup: Fix race condition at rebind_subsystems() (bsc#1012628).
- parisc: Make CONFIG_64BIT available for ARCH=parisc64 only
  (bsc#1012628).
- parisc: Fix exception handler for fldw and fstw instructions
  (bsc#1012628).
- kernel/sys_ni: add compat entry for fadvise64_64 (bsc#1012628).
- kprobes: don't call disarm_kprobe() for disabled kprobes
  (bsc#1012628).
- mm/uffd: reset write protection when unregister with wp-mode
  (bsc#1012628).
- mm/hugetlb: support write-faults in shared mappings
  (bsc#1012628).
- mt76: mt7921: fix command timeout in AP stop period
  (bsc#1012628).
- xfrm: fix refcount leak in __xfrm_policy_check() (bsc#1012628).
- Revert "xfrm: update SA curlft.use_time" (bsc#1012628).
- xfrm: clone missing x->lastused in xfrm_do_migrate
  (bsc#1012628).
- af_key: Do not call xfrm_probe_algs in parallel (bsc#1012628).
- xfrm: policy: fix metadata dst->dev xmit null pointer
  dereference (bsc#1012628).
- fs: require CAP_SYS_ADMIN in target namespace for idmapped
  mounts (bsc#1012628).
- Revert "net: macsec: update SCI upon MAC address
  change." (bsc#1012628).
- NFSv4.2 fix problems with __nfs42_ssc_open (bsc#1012628).
- SUNRPC: RPC level errors should set task->tk_rpc_status
  (bsc#1012628).
- mm/smaps: don't access young/dirty bit if pte unpresent
  (bsc#1012628).
- ntfs: fix acl handling (bsc#1012628).
- rose: check NULL rose_loopback_neigh->loopback (bsc#1012628).
- r8152: fix the units of some registers for RTL8156A
  (bsc#1012628).
- r8152: fix the RX FIFO settings when suspending (bsc#1012628).
- nfc: pn533: Fix use-after-free bugs caused by pn532_cmd_timeout
  (bsc#1012628).
- ice: xsk: prohibit usage of non-balanced queue id (bsc#1012628).
- ice: xsk: use Rx ring's XDP ring when picking NAPI context
  (bsc#1012628).
- net/mlx5e: Properly disable vlan strip on non-UL reps
  (bsc#1012628).
- net/mlx5: LAG, fix logic over MLX5_LAG_FLAG_NDEVS_READY
  (bsc#1012628).
- net/mlx5: Eswitch, Fix forwarding decision to uplink
  (bsc#1012628).
- net/mlx5: Disable irq when locking lag_lock (bsc#1012628).
- net/mlx5: Fix cmd error logging for manage pages cmd
  (bsc#1012628).
- net/mlx5: Avoid false positive lockdep warning by adding
  lock_class_key (bsc#1012628).
- net/mlx5e: Fix wrong application of the LRO state (bsc#1012628).
- net/mlx5e: Fix wrong tc flag used when set hw-tc-offload off
  (bsc#1012628).
- net: dsa: microchip: ksz9477: cleanup the ksz9477_switch_detect
  (bsc#1012628).
- net: dsa: microchip: move switch chip_id detection to ksz_common
  (bsc#1012628).
- net: dsa: microchip: move tag_protocol to ksz_common
  (bsc#1012628).
- net: dsa: microchip: move vlan functionality to ksz_common
  (bsc#1012628).
- net: dsa: microchip: move the port mirror to ksz_common
  (bsc#1012628).
- net: dsa: microchip: update the ksz_phylink_get_caps
  (bsc#1012628).
- net: dsa: microchip: keep compatibility with device tree blobs
  with no phy-mode (bsc#1012628).
- net: ipa: don't assume SMEM is page-aligned (bsc#1012628).
- net: phy: Don't WARN for PHY_READY state in
  mdio_bus_phy_resume() (bsc#1012628).
- net: moxa: get rid of asymmetry in DMA mapping/unmapping
  (bsc#1012628).
- bonding: 802.3ad: fix no transmission of LACPDUs (bsc#1012628).
- net: ipvtap - add __init/__exit annotations to module init/exit
  funcs (bsc#1012628).
- netfilter: ebtables: reject blobs that don't provide all entry
  points (bsc#1012628).
- netfilter: nft_tproxy: restrict to prerouting hook
  (bsc#1012628).
- bnxt_en: Use PAGE_SIZE to init buffer when multi buffer XDP
  is not in use (bsc#1012628).
- bnxt_en: set missing reload flag in devlink features
  (bsc#1012628).
- bnxt_en: fix NQ resource accounting during vf creation on
  57500 chips (bsc#1012628).
- bnxt_en: fix LRO/GRO_HW features in ndo_fix_features callback
  (bsc#1012628).
- netfilter: nf_tables: disallow updates of implicit chain
  (bsc#1012628).
- netfilter: nf_tables: make table handle allocation per-netns
  friendly (bsc#1012628).
- netfilter: nft_payload: report ERANGE for too long offset and
  length (bsc#1012628).
- netfilter: nft_payload: do not truncate csum_offset and
  csum_type (bsc#1012628).
- netfilter: nf_tables: do not leave chain stats enabled on error
  (bsc#1012628).
- netfilter: nft_osf: restrict osf to ipv4, ipv6 and inet families
  (bsc#1012628).
- netfilter: nft_tunnel: restrict it to netdev family
  (bsc#1012628).
- netfilter: nf_tables: disallow binding to already bound chain
  (bsc#1012628).
- netfilter: flowtable: add function to invoke garbage collection
  immediately (bsc#1012628).
- netfilter: flowtable: fix stuck flows on cleanup due to pending
  work (bsc#1012628).
- net: Fix data-races around sysctl_[rw]mem_(max|default)
  (bsc#1012628).
- net: Fix data-races around weight_p and dev_weight_[rt]x_bias
  (bsc#1012628).
- net: Fix data-races around netdev_max_backlog (bsc#1012628).
- net: Fix data-races around netdev_tstamp_prequeue (bsc#1012628).
- ratelimit: Fix data-races in ___ratelimit() (bsc#1012628).
- net: Fix data-races around sysctl_optmem_max (bsc#1012628).
- net: Fix a data-race around sysctl_tstamp_allow_data
  (bsc#1012628).
- net: Fix a data-race around sysctl_net_busy_poll (bsc#1012628).
- net: Fix a data-race around sysctl_net_busy_read (bsc#1012628).
- net: Fix a data-race around netdev_budget (bsc#1012628).
- net: Fix data-races around sysctl_max_skb_frags (bsc#1012628).
- net: Fix a data-race around netdev_budget_usecs (bsc#1012628).
- net: Fix data-races around sysctl_fb_tunnels_only_for_init_net
  (bsc#1012628).
- net: Fix data-races around sysctl_devconf_inherit_init_net
  (bsc#1012628).
- net: Fix a data-race around gro_normal_batch (bsc#1012628).
- net: Fix a data-race around netdev_unregister_timeout_secs
  (bsc#1012628).
- net: Fix a data-race around sysctl_somaxconn (bsc#1012628).
- ixgbe: stop resetting SYSTIME in ixgbe_ptp_start_cyclecounter
  (bsc#1012628).
- i40e: Fix incorrect address type for IPv6 flow rules
  (bsc#1012628).
- net: ethernet: mtk_eth_soc: enable rx cksum offload for
  MTK_NETSYS_V2 (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix hw hash reporting for
  MTK_NETSYS_V2 (bsc#1012628).
- rxrpc: Fix locking in rxrpc's sendmsg (bsc#1012628).
- ionic: clear broken state on generation change (bsc#1012628).
- ionic: fix up issues with handling EAGAIN on FW cmds
  (bsc#1012628).
- ionic: VF initial random MAC address if no assigned mac
  (bsc#1012628).
- net: stmmac: work around sporadic tx issue on link-up
  (bsc#1012628).
- net: lantiq_xrx200: confirm skb is allocated before using
  (bsc#1012628).
- net: lantiq_xrx200: fix lock under memory pressure
  (bsc#1012628).
- net: lantiq_xrx200: restore buffer if memory allocation failed
  (bsc#1012628).
- btrfs: fix silent failure when deleting root reference
  (bsc#1012628).
- btrfs: replace: drop assert for suspended replace (bsc#1012628).
- btrfs: add info when mount fails due to stale replace target
  (bsc#1012628).
- btrfs: fix space cache corruption and potential double
  allocations (bsc#1012628).
- btrfs: check if root is readonly while setting security xattr
  (bsc#1012628).
- btrfs: fix possible memory leak in
  btrfs_get_dev_args_from_path() (bsc#1012628).
- btrfs: update generation of hole file extent item when merging
  holes (bsc#1012628).
- x86/boot: Don't propagate uninitialized
  boot_params->cc_blob_address (bsc#1012628).
- perf/x86/intel: Fix pebs event constraints for ADL
  (bsc#1012628).
- perf/x86/lbr: Enable the branch type for the Arch LBR by default
  (bsc#1012628).
- x86/entry: Fix entry_INT80_compat for Xen PV guests
  (bsc#1012628).
- x86/unwind/orc: Unwind ftrace trampolines with correct ORC entry
  (bsc#1012628).
- x86/sev: Don't use cc_platform_has() for early SEV-SNP calls
  (bsc#1012628).
- x86/bugs: Add "unknown" reporting for MMIO Stale Data
  (bsc#1012628).
- x86/nospec: Unwreck the RSB stuffing (bsc#1012628).
- x86/PAT: Have pat_enabled() properly reflect state when running
  on Xen (bsc#1012628).
- loop: Check for overflow while configuring loop (bsc#1012628).
- writeback: avoid use-after-free after removing device
  (bsc#1012628).
- audit: move audit_return_fixup before the filters (bsc#1012628).
- asm-generic: sections: refactor memory_intersects (bsc#1012628).
- mm/damon/dbgfs: avoid duplicate context directory creation
  (bsc#1012628).
- s390/mm: do not trigger write fault when vma does not allow
  VM_WRITE (bsc#1012628).
- bootmem: remove the vmemmap pages from kmemleak in
  put_page_bootmem (bsc#1012628).
- mm/hugetlb: avoid corrupting page->mapping in
  hugetlb_mcopy_atomic_pte (bsc#1012628).
- mm/mprotect: only reference swap pfn page if type match
  (bsc#1012628).
- cifs: skip extra NULL byte in filenames (bsc#1012628).
- s390: fix double free of GS and RI CBs on fork() failure
  (bsc#1012628).
- fbdev: fbcon: Properly revert changes when vc_resize() failed
  (bsc#1012628).
- Revert "memcg: cleanup racy sum avoidance code" (bsc#1012628).
- shmem: update folio if shmem_replace_page() updates the page
  (bsc#1012628).
- ACPI: processor: Remove freq Qos request for all CPUs
  (bsc#1012628).
- nouveau: explicitly wait on the fence in nouveau_bo_move_m2mf
  (bsc#1012628).
- smb3: missing inode locks in punch hole (bsc#1012628).
- ocfs2: fix freeing uninitialized resource on ocfs2_dlm_shutdown
  (bsc#1012628).
- xen/privcmd: fix error exit of privcmd_ioctl_dm_op()
  (bsc#1012628).
- riscv: signal: fix missing prototype warning (bsc#1012628).
- riscv: traps: add missing prototype (bsc#1012628).
- riscv: dts: microchip: correct L2 cache interrupts
  (bsc#1012628).
- io_uring: fix issue with io_write() not always undoing
  sb_start_write() (bsc#1012628).
- mm/hugetlb: fix hugetlb not supporting softdirty tracking
  (bsc#1012628).
- Revert "md-raid: destroy the bitmap after destroying the thread"
  (bsc#1012628).
- md: call __md_stop_writes in md_stop (bsc#1012628).
- arm64: Fix match_list for erratum 1286807 on Arm Cortex-A76
  (bsc#1012628).
- binder_alloc: add missing mmap_lock calls when using the VMA
  (bsc#1012628).
- x86/nospec: Fix i386 RSB stuffing (bsc#1012628).
- drm/amdkfd: Fix isa version for the GC 10.3.7 (bsc#1012628).
- Documentation/ABI: Mention retbleed vulnerability info file
  for sysfs (bsc#1012628).
- blk-mq: fix io hung due to missing commit_rqs (bsc#1012628).
- perf python: Fix build when PYTHON_CONFIG is user supplied
  (bsc#1012628).
- perf/x86/intel/uncore: Fix broken read_counter() for SNB IMC
  PMU (bsc#1012628).
- perf/x86/intel/ds: Fix precise store latency handling
  (bsc#1012628).
- perf stat: Clear evsel->reset_group for each stat run
  (bsc#1012628).
- arm64: fix rodata=full (bsc#1012628).
- arm64/signal: Flush FPSIMD register state when disabling
  streaming mode (bsc#1012628).
- arm64/sme: Don't flush SVE register state when allocating SME
  storage (bsc#1012628).
- arm64/sme: Don't flush SVE register state when handling SME
  traps (bsc#1012628).
- scsi: ufs: core: Enable link lost interrupt (bsc#1012628).
- scsi: storvsc: Remove WQ_MEM_RECLAIM from storvsc_error_wq
  (bsc#1012628).
- scsi: core: Fix passthrough retry counter handling
  (bsc#1012628).
- riscv: dts: microchip: mpfs: fix incorrect pcie child node name
  (bsc#1012628).
- riscv: dts: microchip: mpfs: remove ti,fifo-depth property
  (bsc#1012628).
- riscv: dts: microchip: mpfs: remove bogus card-detect-delay
  (bsc#1012628).
- riscv: dts: microchip: mpfs: remove pci axi address translation
  property (bsc#1012628).
- bpf: Don't use tnum_range on array range checking for poke
  descriptors (bsc#1012628).
- Delete
  patches.suse/mm-mprotect-fix-soft-dirty-check-in-can_change_pte_w.patch.
- commit 9e364bb
* Wed Aug 31 2022 msuchanek@suse.de
- mkspec: eliminate @NOSOURCE@ macro
  This should be alsways used with @SOURCES@, just include the content
  there.
- commit 403d89f
* Wed Aug 31 2022 msuchanek@suse.de
- kernel-source: include the kernel signature file
  We assume that the upstream tarball is used for released kernels.
  Then we can also include the signature file and keyring in the
  kernel-source src.rpm.
  Because of mkspec code limitation exclude the signature and keyring from
  binary packages always - mkspec does not parse spec conditionals.
- commit e76c4ca
* Wed Aug 31 2022 msuchanek@suse.de
- kernel-binary: move @NOSOURCE@ to @SOURCES@ as in other packages
- commit 4b42fb2
* Wed Aug 31 2022 msuchanek@suse.de
- dtb: Do not include sources in src.rpm - refer to kernel-source
  Same as other kernel binary packages there is no need to carry duplicate
  sources in dtb packages.
- commit 1bd288c
* Tue Aug 30 2022 jslaby@suse.cz
- Refresh
  patches.rpmify/kbuild-dummy-tools-pretend-we-understand-__LONG_DOUB.patch.
- Refresh
  patches.suse/Revert-zram-remove-double-compression-logic.patch.
- Refresh
  patches.suse/mm-gup-fix-FOLL_FORCE-COW-security-issue-and-remove-.patch.
- wifi: mt76: mt7921e: fix crash in chip reset fail (bsc#1201845).
  Update to upstream versions and shuffle in series.
- commit b7da698
* Tue Aug 30 2022 jslaby@suse.cz
- Update
  patches.kernel.org/5.19.2-1109-dm-fix-dm-raid-crash-if-md_handle_request-spl.patch
  (bsc#1012628 bsc#1202369).
  Add a bsc#.
- commit 86a8641
* Mon Aug 29 2022 tiwai@suse.de
- Revert "block: freeze the queue earlier in del_gendisk"
  (bsc#1202534 bsc#1202589).
- commit 157e5ea
* Mon Aug 29 2022 jslaby@suse.cz
- Delete
  patches.suse/Revert-Revert-tcp-change-pingpong-threshold-to-3.patch.
  The test was disabled in python-eventlet. The code is correct, unlike
  the test.
- commit 22072b3
* Mon Aug 29 2022 jslaby@suse.cz
- kbuild: dummy-tools: avoid tmpdir leak in dummy gcc
  (bsc#1012628).
- Linux 5.19.5 (bsc#1012628).
- Refresh
  patches.kernel.org/5.19.4-144-kbuild-dummy-tools-avoid-tmpdir-leak-in-dummy-.patch.
- commit 8b6f0a1
* Mon Aug 29 2022 jslaby@suse.cz
- Refresh
  patches.kernel.org/5.19.4-144-kbuild-dummy-tools-avoid-tmpdir-leak-in-dummy-.patch.
  Reenable the patch after fixing it (missing plugin-version.h in the
  patch).
- commit 2ea108c
* Mon Aug 29 2022 mkubecek@suse.cz
- Update to 6.0-rc3
- eliminate 2 patches
  - patches.suse/0001-scsi-sd-Revert-Rework-asynchronous-resume-support.patch
  - patches.suse/Revert-zram-remove-double-compression-logic.patch
- commit 824e6f8
* Sat Aug 27 2022 jslaby@suse.cz
- Disable aac289653fa5adf9e9985e4912c1d24a3e8cbab2.
  It breaks with dummy tools.
- commit 15b473a
* Sat Aug 27 2022 jslaby@suse.cz
- Update config files.
  CONFIG_VIRTIO_HARDEN_NOTIFICATION was marked as BROKEN.
- Linux 5.19.4 (bsc#1012628).
- Revert "ALSA: hda: Fix page fault in snd_hda_codec_shutdown()"
  (bsc#1012628).
- scsi: ufs: ufs-mediatek: Fix build error and type mismatch
  (bsc#1012628).
- f2fs: fix null-ptr-deref in f2fs_get_dnode_of_data
  (bsc#1012628).
- f2fs: revive F2FS_IOC_ABORT_VOLATILE_WRITE (bsc#1012628).
- MIPS: tlbex: Explicitly compare _PAGE_NO_EXEC against 0
  (bsc#1012628).
- video: fbdev: i740fb: Check the argument of i740_calc_vclk()
  (bsc#1012628).
- venus: pm_helpers: Fix warning in OPP during probe
  (bsc#1012628).
- powerpc/64: Init jump labels before parse_early_param()
  (bsc#1012628).
- smb3: check xattr value length earlier (bsc#1012628).
- f2fs: fix to do sanity check on segment type in
  build_sit_entries() (bsc#1012628).
- f2fs: fix to avoid use f2fs_bug_on() in f2fs_new_node_page()
  (bsc#1012628).
- ALSA: control: Use deferred fasync helper (bsc#1012628).
- ALSA: pcm: Use deferred fasync helper (bsc#1012628).
- ALSA: timer: Use deferred fasync helper (bsc#1012628).
- ALSA: core: Add async signal helpers (bsc#1012628).
- powerpc/ioda/iommu/debugfs: Generate unique debugfs entries
  (bsc#1012628).
- ovl: warn if trusted xattr creation fails (bsc#1012628).
- ASoC: codecs: va-macro: use fsgen as clock (bsc#1012628).
- powerpc/32: Don't always pass -mcpu=powerpc to the compiler
  (bsc#1012628).
- powerpc/32: Set an IBAT covering up to _einittext during init
  (bsc#1012628).
- powerpc/pseries/mobility: set NMI watchdog factor during an LPM
  (bsc#1012628).
- powerpc/watchdog: introduce a NMI watchdog's factor
  (bsc#1012628).
- watchdog: export lockup_detector_reconfigure (bsc#1012628).
- ASoC: Intel: sof_nau8825: Move quirk check to the front in
  late probe (bsc#1012628).
- ASoC: Intel: sof_es8336: ignore GpioInt when looking for
  speaker/headset GPIO lines (bsc#1012628).
- ASoC: Intel: sof_es8336: Fix GPIO quirks set via module option
  (bsc#1012628).
- ASoC: SOF: Intel: hda: add sanity check on SSP index reported
  by NHLT (bsc#1012628).
- ALSA: hda/realtek: Enable speaker and mute LEDs for HP laptops
  (bsc#1012628).
- RISC-V: Add fast call path of crash_kexec() (bsc#1012628).
- riscv: mmap with PROT_WRITE but no PROT_READ is invalid
  (bsc#1012628).
- ASoC: nau8821: Don't unconditionally free interrupt
  (bsc#1012628).
- riscv: dts: canaan: Add k210 topology information (bsc#1012628).
- riscv: dts: sifive: Add fu740 topology information
  (bsc#1012628).
- ASoC: rsnd: care default case on rsnd_ssiu_busif_err_irq_ctrl()
  (bsc#1012628).
- ASoC: SOF: sof-client-probes: Only load the driver if IPC3 is
  used (bsc#1012628).
- ASoC: SOF: Intel: hda-ipc: Do not process IPC reply before
  firmware boot (bsc#1012628).
- ASoC: SOF: Intel: cnl: Do not process IPC reply before firmware
  boot (bsc#1012628).
- modules: Ensure natural alignment for .altinstructions and
  __bug_table sections (bsc#1012628).
- ALSA: hda: Fix page fault in snd_hda_codec_shutdown()
  (bsc#1012628).
- ASoC: Intel: avs: Set max DMA segment size (bsc#1012628).
- iommu/io-pgtable-arm-v7s: Add a quirk to allow pgtable PA up
  to 35bit (bsc#1012628).
- mips: cavium-octeon: Fix missing of_node_put() in
  octeon2_usb_clocks_start (bsc#1012628).
- vfio: Clear the caps->buf to NULL after free (bsc#1012628).
- KVM: PPC: Book3S HV: Fix "rm_exit" entry in debugfs timings
  (bsc#1012628).
- tty: serial: Fix refcount leak bug in ucc_uart.c (bsc#1012628).
- lib/list_debug.c: Detect uninitialized lists (bsc#1012628).
- ext4: avoid resizing to a partial cluster size (bsc#1012628).
- ext4: block range must be validated before use in
  ext4_mb_clear_bb() (bsc#1012628).
- ext4: avoid remove directory when directory is corrupted
  (bsc#1012628).
- drivers:md:fix a potential use-after-free bug (bsc#1012628).
- nvmet-tcp: fix lockdep complaint on nvmet_tcp_wq flush during
  queue teardown (bsc#1012628).
- md/raid5: Make logic blocking check consistent with logic that
  blocks (bsc#1012628).
- md: Notify sysfs sync_completed in md_reap_sync_thread()
  (bsc#1012628).
- phy: samsung: phy-exynos-pcie: sanitize init/power_on callbacks
  (bsc#1012628).
- openrisc: io: Define iounmap argument as volatile (bsc#1012628).
- Revert "RDMA/rxe: Create duplicate mapping tables for FMRs"
  (bsc#1012628).
- dmaengine: sprd: Cleanup in .remove() after
  pm_runtime_get_sync() failed (bsc#1012628).
- dmaengine: tegra: Add terminate() for Tegra234 (bsc#1012628).
- selftests/kprobe: Do not test for GRP/ without event failures
  (bsc#1012628).
- csky/kprobe: reclaim insn_slot on kprobe unregistration
  (bsc#1012628).
- RDMA/rxe: Limit the number of calls to each tasklet
  (bsc#1012628).
- ACPI: PPTT: Leave the table mapped for the runtime usage
  (bsc#1012628).
- mmc: renesas_sdhi: newer SoCs don't need manual tap correction
  (bsc#1012628).
- dmaengine: dw-axi-dmac: ignore interrupt if no descriptor
  (bsc#1012628).
- dmaengine: dw-axi-dmac: do not print NULL LLI during error
  (bsc#1012628).
- of: overlay: Move devicetree_corrupt() check up (bsc#1012628).
- um: add "noreboot" command line option for PANIC_TIMEOUT=-1
  setups (bsc#1012628).
- PCI/ACPI: Guard ARM64-specific mcfg_quirks (bsc#1012628).
- cxl: Fix a memory leak in an error handling path (bsc#1012628).
- pinctrl: intel: Check against matching data instead of ACPI
  companion (bsc#1012628).
- scsi: ufs: ufs-exynos: Change ufs phy control sequence
  (bsc#1012628).
- mmc: tmio: avoid glitches when resetting (bsc#1012628).
- habanalabs/gaudi: mask constant value before cast (bsc#1012628).
- habanalabs/gaudi: fix shift out of bounds (bsc#1012628).
- habanalabs/gaudi: invoke device reset from one code block
  (bsc#1012628).
- habanalabs: add terminating NULL to attrs arrays (bsc#1012628).
- coresight: etm4x: avoid build failure with unrolled loops
  (bsc#1012628).
- gadgetfs: ep_io - wait until IRQ finishes (bsc#1012628).
- scsi: lpfc: Fix possible memory leak when failing to issue
  CMF WQE (bsc#1012628).
- scsi: lpfc: Prevent buffer overflow crashes in debugfs with
  malformed user input (bsc#1012628).
- clk: qcom: clk-alpha-pll: fix clk_trion_pll_configure
  description (bsc#1012628).
- zram: do not lookup algorithm in backends table (bsc#1012628).
- uacce: Handle parent device removal or parent driver module
  rmmod (bsc#1012628).
- clk: qcom: ipq8074: dont disable gcc_sleep_clk_src
  (bsc#1012628).
- vboxguest: Do not use devm for irq (bsc#1012628).
- usb: dwc2: gadget: remove D+ pull-up while no vbus with
  usb-role-switch (bsc#1012628).
- scsi: iscsi: Fix HW conn removal use after free (bsc#1012628).
- usb: renesas: Fix refcount leak bug (bsc#1012628).
- usb: host: ohci-ppc-of: Fix refcount leak bug (bsc#1012628).
- usb: typec: mux: Add CONFIG guards for functions (bsc#1012628).
- scsi: ufs: ufs-mediatek: Fix the timing of configuring device
  regulators (bsc#1012628).
- clk: ti: Stop using legacy clkctrl names for omap4 and 5
  (bsc#1012628).
- drm/meson: Fix overflow implicit truncation warnings
  (bsc#1012628).
- irqchip/tegra: Fix overflow implicit truncation warnings
  (bsc#1012628).
- scsi: ufs: core: Add UFSHCD_QUIRK_HIBERN_FASTAUTO (bsc#1012628).
- scsi: ufs: core: Add UFSHCD_QUIRK_BROKEN_64BIT_ADDRESS
  (bsc#1012628).
- PCI: aardvark: Fix reporting Slot capabilities on emulated
  bridge (bsc#1012628).
- usb: gadget: uvc: call uvc uvcg_warn on completed status
  instead of uvcg_info (bsc#1012628).
- usb: gadget: uvc: calculate the number of request depending
  on framesize (bsc#1012628).
- usb: cdns3 fix use-after-free at workaround 2 (bsc#1012628).
- staging: r8188eu: add error handling of rtw_read32
  (bsc#1012628).
- staging: r8188eu: add error handling of rtw_read16
  (bsc#1012628).
- staging: r8188eu: add error handling of rtw_read8 (bsc#1012628).
- platform/chrome: cros_ec_proto: don't show MKBP version if
  unsupported (bsc#1012628).
- PCI: Add ACS quirk for Broadcom BCM5750x NICs (bsc#1012628).
- HID: multitouch: new device class fix Lenovo X12 trackpad sticky
  (bsc#1012628).
- thunderbolt: Change downstream router's TMU rate in both TMU
  uni/bidir mode (bsc#1012628).
- x86/kvm: Fix "missing ENDBR" BUG for fastop functions
  (bsc#1012628).
- x86/ibt, objtool: Add IBT_NOSEAL() (bsc#1012628).
- net: mscc: ocelot: report ndo_get_stats64 from the
  wraparound-resistant ocelot->stats (bsc#1012628).
- net: mscc: ocelot: make struct ocelot_stat_layout array
  indexable (bsc#1012628).
- net: mscc: ocelot: fix race between ndo_get_stats64 and
  ocelot_check_stats_work (bsc#1012628).
- net: mscc: ocelot: turn stats_lock into a spinlock
  (bsc#1012628).
- KVM: arm64: Reject 32bit user PSTATE on asymmetric systems
  (bsc#1012628).
- KVM: arm64: Treat PMCR_EL1.LC as RES1 on asymmetric systems
  (bsc#1012628).
- drm/amdgpu: Fix use-after-free on amdgpu_bo_list mutex
  (bsc#1012628).
- drm/sun4i: dsi: Prevent underflow when computing packet sizes
  (bsc#1012628).
- drm/bridge: lvds-codec: Fix error checking of
  drm_of_lvds_get_data_mapping() (bsc#1012628).
- drm/amdgpu: Avoid another list of reset devices (bsc#1012628).
- drm/i915/ttm: don't leak the ccs state (bsc#1012628).
- drm/meson: Fix refcount bugs in
  meson_vpu_has_available_connectors() (bsc#1012628).
- drm/imx/dcss: get rid of HPD warning message (bsc#1012628).
- can: j1939: j1939_sk_queue_activate_next_locked(): replace
  WARN_ON_ONCE with netdev_warn_once() (bsc#1012628).
- gcc-plugins: Undefine LATENT_ENTROPY_PLUGIN when plugin disabled
  for a file (bsc#1012628).
- kbuild: fix the modules order between drivers and libs
  (bsc#1012628).
- igb: Add lock to avoid data race (bsc#1012628).
- stmmac: intel: Add a missing clk_disable_unprepare() call in
  intel_eth_pci_remove() (bsc#1012628).
- dt-bindings: display: sun4i: Add D1 TCONs to conditionals
  (bsc#1012628).
- fec: Fix timer capture timing in `fec_ptp_enable_pps()`
  (bsc#1012628).
- tools/rtla: Fix command symlinks (bsc#1012628).
- blk-mq: run queue no matter whether the request is the last
  request (bsc#1012628).
- i40e: Fix to stop tx_timeout recovery if GLOBR fails
  (bsc#1012628).
- regulator: pca9450: Remove restrictions for regulator-name
  (bsc#1012628).
- i40e: Fix tunnel checksum offload with fragmented traffic
  (bsc#1012628).
- i2c: imx: Make sure to unregister adapter on remove()
  (bsc#1012628).
- modpost: fix module versioning when a symbol lacks valid CRC
  (bsc#1012628).
- ice: Ignore error message when setting same promiscuous mode
  (bsc#1012628).
- ice: Fix clearing of promisc mode with bridge over bond
  (bsc#1012628).
- ice: Ignore EEXIST when setting promisc mode (bsc#1012628).
- ice: Fix double VLAN error when entering promisc mode
  (bsc#1012628).
- ice: Fix VF not able to send tagged traffic with no VLAN filters
  (bsc#1012628).
- ice: Fix call trace with null VSI during VF reset (bsc#1012628).
- ice: Fix VSI rebuild WARN_ON check for VF (bsc#1012628).
- net: dsa: sja1105: fix buffer overflow in
  sja1105_setup_devlink_regions() (bsc#1012628).
- net: dsa: don't warn in dsa_port_set_state_now() when driver
  doesn't support it (bsc#1012628).
- net: genl: fix error path memory leak in policy dumping
  (bsc#1012628).
- net: mscc: ocelot: fix address of SYS_COUNT_TX_AGING counter
  (bsc#1012628).
- net: mscc: ocelot: fix incorrect ndo_get_stats64 packet counters
  (bsc#1012628).
- net: dsa: felix: fix ethtool 256-511 and 512-1023 TX packet
  counters (bsc#1012628).
- net: dsa: microchip: ksz9477: fix fdb_dump last invalid entry
  (bsc#1012628).
- net: sched: fix misuse of qcpu->backlog in
  gnet_stats_add_queue_cpu (bsc#1012628).
- net: rtnetlink: fix module reference count leak issue in
  rtnetlink_rcv_msg (bsc#1012628).
- net: fix potential refcount leak in ndisc_router_discovery()
  (bsc#1012628).
- net: moxa: pass pdev instead of ndev to DMA functions
  (bsc#1012628).
- mlxsw: spectrum: Clear PTP configuration after unregistering
  the netdevice (bsc#1012628).
- virtio_net: fix endian-ness for RSS (bsc#1012628).
- net: qrtr: start MHI channel after endpoit creation
  (bsc#1012628).
- net: dsa: mv88e6060: prevent crash on an unused port
  (bsc#1012628).
- net/sunrpc: fix potential memory leaks in
  rpc_sysfs_xprt_state_change() (bsc#1012628).
- spi: meson-spicc: add local pow2 clock ops to preserve rate
  between messages (bsc#1012628).
- powerpc/pci: Fix get_phb_number() locking (bsc#1012628).
- netfilter: nf_tables: check NFT_SET_CONCAT flag if field_count
  is specified (bsc#1012628).
- netfilter: nf_tables: disallow NFT_SET_ELEM_CATCHALL and
  NFT_SET_ELEM_INTERVAL_END (bsc#1012628).
- netfilter: nf_tables: NFTA_SET_ELEM_KEY_END requires concat
  and interval flags (bsc#1012628).
- netfilter: nf_tables: validate NFTA_SET_ELEM_OBJREF based on
  NFT_SET_OBJECT flag (bsc#1012628).
- netfilter: nf_tables: fix scheduling-while-atomic splat
  (bsc#1012628).
- netfilter: nf_tables: really skip inactive sets when allocating
  name (bsc#1012628).
- netfilter: nf_tables: possible module reference underflow in
  error path (bsc#1012628).
- netfilter: nf_ct_irc: cap packet search space to 4k
  (bsc#1012628).
- netfilter: nf_ct_ftp: prefer skb_linearize (bsc#1012628).
- netfilter: nf_ct_h323: cap packet size at 64k (bsc#1012628).
- netfilter: nf_ct_sane: remove pseudo skb linearization
  (bsc#1012628).
- netfilter: nf_tables: disallow NFTA_SET_ELEM_KEY_END with
  NFT_SET_ELEM_INTERVAL_END flag (bsc#1012628).
- fs/ntfs3: uninitialized variable in ntfs_set_acl_ex()
  (bsc#1012628).
- netfilter: nf_tables: use READ_ONCE and WRITE_ONCE for shared
  generation id access (bsc#1012628).
- netfilter: nfnetlink: re-enable conntrack expectation events
  (bsc#1012628).
- RDMA/cxgb4: fix accept failure due to increased
  cpl_t5_pass_accept_rpl size (bsc#1012628).
- RDMA/mlx5: Use the proper number of ports (bsc#1012628).
- IB/iser: Fix login with authentication (bsc#1012628).
- ASoC: codec: tlv320aic32x4: fix mono playback via I2S
  (bsc#1012628).
- ASoC: tas2770: Fix handling of mute/unmute (bsc#1012628).
- ASoC: tas2770: Drop conflicting set_bias_level power setting
  (bsc#1012628).
- ASoC: tas2770: Allow mono streams (bsc#1012628).
- ASoC: tas2770: Set correct FSYNC polarity (bsc#1012628).
- ASoC: DPCM: Don't pick up BE without substream (bsc#1012628).
- ASoC: SOF: Intel: hda: Fix potential buffer overflow by
  snprintf() (bsc#1012628).
- ASoC: SOF: debug: Fix potential buffer overflow by snprintf()
  (bsc#1012628).
- ASoC: Intel: avs: Fix potential buffer overflow by snprintf()
  (bsc#1012628).
- iavf: Fix deadlock in initialization (bsc#1012628).
- iavf: Fix reset error handling (bsc#1012628).
- iavf: Fix NULL pointer dereference in iavf_get_link_ksettings
  (bsc#1012628).
- iavf: Fix adminq error handling (bsc#1012628).
- nios2: add force_successful_syscall_return() (bsc#1012628).
- nios2: restarts apply only to the first sigframe we
  build.. (bsc#1012628).
- nios2: fix syscall restart checks (bsc#1012628).
- nios2: traced syscall does need to check the syscall number
  (bsc#1012628).
- nios2: don't leave NULLs in sys_call_table[] (bsc#1012628).
- nios2: page fault et.al. are *not* restartable
  syscalls.. (bsc#1012628).
- fs/ntfs3: Fix missing i_op in ntfs_read_mft (bsc#1012628).
- fs/ntfs3: Do not change mode if ntfs_set_ea failed
  (bsc#1012628).
- fs/ntfs3: Fix double free on remount (bsc#1012628).
- fs/ntfs3: Don't clear upper bits accidentally in log_replay()
  (bsc#1012628).
- fs/ntfs3: Fix NULL deref in ntfs_update_mftmirr (bsc#1012628).
- fs/ntfs3: Fix using uninitialized value n when calling indx_read
  (bsc#1012628).
- dpaa2-eth: trace the allocated address instead of page struct
  (bsc#1012628).
- perf tests: Fix Track with sched_switch test for hybrid case
  (bsc#1012628).
- perf parse-events: Fix segfault when event parser gets an error
  (bsc#1012628).
- i2c: qcom-geni: Fix GPI DMA buffer sync-back (bsc#1012628).
- perf probe: Fix an error handling path in
  'parse_perf_probe_command()' (bsc#1012628).
- nvme-fc: fix the fc_appid_store return value (bsc#1012628).
- geneve: fix TOS inheriting for ipv4 (bsc#1012628).
- fscache: don't leak cookie access refs if invalidation is in
  progress or failed (bsc#1012628).
- atm: idt77252: fix use-after-free bugs caused by tst_timer
  (bsc#1012628).
- tsnep: Fix tsnep_tx_unmap() error path usage (bsc#1012628).
- xen/xenbus: fix return type in xenbus_file_read() (bsc#1012628).
- nfp: ethtool: fix the display error of `ethtool -m DEVNAME`
  (bsc#1012628).
- NTB: ntb_tool: uninitialized heap data in tool_fn_write()
  (bsc#1012628).
- tools build: Switch to new openssl API for test-libcrypto
  (bsc#1012628).
- kbuild: dummy-tools: avoid tmpdir leak in dummy gcc
  (bsc#1012628).
- tools/testing/cxl: Fix cxl_hdm_decode_init() calling convention
  (bsc#1012628).
- vdpa_sim_blk: set number of address spaces and virtqueue groups
  (bsc#1012628).
- vdpa_sim: use max_iotlb_entries as a limit in vhost_iotlb_init
  (bsc#1012628).
- clk: imx93: Correct the edma1's parent clock (bsc#1012628).
- ceph: don't leak snap_rwsem in handle_cap_grant (bsc#1012628).
- tools/vm/slabinfo: use alphabetic order when two values are
  equal (bsc#1012628).
- tools/testing/cxl: Fix decoder default state (bsc#1012628).
- ceph: use correct index when encoding client supported features
  (bsc#1012628).
- spi: dt-bindings: qcom,spi-geni-qcom: allow three interconnects
  (bsc#1012628).
- dt-bindings: opp: opp-v2-kryo-cpu: Fix example binding checks
  (bsc#1012628).
- spi: dt-bindings: zynqmp-qspi: add missing 'required'
  (bsc#1012628).
- spi: dt-bindings: cadence: add missing 'required' (bsc#1012628).
- dt-bindings: PCI: qcom: Fix reset conditional (bsc#1012628).
- dt-bindings: clock: qcom,gcc-msm8996: add more GCC clock sources
  (bsc#1012628).
- dt-bindings: arm: qcom: fix MSM8994 boards compatibles
  (bsc#1012628).
- dt-bindings: arm: qcom: fix MSM8916 MTP compatibles
  (bsc#1012628).
- dt-bindings: arm: qcom: fix Longcheer L8150 compatibles
  (bsc#1012628).
- dt-bindings: gpio: zynq: Add missing compatible strings
  (bsc#1012628).
- vsock: Set socket state back to SS_UNCONNECTED in
  vsock_connect_timeout() (bsc#1012628).
- vsock: Fix memory leak in vsock_connect() (bsc#1012628).
- plip: avoid rcu debug splat (bsc#1012628).
- ipv6: do not use RT_TOS for IPv6 flowlabel (bsc#1012628).
- mlx5: do not use RT_TOS for IPv6 flowlabel (bsc#1012628).
- vxlan: do not use RT_TOS for IPv6 flowlabel (bsc#1012628).
- geneve: do not use RT_TOS for IPv6 flowlabel (bsc#1012628).
- ACPI: property: Return type of acpi_add_nondev_subnodes()
  should be bool (bsc#1012628).
- octeontx2-af: Fix key checking for source mac (bsc#1012628).
- octeontx2-af: Fix mcam entry resource leak (bsc#1012628).
- octeontx2-af: suppress external profile loading warning
  (bsc#1012628).
- octeontx2-af: Apply tx nibble fixup always (bsc#1012628).
- octeontx2-pf: Fix NIX_AF_TL3_TL2X_LINKX_CFG register
  configuration (bsc#1012628).
- dt-bindings: input: iqs7222: Extend slider-mapped GPIO to
  IQS7222C (bsc#1012628).
- dt-bindings: input: iqs7222: Correct bottom speed step size
  (bsc#1012628).
- dt-bindings: input: iqs7222: Remove support for RF filter
  (bsc#1012628).
- Input: iqs7222 - remove support for RF filter (bsc#1012628).
- Input: iqs7222 - handle reset during ATI (bsc#1012628).
- Input: iqs7222 - acknowledge reset before writing registers
  (bsc#1012628).
- Input: iqs7222 - protect volatile registers (bsc#1012628).
- Input: iqs7222 - fortify slider event reporting (bsc#1012628).
- Input: iqs7222 - correct slider event disable logic
  (bsc#1012628).
- Input: mt6779-keypad - match hardware matrix organization
  (bsc#1012628).
- Input: exc3000 - fix return value check of
  wait_for_completion_timeout (bsc#1012628).
- rtc: spear: set range max (bsc#1012628).
- pinctrl: qcom: sm8250: Fix PDC map (bsc#1012628).
- dt-bindings: pinctrl: mt8186: Add and use
  drive-strength-microamp (bsc#1012628).
- pinctrl: sunxi: Add I/O bias setting for H6 R-PIO (bsc#1012628).
- dt-bindings: pinctrl: mt8195: Add and use
  drive-strength-microamp (bsc#1012628).
- dt-bindings: pinctrl: mt8195: Fix name for
  mediatek,rsel-resistance-in-si-unit (bsc#1012628).
- pinctrl: amd: Don't save/restore interrupt status and wake
  status bits (bsc#1012628).
- pinctrl: qcom: msm8916: Allow CAMSS GP clocks to be muxed
  (bsc#1012628).
- pinctrl: nomadik: Fix refcount leak in
  nmk_pinctrl_dt_subnode_to_map (bsc#1012628).
- dt-bindings: pinctrl: mt8192: Use generic bias instead of
  pull-*-adv (bsc#1012628).
- dt-bindings: pinctrl: mt8192: Add drive-strength-microamp
  (bsc#1012628).
- pinctrl: renesas: rzg2l: Return -EINVAL for pins which have
  input disabled (bsc#1012628).
- dt-bindings: arm: qcom: fix Alcatel OneTouch Idol 3 compatibles
  (bsc#1012628).
- selftests: forwarding: Fix failing tests with old libnet
  (bsc#1012628).
- net: atm: bring back zatm uAPI (bsc#1012628).
- net: bgmac: Fix a BUG triggered by wrong bytes_compl
  (bsc#1012628).
- net: dsa: felix: suppress non-changes to the tagging protocol
  (bsc#1012628).
- net: phy: c45 baset1: do not skip aneg configuration if clock
  role is not specified (bsc#1012628).
- net: bcmgenet: Indicate MAC is in charge of PHY PM
  (bsc#1012628).
- net: phy: Warn about incorrect mdio_bus_phy_resume() state
  (bsc#1012628).
- devlink: Fix use-after-free after a failed reload (bsc#1012628).
- virtio-blk: Avoid use-after-free on suspend/resume
  (bsc#1012628).
- virtio_net: fix memory leak inside XPD_TX with mergeable
  (bsc#1012628).
- virtio: VIRTIO_HARDEN_NOTIFICATION is broken (bsc#1012628).
- ASoC: qdsp6: q6apm-dai: unprepare stream if its already prepared
  (bsc#1012628).
- SUNRPC: Don't reuse bvec on retransmission of the request
  (bsc#1012628).
- SUNRPC: Reinitialise the backchannel request buffers before
  reuse (bsc#1012628).
- SUNRPC: Fix xdr_encode_bool() (bsc#1012628).
- sunrpc: fix expiry of auth creds (bsc#1012628).
- m68k: coldfire/device.c: protect FLEXCAN blocks (bsc#1012628).
- net: atlantic: fix aq_vec index out of range error
  (bsc#1012628).
- can: j1939: j1939_session_destroy(): fix memory leak of skbs
  (bsc#1012628).
- can: mcp251x: Fix race condition on receive interrupt
  (bsc#1012628).
- bpf: Check the validity of max_rdwr_access for sock local
  storage map iterator (bsc#1012628).
- bpf: Acquire map uref in .init_seq_private for sock{map,hash}
  iterator (bsc#1012628).
- bpf: Acquire map uref in .init_seq_private for sock local
  storage map iterator (bsc#1012628).
- bpf: Acquire map uref in .init_seq_private for hash map iterator
  (bsc#1012628).
- bpf: Acquire map uref in .init_seq_private for array map
  iterator (bsc#1012628).
- bpf: Don't reinit map value in prealloc_lru_pop (bsc#1012628).
- bpf: Disallow bpf programs call prog_run command (bsc#1012628).
- BPF: Fix potential bad pointer dereference in bpf_sys_bpf()
  (bsc#1012628).
- selftests: mptcp: make sendfile selftest work (bsc#1012628).
- mptcp: do not queue data on closed subflows (bsc#1012628).
- mptcp: move subflow cleanup in mptcp_destroy_common()
  (bsc#1012628).
- mptcp, btf: Add struct mptcp_sock definition when CONFIG_MPTCP
  is disabled (bsc#1012628).
- NFSv4/pnfs: Fix a use-after-free bug in open (bsc#1012628).
- NFSv4.1: RECLAIM_COMPLETE must handle EACCES (bsc#1012628).
- NFSv4: Fix races in the legacy idmapper upcall (bsc#1012628).
- NFSv4.1: Handle NFS4ERR_DELAY replies to OP_SEQUENCE correctly
  (bsc#1012628).
- NFSv4.1: Don't decrease the value of seq_nr_highest_sent
  (bsc#1012628).
- net: tap: NULL pointer derefence in dev_parse_header_protocol
  when skb->dev is null (bsc#1012628).
- netfilter: nf_tables: fix crash when nf_trace is enabled
  (bsc#1012628).
- Documentation: ACPI: EINJ: Fix obsolete example (bsc#1012628).
- apparmor: Fix memleak in aa_simple_write_to_buffer()
  (bsc#1012628).
- apparmor: fix reference count leak in aa_pivotroot()
  (bsc#1012628).
- apparmor: fix overlapping attachment computation (bsc#1012628).
- apparmor: fix setting unconfined mode on a loaded profile
  (bsc#1012628).
- apparmor: fix aa_label_asxprint return check (bsc#1012628).
- apparmor: Fix failed mount permission check error message
  (bsc#1012628).
- apparmor: fix absroot causing audited secids to begin with =
  (bsc#1012628).
- apparmor: fix quiet_denied for file rules (bsc#1012628).
- can: ems_usb: fix clang's -Wunaligned-access warning
  (bsc#1012628).
- dt-bindings: usb: mtk-xhci: Allow wakeup interrupt-names to
  be optional (bsc#1012628).
- ALSA: hda: Fix crash due to jack poll in suspend (bsc#1012628).
- ALSA: usb-audio: More comprehensive mixer map for ASUS ROG
  Zenith II (bsc#1012628).
- tracing: Have filter accept "common_cpu" to be consistent
  (bsc#1012628).
- tracing/probes: Have kprobes and uprobes use $COMM too
  (bsc#1012628).
- tracing/eprobes: Have event probes be consistent with kprobes
  and uprobes (bsc#1012628).
- tracing/eprobes: Fix reading of string fields (bsc#1012628).
- tracing/eprobes: Do not hardcode $comm as a string
  (bsc#1012628).
- tracing/eprobes: Do not allow eprobes to use $stack, or %%
  for regs (bsc#1012628).
- tracing/perf: Fix double put of trace event when init fails
  (bsc#1012628).
- x86/kprobes: Fix JNG/JNLE emulation (bsc#1012628).
- cifs: Fix memory leak on the deferred close (bsc#1012628).
- drm/i915: pass a pointer for tlb seqno at vma_invalidate_tlb()
  (bsc#1012628).
- drm/i915/gt: Batch TLB invalidations (bsc#1012628).
- drm/i915/gt: Skip TLB invalidations once wedged (bsc#1012628).
- drm/i915/gt: Invalidate TLB of the OA unit at TLB invalidations
  (bsc#1012628).
- drm/i915/gt: Ignore TLB invalidations on idle engines
  (bsc#1012628).
- drm/amdgpu: change vram width algorithm for vram_info v3_0
  (bsc#1012628).
- btrfs: fix warning during log replay when bumping inode link
  count (bsc#1012628).
- btrfs: fix lost error handling when looking up extended ref
  on log replay (bsc#1012628).
- btrfs: reset RO counter on block group if we fail to relocate
  (bsc#1012628).
- btrfs: unset reloc control if transaction commit fails in
  prepare_to_relocate() (bsc#1012628).
- mmc: meson-gx: Fix an error handling path in meson_mmc_probe()
  (bsc#1012628).
- mmc: pxamci: Fix an error handling path in pxamci_probe()
  (bsc#1012628).
- mmc: pxamci: Fix another error handling path in pxamci_probe()
  (bsc#1012628).
- ata: libata-eh: Add missing command name (bsc#1012628).
- s390/ap: fix crash on older machines based on QCI info missing
  (bsc#1012628).
- drm/amd/display: Check correct bounds for stream encoder
  instances for DCN303 (bsc#1012628).
- drm/amdgpu: Only disable prefer_shadow on hawaii (bsc#1012628).
- drm/ttm: Fix dummy res NULL ptr deref bug (bsc#1012628).
- drm/nouveau: recognise GA103 (bsc#1012628).
- locking/atomic: Make test_and_*_bit() ordered on failure
  (bsc#1012628).
- drm/i915/gem: Remove shared locking on freeing objects
  (bsc#1012628).
- rds: add missing barrier to release_refill (bsc#1012628).
- x86/mm: Use proper mask when setting PUD mapping (bsc#1012628).
- KVM: Unconditionally get a ref to /dev/kvm module when creating
  a VM (bsc#1012628).
- RDMA: Handle the return code from dma_resv_wait_timeout()
  properly (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Clevo NS50PU, NS70PU
  (bsc#1012628).
- ALSA: info: Fix llseek return value when using callback
  (bsc#1012628).
- commit 631b6cd
* Thu Aug 25 2022 mkubecek@suse.cz
- series.conf: cleanup
- move recently added patches to "almost mainline" section
  - patches.suse/Revert-zram-remove-double-compression-logic.patch
  - patches.suse/ASoC-nau8821-Implement-hw-constraint-for-rates.patch
  - patches.suse/ASoC-nau8824-Fix-semaphore-unbalance-at-error-paths.patch
  - patches.suse/ASoC-nau8824-Implement-hw-constraint-for-rates.patch
  - patches.suse/ASoC-nau8825-Implement-hw-constraint-for-rates.patch
  - patches.suse/ASoC-nau8540-Implement-hw-constraint-for-rates.patch
- commit 18ca0fb
* Thu Aug 25 2022 tiwai@suse.de
- Refresh USB type-C workaround patch (bsc#1202386)
  It landed in the upstream subsystem repo; also correct the bug reference
- commit bf02544
* Thu Aug 25 2022 tiwai@suse.de
- ASoC: nau8540: Implement hw constraint for rates (bsc#1201418).
- ASoC: nau8825: Implement hw constraint for rates (bsc#1201418).
- ASoC: nau8824: Implement hw constraint for rates (bsc#1201418).
- ASoC: nau8824: Fix semaphore unbalance at error paths
  (bsc#1201418).
- ASoC: nau8821: Implement hw constraint for rates (bsc#1201418).
- commit ef72ecc
* Wed Aug 24 2022 mkubecek@suse.cz
- Update
  patches.kernel.org/5.19.2-1136-net_sched-cls_route-remove-from-list-when-han.patch
  references (add CVE-2022-2588 bsc#1202096).
- Update
  patches.kernel.org/5.19.3-003-net_sched-cls_route-disallow-handle-of-0.patch
  references (add bsc#1202393).
- commit cc8e6d6
* Mon Aug 22 2022 vbabka@suse.cz
- scsi: sd: Revert "Rework asynchronous resume support"
  (rc1 testing).
- commit 4aad010
* Mon Aug 22 2022 mkubecek@suse.cz
- Update to 6.0-rc2
- drop upstreamed patch
  - patches.rpmify/kbuild-dummy-tools-pretend-we-understand-__LONG_DOUB.patch
- refresh configs
- commit 712f762
* Sun Aug 21 2022 jslaby@suse.cz
- Linux 5.19.3 (bsc#1012628).
- arm64: kexec_file: use more system keyrings to verify kernel
  image signature (bsc#1012628).
- kexec, KEYS: make the code in bzImage64_verify_sig generic
  (bsc#1012628).
- btrfs: raid56: don't trust any cached sector in
  __raid56_parity_recover() (bsc#1012628).
- btrfs: only write the sectors in the vertical stripe which
  has data stripes (bsc#1012628).
- net_sched: cls_route: disallow handle of 0 (bsc#1012628).
- tee: add overflow check in register_shm_helper() (bsc#1012628).
- Revert "mm: kfence: apply kmemleak_ignore_phys on early
  allocated pool" (bsc#1012628).
- commit 0140109
* Fri Aug 19 2022 tiwai@suse.de
- Revert "usb: typec: ucsi: add a common function
  ucsi_unregister_connectors()" (bsc#120238).
- commit 46d0607
* Thu Aug 18 2022 msuchanek@suse.de
- Update config files (bsc#1201361 bsc#1192968 https://github.com/rear/rear/issues/2554).
  ppc64: NVRAM=y
- commit e3d4124
* Thu Aug 18 2022 tiwai@suse.de
- Update config files: CONFIG_SPI_AMD=m on x86 (bsc#1201418)
- commit 017ef8a
* Thu Aug 18 2022 tiwai@suse.de
- Workaround for missing HD-audio on AMD platforms (bsc#1202492).
- commit 60e6173
* Thu Aug 18 2022 jslaby@suse.cz
- Linux 5.19.2 (bsc#1012628).
- Revert "pNFS: nfs3_set_ds_client should set NFS_CS_NOPING"
  (bsc#1012628).
- scsi: Revert "scsi: qla2xxx: Fix disk failure to rediscover"
  (bsc#1012628).
- pNFS/flexfiles: Report RDMA connection errors to the server
  (bsc#1012628).
- nfsd: eliminate the NFSD_FILE_BREAK_* flags (bsc#1012628).
- ALSA: usb-audio: Add quirk for Behringer UMC202HD (bsc#1012628).
- ALSA: bcd2000: Fix a UAF bug on the error path of probing
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Clevo NV45PZ (bsc#1012628).
- ALSA: hda/realtek: Add quirk for HP Spectre x360 15-eb0xxx
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Lenovo Yoga9 14IAP7
  (bsc#1012628).
- ASoC: amd: yc: Update DMI table entries (bsc#1012628).
- hwmon: (nct6775) Fix platform driver suspend regression
  (bsc#1012628).
- wifi: mac80211_hwsim: fix race condition in pending packet
  (bsc#1012628).
- wifi: mac80211_hwsim: add back erroneously removed cast
  (bsc#1012628).
- wifi: mac80211_hwsim: use 32-bit skb cookie (bsc#1012628).
- add barriers to buffer_uptodate and set_buffer_uptodate
  (bsc#1012628).
- lockd: detect and reject lock arguments that overflow
  (bsc#1012628).
- HID: hid-input: add Surface Go battery quirk (bsc#1012628).
- HID: nintendo: Add missing array termination (bsc#1012628).
- HID: wacom: Only report rotation for art pen (bsc#1012628).
- HID: wacom: Don't register pad_input for touch switch
  (bsc#1012628).
- KVM: nVMX: Snapshot pre-VM-Enter BNDCFGS for !nested_run_pending
  case (bsc#1012628).
- KVM: nVMX: Snapshot pre-VM-Enter DEBUGCTL for
  !nested_run_pending case (bsc#1012628).
- KVM: SVM: Don't BUG if userspace injects an interrupt with GIF=0
  (bsc#1012628).
- KVM: s390: pv: don't present the ecall interrupt twice
  (bsc#1012628).
- KVM: Drop unused @gpa param from gfn=>pfn cache's
  __release_gpc() helper (bsc#1012628).
- KVM: Put the extra pfn reference when reusing a pfn in the
  gpc cache (bsc#1012628).
- KVM: Fully serialize gfn=>pfn cache refresh via mutex
  (bsc#1012628).
- KVM: Fix multiple races in gfn=>pfn cache refresh (bsc#1012628).
- KVM: Do not incorporate page offset into gfn=>pfn cache user
  address (bsc#1012628).
- KVM: x86: Split kvm_is_valid_cr4() and export only the
  non-vendor bits (bsc#1012628).
- KVM: nVMX: Let userspace set nVMX MSR to any _host_ supported
  value (bsc#1012628).
- KVM: nVMX: Account for KVM reserved CR4 bits in consistency
  checks (bsc#1012628).
- KVM: nVMX: Inject #UD if VMXON is attempted with incompatible
  CR0/CR4 (bsc#1012628).
- KVM: x86: Mark TSS busy during LTR emulation _after_ all fault
  checks (bsc#1012628).
- KVM: x86: Set error code to segment selector on LLDT/LTR
  non-canonical #GP (bsc#1012628).
- KVM: x86/mmu: Treat NX as a valid SPTE bit for NPT
  (bsc#1012628).
- KVM: SVM: Disable SEV-ES support if MMIO caching is disable
  (bsc#1012628).
- KVM: x86: Tag kvm_mmu_x86_module_init() with __init
  (bsc#1012628).
- KVM: x86/mmu: Fully re-evaluate MMIO caching when SPTE masks
  change (bsc#1012628).
- KVM: x86: do not report preemption if the steal time cache is
  stale (bsc#1012628).
- KVM: x86: revalidate steal time cache if MSR value changes
  (bsc#1012628).
- KVM: x86/xen: Initialize Xen timer only once (bsc#1012628).
- KVM: x86/xen: Stop Xen timer before changing IRQ (bsc#1012628).
- ALSA: hda/conexant: Add quirk for LENOVO 20149 Notebook model
  (bsc#1012628).
- ALSA: hda/cirrus - support for iMac 12,1 model (bsc#1012628).
- ALSA: hda/realtek: Add quirk for another Asus K42JZ model
  (bsc#1012628).
- ALSA: hda/realtek: Add a quirk for HP OMEN 15 (8786) mute LED
  (bsc#1012628).
- LoongArch: cpuinfo: Fix a warning for CONFIG_CPUMASK_OFFSTACK
  (bsc#1012628).
- tty: 8250: Add support for Brainboxes PX cards (bsc#1012628).
- tty: vt: initialize unicode screen buffer (bsc#1012628).
- vfs: Check the truncate maximum size in inode_newsize_ok()
  (bsc#1012628).
- fs: Add missing umask strip in vfs_tmpfile (bsc#1012628).
- thermal: sysfs: Fix cooling_device_stats_setup() error code path
  (bsc#1012628).
- fbcon: Fix boundary checks for fbcon=vc:n1-n2 parameters
  (bsc#1012628).
- fbcon: Fix accelerated fbdev scrolling while logo is still shown
  (bsc#1012628).
- usbnet: Fix linkwatch use-after-free on disconnect
  (bsc#1012628).
- usbnet: smsc95xx: Fix deadlock on runtime resume (bsc#1012628).
- fix short copy handling in copy_mc_pipe_to_iter() (bsc#1012628).
- crypto: ccp - Use kzalloc for sev ioctl interfaces to prevent
  kernel memory leak (bsc#1012628).
- ovl: drop WARN_ON() dentry is NULL in ovl_encode_fh()
  (bsc#1012628).
- parisc: Fix device names in /proc/iomem (bsc#1012628).
- parisc: Drop pa_swapper_pg_lock spinlock (bsc#1012628).
- parisc: Check the return value of ioremap() in
  lba_driver_probe() (bsc#1012628).
- parisc: io_pgetevents_time64() needs compat syscall in 32-bit
  compat mode (bsc#1012628).
- riscv:uprobe fix SR_SPIE set/clear handling (bsc#1012628).
- riscv: lib: uaccess: fix CSR_STATUS SR_SUM bit (bsc#1012628).
- dt-bindings: riscv: fix SiFive l2-cache's cache-sets
  (bsc#1012628).
- riscv: dts: starfive: correct number of external interrupts
  (bsc#1012628).
- RISC-V: cpu_ops_spinwait.c should include head.h (bsc#1012628).
- RISC-V: Declare cpu_ops_spinwait in <asm/cpu_ops.h>
  (bsc#1012628).
- RISC-V: kexec: Fixup use of smp_processor_id() in preemptible
  context (bsc#1012628).
- RISC-V: Fixup get incorrect user mode PC for kernel mode regs
  (bsc#1012628).
- RISC-V: Fixup schedule out issue in machine_crash_shutdown()
  (bsc#1012628).
- RISC-V: Add modules to virtual kernel memory layout dump
  (bsc#1012628).
- RISC-V: Fix counter restart during overflow for RV32
  (bsc#1012628).
- RISC-V: Fix SBI PMU calls for RV32 (bsc#1012628).
- RISC-V: Update user page mapping only once during start
  (bsc#1012628).
- wireguard: selftests: set CONFIG_NONPORTABLE on riscv32
  (bsc#1012628).
- rtc: rx8025: fix 12/24 hour mode detection on RX-8035
  (bsc#1012628).
- drm/gem: Properly annotate WW context on
  drm_gem_lock_reservations() error (bsc#1012628).
- drm/shmem-helper: Add missing vunmap on error (bsc#1012628).
- drm/vc4: hdmi: Disable audio if dmas property is present but
  empty (bsc#1012628).
- drm/ingenic: Use the highest possible DMA burst size
  (bsc#1012628).
- drm/fb-helper: Fix out-of-bounds access (bsc#1012628).
- drm/hyperv-drm: Include framebuffer and EDID headers
  (bsc#1012628).
- drm/dp/mst: Read the extended DPCD capabilities during system
  resume (bsc#1012628).
- drm/nouveau: fix another off-by-one in nvbios_addr
  (bsc#1012628).
- drm/nouveau: Don't pm_runtime_put_sync(), only
  pm_runtime_put_autosuspend() (bsc#1012628).
- drm/nouveau/acpi: Don't print error when we get -EINPROGRESS
  from pm_runtime (bsc#1012628).
- drm/nouveau/kms: Fix failure path for creating DP connectors
  (bsc#1012628).
- drm/tegra: Fix vmapping of prime buffers (bsc#1012628).
- drm/amdgpu: Check BO's requested pinning domains against its
  preferred_domains (bsc#1012628).
- bpf: Fix KASAN use-after-free Read in compute_effective_progs
  (bsc#1012628).
- btrfs: reject log replay if there is unsupported RO compat flag
  (bsc#1012628).
- mtd: rawnand: arasan: Fix clock rate in NV-DDR (bsc#1012628).
- mtd: rawnand: arasan: Update NAND bus clock instead of system
  clock (bsc#1012628).
- um: Remove straying parenthesis (bsc#1012628).
- um: seed rng using host OS rng (bsc#1012628).
- iio: fix iio_format_avail_range() printing for none IIO_VAL_INT
  (bsc#1012628).
- iio: light: isl29028: Fix the warning in isl29028_remove()
  (bsc#1012628).
- scsi: lpfc: Remove extra atomic_inc on cmd_pending in
  queuecommand after VMID (bsc#1012628).
- scsi: sg: Allow waiting for commands to complete on removed
  device (bsc#1012628).
- scsi: qla2xxx: Fix incorrect display of max frame size
  (bsc#1012628).
- scsi: qla2xxx: Zero undefined mailbox IN registers
  (bsc#1012628).
- soundwire: qcom: Check device status before reading devid
  (bsc#1012628).
- ksmbd: fix memory leak in smb2_handle_negotiate (bsc#1012628).
- ksmbd: prevent out of bound read for SMB2_TREE_CONNNECT
  (bsc#1012628).
- ksmbd: prevent out of bound read for SMB2_WRITE (bsc#1012628).
- ksmbd: fix use-after-free bug in smb2_tree_disconect
  (bsc#1012628).
- ksmbd: fix heap-based overflow in set_ntacl_dacl()
  (bsc#1012628).
- fuse: limit nsec (bsc#1012628).
- fuse: ioctl: translate ENOSYS (bsc#1012628).
- fuse: write inode in fuse_release() (bsc#1012628).
- fuse: fix deadlock between atomic O_TRUNC and page invalidation
  (bsc#1012628).
- serial: mvebu-uart: uart2 error bits clearing (bsc#1012628).
- md-raid: destroy the bitmap after destroying the thread
  (bsc#1012628).
- md-raid10: fix KASAN warning (bsc#1012628).
- mbcache: don't reclaim used entries (bsc#1012628).
- mbcache: add functions to delete entry if unused (bsc#1012628).
- media: isl7998x: select V4L2_FWNODE to fix build error
  (bsc#1012628).
- media: [PATCH] pci: atomisp_cmd: fix three missing checks on
  list iterator (bsc#1012628).
- ia64, processor: fix -Wincompatible-pointer-types in
  ia64_get_irr() (bsc#1012628).
- powerpc: Restore CONFIG_DEBUG_INFO in defconfigs (bsc#1012628).
- powerpc/64e: Fix early TLB miss with KUAP (bsc#1012628).
- powerpc/fsl-pci: Fix Class Code of PCIe Root Port (bsc#1012628).
- powerpc/ptdump: Fix display of RW pages on FSL_BOOK3E
  (bsc#1012628).
- powerpc/powernv: Avoid crashing if rng is NULL (bsc#1012628).
- MIPS: cpuinfo: Fix a warning for CONFIG_CPUMASK_OFFSTACK
  (bsc#1012628).
- coresight: Clear the connection field properly (bsc#1012628).
- usb: typec: ucsi: Acknowledge the GET_ERROR_STATUS command
  completion (bsc#1012628).
- USB: HCD: Fix URB giveback issue in tasklet function
  (bsc#1012628).
- Revert "net: usb: ax88179_178a needs FLAG_SEND_ZLP"
  (bsc#1012628).
- ARM: dts: uniphier: Fix USB interrupts for PXs2 SoC
  (bsc#1012628).
- arm64: dts: uniphier: Fix USB interrupts for PXs3 SoC
  (bsc#1012628).
- usb: dwc3: gadget: refactor dwc3_repare_one_trb (bsc#1012628).
- usb: dwc3: gadget: fix high speed multiplier setting
  (bsc#1012628).
- netfilter: nf_tables: do not allow SET_ID to refer to another
  table (bsc#1012628).
- netfilter: nf_tables: do not allow CHAIN_ID to refer to another
  table (bsc#1012628).
- netfilter: nf_tables: do not allow RULE_ID to refer to another
  chain (bsc#1012628).
- netfilter: nf_tables: upfront validation of data via
  nft_data_init() (bsc#1012628).
- netfilter: nf_tables: disallow jump to implicit chain from
  set element (bsc#1012628).
- netfilter: nf_tables: fix null deref due to zeroed list head
  (bsc#1012628).
- epoll: autoremove wakers even more aggressively (bsc#1012628).
- x86: Handle idle=nomwait cmdline properly for x86_idle
  (bsc#1012628).
- arch: make TRACE_IRQFLAGS_NMI_SUPPORT generic (bsc#1012628).
- arm64: kasan: do not instrument stacktrace.c (bsc#1012628).
- arm64: stacktrace: use non-atomic __set_bit (bsc#1012628).
- arm64: Do not forget syscall when starting a new thread
  (bsc#1012628).
- arm64: fix oops in concurrently setting insn_emulation sysctls
  (bsc#1012628).
- arm64: kasan: Revert "arm64: mte: reset the page tag in
  page->flags" (bsc#1012628).
- arm64: errata: Remove AES hwcap for COMPAT tasks (bsc#1012628).
- ext2: Add more validity checks for inode counts (bsc#1012628).
- sched/fair: Introduce SIS_UTIL to search idle CPU based on
  sum of util_avg (bsc#1012628).
- genirq: Don't return error on missing optional
  irq_request_resources() (bsc#1012628).
- irqchip/mips-gic: Only register IPI domain when SMP is enabled
  (bsc#1012628).
- genirq: GENERIC_IRQ_IPI depends on SMP (bsc#1012628).
- sched/fair: fix case with reduced capacity CPU (bsc#1012628).
- sched/core: Always flush pending blk_plug (bsc#1012628).
- irqchip/mips-gic: Check the return value of ioremap() in
  gic_of_init() (bsc#1012628).
- ARM: dts: imx6ul: add missing properties for sram (bsc#1012628).
- ARM: dts: imx6ul: change operating-points to uint32-matrix
  (bsc#1012628).
- ARM: dts: imx6ul: fix keypad compatible (bsc#1012628).
- ARM: dts: imx6ul: fix csi node compatible (bsc#1012628).
- ARM: dts: imx6ul: fix lcdif node compatible (bsc#1012628).
- ARM: dts: imx6ul: fix qspi node compatible (bsc#1012628).
- ARM: dts: BCM5301X: Add DT for Meraki MR26 (bsc#1012628).
- ARM: dts: ux500: Fix Janice accelerometer mounting matrix
  (bsc#1012628).
- ARM: dts: ux500: Fix Codina accelerometer mounting matrix
  (bsc#1012628).
- ARM: dts: ux500: Fix Gavini accelerometer mounting matrix
  (bsc#1012628).
- arm64: dts: qcom: timer should use only 32-bit size
  (bsc#1012628).
- spi: synquacer: Add missing clk_disable_unprepare()
  (bsc#1012628).
- ARM: OMAP2+: display: Fix refcount leak bug (bsc#1012628).
- ARM: OMAP2+: pdata-quirks: Fix refcount leak bug (bsc#1012628).
- ACPI: EC: Remove duplicate ThinkPad X1 Carbon 6th entry from
  DMI quirks (bsc#1012628).
- ACPI: EC: Drop the EC_FLAGS_IGNORE_DSDT_GPE quirk (bsc#1012628).
- ACPI: PM: save NVS memory for Lenovo G40-45 (bsc#1012628).
- ACPI: LPSS: Fix missing check in register_device_clock()
  (bsc#1012628).
- ARM: dts: qcom: sdx55: Fix the IRQ trigger type for UART
  (bsc#1012628).
- arm64: dts: qcom: sc7280: Rename sar sensor labels
  (bsc#1012628).
- arm64: dts: qcom: add missing AOSS QMP compatible fallback
  (bsc#1012628).
- arm64: dts: qcom: ipq8074: fix NAND node name (bsc#1012628).
- arm64: dts: allwinner: a64: orangepi-win: Fix LED node name
  (bsc#1012628).
- ARM: shmobile: rcar-gen2: Increase refcount for new reference
  (bsc#1012628).
- firmware: tegra: Fix error check return value of
  debugfs_create_file() (bsc#1012628).
- hwmon: (dell-smm) Add Dell XPS 13 7390 to fan control whitelist
  (bsc#1012628).
- PM: EM: convert power field to micro-Watts precision and align
  drivers (bsc#1012628).
- ACPI: video: Use native backlight on Dell Inspiron N4010
  (bsc#1012628).
- hwmon: (sht15) Fix wrong assumptions in device remove callback
  (bsc#1012628).
- PM: hibernate: defer device probing when resuming from
  hibernation (bsc#1012628).
- selinux: fix memleak in security_read_state_kernel()
  (bsc#1012628).
- selinux: Add boundary check in put_entry() (bsc#1012628).
- io_uring: fix io_uring_cqe_overflow trace format (bsc#1012628).
- kasan: test: Silence GCC 12 warnings (bsc#1012628).
- wait: Fix __wait_event_hrtimeout for RT/DL tasks (bsc#1012628).
- meson-mx-socinfo: Fix refcount leak in meson_mx_socinfo_init
  (bsc#1012628).
- arm64: dts: renesas: beacon: Fix regulator node names
  (bsc#1012628).
- spi: spi-altera-dfl: Fix an error handling path (bsc#1012628).
- ARM: bcm: Fix refcount leak in bcm_kona_smc_init (bsc#1012628).
- ACPI: processor/idle: Annotate more functions to live in
  cpuidle section (bsc#1012628).
- ARM: dts: imx7d-colibri-emmc: add cpu1 supply (bsc#1012628).
- ARM: dts: imx7-colibri: overhaul display/touch functionality
  (bsc#1012628).
- ARM: dts: imx7-colibri: add usb dual-role switching using extcon
  (bsc#1012628).
- ARM: dts: imx7-colibri: improve wake-up with gpio key
  (bsc#1012628).
- ARM: dts: imx7-colibri: move aliases, chosen, extcon and
  gpio-keys (bsc#1012628).
- ARM: dts: imx7-colibri-eval-v3: correct can controller comment
  (bsc#1012628).
- soc: renesas: r8a779a0-sysc: Fix A2DP1 and A2CV[2357] PDR values
  (bsc#1012628).
- soc: amlogic: Fix refcount leak in meson-secure-pwrc.c
  (bsc#1012628).
- arm64: dts: renesas: Fix thermal-sensors on single-zone sensors
  (bsc#1012628).
- Revert "ARM: dts: imx6qdl-apalis: Avoid underscore in node name"
  (bsc#1012628).
- x86/pmem: Fix platform-device leak in error path (bsc#1012628).
- ARM: dts: ast2500-evb: fix board compatible (bsc#1012628).
- ARM: dts: ast2600-evb: fix board compatible (bsc#1012628).
- ARM: dts: ast2600-evb-a1: fix board compatible (bsc#1012628).
- arm64: dts: mt8192: Fix idle-states nodes naming scheme
  (bsc#1012628).
- arm64: dts: mt8192: Fix idle-states entry-method (bsc#1012628).
- arm64: select TRACE_IRQFLAGS_NMI_SUPPORT (bsc#1012628).
- arm64: cpufeature: Allow different PMU versions in ID_DFR0_EL1
  (bsc#1012628).
- locking/lockdep: Fix lockdep_init_map_*() confusion
  (bsc#1012628).
- arm64: dts: qcom: sc7180: Remove ipa_fw_mem node on trogdor
  (bsc#1012628).
- soc: fsl: guts: machine variable might be unset (bsc#1012628).
- spi: s3c64xx: constify fsd_spi_port_config (bsc#1012628).
- block: fix infinite loop for invalid zone append (bsc#1012628).
- arm64: dts: qcom: sdm845-akatsuki: Round down l22a regulator
  voltage (bsc#1012628).
- ARM: dts: qcom: mdm9615: add missing PMIC GPIO reg
  (bsc#1012628).
- ARM: OMAP2+: Fix refcount leak in omapdss_init_of (bsc#1012628).
- ARM: OMAP2+: Fix refcount leak in omap3xxx_prm_late_init
  (bsc#1012628).
- arm64: dts: qcom: sdm630: disable GPU by default (bsc#1012628).
- arm64: dts: qcom: sdm630: fix the qusb2phy ref clock
  (bsc#1012628).
- arm64: dts: qcom: sdm630: fix gpu's interconnect path
  (bsc#1012628).
- arm64: dts: qcom: sdm636-sony-xperia-ganges-mermaid: correct
  sdc2 pinconf (bsc#1012628).
- cpufreq: zynq: Fix refcount leak in zynq_get_revision
  (bsc#1012628).
- arm64: dts: renesas: r8a779m8: Drop operating points above
  1.5 GHz (bsc#1012628).
- arm64: dts: renesas: r9a07g054l2-smarc: Correct SoC name in
  comment (bsc#1012628).
- regulator: qcom_smd: Fix pm8916_pldo range (bsc#1012628).
- ACPI: APEI: Fix _EINJ vs EFI_MEMORY_SP (bsc#1012628).
- ARM: dts: qcom: replace gcc PXO with pxo_board fixed clock
  (bsc#1012628).
- ARM: dts: qcom-msm8974: fix irq type on blsp2_uart1
  (bsc#1012628).
- soc: qcom: ocmem: Fix refcount leak in of_get_ocmem
  (bsc#1012628).
- soc: qcom: aoss: Fix refcount leak in
  qmp_cooling_devices_register (bsc#1012628).
- ARM: dts: qcom: msm8974: add required ranges to OCMEM
  (bsc#1012628).
- ARM: dts: qcom: pm8841: add required thermal-sensor-cells
  (bsc#1012628).
- bus: hisi_lpc: fix missing platform_device_put() in
  hisi_lpc_acpi_probe() (bsc#1012628).
- lib: overflow: Do not define 64-bit tests on 32-bit
  (bsc#1012628).
- stack: Declare {randomize_,}kstack_offset to fix Sparse warnings
  (bsc#1012628).
- arm64: dts: qcom: msm8916: Fix typo in pronto remoteproc node
  (bsc#1012628).
- arm64: dts: qcom: msm8994: add required ranges to OCMEM
  (bsc#1012628).
- perf/x86/intel: Fix PEBS memory access info encoding for ADL
  (bsc#1012628).
- perf/x86/intel: Fix PEBS data source encoding for ADL
  (bsc#1012628).
- arm64: dts: exynosautov9: correct spi11 pin names (bsc#1012628).
- ACPI: VIOT: Fix ACS setup (bsc#1012628).
- m68k: virt: Fix missing platform_device_unregister() on error
  in virt_platform_init() (bsc#1012628).
- arm64: dts: qcom: sm6125: Move sdc2 pinctrl from seine-pdx201
  to sm6125 (bsc#1012628).
- arm64: dts: qcom: sm6125: Append -state suffix to pinctrl nodes
  (bsc#1012628).
- arm64: dts: qcom: msm8996: correct #clock-cells for QMP PHY
  nodes (bsc#1012628).
- arm64: dts: qcom: sc7280: drop PCIe PHY clock index
  (bsc#1012628).
- arm64: dts: qcom: sm8250: add missing PCIe PHY clock-cells
  (bsc#1012628).
- arm64: dts: mt7622: fix BPI-R64 WPS button (bsc#1012628).
- arm64: tegra: Mark BPMP channels as no-memory-wc (bsc#1012628).
- arm64: tegra: Fix SDMMC1 CD on P2888 (bsc#1012628).
- arm64: dts: qcom: sc7280: fix PCIe clock reference
  (bsc#1012628).
- erofs: wake up all waiters after z_erofs_lzma_head ready
  (bsc#1012628).
- erofs: avoid consecutive detection for Highmem memory
  (bsc#1012628).
- spi: Return deferred probe error when controller isn't yet
  available (bsc#1012628).
- blk-mq: don't create hctx debugfs dir until q->debugfs_dir is
  created (bsc#1012628).
- spi: dw: Fix IP-core versions macro (bsc#1012628).
- spi: Fix simplification of devm_spi_register_controller
  (bsc#1012628).
- spi: tegra20-slink: fix UAF in tegra_slink_remove()
  (bsc#1012628).
- hwmon: (sch56xx-common) Add DMI override table (bsc#1012628).
- hwmon: (drivetemp) Add module alias (bsc#1012628).
- blktrace: Trace remapped requests correctly (bsc#1012628).
- PM: domains: Ensure genpd_debugfs_dir exists before remove
  (bsc#1012628).
- dm writecache: return void from functions (bsc#1012628).
- dm writecache: count number of blocks read, not number of read
  bios (bsc#1012628).
- dm writecache: count number of blocks written, not number of
  write bios (bsc#1012628).
- dm writecache: count number of blocks discarded, not number
  of discard bios (bsc#1012628).
- regulator: of: Fix refcount leak bug in
  of_get_regulation_constraints() (bsc#1012628).
- soc: qcom: Make QCOM_RPMPD depend on PM (bsc#1012628).
- soc: qcom: socinfo: Fix the id of SA8540P SoC (bsc#1012628).
- arm64: dts: qcom: msm8998: Make regulator voltages multiple
  of step-size (bsc#1012628).
- arm64: dts: qcom: qcs404: Fix incorrect USB2 PHYs assignment
  (bsc#1012628).
- ARM: dts: qcom: msm8974: Disable remoteprocs by default
  (bsc#1012628).
- irqdomain: Report irq number for NOMAP domains (bsc#1012628).
- perf: RISC-V: Add of_node_put() when breaking out of
  for_each_of_cpu_node() (bsc#1012628).
- drivers/perf: arm_spe: Fix consistency of SYS_PMSCR_EL1.CX
  (bsc#1012628).
- nohz/full, sched/rt: Fix missed tick-reenabling bug in
  dequeue_task_rt() (bsc#1012628).
- sched: only perform capability check on privileged operation
  (bsc#1012628).
- sched/numa: Initialise numa_migrate_retry (bsc#1012628).
- x86/extable: Fix ex_handler_msr() print condition (bsc#1012628).
- io_uring: move to separate directory (bsc#1012628).
- io_uring: define a 'prep' and 'issue' handler for each opcode
  (bsc#1012628).
- io_uring: Don't require reinitable percpu_ref (bsc#1012628).
- selftests/seccomp: Fix compile warning when CC=clang
  (bsc#1012628).
- thermal/tools/tmon: Include pthread and time headers in tmon.h
  (bsc#1012628).
- tools/power turbostat: Fix file pointer leak (bsc#1012628).
- dm: return early from dm_pr_call() if DM device is suspended
  (bsc#1012628).
- pwm: sifive: Simplify offset calculation for PWMCMP registers
  (bsc#1012628).
- pwm: sifive: Ensure the clk is enabled exactly once per running
  PWM (bsc#1012628).
- pwm: sifive: Shut down hardware only after pwmchip_remove()
  completed (bsc#1012628).
- pwm: lpc18xx: Fix period handling (bsc#1012628).
- erofs: update ctx->pos for every emitted dirent (bsc#1012628).
- dt-bindings: display: bridge: ldb: Fill in reg property
  (bsc#1012628).
- drm/i915: remove unused GEM_DEBUG_DECL() and GEM_DEBUG_BUG_ON()
  (bsc#1012628).
- drm/rockchip: vop2: unlock on error path in
  vop2_crtc_atomic_enable() (bsc#1012628).
- drm: bridge: DRM_FSL_LDB should depend on ARCH_MXC
  (bsc#1012628).
- drm/bridge: anx7625: Use DPI bus type (bsc#1012628).
- drm/mgag200: Acquire I/O lock while reading EDID (bsc#1012628).
- drm/meson: Fix refcount leak in meson_encoder_hdmi_init
  (bsc#1012628).
- drm/dp: Export symbol / kerneldoc fixes for DP AUX bus
  (bsc#1012628).
- drm/bridge: tc358767: Handle dsi_lanes == 0 as invalid
  (bsc#1012628).
- drm/bridge: tc358767: Make sure Refclk clock are enabled
  (bsc#1012628).
- ath10k: do not enforce interrupt trigger type (bsc#1012628).
- ath11k: Fix warning on variable 'sar' dereference before check
  (bsc#1012628).
- ath11k: Init hw_params before setting up AHB resources
  (bsc#1012628).
- drm/edid: reset display info in drm_add_edid_modes() for NULL
  edid (bsc#1012628).
- drm/bridge: lt9611: Use both bits for HDMI sensing
  (bsc#1012628).
- drm/st7735r: Fix module autoloading for Okaya RH128128T
  (bsc#1012628).
- drm/panel: Fix build error when
  CONFIG_DRM_PANEL_SAMSUNG_ATNA33XC20=y &&
  CONFIG_DRM_DISPLAY_HELPER=m (bsc#1012628).
- drm: bridge: adv7511: Move CEC definitions to adv7511_cec.c
  (bsc#1012628).
- wifi: rtlwifi: fix error codes in rtl_debugfs_set_write_h2c()
  (bsc#1012628).
- wifi: wilc1000: use correct sequence of RESET for chip
  Power-UP/Down (bsc#1012628).
- ath11k: fix netdev open race (bsc#1012628).
- ath11k: fix IRQ affinity warning on shutdown (bsc#1012628).
- drm/mipi-dbi: align max_chunk to 2 in spi_transfer
  (bsc#1012628).
- drm/ssd130x: Only define a SPI device ID table when built as
  a module (bsc#1012628).
- selftests/bpf: Fix test_run logic in fexit_stress.c
  (bsc#1012628).
- sample: bpf: xdp_router_ipv4: Allow the kernel to send arp
  requests (bsc#1012628).
- selftests/bpf: Fix tc_redirect_dtime (bsc#1012628).
- libbpf: Fix is_pow_of_2 (bsc#1012628).
- ath11k: fix missing skb drop on htc_tx_completion error
  (bsc#1012628).
- ath11k: Fix incorrect debug_mask mappings (bsc#1012628).
- ath11k: Avoid REO CMD failed prints during firmware recovery
  (bsc#1012628).
- drm/radeon: fix potential buffer overflow in
  ni_set_mc_special_registers() (bsc#1012628).
- drm/mediatek: Modify dsi funcs to atomic operations
  (bsc#1012628).
- drm/mediatek: Separate poweron/poweroff from enable/disable
  and define new funcs (bsc#1012628).
- drm/mediatek: Add pull-down MIPI operation in mtk_dsi_poweroff
  function (bsc#1012628).
- drm/meson: encoder_cvbs: Fix refcount leak in
  meson_encoder_cvbs_init (bsc#1012628).
- drm/meson: encoder_hdmi: Fix refcount leak in
  meson_encoder_hdmi_init (bsc#1012628).
- drm/bridge: lt9611uxc: Cancel only driver's work (bsc#1012628).
- drm/amdgpu: fix scratch register access method in SRIOV
  (bsc#1012628).
- drm/amdgpu/display: Prepare for new interfaces (bsc#1012628).
- i2c: npcm: Remove own slave addresses 2:10 (bsc#1012628).
- i2c: npcm: Correct slave role behavior (bsc#1012628).
- i2c: mxs: Silence a clang warning (bsc#1012628).
- virtio-gpu: fix a missing check to avoid NULL dereference
  (bsc#1012628).
- drm/virtio: Fix NULL vs IS_ERR checking in
  virtio_gpu_object_shmem_init (bsc#1012628).
- libbpf: Fix uprobe symbol file offset calculation logic
  (bsc#1012628).
- drm: adv7511: override i2c address of cec before accessing it
  (bsc#1012628).
- crypto: sun8i-ss - fix error codes in allocate_flows()
  (bsc#1012628).
- crypto: sun8i-ss - Fix error codes for dma_mapping_error()
  (bsc#1012628).
- crypto: sun8i-ss - fix a NULL vs IS_ERR() check in
  sun8i_ss_hashkey (bsc#1012628).
- net: fix sk_wmem_schedule() and sk_rmem_schedule() errors
  (bsc#1012628).
- can: netlink: allow configuring of fixed bit rates without
  need for do_set_bittiming callback (bsc#1012628).
- drm/vkms: check plane_composer->map[0] before using it
  (bsc#1012628).
- can: netlink: allow configuring of fixed data bit rates without
  need for do_set_data_bittiming callback (bsc#1012628).
- drm/bridge: anx7625: Zero error variable when panel bridge
  not present (bsc#1012628).
- drm/bridge: it6505: Add missing CRYPTO_HASH dependency
  (bsc#1012628).
- i2c: Fix a potential use after free (bsc#1012628).
- libbpf: Fix internal USDT address translation logic for shared
  libraries (bsc#1012628).
- selftests/bpf: Don't force lld on non-x86 architectures
  (bsc#1012628).
- tcp: fix possible freeze in tx path under memory pressure
  (bsc#1012628).
- crypto: sun8i-ss - fix infinite loop in sun8i_ss_setup_ivs()
  (bsc#1012628).
- net: ag71xx: fix discards 'const' qualifier warning
  (bsc#1012628).
- ping: convert to RCU lookups, get rid of rwlock (bsc#1012628).
- raw: use more conventional iterators (bsc#1012628).
- raw: convert raw sockets to RCU (bsc#1012628).
- raw: Fix mixed declarations error in raw_icmp_error()
  (bsc#1012628).
- media: atmel: atmel-sama7g5-isc: fix warning in configs without
  OF (bsc#1012628).
- media: camss: csid: fix wrong size passed to
  devm_kmalloc_array() (bsc#1012628).
- media: tw686x: Register the irq at the end of probe
  (bsc#1012628).
- media: amphion: return error if format is unsupported by vpu
  (bsc#1012628).
- media: Hantro: Correct G2 init qp field (bsc#1012628).
- media: imx-jpeg: Correct some definition according specification
  (bsc#1012628).
- media: imx-jpeg: Leave a blank space before the configuration
  data (bsc#1012628).
- media: imx-jpeg: Align upwards buffer size (bsc#1012628).
- media: imx-jpeg: Implement drain using v4l2-mem2mem helpers
  (bsc#1012628).
- media: rcar-vin: Fix channel routing for Ebisu (bsc#1012628).
- wifi: mac80211: set STA deflink addresses (bsc#1012628).
- wifi: iwlegacy: 4965: fix potential off-by-one overflow in
  il4965_rs_fill_link_cmd() (bsc#1012628).
- wifi: rtw89: 8852a: rfk: fix div 0 exception (bsc#1012628).
- drm/radeon: fix incorrrect SPDX-License-Identifiers
  (bsc#1012628).
- drm/amd: Don't show warning on reading vbios values for SMU13
  3.1 (bsc#1012628).
- drm/amdkfd: correct sdma queue number of sdma 6.0.1
  (bsc#1012628).
- torture: Adjust to again produce debugging information
  (bsc#1012628).
- rcutorture: Fix ksoftirqd boosting timing and iteration
  (bsc#1012628).
- test_bpf: fix incorrect netdev features (bsc#1012628).
- drm/display: Fix build error without CONFIG_OF (bsc#1012628).
- selftests/bpf: Fix rare segfault in sock_fields prog test
  (bsc#1012628).
- crypto: ccp - During shutdown, check SEV data pointer before
  using (bsc#1012628).
- drm: bridge: adv7511: Add check for mipi_dsi_driver_register
  (bsc#1012628).
- media: imx-jpeg: Disable slot interrupt when frame done
  (bsc#1012628).
- media: amphion: output firmware error message (bsc#1012628).
- drm/mcde: Fix refcount leak in mcde_dsi_bind (bsc#1012628).
- media: hdpvr: fix error value returns in hdpvr_read
  (bsc#1012628).
- media: v4l2-mem2mem: prevent pollerr when last_buffer_dequeued
  is set (bsc#1012628).
- media: sta2x11: remove VIRT_TO_BUS dependency (bsc#1012628).
- media: mediatek: vcodec: Initialize decoder parameters after
  getting dec_capability (bsc#1012628).
- media: mediatek: vcodec: Skip SOURCE_CHANGE & EOS events for
  stateless (bsc#1012628).
- media: driver/nxp/imx-jpeg: fix a unexpected return value
  problem (bsc#1012628).
- media: tw686x: Fix memory leak in tw686x_video_init
  (bsc#1012628).
- media: mediatek: vcodec: Fix non subdev architecture open
  power fail (bsc#1012628).
- drm/vc4: kms: Use maximum FIFO load for the HVS clock rate
  (bsc#1012628).
- drm/vc4: plane: Remove subpixel positioning check (bsc#1012628).
- drm/vc4: plane: Fix margin calculations for the right/bottom
  edges (bsc#1012628).
- drm/vc4: dsi: Release workaround buffer and DMA (bsc#1012628).
- drm/vc4: dsi: Correct DSI divider calculations (bsc#1012628).
- drm/vc4: dsi: Correct pixel order for DSI0 (bsc#1012628).
- drm/vc4: dsi: Register dsi0 as the correct vc4 encoder type
  (bsc#1012628).
- drm/vc4: dsi: Fix dsi0 interrupt support (bsc#1012628).
- drm/vc4: dsi: Add correct stop condition to
  vc4_dsi_encoder_disable iteration (bsc#1012628).
- drm/vc4: hdmi: Add all the vc5 HDMI registers into the debugfs
  dumps (bsc#1012628).
- drm/vc4: hdmi: Clear unused infoframe packet RAM registers
  (bsc#1012628).
- drm/vc4: hdmi: Avoid full hdmi audio fifo writes (bsc#1012628).
- drm/vc4: hdmi: Reset HDMI MISC_CONTROL register (bsc#1012628).
- drm/vc4: hdmi: Switch to pm_runtime_status_suspended
  (bsc#1012628).
- drm/vc4: hdmi: Move HDMI reset to pm_resume (bsc#1012628).
- drm/vc4: hdmi: Fix timings for interlaced modes (bsc#1012628).
- drm/vc4: hdmi: Force modeset when bpc or format changes
  (bsc#1012628).
- drm/vc4: hdmi: Correct HDMI timing registers for interlaced
  modes (bsc#1012628).
- drm/vc4: hdmi: Move pixel doubling from Pixelvalve to HDMI block
  (bsc#1012628).
- mm: Account dirty folios properly during splits (bsc#1012628).
- crypto: arm64/gcm - Select AEAD for GHASH_ARM64_CE
  (bsc#1012628).
- selftests/xsk: Destroy BPF resources only when ctx refcount
  drops to 0 (bsc#1012628).
- net: dsa: felix: update base time of time-aware shaper when
  adjusting PTP time (bsc#1012628).
- net: dsa: felix: keep reference on entire tc-taprio config
  (bsc#1012628).
- net: dsa: felix: drop oversized frames with tc-taprio instead
  of hanging the port (bsc#1012628).
- selftests: net: fib_rule_tests: fix support for running
  individual tests (bsc#1012628).
- drm/rockchip: vop: Don't crash for invalid duplicate_state()
  (bsc#1012628).
- drm/rockchip: Fix an error handling path rockchip_dp_probe()
  (bsc#1012628).
- drm/mediatek: dpi: Remove output format of YUV (bsc#1012628).
- drm/mediatek: dpi: Only enable dpi after the bridge is enabled
  (bsc#1012628).
- drm/msm/dpu: move intf and wb assignment to
  dpu_encoder_setup_display() (bsc#1012628).
- drm/msm/dpu: fix maxlinewidth for writeback block (bsc#1012628).
- drm/msm/dpu: remove hard-coded linewidth limit for writeback
  (bsc#1012628).
- drm/msm/hdmi: fill the pwr_regs bulk regulators (bsc#1012628).
- drm: bridge: sii8620: fix possible off-by-one (bsc#1012628).
- drm/msm: Fix fence rollover issue (bsc#1012628).
- net: sched: provide shim definitions for
  taprio_offload_{get,free} (bsc#1012628).
- net: dsa: felix: build as module when tc-taprio is module
  (bsc#1012628).
- hinic: Use the bitmap API when applicable (bsc#1012628).
- net: hinic: fix bug that ethtool get wrong stats (bsc#1012628).
- net: hinic: avoid kernel hung in hinic_get_stats64()
  (bsc#1012628).
- drm/bridge: anx7625: Fix NULL pointer crash when using edp-panel
  (bsc#1012628).
- drm/msm: Avoid unclocked GMU register access in 6xx gpu_busy
  (bsc#1012628).
- libbpf, riscv: Use a0 for RC register (bsc#1012628).
- drm/msm/mdp5: Fix global state lock backoff (bsc#1012628).
- drm/radeon: avoid bogus "vram limit (0) must be a power of 2"
  warning (bsc#1012628).
- crypto: hisilicon/sec - don't sleep when in softirq
  (bsc#1012628).
- crypto: hisilicon - Kunpeng916 crypto driver don't sleep when
  in softirq (bsc#1012628).
- media: platform: mtk-mdp: Fix mdp_ipi_comm structure alignment
  (bsc#1012628).
- media: amphion: release core lock before reset vpu core
  (bsc#1012628).
- drm/msm/dpu: Fix for non-visible planes (bsc#1012628).
- media: atomisp: revert "don't pass a pointer to a local
  variable" (bsc#1012628).
- media: mediatek: vcodec: decoder: Fix 4K frame size enumeration
  (bsc#1012628).
- media: mediatek: vcodec: decoder: Fix resolution clamping in
  TRY_FMT (bsc#1012628).
- media: mediatek: vcodec: decoder: Skip alignment for default
  resolution (bsc#1012628).
- media: mediatek: vcodec: decoder: Drop max_{width,height}
  from mtk_vcodec_ctx (bsc#1012628).
- media: mediatek: vcodec: Initialize decoder parameters for
  each instance (bsc#1012628).
- media: amphion: defer setting last_buffer_dequeued until
  resolution changes are processed (bsc#1012628).
- media: hantro: Be more accurate on pixel formats step_width
  constraints (bsc#1012628).
- media: hantro: Fix RK3399 H.264 format advertising
  (bsc#1012628).
- media: amphion: sync buffer status with firmware during abort
  (bsc#1012628).
- media: amphion: only insert the first sequence startcode for
  vc1l format (bsc#1012628).
- mt76: mt7915: fix endianness in mt7915_rf_regval_get
  (bsc#1012628).
- mt76: mt76x02u: fix possible memory leak in
  __mt76x02u_mcu_send_msg (bsc#1012628).
- mt76: mt7915: fix endian bug in mt7915_rf_regval_set()
  (bsc#1012628).
- mt76: mt7921s: fix firmware download random fail (bsc#1012628).
- mt76: mt7921: not support beacon offload disable command
  (bsc#1012628).
- wifi: mac80211: reject WEP or pairwise keys with key ID > 3
  (bsc#1012628).
- wifi: cfg80211: do some rework towards MLO link APIs
  (bsc#1012628).
- wifi: mac80211: move some future per-link data to bss_conf
  (bsc#1012628).
- mt76: mt7615: do not update pm stats in case of error
  (bsc#1012628).
- mt76: mt7921: do not update pm states in case of error
  (bsc#1012628).
- mt76: mt7921s: fix possible sdio deadlock in command fail
  (bsc#1012628).
- mt76: mt7921: fix aggregation subframes setting to HE max
  (bsc#1012628).
- mt76: mt7921: enlarge maximum VHT MPDU length to 11454
  (bsc#1012628).
- mt76: mt7921: rely on mt76_dev in mt7921_mac_write_txwi
  signature (bsc#1012628).
- mt76: mt7915: rely on mt76_dev in mt7915_mac_write_txwi
  signature (bsc#1012628).
- mt76: connac: move mac connac2 defs in mt76_connac2_mac.h
  (bsc#1012628).
- mt76: connac: move connac2_mac_write_txwi in mt76_connac module
  (bsc#1012628).
- mt76: mt7915: fix incorrect testmode ipg on band 1 caused by
  wmm_idx (bsc#1012628).
- mt76: mt7615: fix throughput regression on DFS channels
  (bsc#1012628).
- mediatek: mt76: mac80211: Fix missing of_node_put() in
  mt76_led_init() (bsc#1012628).
- mediatek: mt76: eeprom: fix missing of_node_put() in
  mt76_find_power_limits_node() (bsc#1012628).
- skmsg: Fix invalid last sg check in sk_msg_recvmsg()
  (bsc#1012628).
- drm/exynos/exynos7_drm_decon: free resources when
  clk_set_parent() failed (bsc#1012628).
- bpf, x64: Add predicate for bpf2bpf with tailcalls support in
  JIT (bsc#1012628).
- bpf, x86: fix freeing of not-finalized bpf_prog_pack
  (bsc#1012628).
- tcp: make retransmitted SKB fit into the send window
  (bsc#1012628).
- libbpf: Fix the name of a reused map (bsc#1012628).
- kunit: executor: Fix a memory leak on failure in
  kunit_filter_tests (bsc#1012628).
- selftests: timers: valid-adjtimex: build fix for newer
  toolchains (bsc#1012628).
- selftests: timers: clocksource-switch: fix passing errors from
  child (bsc#1012628).
- bpf: Fix subprog names in stack traces (bsc#1012628).
- wifi: nl80211: acquire wdev mutex for dump_survey (bsc#1012628).
- media: v4l: async: Also match secondary fwnode endpoints
  (bsc#1012628).
- media: ov7251: add missing disable functions on error in
  ov7251_set_power_on() (bsc#1012628).
- fs: check FMODE_LSEEK to control internal pipe splicing
  (bsc#1012628).
- media: cedrus: h265: Fix flag name (bsc#1012628).
- media: uapi: HEVC: Change pic_order_cnt definition in
  v4l2_hevc_dpb_entry (bsc#1012628).
- media: cedrus: h265: Fix logic for not low delay flag
  (bsc#1012628).
- wifi: wil6210: debugfs: fix info leak in wil_write_file_wmi()
  (bsc#1012628).
- wifi: p54: Fix an error handling path in p54spi_probe()
  (bsc#1012628).
- wifi: p54: add missing parentheses in p54_flush() (bsc#1012628).
- drm/amdgpu: use the same HDP flush registers for all nbio 7.4.x
  (bsc#1012628).
- drm/amdgpu: use the same HDP flush registers for all nbio 2.3.x
  (bsc#1012628).
- drm/amdgpu: restore original stable pstate on ctx fini
  (bsc#1012628).
- bpf: fix potential 32-bit overflow when accessing ARRAY map
  element (bsc#1012628).
- libbpf: make RINGBUF map size adjustments more eagerly
  (bsc#1012628).
- selftests/bpf: fix a test for snprintf() overflow (bsc#1012628).
- libbpf: fix an snprintf() overflow check (bsc#1012628).
- can: pch_can: do not report txerr and rxerr during bus-off
  (bsc#1012628).
- can: rcar_can: do not report txerr and rxerr during bus-off
  (bsc#1012628).
- can: sja1000: do not report txerr and rxerr during bus-off
  (bsc#1012628).
- can: hi311x: do not report txerr and rxerr during bus-off
  (bsc#1012628).
- can: sun4i_can: do not report txerr and rxerr during bus-off
  (bsc#1012628).
- can: kvaser_usb_hydra: do not report txerr and rxerr during
  bus-off (bsc#1012628).
- can: kvaser_usb_leaf: do not report txerr and rxerr during
  bus-off (bsc#1012628).
- can: usb_8dev: do not report txerr and rxerr during bus-off
  (bsc#1012628).
- can: error: specify the values of data[5..7] of CAN error frames
  (bsc#1012628).
- libbpf: Fix str_has_sfx()'s return value (bsc#1012628).
- can: pch_can: pch_can_error(): initialize errc before using it
  (bsc#1012628).
- Bluetooth: hci_intel: Add check for platform_driver_register
  (bsc#1012628).
- Bluetooth: When HCI work queue is drained, only queue chained
  work (bsc#1012628).
- Bluetooth: mgmt: Fix refresh cached connection info
  (bsc#1012628).
- Bluetooth: hci_sync: Fix resuming scan after suspend resume
  (bsc#1012628).
- Bluetooth: hci_sync: Fix not updating privacy_mode
  (bsc#1012628).
- Bluetooth: Add default wakeup callback for HCI UART driver
  (bsc#1012628).
- i2c: cadence: Support PEC for SMBus block read (bsc#1012628).
- i2c: qcom-geni: Use the correct return value (bsc#1012628).
- btrfs: update stripe_sectors::uptodate in steal_rbio
  (bsc#1012628).
- ip_tunnels: Add new flow flags field to ip_tunnel_key
  (bsc#1012628).
- bpf: Set flow flag to allow any source IP in bpf_tunnel_key
  (bsc#1012628).
- bpf: Fix bpf_xdp_pointer return pointer (bsc#1012628).
- i2c: mux-gpmux: Add of_node_put() when breaking out of loop
  (bsc#1012628).
- wifi: ath11k: Fix register write failure on QCN9074
  (bsc#1012628).
- wifi: wil6210: debugfs: fix uninitialized variable use in
  `wil_write_file_wmi()` (bsc#1012628).
- wifi: iwlwifi: mvm: fix double list_add at
  iwl_mvm_mac_wake_tx_queue (bsc#1012628).
- wifi: libertas: Fix possible refcount leak in if_usb_probe()
  (bsc#1012628).
- media: cedrus: hevc: Add check for invalid timestamp
  (bsc#1012628).
- hantro: Remove incorrect HEVC SPS validation (bsc#1012628).
- drm/amd/display: fix signedness bug in
  execute_synaptics_rc_command() (bsc#1012628).
- net/mlx5e: Remove WARN_ON when trying to offload an unsupported
  TLS cipher/version (bsc#1012628).
- net/mlx5e: TC, Fix post_act to not match on in_port metadata
  (bsc#1012628).
- net/mlx5e: Fix the value of MLX5E_MAX_RQ_NUM_MTTS (bsc#1012628).
- net/mlx5e: xsk: Account for XSK RQ UMRs when calculating ICOSQ
  size (bsc#1012628).
- net/mlx5e: Fix calculations related to max MPWQE size
  (bsc#1012628).
- net/mlx5e: Modify slow path rules to go to slow fdb
  (bsc#1012628).
- net/mlx5: Adjust log_max_qp to be 18 at most (bsc#1012628).
- net/mlx5: DR, Fix SMFS steering info dump format (bsc#1012628).
- net/mlx5: Fix driver use of uninitialized timeout (bsc#1012628).
- ax25: fix incorrect dev_tracker usage (bsc#1012628).
- crypto: hisilicon/hpre - don't use GFP_KERNEL to alloc mem
  during softirq (bsc#1012628).
- crypto: inside-secure - Add missing MODULE_DEVICE_TABLE for of
  (bsc#1012628).
- crypto: hisilicon/sec - fix auth key size error (bsc#1012628).
- net: allow unbound socket for packets in VRF when
  tcp_l3mdev_accept set (bsc#1012628).
- netdevsim: fib: Fix reference count leak on route deletion
  failure (bsc#1012628).
- wifi: rtw88: check the return value of alloc_workqueue()
  (bsc#1012628).
- iavf: Fix max_rate limiting (bsc#1012628).
- iavf: Fix 'tc qdisc show' listing too many queues (bsc#1012628).
- netdevsim: Avoid allocation warnings triggered from user space
  (bsc#1012628).
- net: rose: fix netdev reference changes (bsc#1012628).
- net: ice: fix error NETIF_F_HW_VLAN_CTAG_FILTER check in
  ice_vsi_sync_fltr() (bsc#1012628).
- net: ionic: fix error check for vlan flags in
  ionic_set_nic_features() (bsc#1012628).
- dccp: put dccp_qpolicy_full() and dccp_qpolicy_push() in the
  same lock (bsc#1012628).
- net: usb: make USB_RTL8153_ECM non user configurable
  (bsc#1012628).
- net/mlx5e: xsk: Discard unaligned XSK frames on striding RQ
  (bsc#1012628).
- wireguard: ratelimiter: use hrtimer in selftest (bsc#1012628).
- wireguard: allowedips: don't corrupt stack when detecting
  overflow (bsc#1012628).
- HID: amd_sfh: Don't show client init failed as error when
  discovery fails (bsc#1012628).
- clk: renesas: r9a06g032: Fix UART clkgrp bitsel (bsc#1012628).
- mtd: maps: Fix refcount leak in of_flash_probe_versatile
  (bsc#1012628).
- mtd: maps: Fix refcount leak in ap_flash_init (bsc#1012628).
- mtd: rawnand: meson: Fix a potential double free issue
  (bsc#1012628).
- clk: renesas: rzg2l: Fix reset status function (bsc#1012628).
- of: check previous kernel's ima-kexec-buffer against memory
  bounds (bsc#1012628).
- scsi: qla2xxx: edif: Reduce Initiator-Initiator thrashing
  (bsc#1012628).
- scsi: qla2xxx: edif: bsg refactor (bsc#1012628).
- scsi: qla2xxx: edif: Wait for app to ack on sess down
  (bsc#1012628).
- scsi: qla2xxx: edif: Add bsg interface to read doorbell events
  (bsc#1012628).
- scsi: qla2xxx: edif: Fix potential stuck session in sa update
  (bsc#1012628).
- scsi: qla2xxx: edif: Synchronize NPIV deletion with
  authentication application (bsc#1012628).
- scsi: qla2xxx: edif: Add retry for ELS passthrough
  (bsc#1012628).
- scsi: qla2xxx: edif: Fix n2n discovery issue with secure target
  (bsc#1012628).
- scsi: qla2xxx: edif: Fix n2n login retry for secure device
  (bsc#1012628).
- KVM: SVM: Unwind "speculative" RIP advancement if INTn injection
  "fails" (bsc#1012628).
- KVM: SVM: Stuff next_rip on emulated INT3 injection if NRIPS
  is supported (bsc#1012628).
- KVM: x86/mmu: Drop RWX=0 SPTEs during ept_sync_page()
  (bsc#1012628).
- phy: samsung: exynosautov9-ufs: correct TSRV register
  configurations (bsc#1012628).
- PCI: microchip: Fix refcount leak in mc_pcie_init_irq_domains()
  (bsc#1012628).
- PCI: tegra194: Fix PM error handling in tegra_pcie_config_ep()
  (bsc#1012628).
- HID: cp2112: prevent a buffer overflow in cp2112_xfer()
  (bsc#1012628).
- mtd: sm_ftl: Fix deadlock caused by cancel_work_sync in
  sm_release (bsc#1012628).
- mtd: partitions: Fix refcount leak in parse_redboot_of
  (bsc#1012628).
- mtd: parsers: ofpart: Fix refcount leak in
  bcm4908_partitions_fw_offset (bsc#1012628).
- mtd: spear_smi: Don't skip cleanup after mtd_device_unregister()
  failed (bsc#1012628).
- mtd: st_spi_fsm: Add a clk_disable_unprepare() in .probe()'s
  error path (bsc#1012628).
- mtd: spear_smi: Drop if with an always false condition
  (bsc#1012628).
- mtd: st_spi_fsm: Warn about failure to unregister mtd device
  (bsc#1012628).
- mtd: st_spi_fsm: Disable clock only after device was
  unregistered (bsc#1012628).
- PCI: mediatek-gen3: Fix refcount leak in
  mtk_pcie_init_irq_domains() (bsc#1012628).
- fpga: altera-pr-ip: fix unsigned comparison with less than zero
  (bsc#1012628).
- usb: host: Fix refcount leak in ehci_hcd_ppc_of_probe
  (bsc#1012628).
- usb: cdns3: fix random warning message when driver load
  (bsc#1012628).
- usb: gadget: uvc: Fix comment blocks style (bsc#1012628).
- usb: ohci-nxp: Fix refcount leak in ohci_hcd_nxp_probe
  (bsc#1012628).
- usb: gadget: tegra-xudc: Fix error check in
  tegra_xudc_powerdomain_init() (bsc#1012628).
- usbip: vudc: Don't enable IRQs prematurely (bsc#1012628).
- usb: host: ohci-at91: add support to enter suspend using SMC
  (bsc#1012628).
- usb: xhci: tegra: Fix error check (bsc#1012628).
- dmaengine: dw: dmamux: Export the module device table
  (bsc#1012628).
- dmaengine: dw: dmamux: Fix build without CONFIG_OF
  (bsc#1012628).
- netfilter: xtables: Bring SPDX identifier back (bsc#1012628).
- scsi: qla2xxx: edif: Send LOGO for unexpected IKE message
  (bsc#1012628).
- scsi: qla2xxx: edif: Reduce disruption due to multiple app start
  (bsc#1012628).
- scsi: qla2xxx: edif: Fix no login after app start (bsc#1012628).
- scsi: qla2xxx: edif: Tear down session if keys have been removed
  (bsc#1012628).
- scsi: qla2xxx: edif: Fix session thrash (bsc#1012628).
- scsi: qla2xxx: edif: Fix no logout on delete for N2N
  (bsc#1012628).
- scsi: qla2xxx: edif: Reduce N2N thrashing at app_start time
  (bsc#1012628).
- iio: accel: bma400: Fix the scale min and max macro values
  (bsc#1012628).
- platform/chrome: cros_ec: Always expose last resume result
  (bsc#1012628).
- iio: sx9324: Fix register field spelling (bsc#1012628).
- iio: accel: bma400: Reordering of header files (bsc#1012628).
- iio: accel: bma400: conversion to device-managed function
  (bsc#1012628).
- iio: accel: bma400: Add triggered buffer support (bsc#1012628).
- iio: core: Fix IIO_ALIGN and rename as it was not sufficiently
  large (bsc#1012628).
- iio: accel: adxl313: Fix alignment for DMA safety (bsc#1012628).
- iio: accel: adxl355: Fix alignment for DMA safety (bsc#1012628).
- iio: accel: adxl367: Fix alignment for DMA safety (bsc#1012628).
- iio: accel: bma220: Fix alignment for DMA safety (bsc#1012628).
- iio: accel: sca3000: Fix alignment for DMA safety (bsc#1012628).
- iio: accel: sca3300: Fix alignment for DMA safety (bsc#1012628).
- iio: adc: ad7266: Fix alignment for DMA safety (bsc#1012628).
- iio: adc: ad7280a: Fix alignment for DMA safety (bsc#1012628).
- iio: adc: ad7292: Fix alignment for DMA safety (bsc#1012628).
- iio: adc: ad7298: Fix alignment for DMA safety (bsc#1012628).
- iio: adc: ad7476: Fix alignment for DMA safety (bsc#1012628).
- iio: adc: ad7606: Fix alignment for DMA safety (bsc#1012628).
- iio: adc: ad7766: Fix alignment for DMA safety (bsc#1012628).
- iio: adc: ad7768-1: Fix alignment for DMA safety (bsc#1012628).
- iio: adc: ad7887: Fix alignment for DMA safety (bsc#1012628).
- iio: adc: ad7923: Fix alignment for DMA safety (bsc#1012628).
- iio: adc: ad7949: Fix alignment for DMA safety (bsc#1012628).
- iio: adc: hi8435: Fix alignment for DMA safety (bsc#1012628).
- iio: adc: ltc2496: Fix alignment for DMA safety (bsc#1012628).
- iio: adc: ltc2497: Fix alignment for DMA safety (bsc#1012628).
- iio: adc: max1027: Fix alignment for DMA safety (bsc#1012628).
- iio: adc: max11100: Fix alignment for DMA safety (bsc#1012628).
- iio: adc: max1118: Fix alignment for DMA safety (bsc#1012628).
- iio: adc: max1241: Fix alignment for DMA safety (bsc#1012628).
- iio: adc: mcp320x: Fix alignment for DMA safety (bsc#1012628).
- iio: adc: ti-adc0832: Fix alignment for DMA safety
  (bsc#1012628).
- iio: adc: ti-adc084s021: Fix alignment for DMA safety
  (bsc#1012628).
- iio: adc: ti-adc108s102: Fix alignment for DMA safety
  (bsc#1012628).
- iio: adc: ti-adc12138: Fix alignment for DMA safety
  (bsc#1012628).
- iio: adc: ti-adc128s052: Fix alignment for DMA safety
  (bsc#1012628).
- iio: adc: ti-adc161s626: Fix alignment for DMA safety
  (bsc#1012628).
- iio: adc: ti-ads124s08: Fix alignment for DMA safety
  (bsc#1012628).
- iio: adc: ti-ads131e08: Fix alignment for DMA safety
  (bsc#1012628).
- iio: adc: ti-ads7950: Fix alignment for DMA safety
  (bsc#1012628).
- iio: adc: ti-ads8344: Fix alignment for DMA safety
  (bsc#1012628).
- iio: adc: ti-ads8688: Fix alignment for DMA safety
  (bsc#1012628).
- iio: adc: ti-tlc4541: Fix alignment for DMA safety
  (bsc#1012628).
- iio: addac: ad74413r: Fix alignment for DMA safety
  (bsc#1012628).
- iio: amplifiers: ad8366: Fix alignment for DMA safety
  (bsc#1012628).
- iio: common: ssp: Fix alignment for DMA safety (bsc#1012628).
- iio: dac: ad5064: Fix alignment for DMA safety (bsc#1012628).
- iio: dac: ad5360: Fix alignment for DMA safety (bsc#1012628).
- iio: dac: ad5421: Fix alignment for DMA safety (bsc#1012628).
- iio: dac: ad5449: Fix alignment for DMA safety (bsc#1012628).
- iio: dac: ad5504: Fix alignment for DMA safety (bsc#1012628).
- iio: dac: ad5592r: Fix alignment for DMA safety (bsc#1012628).
- iio: dac: ad5686: Fix alignment for DMA safety (bsc#1012628).
- iio: dac: ad5755: Fix alignment for DMA safety (bsc#1012628).
- iio: dac: ad5761: Fix alignment for DMA safety (bsc#1012628).
- iio: dac: ad5764: Fix alignment for DMA safety (bsc#1012628).
- iio: dac: ad5766: Fix alignment for DMA safety (bsc#1012628).
- iio: dac: ad5770r: Fix alignment for DMA safety (bsc#1012628).
- iio: dac: ad5791: Fix alignment for DMA saftey (bsc#1012628).
- iio: dac: ad7293: Fix alignment for DMA safety (bsc#1012628).
- iio: dac: ad7303: Fix alignment for DMA safety (bsc#1012628).
- iio: dac: ad8801: Fix alignment for DMA safety (bsc#1012628).
- iio: dac: ltc2688: Fix alignment for DMA safety (bsc#1012628).
- iio: dac: mcp4922: Fix alignment for DMA safety (bsc#1012628).
- iio: dac: ti-dac082s085: Fix alignment for DMA safety
  (bsc#1012628).
- iio: dac: ti-dac5571: Fix alignment for DMA safety
  (bsc#1012628).
- iio: dac: ti-dac7311: Fix alignment for DMA safety
  (bsc#1012628).
- iio: dac: ti-dac7612: Fix alignment for DMA safety
  (bsc#1012628).
- iio: frequency: ad9523: Fix alignment for DMA safety
  (bsc#1012628).
- iio: frequency: adf4350: Fix alignment for DMA safety
  (bsc#1012628).
- iio: frequency: adf4371: Fix alignment for DMA safety
  (bsc#1012628).
- iio: frequency: admv1013: Fix alignment for DMA safety
  (bsc#1012628).
- iio: frequency: admv1014: Fix alignment for DMA safety
  (bsc#1012628).
- iio: frequency: admv4420: Fix alignment for DMA safety
  (bsc#1012628).
- iio: frequency: adrf6780: Fix alignment for DMA safety
  (bsc#1012628).
- iio: gyro: adis16080: Fix alignment for DMA safety
  (bsc#1012628).
- iio: gyro: adis16130: Fix alignment for DMA safety
  (bsc#1012628).
- iio: gyro: adxrs450: Fix alignment for DMA safety (bsc#1012628).
- iio: gyro: fxas210002c: Fix alignment for DMA safety
  (bsc#1012628).
- iio: imu: fxos8700: Fix alignment for DMA safety (bsc#1012628).
- iio: imu: inv_icm42600: Fix alignment for DMA safety
  (bsc#1012628).
- iio: imu: inv_icm42600: Fix alignment for DMA safety in buffer
  code (bsc#1012628).
- iio: imu: mpu6050: Fix alignment for DMA safety (bsc#1012628).
- iio: potentiometer: ad5110: Fix alignment for DMA safety
  (bsc#1012628).
- iio: potentiometer: ad5272: Fix alignment for DMA safety
  (bsc#1012628).
- iio: potentiometer: max5481: Fix alignment for DMA safety
  (bsc#1012628).
- iio: potentiometer: mcp41010: Fix alignment for DMA safety
  (bsc#1012628).
- iio: potentiometer: mcp4131: Fix alignment for DMA safety
  (bsc#1012628).
- iio: proximity: as3935: Fix alignment for DMA safety
  (bsc#1012628).
- iio: resolver: ad2s1200: Fix alignment for DMA safety
  (bsc#1012628).
- iio: resolver: ad2s90: Fix alignment for DMA safety
  (bsc#1012628).
- iio: temp: ltc2983: Fix alignment for DMA safety (bsc#1012628).
- iio: temp: max31865: Fix alignment for DMA safety (bsc#1012628).
- iio: temp: maxim_thermocouple: Fix alignment for DMA safety
  (bsc#1012628).
- clk: mediatek: reset: Fix written reset bit offset
  (bsc#1012628).
- clk: imx93: use adc_root as the parent clock of adc1
  (bsc#1012628).
- clk: imx93: correct nic_media parent (bsc#1012628).
- clk: imx: clk-fracn-gppll: fix mfd value (bsc#1012628).
- clk: imx: clk-fracn-gppll: Return rate in rate table properly
  in ->recalc_rate() (bsc#1012628).
- clk: imx: clk-fracn-gppll: correct rdiv (bsc#1012628).
- RDMA/rxe: fix xa_alloc_cycle() error return value check again
  (bsc#1012628).
- lib/test_hmm: avoid accessing uninitialized pages (bsc#1012628).
- mm/memremap: fix memunmap_pages() race with get_dev_pagemap()
  (bsc#1012628).
- KVM: Don't set Accessed/Dirty bits for ZERO_PAGE (bsc#1012628).
- KVM: selftests: Convert s390x/diag318_test_handler away from
  VCPU_ID (bsc#1012628).
- KVM: selftests: Use vm_create_with_vcpus() in
  max_guest_memory_test (bsc#1012628).
- devcoredump: remove the useless gfp_t parameter in dev_coredumpv
  and dev_coredumpm (bsc#1012628).
- mwifiex: fix sleep in atomic context bugs caused by
  dev_coredumpv (bsc#1012628).
- scsi: iscsi: Allow iscsi_if_stop_conn() to be called from kernel
  (bsc#1012628).
- scsi: iscsi: Add helper to remove a session from the kernel
  (bsc#1012628).
- scsi: iscsi: Fix session removal on shutdown (bsc#1012628).
- dmaengine: dw-edma: Fix eDMA Rd/Wr-channels and DMA-direction
  semantics (bsc#1012628).
- KVM: x86: Fix errant brace in KVM capability handling
  (bsc#1012628).
- mtd: hyperbus: rpc-if: Fix RPM imbalance in probe error path
  (bsc#1012628).
- mtd: dataflash: Add SPI ID table (bsc#1012628).
- clk: qcom: camcc-sm8250: Fix halt on boot by reducing driver's
  init level (bsc#1012628).
- misc: rtsx: Fix an error handling path in rtsx_pci_probe()
  (bsc#1012628).
- driver core: fix potential deadlock in __driver_attach
  (bsc#1012628).
- clk: qcom: clk-krait: unlock spin after mux completion
  (bsc#1012628).
- coresight: configfs: Fix unload of configurations on module exit
  (bsc#1012628).
- coresight: syscfg: Update load and unload operations
  (bsc#1012628).
- usb: gadget: f_mass_storage: Make CD-ROM emulation works with
  Windows OS (bsc#1012628).
- clk: qcom: gcc-msm8939: Add missing SYSTEM_MM_NOC_BFDCD_CLK_SRC
  (bsc#1012628).
- clk: qcom: gcc-msm8939: Fix bimc_ddr_clk_src rcgr base address
  (bsc#1012628).
- clk: qcom: gcc-msm8939: Add missing system_mm_noc_bfdcd_clk_src
  (bsc#1012628).
- clk: qcom: gcc-msm8939: Point MM peripherals to system_mm_noc
  clock (bsc#1012628).
- usb: host: xhci: use snprintf() in xhci_decode_trb()
  (bsc#1012628).
- RDMA/rxe: Add a responder state for atomic reply (bsc#1012628).
- RDMA/rxe: Fix deadlock in rxe_do_local_ops() (bsc#1012628).
- clk: qcom: ipq8074: fix NSS core PLL-s (bsc#1012628).
- clk: qcom: ipq8074: SW workaround for UBI32 PLL lock
  (bsc#1012628).
- clk: qcom: ipq8074: fix NSS port frequency tables (bsc#1012628).
- clk: qcom: ipq8074: set BRANCH_HALT_DELAY flag for UBI clocks
  (bsc#1012628).
- clk: qcom: camcc-sdm845: Fix topology around titan_top power
  domain (bsc#1012628).
- clk: qcom: camcc-sm8250: Fix topology around titan_top power
  domain (bsc#1012628).
- clk: qcom: clk-rcg2: Fail Duty-Cycle configuration if MND
  divider is not enabled (bsc#1012628).
- clk: qcom: clk-rcg2: Make sure to not write d=0 to the NMD
  register (bsc#1012628).
- kernfs: fix potential NULL dereference in __kernfs_remove
  (bsc#1012628).
- mm: rmap: use the correct parameter name for
  DEFINE_PAGE_VMA_WALK (bsc#1012628).
- mm/migration: return errno when isolate_huge_page failed
  (bsc#1012628).
- mm/migration: fix potential pte_unmap on an not mapped pte
  (bsc#1012628).
- mm: introduce clear_highpage_kasan_tagged (bsc#1012628).
- kasan: fix zeroing vmalloc memory with HW_TAGS (bsc#1012628).
- mm/mempolicy: fix get_nodes out of bound access (bsc#1012628).
- phy: ti: tusb1210: Don't check for write errors when powering on
  (bsc#1012628).
- phy: rockchip-inno-usb2: Sync initial otg state (bsc#1012628).
- PCI: dwc: Stop link on host_init errors and de-initialization
  (bsc#1012628).
- PCI: dwc: Add unroll iATU space support to dw_pcie_disable_atu()
  (bsc#1012628).
- PCI: dwc: Disable outbound windows only for controllers using
  iATU (bsc#1012628).
- PCI: dwc: Set INCREASE_REGION_SIZE flag based on limit address
  (bsc#1012628).
- PCI: dwc: Deallocate EPC memory on dw_pcie_ep_init() errors
  (bsc#1012628).
- PCI: dwc: Always enable CDM check if "snps,enable-cdm-check"
  exists (bsc#1012628).
- soundwire: bus_type: fix remove and shutdown support
  (bsc#1012628).
- soundwire: revisit driver bind/unbind and callbacks
  (bsc#1012628).
- KVM: arm64: Don't return from void function (bsc#1012628).
- dmaengine: sf-pdma: Add multithread support for a DMA channel
  (bsc#1012628).
- PCI: endpoint: Don't stop controller when unbinding endpoint
  function (bsc#1012628).
- phy: qcom-qmp: fix the QSERDES_V5_COM_CMN_MODE register
  (bsc#1012628).
- scsi: qla2xxx: Check correct variable in qla24xx_async_gffid()
  (bsc#1012628).
- scsi: lpfc: Revert RSCN_MEMENTO workaround for misbehaved
  configuration (bsc#1012628).
- intel_th: Fix a resource leak in an error handling path
  (bsc#1012628).
- intel_th: msu-sink: Potential dereference of null pointer
  (bsc#1012628).
- intel_th: msu: Fix vmalloced buffers (bsc#1012628).
- binder: fix redefinition of seq_file attributes (bsc#1012628).
- staging: rtl8192u: Fix sleep in atomic context bug in
  dm_fsync_timer_callback (bsc#1012628).
- rtla/utils: Use calloc and check the potential memory allocation
  failure (bsc#1012628).
- habanalabs: fix double unlock on error in map_device_va()
  (bsc#1012628).
- dt-bindings: mmc: sdhci-msm: Fix issues in yaml bindings
  (bsc#1012628).
- mmc: sdhci-of-esdhc: Fix refcount leak in
  esdhc_signal_voltage_switch (bsc#1012628).
- mmc: mxcmmc: Silence a clang warning (bsc#1012628).
- mmc: renesas_sdhi: Get the reset handle early in the probe
  (bsc#1012628).
- memstick/ms_block: Fix some incorrect memory allocation
  (bsc#1012628).
- memstick/ms_block: Fix a memory leak (bsc#1012628).
- mmc: sdhci-of-at91: fix set_uhs_signaling rewriting of MC1R
  (bsc#1012628).
- of: device: Fix missing of_node_put() in
  of_dma_set_restricted_buffer (bsc#1012628).
- mmc: block: Add single read for 4k sector cards (bsc#1012628).
- KVM: s390: pv: leak the topmost page table when destroy fails
  (bsc#1012628).
- PCI/portdrv: Don't disable AER reporting in
  get_port_device_capability() (bsc#1012628).
- PCI: qcom: Set up rev 2.1.0 PARF_PHY before enabling clocks
  (bsc#1012628).
- scsi: smartpqi: Fix DMA direction for RAID requests
  (bsc#1012628).
- xtensa: iss/network: provide release() callback (bsc#1012628).
- xtensa: iss: fix handling error cases in iss_net_configure()
  (bsc#1012628).
- usb: gadget: udc: amd5536 depends on HAS_DMA (bsc#1012628).
- usb: aspeed-vhub: Fix refcount leak bug in ast_vhub_init_desc()
  (bsc#1012628).
- usb: dwc3: core: Deprecate GCTL.CORESOFTRESET (bsc#1012628).
- usb: dwc3: core: Do not perform GCTL_CORE_SOFTRESET during
  bootup (bsc#1012628).
- usb: dwc3: qcom: fix missing optional irq warnings
  (bsc#1012628).
- eeprom: idt_89hpesx: uninitialized data in idt_dbgfs_csr_write()
  (bsc#1012628).
- phy: stm32: fix error return in stm32_usbphyc_phy_init
  (bsc#1012628).
- phy: rockchip-inno-usb2: Ignore OTG IRQs in host mode
  (bsc#1012628).
- interconnect: imx: fix max_node_id (bsc#1012628).
- KVM: arm64: Fix hypervisor address symbolization (bsc#1012628).
- um: random: Don't initialise hwrng struct with zero
  (bsc#1012628).
- mm: percpu: use kmemleak_ignore_phys() instead of
  kmemleak_free() (bsc#1012628).
- RDMA/irdma: Fix a window for use-after-free (bsc#1012628).
- RDMA/irdma: Fix VLAN connection with wildcard address
  (bsc#1012628).
- RDMA/irdma: Fix setting of QP context err_rq_idx_valid field
  (bsc#1012628).
- RDMA/rtrs-srv: Fix modinfo output for stringify (bsc#1012628).
- RDMA/rtrs-clt: Replace list_next_or_null_rr_rcu with an inline
  function (bsc#1012628).
- RDMA/qedr: Fix potential memory leak in __qedr_alloc_mr()
  (bsc#1012628).
- RDMA/hns: Fix incorrect clearing of interrupt status register
  (bsc#1012628).
- RDMA/siw: Fix duplicated reported IW_CM_EVENT_CONNECT_REPLY
  event (bsc#1012628).
- RDMA/rxe: Fix BUG: KASAN: null-ptr-deref in rxe_qp_do_cleanup
  (bsc#1012628).
- iio: cros: Register FIFO callback after sensor is registered
  (bsc#1012628).
- clk: qcom: Drop mmcx gdsc supply for dispcc and videocc
  (bsc#1012628).
- clk: qcom: gdsc: Bump parent usage count when GDSC is found
  enabled (bsc#1012628).
- clk: qcom: gcc-msm8939: Fix weird field spacing in
  ftbl_gcc_camss_cci_clk (bsc#1012628).
- RDMA/hfi1: fix potential memory leak in setup_base_ctxt()
  (bsc#1012628).
- gpio: gpiolib-of: Fix refcount bugs in of_mm_gpiochip_add_data()
  (bsc#1012628).
- iio: adc: max1027: unlock on error path in
  max1027_read_single_value() (bsc#1012628).
- HID: mcp2221: prevent a buffer overflow in mcp_smbus_write()
  (bsc#1012628).
- HID: amd_sfh: Add NULL check for hid device (bsc#1012628).
- dmaengine: imx-dma: Cast of_device_get_match_data() with
  (uintptr_t) (bsc#1012628).
- scripts/gdb: fix 'lx-dmesg' on 32 bits arch (bsc#1012628).
- RDMA/rxe: Fix mw bind to allow any consumer key portion
  (bsc#1012628).
- mmc: core: quirks: Add of_node_put() when breaking out of loop
  (bsc#1012628).
- mmc: cavium-octeon: Add of_node_put() when breaking out of loop
  (bsc#1012628).
- mmc: cavium-thunderx: Add of_node_put() when breaking out of
  loop (bsc#1012628).
- HID: alps: Declare U1_UNICORN_LEGACY support (bsc#1012628).
- RDMA/rxe: For invalidate compare according to set keys in mr
  (bsc#1012628).
- RDMA/rxe: Fix rnr retry behavior (bsc#1012628).
- PCI: tegra194: Fix Root Port interrupt handling (bsc#1012628).
- PCI: tegra194: Fix link up retry sequence (bsc#1012628).
- HID: amd_sfh: Handle condition of "no sensors" (bsc#1012628).
- USB: serial: fix tty-port initialized comments (bsc#1012628).
- usb: xhci_plat_remove: avoid NULL dereference (bsc#1012628).
- usb: cdns3: change place of 'priv_ep' assignment in
  cdns3_gadget_ep_dequeue(), cdns3_gadget_ep_enable()
  (bsc#1012628).
- mtd: spi-nor: fix spi_nor_spimem_setup_op() call in
  spi_nor_erase_{sector,chip}() (bsc#1012628).
- staging: fbtft: core: set smem_len before fb_deferred_io_init
  call (bsc#1012628).
- KVM: nVMX: Set UMIP bit CR4_FIXED1 MSR when emulating UMIP
  (bsc#1012628).
- tools/power/x86/intel-speed-select: Fix off by one check
  (bsc#1012628).
- platform/x86: pmc_atom: Match all Lex BayTrail boards with
  critclk_systems DMI table (bsc#1012628).
- platform/mellanox: mlxreg-lc: Fix error flow and extend
  verbosity (bsc#1012628).
- platform/olpc: Fix uninitialized data in debugfs write
  (bsc#1012628).
- RDMA/srpt: Duplicate port name members (bsc#1012628).
- RDMA/srpt: Introduce a reference count in struct srpt_device
  (bsc#1012628).
- RDMA/srpt: Fix a use-after-free (bsc#1012628).
- android: binder: stop saving a pointer to the VMA (bsc#1012628).
- mm/mmap.c: fix missing call to vm_unacct_memory in mmap_region
  (bsc#1012628).
- selftests/vm: fix errno handling in mrelease_test (bsc#1012628).
- tools/testing/selftests/vm/hugetlb-madvise.c: silence
  uninitialized variable warning (bsc#1012628).
- selftest/vm: uninitialized variable in main() (bsc#1012628).
- rtla: Fix Makefile when called from -C tools/ (bsc#1012628).
- rtla: Fix double free (bsc#1012628).
- virtio: replace restricted mem access flag with callback
  (bsc#1012628).
- xen: don't require virtio with grants for non-PV guests
  (bsc#1012628).
- selftests: kvm: set rax before vmcall (bsc#1012628).
- of/fdt: declared return type does not match actual return type
  (bsc#1012628).
- RDMA/mlx5: Add missing check for return value in get namespace
  flow (bsc#1012628).
- RDMA/rxe: Fix error unwind in rxe_create_qp() (bsc#1012628).
- block/rnbd-srv: Set keep_id to true after mutex_trylock
  (bsc#1012628).
- null_blk: fix ida error handling in null_add_dev()
  (bsc#1012628).
- nbd: add missing definition of pr_fmt (bsc#1012628).
- mtip32xx: fix device removal (bsc#1012628).
- nvme: use command_id instead of req->tag in
  trace_nvme_complete_rq() (bsc#1012628).
- nvme: define compat_ioctl again to unbreak 32-bit userspace
  (bsc#1012628).
- nvme: catch -ENODEV from nvme_revalidate_zones again
  (bsc#1012628).
- block/bio: remove duplicate append pages code (bsc#1012628).
- block: ensure iov_iter advances for added pages (bsc#1012628).
- jbd2: fix outstanding credits assert in
  jbd2_journal_commit_transaction() (bsc#1012628).
- ext4: recover csum seed of tmp_inode after migrating to extents
  (bsc#1012628).
- jbd2: fix assertion 'jh->b_frozen_data == NULL' failure when
  journal aborted (bsc#1012628).
- usb: cdns3: Don't use priv_dev uninitialized in
  cdns3_gadget_ep_enable() (bsc#1012628).
- opp: Fix error check in dev_pm_opp_attach_genpd() (bsc#1012628).
- ASoC: cros_ec_codec: Fix refcount leak in
  cros_ec_codec_platform_probe (bsc#1012628).
- ASoC: samsung: Fix error handling in aries_audio_probe
  (bsc#1012628).
- ASoC: imx-audmux: Silence a clang warning (bsc#1012628).
- ASoC: mediatek: mt8173: Fix refcount leak in
  mt8173_rt5650_rt5676_dev_probe (bsc#1012628).
- ASoC: max98390: use linux/gpio/consumer.h to fix build
  (bsc#1012628).
- ASoC: mt6797-mt6351: Fix refcount leak in
  mt6797_mt6351_dev_probe (bsc#1012628).
- ASoC: codecs: da7210: add check for i2c_add_driver
  (bsc#1012628).
- ASoC: mediatek: mt8173-rt5650: Fix refcount leak in
  mt8173_rt5650_dev_probe (bsc#1012628).
- serial: pic32: fix missing clk_disable_unprepare() on error
  in pic32_uart_startup() (bsc#1012628).
- serial: 8250: Create serial_lsr_in() (bsc#1012628).
- serial: 8250: Get preserved flags using serial_lsr_in()
  (bsc#1012628).
- serial: 8250_dw: Use serial_lsr_in() in dw8250_handle_irq()
  (bsc#1012628).
- serial: 8250_dw: Store LSR into lsr_saved_flags in
  dw8250_tx_wait_empty() (bsc#1012628).
- ASoC: SOF: make ctx_store and ctx_restore as optional
  (bsc#1012628).
- ASoC: codecs: msm8916-wcd-digital: move gains from SX_TLV to
  S8_TLV (bsc#1012628).
- ASoC: codecs: wcd9335: move gains from SX_TLV to S8_TLV
  (bsc#1012628).
- ASoC: cs35l45: Add endianness flag in snd_soc_component_driver
  (bsc#1012628).
- rpmsg: char: Add mutex protection for rpmsg_eptdev_open()
  (bsc#1012628).
- rpmsg: mtk_rpmsg: Fix circular locking dependency (bsc#1012628).
- remoteproc: k3-r5: Fix refcount leak in k3_r5_cluster_of_init
  (bsc#1012628).
- selftests/livepatch: better synchronize test_klp_callbacks_busy
  (bsc#1012628).
- profiling: fix shift too large makes kernel panic (bsc#1012628).
- remoteproc: imx_rproc: Fix refcount leak in imx_rproc_addr_init
  (bsc#1012628).
- KVM: PPC: Book3s: Fix warning about xics_rm_h_xirr_x
  (bsc#1012628).
- rpmsg: Fix possible refcount leak in
  rpmsg_register_device_override() (bsc#1012628).
- selftests/powerpc: Skip energy_scale_info test on older firmware
  (bsc#1012628).
- ASoC: samsung: h1940_uda1380: include proepr GPIO consumer
  header (bsc#1012628).
- powerpc/perf: Optimize clearing the pending PMI and remove
  WARN_ON for PMI check in power_pmu_disable (bsc#1012628).
- ASoC: soc-core.c: fixup snd_soc_of_get_dai_link_cpus()
  (bsc#1012628).
- ASoC: samsung: change gpiod_speaker_power and rx1950_audio
  from global to static variables (bsc#1012628).
- serial: 8250_dw: Take port lock while accessing LSR
  (bsc#1012628).
- ASoC: codecs: wsa881x: handle timeouts in resume path
  (bsc#1012628).
- vfio/mlx5: Protect mlx5vf_disable_fds() upon close device
  (bsc#1012628).
- vfio: Split migration ops from main device ops (bsc#1012628).
- net/ice: fix initializing the bitmap in the switch code
  (bsc#1012628).
- tty: n_gsm: fix user open not possible at responder until
  initiator open (bsc#1012628).
- tty: n_gsm: fix tty registration before control channel open
  (bsc#1012628).
- tty: n_gsm: fix wrong queuing behavior in gsm_dlci_data_output()
  (bsc#1012628).
- tty: n_gsm: fix missing timer to handle stalled links
  (bsc#1012628).
- tty: n_gsm: fix non flow control frames during mux flow off
  (bsc#1012628).
- tty: n_gsm: fix packet re-transmission without open control
  channel (bsc#1012628).
- tty: n_gsm: fix race condition in gsmld_write() (bsc#1012628).
- tty: n_gsm: fix deadlock and link starvation in outgoing data
  path (bsc#1012628).
- tty: n_gsm: fix resource allocation order in gsm_activate_mux()
  (bsc#1012628).
- ASoC: qcom: Fix missing of_node_put() in
  asoc_qcom_lpass_cpu_platform_probe() (bsc#1012628).
- MIPS: Loongson64: Fix section mismatch warning (bsc#1012628).
- ASoC: imx-card: Fix DSD/PDM mclk frequency (bsc#1012628).
- remoteproc: qcom: wcnss: Fix handling of IRQs (bsc#1012628).
- vfio/ccw: Remove UUID from s390 debug log (bsc#1012628).
- vfio/ccw: Fix FSM state if mdev probe fails (bsc#1012628).
- vfio/ccw: Do not change FSM state in subchannel event
  (bsc#1012628).
- ASoC: audio-graph-card2.c: use of_property_read_u32() for rate
  (bsc#1012628).
- serial: 8250_fsl: Don't report FE, PE and OE twice
  (bsc#1012628).
- tty: n_gsm: fix wrong T1 retry count handling (bsc#1012628).
- tty: n_gsm: fix DM command (bsc#1012628).
- tty: n_gsm: fix flow control handling in tx path (bsc#1012628).
- tty: n_gsm: fix missing corner cases in gsmld_poll()
  (bsc#1012628).
- MIPS: vdso: Utilize __pa() for gic_pfn (bsc#1012628).
- ASoC: SOF: mediatek: fix mt8195 StatvectorSel wrong setting
  (bsc#1012628).
- swiotlb: fail map correctly with failed io_tlb_default_mem
  (bsc#1012628).
- lib/bitmap: fix off-by-one in bitmap_to_arr64() (bsc#1012628).
- ASoC: SOF: ipc3-topology: Prevent double freeing of
  ipc_control_data via load_bytes (bsc#1012628).
- cpufreq: mediatek: fix error return code in
  mtk_cpu_dvfs_info_init() (bsc#1012628).
- ASoc: audio-graph-card2: Fix refcount leak bug in
  __graph_get_type() (bsc#1012628).
- ASoC: mt6359: Fix refcount leak bug (bsc#1012628).
- ASoC: SOF: ipc-msg-injector: fix copy in
  sof_msg_inject_ipc4_dfs_write() (bsc#1012628).
- serial: 8250_bcm7271: Save/restore RTS in suspend/resume
  (bsc#1012628).
- iommu/exynos: Handle failed IOMMU device registration properly
  (bsc#1012628).
- 9p: Drop kref usage (bsc#1012628).
- 9p: Add client parameter to p9_req_put() (bsc#1012628).
- net: 9p: fix refcount leak in p9_read_work() error handling
  (bsc#1012628).
- MIPS: Fixed __debug_virt_addr_valid() (bsc#1012628).
- rpmsg: qcom_smd: Fix refcount leak in qcom_smd_parse_edge
  (bsc#1012628).
- leds: pwm-multicolor: Don't show -EPROBE_DEFER as errors
  (bsc#1012628).
- kfifo: fix kfifo_to_user() return type (bsc#1012628).
- lib/smp_processor_id: fix imbalanced instrumentation_end()
  call (bsc#1012628).
- proc: fix a dentry lock race between release_task and lookup
  (bsc#1012628).
- remoteproc: qcom: pas: Check if coredump is enabled
  (bsc#1012628).
- remoteproc: sysmon: Wait for SSCTL service to come up
  (bsc#1012628).
- mfd: t7l66xb: Drop platform disable callback (bsc#1012628).
- mfd: max77620: Fix refcount leak in max77620_initialise_fps
  (bsc#1012628).
- ASoC: amd: yc: Decrease level of error message (bsc#1012628).
- iommu/arm-smmu: qcom_iommu: Add of_node_put() when breaking
  out of loop (bsc#1012628).
- perf tools: Fix dso_id inode generation comparison
  (bsc#1012628).
- riscv: spinwait: Fix hartid variable type (bsc#1012628).
- s390/crash: fix incorrect number of bytes to copy to user space
  (bsc#1012628).
- s390/zcore: fix race when reading from hardware system area
  (bsc#1012628).
- perf test: Fix test case 83 ('perf stat CSV output linter')
  on s390 (bsc#1012628).
- ASoC: fsl_asrc: force cast the asrc_format type (bsc#1012628).
- ASoC: fsl-asoc-card: force cast the asrc_format type
  (bsc#1012628).
- ASoC: fsl_easrc: use snd_pcm_format_t type for sample_format
  (bsc#1012628).
- ASoC: imx-card: use snd_pcm_format_t type for asrc_format
  (bsc#1012628).
- ASoC: qcom: q6dsp: Fix an off-by-one in q6adm_alloc_copp()
  (bsc#1012628).
- fuse: Remove the control interface for virtio-fs (bsc#1012628).
- ASoC: audio-graph-card: Add of_node_put() in fail path
  (bsc#1012628).
- ASoC: audio-graph-card2: Add of_node_put() in fail path
  (bsc#1012628).
- watchdog: f71808e_wdt: Add check for platform_driver_register
  (bsc#1012628).
- watchdog: sp5100_tco: Fix a memory leak of EFCH MMIO resource
  (bsc#1012628).
- watchdog: armada_37xx_wdt: check the return value of
  devm_ioremap() in armada_37xx_wdt_probe() (bsc#1012628).
- ASoC: Intel: sof_rt5682: Perform quirk check first in card
  late probe (bsc#1012628).
- video: fbdev: amba-clcd: Fix refcount leak bugs (bsc#1012628).
- video: fbdev: sis: fix typos in SiS_GetModeID() (bsc#1012628).
- ASoC: mchp-spdifrx: disable end of block interrupt on failures
  (bsc#1012628).
- powerpc/32: Call mmu_mark_initmem_nx() regardless of data
  block mapping (bsc#1012628).
- powerpc/32s: Fix boot failure with KASAN + SMP +
  JUMP_LABEL_FEATURE_CHECK_DEBUG (bsc#1012628).
- powerpc/32: Do not allow selection of e5500 or e6500 CPUs on
  PPC32 (bsc#1012628).
- video: fbdev: offb: Include missing linux/platform_device.h
  (bsc#1012628).
- pseries/iommu/ddw: Fix kdump to work in absence of
  ibm,dma-window (bsc#1012628).
- powerpc/iommu: Fix iommu_table_in_use for a small default DMA
  window case (bsc#1012628).
- powerpc/pci: Prefer PCI domain assignment via DT
  'linux,pci-domain' and alias (bsc#1012628).
- selftests/powerpc: Fix matrix multiply assist test
  (bsc#1012628).
- serial: 8250_bcm2835aux: Add missing clk_disable_unprepare()
  (bsc#1012628).
- tty: serial: qcom-geni-serial: Fix get_clk_div_rate() which
  otherwise could return a sub-optimal clock rate (bsc#1012628).
- tty: serial: fsl_lpuart: correct the count of break characters
  (bsc#1012628).
- s390/smp: enforce lowcore protection on CPU restart
  (bsc#1012628).
- perf stat: Revert "perf stat: Add default hybrid events"
  (bsc#1012628).
- f2fs: fix to invalidate META_MAPPING before DIO write
  (bsc#1012628).
- f2fs: fix to check inline_data during compressed inode
  conversion (bsc#1012628).
- f2fs: fix to remove F2FS_COMPR_FL and tag F2FS_NOCOMP_FL at
  the same time (bsc#1012628).
- cifs: Fix memory leak when using fscache (bsc#1012628).
- powerpc/spufs: Fix refcount leak in spufs_init_isolated_loader
  (bsc#1012628).
- powerpc/xive: Fix refcount leak in xive_get_max_prio
  (bsc#1012628).
- powerpc/cell/axon_msi: Fix refcount leak in
  setup_msi_msg_address (bsc#1012628).
- perf symbol: Fail to read phdr workaround (bsc#1012628).
- kprobes: Forbid probing on trampoline and BPF code areas
  (bsc#1012628).
- x86/bus_lock: Don't assume the init value of
  DEBUGCTLMSR.BUS_LOCK_DETECT to be zero (bsc#1012628).
- powerpc/pci: Fix PHB numbering when using opal-phbid
  (bsc#1012628).
- genelf: Use HAVE_LIBCRYPTO_SUPPORT, not the never defined
  HAVE_LIBCRYPTO (bsc#1012628).
- scripts/faddr2line: Fix vmlinux detection on arm64
  (bsc#1012628).
- tty: serial: qcom-geni-serial: Fix %%lu -> %%u in print statements
  (bsc#1012628).
- powerpc/64e: Fix kexec build error (bsc#1012628).
- sched, cpuset: Fix dl_cpu_busy() panic due to empty
  cs->cpus_allowed (bsc#1012628).
- x86/numa: Use cpumask_available instead of hardcoded NULL check
  (bsc#1012628).
- video: fbdev: arkfb: Fix a divide-by-zero bug in
  ark_set_pixclock() (bsc#1012628).
- tools/thermal: Fix possible path truncations (bsc#1012628).
- sched: Fix the check of nr_running at queue wakelist
  (bsc#1012628).
- sched: Remove the limitation of WF_ON_CPU on wakelist if wakee
  cpu is idle (bsc#1012628).
- sched/core: Do not requeue task on CPU excluded from cpus_mask
  (bsc#1012628).
- x86/entry: Build thunk_$(BITS) only if CONFIG_PREEMPTION=y
  (bsc#1012628).
- f2fs: do not allow to decompress files have FI_COMPRESS_RELEASED
  (bsc#1012628).
- video: fbdev: vt8623fb: Check the size of screen before
  memset_io() (bsc#1012628).
- video: fbdev: arkfb: Check the size of screen before memset_io()
  (bsc#1012628).
- video: fbdev: s3fb: Check the size of screen before memset_io()
  (bsc#1012628).
- scsi: ufs: core: Correct ufshcd_shutdown() flow (bsc#1012628).
- scsi: zfcp: Fix missing auto port scan and thus missing target
  ports (bsc#1012628).
- scsi: qla2xxx: Fix imbalance vha->vref_count (bsc#1012628).
- scsi: qla2xxx: Fix discovery issues in FC-AL topology
  (bsc#1012628).
- scsi: qla2xxx: Turn off multi-queue for 8G adapters
  (bsc#1012628).
- scsi: qla2xxx: Fix crash due to stale SRB access around I/O
  timeouts (bsc#1012628).
- scsi: qla2xxx: Fix excessive I/O error messages by default
  (bsc#1012628).
- scsi: qla2xxx: Fix erroneous mailbox timeout after PCI error
  injection (bsc#1012628).
- scsi: qla2xxx: Wind down adapter after PCIe error (bsc#1012628).
- scsi: qla2xxx: Fix losing FCP-2 targets on long port disable
  with I/Os (bsc#1012628).
- scsi: qla2xxx: Fix losing target when it reappears during delete
  (bsc#1012628).
- scsi: qla2xxx: Fix losing FCP-2 targets during port perturbation
  tests (bsc#1012628).
- cifs: fix lock length calculation (bsc#1012628).
- x86/bugs: Enable STIBP for IBPB mitigated RETBleed
  (bsc#1012628).
- ftrace/x86: Add back ftrace_expected assignment (bsc#1012628).
- x86/kprobes: Update kcb status flag after singlestepping
  (bsc#1012628).
- x86/olpc: fix 'logical not is only applied to the left hand
  side' (bsc#1012628).
- SMB3: fix lease break timeout when multiple deferred close
  handles for the same file (bsc#1012628).
- posix-cpu-timers: Cleanup CPU timers before freeing them during
  exec (bsc#1012628).
- Input: gscps2 - check return value of ioremap() in
  gscps2_probe() (bsc#1012628).
- __follow_mount_rcu(): verify that mount_lock remains unchanged
  (bsc#1012628).
- spmi: trace: fix stack-out-of-bound access in SPMI tracing
  functions (bsc#1012628).
- csky: abiv1: Fixup compile error (bsc#1012628).
- drivers/base: fix userspace break from using bin_attributes
  for cpumap and cpulist (bsc#1012628).
- drm/mediatek: Keep dsi as LP00 before dcs cmds transfer
  (bsc#1012628).
- crypto: blake2s - remove shash module (bsc#1012628).
- firmware: arm_scpi: Ensure scpi_info is not assigned if the
  probe fails (bsc#1012628).
- intel_th: pci: Add Meteor Lake-P support (bsc#1012628).
- intel_th: pci: Add Raptor Lake-S PCH support (bsc#1012628).
- intel_th: pci: Add Raptor Lake-S CPU support (bsc#1012628).
- KVM: set_msr_mce: Permit guests to ignore single-bit ECC errors
  (bsc#1012628).
- KVM: x86: Signal #GP, not -EPERM, on bad WRMSR(MCi_CTL/STATUS)
  (bsc#1012628).
- iommu/vt-d: avoid invalid memory access via
  node_online(NUMA_NO_NODE) (bsc#1012628).
- PCI/AER: Iterate over error counters instead of error strings
  (bsc#1012628).
- PCI: qcom: Power on PHY before IPQ8074 DBI register accesses
  (bsc#1012628).
- dm writecache: set a default MAX_WRITEBACK_JOBS (bsc#1012628).
- kexec_file: drop weak attribute from functions (bsc#1012628).
- kexec: clean up arch_kexec_kernel_verify_sig (bsc#1012628).
- kexec, KEYS, s390: Make use of built-in and secondary keyring
  for signature verification (bsc#1012628).
- tracing/events: Add __vstring() and __assign_vstr() helper
  macros (bsc#1012628).
- dm thin: fix use-after-free crash in
  dm_sm_register_threshold_callback (bsc#1012628).
- net/9p: Initialize the iounit field during fid creation
  (bsc#1012628).
- ARM: Marvell: Update PCIe fixup (bsc#1012628).
- timekeeping: contribute wall clock to rng on time change
  (bsc#1012628).
- locking/csd_lock: Change csdlock_debug from early_param to
  __setup (bsc#1012628).
- block: don't allow the same type rq_qos add more than once
  (bsc#1012628).
- btrfs: tree-log: make the return value for log syncing
  consistent (bsc#1012628).
- btrfs: ensure pages are unlocked on cow_file_range() failure
  (bsc#1012628).
- btrfs: fix error handling of fallback uncompress write
  (bsc#1012628).
- btrfs: reset block group chunk force if we have to wait
  (bsc#1012628).
- btrfs: properly flag filesystem with
  BTRFS_FEATURE_INCOMPAT_BIG_METADATA (bsc#1012628).
- block: add bdev_max_segments() helper (bsc#1012628).
- btrfs: zoned: revive max_zone_append_bytes (bsc#1012628).
- btrfs: replace BTRFS_MAX_EXTENT_SIZE with
  fs_info->max_extent_size (bsc#1012628).
- btrfs: convert count_max_extents() to use
  fs_info->max_extent_size (bsc#1012628).
- btrfs: let can_allocate_chunk return error (bsc#1012628).
- btrfs: zoned: finish least available block group on data bg
  allocation (bsc#1012628).
- btrfs: zoned: disable metadata overcommit for zoned
  (bsc#1012628).
- btrfs: store chunk size in space-info struct (bsc#1012628).
- btrfs: zoned: introduce space_info->active_total_bytes
  (bsc#1012628).
- btrfs: zoned: activate metadata block group on flush_space
  (bsc#1012628).
- btrfs: zoned: activate necessary block group (bsc#1012628).
- btrfs: zoned: write out partially allocated region
  (bsc#1012628).
- btrfs: zoned: wait until zone is finished when allocation
  didn't progress (bsc#1012628).
- btrfs: join running log transaction when logging new name
  (bsc#1012628).
- intel_idle: make SPR C1 and C1E be independent (bsc#1012628).
- ACPI: CPPC: Do not prevent CPPC from working in the future
  (bsc#1012628).
- powerpc/powernv/kvm: Use darn for H_RANDOM on Power9
  (bsc#1012628).
- s390/unwind: fix fgraph return address recovery (bsc#1012628).
- KVM: x86/pmu: Introduce the ctrl_mask value for fixed counter
  (bsc#1012628).
- KVM: VMX: Mark all PERF_GLOBAL_(OVF)_CTRL bits reserved if
  there's no vPMU (bsc#1012628).
- KVM: x86/pmu: Ignore pmu->global_ctrl check if vPMU doesn't
  support global_ctrl (bsc#1012628).
- KVM: x86/pmu: Accept 0 for absent PMU MSRs when host-initiated
  if !enable_pmu (bsc#1012628).
- Revert "KVM: x86/pmu: Accept 0 for absent PMU MSRs when
  host-initiated if !enable_pmu" (bsc#1012628).
- KVM: VMX: Add helper to check if the guest PMU has
  PERF_GLOBAL_CTRL (bsc#1012628).
- KVM: nVMX: Attempt to load PERF_GLOBAL_CTRL on nVMX xfer iff
  it exists (bsc#1012628).
- dm raid: fix address sanitizer warning in raid_status
  (bsc#1012628).
- dm raid: fix address sanitizer warning in raid_resume
  (bsc#1012628).
- dm: fix dm-raid crash if md_handle_request() splits bio
  (bsc#1012628).
- mm/damon/reclaim: fix potential memory leak in
  damon_reclaim_init() (bsc#1012628).
- hugetlb_cgroup: fix wrong hugetlb cgroup numa stat
  (bsc#1012628).
- batman-adv: tracing: Use the new __vstring() helper
  (bsc#1012628).
- tracing: Use a struct alignof to determine trace event field
  alignment (bsc#1012628).
- ext4: fix reading leftover inlined symlinks (bsc#1012628).
- ext4: update s_overhead_clusters in the superblock during an
  on-line resize (bsc#1012628).
- ext4: fix extent status tree race in writeback error recovery
  path (bsc#1012628).
- ext4: add EXT4_INODE_HAS_XATTR_SPACE macro in xattr.h
  (bsc#1012628).
- ext4: fix use-after-free in ext4_xattr_set_entry (bsc#1012628).
- ext4: correct max_inline_xattr_value_size computing
  (bsc#1012628).
- ext4: correct the misjudgment in ext4_iget_extra_inode
  (bsc#1012628).
- ext4: fix warning in ext4_iomap_begin as race between bmap
  and write (bsc#1012628).
- Documentation: ext4: fix cell spacing of table heading on
  blockmap table (bsc#1012628).
- ext4: check if directory block is within i_size (bsc#1012628).
- ext4: make sure ext4_append() always allocates new block
  (bsc#1012628).
- ext4: remove EA inode entry from mbcache on inode eviction
  (bsc#1012628).
- ext4: unindent codeblock in ext4_xattr_block_set()
  (bsc#1012628).
- ext4: fix race when reusing xattr blocks (bsc#1012628).
- KEYS: asymmetric: enforce SM2 signature use pkey algo
  (bsc#1012628).
- tpm: eventlog: Fix section mismatch for DEBUG_SECTION_MISMATCH
  (bsc#1012628).
- tpm: Add check for Failure mode for TPM2 modules (bsc#1012628).
- xen-blkback: fix persistent grants negotiation (bsc#1012628).
- xen-blkback: Apply 'feature_persistent' parameter when connect
  (bsc#1012628).
- xen-blkfront: Apply 'feature_persistent' parameter when connect
  (bsc#1012628).
- powerpc: Fix eh field when calling lwarx on PPC32 (bsc#1012628).
- powerpc64/ftrace: Fix ftrace for clang builds (bsc#1012628).
- net_sched: cls_route: remove from list when handle is 0
  (bsc#1012628).
- Revert "drm/bridge: anx7625: Use DPI bus type" (bsc#1012628).
- tcp: fix over estimation in sk_forced_mem_schedule()
  (bsc#1012628).
- crypto: lib/blake2s - reduce stack frame usage in self test
  (bsc#1012628).
- raw: remove unused variables from raw6_icmp_error()
  (bsc#1012628).
- raw: fix a typo in raw_icmp_error() (bsc#1012628).
- Revert "mwifiex: fix sleep in atomic context bugs caused by
  dev_coredumpv" (bsc#1012628).
- Revert "devcoredump: remove the useless gfp_t parameter in
  dev_coredumpv and dev_coredumpm" (bsc#1012628).
- mptcp: refine memory scheduling (bsc#1012628).
- wifi: cfg80211: handle IBSS in channel switch (bsc#1012628).
- wifi: nl80211: hold wdev mutex for tid config (bsc#1012628).
- wifi: nl80211: relax wdev mutex check in wdev_chandef()
  (bsc#1012628).
- wifi: nl80211: acquire wdev mutex earlier in start_ap
  (bsc#1012628).
- wifi: cfg80211: remove chandef check in cfg80211_cac_event()
  (bsc#1012628).
- tracing: Use a copy of the va_list for __assign_vstr()
  (bsc#1012628).
- net: dsa: felix: fix min gate len calculation for tc when its
  first gate is closed (bsc#1012628).
- Revert "s390/smp: enforce lowcore protection on CPU restart"
  (bsc#1012628).
- powerpc/kexec: Fix build failure from uninitialised variable
  (bsc#1012628).
- io_uring: mem-account pbuf buckets (bsc#1012628).
- Bluetooth: L2CAP: Fix l2cap_global_chan_by_psm regression
  (bsc#1012628).
- ASoC: Intel: avs: Use lookup table to create modules
  (bsc#1012628).
- geneve: Use ip_tunnel_key flow flags in route lookups
  (bsc#1012628).
- vxlan: Use ip_tunnel_key flow flags in route lookups
  (bsc#1012628).
- Update config files.
- commit 6c252ef
* Tue Aug 16 2022 jslaby@suse.cz
- rpm/kernel-binary.spec.in: move vdso to a separate package (bsc#1202385)
  We do the move only on 15.5+.
- commit 9c7ade3
* Tue Aug 16 2022 jslaby@suse.cz
- rpm/kernel-binary.spec.in: simplify find for usrmerged
  The type test and print line are the same for both cases. The usrmerged
  case only ignores more, so refactor it to make it more obvious.
- commit 583c9be
* Tue Aug 16 2022 jslaby@suse.cz
- x86: link vdso and boot with -z noexecstack
  - -no-warn-rwx-segments (binutils 2.39).
- commit 4fdb301
* Tue Aug 16 2022 jslaby@suse.cz
- Makefile: link with -z noexecstack --no-warn-rwx-segments
  (binutils-2.39).
- commit 7c9d0cf
* Mon Aug 15 2022 dmueller@suse.com
- config.conf: reenable armv7hl configs
- Update config files for armv7hl (following x86_64 settings,
  compiling as module unless DEBUG or DEPRECATED)
- commit 0329b6a
* Mon Aug 15 2022 jslaby@suse.cz
- Refresh
  patches.rpmify/kbuild-dummy-tools-pretend-we-understand-__LONG_DOUB.patch.
  Update upstream status.
- commit 8711731
* Mon Aug 15 2022 dmueller@suse.com
- armv7hl: rebuilt as an overlay over default config
  generated automatically with scripts/config-diff
- commit 1d75725
* Mon Aug 15 2022 dmueller@suse.com
- armv6/v7: enable BT_VIRTIO
- commit ba8dcca
* Mon Aug 15 2022 tiwai@suse.de
- Refresh and re-apply i8042 quirk patch for ASUS ZenBook (bsc#1190256)
- commit aeed1e4
* Mon Aug 15 2022 mkubecek@suse.cz
- Update to 6.0-rc1
- eliminate 4 patches (all mainline)
  - patches.suse/0001-drm-Always-warn-if-user-defined-modes-are-not-suppor.patch
  - patches.suse/0001-drm-client-Don-t-add-new-command-line-mode.patch
  - patches.suse/0001-drm-client-Look-for-command-line-modes-first.patch
  - patches.suse/ath9k-fix-use-after-free-in-ath9k_hif_usb_rx_cb.patch
- disable
  - patches.suse/Input-i8042-Apply-probe-defer-to-more-ASUS-ZenBook-m.patch
- refresh
  - patches.suse/add-suse-supported-flag.patch
  - patches.suse/add-product-identifying-information-to-vmcoreinfo.patch
  - patches.suse/vfs-add-super_operations-get_inode_dev
  - patches.suse/Revert-zram-remove-double-compression-logic.patch
- disable ARM architectures (need config update)
- new config options
  - General setup
  - CONTEXT_TRACKING_USER_FORCE=n
  - RCU_NOCB_CPU_DEFAULT_ALL=n
  - CGROUP_FAVOR_DYNMODS=n
  - Power management and ACPI options
  - PM_USERSPACE_AUTOSLEEP=n
  - Networking support
  - NF_FLOW_TABLE_PROCFS=y
  - NET_DSA_TAG_RZN1_A5PSW=m
  - File systems
  - DLM_DEPRECATED_API=n
  - Security options
  - SECURITY_APPARMOR_INTROSPECT_POLICY=y
  - SECURITY_APPARMOR_EXPORT_BINARY=y
  - SECURITY_APPARMOR_PARANOID_LOAD=y
  - IMA_KEXEC=n
  - Cryptographic API
  - CRYPTO_FIPS_NAME="Linux Kernel Cryptographic API"
  - CRYPTO_FIPS_CUSTOM_VERSION=n
  - CRYPTO_HCTR2=m
  - CRYPTO_POLYVAL_CLMUL_NI=m
  - CRYPTO_ARIA=m
  - Kernel hacking
  - SHRINKER_DEBUG=n
  - RV=n
  - PCI support
  - PCI_EPF_VNTB=m
  - Block devices
  - BLK_DEV_UBLK=m
  - NVME Support
  - NVME_AUTH=n
  - NVME_TARGET_AUTH=n
  - Network device support
  - NET_DSA_MICROCHIP_KSZ_SPI=m
  - NET_VENDOR_WANGXUN=y
  - TXGBE=m
  - CAN_NETLINK=y
  - CAN_CAN327=m
  - CAN_ESD_USB=m
  - Sound card support
  - SND_CTL_FAST_LOOKUP=y
  - SND_CTL_INPUT_VALIDATION=n
  - SND_CTL_DEBUG=n
  - SND_SOC_AMD_ST_ES8336_MACH=m
  - SND_AMD_ASOC_REMBRANDT=m
  - SND_SOC_AMD_RPL_ACP6x=m
  - SND_SOC_INTEL_AVS_MACH_DA7219=m
  - SND_SOC_INTEL_AVS_MACH_DMIC=m
  - SND_SOC_INTEL_AVS_MACH_HDAUDIO=m
  - SND_SOC_INTEL_AVS_MACH_I2S_TEST=m
  - SND_SOC_INTEL_AVS_MACH_MAX98357A=m
  - SND_SOC_INTEL_AVS_MACH_MAX98373=m
  - SND_SOC_INTEL_AVS_MACH_NAU8825=m
  - SND_SOC_INTEL_AVS_MACH_RT274=m
  - SND_SOC_INTEL_AVS_MACH_RT286=m
  - SND_SOC_INTEL_AVS_MACH_RT298=m
  - SND_SOC_INTEL_AVS_MACH_RT5682=m
  - SND_SOC_INTEL_AVS_MACH_SSM4567=m
  - SND_SOC_SOF_METEORLAKE=m
  - SND_SOC_TAS2780=n
  - SND_SOC_WSA883X=n
  - USB support
  - UCSI_STM32G0=m
  - TYPEC_ANX7411=m
  - Microsoft Surface Platform-Specific Device Drivers
  - SURFACE_AGGREGATOR_HUB=m
  - SURFACE_AGGREGATOR_TABLET_SWITCH=m
  - Industrial I/O support
  - ENVELOPE_DETECTOR=n
  - SD_ADC_MODULATOR=n
  - VF610_ADC=n
  - Misc devices
  - TCG_TIS_I2C=m
  - SPI_MICROCHIP_CORE=m
  - PINCTRL_METEORLAKE=m
  - SENSORS_LT7182S=m
  - VIDEO_AR0521=m
  - LEDS_IS31FL319X=m
  - INFINIBAND_ERDMA=m
  - XEN_VIRTIO_FORCE_GRANT=n
  - VIDEO_STKWEBCAM=n
  - PWM_CLK=m
  - RESET_TI_TPS380X=n
  - ANDROID_BINDER_IPC=n
  - FPGA_MGR_MICROCHIP_SPI=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - VCPU_STALL_DETECTOR=m
  - DRM_PANEL_EBBG_FT8719=n
  - DRM_TI_DLPC3433=n
  - DRM_LOGICVC=n
  - DRM_IMX_LCDIF=n
  - I2C_HID_OF_ELAN=m
  - USB_ONBOARD_HUB=m
  - RTC_DRV_NCT3018Y=m
  - ppc64(le), s390x and riscv64
  - SCSI_BUSLOGIC=m
  - SCSI_FLASHPOINT=n
  - ppc64le and riscv64
  - CRYPTO_DEV_QAT_DH895xCC=m
  - CRYPTO_DEV_QAT_C3XXX=m
  - CRYPTO_DEV_QAT_C62X=m
  - CRYPTO_DEV_QAT_4XXX=m
  - CRYPTO_DEV_QAT_DH895xCCVF=m
  - CRYPTO_DEV_QAT_C3XXXVF=m
  - CRYPTO_DEV_QAT_C62XVF=m
  - ppc64 / ppc64le
  - PSERIES_PLPKS=y
  - KVM_BOOK3S_HV_P9_TIMING=n
  - KVM_BOOK3S_HV_P8_TIMING=n
  - RANDOMIZE_KSTACK_OFFSET=y
  - RANDOMIZE_KSTACK_OFFSET_DEFAULT=y
  - PSERIES_WDT=m
  - s390x
  - VFIO_PCI_ZDEV_KVM=y
  - riscv64
  - ERRATA_THEAD_CMO=y
  - NONPORTABLE=n
  - RISCV_ISA_ZICBOM=y
  - RANDOM_TRUST_CPU=y
  - I2C_MICROCHIP_CORE=m
  - SND_SOC_HDA=m
  - USB_MUSB_POLARFIRE_SOC=m
  - RTC_DRV_POLARFIRE_SOC=m
- commit c35dc38
* Fri Aug 12 2022 tiwai@suse.de
- drm/amd/display: Removing assert statements for Linux
  (bsc#1202366).
- drm/amd/display: Add SMU logging code (bsc#1202366).
- commit 9b717b4
* Fri Aug 12 2022 tiwai@suse.de
- Refresh patches.suse/iwlwifi-module-firmware-ucode-fix.patch.
  Now iwlwifi queries *-72.ucode, but again, this is non-existing version.
  Correct to the existing *-71.ucode
- commit 58a95c5
* Thu Aug 11 2022 jslaby@suse.cz
- Linux 5.19.1 (bsc#1012628).
- x86/speculation: Add LFENCE to RSB fill sequence (bsc#1012628).
- x86/speculation: Add RSB VM Exit protections (bsc#1012628).
- macintosh/adb: fix oob read in do_adb_query() function
  (bsc#1012628).
- Bluetooth: btusb: Add Realtek RTL8852C support ID 0x13D3:0x3586
  (bsc#1012628).
- Bluetooth: btusb: Add Realtek RTL8852C support ID 0x13D3:0x3587
  (bsc#1012628).
- Bluetooth: btusb: Add Realtek RTL8852C support ID 0x0CB8:0xC558
  (bsc#1012628).
- Bluetooth: btusb: Add Realtek RTL8852C support ID 0x04C5:0x1675
  (bsc#1012628).
- Bluetooth: btusb: Add Realtek RTL8852C support ID 0x04CA:0x4007
  (bsc#1012628).
- Bluetooth: btusb: Add support of IMC Networks PID 0x3568
  (bsc#1012628).
- dt-bindings: bluetooth: broadcom: Add BCM4349B1 DT binding
  (bsc#1012628).
- Bluetooth: hci_bcm: Add DT compatible for CYW55572
  (bsc#1012628).
- Bluetooth: hci_bcm: Add BCM4349B1 variant (bsc#1012628).
- Bluetooth: hci_qca: Return wakeup for qca_wakeup (bsc#1012628).
- arm64: set UXN on swapper page tables (bsc#1012628).
- ata: sata_mv: Fixes expected number of resources now IRQs are
  gone (bsc#1012628).
- crypto: arm64/poly1305 - fix a read out-of-bound (bsc#1012628).
- ACPI: APEI: Better fix to avoid spamming the console with old
  error logs (bsc#1012628).
- ACPI: video: Shortening quirk list by identifying Clevo by
  board_name only (bsc#1012628).
- ACPI: video: Force backlight native for some TongFang devices
  (bsc#1012628).
- tools/vm/slabinfo: Handle files in debugfs (bsc#1012628).
- block: fix default IO priority handling again (bsc#1012628).
- commit a5bf6c0
* Thu Aug 11 2022 jslaby@suse.cz
- mm/mprotect: fix soft-dirty check in can_change_pte_writable()
  (bsc#1202013 CVE-2022-2590).
- commit 46cb433
* Thu Aug 11 2022 jslaby@suse.cz
- Refresh
  patches.suse/Revert-zram-remove-double-compression-logic.patch.
  Update upstream status.
- commit e707d80
* Thu Aug 11 2022 jslaby@suse.cz
- mm/gup: fix FOLL_FORCE COW security issue and remove FOLL_COW
  (bsc#1202013 CVE-2022-2590).
- commit cbcf3e8
* Wed Aug 10 2022 jeffm@suse.com
- config: Disable reiserfs kernel module (bsc#1202309).
  Future access of reiserfs file systems can be done by using the FUSE
  implementation of reiserfs that ships with GRUB.
  $ grub2-mount <dev> /path/to/mountpoint
- commit db8891f
* Wed Aug 10 2022 jslaby@suse.cz
- kbuild: dummy-tools: pretend we understand __LONG_DOUBLE_128__
  (ppc config fix).
- Update config files.
  This sets PPC_LONG_DOUBLE_128 automatically and allows us to set
  DRM_AMD_SECURE_DISPLAY too. I set it to y to copy other architectures.
- commit 48dfdff
* Tue Aug  9 2022 jslaby@suse.cz
- Update config files -- set SECURITY_SELINUX_CHECKREQPROT_VALUE=0 (bsc#1202280)
- commit 6a791bc
* Tue Aug  9 2022 jslaby@suse.cz
- Revert "zram: remove double compression logic" (bsc#1202203).
- commit 9739fe2
* Tue Aug  9 2022 tiwai@suse.de
- mt76: mt7921e: fix crash in chip reset fail (bsc#1201845).
- commit 6263241
* Tue Aug  9 2022 jslaby@suse.cz
- tools bpftool: Don't display disassembler-four-args feature test
  (bsc#1202195).
- tools bpftool: Fix compilation error with new binutils
  (bsc#1202195).
- tools bpf_jit_disasm: Don't display disassembler-four-args
  feature test (bsc#1202195).
- tools bpf_jit_disasm: Fix compilation error with new binutils
  (bsc#1202195).
- tools perf: Fix compilation error with new binutils
  (bsc#1202195).
- tools include: add dis-asm-compat.h to handle version
  differences (bsc#1202195).
- tools build: Don't display disassembler-four-args feature test
  (bsc#1202195).
- tools build: Add feature test for init_disassemble_info API
  changes (bsc#1202195).
- commit fa8853d
* Tue Aug  9 2022 jslaby@suse.cz
- series.conf: remove blank line from sorted section
  It causes troubles when adding multiple patches -- the current ones are
  duplicated then.
- commit 309e362
* Sat Aug  6 2022 jslaby@suse.cz
- Update
  patches.suse/Revert-Revert-tcp-change-pingpong-threshold-to-3.patch
  (bsc#1202188).
  Add a reference and refresh.
- commit 5ea3c65
* Sat Aug  6 2022 jslaby@suse.cz
- Revert "Revert "tcp: change pingpong threshold to 3"" (eventlet
  tests fix).
- commit 8268096
* Fri Aug  5 2022 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  - patches.suse/0001-drm-Always-warn-if-user-defined-modes-are-not-suppor.patch
  - patches.suse/0001-drm-client-Don-t-add-new-command-line-mode.patch
  - patches.suse/0001-drm-client-Look-for-command-line-modes-first.patch
- update upstream references and move into sorted section:
  - patches.suse/ath9k-fix-use-after-free-in-ath9k_hif_usb_rx_cb.patch
- commit 35466a9
* Wed Aug  3 2022 msuchanek@suse.de
- Update config files (bsc#1184924).
  +RANDOM_TRUST_BOOTLOADER on arm
  This is set on all other platforms in Tumbleweed, and only on ARM in
  Leap. The ARM platform is unique in that it can have random source
  defined in EFI firmware as well as device tree, and we don't test this
  configuration in Factory because of the inverted config situation
  betwween Tumbleweed and Leap.
- commit 1275841
* Tue Aug  2 2022 msuchanek@suse.de
- Fix parsing of rpm/macros.kernel-source on SLE12 (bsc#1201019).
- commit 9816878
* Sun Jul 31 2022 mkubecek@suse.cz
- Update to 5.19 final
- refresh configs
- commit e9f89c9
* Sat Jul 30 2022 jslaby@suse.cz
- Linux 5.18.15 (bsc#1012628).
- watch-queue: remove spurious double semicolon (bsc#1012628).
- ASoC: SOF: Intel: disable IMR boot when resuming from ACPI S4
  and S5 states (bsc#1012628).
- ASoC: SOF: pm: add definitions for S4 and S5 states
  (bsc#1012628).
- ASoC: SOF: pm: add explicit behavior for ACPI S1 and S2
  (bsc#1012628).
- watchqueue: make sure to serialize 'wqueue->defunct' properly
  (bsc#1012628).
- x86/alternative: Report missing return thunk details
  (bsc#1012628).
- x86/amd: Use IBPB for firmware calls (bsc#1012628).
- exfat: use updated exfat_chain directly during renaming
  (bsc#1012628).
- exfat: fix referencing wrong parent directory information
  after renaming (bsc#1012628).
- crypto: qat - re-enable registration of algorithms
  (bsc#1012628).
- crypto: qat - add param check for DH (bsc#1012628).
- crypto: qat - add param check for RSA (bsc#1012628).
- crypto: qat - remove dma_free_coherent() for DH (bsc#1012628).
- crypto: qat - remove dma_free_coherent() for RSA (bsc#1012628).
- crypto: qat - fix memory leak in RSA (bsc#1012628).
- crypto: qat - add backlog mechanism (bsc#1012628).
- crypto: qat - refactor submission logic (bsc#1012628).
- crypto: qat - use pre-allocated buffers in datapath
  (bsc#1012628).
- crypto: qat - set to zero DH parameters before free
  (bsc#1012628).
- dlm: fix pending remove if msg allocation fails (bsc#1012628).
- clk: lan966x: Fix the lan966x clock gate register address
  (bsc#1012628).
- x86/bugs: Warn when "ibrs" mitigation is selected on Enhanced
  IBRS parts (bsc#1012628).
- perf/x86/intel/lbr: Fix unchecked MSR access error on HSW
  (bsc#1012628).
- sched/deadline: Fix BUG_ON condition for deboosted tasks
  (bsc#1012628).
- bpf: Make sure mac_header was set before using it (bsc#1012628).
- mm/mempolicy: fix uninit-value in mpol_rebind_policy()
  (bsc#1012628).
- KVM: Don't null dereference ops->destroy (bsc#1012628).
- spi: bcm2835: bcm2835_spi_handle_err(): fix NULL pointer deref
  for non DMA transfers (bsc#1012628).
- KVM: selftests: Fix target thread to be migrated in rseq_test
  (bsc#1012628).
- gpio: gpio-xilinx: Fix integer overflow (bsc#1012628).
- selftests: gpio: fix include path to kernel headers for out
  of tree builds (bsc#1012628).
- net/sched: cls_api: Fix flow action initialization
  (bsc#1012628).
- tcp: Fix data-races around sysctl_tcp_max_reordering
  (bsc#1012628).
- tcp: Fix a data-race around sysctl_tcp_abort_on_overflow
  (bsc#1012628).
- tcp: Fix a data-race around sysctl_tcp_rfc1337 (bsc#1012628).
- tcp: Fix a data-race around sysctl_tcp_stdurg (bsc#1012628).
- tcp: Fix a data-race around sysctl_tcp_retrans_collapse
  (bsc#1012628).
- tcp: Fix data-races around sysctl_tcp_slow_start_after_idle
  (bsc#1012628).
- tcp: Fix a data-race around sysctl_tcp_thin_linear_timeouts
  (bsc#1012628).
- tcp: Fix data-races around sysctl_tcp_recovery (bsc#1012628).
- tcp: Fix a data-race around sysctl_tcp_early_retrans
  (bsc#1012628).
- tcp: Fix data-races around sysctl knobs related to SYN option
  (bsc#1012628).
- udp: Fix a data-race around sysctl_udp_l3mdev_accept
  (bsc#1012628).
- ip: Fix data-races around sysctl_ip_prot_sock (bsc#1012628).
- ipv4: Fix data-races around sysctl_fib_multipath_hash_fields
  (bsc#1012628).
- ipv4: Fix data-races around sysctl_fib_multipath_hash_policy
  (bsc#1012628).
- ipv4: Fix a data-race around sysctl_fib_multipath_use_neigh
  (bsc#1012628).
- can: rcar_canfd: Add missing of_node_put() in rcar_canfd_probe()
  (bsc#1012628).
- drm/imx/dcss: Add missing of_node_put() in fail path
  (bsc#1012628).
- drm/panel-edp: Fix variable typo when saving hpd absent delay
  from DT (bsc#1012628).
- amt: do not use amt->nr_tunnels outside of lock (bsc#1012628).
- amt: drop unexpected multicast data (bsc#1012628).
- amt: drop unexpected query message (bsc#1012628).
- amt: drop unexpected advertisement message (bsc#1012628).
- amt: add missing regeneration nonce logic in request logic
  (bsc#1012628).
- amt: use READ_ONCE() in amt module (bsc#1012628).
- amt: remove unnecessary locks (bsc#1012628).
- amt: use workqueue for gateway side message handling
  (bsc#1012628).
- net: dsa: vitesse-vsc73xx: silent spi_device_id warnings
  (bsc#1012628).
- net: dsa: sja1105: silent spi_device_id warnings (bsc#1012628).
- be2net: Fix buffer overflow in be_get_module_eeprom
  (bsc#1012628).
- gpio: pca953x: use the correct register address when regcache
  sync during init (bsc#1012628).
- gpio: pca953x: use the correct range when do regmap sync
  (bsc#1012628).
- gpio: pca953x: only use single read/write for No AI mode
  (bsc#1012628).
- net: stmmac: remove redunctant disable xPCS EEE call
  (bsc#1012628).
- net: dsa: fix NULL pointer dereference in
  dsa_port_reset_vlan_filtering (bsc#1012628).
- net: dsa: move reset of VLAN filtering to
  dsa_port_switchdev_unsync_attrs (bsc#1012628).
- net: dsa: fix dsa_port_vlan_filtering when global (bsc#1012628).
- ixgbe: Add locking to prevent panic when setting sriov_numvfs
  to zero (bsc#1012628).
- i40e: Fix erroneous adapter reinitialization during recovery
  process (bsc#1012628).
- net: lan966x: Fix usage of lan966x->mac_lock when used by FDB
  (bsc#1012628).
- net: lan966x: Fix usage of lan966x->mac_lock inside
  lan966x_mac_irq_handler (bsc#1012628).
- net: lan966x: Fix usage of lan966x->mac_lock when entry is
  removed (bsc#1012628).
- net: lan966x: Fix usage of lan966x->mac_lock when entry is added
  (bsc#1012628).
- net: lan966x: Fix taking rtnl_lock while holding spin_lock
  (bsc#1012628).
- pinctrl: armada-37xx: make irq_lock a raw spinlock to avoid
  invalid wait context (bsc#1012628).
- pinctrl: armada-37xx: Reuse GPIO fwnode in
  armada_37xx_irqchip_register() (bsc#1012628).
- ACPI: CPPC: Don't require flexible address space if
  X86_FEATURE_CPPC is supported (bsc#1012628).
- iavf: Fix missing state logs (bsc#1012628).
- iavf: Fix handling of dummy receive descriptors (bsc#1012628).
- iavf: Disallow changing rx/tx-frames and rx/tx-frames-irq
  (bsc#1012628).
- iavf: Fix VLAN_V2 addition/rejection (bsc#1012628).
- tcp: Fix data-races around sysctl_tcp_fastopen_blackhole_timeout
  (bsc#1012628).
- tcp: Fix data-races around sysctl_tcp_fastopen (bsc#1012628).
- tcp: Fix data-races around sysctl_max_syn_backlog (bsc#1012628).
- tcp: Fix a data-race around sysctl_tcp_tw_reuse (bsc#1012628).
- tcp: Fix a data-race around sysctl_tcp_notsent_lowat
  (bsc#1012628).
- tcp: Fix data-races around some timeout sysctl knobs
  (bsc#1012628).
- tcp: Fix data-races around sysctl_tcp_reordering (bsc#1012628).
- tcp: Fix data-races around sysctl_tcp_migrate_req (bsc#1012628).
- tcp: Fix data-races around sysctl_tcp_syncookies (bsc#1012628).
- tcp: Fix data-races around sysctl_tcp_syn(ack)?_retries
  (bsc#1012628).
- tcp: Fix data-races around keepalive sysctl knobs (bsc#1012628).
- igmp: Fix data-races around sysctl_igmp_qrv (bsc#1012628).
- igmp: Fix data-races around sysctl_igmp_max_msf (bsc#1012628).
- igmp: Fix a data-race around sysctl_igmp_max_memberships
  (bsc#1012628).
- igmp: Fix data-races around sysctl_igmp_llm_reports
  (bsc#1012628).
- net: prestera: acl: use proper mask for port selector
  (bsc#1012628).
- net/tls: Fix race in TLS device down flow (bsc#1012628).
- net: stmmac: fix dma queue left shift overflow issue
  (bsc#1012628).
- pinctrl: ocelot: Fix pincfg (bsc#1012628).
- pinctrl: ocelot: Fix pincfg for lan966x (bsc#1012628).
- perf tests: Fix Convert perf time to TSC test for hybrid
  (bsc#1012628).
- perf tests: Stop Convert perf time to TSC test opening events
  twice (bsc#1012628).
- i2c: cadence: Change large transfer count reset logic to be
  unconditional (bsc#1012628).
- i2c: mlxcpld: Fix register setting for 400KHz frequency
  (bsc#1012628).
- tcp/udp: Make early_demux back namespacified (bsc#1012628).
- net: dsa: microchip: ksz_common: Fix refcount leak bug
  (bsc#1012628).
- net: stmmac: fix unbalanced ptp clock issue in suspend/resume
  flow (bsc#1012628).
- net: stmmac: fix pm runtime issue in stmmac_dvr_remove()
  (bsc#1012628).
- stmmac: dwmac-mediatek: fix clock issue (bsc#1012628).
- tcp: Fix a data-race around sysctl_tcp_probe_interval
  (bsc#1012628).
- tcp: Fix a data-race around sysctl_tcp_probe_threshold
  (bsc#1012628).
- tcp: Fix a data-race around sysctl_tcp_mtu_probe_floor
  (bsc#1012628).
- tcp: Fix data-races around sysctl_tcp_min_snd_mss (bsc#1012628).
- tcp: Fix data-races around sysctl_tcp_base_mss (bsc#1012628).
- tcp: Fix data-races around sysctl_tcp_mtu_probing (bsc#1012628).
- tcp: Fix data-races around sysctl_tcp_l3mdev_accept
  (bsc#1012628).
- tcp: sk->sk_bound_dev_if once in inet_request_bound_dev_if()
  (bsc#1012628).
- tcp/dccp: Fix a data-race around sysctl_tcp_fwmark_accept
  (bsc#1012628).
- ip: Fix a data-race around sysctl_fwmark_reflect (bsc#1012628).
- ip: Fix a data-race around sysctl_ip_autobind_reuse
  (bsc#1012628).
- ip: Fix data-races around sysctl_ip_nonlocal_bind (bsc#1012628).
- ip: Fix data-races around sysctl_ip_fwd_update_priority
  (bsc#1012628).
- ip: Fix data-races around sysctl_ip_fwd_use_pmtu (bsc#1012628).
- ip: Fix data-races around sysctl_ip_no_pmtu_disc (bsc#1012628).
- igc: Reinstate IGC_REMOVED logic and implement it properly
  (bsc#1012628).
- Revert "e1000e: Fix possible HW unit hang after an s0ix exit"
  (bsc#1012628).
- e1000e: Enable GPT clock before sending message to CSME
  (bsc#1012628).
- perf/core: Fix data race between perf_event_set_output()
  and perf_mmap_close() (bsc#1012628).
- pinctrl: sunplus: Add check for kcalloc (bsc#1012628).
- pinctrl: ralink: Check for null return of devm_kcalloc
  (bsc#1012628).
- pinctrl: ralink: rename pinctrl-rt2880 to pinctrl-ralink
  (bsc#1012628).
- pinctrl: ralink: rename MT7628(an) functions to MT76X8
  (bsc#1012628).
- RDMA/irdma: Fix sleep from invalid context BUG (bsc#1012628).
- RDMA/irdma: Do not advertise 1GB page size for x722
  (bsc#1012628).
- power/reset: arm-versatile: Fix refcount leak in
  versatile_reboot_probe (bsc#1012628).
- power: supply: ab8500_fg: add missing destroy_workqueue in
  ab8500_fg_probe (bsc#1012628).
- xfrm: xfrm_policy: fix a possible double xfrm_pols_put()
  in xfrm_bundle_lookup() (bsc#1012628).
- ip: Fix data-races around sysctl_ip_default_ttl (bsc#1012628).
- r8152: fix a WOL issue (bsc#1012628).
- PCI: hv: Fix interrupt mapping for multi-MSI (bsc#1012628).
- PCI: hv: Reuse existing IRTE allocation in compose_msi_msg()
  (bsc#1012628).
- PCI: hv: Fix hv_arch_irq_unmask() for multi-MSI (bsc#1012628).
- PCI: hv: Fix multi-MSI to allow more than one MSI vector
  (bsc#1012628).
- bus: mhi: host: pci_generic: add Telit FN990 (bsc#1012628).
- bus: mhi: host: pci_generic: add Telit FN980 v1 hardware
  revision (bsc#1012628).
- net: usb: ax88179_178a needs FLAG_SEND_ZLP (bsc#1012628).
- drm/scheduler: Don't kill jobs in interrupt context
  (bsc#1012628).
- drm/amd/display: Fix new dmub notification enabling in DM
  (bsc#1012628).
- drm/ttm: fix locking in vmap/vunmap TTM GEM helpers
  (bsc#1012628).
- mtd: rawnand: gpmi: Set WAIT_FOR_READY timeout based on
  program/erase times (bsc#1012628).
- mmc: sdhci-omap: Fix a lockdep warning for PM runtime init
  (bsc#1012628).
- lockdown: Fix kexec lockdown bypass with ima policy
  (bsc#1012628).
- mlxsw: spectrum_router: Fix IPv4 nexthop gateway indication
  (bsc#1012628).
- riscv: add as-options for modules with assembly compontents
  (bsc#1012628).
- pinctrl: stm32: fix optional IRQ support to gpios (bsc#1012628).
- pinctrl: armada-37xx: use raw spinlocks for regmap to avoid
  invalid wait context (bsc#1012628).
- commit 0b7935a
* Tue Jul 26 2022 mbrugger@suse.com
- armv7hl: Update config files. (bsc#1201857)
  Unify IWLWIFI debug options with other archs.
- armv7hl: Update config files. (bsc#1201857)
  Enable PCI wifi chips
- commit 0cc672e
* Mon Jul 25 2022 tzimmermann@suse.de
- config: riscv64: Enable DRM stack for early-boot graphics (boo#1201833)
  Replace fbdev's generic drivers with DRM-based simpledrm. Enables the
  DRM graphics stack for early-boot graphics, recovery and unsupported
  chipsets.
- commit b8947d7
* Mon Jul 25 2022 tzimmermann@suse.de
- config: armv7hl: Enable DRM stack for early-boot graphics (boo#1193475)
  Replace fbdev's generic drivers with DRM-based simpledrm. Enables the
  DRM graphics stack for early-boot graphics, recovery and unsupported
  chipsets.
- commit 374bc62
* Mon Jul 25 2022 tzimmermann@suse.de
- config: armv6hl: Enable DRM stack for early-boot graphics (boo#1193475)
  Replace fbdev's generic drivers with DRM-based simpledrm. Enables the
  DRM graphics stack for early-boot graphics, recovery and unsupported
  chipsets.
- commit 07f549a
* Mon Jul 25 2022 tzimmermann@suse.de
- config: arm64: Enable DRM stack for early-boot graphics (boo#1193475)
  Replace fbdev's generic drivers with DRM-based simpledrm. Enables the
  DRM graphics stack for early-boot graphics, recovery and unsupported
  chipsets.
- commit 146fbca
* Mon Jul 25 2022 mkubecek@suse.cz
- Update to 5.19-rc8
- update configs
  - PINCTRL_AMD=y (arm64 only, no longer allowed to be a module)
- commit 96ba878
* Sun Jul 24 2022 mkubecek@suse.cz
- config: update and enable armv6hl
  Config option values were taken from global 5.19 updates while armv6hl
  configs were disabled, arm64 updates in commit 14beb34d0af9 ("config:
  update and enable arm64") and armv7hl config updates in commit 36833cf30926
  ("config: update and enable armv7hl").
- commit de516ba
* Sun Jul 24 2022 mkubecek@suse.cz
- config: update and enable armv7hl
  The list below omits config options update globally while armv7hl configs
  were disabled and config options updated on arm64 for 5.19 in commit
  14beb34d0af9 ("config: update and enable arm64").
- new config options
  - ARCH_BCMBCA=y
  - ARCH_HPE=y
  - ARCH_HPE_GXP=y
  - CPU_LITTLE_ENDIAN=y
  - ARM_ERRATA_764319=y
  - GVE=m
  - PINCTRL_IMXRT1170=y
  - GXP_WATCHDOG=m
  - MEDIA_CEC_RC=y
  - COMMON_CLK_EN7523=y
- new config options in armv7hl/lpae
  - EDAC_SYNOPSYS=m
  - XILINX_INTC=y
- commit 36833cf
* Sun Jul 24 2022 mkubecek@suse.cz
- config: update and enable arm64
  The list below omits config options updated globally while arm64 configs
  were disabled.
- new config options
  - ARM64_SME=y
  - CRYPTO_SM4_ARM64_CE_BLK=m
  - CRYPTO_SM4_ARM64_NEON_BLK=m
  - CAN_CTUCANFD_PLATFORM=m
  - QCOM_SSC_BLOCK_BUS=y
  - MTK_ADSP_IPC=m
  - MTD_NAND_ECC_MEDIATEK=m
  - NVME_APPLE=m
  - VMWARE_VMCI=m
  - SPI_MTK_SNFI=m
  - PINCTRL_IMXRT1170=m
  - PINCTRL_MT6795=y
  - PINCTRL_SC7280_LPASS_LPI=m
  - PINCTRL_SM8250_LPASS_LPI=m
  - ROCKCHIP_VOP=y
  - ROCKCHIP_VOP2=y
  - DRM_MSM_MDP4=y
  - DRM_MSM_MDP5=y
  - DRM_MSM_DPU=y
  - DRM_MSM_HDMI=y
  - DRM_PANEL_NEWVISION_NV3052C=m
  - DRM_FSL_LDB=m
  - DRM_LONTIUM_LT9211=m
  - DRM_DW_HDMI_GP_AUDIO=m
  - DRM_SSD130X_SPI=m
  - SND_SERIAL_GENERIC=m
  - SND_SOC_MT8195_MT6359=m
  - SND_SOC_SOF_MT8186=m
  - SND_SOC_TEGRA186_ASRC=m
  - LEDS_QCOM_LPG=m
  - TEGRA186_GPC_DMA=m
  - COMMON_CLK_MT8186=y
  - SC_GCC_8280XP=m
  - SC_LPASS_CORECC_7280=m
  - APPLE_RTKIT=m
  - APPLE_SART=m
  - PWM_XILINX=m
  - NVMEM_APPLE_EFUSES=m
  - INTERCONNECT_QCOM_SC8280XP=m
  - INTERCONNECT_QCOM_SDX65=m
  - HTE_TEGRA194=m
  - HTE_TEGRA194_TEST=n
  - TRUSTED_KEYS_CAAM=y
  - CRYPTO_DEV_FSL_CAAM_PRNG_API=y
  - FIPS_SIGNATURE_SELFTEST=n
  - PAGE_TABLE_CHECK=y
  - PAGE_TABLE_CHECK_ENFORCED=n
  - VMWARE_VMCI_VSOCKETS=m
- commit 14beb34
* Sat Jul 23 2022 schwab@suse.de
- riscv: enable CONFIG_STRICT_DEVMEM
- new config options
  - CONFIG_EXCLUSIVE_SYSTEM_RAM=y
  - CONFIG_IO_STRICT_DEVMEM=y
- commit 2477a0c
* Sat Jul 23 2022 schwab@suse.de
- riscv: enable CONFIG_FTRACE
  - new config options
  - CONFIG_BPF_LSM=y
  - CONFIG_TASKS_RUDE_RCU=y
  - CONFIG_TRACEPOINTS=y
  - CONFIG_KPROBES_ON_FTRACE=y
  - CONFIG_UPROBES=y
  - CONFIG_BATMAN_ADV_TRACING=n
  - CONFIG_NET_DROP_MONITOR=m
  - CONFIG_ATH5K_TRACER=n
  - CONFIG_ATH6KL_TRACING=n
  - CONFIG_WIL6210_TRACING=y
  - CONFIG_ATH10K_TRACING=n
  - CONFIG_ATH11K_TRACING=n
  - CONFIG_IWLWIFI_DEVICE_TRACING=n
  - CONFIG_STM_SOURCE_FTRACE=m
  - CONFIG_PSTORE_FTRACE=n
  - CONFIG_DEBUG_PAGE_REF=n
  - CONFIG_NOP_TRACER=y
  - CONFIG_TRACER_MAX_TRACE=y
  - CONFIG_TRACE_CLOCK=y
  - CONFIG_RING_BUFFER=y
  - CONFIG_EVENT_TRACING=y
  - CONFIG_CONTEXT_SWITCH_TRACER=y
  - CONFIG_RING_BUFFER_ALLOW_SWAP=y
  - CONFIG_TRACING=y
  - CONFIG_GENERIC_TRACER=y
  - CONFIG_BOOTTIME_TRACING=y
  - CONFIG_FUNCTION_TRACER=y
  - CONFIG_FUNCTION_GRAPH_TRACER=y
  - CONFIG_DYNAMIC_FTRACE=y
  - CONFIG_DYNAMIC_FTRACE_WITH_REGS=y
  - CONFIG_FUNCTION_PROFILER=y
  - CONFIG_STACK_TRACER=y
  - CONFIG_IRQSOFF_TRACER=n
  - CONFIG_SCHED_TRACER=y
  - CONFIG_HWLAT_TRACER=n
  - CONFIG_OSNOISE_TRACER=y
  - CONFIG_TIMERLAT_TRACER=y
  - CONFIG_FTRACE_SYSCALLS=y
  - CONFIG_TRACER_SNAPSHOT=y
  - CONFIG_TRACER_SNAPSHOT_PER_CPU_SWAP=y
  - CONFIG_BRANCH_PROFILE_NONE=y
  - CONFIG_PROFILE_ANNOTATED_BRANCHES=n
  - CONFIG_BLK_DEV_IO_TRACE=y
  - CONFIG_KPROBE_EVENTS=y
  - CONFIG_KPROBE_EVENTS_ON_NOTRACE=n
  - CONFIG_UPROBE_EVENTS=y
  - CONFIG_BPF_EVENTS=y
  - CONFIG_DYNAMIC_EVENTS=y
  - CONFIG_PROBE_EVENTS=y
  - CONFIG_BPF_KPROBE_OVERRIDE=n
  - CONFIG_FTRACE_MCOUNT_RECORD=y
  - CONFIG_FTRACE_MCOUNT_USE_CC=y
  - CONFIG_SYNTH_EVENTS=y
  - CONFIG_TRACE_EVENT_INJECT=n
  - CONFIG_TRACEPOINT_BENCHMARK=n
  - CONFIG_RING_BUFFER_BENCHMARK=m
  - CONFIG_TRACE_EVAL_MAP_FILE=n
  - CONFIG_FTRACE_RECORD_RECURSION=n
  - CONFIG_FTRACE_STARTUP_TEST=n
  - CONFIG_RING_BUFFER_STARTUP_TEST=n
  - CONFIG_RING_BUFFER_VALIDATE_TIME_DELTAS=n
  - CONFIG_PREEMPTIRQ_DELAY_TEST=m
  - CONFIG_SYNTH_EVENT_GEN_TEST=n
  - CONFIG_KPROBE_EVENT_GEN_TEST=n
- commit 9875d6f
* Sat Jul 23 2022 jslaby@suse.cz
- Linux 5.18.14 (bsc#1012628).
- objtool: skip non-text sections when adding return-thunk sites
  (bsc#1012628).
- x86/speculation: Use DECLARE_PER_CPU for x86_spec_ctrl_current
  (bsc#1012628).
- efi/x86: use naked RET on mixed mode call wrapper (bsc#1012628).
- KVM: emulate: do not adjust size of fastop and setcc subroutines
  (bsc#1012628).
- tools arch x86: Sync the msr-index.h copy with the kernel
  sources (bsc#1012628).
- tools headers cpufeatures: Sync with the kernel sources
  (bsc#1012628).
- um: Add missing apply_returns() (bsc#1012628).
- commit 847b26a
* Sat Jul 23 2022 jslaby@suse.cz
- Linux 5.18.13 (bsc#1012628).
- USB: serial: ftdi_sio: add Belimo device ids (bsc#1012628).
- usb: typec: add missing uevent when partner support PD
  (bsc#1012628).
- usb: dwc3: gadget: Fix event pending check (bsc#1012628).
- gpio: sim: fix the chip_name configfs item (bsc#1012628).
- tty: serial: samsung_tty: set dma burst_size to 1 (bsc#1012628).
- x86/xen: Use clear_bss() for Xen PV guests (bsc#1012628).
- ALSA: hda - Add fixup for Dell Latitidue E5430 (bsc#1012628).
- ALSA: hda/conexant: Apply quirk for another HP ProDesk 600 G3
  model (bsc#1012628).
- ALSA: hda/realtek: Fix headset mic for Acer SF313-51
  (bsc#1012628).
- ALSA: hda/realtek - Fix headset mic problem for a HP machine
  with alc671 (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP machines
  (bsc#1012628).
- ALSA: hda/realtek - Fix headset mic problem for a HP machine
  with alc221 (bsc#1012628).
- ALSA: hda/realtek - Enable the headset-mic on a Xiaomi's laptop
  (bsc#1012628).
- xen/netback: avoid entering xenvif_rx_next_skb() with an empty
  rx queue (bsc#1012628).
- fix race between exit_itimers() and /proc/pid/timers
  (bsc#1012628).
- mm: userfaultfd: fix UFFDIO_CONTINUE on fallocated shmem pages
  (bsc#1012628).
- mm: sparsemem: fix missing higher order allocation splitting
  (bsc#1012628).
- mm: split huge PUD on wp_huge_pud fallback (bsc#1012628).
- mm/damon: use set_huge_pte_at() to make huge pte old
  (bsc#1012628).
- tracing/histograms: Fix memory leak problem (bsc#1012628).
- net: sock: tracing: Fix sock_exceed_buf_limit not to dereference
  stale pointer (bsc#1012628).
- ip: fix dflt addr selection for connected nexthop (bsc#1012628).
- ARM: 9213/1: Print message about disabled Spectre workarounds
  only once (bsc#1012628).
- ARM: 9214/1: alignment: advance IT state after emulating Thumb
  instruction (bsc#1012628).
- wifi: mac80211: fix queue selection for mesh/OCB interfaces
  (bsc#1012628).
- cgroup: Use separate src/dst nodes when preloading css_sets
  for migration (bsc#1012628).
- btrfs: return -EAGAIN for NOWAIT dio reads/writes on compressed
  and inline extents (bsc#1012628).
- btrfs: zoned: fix a leaked bioc in read_zone_info (bsc#1012628).
- drm/panfrost: Put mapping instead of shmem obj on
  panfrost_mmu_map_fault_addr() error (bsc#1012628).
- drm/panfrost: Fix shrinker list corruption by madvise IOCTL
  (bsc#1012628).
- fs/remap: constrain dedupe of EOF blocks (bsc#1012628).
- nilfs2: fix incorrect masking of permission flags for symlinks
  (bsc#1012628).
- sh: convert nommu io{re,un}map() to static inline functions
  (bsc#1012628).
- Revert "evm: Fix memleak in init_desc" (bsc#1012628).
- reset: Fix devm bulk optional exclusive control getter
  (bsc#1012628).
- arm64: dts: ls1028a: Update SFP node to include clock
  (bsc#1012628).
- ARM: dts: imx6qdl-ts7970: Fix ngpio typo and count
  (bsc#1012628).
- riscv: dts: microchip: hook up the mpfs' l2cache (bsc#1012628).
- spi: amd: Limit max transfer and message size (bsc#1012628).
- ARM: 9209/1: Spectre-BHB: avoid pr_info() every time a CPU
  comes out of idle (bsc#1012628).
- ARM: 9210/1: Mark the FDT_FIXED sections as shareable
  (bsc#1012628).
- net/mlx5e: kTLS, Fix build time constant test in TX
  (bsc#1012628).
- net/mlx5e: kTLS, Fix build time constant test in RX
  (bsc#1012628).
- net/mlx5e: Fix enabling sriov while tc nic rules are offloaded
  (bsc#1012628).
- net/mlx5e: CT: Use own workqueue instead of mlx5e priv
  (bsc#1012628).
- net/mlx5e: Fix capability check for updating vnic env counters
  (bsc#1012628).
- net/mlx5e: Ring the TX doorbell on DMA errors (bsc#1012628).
- drm/amdgpu: keep fbdev buffers pinned during suspend
  (bsc#1012628).
- drm/amdgpu/display: disable prefer_shadow for generic fb helpers
  (bsc#1012628).
- drm/i915: fix a possible refcount leak in
  intel_dp_add_mst_connector() (bsc#1012628).
- drm/i915/guc: ADL-N should use the same GuC FW as ADL-S
  (bsc#1012628).
- ima: Fix a potential integer overflow in
  ima_appraise_measurement (bsc#1012628).
- ASoC: sgtl5000: Fix noise on shutdown/remove (bsc#1012628).
- ASoC: tas2764: Add post reset delays (bsc#1012628).
- ASoC: tas2764: Fix and extend FSYNC polarity handling
  (bsc#1012628).
- ASoC: tas2764: Correct playback volume range (bsc#1012628).
- ASoC: tas2764: Fix amp gain register offset & default
  (bsc#1012628).
- ASoC: Intel: Skylake: Correct the ssp rate discovery in
  skl_get_ssp_clks() (bsc#1012628).
- ASoC: Intel: Skylake: Correct the handling of fmt_config
  flexible array (bsc#1012628).
- netfilter: ecache: move to separate structure (bsc#1012628).
- netfilter: conntrack: split inner loop of list dumping to own
  function (bsc#1012628).
- netfilter: ecache: use dedicated list for event redelivery
  (bsc#1012628).
- netfilter: conntrack: include ecache dying list in dumps
  (bsc#1012628).
- netfilter: conntrack: remove the percpu dying list
  (bsc#1012628).
- netfilter: conntrack: fix crash due to confirmed bit load
  reordering (bsc#1012628).
- net: stmmac: dwc-qos: Disable split header for Tegra194
  (bsc#1012628).
- net: ethernet: ti: am65-cpsw: Fix devlink port register sequence
  (bsc#1012628).
- net: ocelot: fix wrong time_after usage (bsc#1012628).
- sysctl: Fix data races in proc_dointvec() (bsc#1012628).
- sysctl: Fix data races in proc_douintvec() (bsc#1012628).
- sysctl: Fix data races in proc_dointvec_minmax() (bsc#1012628).
- sysctl: Fix data races in proc_douintvec_minmax() (bsc#1012628).
- sysctl: Fix data races in proc_doulongvec_minmax()
  (bsc#1012628).
- sysctl: Fix data races in proc_dointvec_jiffies() (bsc#1012628).
- tcp: Fix a data-race around sysctl_tcp_max_orphans
  (bsc#1012628).
- inetpeer: Fix data-races around sysctl (bsc#1012628).
- net: Fix data-races around sysctl_mem (bsc#1012628).
- cipso: Fix data-races around sysctl (bsc#1012628).
- icmp: Fix data-races around sysctl (bsc#1012628).
- ipv4: Fix a data-race around sysctl_fib_sync_mem (bsc#1012628).
- ARM: dts: at91: sama5d2: Fix typo in i2s1 node (bsc#1012628).
- ARM: dts: sunxi: Fix SPI NOR campatible on Orange Pi Zero
  (bsc#1012628).
- arm64: dts: broadcom: bcm4908: Fix timer node for BCM4906 SoC
  (bsc#1012628).
- arm64: dts: broadcom: bcm4908: Fix cpu node for smp boot
  (bsc#1012628).
- netfilter: nf_log: incorrect offset to network header
  (bsc#1012628).
- nfp: fix issue of skb segments exceeds descriptor limitation
  (bsc#1012628).
- vlan: fix memory leak in vlan_newlink() (bsc#1012628).
- netfilter: nf_tables: replace BUG_ON by element length check
  (bsc#1012628).
- RISC-V: KVM: Fix SRCU deadlock caused by
  kvm_riscv_check_vcpu_requests() (bsc#1012628).
- drm/i915/gvt: IS_ERR() vs NULL bug in
  intel_gvt_update_reg_whitelist() (bsc#1012628).
- xen/gntdev: Ignore failure to unmap INVALID_GRANT_HANDLE
  (bsc#1012628).
- mptcp: fix subflow traversal at disconnect time (bsc#1012628).
- NFSD: Decode NFSv4 birth time attribute (bsc#1012628).
- lockd: set fl_owner when unlocking files (bsc#1012628).
- lockd: fix nlm_close_files (bsc#1012628).
- net: marvell: prestera: fix missed deinit sequence
  (bsc#1012628).
- ice: handle E822 generic device ID in PLDM header (bsc#1012628).
- ice: change devlink code to read NVM in blocks (bsc#1012628).
- tracing: Fix sleeping while atomic in kdb ftdump (bsc#1012628).
- drm/i915/selftests: fix a couple IS_ERR() vs NULL tests
  (bsc#1012628).
- drm/i915/ttm: fix sg_table construction (bsc#1012628).
- drm/i915/gt: Serialize GRDOM access between multiple engine
  resets (bsc#1012628).
- drm/i915/gt: Serialize TLB invalidates with GT resets
  (bsc#1012628).
- drm/i915/selftests: fix subtraction overflow bug (bsc#1012628).
- bnxt_en: reclaim max resources if sriov enable fails
  (bsc#1012628).
- bnxt_en: Fix bnxt_reinit_after_abort() code path (bsc#1012628).
- bnxt_en: fix livepatch query (bsc#1012628).
- bnxt_en: Fix bnxt_refclk_read() (bsc#1012628).
- sysctl: Fix data-races in proc_dou8vec_minmax() (bsc#1012628).
- sysctl: Fix data-races in proc_dointvec_ms_jiffies()
  (bsc#1012628).
- tcp: Fix a data-race around sysctl_max_tw_buckets (bsc#1012628).
- icmp: Fix a data-race around sysctl_icmp_echo_ignore_all
  (bsc#1012628).
- icmp: Fix data-races around sysctl_icmp_echo_enable_probe
  (bsc#1012628).
- icmp: Fix a data-race around sysctl_icmp_echo_ignore_broadcasts
  (bsc#1012628).
- icmp: Fix a data-race around
  sysctl_icmp_ignore_bogus_error_responses (bsc#1012628).
- icmp: Fix a data-race around
  sysctl_icmp_errors_use_inbound_ifaddr (bsc#1012628).
- icmp: Fix a data-race around sysctl_icmp_ratelimit
  (bsc#1012628).
- icmp: Fix a data-race around sysctl_icmp_ratemask (bsc#1012628).
- raw: Fix a data-race around sysctl_raw_l3mdev_accept
  (bsc#1012628).
- tcp: Fix data-races around sysctl_tcp_ecn (bsc#1012628).
- tcp: Fix a data-race around sysctl_tcp_ecn_fallback
  (bsc#1012628).
- ipv4: Fix data-races around sysctl_ip_dynaddr (bsc#1012628).
- nexthop: Fix data-races around nexthop_compat_mode
  (bsc#1012628).
- net: ftgmac100: Hold reference returned by
  of_get_child_by_name() (bsc#1012628).
- net: stmmac: fix leaks in probe (bsc#1012628).
- ima: force signature verification when CONFIG_KEXEC_SIG is
  configured (bsc#1012628).
- ima: Fix potential memory leak in ima_init_crypto()
  (bsc#1012628).
- drm/amd/display: Ignore First MST Sideband Message Return Error
  (bsc#1012628).
- drm/amdkfd: correct the MEC atomic support firmware checking
  for GC 10.3.7 (bsc#1012628).
- drm/amd/display: Only use depth 36 bpp linebuffers on DCN
  display engines (bsc#1012628).
- drm/amd/pm: Prevent divide by zero (bsc#1012628).
- drm/amd/display: Ensure valid event timestamp for cursor-only
  commits (bsc#1012628).
- smb3: workaround negprot bug in some Samba servers
  (bsc#1012628).
- sfc: fix use after free when disabling sriov (bsc#1012628).
- netfs: do not unlock and put the folio twice (bsc#1012628).
- seg6: fix skb checksum evaluation in SRH encapsulation/insertion
  (bsc#1012628).
- seg6: fix skb checksum in SRv6 End.B6 and End.B6.Encaps
  behaviors (bsc#1012628).
- seg6: bpf: fix skb checksum in bpf_push_seg6_encap()
  (bsc#1012628).
- sfc: fix kernel panic when creating VF (bsc#1012628).
- net: atlantic: remove deep parameter on suspend/resume functions
  (bsc#1012628).
- net: atlantic: remove aq_nic_deinit() when resume (bsc#1012628).
- KVM: x86: Fully initialize 'struct kvm_lapic_irq' in
  kvm_pv_kick_cpu_op() (bsc#1012628).
- net/tls: Check for errors in tls_device_init (bsc#1012628).
- mm: sysctl: fix missing numa_stat when !CONFIG_HUGETLB_PAGE
  (bsc#1012628).
- ARM: 9211/1: domain: drop modify_domain() (bsc#1012628).
- ARM: 9212/1: domain: Modify Kconfig help text (bsc#1012628).
- ASoC: dt-bindings: Fix description for msm8916 (bsc#1012628).
- tee: tee_get_drvdata(): fix description of return value
  (bsc#1012628).
- s390/nospec: build expoline.o for modules_prepare target
  (bsc#1012628).
- scsi: megaraid: Clear READ queue map's nr_queues (bsc#1012628).
- scsi: ufs: core: Drop loglevel of WriteBoost message
  (bsc#1012628).
- nvme: fix block device naming collision (bsc#1012628).
- ksmbd: use SOCK_NONBLOCK type for kernel_accept() (bsc#1012628).
- powerpc/xive/spapr: correct bitmap allocation size
  (bsc#1012628).
- vdpa/mlx5: Initialize CVQ vringh only once (bsc#1012628).
- vduse: Tie vduse mgmtdev and its device (bsc#1012628).
- platform/x86: intel/pmc: Add Alder Lake N support to PMC core
  driver (bsc#1012628).
- virtio_mmio: Add missing PM calls to freeze/restore
  (bsc#1012628).
- virtio_mmio: Restore guest page size on resume (bsc#1012628).
- netfilter: nf_tables: avoid skb access on nf_stolen
  (bsc#1012628).
- netfilter: br_netfilter: do not skip all hooks with 0 priority
  (bsc#1012628).
- scsi: hisi_sas: Limit max hw sectors for v3 HW (bsc#1012628).
- cpufreq: pmac32-cpufreq: Fix refcount leak bug (bsc#1012628).
- platform/x86: thinkpad-acpi: profile capabilities as integer
  (bsc#1012628).
- platform/x86: thinkpad_acpi: do not use PSC mode on Intel
  platforms (bsc#1012628).
- platform/x86: hp-wmi: Ignore Sanitization Mode event
  (bsc#1012628).
- net: tipc: fix possible refcount leak in tipc_sk_create()
  (bsc#1012628).
- NFC: nxp-nci: don't print header length mismatch on i2c error
  (bsc#1012628).
- nvme-tcp: always fail a request when sending it failed
  (bsc#1012628).
- nvme: fix regression when disconnect a recovering ctrl
  (bsc#1012628).
- net: sfp: fix memory leak in sfp_probe() (bsc#1012628).
- ASoC: ops: Fix off by one in range control validation
  (bsc#1012628).
- pinctrl: aspeed: Fix potential NULL dereference in
  aspeed_pinmux_set_mux() (bsc#1012628).
- ASoC: Realtek/Maxim SoundWire codecs: disable pm_runtime on
  remove (bsc#1012628).
- ASoC: rt711-sdca-sdw: fix calibrate mutex initialization
  (bsc#1012628).
- ASoC: Intel: sof_sdw: handle errors on card registration
  (bsc#1012628).
- ASoC: rt711: fix calibrate mutex initialization (bsc#1012628).
- ASoC: rt7*-sdw: harden jack_detect_handler (bsc#1012628).
- ASoC: codecs: rt700/rt711/rt711-sdca: initialize workqueues
  in probe (bsc#1012628).
- ASoC: SOF: Intel: hda-dsp: Expose hda_dsp_core_power_up()
  (bsc#1012628).
- ASoC: SOF: Intel: hda-loader: Make sure that the fw load
  sequence is followed (bsc#1012628).
- ASoC: SOF: Intel: hda-loader: Clarify the cl_dsp_init() flow
  (bsc#1012628).
- ASoC: wcd9335: Remove RX channel from old list before adding
  it to a new one (bsc#1012628).
- ASoC: wcd9335: Fix spurious event generation (bsc#1012628).
- ASoC: wcd938x: Fix event generation for some controls
  (bsc#1012628).
- ASoC: Intel: bytcr_wm5102: Fix GPIO related probe-ordering
  problem (bsc#1012628).
- ASoC: wm_adsp: Fix event for preloader (bsc#1012628).
- ASoC: wm5110: Fix DRE control (bsc#1012628).
- ASoC: cs35l41: Correct some control names (bsc#1012628).
- ASoC: rt711-sdca: fix kernel NULL pointer dereference when IO
  error (bsc#1012628).
- ASoC: dapm: Initialise kcontrol data for mux/demux controls
  (bsc#1012628).
- ASoC: cs35l41: Add ASP TX3/4 source to register patch
  (bsc#1012628).
- ASoC: cs47l15: Fix event generation for low power mux control
  (bsc#1012628).
- ASoC: madera: Fix event generation for OUT1 demux (bsc#1012628).
- ASoC: madera: Fix event generation for rate controls
  (bsc#1012628).
- irqchip: or1k-pic: Undefine mask_ack for level triggered
  hardware (bsc#1012628).
- pinctrl: imx: Add the zero base flag for imx93 (bsc#1012628).
- x86: Clear .brk area at early boot (bsc#1012628).
- soc: ixp4xx/npe: Fix unused match warning (bsc#1012628).
- ARM: dts: stm32: use the correct clock source for CEC on
  stm32mp151 (bsc#1012628).
- Revert "can: xilinx_can: Limit CANFD brp to 2" (bsc#1012628).
- ALSA: usb-audio: Add quirks for MacroSilicon MS2100/MS2106
  devices (bsc#1012628).
- ALSA: usb-audio: Add quirk for Fiero SC-01 (bsc#1012628).
- ALSA: usb-audio: Add quirk for Fiero SC-01 (fw v1.0.0)
  (bsc#1012628).
- nvme-pci: phison e16 has bogus namespace ids (bsc#1012628).
- nvme: use struct group for generic command dwords (bsc#1012628).
- wireguard: selftests: set fake real time in init (bsc#1012628).
- wireguard: selftests: always call kernel makefile (bsc#1012628).
- signal handling: don't use BUG_ON() for debugging (bsc#1012628).
- ACPI: video: Fix acpi_video_handles_brightness_key_presses()
  (bsc#1012628).
- vt: fix memory overlapping when deleting chars in the buffer
  (bsc#1012628).
- s390/ap: fix error handling in __verify_queue_reservations()
  (bsc#1012628).
- ACPI: CPPC: Fix enabling CPPC on AMD systems with shared memory
  (bsc#1012628).
- serial: 8250: fix return error code in
  serial8250_request_std_resource() (bsc#1012628).
- power: supply: core: Fix boundary conditions in interpolation
  (bsc#1012628).
- serial: stm32: Clear prev values before setting RTS delays
  (bsc#1012628).
- serial: pl011: UPSTAT_AUTORTS requires .throttle/unthrottle
  (bsc#1012628).
- serial: 8250: Fix PM usage_count for console handover
  (bsc#1012628).
- serial: mvebu-uart: correctly report configured baudrate value
  (bsc#1012628).
- x86/pat: Fix x86_has_pat_wp() (bsc#1012628).
- drm/i915/ttm: fix 32b build (bsc#1012628).
- Refresh patches.suse/x86-mm-Simplify-RESERVE_BRK.patch.
- commit b66ab1b
* Thu Jul 21 2022 mbrugger@suse.com
- arm64: Update config files. (bsc#1198737)
  Enable RTC_DRV_RX8025 to support RX-8035 on Traveres Ten64 board.
- commit 74f2920
* Wed Jul 20 2022 ludwig.nussel@suse.de
- kernel-obs-build: include qemu_fw_cfg (boo#1201705)
- commit e2263d4
* Wed Jul 20 2022 jslaby@suse.cz
- Refresh
  patches.suse/0001-fbdev-Disable-sysfb-device-registration-when-removin.patch.
- Refresh
  patches.suse/0001-firmware-sysfb-Add-sysfb_disable-helper-function.patch.
- Refresh
  patches.suse/0001-firmware-sysfb-Make-sysfb_create_simplefb-return-a-p.patch.
  Update upstream status.
- commit 6a770c6
* Wed Jul 20 2022 jslaby@suse.cz
- Delete
  patches.kernel.org/5.18.12-013-objtool-skip-non-text-sections-when-adding-re.patch.
  No traces of the objtool patch in upstream whatsoever, so drop that.
  The rest: move out of patches.kernel.org as it hasn't landed there yet.
  Place the patches into sorted section instead where they belong.
- commit 3415e51
* Tue Jul 19 2022 tiwai@suse.de
- Input: i8042 - Apply probe defer to more ASUS ZenBook models
  (bsc#1190256).
- commit 6307fb1
* Mon Jul 18 2022 tzimmermann@suse.de
- config: i386: Enable DRM stack for early-boot graphics (boo#1193474)
  Replace fbdev's generic drivers with DRM-based simpledrm. Enables the
  DRM graphics stack for early-boot graphics, recovery and unsupported
  chipsets.
- commit 3305623
* Mon Jul 18 2022 jslaby@suse.cz
- x86/bugs: Remove apostrophe typo (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- commit 34930df
* Mon Jul 18 2022 jslaby@suse.cz
- Refresh
  patches.rpmify/x86-asm-32-fix-ANNOTATE_UNRET_SAFE-use-on-32bit.patch.
- Refresh
  patches.suse/tty-extract-tty_flip_buffer_commit-from-tty_flip_buf.patch.
- Refresh
  patches.suse/tty-use-new-tty_insert_flip_string_and_push_buffer-i.patch.
- Refresh
  patches.suse/x86-entry-Remove-UNTRAIN_RET-from-native_irq_return_.patch.
- Refresh
  patches.suse/x86-kvm-fix-FASTOP_SIZE-when-return-thunks-are-enabl.patch.
  Update upstream status.
- commit fcd7336
* Sun Jul 17 2022 mkubecek@suse.cz
- Update to 5.19-rc7
- drop obsolete patches
  - patches.suse/tty-extract-tty_flip_buffer_commit-from-tty_flip_buf.patch
  - patches.suse/tty-use-new-tty_insert_flip_string_and_push_buffer-i.patch
- update configs (x86 only)
  - SPECULATION_MITIGATIONS=y
  - RETHUNK=y
  - CPU_UNRET_ENTRY=y
  - CPU_IBPB_ENTRY=y
  - CPU_IBRS_ENTRY=y
- commit 900302b
* Fri Jul 15 2022 jslaby@suse.cz
- Linux 5.18.12 (bsc#1012628).
- Revert "mtd: rawnand: gpmi: Fix setting busy timeout setting"
  (bsc#1012628).
- commit 3198c22
* Fri Jul 15 2022 jslaby@suse.cz
- Refresh
  patches.suse/0001-drm-aperture-Run-fbdev-removal-before-internal-helpe.patch.
  Update upstream status.
- commit 4fcb983
* Fri Jul 15 2022 jslaby@suse.cz
- x86/mm: Simplify RESERVE_BRK() (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- commit da1381f
* Fri Jul 15 2022 jslaby@suse.cz
- x86/entry: Remove UNTRAIN_RET from native_irq_return_ldt
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- commit ce3ce6a
* Fri Jul 15 2022 jslaby@suse.cz
- Refresh
  patches.suse/x86-kvm-fix-FASTOP_SIZE-when-return-thunks-are-enabl.patch.
  Update to upstream version.
- commit 3f7e318
* Thu Jul 14 2022 jeffm@suse.com
- rpm/kernel-binary.spec.in: Require dwarves >= 1.22 on SLE15-SP3 or newer
  Dwarves 1.22 or newer is required to build kernels with BTF information
  embedded in modules.
- commit ee19e9d
* Thu Jul 14 2022 jslaby@suse.cz
- x86/asm/32: Fix ANNOTATE_UNRET_SAFE use on 32-bit (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
  Update upstream status.
- commit eae54b1
* Thu Jul 14 2022 jslaby@suse.cz
- tty: use new tty_insert_flip_string_and_push_buffer() in
  pty_write() (bsc#1198829 CVE-2022-1462).
- tty: extract tty_flip_buffer_commit() from
  tty_flip_buffer_push() (bsc#1198829 CVE-2022-1462).
- tty: use new tty_insert_flip_string_and_push_buffer() in
  pty_write() (bsc#1198829 CVE-2022-1462).
- tty: extract tty_flip_buffer_commit() from
  tty_flip_buffer_push() (bsc#1198829 CVE-2022-1462).
- commit cec52d3
* Thu Jul 14 2022 jslaby@suse.cz
- x86/kvm: fix FASTOP_SIZE when return thunks are enabled
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- commit 86ef7b4
* Wed Jul 13 2022 jslaby@suse.cz
- x86/asm/32: fix ANNOTATE_UNRET_SAFE use on 32bit (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86/static_call: Serialize __static_call_fixup() properly
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- x86/speculation: Disable RRSBA behavior (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86/kexec: Disable RET on kexec (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- x86/bugs: Do not enable IBPB-on-entry when IBPB is not supported
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- x86/entry: Move PUSH_AND_CLEAR_REGS() back into error_entry
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- x86/bugs: Add Cannon lake to RETBleed affected CPU list
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- commit 834606b
* Wed Jul 13 2022 jslaby@suse.cz
- x86/retbleed: Add fine grained Kconfig knobs (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- Update config files.
- commit 9dbc2f6
* Wed Jul 13 2022 jslaby@suse.cz
- x86/cpu/amd: Enumerate BTC_NO (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- x86/common: Stamp out the stepping madness (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- KVM: VMX: Prevent RSB underflow before vmenter (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86/speculation: Fill RSB on vmexit for IBRS (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- KVM: VMX: Fix IBRS handling after vmexit (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- KVM: VMX: Prevent guest RSB poisoning attacks with eIBRS
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- KVM: VMX: Convert launched argument to flags (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- KVM: VMX: Flatten __vmx_vcpu_run() (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- objtool: Re-add UNWIND_HINT_{SAVE_RESTORE} (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86/speculation: Remove x86_spec_ctrl_mask (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86/speculation: Use cached host SPEC_CTRL value for guest
  entry/exit (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- x86/speculation: Fix SPEC_CTRL write on SMT state change
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- x86/speculation: Fix firmware entry SPEC_CTRL handling
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- x86/speculation: Fix RSB filling with CONFIG_RETPOLINE=n
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- x86/cpu/amd: Add Spectral Chicken (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- objtool: Add entry UNRET validation (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- x86/bugs: Do IBPB fallback check only once (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86/bugs: Add retbleed=ibpb (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- x86/xen: Add UNTRAIN_RET (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- x86/xen: Rename SYS* entry points (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- objtool: Update Retpoline validation (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- intel_idle: Disable IBRS during long idle (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86/bugs: Report Intel retbleed vulnerability (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86/bugs: Split spectre_v2_select_mitigation() and
  spectre_v2_user_select_mitigation() (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- x86/speculation: Add spectre_v2=ibrs option to support Kernel
  IBRS (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- x86/bugs: Optimize SPEC_CTRL MSR writes (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86/entry: Add kernel IBRS implementation (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86/bugs: Keep a per-CPU IA32_SPEC_CTRL value (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86/bugs: Enable STIBP for JMP2RET (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- commit 023a0b9
* Wed Jul 13 2022 jslaby@suse.cz
- x86/bugs: Add AMD retbleed= boot parameter (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- Update config files.
- commit a4a04c4
* Wed Jul 13 2022 jslaby@suse.cz
- x86/bugs: Report AMD retbleed vulnerability (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86: Add magic AMD return-thunk (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- objtool: Treat .text.__x86.* as noinstr (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86/entry: Avoid very early RET (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- x86: Use return-thunk in asm code (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- x86/sev: Avoid using __x86_return_thunk (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86/vsyscall_emu/64: Don't use RET in vsyscall emulation
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- x86/kvm: Fix SETcc emulation for return thunks (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86/bpf: Use alternative RET encoding (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86/ftrace: Use alternative RET encoding (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86,static_call: Use alternative RET encoding (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- objtool: skip non-text sections when adding return-thunk sites
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- x86,objtool: Create .return_sites (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- x86: Undo return-thunk damage (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- x86/retpoline: Use -mfunction-return (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- x86/retpoline: Swizzle retpoline thunk (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86/retpoline: Cleanup some #ifdefery (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86/cpufeatures: Move RETPOLINE flags to word 11 (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86/kvm/vmx: Make noinstr clean (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- x86/entry: Remove skip_r11rcx (bsc#1199657 CVE-2022-29900
  CVE-2022-29901).
- x86/entry: Don't call error_entry() for XENPV (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- x86/entry: Move PUSH_AND_CLEAR_REGS out of error_entry()
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- x86/entry: Switch the stack after error_entry() returns
  (bsc#1199657 CVE-2022-29900 CVE-2022-29901).
- x86/traps: Use pt_regs directly in fixup_bad_iret() (bsc#1199657
  CVE-2022-29900 CVE-2022-29901).
- commit bc4fd7c
* Wed Jul 13 2022 schwab@suse.de
- config: riscv: disable RISCV_BOOT_SPINWAIT
  We now rely on the SBI HSM extension which is provided by openSBI 0.7 or
  later.
- commit 8752291
* Wed Jul 13 2022 schwab@suse.de
- config: riscv: disable RISCV_SBI_V01
  The SBI v0.1 API is obsolete.
- commit 44178e7
* Tue Jul 12 2022 jslaby@suse.cz
- Linux 5.18.11 (bsc#1012628).
- io_uring: fix provided buffer import (bsc#1012628).
- ALSA: usb-audio: Workarounds for Behringer UMC 204/404 HD
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Clevo L140PU (bsc#1012628).
- ALSA: cs46xx: Fix missing snd_card_free() call at probe error
  (bsc#1012628).
- can: bcm: use call_rcu() instead of costly synchronize_rcu()
  (bsc#1012628).
- can: grcan: grcan_probe(): remove extra of_node_get()
  (bsc#1012628).
- can: gs_usb: gs_usb_open/close(): fix memory leak (bsc#1012628).
- can: m_can: m_can_chip_config(): actually enable internal
  timestamping (bsc#1012628).
- can: m_can: m_can_{read_fifo,echo_tx_event}(): shift timestamp
  to full 32 bits (bsc#1012628).
- can: kvaser_usb: replace run-time checks with struct
  kvaser_usb_driver_info (bsc#1012628).
- can: kvaser_usb: kvaser_usb_leaf: fix CAN clock frequency
  regression (bsc#1012628).
- can: kvaser_usb: kvaser_usb_leaf: fix bittiming limits
  (bsc#1012628).
- can: mcp251xfd: mcp251xfd_regmap_crc_read(): improve workaround
  handling for mcp2517fd (bsc#1012628).
- can: mcp251xfd: mcp251xfd_regmap_crc_read(): update workaround
  broken CRC on TBC register (bsc#1012628).
- can: mcp251xfd: mcp251xfd_stop(): add missing hrtimer_cancel()
  (bsc#1012628).
- bpf: Fix incorrect verifier simulation around jmp32's jeq/jne
  (bsc#1012628).
- bpf: Fix insufficient bounds propagation from
  adjust_scalar_min_max_vals (bsc#1012628).
- usbnet: fix memory leak in error case (bsc#1012628).
- net: rose: fix UAF bug caused by rose_t0timer_expiry
  (bsc#1012628).
- net: lan966x: hardcode the number of external ports
  (bsc#1012628).
- netfilter: nft_set_pipapo: release elements in clone from
  abort path (bsc#1012628).
- selftests/net: fix section name when using xdp_dummy.o
  (bsc#1012628).
- can: mcp251xfd: mcp251xfd_register_get_dev_id(): use correct
  length to read dev_id (bsc#1012628).
- can: mcp251xfd: mcp251xfd_register_get_dev_id(): fix endianness
  conversion (bsc#1012628).
- can: rcar_canfd: Fix data transmission failed on R-Car V3U
  (bsc#1012628).
- ASoC: qdsp6: q6apm-dai: unprepare stream if its already prepared
  (bsc#1012628).
- MAINTAINERS: Remove iommu@lists.linux-foundation.org
  (bsc#1012628).
- iommu/vt-d: Fix PCI bus rescan device hot add (bsc#1012628).
- iommu/vt-d: Fix RID2PASID setup/teardown failure (bsc#1012628).
- cxl/mbox: Use __le32 in get,set_lsa mailbox structures
  (bsc#1012628).
- cxl: Fix cleanup of port devices on failure to probe driver
  (bsc#1012628).
- fbdev: fbmem: Fix logo center image dx issue (bsc#1012628).
- fbmem: Check virtual screen sizes in fb_set_var() (bsc#1012628).
- fbcon: Disallow setting font bigger than screen size
  (bsc#1012628).
- fbcon: Prevent that screen size is smaller than font size
  (bsc#1012628).
- PM: runtime: Redefine pm_runtime_release_supplier()
  (bsc#1012628).
- PM: runtime: Fix supplier device management during consumer
  probe (bsc#1012628).
- memregion: Fix memregion_free() fallback definition
  (bsc#1012628).
- video: of_display_timing.h: include errno.h (bsc#1012628).
- fscache: Fix invalidation/lookup race (bsc#1012628).
- fscache: Fix if condition in fscache_wait_on_volume_collision()
  (bsc#1012628).
- powerpc/powernv: delay rng platform device creation until
  later in boot (bsc#1012628).
- net: dsa: qca8k: reset cpu port on MTU change (bsc#1012628).
- ARM: meson: Fix refcount leak in meson_smp_prepare_cpus
  (bsc#1012628).
- pinctrl: sunxi: a83t: Fix NAND function name for some pins
  (bsc#1012628).
- srcu: Tighten cleanup_srcu_struct() GP checks (bsc#1012628).
- ASoC: rt711: Add endianness flag in snd_soc_component_driver
  (bsc#1012628).
- ASoC: rt711-sdca: Add endianness flag in
  snd_soc_component_driver (bsc#1012628).
- ASoC: codecs: rt700/rt711/rt711-sdca: resume bus/codec in
  .set_jack_detect (bsc#1012628).
- ASoC: SOF: ipc3-topology: Move and correct size checks in
  sof_ipc3_control_load_bytes() (bsc#1012628).
- ASoC: SOF: Intel: hda: Fix compressed stream position tracking
  (bsc#1012628).
- arm64: dts: qcom: sm8450: fix interconnects property of UFS node
  (bsc#1012628).
- arm64: dts: qcom: msm8994: Fix CPU6/7 reg values (bsc#1012628).
- arm64: dts: qcom: sdm845: use dispcc AHB clock for mdss node
  (bsc#1012628).
- ARM: mxs_defconfig: Enable the framebuffer (bsc#1012628).
- arm64: dts: imx8mp-evk: correct mmc pad settings (bsc#1012628).
- arm64: dts: imx8mp-evk: correct the uart2 pinctl value
  (bsc#1012628).
- arm64: dts: imx8mp-evk: correct gpio-led pad settings
  (bsc#1012628).
- arm64: dts: imx8mp-evk: correct vbus pad settings (bsc#1012628).
- arm64: dts: imx8mp-evk: correct eqos pad settings (bsc#1012628).
- arm64: dts: imx8mp-evk: correct I2C5 pad settings (bsc#1012628).
- arm64: dts: imx8mp-evk: correct I2C1 pad settings (bsc#1012628).
- arm64: dts: imx8mp-evk: correct I2C3 pad settings (bsc#1012628).
- arm64: dts: imx8mp-phyboard-pollux-rdk: correct uart pad
  settings (bsc#1012628).
- arm64: dts: imx8mp-phyboard-pollux-rdk: correct eqos pad
  settings (bsc#1012628).
- arm64: dts: imx8mp-phyboard-pollux-rdk: correct i2c2 & mmc
  settings (bsc#1012628).
- pinctrl: sunxi: sunxi_pconf_set: use correct offset
  (bsc#1012628).
- arm64: dts: qcom: msm8992-*: Fix vdd_lvs1_2-supply typo
  (bsc#1012628).
- ARM: at91: pm: use proper compatible for sama5d2's rtc
  (bsc#1012628).
- ARM: at91: pm: use proper compatibles for sam9x60's rtc and rtt
  (bsc#1012628).
- ARM: at91: pm: use proper compatibles for sama7g5's rtc and rtt
  (bsc#1012628).
- ARM: dts: at91: sam9x60ek: fix eeprom compatible and size
  (bsc#1012628).
- ARM: dts: at91: sama5d2_icp: fix eeprom compatibles
  (bsc#1012628).
- ARM: at91: fix soc detection for SAM9X60 SiPs (bsc#1012628).
- xsk: Clear page contiguity bit when unmapping pool
  (bsc#1012628).
- i2c: piix4: Fix a memory leak in the EFCH MMIO support
  (bsc#1012628).
- i40e: Fix dropped jumbo frames statistics (bsc#1012628).
- i40e: Fix VF's MAC Address change on VM (bsc#1012628).
- ARM: dts: stm32: add missing usbh clock and fix clk order on
  stm32mp15 (bsc#1012628).
- ibmvnic: Properly dispose of all skbs during a failover
  (bsc#1012628).
- selftests: forwarding: fix flood_unicast_test when h2 supports
  IFF_UNICAST_FLT (bsc#1012628).
- selftests: forwarding: fix learning_test when h1 supports
  IFF_UNICAST_FLT (bsc#1012628).
- selftests: forwarding: fix error message in learning_test
  (bsc#1012628).
- ACPI: CPPC: Check _OSC for flexible address space (bsc#1012628).
- ACPI: bus: Set CPPC _OSC bits for all and when CPPC_LIB is
  supported (bsc#1012628).
- ACPI: CPPC: Only probe for _CPC if CPPC v2 is acked
  (bsc#1012628).
- ACPI: CPPC: Don't require _OSC if X86_FEATURE_CPPC is supported
  (bsc#1012628).
- net/mlx5e: Fix matchall police parameters validation
  (bsc#1012628).
- mptcp: Avoid acquiring PM lock for subflow priority changes
  (bsc#1012628).
- mptcp: Acquire the subflow socket lock before modifying MP_PRIO
  flags (bsc#1012628).
- mptcp: fix local endpoint accounting (bsc#1012628).
- r8169: fix accessing unset transport header (bsc#1012628).
- i2c: cadence: Unregister the clk notifier in error path
  (bsc#1012628).
- net/sched: act_api: Add extack to offload_act_setup() callback
  (bsc#1012628).
- net/sched: act_police: Add extack messages for offload failure
  (bsc#1012628).
- net/sched: act_police: allow 'continue' action offload
  (bsc#1012628).
- dmaengine: imx-sdma: Allow imx8m for imx7 FW revs (bsc#1012628).
- dmaengine: imx-sdma: only restart cyclic channel when enabled
  (bsc#1012628).
- misc: rtsx_usb: fix use of dma mapped buffer for usb bulk
  transfer (bsc#1012628).
- misc: rtsx_usb: use separate command and response buffers
  (bsc#1012628).
- misc: rtsx_usb: set return value in rsp_buf alloc err path
  (bsc#1012628).
- dmaengine: dw-axi-dmac: Fix RMW on channel suspend register
  (bsc#1012628).
- dt-bindings: dma: allwinner,sun50i-a64-dma: Fix min/max typo
  (bsc#1012628).
- ida: don't use BUG_ON() for debugging (bsc#1012628).
- dmaengine: pl330: Fix lockdep warning about non-static key
  (bsc#1012628).
- dmaengine: lgm: Fix an error handling path in intel_ldma_probe()
  (bsc#1012628).
- dmaengine: at_xdma: handle errors of at_xdmac_alloc_desc()
  correctly (bsc#1012628).
- dmaengine: ti: Fix refcount leak in ti_dra7_xbar_route_allocate
  (bsc#1012628).
- dmaengine: qcom: bam_dma: fix runtime PM underflow
  (bsc#1012628).
- dmaengine: ti: Add missing put_device in
  ti_dra7_xbar_route_allocate (bsc#1012628).
- dmaengine: idxd: force wq context cleanup on device disable path
  (bsc#1012628).
- commit 0e7e901
* Mon Jul 11 2022 mkubecek@suse.cz
- Update to 5.19-rc6
- update configs
  - s390x/zfcpdump
  - CRC32_S390=n
  - SHA512_S390=n
  - SHA1_S390=n
  - SHA256_S390=n
  - SHA3_256_S390=n
  - SHA3_512_S390=n
  - GHASH_S390=n
  - AES_S390=n
  - DES_S390=n
  - CHACHA_S390=n
  - KEXEC_FILE=n
- commit 5477bdd
* Fri Jul  8 2022 jslaby@suse.cz
- Linux 5.18.10 (bsc#1012628).
- xen/arm: Fix race in RB-tree based P2M accounting (bsc#1012628).
- xen-netfront: restore __skb_queue_tail() positioning in
  xennet_get_responses() (bsc#1012628).
- xen/blkfront: force data bouncing when backend is untrusted
  (bsc#1012628).
- xen/netfront: force data bouncing when backend is untrusted
  (bsc#1012628).
- xen/netfront: fix leaking data in shared pages (bsc#1012628).
- xen/blkfront: fix leaking data in shared pages (bsc#1012628).
- hwmon: (ibmaem) don't call platform_device_del() if
  platform_device_add() fails (bsc#1012628).
- net: sparx5: mdb add/del handle non-sparx5 devices
  (bsc#1012628).
- net: sparx5: Add handling of host MDB entries (bsc#1012628).
- drm/fourcc: fix integer type usage in uapi header (bsc#1012628).
- platform/x86: panasonic-laptop: filter out duplicate volume
  up/down/mute keypresses (bsc#1012628).
- platform/x86: panasonic-laptop: don't report duplicate
  brightness key-presses (bsc#1012628).
- platform/x86: panasonic-laptop: revert "Resolve hotkey double
  trigger bug" (bsc#1012628).
- platform/x86: panasonic-laptop: sort includes alphabetically
  (bsc#1012628).
- platform/x86: panasonic-laptop: de-obfuscate button codes
  (bsc#1012628).
- drivers: cpufreq: Add missing of_node_put() in qoriq-cpufreq.c
  (bsc#1012628).
- drm/msm/gem: Fix error return on fence id alloc fail
  (bsc#1012628).
- drm/i915/dgfx: Disable d3cold at gfx root port (bsc#1012628).
- drm/i915/gem: add missing else (bsc#1012628).
- platform/x86: ideapad-laptop: Add allow_v4_dytc module parameter
  (bsc#1012628).
- drm/msm/dpu: Increment vsync_cnt before waking up userspace
  (bsc#1012628).
- cifs: fix minor compile warning (bsc#1012628).
- net: tun: avoid disabling NAPI twice (bsc#1012628).
- mlxsw: spectrum_router: Fix rollback in tunnel next hop init
  (bsc#1012628).
- ipv6: fix lockdep splat in in6_dump_addrs() (bsc#1012628).
- ipv6/sit: fix ipip6_tunnel_get_prl return value (bsc#1012628).
- nvmet: add a clear_ids attribute for passthru targets
  (bsc#1012628).
- fanotify: refine the validation checks on non-dir inode mask
  (bsc#1012628).
- tunnels: do not assume mac header is set in
  skb_tunnel_check_pmtu() (bsc#1012628).
- ACPI: video: Change how we determine if brightness key-presses
  are handled (bsc#1012628).
- nvmet-tcp: fix regression in data_digest calculation
  (bsc#1012628).
- tcp: add a missing nf_reset_ct() in 3WHS handling (bsc#1012628).
- cpufreq: qcom-hw: Don't do lmh things without a throttle
  interrupt (bsc#1012628).
- epic100: fix use after free on rmmod (bsc#1012628).
- tipc: move bc link creation back to tipc_node_create
  (bsc#1012628).
- NFC: nxp-nci: Don't issue a zero length i2c_master_read()
  (bsc#1012628).
- nfc: nfcmrvl: Fix irq_of_parse_and_map() return value
  (bsc#1012628).
- platform/x86: ideapad-laptop: Add Ideapad 5 15ITL05 to
  ideapad_dytc_v4_allow_table[] (bsc#1012628).
- platform/x86: thinkpad_acpi: Fix a memory leak of EFCH MMIO
  resource (bsc#1012628).
- powerpc/memhotplug: Add add_pages override for PPC
  (bsc#1012628).
- Update config files.
- net: dsa: felix: fix race between reading PSFP stats and port
  stats (bsc#1012628).
- net: bonding: fix use-after-free after 802.3ad slave unbind
  (bsc#1012628).
- selftests net: fix kselftest net fatal error (bsc#1012628).
- net: phy: ax88772a: fix lost pause advertisement configuration
  (bsc#1012628).
- net: bonding: fix possible NULL deref in rlb code (bsc#1012628).
- net: asix: fix "can't send until first packet is send" issue
  (bsc#1012628).
- net/sched: act_api: Notify user space if any actions were
  flushed before error (bsc#1012628).
- net/dsa/hirschmann: Add missing of_node_get() in
  hellcreek_led_setup() (bsc#1012628).
- netfilter: nft_dynset: restore set element counter when failing
  to update (bsc#1012628).
- s390: remove unneeded 'select BUILD_BIN2C' (bsc#1012628).
- vdpa/mlx5: Update Control VQ callback information (bsc#1012628).
- lib/sbitmap: Fix invalid loop in __sbitmap_queue_get_batch()
  (bsc#1012628).
- PM / devfreq: exynos-ppmu: Fix refcount leak in
  of_get_devfreq_events (bsc#1012628).
- io_uring: ensure that send/sendmsg and recv/recvmsg check
  sqe->ioprio (bsc#1012628).
- caif_virtio: fix race between virtio_device_ready() and
  ndo_open() (bsc#1012628).
- vfs: fix copy_file_range() regression in cross-fs copies
  (bsc#1012628).
- NFSv4: Add an fattr allocation to _nfs4_discover_trunking()
  (bsc#1012628).
- NFSD: restore EINVAL error translation in nfsd_commit()
  (bsc#1012628).
- NFS: restore module put when manager exits (bsc#1012628).
- net: ipv6: unexport __init-annotated seg6_hmac_net_init()
  (bsc#1012628).
- hwmon: (occ) Prevent power cap command overwriting poll response
  (bsc#1012628).
- selftests: mptcp: Initialize variables to quiet gcc 12 warnings
  (bsc#1012628).
- mptcp: fix conflict with <netinet/in.h> (bsc#1012628).
- selftests: mptcp: more stable diag tests (bsc#1012628).
- mptcp: fix race on unaccepted mptcp sockets (bsc#1012628).
- usbnet: fix memory allocation in helpers (bsc#1012628).
- net: usb: asix: do not force pause frames support (bsc#1012628).
- linux/dim: Fix divide by 0 in RDMA DIM (bsc#1012628).
- RDMA/cm: Fix memory leak in ib_cm_insert_listen (bsc#1012628).
- RDMA/qedr: Fix reporting QP timeout attribute (bsc#1012628).
- net: dp83822: disable rx error interrupt (bsc#1012628).
- net: dp83822: disable false carrier interrupt (bsc#1012628).
- net: fix IFF_TX_SKB_NO_LINEAR definition (bsc#1012628).
- net: tun: stop NAPI when detaching queues (bsc#1012628).
- net: tun: unlink NAPI from device on destruction (bsc#1012628).
- net: dsa: bcm_sf2: force pause link settings (bsc#1012628).
- selftests/net: pass ipv6_args to udpgso_bench's IPv6 TCP test
  (bsc#1012628).
- virtio-net: fix race between ndo_open() and
  virtio_device_ready() (bsc#1012628).
- net: usb: ax88179_178a: Fix packet receiving (bsc#1012628).
- net: rose: fix UAF bugs caused by timer handler (bsc#1012628).
- SUNRPC: Fix READ_PLUS crasher (bsc#1012628).
- dm raid: fix KASAN warning in raid5_add_disks (bsc#1012628).
- dm raid: fix accesses beyond end of raid member array
  (bsc#1012628).
- cpufreq: amd-pstate: Add resume and suspend callbacks
  (bsc#1012628).
- powerpc/bpf: Fix use of user_pt_regs in uapi (bsc#1012628).
- powerpc/book3e: Fix PUD allocation size in map_kernel_page()
  (bsc#1012628).
- powerpc/prom_init: Fix kernel config grep (bsc#1012628).
- parisc/unaligned: Fix emulate_ldw() breakage (bsc#1012628).
- parisc: Fix vDSO signal breakage on 32-bit kernel (bsc#1012628).
- ceph: wait on async create before checking caps for syncfs
  (bsc#1012628).
- nvdimm: Fix badblocks clear off-by-one error (bsc#1012628).
- nvme-pci: add NVME_QUIRK_BOGUS_NID for ADATA IM2P33F8ABR1
  (bsc#1012628).
- nvme-pci: add NVME_QUIRK_BOGUS_NID for ADATA XPG SX6000LNP
  (AKA SPECTRIX S40G) (bsc#1012628).
- s390/archrandom: simplify back to earlier design and initialize
  earlier (bsc#1012628).
- net: phy: Don't trigger state machine while in suspend
  (bsc#1012628).
- ipv6: take care of disable_policy when restoring routes
  (bsc#1012628).
- ksmbd: use vfs_llseek instead of dereferencing NULL
  (bsc#1012628).
- ksmbd: check invalid FileOffset and BeyondFinalZero in
  FSCTL_ZERO_DATA (bsc#1012628).
- ksmbd: set the range of bytes to zero without extending file
  size in FSCTL_ZERO_DATA (bsc#1012628).
- drm/amdgpu: To flush tlb for MMHUB of RAVEN series
  (bsc#1012628).
- Revert "drm/amdgpu/display: set vblank_disable_immediate for DC"
  (bsc#1012628).
- drm/amdgpu: fix adev variable used in
  amdgpu_device_gpu_recover() (bsc#1012628).
- commit 97c4fd2
* Tue Jul  5 2022 tzimmermann@suse.de
- drm/aperture: Run fbdev removal before internal helpers (boo#1193472)
- commit aff8e8a
* Tue Jul  5 2022 tiwai@suse.de
- netfilter: nf_tables: stricter validation of element data
  (CVE-2022-34918 bsc#1201171).
- commit a1fda0d
* Mon Jul  4 2022 tzimmermann@suse.de
- fbdev: Disable sysfb device registration when removing conflicting (boo#1193472)
- commit c76a69f
* Mon Jul  4 2022 tzimmermann@suse.de
- firmware: sysfb: Add sysfb_disable() helper function (boo#1193472)
- commit 6072450
* Mon Jul  4 2022 tzimmermann@suse.de
- firmware: sysfb: Make sysfb_create_simplefb() return a pdev pointer (boo#1193472)
- commit 326d1c1
* Mon Jul  4 2022 mkubecek@suse.cz
- Update to 5.19-rc5
- update contigs
  - VIRTIO_HARDEN_NOTIFICATION=n
- commit 59940d4
* Sun Jul  3 2022 jslaby@suse.cz
- Linux 5.18.9 (bsc#1012628).
- clocksource/drivers/ixp4xx: Drop boardfile probe path
  (bsc#1012628).
- bcache: memset on stack variables in bch_btree_check() and
  bch_sectors_dirty_init() (bsc#1012628).
- hinic: Replace memcpy() with direct assignment (bsc#1012628).
- powerpc/ftrace: Remove ftrace init tramp once kernel init is
  complete (bsc#1012628).
- io_uring: fix not locked access to fixed buf table
  (bsc#1012628).
- commit 0e67dc1
* Fri Jul  1 2022 jslaby@suse.cz
- tick/nohz: unexport __init-annotated tick_nohz_full_setup()
  (tick_nohz_full_setup fix).
- commit 296483f
* Wed Jun 29 2022 jslaby@suse.cz
- Linux 5.18.8 (bsc#1012628).
- random: schedule mix_interrupt_randomness() less often
  (bsc#1012628).
- random: quiet urandom warning ratelimit suppression message
  (bsc#1012628).
- ALSA: memalloc: Drop x86-specific hack for WC allocations
  (bsc#1012628).
- ALSA: hda/via: Fix missing beep setup (bsc#1012628).
- ALSA: hda/conexant: Fix missing beep setup (bsc#1012628).
- ALSA: hda/realtek: Add mute LED quirk for HP Omen laptop
  (bsc#1012628).
- ALSA: hda/realtek - ALC897 headset MIC no sound (bsc#1012628).
- ALSA: hda/realtek: Apply fixup for Lenovo Yoga Duet 7 properly
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Clevo PD70PNT (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Clevo NS50PU (bsc#1012628).
- net: openvswitch: fix parsing of nw_proto for IPv6 fragments
  (bsc#1012628).
- ipv4: ping: fix bind address validity check (bsc#1012628).
- 9p: Fix refcounting during full path walks for fid lookups
  (bsc#1012628).
- 9p: fix fid refcount leak in v9fs_vfs_atomic_open_dotl
  (bsc#1012628).
- 9p: fix fid refcount leak in v9fs_vfs_get_link (bsc#1012628).
- 9p: fix EBADF errors in cached mode (bsc#1012628).
- btrfs: fix hang during unmount when block group reclaim task
  is running (bsc#1012628).
- btrfs: prevent remounting to v1 space cache for subpage mount
  (bsc#1012628).
- btrfs: add error messages to all unrecognized mount options
  (bsc#1012628).
- scsi: ibmvfc: Store vhost pointer during subcrq allocation
  (bsc#1012628).
- scsi: ibmvfc: Allocate/free queue resource only during
  probe/remove (bsc#1012628).
- mmc: sdhci-pci-o2micro: Fix card detect by dealing with
  debouncing (bsc#1012628).
- mmc: mediatek: wait dma stop bit reset to 0 (bsc#1012628).
- xen/gntdev: Avoid blocking in unmap_grant_pages() (bsc#1012628).
- MAINTAINERS: Add new IOMMU development mailing list
  (bsc#1012628).
- mtd: rawnand: gpmi: Fix setting busy timeout setting
  (bsc#1012628).
- ata: libata: add qc->flags in ata_qc_complete_template
  tracepoint (bsc#1012628).
- dm era: commit metadata in postsuspend after worker stops
  (bsc#1012628).
- dm: do not return early from dm_io_complete if BLK_STS_AGAIN
  without polling (bsc#1012628).
- dm mirror log: clear log bits up to BITS_PER_LONG boundary
  (bsc#1012628).
- tracing/kprobes: Check whether get_kretprobe() returns NULL
  in kretprobe_dispatcher() (bsc#1012628).
- filemap: Handle sibling entries in filemap_get_read_batch()
  (bsc#1012628).
- mm/slub: add missing TID updates on slab deactivation
  (bsc#1012628).
- drm/i915: Implement w/a 22010492432 for adl-s (bsc#1012628).
- amd/display/dc: Fix COLOR_ENCODING and COLOR_RANGE doing
  nothing for DCN20+ (bsc#1012628).
- drm/amd/display: Fix typo in override_lane_settings
  (bsc#1012628).
- USB: serial: pl2303: add support for more HXN (G) types
  (bsc#1012628).
- USB: serial: option: add Telit LE910Cx 0x1250 composition
  (bsc#1012628).
- USB: serial: option: add Quectel EM05-G modem (bsc#1012628).
- USB: serial: option: add Quectel RM500K module support
  (bsc#1012628).
- drm/msm: Ensure mmap offset is initialized (bsc#1012628).
- drm/msm: Fix double pm_runtime_disable() call (bsc#1012628).
- netfilter: use get_random_u32 instead of prandom (bsc#1012628).
- scsi: scsi_debug: Fix zone transition to full condition
  (bsc#1012628).
- drm/msm: Switch ordering of runpm put vs devfreq_idle
  (bsc#1012628).
- scsi: iscsi: Exclude zero from the endpoint ID range
  (bsc#1012628).
- xsk: Fix generic transmit when completion queue reservation
  fails (bsc#1012628).
- drm/msm: use for_each_sgtable_sg to iterate over scatterlist
  (bsc#1012628).
- bpf: Fix request_sock leak in sk lookup helpers (bsc#1012628).
- drm/sun4i: Fix crash during suspend after component bind failure
  (bsc#1012628).
- bpf, x86: Fix tail call count offset calculation on bpf2bpf call
  (bsc#1012628).
- selftests dma: fix compile error for dma_map_benchmark
  (bsc#1012628).
- scsi: storvsc: Correct reporting of Hyper-V I/O size limits
  (bsc#1012628).
- phy: aquantia: Fix AN when higher speeds than 1G are not
  advertised (bsc#1012628).
- KVM: arm64: Prevent kmemleak from accessing pKVM memory
  (bsc#1012628).
- net: fix data-race in dev_isalive() (bsc#1012628).
- veth: Add updating of trans_start (bsc#1012628).
- tipc: fix use-after-free Read in tipc_named_reinit
  (bsc#1012628).
- block: disable the elevator int del_gendisk (bsc#1012628).
- rethook: Reject getting a rethook if RCU is not watching
  (bsc#1012628).
- igb: fix a use-after-free issue in igb_clean_tx_ring
  (bsc#1012628).
- bonding: ARP monitor spams NETDEV_NOTIFY_PEERS notifiers
  (bsc#1012628).
- ethtool: Fix get module eeprom fallback (bsc#1012628).
- net/sched: sch_netem: Fix arithmetic in netem_dump() for 32-bit
  platforms (bsc#1012628).
- drm/msm/mdp4: Fix refcount leak in mdp4_modeset_init_intf
  (bsc#1012628).
- drm/msm/dp: check core_initialized before disable interrupts
  at dp_display_unbind() (bsc#1012628).
- drm/msm/dp: force link training for display resolution change
  (bsc#1012628).
- net: phy: at803x: fix NULL pointer dereference on AR9331 PHY
  (bsc#1012628).
- perf test: Record only user callchains on the "Check Arm64
  callgraphs are complete in fp mode" test (bsc#1012628).
- perf test topology: Use !strncmp(right platform) to fix guest
  PPC comparision check (bsc#1012628).
- perf arm-spe: Don't set data source if it's not a memory
  operation (bsc#1012628).
- ipv4: fix bind address validity regression tests (bsc#1012628).
- erspan: do not assume transport header is always set
  (bsc#1012628).
- net/tls: fix tls_sk_proto_close executed repeatedly
  (bsc#1012628).
- udmabuf: add back sanity check (bsc#1012628).
- selftests: netfilter: correct PKTGEN_SCRIPT_PATHS in
  nft_concat_range.sh (bsc#1012628).
- netfilter: nf_dup_netdev: do not push mac header a second time
  (bsc#1012628).
- netfilter: nf_dup_netdev: add and use recursion counter
  (bsc#1012628).
- xen-blkfront: Handle NULL gendisk (bsc#1012628).
- x86/xen: Remove undefined behavior in setup_features()
  (bsc#1012628).
- MIPS: Remove repetitive increase irq_err_count (bsc#1012628).
- afs: Fix dynamic root getattr (bsc#1012628).
- block: pop cached rq before potentially blocking
  rq_qos_throttle() (bsc#1012628).
- ice: ignore protocol field in GTP offload (bsc#1012628).
- ice: Fix switchdev rules book keeping (bsc#1012628).
- ice: ethtool: advertise 1000M speeds properly (bsc#1012628).
- ice: ethtool: Prohibit improper channel config for DCB
  (bsc#1012628).
- io_uring: fail links when poll fails (bsc#1012628).
- regmap-irq: Fix a bug in regmap_irq_enable() for type_in_mask
  chips (bsc#1012628).
- regmap-irq: Fix offset/index mismatch in read_sub_irq_data()
  (bsc#1012628).
- iommu/ipmmu-vmsa: Fix compatible for rcar-gen4 (bsc#1012628).
- drm/amd: Revert "drm/amd/display: keep eDP Vdd on when eDP
  stream is already enabled" (bsc#1012628).
- net: dsa: qca8k: reduce mgmt ethernet timeout (bsc#1012628).
- igb: Make DMA faster when CPU is active on the PCIe link
  (bsc#1012628).
- virtio_net: fix xdp_rxq_info bug after suspend/resume
  (bsc#1012628).
- Revert "net/tls: fix tls_sk_proto_close executed repeatedly"
  (bsc#1012628).
- sock: redo the psock vs ULP protection check (bsc#1012628).
- nvme: move the Samsung X5 quirk entry to the core quirks
  (bsc#1012628).
- gpio: winbond: Fix error code in winbond_gpio_get()
  (bsc#1012628).
- s390/cpumf: Handle events cycles and instructions identical
  (bsc#1012628).
- filemap: Fix serialization adding transparent huge pages to
  page cache (bsc#1012628).
- KVM: SEV: Init target VMCBs in sev_migrate_from (bsc#1012628).
- iio: mma8452: fix probe fail when device tree compatible is used
  (bsc#1012628).
- iio: magnetometer: yas530: Fix memchr_inv() misuse
  (bsc#1012628).
- iio: adc: xilinx-ams: fix return error variable (bsc#1012628).
- iio: adc: vf610: fix conversion mode sysfs node name
  (bsc#1012628).
- io_uring: make apoll_events a __poll_t (bsc#1012628).
- io_uring: fix req->apoll_events (bsc#1012628).
- usb: typec: wcove: Drop wrong dependency to INTEL_SOC_PMIC
  (bsc#1012628).
- io_uring: fix wrong arm_poll error handling (bsc#1012628).
- vmcore: convert copy_oldmem_page() to take an iov_iter
  (bsc#1012628).
- s390/crash: add missing iterator advance in copy_oldmem_page()
  (bsc#1012628).
- s390/crash: make copy_oldmem_page() return number of bytes
  copied (bsc#1012628).
- xhci: turn off port power in shutdown (bsc#1012628).
- xhci-pci: Allow host runtime PM as default for Intel Raptor
  Lake xHCI (bsc#1012628).
- xhci-pci: Allow host runtime PM as default for Intel Meteor
  Lake xHCI (bsc#1012628).
- usb: gadget: uvc: fix list double add in uvcg_video_pump
  (bsc#1012628).
- usb: gadget: Fix non-unique driver names in raw-gadget driver
  (bsc#1012628).
- USB: gadget: Fix double-free bug in raw_gadget driver
  (bsc#1012628).
- usb: chipidea: udc: check request status before setting device
  address (bsc#1012628).
- dt-bindings: usb: ohci: Increase the number of PHYs
  (bsc#1012628).
- dt-bindings: usb: ehci: Increase the number of PHYs
  (bsc#1012628).
- btrfs: fix race between reflinking and ordered extent completion
  (bsc#1012628).
- btrfs: don't set lock_owner when locking extent buffer for
  reading (bsc#1012628).
- btrfs: fix deadlock with fsync+fiemap+transaction commit
  (bsc#1012628).
- f2fs: attach inline_data after setting compression
  (bsc#1012628).
- f2fs: fix iostat related lock protection (bsc#1012628).
- f2fs: do not count ENOENT for error case (bsc#1012628).
- iio:humidity:hts221: rearrange iio trigger get and register
  (bsc#1012628).
- iio:proximity:sx9324: Check ret value of
  device_property_read_u32_array() (bsc#1012628).
- iio:chemical:ccs811: rearrange iio trigger get and register
  (bsc#1012628).
- iio:accel:kxcjk-1013: rearrange iio trigger get and register
  (bsc#1012628).
- iio:accel:bma180: rearrange iio trigger get and register
  (bsc#1012628).
- iio:accel:mxc4005: rearrange iio trigger get and register
  (bsc#1012628).
- iio: accel: mma8452: ignore the return value of reset operation
  (bsc#1012628).
- iio: gyro: mpu3050: Fix the error handling in mpu3050_power_up()
  (bsc#1012628).
- iio: trigger: sysfs: fix use-after-free on remove (bsc#1012628).
- iio: adc: stm32: fix maximum clock rate for stm32mp15x
  (bsc#1012628).
- iio: imu: inv_icm42600: Fix broken icm42600 (chip id 0 value)
  (bsc#1012628).
- iio: afe: rescale: Fix boolean logic bug (bsc#1012628).
- iio: test: fix missing MODULE_LICENSE for IIO_RESCALE=m
  (bsc#1012628).
- iio: adc: aspeed: Fix refcount leak in aspeed_adc_set_trim_data
  (bsc#1012628).
- iio: adc: stm32: Fix ADCs iteration in irq handler
  (bsc#1012628).
- iio: adc: stm32: Fix IRQs on STM32F4 by removing custom spurious
  IRQs message (bsc#1012628).
- iio: adc: stm32: fix vrefint wrong calibration value handling
  (bsc#1012628).
- iio: adc: axp288: Override TS pin bias current for some models
  (bsc#1012628).
- iio: adc: rzg2l_adc: add missing fwnode_handle_put() in
  rzg2l_adc_parse_properties() (bsc#1012628).
- iio: adc: adi-axi-adc: Fix refcount leak in
  adi_axi_adc_attach_client (bsc#1012628).
- iio: adc: ti-ads131e08: add missing fwnode_handle_put() in
  ads131e08_alloc_channels() (bsc#1012628).
- xtensa: xtfpga: Fix refcount leak bug in setup (bsc#1012628).
- xtensa: Fix refcount leak bug in time.c (bsc#1012628).
- parisc/stifb: Fix fb_is_primary_device() only available with
  CONFIG_FB_STI (bsc#1012628).
- parisc: Fix flush_anon_page on PA8800/PA8900 (bsc#1012628).
- parisc: Enable ARCH_HAS_STRICT_MODULE_RWX (bsc#1012628).
- arm64: dts: ti: k3-j721s2: Fix overlapping GICD memory region
  (bsc#1012628).
- powerpc/microwatt: wire up rng during setup_arch()
  (bsc#1012628).
- powerpc: Enable execve syscall exit tracepoint (bsc#1012628).
- powerpc/rtas: Allow ibm,platform-dump RTAS call with null
  buffer address (bsc#1012628).
- powerpc/powernv: wire up rng during setup_arch (bsc#1012628).
- mm/memory-failure: disable unpoison once hw error happens
  (bsc#1012628).
- mm: lru_cache_disable: use synchronize_rcu_expedited
  (bsc#1012628).
- ARM: dts: imx7: Move hsic_phy power domain to HSIC PHY node
  (bsc#1012628).
- ARM: dts: imx6qdl: correct PU regulator ramp delay
  (bsc#1012628).
- arm64: dts: ti: k3-am64-main: Remove support for HS400 speed
  mode (bsc#1012628).
- ARM: exynos: Fix refcount leak in exynos_map_pmu (bsc#1012628).
- arm64: dts: exynos: Correct UART clocks on Exynos7885
  (bsc#1012628).
- soc: bcm: brcmstb: pm: pm-arm: Fix refcount leak in
  brcmstb_pm_probe (bsc#1012628).
- ARM: Fix refcount leak in axxia_boot_secondary (bsc#1012628).
- memory: mtk-smi: add missing put_device() call in
  mtk_smi_device_link_common (bsc#1012628).
- memory: samsung: exynos5422-dmc: Fix refcount leak in
  of_get_dram_timings (bsc#1012628).
- ARM: cns3xxx: Fix refcount leak in cns3xxx_init (bsc#1012628).
- modpost: fix section mismatch check for exported init/exit
  sections (bsc#1012628).
- ARM: dts: bcm2711-rpi-400: Fix GPIO line names (bsc#1012628).
- smb3: fix empty netname context on secondary channels
  (bsc#1012628).
- random: update comment from copy_to_user() -> copy_to_iter()
  (bsc#1012628).
- perf build-id: Fix caching files with a wrong build ID
  (bsc#1012628).
- smb3: use netname when available on secondary channels
  (bsc#1012628).
- dma-direct: use the correct size for dma_set_encrypted()
  (bsc#1012628).
- kbuild: link vmlinux only once for CONFIG_TRIM_UNUSED_KSYMS
  (2nd attempt) (bsc#1012628).
- powerpc/pseries: wire up rng during setup_arch() (bsc#1012628).
- commit 4e30480
* Mon Jun 27 2022 mkubecek@suse.cz
- Update to 5.19-rc4
- update configs
  - FIPS_SIGNATURE_SELFTEST=n
- commit c256fc8
* Sun Jun 26 2022 jslaby@suse.cz
- Linux 5.18.7 (bsc#1012628).
- s390/mm: use non-quiescing sske for KVM switch to keyed guest
  (bsc#1012628).
- zonefs: fix zonefs_iomap_begin() for reads (bsc#1012628).
- fsnotify: introduce mark type iterator (bsc#1012628).
- fsnotify: consistent behavior for parent not watching children
  (bsc#1012628).
- bpf: Fix calling global functions from BPF_PROG_TYPE_EXT
  programs (bsc#1012628).
- selftests/bpf: Add selftest for calling global functions from
  freplace (bsc#1012628).
- dt-bindings: nvmem: sfp: Add clock properties (bsc#1012628).
- io_uring: use original request task for inflight tracking
  (bsc#1012628).
- commit 531894c
* Fri Jun 24 2022 mkubecek@suse.cz
- config: enable MLX90614
  MLX90614 is I2C (SMBus) remote temperature sensor.
  The boards are available for SBCs:
  https://www.waveshare.com/product/modules/sensors/temperature-humidity-barometer/infrared-temperature-sensor.htm
  Enable the driver for potential users.
  Link: https://lists.opensuse.org/archives/list/kernel@lists.opensuse.org/thread/VHBAZ4YTJZ6H2DTMELYWILNGMRBXBMPI/
- commit 1a61419
* Thu Jun 23 2022 jslaby@suse.cz
- Linux 5.18.6 (bsc#1012628).
- Revert "drm/amd/display: Fix DCN3 B0 DP Alt Mapping"
  (bsc#1012628).
- arm64: dts: imx8mm-beacon: Enable RTS-CTS on UART3
  (bsc#1012628).
- arm64: dts: imx8mn-beacon: Enable RTS-CTS on UART3
  (bsc#1012628).
- io_uring: reinstate the inflight tracking (bsc#1012628).
- powerpc/kasan: Silence KASAN warnings in __get_wchan()
  (bsc#1012628).
- ASoC: nau8822: Add operation for internal PLL off and on
  (bsc#1012628).
- ASoC: qcom: lpass-platform: Update VMA access permissions in
  mmap callback (bsc#1012628).
- drm/amd/display: Read Golden Settings Table from VBIOS
  (bsc#1012628).
- drm/amdgpu: Resolve RAS GFX error count issue after cold boot
  on Arcturus (bsc#1012628).
- drm/amdkfd: Use mmget_not_zero in MMU notifier (bsc#1012628).
- dma-debug: make things less spammy under memory pressure
  (bsc#1012628).
- ASoC: Intel: cirrus-common: fix incorrect channel mapping
  (bsc#1012628).
- ASoC: cs42l52: Fix TLV scales for mixer controls (bsc#1012628).
- ASoC: cs35l36: Update digital volume TLV (bsc#1012628).
- ASoC: cs53l30: Correct number of volume levels on SX controls
  (bsc#1012628).
- ASoC: cs42l52: Correct TLV for Bypass Volume (bsc#1012628).
- ASoC: cs42l56: Correct typo in minimum level for SX volume
  controls (bsc#1012628).
- ASoC: cs42l51: Correct minimum value for SX volume control
  (bsc#1012628).
- drm/amdkfd: add pinned BOs to kfd_bo_list (bsc#1012628).
- ata: libata-core: fix NULL pointer deref in
  ata_host_alloc_pinfo() (bsc#1012628).
- quota: Prevent memory allocation recursion while holding dq_lock
  (bsc#1012628).
- ASoC: wm8962: Fix suspend while playing music (bsc#1012628).
- ASoC: es8328: Fix event generation for deemphasis control
  (bsc#1012628).
- ASoC: wm_adsp: Fix event generation for wm_adsp_fw_put()
  (bsc#1012628).
- ALSA: hda: MTL: add HD Audio PCI ID and HDMI codec vendor ID
  (bsc#1012628).
- Input: soc_button_array - also add Lenovo Yoga Tablet2 1051F
  to dmi_use_low_level_irq (bsc#1012628).
- scsi: vmw_pvscsi: Expand vcpuHint to 16 bits (bsc#1012628).
- scsi: lpfc: Resolve NULL ptr dereference after an ELS LOGO is
  aborted (bsc#1012628).
- scsi: lpfc: Fix port stuck in bypassed state after LIP in
  PT2PT topology (bsc#1012628).
- scsi: lpfc: Allow reduced polling rate for
  nvme_admin_async_event cmd completion (bsc#1012628).
- scsi: mpt3sas: Fix out-of-bounds compiler warning (bsc#1012628).
- scsi: ipr: Fix missing/incorrect resource cleanup in error case
  (bsc#1012628).
- scsi: pmcraid: Fix missing resource cleanup in error case
  (bsc#1012628).
- ALSA: hda/realtek - Add HW8326 support (bsc#1012628).
- virtio-mmio: fix missing put_device() when vm_cmdline_parent
  registration failed (bsc#1012628).
- nfc: nfcmrvl: Fix memory leak in nfcmrvl_play_deferred
  (bsc#1012628).
- ipv6: Fix signed integer overflow in __ip6_append_data
  (bsc#1012628).
- ipv6: Fix signed integer overflow in l2tp_ip6_sendmsg
  (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix misuse of mem alloc interface
  netdev[napi]_alloc_frag (bsc#1012628).
- mellanox: mlx5: avoid uninitialized variable warning with gcc-12
  (bsc#1012628).
- MIPS: Loongson-3: fix compile mips cpu_hwmon as module build
  error (bsc#1012628).
- random: credit cpu and bootloader seeds by default
  (bsc#1012628).
- gpio: dwapb: Don't print error on -EPROBE_DEFER (bsc#1012628).
- platform/x86/intel: Fix pmt_crashlog array reference
  (bsc#1012628).
- platform/x86/intel: pmc: Support Intel Raptorlake P
  (bsc#1012628).
- platform/x86: gigabyte-wmi: Add Z690M AORUS ELITE AX DDR4
  support (bsc#1012628).
- platform/x86: gigabyte-wmi: Add support for B450M DS3H-CF
  (bsc#1012628).
- platform/x86/intel: hid: Add Surface Go to VGBS allow list
  (bsc#1012628).
- staging: r8188eu: fix rtw_alloc_hwxmits error detection for now
  (bsc#1012628).
- staging: r8188eu: Fix warning of array overflow in ioctl_linux.c
  (bsc#1012628).
- pNFS: Don't keep retrying if the server replied
  NFS4ERR_LAYOUTUNAVAILABLE (bsc#1012628).
- pNFS: Avoid a live lock condition in pnfs_update_layout()
  (bsc#1012628).
- sunrpc: set cl_max_connect when cloning an rpc_clnt
  (bsc#1012628).
- clocksource: hyper-v: unexport __init-annotated
  hv_init_clocksource() (bsc#1012628).
- i40e: Fix adding ADQ filter to TC0 (bsc#1012628).
- i40e: Fix calculating the number of queue pairs (bsc#1012628).
- i40e: Fix call trace in setup_tx_descriptors (bsc#1012628).
- iavf: Fix issue with MAC address of VF shown as zero
  (bsc#1012628).
- Drivers: hv: vmbus: Release cpu lock in error case
  (bsc#1012628).
- tty: goldfish: Fix free_irq() on remove (bsc#1012628).
- misc: atmel-ssc: Fix IRQ check in ssc_probe (bsc#1012628).
- riscv: dts: microchip: re-add pdma to mpfs device tree
  (bsc#1012628).
- io_uring: fix races with file table unregister (bsc#1012628).
- io_uring: fix races with buffer table unregister (bsc#1012628).
- drm/i915/reset: Fix error_state_read ptr + offset use
  (bsc#1012628).
- net: hns3: set port base vlan tbl_sta to false before removing
  old vlan (bsc#1012628).
- net: hns3: don't push link state to VF if unalive (bsc#1012628).
- net: hns3: restore tm priority/qset to default settings when
  tc disabled (bsc#1012628).
- net: hns3: fix PF rss size initialization bug (bsc#1012628).
- net: hns3: fix tm port shapping of fibre port is incorrect
  after driver initialization (bsc#1012628).
- nvme: add device name to warning in uuid_show() (bsc#1012628).
- mlxsw: spectrum_cnt: Reorder counter pools (bsc#1012628).
- ice: Fix PTP TX timestamp offset calculation (bsc#1012628).
- ice: Sync VLAN filtering features for DVM (bsc#1012628).
- ice: Fix queue config fail handling (bsc#1012628).
- ice: Fix memory corruption in VF driver (bsc#1012628).
- net: bgmac: Fix an erroneous kfree() in bgmac_remove()
  (bsc#1012628).
- net: remove noblock parameter from skb_recv_datagram()
  (bsc#1012628).
- net: ax25: Fix deadlock caused by skb_recv_datagram in
  ax25_recvmsg (bsc#1012628).
- arm64: ftrace: fix branch range checks (bsc#1012628).
- arm64: ftrace: consistently handle PLTs (bsc#1012628).
- certs/blacklist_hashes.c: fix const confusion in certs blacklist
  (bsc#1012628).
- init: Initialize noop_backing_dev_info early (bsc#1012628).
- block: Fix handling of offline queues in
  blk_mq_alloc_request_hctx() (bsc#1012628).
- faddr2line: Fix overlapping text section failures, the sequel
  (bsc#1012628).
- x86/ftrace: Remove OBJECT_FILES_NON_STANDARD usage
  (bsc#1012628).
- i2c: npcm7xx: Add check for platform_driver_register
  (bsc#1012628).
- irqchip/gic/realview: Fix refcount leak in realview_gic_of_init
  (bsc#1012628).
- irqchip/apple-aic: Fix refcount leak in build_fiq_affinity
  (bsc#1012628).
- irqchip/apple-aic: Fix refcount leak in aic_of_ic_init
  (bsc#1012628).
- irqchip/gic-v3: Fix error handling in
  gic_populate_ppi_partitions (bsc#1012628).
- irqchip/gic-v3: Fix refcount leak in gic_populate_ppi_partitions
  (bsc#1012628).
- irqchip/realtek-rtl: Fix refcount leak in map_interrupts
  (bsc#1012628).
- sched: Fix balance_push() vs __sched_setscheduler()
  (bsc#1012628).
- i2c: designware: Use standard optional ref clock implementation
  (bsc#1012628).
- i2c: mediatek: Fix an error handling path in mtk_i2c_probe()
  (bsc#1012628).
- mei: hbm: drop capability response on early shutdown
  (bsc#1012628).
- mei: me: add raptor lake point S DID (bsc#1012628).
- comedi: vmk80xx: fix expression for tx buffer size
  (bsc#1012628).
- crypto: memneq - move into lib/ (bsc#1012628).
- USB: serial: option: add support for Cinterion MV31 with new
  baseline (bsc#1012628).
- USB: serial: io_ti: add Agilent E5805A support (bsc#1012628).
- arm64: mm: Don't invalidate FROM_DEVICE buffers at start of
  DMA transfer (bsc#1012628).
- usb: dwc2: Fix memory leak in dwc2_hcd_init (bsc#1012628).
- usb: cdnsp: Fixed setting last_trb incorrectly (bsc#1012628).
- usb: dwc3: gadget: Fix IN endpoint max packet size allocation
  (bsc#1012628).
- usb: dwc3: pci: Restore line lost in merge conflict resolution
  (bsc#1012628).
- usb: gadget: u_ether: fix regression in setting fixed MAC
  address (bsc#1012628).
- usb: gadget: lpc32xx_udc: Fix refcount leak in lpc32xx_udc_probe
  (bsc#1012628).
- usb: gadget: f_fs: change ep->status safe in ffs_epfile_io()
  (bsc#1012628).
- usb: gadget: f_fs: change ep->ep safe in ffs_epfile_io()
  (bsc#1012628).
- tty: n_gsm: Debug output allocation must use GFP_ATOMIC
  (bsc#1012628).
- serial: 8250: Store to lsr_save_flags after lsr read
  (bsc#1012628).
- bus: fsl-mc-bus: fix KASAN use-after-free in fsl_mc_bus_remove()
  (bsc#1012628).
- md/raid5-ppl: Fix argument order in bio_alloc_bioset()
  (bsc#1012628).
- dm: fix race in dm_start_io_acct (bsc#1012628).
- dm mirror log: round up region bitmap size to BITS_PER_LONG
  (bsc#1012628).
- drm/amdgpu: Fix GTT size reporting in amdgpu_ioctl
  (bsc#1012628).
- drm/amd/display: Cap OLED brightness per max frame-average
  luminance (bsc#1012628).
- audit: free module name (bsc#1012628).
- cfi: Fix __cfi_slowpath_diag RCU usage with cpuidle
  (bsc#1012628).
- fs: account for group membership (bsc#1012628).
- selinux: free contexts previously transferred in
  selinux_add_opt() (bsc#1012628).
- ext4: fix super block checksum incorrect after mount
  (bsc#1012628).
- ext4: fix bug_on ext4_mb_use_inode_pa (bsc#1012628).
- ext4: make variable "count" signed (bsc#1012628).
- ext4: add reserved GDT blocks check (bsc#1012628).
- KVM: arm64: Always start with clearing SVE flag on load
  (bsc#1012628).
- KVM: arm64: Don't read a HW interrupt pending state in user
  context (bsc#1012628).
- virtio-pci: Remove wrong address verification in vp_del_vqs()
  (bsc#1012628).
- drm/i915/uc: remove accidental static from a local variable
  (bsc#1012628).
- bpf: Use safer kvmalloc_array() where possible (bsc#1012628).
- powerpc/book3e: get rid of #include <generated/compile.h>
  (bsc#1012628).
- dt-bindings: mfd: bd9571mwv: update rohm,bd9571mwv.yaml
  reference (bsc#1012628).
- dt-bindings: interrupt-controller: update brcm,l2-intc.yaml
  reference (bsc#1012628).
- dm: fix bio_set allocation (bsc#1012628).
- clk: imx8mp: fix usb_root_clk parent (bsc#1012628).
- Delete
  patches.suse/netfs-Eliminate-Clang-randstruct-warning.patch.
- Update config files.
- commit 5aa0763
* Wed Jun 22 2022 jslaby@suse.cz
- Update config files.
  Run oldconfig which unsets CC_NO_ARRAY_BOUNDS as dummy tools emulate gcc
  20. We are ignoring it thanks to update in packaging, so that real
  compilation sets this right later.
- commit e4ff964
* Wed Jun 22 2022 jslaby@suse.cz
- rpm/check-for-config-changes: ignore GCC12/CC_NO_ARRAY_BOUNDS
  Upstream commit f0be87c42cbd (gcc-12: disable '-Warray-bounds'
  universally for now) added two new compiler-dependent configs:
  * CC_NO_ARRAY_BOUNDS
  * GCC12_NO_ARRAY_BOUNDS
  Ignore them -- they are unset by dummy tools (they depend on gcc version
  == 12), but set as needed during real compilation.
- commit a14607c
* Tue Jun 21 2022 tiwai@suse.de
- ath9k: fix use-after-free in ath9k_hif_usb_rx_cb (CVE-2022-1679
  bsc#1199487).
- commit f4c43ea
* Tue Jun 21 2022 tiwai@suse.de
- ALSA: hda: Fix discovery of i915 graphics PCI device
  (bsc#1200611).
- commit ef301cb
* Tue Jun 21 2022 jslaby@suse.cz
- netfs: Fix gcc-12 warning by embedding vfs inode in
  netfs_i_context (gcc 12 warnings).
- netfs: gcc-12: temporarily disable '-Wattribute-warning'
  for now (gcc 12 warnings).
- gcc-12: disable '-Warray-bounds' universally for now (gcc
  12 warnings).
- Update config files.
  CC_NO_ARRAY_BOUNDS=y is manually selected, see commit b2fb712ddc6e.
- gcc-12: disable '-Wdangling-pointer' warning for now (gcc
  12 warnings).
- wifi: rtlwifi: remove always-true condition pointed out by
  GCC 12 (gcc 12 warnings).
- net: wwan: iosm: remove pointless null check (gcc 12 warnings).
- eth: sun: cassini: remove dead code (gcc 12 warnings).
- netfs: Eliminate Clang randstruct warning (gcc 12 warnings).
- x86/boot: Wrap literal addresses in absolute_pointer() (gcc
  12 warnings).
- commit 983c97f
* Tue Jun 21 2022 jslaby@suse.cz
- series.conf: remove empty line in sorted section
  It causes troubles to scripts.
- commit b01fcd9
* Sun Jun 19 2022 mkubecek@suse.cz
- Update to 5.19-rc3
- update configs
  - XILINX_INTC=y (OF architectures - i386, ppc64/ppc64le, riscv64)
- commit e8495ca
* Thu Jun 16 2022 jslaby@suse.cz
- Linux 5.18.5 (bsc#1012628).
- x86/speculation/mmio: Print SMT warning (bsc#1012628).
- KVM: x86/speculation: Disable Fill buffer clear within guests
  (bsc#1012628).
- x86/speculation/mmio: Reuse SRBDS mitigation for SBDS
  (bsc#1012628).
- x86/speculation/srbds: Update SRBDS mitigation selection
  (bsc#1012628).
- x86/speculation/mmio: Add sysfs reporting for Processor MMIO
  Stale Data (bsc#1012628).
- x86/speculation/mmio: Enable CPU Fill buffer clearing on idle
  (bsc#1012628).
- x86/bugs: Group MDS, TAA & Processor MMIO Stale Data mitigations
  (bsc#1012628).
- x86/speculation/mmio: Add mitigation for Processor MMIO Stale
  Data (bsc#1012628).
- x86/speculation: Add a common function for MD_CLEAR mitigation
  update (bsc#1012628).
- x86/speculation/mmio: Enumerate Processor MMIO Stale Data bug
  (bsc#1012628).
- Documentation: Add documentation for Processor MMIO Stale Data
  (bsc#1012628).
- commit 0ac72f9
* Wed Jun 15 2022 jslaby@suse.cz
- Linux 5.18.4 (bsc#1012628).
- pcmcia: db1xxx_ss: restrict to MIPS_DB1XXX boards (bsc#1012628).
- staging: greybus: codecs: fix type confusion of list iterator
  variable (bsc#1012628).
- iio: adc: ad7124: Remove shift from scan_type (bsc#1012628).
- soundwire: qcom: fix an error message in
  swrm_wait_for_frame_gen_enabled() (bsc#1012628).
- remoteproc: mediatek: Fix side effect of mt8195 sram power on
  (bsc#1012628).
- remoteproc: mtk_scp: Fix a potential double free (bsc#1012628).
- lkdtm/bugs: Check for the NULL pointer after calling kmalloc
  (bsc#1012628).
- lkdtm/bugs: Don't expect thread termination without
  CONFIG_UBSAN_TRAP (bsc#1012628).
- tty: goldfish: Use tty_port_destroy() to destroy port
  (bsc#1012628).
- tty: serial: owl: Fix missing clk_disable_unprepare() in
  owl_uart_probe (bsc#1012628).
- tty: n_tty: Restore EOF push handling behavior (bsc#1012628).
- serial: 8250_aspeed_vuart: Fix potential NULL dereference in
  aspeed_vuart_probe (bsc#1012628).
- tty: serial: fsl_lpuart: fix potential bug when using both
  of_alias_get_id and ida_simple_get (bsc#1012628).
- remoteproc: imx_rproc: Ignore create mem entry for resource
  table (bsc#1012628).
- phy: rockchip-inno-usb2: Fix muxed interrupt support
  (bsc#1012628).
- staging: r8188eu: fix struct rt_firmware_hdr (bsc#1012628).
- usb: usbip: fix a refcount leak in stub_probe() (bsc#1012628).
- usb: usbip: add missing device lock on tweak configuration cmd
  (bsc#1012628).
- USB: storage: karma: fix rio_karma_init return (bsc#1012628).
- usb: musb: Fix missing of_node_put() in omap2430_probe
  (bsc#1012628).
- staging: fieldbus: Fix the error handling path in
  anybuss_host_common_probe() (bsc#1012628).
- pwm: lp3943: Fix duty calculation in case period was clamped
  (bsc#1012628).
- pwm: raspberrypi-poe: Fix endianness in firmware struct
  (bsc#1012628).
- rpmsg: qcom_smd: Fix irq_of_parse_and_map() return value
  (bsc#1012628).
- usb: dwc3: gadget: Replace list_for_each_entry_safe() if using
  giveback (bsc#1012628).
- usb: dwc3: pci: Fix pm_runtime_get_sync() error checking
  (bsc#1012628).
- scripts/get_abi: Fix wrong script file name in the help message
  (bsc#1012628).
- misc: fastrpc: fix an incorrect NULL check on list iterator
  (bsc#1012628).
- firmware: stratix10-svc: fix a missing check on list iterator
  (bsc#1012628).
- usb: typec: mux: Check dev_set_name() return value
  (bsc#1012628).
- rpmsg: virtio: Fix possible double free in rpmsg_probe()
  (bsc#1012628).
- rpmsg: virtio: Fix possible double free in
  rpmsg_virtio_add_ctrl_dev() (bsc#1012628).
- rpmsg: virtio: Fix the unregistration of the device rpmsg_ctrl
  (bsc#1012628).
- iio: adc: stmpe-adc: Fix wait_for_completion_timeout return
  value check (bsc#1012628).
- iio: proximity: vl53l0x: Fix return value check of
  wait_for_completion_timeout (bsc#1012628).
- iio: adc: sc27xx: fix read big scale voltage not right
  (bsc#1012628).
- iio: adc: sc27xx: Fine tune the scale calibration values
  (bsc#1012628).
- rpmsg: qcom_smd: Fix returning 0 if irq_of_parse_and_map()
  fails (bsc#1012628).
- misc/pvpanic: Convert regular spinlock into trylock on panic
  path (bsc#1012628).
- phy: qcom-qmp: fix pipe-clock imbalance on power-on failure
  (bsc#1012628).
- power: supply: core: Initialize struct to zero (bsc#1012628).
- power: supply: axp288_fuel_gauge: Fix battery reporting on
  the One Mix 1 (bsc#1012628).
- power: supply: axp288_fuel_gauge: Drop BIOS version check from
  "T3 MRD" DMI quirk (bsc#1012628).
- power: supply: ab8500_fg: Allocate wq in probe (bsc#1012628).
- serial: sifive: Report actual baud base rather than fixed 115200
  (bsc#1012628).
- export: fix string handling of namespace in EXPORT_SYMBOL_NS
  (bsc#1012628).
- watchdog: rzg2l_wdt: Fix 32bit overflow issue (bsc#1012628).
- watchdog: rzg2l_wdt: Fix Runtime PM usage (bsc#1012628).
- watchdog: rzg2l_wdt: Fix 'BUG: Invalid wait context'
  (bsc#1012628).
- watchdog: rzg2l_wdt: Fix reset control imbalance (bsc#1012628).
- soundwire: intel: prevent pm_runtime resume prior to system
  suspend (bsc#1012628).
- soundwire: qcom: return error when pm_runtime_get_sync fails
  (bsc#1012628).
- coresight: cpu-debug: Replace mutex with mutex_trylock on
  panic notifier (bsc#1012628).
- ksmbd: fix reference count leak in smb_check_perm_dacl()
  (bsc#1012628).
- extcon: ptn5150: Add queue work sync before driver release
  (bsc#1012628).
- dt-bindings: remoteproc: mediatek: Make l1tcm reg exclusive
  to mt819x (bsc#1012628).
- soc: rockchip: Fix refcount leak in rockchip_grf_init
  (bsc#1012628).
- clocksource/drivers/riscv: Events are stopped during CPU suspend
  (bsc#1012628).
- ARM: dts: aspeed: ast2600-evb: Enable RX delay for MAC0/MAC1
  (bsc#1012628).
- rtc: mt6397: check return value after calling
  platform_get_resource() (bsc#1012628).
- rtc: ftrtc010: Fix error handling in ftrtc010_rtc_probe
  (bsc#1012628).
- staging: r8188eu: add check for kzalloc (bsc#1012628).
- serial: meson: acquire port->lock in startup() (bsc#1012628).
- Revert "serial: 8250_mtk: Make sure to select the right
  FEATURE_SEL" (bsc#1012628).
- serial: 8250_fintek: Check SER_RS485_RTS_* only with RS485
  (bsc#1012628).
- serial: cpm_uart: Fix build error without
  CONFIG_SERIAL_CPM_CONSOLE (bsc#1012628).
- serial: uartlite: Fix BRKINT clearing (bsc#1012628).
- serial: digicolor-usart: Don't allow CS5-6 (bsc#1012628).
- serial: rda-uart: Don't allow CS5-6 (bsc#1012628).
- serial: txx9: Don't allow CS5-6 (bsc#1012628).
- serial: sh-sci: Don't allow CS5-6 (bsc#1012628).
- serial: sifive: Sanitize CSIZE and c_iflag (bsc#1012628).
- serial: st-asc: Sanitize CSIZE and correct PARENB for CS7
  (bsc#1012628).
- serial: stm32-usart: Correct CSIZE, bits, and parity
  (bsc#1012628).
- firmware: dmi-sysfs: Fix memory leak in
  dmi_sysfs_register_handle (bsc#1012628).
- bus: ti-sysc: Fix warnings for unbind for serial (bsc#1012628).
- driver: base: fix UAF when driver_attach failed (bsc#1012628).
- driver core: fix deadlock in __device_attach (bsc#1012628).
- watchdog: rti-wdt: Fix pm_runtime_get_sync() error checking
  (bsc#1012628).
- watchdog: ts4800_wdt: Fix refcount leak in ts4800_wdt_probe
  (bsc#1012628).
- blk-mq: don't touch ->tagset in blk_mq_get_sq_hctx
  (bsc#1012628).
- ASoC: fsl_sai: Fix FSL_SAI_xDR/xFR definition (bsc#1012628).
- scsi: sd: Don't call blk_cleanup_disk() in sd_probe()
  (bsc#1012628).
- clocksource/drivers/oxnas-rps: Fix irq_of_parse_and_map()
  return value (bsc#1012628).
- s390/crypto: fix scatterwalk_unmap() callers in AES-GCM
  (bsc#1012628).
- amt: fix return value of amt_update_handler() (bsc#1012628).
- amt: fix possible memory leak in amt_rcv() (bsc#1012628).
- net: ethernet: ti: am65-cpsw: Fix fwnode passed to
  phylink_create() (bsc#1012628).
- net/smc: set ini->smcrv2.ib_dev_v2 to NULL if SMC-Rv2 is
  unavailable (bsc#1012628).
- spi: fsi: Fix spurious timeout (bsc#1012628).
- drm/amdgpu: Off by one in dm_dmub_outbox1_low_irq()
  (bsc#1012628).
- net: lan966x: check devm_of_phy_get() for -EDEFER_PROBE
  (bsc#1012628).
- net: sched: fixed barrier to prevent skbuff sticking in qdisc
  backlog (bsc#1012628).
- net: ethernet: mtk_eth_soc: out of bounds read in
  mtk_hwlro_get_fdir_entry() (bsc#1012628).
- net: ethernet: ti: am65-cpsw-nuss: Fix some refcount leaks
  (bsc#1012628).
- net: dsa: mv88e6xxx: Fix refcount leak in
  mv88e6xxx_mdios_register (bsc#1012628).
- modpost: fix removing numeric suffixes (bsc#1012628).
- block, loop: support partitions without scanning (bsc#1012628).
- ep93xx: clock: Do not return the address of the freed memory
  (bsc#1012628).
- jffs2: fix memory leak in jffs2_do_fill_super (bsc#1012628).
- ubi: fastmap: Fix high cpu usage of ubi_bgt by making sure
  wl_pool not empty (bsc#1012628).
- ubi: ubi_create_volume: Fix use-after-free when volume creation
  failed (bsc#1012628).
- selftests/bpf: fix stacktrace_build_id with missing
  kprobe/urandom_read (bsc#1012628).
- bpf: Fix probe read error in ___bpf_prog_run() (bsc#1012628).
- block: take destination bvec offsets into account in
  bio_copy_data_iter (bsc#1012628).
- nbd: don't clear 'NBD_CMD_INFLIGHT' flag if request is not
  completed (bsc#1012628).
- nbd: fix possible overflow on 'first_minor' in nbd_dev_add()
  (bsc#1012628).
- riscv: read-only pages should not be writable (bsc#1012628).
- net/smc: fixes for converting from "struct smc_cdc_tx_pend **"
  to "struct smc_wr_tx_pend_priv *" (bsc#1012628).
- tcp: add accessors to read/set tp->snd_cwnd (bsc#1012628).
- nfp: only report pause frame configuration for physical device
  (bsc#1012628).
- block: use bio_queue_enter instead of blk_queue_enter in
  bio_poll (bsc#1012628).
- bonding: NS target should accept link local address
  (bsc#1012628).
- sfc: fix considering that all channels have TX queues
  (bsc#1012628).
- sfc: fix wrong tx channel offset with efx_separate_tx_channels
  (bsc#1012628).
- block: make bioset_exit() fully resilient against being called
  twice (bsc#1012628).
- sched/autogroup: Fix sysctl move (bsc#1012628).
- blk-mq: do not update io_ticks with passthrough requests
  (bsc#1012628).
- net: phy: at803x: disable WOL at probe (bsc#1012628).
- bonding: show NS IPv6 targets in proc master info (bsc#1012628).
- erofs: fix 'backmost' member of z_erofs_decompress_frontend
  (bsc#1012628).
- vdpa: Fix error logic in vdpa_nl_cmd_dev_get_doit (bsc#1012628).
- virtio: pci: Fix an error handling path in vp_modern_probe()
  (bsc#1012628).
- net/mlx5: Don't use already freed action pointer (bsc#1012628).
- net/mlx5e: TC NIC mode, fix tc chains miss table (bsc#1012628).
- net/mlx5: CT: Fix header-rewrite re-use for tupels
  (bsc#1012628).
- net/mlx5e: Disable softirq in mlx5e_activate_rq to avoid race
  condition (bsc#1012628).
- net/mlx5: correct ECE offset in query qp output (bsc#1012628).
- net/mlx5e: Update netdev features after changing XDP state
  (bsc#1012628).
- net: sched: add barrier to fix packet stuck problem for lockless
  qdisc (bsc#1012628).
- tcp: tcp_rtx_synack() can be called from process context
  (bsc#1012628).
- vdpa: ifcvf: set pci driver data in probe (bsc#1012628).
- bonding: guard ns_targets by CONFIG_IPV6 (bsc#1012628).
- octeontx2-af: fix error code in is_valid_offset() (bsc#1012628).
- s390/mcck: isolate SIE instruction when setting CIF_MCCK_GUEST
  flag (bsc#1012628).
- regulator: mt6315-regulator: fix invalid allowed mode
  (bsc#1012628).
- net: ping6: Fix ping -6 with interface name (bsc#1012628).
- net/sched: act_api: fix error code in
  tcf_ct_flow_table_fill_tuple_ipv6() (bsc#1012628).
- gpio: pca953x: use the correct register address to do regcache
  sync (bsc#1012628).
- afs: Fix infinite loop found by xfstest generic/676
  (bsc#1012628).
- drm/msm/dp: Always clear mask bits to disable interrupts at
  dp_ctrl_reset_irq_ctrl() (bsc#1012628).
- scsi: sd: Fix potential NULL pointer dereference (bsc#1012628).
- ax25: Fix ax25 session cleanup problems (bsc#1012628).
- nfp: remove padding in nfp_nfdk_tx_desc (bsc#1012628).
- tipc: check attribute length for bearer name (bsc#1012628).
- driver core: Fix wait_for_device_probe() &
  deferred_probe_timeout interaction (bsc#1012628).
- perf evsel: Fixes topdown events in a weak group for the hybrid
  platform (bsc#1012628).
- perf parse-events: Move slots event for the hybrid platform too
  (bsc#1012628).
- perf record: Support sample-read topdown metric group for
  hybrid platforms (bsc#1012628).
- perf c2c: Fix sorting in percent_rmt_hitm_cmp() (bsc#1012628).
- Bluetooth: MGMT: Add conditions for setting
  HCI_CONN_FLAG_REMOTE_WAKEUP (bsc#1012628).
- Bluetooth: hci_sync: Fix attempting to suspend with unfiltered
  passive scan (bsc#1012628).
- bluetooth: don't use bitmaps for random flag accesses
  (bsc#1012628).
- dmaengine: idxd: set DMA_INTERRUPT cap bit (bsc#1012628).
- mips: cpc: Fix refcount leak in mips_cpc_default_phys_base
  (bsc#1012628).
- bootconfig: Make the bootconfig.o as a normal object file
  (bsc#1012628).
- tracing: Make tp_printk work on syscall tracepoints
  (bsc#1012628).
- tracing: Fix sleeping function called from invalid context on
  RT kernel (bsc#1012628).
- tracing: Avoid adding tracer option before update_tracer_options
  (bsc#1012628).
- i2c: mediatek: Optimize master_xfer() and avoid circular locking
  (bsc#1012628).
- iommu/arm-smmu: fix possible null-ptr-deref in
  arm_smmu_device_probe() (bsc#1012628).
- iommu/arm-smmu-v3: check return value after calling
  platform_get_resource() (bsc#1012628).
- f2fs: remove WARN_ON in f2fs_is_valid_blkaddr (bsc#1012628).
- f2fs: avoid infinite loop to flush node pages (bsc#1012628).
- i2c: cadence: Increase timeout per message if necessary
  (bsc#1012628).
- m68knommu: set ZERO_PAGE() to the allocated zeroed page
  (bsc#1012628).
- m68knommu: fix undefined reference to `_init_sp' (bsc#1012628).
- dmaengine: zynqmp_dma: In struct zynqmp_dma_chan fix desc_size
  data type (bsc#1012628).
- NFSv4: Don't hold the layoutget locks across multiple RPC calls
  (bsc#1012628).
- video: fbdev: hyperv_fb: Allow resolutions with size > 64 MB
  for Gen1 (bsc#1012628).
- video: fbdev: pxa3xx-gcu: release the resources correctly in
  pxa3xx_gcu_probe/remove() (bsc#1012628).
- RISC-V: use memcpy for kexec_file mode (bsc#1012628).
- m68knommu: fix undefined reference to `mach_get_rtc_pll'
  (bsc#1012628).
- rtla/Makefile: Properly handle dependencies (bsc#1012628).
- f2fs: fix to tag gcing flag on page during file defragment
  (bsc#1012628).
- xprtrdma: treat all calls not a bcall when bc_serv is NULL
  (bsc#1012628).
- drm/bridge: ti-sn65dsi83: Handle dsi_lanes == 0 as invalid
  (bsc#1012628).
- drm/panfrost: Job should reference MMU not file_priv
  (bsc#1012628).
- powerpc/papr_scm: don't requests stats with '0' sized stats
  buffer (bsc#1012628).
- netfilter: nat: really support inet nat without l3 address
  (bsc#1012628).
- netfilter: nf_tables: use kfree_rcu(ptr, rcu) to release hooks
  in clean_net path (bsc#1012628).
- netfilter: nf_tables: delete flowtable hooks via transaction
  list (bsc#1012628).
- powerpc/kasan: Force thread size increase with KASAN
  (bsc#1012628).
- NFSD: Fix potential use-after-free in nfsd_file_put()
  (bsc#1012628).
- SUNRPC: Trap RDMA segment overflows (bsc#1012628).
- netfilter: nf_tables: always initialize flowtable hook list
  in transaction (bsc#1012628).
- ata: pata_octeon_cf: Fix refcount leak in octeon_cf_probe
  (bsc#1012628).
- netfilter: nf_tables: release new hooks on unsupported flowtable
  flags (bsc#1012628).
- netfilter: nf_tables: memleak flow rule from commit path
  (bsc#1012628).
- netfilter: nf_tables: bail out early if hardware offload is
  not supported (bsc#1012628).
- amt: fix wrong usage of pskb_may_pull() (bsc#1012628).
- amt: fix possible null-ptr-deref in amt_rcv() (bsc#1012628).
- amt: fix wrong type string definition (bsc#1012628).
- net: ethernet: bgmac: Fix refcount leak in
  bcma_mdio_mii_register (bsc#1012628).
- xen: unexport __init-annotated xen_xlate_map_ballooned_pages()
  (bsc#1012628).
- stmmac: intel: Fix an error handling path in
  intel_eth_pci_probe() (bsc#1012628).
- af_unix: Fix a data-race in unix_dgram_peer_wake_me()
  (bsc#1012628).
- selftests net: fix bpf build error (bsc#1012628).
- x86: drop bogus "cc" clobber from __try_cmpxchg_user_asm()
  (bsc#1012628).
- bpf, arm64: Clear prog->jited_len along prog->jited
  (bsc#1012628).
- net: dsa: lantiq_gswip: Fix refcount leak in gswip_gphy_fw_list
  (bsc#1012628).
- net/mlx4_en: Fix wrong return value on ioctl EEPROM query
  failure (bsc#1012628).
- xsk: Fix handling of invalid descriptors in XSK TX batching API
  (bsc#1012628).
- drm/amdgpu: fix limiting AV1 to the first instance on VCN3
  (bsc#1012628).
- SUNRPC: Fix the calculation of xdr->end in
  xdr_get_next_encode_buffer() (bsc#1012628).
- net: mdio: unexport __init-annotated mdio_bus_init()
  (bsc#1012628).
- net: xfrm: unexport __init-annotated xfrm4_protocol_init()
  (bsc#1012628).
- net: ipv6: unexport __init-annotated seg6_hmac_init()
  (bsc#1012628).
- net/mlx5e: CT: Fix cleanup of CT before cleanup of TC ct rules
  (bsc#1012628).
- net/mlx5: Lag, filter non compatible devices (bsc#1012628).
- net/mlx5: Fix mlx5_get_next_dev() peer device matching
  (bsc#1012628).
- net/mlx5: Rearm the FW tracer after each tracer event
  (bsc#1012628).
- net/mlx5: fs, fail conflicting actions (bsc#1012628).
- ip_gre: test csum_start instead of transport header
  (bsc#1012628).
- net: altera: Fix refcount leak in altera_tse_mdio_create
  (bsc#1012628).
- net: dsa: mv88e6xxx: use BMSR_ANEGCOMPLETE bit for filling
  an_complete (bsc#1012628).
- net: dsa: realtek: rtl8365mb: fix GMII caps for ports with
  internal PHY (bsc#1012628).
- tcp: use alloc_large_system_hash() to allocate table_perturb
  (bsc#1012628).
- drm: imx: fix compiler warning with gcc-12 (bsc#1012628).
- nfp: flower: restructure flow-key for gre+vlan combination
  (bsc#1012628).
- net: seg6: fix seg6_lookup_any_nexthop() to handle VRFs using
  flowi_l3mdev (bsc#1012628).
- iov_iter: Fix iter_xarray_get_pages{,_alloc}() (bsc#1012628).
- iio: dummy: iio_simple_dummy: check the return value of
  kstrdup() (bsc#1012628).
- staging: rtl8712: fix a potential memory leak in
  r871xu_drv_init() (bsc#1012628).
- iio: st_sensors: Add a local lock for protecting odr
  (bsc#1012628).
- lkdtm/usercopy: Expand size of "out of frame" object
  (bsc#1012628).
- drivers: staging: rtl8723bs: Fix deadlock in
  rtw_surveydone_event_callback() (bsc#1012628).
- drivers: staging: rtl8192bs: Fix deadlock in
  rtw_joinbss_event_prehandle() (bsc#1012628).
- drivers: staging: rtl8192eu: Fix deadlock in
  rtw_joinbss_event_prehandle (bsc#1012628).
- tty: synclink_gt: Fix null-pointer-dereference in slgt_clean()
  (bsc#1012628).
- tty: Fix a possible resource leak in icom_probe (bsc#1012628).
- thunderbolt: Use different lane for second DisplayPort tunnel
  (bsc#1012628).
- drivers: staging: rtl8192u: Fix deadlock in
  ieee80211_beacons_stop() (bsc#1012628).
- drivers: staging: rtl8192e: Fix deadlock in
  rtllib_beacons_stop() (bsc#1012628).
- USB: host: isp116x: check return value after calling
  platform_get_resource() (bsc#1012628).
- drivers: tty: serial: Fix deadlock in sa1100_set_termios()
  (bsc#1012628).
- drivers: usb: host: Fix deadlock in oxu_bus_suspend()
  (bsc#1012628).
- USB: hcd-pci: Fully suspend across freeze/thaw cycle
  (bsc#1012628).
- char: xillybus: fix a refcount leak in cleanup_dev()
  (bsc#1012628).
- sysrq: do not omit current cpu when showing backtrace of all
  active CPUs (bsc#1012628).
- usb: dwc2: gadget: don't reset gadget's driver->bus
  (bsc#1012628).
- usb: dwc3: host: Stop setting the ACPI companion (bsc#1012628).
- usb: dwc3: gadget: Only End Transfer for ep0 data phase
  (bsc#1012628).
- soundwire: qcom: adjust autoenumeration timeout (bsc#1012628).
- misc: rtsx: set NULL intfdata when probe fails (bsc#1012628).
- extcon: Fix extcon_get_extcon_dev() error handling
  (bsc#1012628).
- extcon: Modify extcon device to be created after driver data
  is set (bsc#1012628).
- clocksource/drivers/sp804: Avoid error on multiple instances
  (bsc#1012628).
- staging: rtl8712: fix uninit-value in usb_read8() and friends
  (bsc#1012628).
- staging: rtl8712: fix uninit-value in r871xu_drv_init()
  (bsc#1012628).
- serial: msm_serial: disable interrupts in __msm_console_write()
  (bsc#1012628).
- kernfs: Separate kernfs_pr_cont_buf and rename_lock
  (bsc#1012628).
- watchdog: wdat_wdt: Stop watchdog when rebooting the system
  (bsc#1012628).
- ksmbd: smbd: fix connection dropped issue (bsc#1012628).
- md: protect md_unregister_thread from reentrancy (bsc#1012628).
- ASoC: SOF: amd: Fixed Build error (bsc#1012628).
- scsi: myrb: Fix up null pointer access on myrb_cleanup()
  (bsc#1012628).
- ASoC: rt5640: Do not manipulate pin "Platform Clock" if the
  "Platform Clock" is not in the DAPM (bsc#1012628).
- ceph: allow ceph.dir.rctime xattr to be updatable (bsc#1012628).
- ceph: flush the mdlog for filesystem sync (bsc#1012628).
- ceph: fix possible deadlock when holding Fwb to get inline_data
  (bsc#1012628).
- net, neigh: Set lower cap for neigh_managed_work rearming
  (bsc#1012628).
- drm/amd/display: Check if modulo is 0 before dividing
  (bsc#1012628).
- drm/amd/display: Check zero planes for OTG disable W/A on
  clock change (bsc#1012628).
- drm/radeon: fix a possible null pointer dereference
  (bsc#1012628).
- drm/amd/pm: fix a potential gpu_metrics_table memory leak
  (bsc#1012628).
- drm/amd/pm: Fix missing thermal throttler status (bsc#1012628).
- drm/amd/pm: correct the metrics version for SMU 11.0.11/12/13
  (bsc#1012628).
- um: line: Use separate IRQs per line (bsc#1012628).
- modpost: fix undefined behavior of is_arm_mapping_symbol()
  (bsc#1012628).
- objtool: Mark __ubsan_handle_builtin_unreachable() as noreturn
  (bsc#1012628).
- x86/cpu: Elide KCSAN for cpu_has() and friends (bsc#1012628).
- jump_label,noinstr: Avoid instrumentation for JUMP_LABEL=n
  builds (bsc#1012628).
- nbd: call genl_unregister_family() first in nbd_cleanup()
  (bsc#1012628).
- nbd: fix race between nbd_alloc_config() and module removal
  (bsc#1012628).
- nbd: fix io hung while disconnecting device (bsc#1012628).
- Revert "PCI: brcmstb: Do not turn off WOL regulators on suspend"
  (bsc#1012628).
- Revert "PCI: brcmstb: Add control of subdevice voltage
  regulators" (bsc#1012628).
- Revert "PCI: brcmstb: Add mechanism to turn on subdev
  regulators" (bsc#1012628).
- Revert "PCI: brcmstb: Split brcm_pcie_setup() into two funcs"
  (bsc#1012628).
- cifs: fix potential deadlock in direct reclaim (bsc#1012628).
- s390/gmap: voluntarily schedule during key setting
  (bsc#1012628).
- cifs: version operations for smb20 unneeded when legacy support
  disabled (bsc#1012628).
- drm/amd/pm: use bitmap_{from,to}_arr32 where appropriate
  (bsc#1012628).
- nodemask: Fix return values to be unsigned (bsc#1012628).
- scsi: lpfc: Correct BDE type for XMIT_SEQ64_WQE in
  lpfc_ct_reject_event() (bsc#1012628).
- vringh: Fix loop descriptors check in the indirect cases
  (bsc#1012628).
- platform/x86: barco-p50-gpio: Add check for
  platform_driver_register (bsc#1012628).
- scripts/gdb: change kernel config dumping method (bsc#1012628).
- platform/x86: hp-wmi: Resolve WMI query failures on some devices
  (bsc#1012628).
- platform/x86: hp-wmi: Use zero insize parameter only when
  supported (bsc#1012628).
- ALSA: usb-audio: Skip generic sync EP parse for secondary EP
  (bsc#1012628).
- ALSA: usb-audio: Set up (implicit) sync for Saffire 6
  (bsc#1012628).
- ALSA: hda/conexant - Fix loopback issue with CX20632
  (bsc#1012628).
- ALSA: hda/realtek: Fix for quirk to enable speaker output on
  the Lenovo Yoga DuetITL 2021 (bsc#1012628).
- ALSA: hda/realtek: Add quirk for HP Dev One (bsc#1012628).
- cifs: return errors during session setup during reconnects
  (bsc#1012628).
- cifs: fix reconnect on smb3 mount types (bsc#1012628).
- cifs: populate empty hostnames for extra channels (bsc#1012628).
- scsi: sd: Fix interpretation of VPD B9h length (bsc#1012628).
- scsi: lpfc: Resolve some cleanup issues following abort path
  refactoring (bsc#1012628).
- scsi: lpfc: Resolve some cleanup issues following SLI path
  refactoring (bsc#1012628).
- scsi: lpfc: Address NULL pointer dereference after
  starget_to_rport() (bsc#1012628).
- KVM: x86/mmu: Check every prev_roots in
  __kvm_mmu_free_obsolete_roots() (bsc#1012628).
- KVM: SVM: fix tsc scaling cache logic (bsc#1012628).
- filemap: Cache the value of vm_flags (bsc#1012628).
- KEYS: trusted: tpm2: Fix migratable logic (bsc#1012628).
- libata: fix reading concurrent positioning ranges log
  (bsc#1012628).
- libata: fix translation of concurrent positioning ranges
  (bsc#1012628).
- ata: libata-transport: fix {dma|pio|xfer}_mode sysfs files
  (bsc#1012628).
- mmc: sdhci-pci-gli: Fix GL9763E runtime PM when the system
  resumes from suspend (bsc#1012628).
- mmc: block: Fix CQE recovery reset success (bsc#1012628).
- net: phy: dp83867: retrigger SGMII AN when link change
  (bsc#1012628).
- net: openvswitch: fix misuse of the cached connection on tuple
  changes (bsc#1012628).
- writeback: Fix inode->i_io_list not be protected by
  inode->i_lock error (bsc#1012628).
- nfc: st21nfca: fix incorrect validating logic in EVT_TRANSACTION
  (bsc#1012628).
- nfc: st21nfca: fix memory leaks in EVT_TRANSACTION handling
  (bsc#1012628).
- nfc: st21nfca: fix incorrect sizing calculations in
  EVT_TRANSACTION (bsc#1012628).
- ixgbe: fix bcast packets Rx on VF after promisc removal
  (bsc#1012628).
- ixgbe: fix unexpected VLAN Rx in promisc mode on VF
  (bsc#1012628).
- Input: bcm5974 - set missing URB_NO_TRANSFER_DMA_MAP urb flag
  (bsc#1012628).
- vduse: Fix NULL pointer dereference on sysfs access
  (bsc#1012628).
- cpuidle,intel_idle: Fix CPUIDLE_FLAG_IRQ_ENABLE (bsc#1012628).
- mm/huge_memory: Fix xarray node memory leak (bsc#1012628).
- powerpc: Don't select HAVE_IRQ_EXIT_ON_IRQ_STACK (bsc#1012628).
- drm/amdkfd:Fix fw version for 10.3.6 (bsc#1012628).
- drm/bridge: analogix_dp: Support PSR-exit to disable transition
  (bsc#1012628).
- drm/atomic: Force bridge self-refresh-exit on CRTC switch
  (bsc#1012628).
- drm/amdgpu/jpeg2: Add jpeg vmid update under IB submit
  (bsc#1012628).
- drm/amd/display: remove stale config guards (bsc#1012628).
- drm/amdgpu: update VCN codec support for Yellow Carp
  (bsc#1012628).
- virtio-rng: make device ready before making request
  (bsc#1012628).
- powerpc/32: Fix overread/overwrite of thread_struct via ptrace
  (bsc#1012628).
- random: avoid checking crng_ready() twice in random_init()
  (bsc#1012628).
- random: mark bootloader randomness code as __init (bsc#1012628).
- random: account for arch randomness in bits (bsc#1012628).
- md/raid0: Ignore RAID0 layout if the second zone has only one
  device (bsc#1012628).
- zonefs: fix handling of explicit_open option on mount
  (bsc#1012628).
- iov_iter: fix build issue due to possible type mis-match
  (bsc#1012628).
- dmaengine: idxd: add missing callback function to support
  DMA_INTERRUPT (bsc#1012628).
- tcp: fix tcp_mtup_probe_success vs wrong snd_cwnd (bsc#1012628).
- net/mlx5: E-Switch, pair only capable devices (bsc#1012628).
- Update config files.
- commit c6d8e6e
* Tue Jun 14 2022 mkubecek@suse.cz
- kernel-binary.spec: check s390x vmlinux location
  As a side effect of mainline commit edd4a8667355 ("s390/boot: get rid of
  startup archive"), vmlinux on s390x moved from "compressed" subdirectory
  directly into arch/s390/boot. As the specfile is shared among branches,
  check both locations and let objcopy use one that exists.
- commit cd15543
* Tue Jun 14 2022 tiwai@suse.de
- Add missing recommends of kernel-install-tools to kernel-source-vanilla (bsc#1200442)
- commit 93b1375
* Mon Jun 13 2022 tzimmermann@suse.de
- drm/format-helper: Add RGB565-to-XRGB8888 conversion (boo#1193472)
- commit b55db46
* Mon Jun 13 2022 tzimmermann@suse.de
- drm/format-helper: Add RGB888-to-XRGB8888 conversion (boo#1193472)
- commit 24daa98
* Mon Jun 13 2022 tzimmermann@suse.de
- drm/format-helper: Print warning on missing format conversion (boo#1193472)
- commit 4895b27
* Mon Jun 13 2022 mkubecek@suse.cz
- config: add CC_NO_ARRAY_BOUNDS=y
  Mainline commit f0be87c42cbd ("gcc-12: disable '-Warray-bounds' universally
  for now") adds new config option CONFIG_CC_NO_ARRAY_BOUNDS which is only
  present for gcc12 (and not future gcc >= 13). Therefore it is not added
  with dummy gcc which pretends to be gcc20 but it is with Factory gcc12,
  resulting in failed "missing config option" check.
  As a quick hack, add CONFIG_CC_NO_ARRAY_BOUNDS=y to all full configs until
  we have a more robust solution (manually added config option won't survive
  a config update with run_oldconfig.sh).
- commit b2fb712
* Mon Jun 13 2022 mkubecek@suse.cz
- config: refresh
- commit dbcb5bd
* Mon Jun 13 2022 mkubecek@suse.cz
- Update to 5.19-rc2
- drop obsolete patch
  - patches.suse/drm-amdgpu-always-flush-the-TLB-on-gfx8.patch
- update configs
  - XEN_VIRTIO=y (x86 only)
- commit 02193c9
* Fri Jun 10 2022 tzimmermann@suse.de
- Add parameter to disable simple-framebuffer devices (boo#1193472)
  Temporary workaround for simpledrm bugs.
- commit 1d1dbce
* Fri Jun 10 2022 tzimmermann@suse.de
- drivers/firmware: skip simpledrm if nvidia-drm.modeset=1 is set (boo#1193472)
  Temporary workaround for nvidia.ko with simpledrm.
- commit c35bbe0
* Fri Jun 10 2022 tzimmermann@suse.de
- drm/client: Don't add new command-line mode (boo#1193472)
  Backported for simpledrm support.
- commit 141a4fc
* Fri Jun 10 2022 tzimmermann@suse.de
- drm/client: Look for command-line modes first (boo#1193472)
  Backported for simpledrm support.
- commit 1bf947f
* Fri Jun 10 2022 tzimmermann@suse.de
- drm: Always warn if user-defined modes are not supported (boo#1193472)
  Backported for simpledrm support.
- commit 95c4112
* Thu Jun  9 2022 jslaby@suse.cz
- Linux 5.18.3 (bsc#1012628).
- binfmt_flat: do not stop relocating GOT entries prematurely
  on riscv (bsc#1012628).
- parisc: fix a crash with multicore scheduler (bsc#1012628).
- parisc/stifb: Implement fb_is_primary_device() (bsc#1012628).
- parisc/stifb: Keep track of hardware path of graphics card
  (bsc#1012628).
- RISC-V: Mark IORESOURCE_EXCLUSIVE for reserved mem instead of
  IORESOURCE_BUSY (bsc#1012628).
- riscv: Initialize thread pointer before calling C functions
  (bsc#1012628).
- riscv: Fix irq_work when SMP is disabled (bsc#1012628).
- riscv: Wire up memfd_secret in UAPI header (bsc#1012628).
- riscv: Move alternative length validation into subsection
  (bsc#1012628).
- ALSA: hda/realtek - Add new type for ALC245 (bsc#1012628).
- ALSA: hda/realtek: Enable 4-speaker output for Dell XPS 15
  9520 laptop (bsc#1012628).
- ALSA: hda/realtek - Fix microphone noise on ASUS TUF B550M-PLUS
  (bsc#1012628).
- ALSA: usb-audio: Cancel pending work at closing a MIDI substream
  (bsc#1012628).
- USB: serial: pl2303: fix type detection for odd device
  (bsc#1012628).
- USB: serial: option: add Quectel BG95 modem (bsc#1012628).
- USB: new quirk for Dell Gen 2 devices (bsc#1012628).
- usb: isp1760: Fix out-of-bounds array access (bsc#1012628).
- usb: dwc3: gadget: Move null pinter check to proper place
  (bsc#1012628).
- usb: core: hcd: Add support for deferring roothub registration
  (bsc#1012628).
- fs/ntfs3: provide block_invalidate_folio to fix memory leak
  (bsc#1012628).
- fs/ntfs3: Update valid size if -EIOCBQUEUED (bsc#1012628).
- fs/ntfs3: Fix fiemap + fix shrink file size (to remove
  preallocated space) (bsc#1012628).
- fs/ntfs3: Keep preallocated only if option prealloc enabled
  (bsc#1012628).
- fs/ntfs3: Check new size for limits (bsc#1012628).
- fs/ntfs3: In function ntfs_set_acl_ex do not change
  inode->i_mode if called from function ntfs_init_acl
  (bsc#1012628).
- fs/ntfs3: Fix some memory leaks in an error handling path of
  'log_replay()' (bsc#1012628).
- fs/ntfs3: Update i_ctime when xattr is added (bsc#1012628).
- fs/ntfs3: Restore ntfs_xattr_get_acl and ntfs_xattr_set_acl
  functions (bsc#1012628).
- cifs: don't call cifs_dfs_query_info_nonascii_quirk() if nodfs
  was set (bsc#1012628).
- cifs: fix ntlmssp on old servers (bsc#1012628).
- cifs: fix potential double free during failed mount
  (bsc#1012628).
- cifs: when extending a file with falloc we should make files
  not-sparse (bsc#1012628).
- xhci: Set HCD flag to defer primary roothub registration
  (bsc#1012628).
- xhci: Allow host runtime PM as default for Intel Alder Lake
  N xHCI (bsc#1012628).
- platform/x86: intel-hid: fix _DSM function index handling
  (bsc#1012628).
- x86/MCE/AMD: Fix memory leak when threshold_create_bank()
  fails (bsc#1012628).
- perf/x86/intel: Fix event constraints for ICL (bsc#1012628).
- x86/kexec: fix memory leak of elf header buffer (bsc#1012628).
- x86/sgx: Set active memcg prior to shmem allocation
  (bsc#1012628).
- kthread: Don't allocate kthread_struct for init and umh
  (bsc#1012628).
- ptrace/um: Replace PT_DTRACE with TIF_SINGLESTEP (bsc#1012628).
- ptrace/xtensa: Replace PT_SINGLESTEP with TIF_SINGLESTEP
  (bsc#1012628).
- ptrace: Reimplement PTRACE_KILL by always sending SIGKILL
  (bsc#1012628).
- btrfs: add "0x" prefix for unsupported optional features
  (bsc#1012628).
- btrfs: return correct error number for __extent_writepage_io()
  (bsc#1012628).
- btrfs: repair super block num_devices automatically
  (bsc#1012628).
- btrfs: fix the error handling for submit_extent_page() for
  btrfs_do_readpage() (bsc#1012628).
- btrfs: fix deadlock between concurrent dio writes when low on
  free data space (bsc#1012628).
- btrfs: zoned: properly finish block group on metadata write
  (bsc#1012628).
- btrfs: zoned: zone finish unused block group (bsc#1012628).
- btrfs: zoned: finish block group when there are no more
  allocatable bytes left (bsc#1012628).
- btrfs: zoned: fix comparison of alloc_offset vs
  meta_write_pointer (bsc#1012628).
- iommu/vt-d: Add RPLS to quirk list to skip TE disabling
  (bsc#1012628).
- drm/selftests: fix a shift-out-of-bounds bug (bsc#1012628).
- drm/vmwgfx: validate the screen formats (bsc#1012628).
- ath11k: fix the warning of dev_wake in
  mhi_pm_disable_transition() (bsc#1012628).
- drm/virtio: fix NULL pointer dereference in
  virtio_gpu_conn_get_modes (bsc#1012628).
- selftests/bpf: Fix vfs_link kprobe definition (bsc#1012628).
- selftests/bpf: Fix parsing of prog types in UAPI hdr for
  bpftool sync (bsc#1012628).
- ath11k: Change max no of active probe SSID and BSSID to fw
  capability (bsc#1012628).
- selftests/bpf: Fix file descriptor leak in load_kallsyms()
  (bsc#1012628).
- rtw89: ser: fix CAM leaks occurring in L2 reset (bsc#1012628).
- rtw89: fix misconfiguration on hw_scan channel time
  (bsc#1012628).
- mwifiex: add mutex lock for call in
  mwifiex_dfs_chan_sw_work_queue (bsc#1012628).
- b43legacy: Fix assigning negative value to unsigned variable
  (bsc#1012628).
- b43: Fix assigning negative value to unsigned variable
  (bsc#1012628).
- ipw2x00: Fix potential NULL dereference in libipw_xmit()
  (bsc#1012628).
- ipv6: fix locking issues with loops over idev->addr_list
  (bsc#1012628).
- fbcon: Consistently protect deferred_takeover with
  console_lock() (bsc#1012628).
- x86/platform/uv: Update TSC sync state for UV5 (bsc#1012628).
- ACPICA: Avoid cache flush inside virtual machines (bsc#1012628).
- libbpf: Fix a bug with checking bpf_probe_read_kernel()
  support in old kernels (bsc#1012628).
- mac80211: minstrel_ht: fix where rate stats are stored (fixes
  debugfs output) (bsc#1012628).
- drm/komeda: return early if drm_universal_plane_init() fails
  (bsc#1012628).
- drm/amd/display: Disabling Z10 on DCN31 (bsc#1012628).
- rcu-tasks: Fix race in schedule and flush work (bsc#1012628).
- rcu-tasks: Handle sparse cpu_possible_mask in
  rcu_tasks_invoke_cbs() (bsc#1012628).
- rcu: Make TASKS_RUDE_RCU select IRQ_WORK (bsc#1012628).
- sfc: ef10: Fix assigning negative value to unsigned variable
  (bsc#1012628).
- ALSA: jack: Access input_dev under mutex (bsc#1012628).
- rtw88: fix incorrect frequency reported (bsc#1012628).
- rtw88: 8821c: fix debugfs rssi value (bsc#1012628).
- spi: spi-rspi: Remove setting {src,dst}_{addr,addr_width}
  based on DMA direction (bsc#1012628).
- tools/power turbostat: fix ICX DRAM power numbers (bsc#1012628).
- tcp: consume incoming skb leading to a reset (bsc#1012628).
- loop: implement ->free_disk (bsc#1012628).
- scsi: lpfc: Move cfg_log_verbose check before calling
  lpfc_dmp_dbg() (bsc#1012628).
- scsi: lpfc: Fix SCSI I/O completion and abort handler deadlock
  (bsc#1012628).
- scsi: lpfc: Fix null pointer dereference after failing to
  issue FLOGI and PLOGI (bsc#1012628).
- scsi: lpfc: Protect memory leak for NPIV ports sending PLOGI_RJT
  (bsc#1012628).
- scsi: lpfc: Fix call trace observed during I/O with CMF enabled
  (bsc#1012628).
- cpuidle: PSCI: Improve support for suspend-to-RAM for PSCI
  OSI mode (bsc#1012628).
- drm/amdgpu/pm: fix the null pointer while the smu is disabled
  (bsc#1012628).
- drm/amd/pm: fix double free in si_parse_power_table()
  (bsc#1012628).
- ASoC: rsnd: care default case on
  rsnd_ssiu_busif_err_status_clear() (bsc#1012628).
- ASoC: rsnd: care return value from rsnd_node_fixed_index()
  (bsc#1012628).
- net: macb: In ZynqMP initialization make SGMII phy configuration
  optional (bsc#1012628).
- ath9k: fix QCA9561 PA bias level (bsc#1012628).
- media: Revert "media: dw9768: activate runtime PM and turn
  off device" (bsc#1012628).
- media: i2c: dw9714: Disable the regulator when the driver
  fails to probe (bsc#1012628).
- media: venus: hfi: avoid null dereference in deinit
  (bsc#1012628).
- media: venus: do not queue internal buffers from previous
  sequence (bsc#1012628).
- media: pci: cx23885: Fix the error handling in cx23885_initdev()
  (bsc#1012628).
- media: cx25821: Fix the warning when removing the module
  (bsc#1012628).
- md/bitmap: don't set sb values if can't pass sanity check
  (bsc#1012628).
- mmc: jz4740: Apply DMA engine limits to maximum segment size
  (bsc#1012628).
- drivers: mmc: sdhci_am654: Add the quirk to set TESTCD bit
  (bsc#1012628).
- scsi: megaraid: Fix error check return value of
  register_chrdev() (bsc#1012628).
- drm/amdgpu/sdma: Fix incorrect calculations of the wptr of
  the doorbells (bsc#1012628).
- scsi: ufs: Use pm_runtime_resume_and_get() instead of
  pm_runtime_get_sync() (bsc#1012628).
- scsi: lpfc: Fix resource leak in lpfc_sli4_send_seq_to_ulp()
  (bsc#1012628).
- ath11k: disable spectral scan during spectral deinit
  (bsc#1012628).
- ASoC: Intel: bytcr_rt5640: Add quirk for the HP Pro Tablet 408
  (bsc#1012628).
- drm/plane: Move range check for format_count earlier
  (bsc#1012628).
- drm/amdkfd: Fix circular lock dependency warning (bsc#1012628).
- drm/amd/pm: fix the compile warning (bsc#1012628).
- ath10k: skip ath10k_halt during suspend for driver state
  RESTARTING (bsc#1012628).
- arm64: compat: Do not treat syscall number as ESR_ELx for a
  bad syscall (bsc#1012628).
- drm: msm: fix error check return value of irq_of_parse_and_map()
  (bsc#1012628).
- drm/msm/dpu: Clean up CRC debug logs (bsc#1012628).
- xtensa: move trace_hardirqs_off call back to entry.S
  (bsc#1012628).
- ath11k: fix warning of not found station for bssid in message
  (bsc#1012628).
- scsi: target: tcmu: Fix possible data corruption (bsc#1012628).
- ipv6: Don't send rs packets to the interface of ARPHRD_TUNNEL
  (bsc#1012628).
- net/mlx5: use kvfree() for kvzalloc() in
  mlx5_ct_fs_smfs_matcher_create (bsc#1012628).
- net/mlx5: fs, delete the FTE when there are no rules attached
  to it (bsc#1012628).
- ASoC: dapm: Don't fold register value changes into notifications
  (bsc#1012628).
- ASoC: SOF: ipc3-topology: Correct get_control_data for non
  bytes payload (bsc#1012628).
- mlxsw: spectrum_dcb: Do not warn about priority changes
  (bsc#1012628).
- mlxsw: Treat LLDP packets as control (bsc#1012628).
- drm/amdgpu/psp: move PSP memory alloc from hw_init to sw_init
  (bsc#1012628).
- drm/amdgpu/ucode: Remove firmware load type check in
  amdgpu_ucode_free_bo (bsc#1012628).
- regulator: mt6315: Enforce regulator-compatible, not name
  (bsc#1012628).
- ice: always check VF VSI pointer values (bsc#1012628).
- HID: bigben: fix slab-out-of-bounds Write in bigben_probe
  (bsc#1012628).
- drm/tegra: gem: Do not try to dereference ERR_PTR()
  (bsc#1012628).
- of: Support more than one crash kernel regions for kexec -s
  (bsc#1012628).
- ASoC: tscs454: Add endianness flag in snd_soc_component_driver
  (bsc#1012628).
- net/mlx5: Increase FW pre-init timeout for health recovery
  (bsc#1012628).
- ASoC: Intel: sof_ssp_amp: fix no DMIC BE Link on Chromebooks
  (bsc#1012628).
- scsi: hisi_sas: Undo RPM resume for failed notify phy event
  for v3 HW (bsc#1012628).
- scsi: lpfc: Inhibit aborts if external loopback plug is inserted
  (bsc#1012628).
- scsi: lpfc: Alter FPIN stat accounting logic (bsc#1012628).
- net: remove two BUG() from skb_checksum_help() (bsc#1012628).
- s390/preempt: disable __preempt_count_add() optimization for
  PROFILE_ALL_BRANCHES (bsc#1012628).
- perf/amd/ibs: Cascade pmu init functions' return value
  (bsc#1012628).
- sched/core: Avoid obvious double update_rq_clock warning
  (bsc#1012628).
- spi: stm32-qspi: Fix wait_cmd timeout in APM mode (bsc#1012628).
- dma-debug: change allocation mode from GFP_NOWAIT to GFP_ATIOMIC
  (bsc#1012628).
- fs: hold writers when changing mount's idmapping (bsc#1012628).
- ASoC: SOF: amd: add missing platform_device_unregister in
  acp_pci_rn_probe (bsc#1012628).
- ACPI: PM: Block ASUS B1400CEAE from suspend to idle by default
  (bsc#1012628).
- ipmi:ssif: Check for NULL msg when handling events and messages
  (bsc#1012628).
- ipmi: Add an intializer for ipmi_smi_msg struct (bsc#1012628).
- ipmi: Fix pr_fmt to avoid compilation issues (bsc#1012628).
- kunit: bail out of test filtering logic quicker if OOM
  (bsc#1012628).
- rtlwifi: Use pr_warn instead of WARN_ONCE (bsc#1012628).
- mt76: mt7915: accept rx frames with non-standard VHT MCS10-11
  (bsc#1012628).
- mt76: mt7921: accept rx frames with non-standard VHT MCS10-11
  (bsc#1012628).
- mt76: fix encap offload ethernet type check (bsc#1012628).
- media: rga: fix possible memory leak in rga_probe (bsc#1012628).
- media: coda: limit frame interval enumeration to supported
  encoder frame sizes (bsc#1012628).
- media: hantro: HEVC: unconditionnaly set pps_{cb/cr}_qp_offset
  values (bsc#1012628).
- media: ccs-core.c: fix failure to call clk_disable_unprepare
  (bsc#1012628).
- media: imon: reorganize serialization (bsc#1012628).
- media: cec-adap.c: fix is_configuring state (bsc#1012628).
- usbnet: Run unregister_netdev() before unbind() again
  (bsc#1012628).
- Bluetooth: HCI: Add HCI_QUIRK_BROKEN_ENHANCED_SETUP_SYNC_CONN
  quirk (bsc#1012628).
- Bluetooth: btusb: Set HCI_QUIRK_BROKEN_ENHANCED_SETUP_SYNC_CONN
  for QCA (bsc#1012628).
- Bluetooth: btusb: Set HCI_QUIRK_BROKEN_ERR_DATA_REPORTING for
  QCA (bsc#1012628).
- bnxt_en: Configure ptp filters during bnxt open (bsc#1012628).
- media: mediatek: vcodec: prevent kernel crash when rmmod
  mtk-vcodec-dec.ko (bsc#1012628).
- openrisc: start CPU timer early in boot (bsc#1012628).
- nvme-pci: fix a NULL pointer dereference in
  nvme_alloc_admin_tags (bsc#1012628).
- ASoC: rt5645: Fix errorenous cleanup order (bsc#1012628).
- nbd: Fix hung on disconnect request if socket is closed before
  (bsc#1012628).
- drm/amd/pm: update smartshift powerboost calc for smu12
  (bsc#1012628).
- drm/amd/pm: update smartshift powerboost calc for smu13
  (bsc#1012628).
- drm/amdgpu: Move mutex_init(&smu->message_lock) to
  smu_early_init() (bsc#1012628).
- btrfs: fix anon_dev leak in create_subvol() (bsc#1012628).
- kunit: tool: make parser stop overwriting status of suites w/
  no_tests (bsc#1012628).
- net: phy: micrel: Allow probing without .driver_data
  (bsc#1012628).
- media: exynos4-is: Fix compile warning (bsc#1012628).
- media: hantro: Stop using H.264 parameter pic_num (bsc#1012628).
- rtw89: cfo: check mac_id to avoid out-of-bounds (bsc#1012628).
- of/fdt: Ignore disabled memory nodes (bsc#1012628).
- blk-throttle: Set BIO_THROTTLED when bio has been throttled
  (bsc#1012628).
- ASoC: max98357a: remove dependency on GPIOLIB (bsc#1012628).
- ASoC: rt1015p: remove dependency on GPIOLIB (bsc#1012628).
- ACPI: CPPC: Assume no transition latency if no PCCT
  (bsc#1012628).
- nvme: set non-mdts limits in nvme_scan_work (bsc#1012628).
- can: mcp251xfd: silence clang's -Wunaligned-access warning
  (bsc#1012628).
- x86/microcode: Add explicit CPU vendor dependency (bsc#1012628).
- net: ipa: ignore endianness if there is no header (bsc#1012628).
- selftests/bpf: Add missing trampoline program type to
  trampoline_count test (bsc#1012628).
- m68k: atari: Make Atari ROM port I/O write macros return void
  (bsc#1012628).
- hwmon: (pmbus) Add get_voltage/set_voltage ops (bsc#1012628).
- rxrpc: Return an error to sendmsg if call failed (bsc#1012628).
- rxrpc, afs: Fix selection of abort codes (bsc#1012628).
- afs: Adjust ACK interpretation to try and cope with NAT
  (bsc#1012628).
- eth: tg3: silence the GCC 12 array-bounds warning (bsc#1012628).
- char: tpm: cr50_i2c: Suppress duplicated error message in
  .remove() (bsc#1012628).
- selftests/bpf: fix btf_dump/btf_dump due to recent clang change
  (bsc#1012628).
- gfs2: use i_lock spin_lock for inode qadata (bsc#1012628).
- linux/types.h: reinstate "__bitwise__" macro for user space use
  (bsc#1012628).
- scsi: target: tcmu: Avoid holding XArray lock when calling
  lock_page (bsc#1012628).
- kunit: fix executor OOM error handling logic on non-UML
  (bsc#1012628).
- IB/rdmavt: add missing locks in rvt_ruc_loopback (bsc#1012628).
- PCI/ASPM: Make Intel DG2 L1 acceptable latency unlimited
  (bsc#1012628).
- ARM: dts: ox820: align interrupt controller node name with
  dtschema (bsc#1012628).
- ARM: dts: socfpga: align interrupt controller node name with
  dtschema (bsc#1012628).
- ARM: dts: s5pv210: align DMA channels with dtschema
  (bsc#1012628).
- ASoC: amd: Add driver data to acp6x machine driver
  (bsc#1012628).
- arm64: dts: qcom: msm8994: Fix the cont_splash_mem address
  (bsc#1012628).
- arm64: dts: qcom: msm8994: Fix BLSP[12]_DMA channels count
  (bsc#1012628).
- PM / devfreq: rk3399_dmc: Disable edev on remove()
  (bsc#1012628).
- crypto: ccree - use fine grained DMA mapping dir (bsc#1012628).
- crypto: qat - fix off-by-one error in PFVF debug print
  (bsc#1012628).
- soc: ti: ti_sci_pm_domains: Check for null return of
  devm_kcalloc (bsc#1012628).
- fs: jfs: fix possible NULL pointer dereference in dbFree()
  (bsc#1012628).
- arm64: dts: qcom: sdm845-xiaomi-beryllium: fix typo in panel's
  vddio-supply property (bsc#1012628).
- ALSA: usb-audio: Add quirk bits for enabling/disabling generic
  implicit fb (bsc#1012628).
- ALSA: usb-audio: Move generic implicit fb quirk entries into
  quirks.c (bsc#1012628).
- ARM: OMAP1: clock: Fix UART rate reporting algorithm
  (bsc#1012628).
- powerpc/fadump: Fix fadump to work with a different endian
  capture kernel (bsc#1012628).
- fat: add ratelimit to fat*_ent_bread() (bsc#1012628).
- pinctrl: renesas: rzn1: Fix possible null-ptr-deref in
  sh_pfc_map_resources() (bsc#1012628).
- ARM: versatile: Add missing of_node_put in dcscb_init
  (bsc#1012628).
- ARM: dts: exynos: add atmel,24c128 fallback to Samsung EEPROM
  (bsc#1012628).
- arm64: dts: qcom: sc7280-idp: Configure CTS pin to bias-bus-hold
  for bluetooth (bsc#1012628).
- arm64: dts: qcom: sc7280-qcard: Configure CTS pin to
  bias-bus-hold for bluetooth (bsc#1012628).
- ARM: hisi: Add missing of_node_put after of_find_compatible_node
  (bsc#1012628).
- cpufreq: Avoid unnecessary frequency updates due to mismatch
  (bsc#1012628).
- PCI: microchip: Add missing chained_irq_enter()/exit() calls
  (bsc#1012628).
- powerpc/rtas: Keep MSR[RI] set when calling RTAS (bsc#1012628).
- PCI: Avoid pci_dev_lock() AB/BA deadlock with
  sriov_numvfs_store() (bsc#1012628).
- PCI: cadence: Clear FLR in device capabilities register
  (bsc#1012628).
- KVM: PPC: Book3S HV Nested: L2 LPCR should inherit L1 LPES
  setting (bsc#1012628).
- alpha: fix alloc_zeroed_user_highpage_movable() (bsc#1012628).
- tracing: incorrect isolate_mote_t cast in mm_vmscan_lru_isolate
  (bsc#1012628).
- cifs: return ENOENT for DFS lookup_cache_entry() (bsc#1012628).
- powerpc/powernv/vas: Assign real address to rx_fifo in
  vas_rx_win_attr (bsc#1012628).
- powerpc/xics: fix refcount leak in icp_opal_init()
  (bsc#1012628).
- powerpc/powernv: fix missing of_node_put in uv_init()
  (bsc#1012628).
- macintosh/via-pmu: Fix build failure when CONFIG_INPUT is
  disabled (bsc#1012628).
- powerpc/iommu: Add missing of_node_put in iommu_init_early_dart
  (bsc#1012628).
- fanotify: fix incorrect fmode_t casts (bsc#1012628).
- smb3: check for null tcon (bsc#1012628).
- RDMA/hfi1: Prevent panic when SDMA is disabled (bsc#1012628).
- cifs: do not use tcpStatus after negotiate completes
  (bsc#1012628).
- Input: gpio-keys - cancel delayed work only in case of GPIO
  (bsc#1012628).
- drm: fix EDID struct for old ARM OABI format (bsc#1012628).
- drm/bridge_connector: enable HPD by default if supported
  (bsc#1012628).
- drm/selftests: missing error code in igt_buddy_alloc_smoke()
  (bsc#1012628).
- drm/omap: fix NULL but dereferenced coccicheck error
  (bsc#1012628).
- dt-bindings: display: sitronix, st7735r: Fix backlight in
  example (bsc#1012628).
- drm/bridge: anx7625: check the return on anx7625_aux_trans
  (bsc#1012628).
- drm: ssd130x: Fix COM scan direction register mask
  (bsc#1012628).
- drm: ssd130x: Always apply segment remap setting (bsc#1012628).
- drm/solomon: Make DRM_SSD130X depends on MMU (bsc#1012628).
- drm/format-helper: Rename drm_fb_xrgb8888_to_mono_reversed()
  (bsc#1012628).
- drm/format-helper: Fix XRGB888 to monochrome conversion
  (bsc#1012628).
- drm/ssd130x: Fix rectangle updates (bsc#1012628).
- drm/ssd130x: Reduce temporary buffer sizes (bsc#1012628).
- fbdev: defio: fix the pagelist corruption (bsc#1012628).
- drm/vmwgfx: Fix an invalid read (bsc#1012628).
- ath11k: acquire ab->base_lock in unassign when finding the
  peer by addr (bsc#1012628).
- drm: bridge: it66121: Fix the register page length
  (bsc#1012628).
- drm/bridge: it6505: Fix build error (bsc#1012628).
- ath9k: fix ar9003_get_eepmisc (bsc#1012628).
- drm/edid: fix invalid EDID extension block filtering
  (bsc#1012628).
- drm/bridge: anx7625: add missing destroy_workqueue() in
  anx7625_i2c_probe() (bsc#1012628).
- drm/bridge: adv7511: clean up CEC adapter when probe fails
  (bsc#1012628).
- drm: bridge: icn6211: Fix register layout (bsc#1012628).
- drm: bridge: icn6211: Fix HFP_HSW_HBP_HI and HFP_MIN handling
  (bsc#1012628).
- mtd: spinand: gigadevice: fix Quad IO for GD5F1GQ5UExxG
  (bsc#1012628).
- spi: qcom-qspi: Add minItems to interconnect-names
  (bsc#1012628).
- ASoC: codecs: Fix error handling in power domain init and exit
  handlers (bsc#1012628).
- ASoC: cs35l41: Fix an out-of-bounds access in
  otp_packed_element_t (bsc#1012628).
- ASoC: SOF: ipc3-topology: Set scontrol->priv to NULL after
  freeing it (bsc#1012628).
- ASoC: mediatek: Fix error handling in mt8173_max98090_dev_probe
  (bsc#1012628).
- ASoC: mediatek: Fix missing of_node_put in
  mt2701_wm8960_machine_probe (bsc#1012628).
- docs: driver-api/thermal/intel_dptf: Use copyright symbol
  (bsc#1012628).
- x86/delay: Fix the wrong asm constraint in delay_loop()
  (bsc#1012628).
- drm/mediatek: Add vblank register/unregister callback functions
  (bsc#1012628).
- drm/mediatek: Fix DPI component detection for MT8192
  (bsc#1012628).
- drm/vc4: kms: Take old state core clock rate into account
  (bsc#1012628).
- drm/vc4: hvs: Fix frame count register readout (bsc#1012628).
- drm/mediatek: Fix mtk_cec_mask() (bsc#1012628).
- drm/amd/amdgpu: Only reserve vram for firmware with vega9
  MS_HYPERV host (bsc#1012628).
- drm/vc4: hvs: Reset muxes at probe time (bsc#1012628).
- drm/vc4: txp: Don't set TXP_VSTART_AT_EOF (bsc#1012628).
- drm/vc4: txp: Force alpha to be 0xff if it's disabled
  (bsc#1012628).
- libbpf: Don't error out on CO-RE relos for overriden weak
  subprogs (bsc#1012628).
- x86/PCI: Fix ALi M1487 (IBC) PIRQ router link value
  interpretation (bsc#1012628).
- mptcp: optimize release_cb for the common case (bsc#1012628).
- mptcp: reset the packet scheduler on incoming MP_PRIO
  (bsc#1012628).
- mptcp: reset the packet scheduler on PRIO change (bsc#1012628).
- nl80211: show SSID for P2P_GO interfaces (bsc#1012628).
- drm/komeda: Fix an undefined behavior bug in komeda_plane_add()
  (bsc#1012628).
- drm: mali-dp: potential dereference of null pointer
  (bsc#1012628).
- drm/amd/amdgpu: Fix asm/hypervisor.h build error (bsc#1012628).
- spi: spi-ti-qspi: Fix return value handling of
  wait_for_completion_timeout (bsc#1012628).
- scftorture: Fix distribution of short handler delays
  (bsc#1012628).
- net: ethernet: ti: am65-cpsw: Fix build error without PHYLINK
  (bsc#1012628).
- net: dsa: mt7530: 1G can also support 1000BASE-X link mode
  (bsc#1012628).
- ixp4xx_eth: fix error check return value of platform_get_irq()
  (bsc#1012628).
- NFC: NULL out the dev->rfkill to prevent UAF (bsc#1012628).
- cpufreq: governor: Use kobject release() method to free dbs_data
  (bsc#1012628).
- efi: Allow to enable EFI runtime services by default on RT
  (bsc#1012628).
- efi: Add missing prototype for efi_capsule_setup_info
  (bsc#1012628).
- device property: Allow error pointer to be passed to fwnode APIs
  (bsc#1012628).
- drm/amd/amdgpu: Remove static from variable in RLCG Reg RW
  (bsc#1012628).
- net: dsa: qca8k: correctly handle mdio read error (bsc#1012628).
- target: remove an incorrect unmap zeroes data deduction
  (bsc#1012628).
- drbd: remove assign_p_sizes_qlim (bsc#1012628).
- drbd: use bdev based limit helpers in drbd_send_sizes
  (bsc#1012628).
- drbd: use bdev_alignment_offset instead of
  queue_alignment_offset (bsc#1012628).
- drbd: fix duplicate array initializer (bsc#1012628).
- EDAC/dmc520: Don't print an error for each unconfigured
  interrupt line (bsc#1012628).
- bpf: Move rcu lock management out of BPF_PROG_RUN routines
  (bsc#1012628).
- drm/bridge: anx7625: Use uint8 for lane-swing arrays
  (bsc#1012628).
- mtd: rawnand: denali: Use managed device resources
  (bsc#1012628).
- HID: hid-led: fix maximum brightness for Dream Cheeky
  (bsc#1012628).
- HID: elan: Fix potential double free in elan_input_configured
  (bsc#1012628).
- drm/bridge: Fix error handling in analogix_dp_probe
  (bsc#1012628).
- regulator: da9121: Fix uninit-value in
  da9121_assign_chip_model() (bsc#1012628).
- drm/mediatek: dpi: Use mt8183 output formats for mt8192
  (bsc#1012628).
- signal: Deliver SIGTRAP on perf event asynchronously if blocked
  (bsc#1012628).
- sched/fair: Fix cfs_rq_clock_pelt() for throttled cfs_rq
  (bsc#1012628).
- sched/psi: report zeroes for CPU full at the system level
  (bsc#1012628).
- spi: img-spfi: Fix pm_runtime_get_sync() error checking
  (bsc#1012628).
- drm/bridge: Fix it6505 Kconfig DRM_DP_AUX_BUS dependency
  (bsc#1012628).
- cpufreq: Fix possible race in cpufreq online error path
  (bsc#1012628).
- printk: add missing memory barrier to wake_up_klogd()
  (bsc#1012628).
- printk: wake waiters for safe and NMI contexts (bsc#1012628).
- ath9k_htc: fix potential out of bounds access with invalid
  rxstatus->rs_keyix (bsc#1012628).
- media: i2c: max9286: fix kernel oops when removing module
  (bsc#1012628).
- media: amphion: fix decoder's interlaced field (bsc#1012628).
- media: hantro: Implement support for encoder commands
  (bsc#1012628).
- media: hantro: Empty encoder capture buffers by default
  (bsc#1012628).
- media: imx: imx-mipi-csis: Rename csi_state to mipi_csis_device
  (bsc#1012628).
- media: imx: imx-mipi-csis: Fix active format initialization
  on source pad (bsc#1012628).
- drm/panel: simple: Add missing bus flags for Innolux G070Y2-L01
  (bsc#1012628).
- ALSA: pcm: Check for null pointer of pointer substream before
  dereferencing it (bsc#1012628).
- mtdblock: warn if opened on NAND (bsc#1012628).
- inotify: show inotify mask flags in proc fdinfo (bsc#1012628).
- fsnotify: fix wrong lockdep annotations (bsc#1012628).
- spi: rockchip: fix missing error on unsupported SPI_CS_HIGH
  (bsc#1012628).
- of: overlay: do not break notify on NOTIFY_{OK|STOP}
  (bsc#1012628).
- selftests/damon: add damon to selftests root Makefile
  (bsc#1012628).
- drm/msm: properly add and remove internal bridges (bsc#1012628).
- drm/msm/dpu: adjust display_v_end for eDP and DP (bsc#1012628).
- scsi: iscsi: Fix harmless double shift bug (bsc#1012628).
- scsi: ufs: qcom: Fix ufs_qcom_resume() (bsc#1012628).
- scsi: ufs: core: Exclude UECxx from SFR dump list (bsc#1012628).
- drm/v3d: Fix null pointer dereference of pointer perfmon
  (bsc#1012628).
- selftests/resctrl: Fix null pointer dereference on open failed
  (bsc#1012628).
- libbpf: Fix logic for finding matching program for CO-RE
  relocation (bsc#1012628).
- mtd: spi-nor: core: Check written SR value in
  spi_nor_write_16bit_sr_and_check() (bsc#1012628).
- x86/pm: Fix false positive kmemleak report in
  msr_build_context() (bsc#1012628).
- mtd: rawnand: cadence: fix possible null-ptr-deref in
  cadence_nand_dt_probe() (bsc#1012628).
- mtd: rawnand: intel: fix possible null-ptr-deref in
  ebu_nand_probe() (bsc#1012628).
- x86/speculation: Add missing prototype for unpriv_ebpf_notify()
  (bsc#1012628).
- ASoC: rk3328: fix disabling mclk on pclk probe failure
  (bsc#1012628).
- perf tools: Add missing headers needed by util/data.h
  (bsc#1012628).
- drm/msm/disp/dpu1: set vbif hw config to NULL to avoid use
  after memory free during pm runtime resume (bsc#1012628).
- drm/msm/dp: stop event kernel thread when DP unbind
  (bsc#1012628).
- drm/msm/dp: fix error check return value of
  irq_of_parse_and_map() (bsc#1012628).
- drm/msm/dp: reset DP controller before transmit phy test pattern
  (bsc#1012628).
- drm/msm/dp: do not stop transmitting phy test pattern during
  DP phy compliance test (bsc#1012628).
- drm/msm/dsi: fix error checks and return values for DSI xmit
  functions (bsc#1012628).
- drm/msm/hdmi: check return value after calling
  platform_get_resource_byname() (bsc#1012628).
- drm/msm/hdmi: fix error check return value of
  irq_of_parse_and_map() (bsc#1012628).
- drm/msm: add missing include to msm_drv.c (bsc#1012628).
- drm/panel: panel-simple: Fix proper bpc for
  AM-1280800N3TZQW-T00H (bsc#1012628).
- drm/bridge: it6505: Send DPCD SET_POWER to downstream
  (bsc#1012628).
- drm/msm: Fix null pointer dereferences without iommu
  (bsc#1012628).
- kunit: fix debugfs code to use enum kunit_status, not bool
  (bsc#1012628).
- drm/rockchip: vop: fix possible null-ptr-deref in vop_bind()
  (bsc#1012628).
- spi: cadence-quadspi: fix Direct Access Mode disable for SoCFPGA
  (bsc#1012628).
- perf tools: Use Python devtools for version autodetection
  rather than runtime (bsc#1012628).
- virtio_blk: fix the discard_granularity and discard_alignment
  queue limits (bsc#1012628).
- nl80211: don't hold RTNL in color change request (bsc#1012628).
- x86: Fix return value of __setup handlers (bsc#1012628).
- irqchip/exiu: Fix acknowledgment of edge triggered interrupts
  (bsc#1012628).
- irqchip/aspeed-i2c-ic: Fix irq_of_parse_and_map() return value
  (bsc#1012628).
- irqchip/aspeed-scu-ic: Fix irq_of_parse_and_map() return value
  (bsc#1012628).
- x86/mm: Cleanup the control_va_addr_alignment() __setup handler
  (bsc#1012628).
- arm64: fix types in copy_highpage() (bsc#1012628).
- regulator: core: Fix enable_count imbalance with EXCLUSIVE_GET
  (bsc#1012628).
- wl1251: dynamically allocate memory used for DMA (bsc#1012628).
- linkage: Fix issue with missing symbol size (bsc#1012628).
- ACPI: AGDI: Fix missing prototype warning for acpi_agdi_init()
  (bsc#1012628).
- drm/msm/disp/dpu1: avoid clearing hw interrupts if hw_intr is
  null during drm uninit (bsc#1012628).
- drm/msm/dsi: fix address for second DSI PHY on SDM660
  (bsc#1012628).
- drm/msm/dp: fix event thread stuck in wait_event after
  kthread_stop() (bsc#1012628).
- drm/msm/mdp5: Return error code in mdp5_pipe_release when
  deadlock is detected (bsc#1012628).
- drm/msm/mdp5: Return error code in mdp5_mixer_release when
  deadlock is detected (bsc#1012628).
- drm/msm: return an error pointer in msm_gem_prime_get_sg_table()
  (bsc#1012628).
- media: uvcvideo: Fix missing check to determine if element is
  found in list (bsc#1012628).
- arm64: stackleak: fix current_top_of_stack() (bsc#1012628).
- iomap: iomap_write_failed fix (bsc#1012628).
- spi: spi-fsl-qspi: check return value after calling
  platform_get_resource_byname() (bsc#1012628).
- selftests/bpf: Prevent skeleton generation race (bsc#1012628).
- Revert "cpufreq: Fix possible race in cpufreq online error path"
  (bsc#1012628).
- regulator: qcom_smd: Fix up PM8950 regulator configuration
  (bsc#1012628).
- samples: bpf: Don't fail for a missing VMLINUX_BTF when
  VMLINUX_H is provided (bsc#1012628).
- perf/amd/ibs: Use interrupt regs ip for stack unwinding
  (bsc#1012628).
- ath11k: Don't check arvif->is_started before sending management
  frames (bsc#1012628).
- scsi: lpfc: Fix element offset in __lpfc_sli_release_iocbq_s4()
  (bsc#1012628).
- scsi: lpfc: Fix dmabuf ptr assignment in lpfc_ct_reject_event()
  (bsc#1012628).
- wilc1000: fix crash observed in AP mode with
  cfg80211_register_netdevice() (bsc#1012628).
- HID: amd_sfh: Modify the bus name (bsc#1012628).
- HID: amd_sfh: Modify the hid name (bsc#1012628).
- ASoC: fsl: Fix refcount leak in imx_sgtl5000_probe
  (bsc#1012628).
- ASoC: imx-hdmi: Fix refcount leak in imx_hdmi_probe
  (bsc#1012628).
- ASoC: mxs-saif: Fix refcount leak in mxs_saif_probe
  (bsc#1012628).
- regulator: pfuze100: Fix refcount leak in
  pfuze_parse_regulators_dt (bsc#1012628).
- PM: EM: Decrement policy counter (bsc#1012628).
- dma-direct: don't fail on highmem CMA pages in
  dma_direct_alloc_pages (bsc#1012628).
- ASoC: samsung: Fix refcount leak in aries_audio_probe
  (bsc#1012628).
- block: Fix the bio.bi_opf comment (bsc#1012628).
- kselftest/cgroup: fix test_stress.sh to use OUTPUT dir
  (bsc#1012628).
- scripts/faddr2line: Fix overlapping text section failures
  (bsc#1012628).
- media: aspeed: Fix an error handling path in
  aspeed_video_probe() (bsc#1012628).
- media: exynos4-is: Fix PM disable depth imbalance in
  fimc_is_probe (bsc#1012628).
- mt76: mt7915: fix DBDC default band selection on MT7915D
  (bsc#1012628).
- mt76: mt7921: honor pm user configuration in
  mt7921_sniffer_interface_iter (bsc#1012628).
- mt76: mt7915: fix unbounded shift in mt7915_mcu_beacon_mbss
  (bsc#1012628).
- mt76: mt7921: Fix the error handling path of mt7921_pci_probe()
  (bsc#1012628).
- mt76: mt7915: fix possible uninitialized pointer dereference
  in mt7986_wmac_gpio_setup (bsc#1012628).
- mt76: mt7915: fix possible NULL pointer dereference in
  mt7915_mac_fill_rx_vector (bsc#1012628).
- mt76: mt7915: do not pass data pointer to
  mt7915_mcu_muru_debug_set (bsc#1012628).
- mt76: mt7915: report rx mode value in mt7915_mac_fill_rx_rate
  (bsc#1012628).
- mt76: fix antenna config missing in 6G cap (bsc#1012628).
- mt76: mt7921: fix kernel crash at mt7921_pci_remove
  (bsc#1012628).
- mt76: do not attempt to reorder received 802.3 packets without
  agg session (bsc#1012628).
- mt76: fix tx status related use-after-free race on station
  removal (bsc#1012628).
- mt76: mt7915: fix twt table_mask to u16 in mt7915_dev
  (bsc#1012628).
- media: st-delta: Fix PM disable depth imbalance in delta_probe
  (bsc#1012628).
- media: atmel: atmel-isc: Fix PM disable depth imbalance in
  atmel_isc_probe (bsc#1012628).
- media: i2c: rdacm2x: properly set subdev entity function
  (bsc#1012628).
- media: exynos4-is: Change clk_disable to clk_disable_unprepare
  (bsc#1012628).
- media: pvrusb2: fix array-index-out-of-bounds in
  pvr2_i2c_core_init (bsc#1012628).
- media: make RADIO_ADAPTERS tristate (bsc#1012628).
- media: vsp1: Fix offset calculation for plane cropping
  (bsc#1012628).
- media: atmel: atmel-sama5d2-isc: fix wrong mask in YUYV format
  check (bsc#1012628).
- media: hantro: HEVC: Fix tile info buffer value computation
  (bsc#1012628).
- Bluetooth: mt7921s: Fix the incorrect pointer check
  (bsc#1012628).
- Bluetooth: fix dangling sco_conn and use-after-free in
  sco_sock_timeout (bsc#1012628).
- Bluetooth: use hdev lock in activate_scan for
  hci_is_adv_monitoring (bsc#1012628).
- Bluetooth: use hdev lock for accept_list and reject_list in
  conn req (bsc#1012628).
- Bluetooth: protect le accept and resolv lists with hdev->lock
  (bsc#1012628).
- Bluetooth: btmtksdio: fix use-after-free at btmtksdio_recv_event
  (bsc#1012628).
- Bluetooth: btmtksdio: fix possible FW initialization failure
  (bsc#1012628).
- Bluetooth: btmtksdio: fix the reset takes too long
  (bsc#1012628).
- media: mediatek: vcodec: Fix v4l2 compliance decoder cmd test
  fail (bsc#1012628).
- io_uring: avoid io-wq -EAGAIN looping for !IOPOLL (bsc#1012628).
- io_uring: only wake when the correct events are set
  (bsc#1012628).
- irqchip/gic-v3: Ensure pseudo-NMIs have an ISB between ack
  and handling (bsc#1012628).
- irqchip/gic-v3: Refactor ISB + EOIR at ack time (bsc#1012628).
- irqchip/gic-v3: Fix priority mask handling (bsc#1012628).
- nvme: set dma alignment to dword (bsc#1012628).
- m68k: math-emu: Fix dependencies of math emulation support
  (bsc#1012628).
- net: annotate races around sk->sk_bound_dev_if (bsc#1012628).
- sctp: read sk->sk_bound_dev_if once in sctp_rcv() (bsc#1012628).
- net: hinic: add missing destroy_workqueue in
  hinic_pf_to_mgmt_init (bsc#1012628).
- ASoC: ti: j721e-evm: Fix refcount leak in j721e_soc_probe_*
  (bsc#1012628).
- kselftest/arm64: bti: force static linking (bsc#1012628).
- media: ov7670: remove ov7670_power_off from ov7670_remove
  (bsc#1012628).
- media: i2c: ov2640: Depend on V4L2_ASYNC (bsc#1012628).
- media: i2c: ov5648: fix wrong pointer passed to IS_ERR()
  and PTR_ERR() (bsc#1012628).
- media: rkvdec: h264: Fix dpb_valid implementation (bsc#1012628).
- media: rkvdec: h264: Fix bit depth wrap in pps packet
  (bsc#1012628).
- regulator: scmi: Fix refcount leak in scmi_regulator_probe
  (bsc#1012628).
- blk-cgroup: always terminate io.stat lines (bsc#1012628).
- erofs: fix buffer copy overflow of ztailpacking feature
  (bsc#1012628).
- net/mlx5e: Correct the calculation of max channels for rep
  (bsc#1012628).
- ext4: reject the 'commit' option on ext2 filesystems
  (bsc#1012628).
- drm/msm/dsi: don't powerup at modeset time for parade-ps8640
  (bsc#1012628).
- drm/msm/a6xx: Fix refcount leak in a6xx_gpu_init (bsc#1012628).
- drm: msm: fix possible memory leak in mdp5_crtc_cursor_set()
  (bsc#1012628).
- x86/sev: Annotate stack change in the #VC handler (bsc#1012628).
- drm/msm: don't free the IRQ if it was not requested
  (bsc#1012628).
- selftests/bpf: Add missed ima_setup.sh in Makefile
  (bsc#1012628).
- drm/msm/dpu: handle pm_runtime_get_sync() errors in bind path
  (bsc#1012628).
- drm/i915: Fix CFI violation with show_dynamic_id()
  (bsc#1012628).
- thermal/drivers/bcm2711: Don't clamp temperature at zero
  (bsc#1012628).
- thermal/drivers/broadcom: Fix potential NULL dereference in
  sr_thermal_probe (bsc#1012628).
- thermal/core: Fix memory leak in
  __thermal_cooling_device_register() (bsc#1012628).
- thermal/drivers/imx_sc_thermal: Fix refcount leak in
  imx_sc_thermal_probe (bsc#1012628).
- bfq: Relax waker detection for shared queues (bsc#1012628).
- bfq: Allow current waker to defend against a tentative one
  (bsc#1012628).
- ASoC: codecs: lpass: Fix passing zero to 'PTR_ERR'
  (bsc#1012628).
- ASoC: wm2000: fix missing clk_disable_unprepare() on error in
  wm2000_anc_transition() (bsc#1012628).
- cpuidle: psci: Fix regression leading to no genpd governor
  (bsc#1012628).
- cpuidle: riscv-sbi: Fix code to allow a genpd governor to be
  used (bsc#1012628).
- platform/x86: intel_cht_int33fe: Set driver data (bsc#1012628).
- PM: domains: Fix initialization of genpd's next_wakeup
  (bsc#1012628).
- net: macb: Fix PTP one step sync support (bsc#1012628).
- scsi: hisi_sas: Fix rescan after deleting a disk (bsc#1012628).
- scsi: hisi_sas: Fix memory ordering in hisi_sas_task_deliver()
  (bsc#1012628).
- NFC: hci: fix sleep in atomic context bugs in
  nfc_hci_hcp_message_tx (bsc#1012628).
- bonding: fix missed rcu protection (bsc#1012628).
- ASoC: max98090: Move check for invalid values before casting
  in max98090_put_enab_tlv() (bsc#1012628).
- perf parse-events: Support different format of the topdown
  event name (bsc#1012628).
- net: stmmac: fix out-of-bounds access in a selftest
  (bsc#1012628).
- amt: fix gateway mode stuck (bsc#1012628).
- amt: fix memory leak for advertisement message (bsc#1012628).
- hv_netvsc: Fix potential dereference of NULL pointer
  (bsc#1012628).
- hwmon: (dimmtemp) Fix bitmap handling (bsc#1012628).
- hwmon: (pmbus) Check PEC support before reading other registers
  (bsc#1012628).
- rxrpc: Fix locking issue (bsc#1012628).
- rxrpc: Fix listen() setting the bar too high for the prealloc
  rings (bsc#1012628).
- rxrpc: Don't try to resend the request if we're receiving the
  reply (bsc#1012628).
- rxrpc: Fix overlapping ACK accounting (bsc#1012628).
- rxrpc: Don't let ack.previousPacket regress (bsc#1012628).
- rxrpc: Fix decision on when to generate an IDLE ACK
  (bsc#1012628).
- hinic: Avoid some over memory allocation (bsc#1012628).
- dpaa2-eth: retrieve the virtual address before dma_unmap
  (bsc#1012628).
- dpaa2-eth: use the correct software annotation field
  (bsc#1012628).
- dpaa2-eth: unmap the SGT buffer before accessing its contents
  (bsc#1012628).
- net: dsa: restrict SMSC_LAN9303_I2C kconfig (bsc#1012628).
- net/smc: postpone sk_refcnt increment in connect()
  (bsc#1012628).
- net/smc: fix listen processing for SMC-Rv2 (bsc#1012628).
- dma-direct: don't over-decrypt memory (bsc#1012628).
- Bluetooth: hci_conn: Fix hci_connect_le_sync (bsc#1012628).
- Revert "net/smc: fix listen processing for SMC-Rv2"
  (bsc#1012628).
- media: lirc: revert removal of unused feature flags
  (bsc#1012628).
- arm64: dts: rockchip: Move drive-impedance-ohm to emmc phy on
  rk3399 (bsc#1012628).
- arm64: dts: mt8192: Fix nor_flash status disable typo
  (bsc#1012628).
- PCI/ACPI: Allow D3 only if Root Port can signal and wake from D3
  (bsc#1012628).
- memory: samsung: exynos5422-dmc: Avoid some over memory
  allocation (bsc#1012628).
- ARM: dts: BCM5301X: Update pin controller node name
  (bsc#1012628).
- ARM: dts: suniv: F1C100: fix watchdog compatible (bsc#1012628).
- soc: qcom: smp2p: Fix missing of_node_put() in smp2p_parse_ipc
  (bsc#1012628).
- soc: qcom: smsm: Fix missing of_node_put() in smsm_parse_ipc
  (bsc#1012628).
- arm64: defconfig: reenable SM_DISPCC_8250 (bsc#1012628).
- PCI: cadence: Fix find_first_zero_bit() limit (bsc#1012628).
- PCI: rockchip: Fix find_first_zero_bit() limit (bsc#1012628).
- PCI: mediatek: Fix refcount leak in mtk_pcie_subsys_powerup()
  (bsc#1012628).
- PCI: dwc: Fix setting error return on MSI DMA mapping failure
  (bsc#1012628).
- ARM: dts: ci4x10: Adapt to changes in imx6qdl.dtsi regarding
  fec clocks (bsc#1012628).
- arm64: dts: qcom: sc7280: Fix sar1_irq_odl node name
  (bsc#1012628).
- arm64: dts: qcom: sc7280-herobrine: Drop outputs on fpmcu pins
  (bsc#1012628).
- soc: qcom: llcc: Add MODULE_DEVICE_TABLE() (bsc#1012628).
- cxl/pci: Add debug for DVSEC range init failures (bsc#1012628).
- cxl/pci: Make cxl_dvsec_ranges() failure not fatal to cxl_pci
  (bsc#1012628).
- KVM: nVMX: Leave most VM-Exit info fields unmodified on failed
  VM-Entry (bsc#1012628).
- KVM: nVMX: Clear IDT vectoring on nested VM-Exit for
  double/triple fault (bsc#1012628).
- arm64: dts: juno: Fix SCMI power domain IDs for ETF and CS
  funnel (bsc#1012628).
- crypto: qat - set CIPHER capability for DH895XCC (bsc#1012628).
- crypto: qat - set COMPRESSION capability for DH895XCC
  (bsc#1012628).
- platform/chrome: cros_ec: fix error handling in
  cros_ec_register() (bsc#1012628).
- ARM: dts: imx6dl-colibri: Fix I2C pinmuxing (bsc#1012628).
- platform/chrome: Re-introduce cros_ec_cmd_xfer and use it for
  ioctls (bsc#1012628).
- can: xilinx_can: mark bit timing constants as const
  (bsc#1012628).
- ARM: dts: stm32: Fix PHY post-reset delay on Avenger96
  (bsc#1012628).
- dt-bindings: soc: qcom: smd-rpm: Fix missing MSM8936 compatible
  (bsc#1012628).
- ARM: dts: qcom: sdx55: remove wrong unit address from RPMH
  RSC clocks (bsc#1012628).
- arm64: dts: qcom: sm8450: Fix missing iommus for qup
  (bsc#1012628).
- arm64: dts: qcom: sm8450: Fix missing iommus for qup1
  (bsc#1012628).
- ARM: dts: bcm2835-rpi-zero-w: Fix GPIO line name for Wifi/BT
  (bsc#1012628).
- ARM: dts: bcm2837-rpi-cm3-io3: Fix GPIO line names for SMPS I2C
  (bsc#1012628).
- ARM: dts: bcm2837-rpi-3-b-plus: Fix GPIO line name of power LED
  (bsc#1012628).
- ARM: dts: bcm2835-rpi-b: Fix GPIO line names (bsc#1012628).
- misc: ocxl: fix possible double free in ocxl_file_register_afu
  (bsc#1012628).
- hwrng: cn10k - Optimize cn10k_rng_read() (bsc#1012628).
- hwrng: cn10k - Make check_rng_health() return an error code
  (bsc#1012628).
- crypto: marvell/cesa - ECB does not IV (bsc#1012628).
- gpiolib: of: Introduce hook for missing gpio-ranges
  (bsc#1012628).
- pinctrl: bcm2835: implement hook for missing gpio-ranges
  (bsc#1012628).
- drm/msm: simplify gpu_busy callback (bsc#1012628).
- drm/msm: return the average load over the polling period
  (bsc#1012628).
- arm: mediatek: select arch timer for mt7629 (bsc#1012628).
- pinctrl/rockchip: support deferring other gpio params
  (bsc#1012628).
- pinctrl: mediatek: mt8195: enable driver on mtk platforms
  (bsc#1012628).
- arm64: dts: qcom: qrb5165-rb5: Fix can-clock node name
  (bsc#1012628).
- Drivers: hv: vmbus: Fix handling of messages with transaction
  ID of zero (bsc#1012628).
- powerpc/fadump: fix PT_LOAD segment for boot memory area
  (bsc#1012628).
- mfd: ipaq-micro: Fix error check return value of
  platform_get_irq() (bsc#1012628).
- scsi: fcoe: Fix Wstringop-overflow warnings in
  fcoe_wwn_from_mac() (bsc#1012628).
- soc: bcm: Check for NULL return of devm_kzalloc() (bsc#1012628).
- arm64: dts: ti: k3-am64-mcu: remove incorrect UART base clock
  rates (bsc#1012628).
- ASoC: sh: rz-ssi: Propagate error codes returned from
  platform_get_irq_byname() (bsc#1012628).
- ASoC: sh: rz-ssi: Release the DMA channels in rz_ssi_probe()
  error path (bsc#1012628).
- firmware: arm_scmi: Fix list protocols enumeration in the base
  protocol (bsc#1012628).
- nvdimm: Fix firmware activation deadlock scenarios
  (bsc#1012628).
- nvdimm: Allow overwrite in the presence of disabled dimms
  (bsc#1012628).
- pinctrl: mvebu: Fix irq_of_parse_and_map() return value
  (bsc#1012628).
- crypto: ccp - Fix the INIT_EX data file open failure
  (bsc#1012628).
- drivers/base/node.c: fix compaction sysfs file leak
  (bsc#1012628).
- dax: fix cache flush on PMD-mapped pages (bsc#1012628).
- drivers/base/memory: fix an unlikely reference counting issue
  in __add_memory_block() (bsc#1012628).
- firmware: arm_ffa: Fix uuid parameter to ffa_partition_probe
  (bsc#1012628).
- firmware: arm_ffa: Remove incorrect assignment of driver_data
  (bsc#1012628).
- ocfs2: fix mounting crash if journal is not alloced
  (bsc#1012628).
- list: fix a data-race around ep->rdllist (bsc#1012628).
- drm/msm/dpu: fix error check return value of
  irq_of_parse_and_map() (bsc#1012628).
- powerpc/8xx: export 'cpm_setbrg' for modules (bsc#1012628).
- pinctrl: renesas: r8a779a0: Fix GPIO function on I2C-capable
  pins (bsc#1012628).
- pinctrl: renesas: r8a779f0: Fix GPIO function on I2C-capable
  pins (bsc#1012628).
- pinctrl: renesas: core: Fix possible null-ptr-deref in
  sh_pfc_map_resources() (bsc#1012628).
- powerpc/idle: Fix return value of __setup() handler
  (bsc#1012628).
- powerpc/4xx/cpm: Fix return value of __setup() handler
  (bsc#1012628).
- RDMA/hns: Add the detection for CMDQ status in the device
  initialization process (bsc#1012628).
- arm64: dts: marvell: espressobin-ultra: fix SPI-NOR config
  (bsc#1012628).
- arm64: dts: marvell: espressobin-ultra: enable front USB3 port
  (bsc#1012628).
- ASoC: atmel-pdmic: Remove endianness flag on pdmic component
  (bsc#1012628).
- ASoC: atmel-classd: Remove endianness flag on class d component
  (bsc#1012628).
- proc: fix dentry/inode overinstantiating under /proc/${pid}/net
  (bsc#1012628).
- ipc/mqueue: use get_tree_nodev() in mqueue_get_tree()
  (bsc#1012628).
- PCI: imx6: Fix PERST# start-up sequence (bsc#1012628).
- PCI: mediatek-gen3: Assert resets to ensure expected init state
  (bsc#1012628).
- module.h: simplify MODULE_IMPORT_NS (bsc#1012628).
- module: fix [e_shstrndx].sh_size=0 OOB access (bsc#1012628).
- tty: fix deadlock caused by calling printk() under
  tty_port->lock (bsc#1012628).
- crypto: sun8i-ss - rework handling of IV (bsc#1012628).
- crypto: sun8i-ss - handle zero sized sg (bsc#1012628).
- crypto: cryptd - Protect per-CPU resource by disabling BH
  (bsc#1012628).
- ARM: dts: at91: sama7g5: remove interrupt-parent from gic node
  (bsc#1012628).
- ARM: dts: lan966x: swap dma channels for crypto node
  (bsc#1012628).
- hugetlbfs: fix hugetlbfs_statfs() locking (bsc#1012628).
- x86/mce: relocate set{clear}_mce_nospec() functions
  (bsc#1012628).
- mce: fix set_mce_nospec to always unmap the whole page
  (bsc#1012628).
- Input: sparcspkr - fix refcount leak in bbc_beep_probe
  (bsc#1012628).
- PCI/AER: Clear MULTI_ERR_COR/UNCOR_RCV bits (bsc#1012628).
- KVM: PPC: Book3S HV: Fix vcore_blocked tracepoint (bsc#1012628).
- PCI: microchip: Fix potential race in interrupt handling
  (bsc#1012628).
- cxl/mem: Drop mem_enabled check from wait_for_media()
  (bsc#1012628).
- hwrng: omap3-rom - fix using wrong clk_disable() in
  omap_rom_rng_runtime_resume() (bsc#1012628).
- perf evlist: Keep topdown counters in weak group (bsc#1012628).
- perf stat: Always keep perf metrics topdown events in a group
  (bsc#1012628).
- mailbox: pcc: Fix an invalid-load caught by the address
  sanitizer (bsc#1012628).
- powerpc/64: Only WARN if __pa()/__va() called with bad addresses
  (bsc#1012628).
- powerpc/powernv: Get L1D flush requirements from device-tree
  (bsc#1012628).
- powerpc/powernv: Get STF barrier requirements from device-tree
  (bsc#1012628).
- powerpc/perf: Fix the threshold compare group constraint for
  power10 (bsc#1012628).
- powerpc/perf: Fix the threshold compare group constraint for
  power9 (bsc#1012628).
- macintosh: via-pmu and via-cuda need RTC_LIB (bsc#1012628).
- powerpc/xive: Fix refcount leak in xive_spapr_init
  (bsc#1012628).
- powerpc/fsl_rio: Fix refcount leak in fsl_rio_setup
  (bsc#1012628).
- powerpc/papr_scm: Fix leaking nvdimm_events_map elements
  (bsc#1012628).
- powerpc/fsl_book3e: Don't set rodata RO too early (bsc#1012628).
- gpio: sim: Use correct order for the parameters of
  devm_kcalloc() (bsc#1012628).
- mfd: davinci_voicecodec: Fix possible null-ptr-deref
  davinci_vc_probe() (bsc#1012628).
- nfsd: destroy percpu stats counters after reply cache shutdown
  (bsc#1012628).
- mailbox: forward the hrtimer if not queued and under a lock
  (bsc#1012628).
- RDMA/rxe: Fix an error handling path in rxe_get_mcg()
  (bsc#1012628).
- RDMA/hfi1: Prevent use of lock before it is initialized
  (bsc#1012628).
- pinctrl: apple: Use a raw spinlock for the regmap (bsc#1012628).
- KVM: LAPIC: Drop pending LAPIC timer injection when canceling
  the timer (bsc#1012628).
- Input: stmfts - do not leave device disabled in
  stmfts_input_open (bsc#1012628).
- OPP: call of_node_put() on error path in _bandwidth_supported()
  (bsc#1012628).
- dmaengine: ti: k3-psil-am62: Update PSIL thread for saul
  (bsc#1012628).
- f2fs: fix to do sanity check on inline_dots inode (bsc#1012628).
- f2fs: fix dereference of stale list iterator after loop body
  (bsc#1012628).
- riscv: Fixup difference with defconfig (bsc#1012628).
- iommu/amd: Enable swiotlb in all cases (bsc#1012628).
- iommu/amd: Do not call sleep while holding spinlock
  (bsc#1012628).
- iommu/mediatek: Fix 2 HW sharing pgtable issue (bsc#1012628).
- iommu/mediatek: Add list_del in mtk_iommu_remove (bsc#1012628).
- iommu/mediatek: Remove clk_disable in mtk_iommu_remove
  (bsc#1012628).
- iommu/mediatek: Add mutex for m4u_group and m4u_dom in data
  (bsc#1012628).
- i2c: at91: use dma safe buffers (bsc#1012628).
- cpufreq: mediatek: Use module_init and add module_exit
  (bsc#1012628).
- cpufreq: mediatek: Unregister platform device on exit
  (bsc#1012628).
- iommu/arm-smmu-v3-sva: Fix mm use-after-free (bsc#1012628).
- MIPS: Loongson: Use hwmon_device_register_with_groups() to
  register hwmon (bsc#1012628).
- iommu/mediatek: Fix NULL pointer dereference when printing
  dev_name (bsc#1012628).
- i2c: at91: Initialize dma_buf in at91_twi_xfer() (bsc#1012628).
- dmaengine: idxd: Fix the error handling path in
  idxd_cdev_register() (bsc#1012628).
- NFS: Do not report EINTR/ERESTARTSYS as mapping errors
  (bsc#1012628).
- NFS: fsync() should report filesystem errors over
  EINTR/ERESTARTSYS (bsc#1012628).
- NFS: Don't report ENOSPC write errors twice (bsc#1012628).
- NFS: Do not report flush errors in nfs_write_end()
  (bsc#1012628).
- NFS: Don't report errors from nfs_pageio_complete() more than
  once (bsc#1012628).
- NFSv4/pNFS: Do not fail I/O when we fail to allocate the pNFS
  layout (bsc#1012628).
- NFS: Further fixes to the writeback error handling
  (bsc#1012628).
- NFS: Pass i_size to fscache_unuse_cookie() when a file is
  released (bsc#1012628).
- video: fbdev: clcdfb: Fix refcount leak in clcdfb_of_vram_setup
  (bsc#1012628).
- dmaengine: stm32-mdma: remove GISR1 register (bsc#1012628).
- dmaengine: stm32-mdma: fix chan initialization in
  stm32_mdma_irq_handler() (bsc#1012628).
- i2c: npcm: Fix timeout calculation (bsc#1012628).
- i2c: npcm: Correct register access width (bsc#1012628).
- i2c: npcm: Handle spurious interrupts (bsc#1012628).
- i2c: rcar: fix PM ref counts in probe error paths (bsc#1012628).
- tracing: Reset the function filter after completing
  trampoline/graph selftest (bsc#1012628).
- RISC-V: Split out the XIP fixups into their own file
  (bsc#1012628).
- RISC-V: Fix the XIP build (bsc#1012628).
- MIPS: RALINK: Define pci_remap_iospace under
  CONFIG_PCI_DRIVERS_GENERIC (bsc#1012628).
- perf build: Fix btf__load_from_kernel_by_id() feature check
  (bsc#1012628).
- perf c2c: Use stdio interface if slang is not supported
  (bsc#1012628).
- rtla: Avoid record NULL pointer dereference (bsc#1012628).
- rtla: Don't overwrite existing directory mode (bsc#1012628).
- rtla: Minor grammar fix for rtla README (bsc#1012628).
- rtla: Fix __set_sched_attr error message (bsc#1012628).
- rtla: Remove procps-ng dependency (bsc#1012628).
- tracing/timerlat: Notify IRQ new max latency only if stop
  tracing is set (bsc#1012628).
- perf jevents: Fix event syntax error caused by ExtSel
  (bsc#1012628).
- video: fbdev: vesafb: Fix a use-after-free due early fb_info
  cleanup (bsc#1012628).
- NFSv4: Fix free of uninitialized nfs4_label on referral lookup
  (bsc#1012628).
- NFSv4.1 mark qualified async operations as MOVEABLE tasks
  (bsc#1012628).
- f2fs: fix to avoid f2fs_bug_on() in dec_valid_node_count()
  (bsc#1012628).
- f2fs: fix to do sanity check on block address in
  f2fs_do_zero_range() (bsc#1012628).
- f2fs: fix to clear dirty inode in f2fs_evict_inode()
  (bsc#1012628).
- f2fs: fix deadloop in foreground GC (bsc#1012628).
- f2fs: don't need inode lock for system hidden quota
  (bsc#1012628).
- f2fs: fix to do sanity check on total_data_blocks (bsc#1012628).
- f2fs: don't use casefolded comparison for "." and
  ".." (bsc#1012628).
- f2fs: fix fallocate to use file_modified to update permissions
  consistently (bsc#1012628).
- f2fs: fix to do sanity check for inline inode (bsc#1012628).
- objtool: Fix objtool regression on x32 systems (bsc#1012628).
- objtool: Fix symbol creation (bsc#1012628).
- wifi: mac80211: fix use-after-free in chanctx code
  (bsc#1012628).
- iwlwifi: fw: init SAR GEO table only if data is present
  (bsc#1012628).
- iwlwifi: mvm: fix assert 1F04 upon reconfig (bsc#1012628).
- iwlwifi: mei: clear the sap data header before sending
  (bsc#1012628).
- iwlwifi: mei: fix potential NULL-ptr deref (bsc#1012628).
- ipmi:ipmb: Fix refcount leak in ipmi_ipmb_probe (bsc#1012628).
- =?UTF-8?q?fs-writeback:=20writeback=5Fsb=5Finodes?=
  =?UTF-8?q?=EF=BC=9ARecalculate=20'wrote'=20according=20skipped=20pages?=
  (bsc#1012628).
- efi: Do not import certificates from UEFI Secure Boot for T2
  Macs (bsc#1012628).
- bfq: Avoid false marking of bic as stably merged (bsc#1012628).
- bfq: Avoid merging queues with different parents (bsc#1012628).
- bfq: Split shared queues on move between cgroups (bsc#1012628).
- bfq: Update cgroup information before merging bio (bsc#1012628).
- bfq: Drop pointless unlock-lock pair (bsc#1012628).
- bfq: Remove pointless bfq_init_rq() calls (bsc#1012628).
- bfq: Track whether bfq_group is still online (bsc#1012628).
- bfq: Get rid of __bio_blkcg() usage (bsc#1012628).
- bfq: Make sure bfqg for which we are queueing requests is online
  (bsc#1012628).
- ext4: mark group as trimmed only if it was fully scanned
  (bsc#1012628).
- ext4: fix use-after-free in ext4_rename_dir_prepare
  (bsc#1012628).
- ext4: fix journal_ioprio mount option handling (bsc#1012628).
- ext4: fix race condition between ext4_write and
  ext4_convert_inline_data (bsc#1012628).
- ext4: fix warning in ext4_handle_inode_extension (bsc#1012628).
- ext4: fix memory leak in parse_apply_sb_mount_options()
  (bsc#1012628).
- ext4: fix bug_on in ext4_writepages (bsc#1012628).
- ext4: filter out EXT4_FC_REPLAY from on-disk superblock field
  s_state (bsc#1012628).
- ext4: fix bug_on in __es_tree_search (bsc#1012628).
- ext4: verify dir block before splitting it (bsc#1012628).
- ext4: avoid cycles in directory h-tree (bsc#1012628).
- ACPI: property: Release subnode properties with data nodes
  (bsc#1012628).
- tty: goldfish: Introduce gf_ioread32()/gf_iowrite32()
  (bsc#1012628).
- tracing: Have event format check not flag %%p* on
  __get_dynamic_array() (bsc#1012628).
- tracing: Fix potential double free in create_var_ref()
  (bsc#1012628).
- tracing: Fix return value of trace_pid_write() (bsc#1012628).
- tracing: Initialize integer variable to prevent garbage return
  value (bsc#1012628).
- drm/amdgpu: add beige goby PCI ID (bsc#1012628).
- PCI/PM: Fix bridge_d3_blacklist[] Elo i2 overwrite of Gigabyte
  X299 (bsc#1012628).
- PCI: qcom: Fix pipe clock imbalance (bsc#1012628).
- PCI: qcom: Fix runtime PM imbalance on probe errors
  (bsc#1012628).
- PCI: qcom: Fix unbalanced PHY init on probe errors
  (bsc#1012628).
- staging: r8188eu: prevent ->Ssid overflow in rtw_wx_set_scan()
  (bsc#1012628).
- block: Fix potential deadlock in blk_ia_range_sysfs_show()
  (bsc#1012628).
- mm, compaction: fast_find_migrateblock() should return pfn in
  the target zone (bsc#1012628).
- s390/perf: obtain sie_block from the right address
  (bsc#1012628).
- s390/stp: clock_delta should be signed (bsc#1012628).
- dlm: fix plock invalid read (bsc#1012628).
- dlm: uninitialized variable on error in dlm_listen_for_all()
  (bsc#1012628).
- dlm: fix wake_up() calls for pending remove (bsc#1012628).
- dlm: fix missing lkb refcount handling (bsc#1012628).
- ocfs2: dlmfs: fix error handling of user_dlm_destroy_lock
  (bsc#1012628).
- scsi: dc395x: Fix a missing check on list iterator
  (bsc#1012628).
- scsi: ufs: qcom: Add a readl() to make sure ref_clk gets enabled
  (bsc#1012628).
- landlock: Add clang-format exceptions (bsc#1012628).
- landlock: Format with clang-format (bsc#1012628).
- selftests/landlock: Add clang-format exceptions (bsc#1012628).
- selftests/landlock: Normalize array assignment (bsc#1012628).
- selftests/landlock: Format with clang-format (bsc#1012628).
- samples/landlock: Add clang-format exceptions (bsc#1012628).
- samples/landlock: Format with clang-format (bsc#1012628).
- landlock: Fix landlock_add_rule(2) documentation (bsc#1012628).
- selftests/landlock: Make tests build with old libc
  (bsc#1012628).
- selftests/landlock: Extend tests for minimal valid attribute
  size (bsc#1012628).
- selftests/landlock: Add tests for unknown access rights
  (bsc#1012628).
- selftests/landlock: Extend access right tests to directories
  (bsc#1012628).
- selftests/landlock: Fully test file rename with "remove" access
  (bsc#1012628).
- selftests/landlock: Add tests for O_PATH (bsc#1012628).
- landlock: Change landlock_add_rule(2) argument check ordering
  (bsc#1012628).
- landlock: Change landlock_restrict_self(2) check ordering
  (bsc#1012628).
- selftests/landlock: Test landlock_create_ruleset(2) argument
  check ordering (bsc#1012628).
- landlock: Define access_mask_t to enforce a consistent access
  mask size (bsc#1012628).
- landlock: Reduce the maximum number of layers to 16
  (bsc#1012628).
- landlock: Create find_rule() from unmask_layers() (bsc#1012628).
- landlock: Fix same-layer rule unions (bsc#1012628).
- drm/amdgpu/cs: make commands with 0 chunks illegal behaviour
  (bsc#1012628).
- drm/nouveau/subdev/bus: Ratelimit logging for fault errors
  (bsc#1012628).
- drm/etnaviv: check for reaped mapping in etnaviv_iommu_unmap_gem
  (bsc#1012628).
- drm/nouveau/clk: Fix an incorrect NULL check on list iterator
  (bsc#1012628).
- drm/nouveau/kms/nv50-: atom: fix an incorrect NULL check on
  list iterator (bsc#1012628).
- drm/bridge: analogix_dp: Grab runtime PM reference for DP-AUX
  (bsc#1012628).
- drm/i915/dsi: fix VBT send packet port selection for ICL+
  (bsc#1012628).
- md: fix an incorrect NULL check in does_sb_need_changing
  (bsc#1012628).
- md: fix an incorrect NULL check in md_reload_sb (bsc#1012628).
- mtd: cfi_cmdset_0002: Move and rename
  chip_check/chip_ready/chip_good_for_write (bsc#1012628).
- mtd: cfi_cmdset_0002: Use chip_ready() for write on S29GL064N
  (bsc#1012628).
- media: coda: Fix reported H264 profile (bsc#1012628).
- media: coda: Add more H264 levels for CODA960 (bsc#1012628).
- ima: remove the IMA_TEMPLATE Kconfig option (bsc#1012628).
- Kconfig: Add option for asm goto w/ tied outputs to workaround
  clang-13 bug (bsc#1012628).
- lib/string_helpers: fix not adding strarray to device's resource
  list (bsc#1012628).
- RDMA/hfi1: Fix potential integer multiplication overflow errors
  (bsc#1012628).
- mmc: core: Allows to override the timeout value for ioctl()
  path (bsc#1012628).
- csky: patch_text: Fixup last cpu should be master (bsc#1012628).
- irqchip/armada-370-xp: Do not touch Performance Counter Overflow
  on A375, A38x, A39x (bsc#1012628).
- irqchip: irq-xtensa-mx: fix initial IRQ affinity (bsc#1012628).
- thermal: devfreq_cooling: use local ops instead of global ops
  (bsc#1012628).
- mt76: fix use-after-free by removing a non-RCU wcid pointer
  (bsc#1012628).
- cfg80211: declare MODULE_FIRMWARE for regulatory.db
  (bsc#1012628).
- mac80211: upgrade passive scan to active scan on DFS channels
  after beacon rx (bsc#1012628).
- um: virtio_uml: Fix broken device handling in time-travel
  (bsc#1012628).
- um: Use asm-generic/dma-mapping.h (bsc#1012628).
- um: chan_user: Fix winch_tramp() return value (bsc#1012628).
- um: Fix out-of-bounds read in LDT setup (bsc#1012628).
- MIPS: IP27: Remove incorrect `cpu_has_fpu' override
  (bsc#1012628).
- MIPS: IP30: Remove incorrect `cpu_has_fpu' override
  (bsc#1012628).
- kexec_file: drop weak attribute from
  arch_kexec_apply_relocations[_add] (bsc#1012628).
- ftrace: Clean up hash direct_functions on register failures
  (bsc#1012628).
- ksmbd: fix outstanding credits related bugs (bsc#1012628).
- iommu/msm: Fix an incorrect NULL check on list iterator
  (bsc#1012628).
- iommu/dma: Fix iova map result check bug (bsc#1012628).
- kprobes: Fix build errors with CONFIG_KRETPROBES=n
  (bsc#1012628).
- Revert "mm/cma.c: remove redundant cma_mutex lock"
  (bsc#1012628).
- mm/page_owner: use strscpy() instead of strlcpy() (bsc#1012628).
- mm/page_alloc: always attempt to allocate at least one page
  during bulk allocation (bsc#1012628).
- nodemask.h: fix compilation error with GCC12 (bsc#1012628).
- hugetlb: fix huge_pmd_unshare address update (bsc#1012628).
- mm/memremap: fix missing call to untrack_pfn() in
  pagemap_range() (bsc#1012628).
- xtensa/simdisk: fix proc_read_simdisk() (bsc#1012628).
- rtl818x: Prevent using not initialized queues (bsc#1012628).
- ASoC: rt5514: Fix event generation for "DSP Voice Wake Up"
  control (bsc#1012628).
- carl9170: tx: fix an incorrect use of list iterator
  (bsc#1012628).
- stm: ltdc: fix two incorrect NULL checks on list iterator
  (bsc#1012628).
- bcache: improve multithreaded bch_btree_check() (bsc#1012628).
- bcache: improve multithreaded bch_sectors_dirty_init()
  (bsc#1012628).
- bcache: remove incremental dirty sector counting for
  bch_sectors_dirty_init() (bsc#1012628).
- bcache: avoid journal no-space deadlock by reserving 1 journal
  bucket (bsc#1012628).
- serial: pch: don't overwrite xmit->buf[0] by x_char
  (bsc#1012628).
- tilcdc: tilcdc_external: fix an incorrect NULL check on list
  iterator (bsc#1012628).
- gma500: fix an incorrect NULL check on list iterator
  (bsc#1012628).
- arm64: dts: qcom: ipq8074: fix the sleep clock frequency
  (bsc#1012628).
- arm64: tegra: Add missing DFLL reset on Tegra210 (bsc#1012628).
- clk: tegra: Add missing reset deassertion (bsc#1012628).
- phy: qcom-qmp: fix struct clk leak on probe errors
  (bsc#1012628).
- ARM: dts: s5pv210: Remove spi-cs-high on panel in Aries
  (bsc#1012628).
- ARM: pxa: maybe fix gpio lookup tables (bsc#1012628).
- ceph: fix decoding of client session messages flags
  (bsc#1012628).
- misc: fastrpc: fix list iterator in fastrpc_req_mem_unmap_impl
  (bsc#1012628).
- SMB3: EBADF/EIO errors in rename/open caused by race condition
  in smb2_compound_op (bsc#1012628).
- docs/conf.py: Cope with removal of language=None in Sphinx 5.0.0
  (bsc#1012628).
- dt-bindings: gpio: altera: correct interrupt-cells
  (bsc#1012628).
- vdpasim: allow to enable a vq repeatedly (bsc#1012628).
- blk-iolatency: Fix inflight count imbalances and IO hangs on
  offline (bsc#1012628).
- coresight: core: Fix coresight device probe failure issue
  (bsc#1012628).
- phy: qcom-qmp: fix reset-controller leak on probe errors
  (bsc#1012628).
- net: ipa: fix page free in ipa_endpoint_trans_release()
  (bsc#1012628).
- net: ipa: fix page free in ipa_endpoint_replenish_one()
  (bsc#1012628).
- media: lirc: add missing exceptions for lirc uapi header file
  (bsc#1012628).
- kseltest/cgroup: Make test_stress.sh work if run interactively
  (bsc#1012628).
- perf evlist: Extend arch_evsel__must_be_in_group to support
  hybrid systems (bsc#1012628).
- Revert "random: use static branch for crng_ready()"
  (bsc#1012628).
- staging: r8188eu: delete rtw_wx_read/write32() (bsc#1012628).
- binder: fix sender_euid type in uapi header (bsc#1012628).
- RDMA/hns: Remove the num_cqc_timer variable (bsc#1012628).
- RDMA/rxe: Generate a completion for unsupported/invalid opcode
  (bsc#1012628).
- ext4: only allow test_dummy_encryption when supported
  (bsc#1012628).
- fs: add two trivial lookup helpers (bsc#1012628).
- exportfs: support idmapped mounts (bsc#1012628).
- md: Don't set mddev private to NULL in raid0 pers->free
  (bsc#1012628).
- md: fix double free of io_acct_set bioset (bsc#1012628).
- md: bcache: check the return value of kzalloc() in
  detached_dev_do_request() (bsc#1012628).
- macsec: fix UAF bug for real_dev (bsc#1012628).
- tty: n_gsm: Fix packet data hex dump output (bsc#1012628).
- pinctrl/rockchip: support setting input-enable param
  (bsc#1012628).
- block: fix bio_clone_blkg_association() to associate with
  proper blkcg_gq (bsc#1012628).
- Update config files.
  * EFI_DISABLE_RUNTIME=n -- the default.
  * the rest is non-configurable.
- Refresh patches.suse/vfs-add-super_operations-get_inode_dev.
- commit b06f595
* Wed Jun  8 2022 tiwai@suse.de
- Update config files: disable CONFIG_NET_DSA_REALTEK_* on x86_64 (bsc#1200254)
- commit 262234b
* Wed Jun  8 2022 tiwai@suse.de
- fs/ntfs3: Fix invalid free in log_replay (CVE-2022-1973
  bsc#1200023).
- commit 3433bd9
* Tue Jun  7 2022 tiwai@suse.de
- Update config files: restore CONFIG_I8K=y (bsc#1199958)
- commit 04cadbf
* Tue Jun  7 2022 mkubecek@suse.cz
- update CVE and bugzilla references
- patches.kernel.org/5.18.2-001-netfilter-nf_tables-disallow-non-stateful-expr.patch
  - add CVE-2022-1966 bsc#1200015
- patches.kernel.org/5.18.2-010-netfilter-nf_tables-sanitize-nft_set_desc_conc.patch
  - add CVE-2022-1972 bsc#1200019
- commit 6d13af9
* Tue Jun  7 2022 jslaby@suse.cz
- Update config files (only run_oldconfig.sh).
- commit 695cfee
* Mon Jun  6 2022 mkubecek@suse.cz
- Update to 5.19-rc1
- eliminate 54 patches (48 stable, 5 mainline, 1 other)
  - patches.kernel.org/*
  - patches.rpmify/scripts-dummy-tools-add-pahole.patch
  - patches.suse/KVM-x86-avoid-calling-x86-emulator-without-a-decoded-instruction
  - patches.suse/Revert-net-af_key-add-check-for-pfkey_broadcast-in-f.patch
  - patches.suse/iommu-amd-Increase-timeout-waiting-for-GA-log-enablement
  - patches.suse/simplefb-Enable-boot-time-VESA-graphic-mode-selectio.patch
  - patches.rpmify/powerpc-64-BE-option-to-use-ELFv2-ABI-for-big-endian.patch
- refresh
  - patches.suse/add-suse-supported-flag.patch
  - patches.suse/genksyms-add-override-flag.diff
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/vfs-add-super_operations-get_inode_dev
- 5.19-rc1 regression fix
  - patches.suse/drm-amdgpu-always-flush-the-TLB-on-gfx8.patch
- disable ARM architectures (need config update)
- new config options
  - General setup
  - CONFIG_BOOT_CONFIG_EMBED=n
  - CONFIG_INITRAMFS_PRESERVE_MTIME=y
  - Processor type and features
  - CONFIG_INTEL_TDX_GUEST=y
  - CONFIG_PERF_EVENTS_AMD_BRS=y
  - CONFIG_MICROCODE_LATE_LOADING=n
  - Enable loadable module support
  - CONFIG_MODULE_UNLOAD_TAINT_TRACKING=y
  - Memory Management options
  - CONFIG_PTE_MARKER_UFFD_WP=y
  - Networking support
  - CONFIG_CAN_CTUCANFD_PCI=m
  - File systems
  - CONFIG_CACHEFILES_ONDEMAND=n
  - CONFIG_HUGETLB_PAGE_OPTIMIZE_VMEMMAP_DEFAULT_ON=n
  - Security options
  - CONFIG_TRUSTED_KEYS_TPM=y
  - CONFIG_TRUSTED_KEYS_TEE=y
  - CONFIG_RANDSTRUCT_NONE=y
  - Cryptographic API
  - CONFIG_CRYPTO_SM3_GENERIC=m
  - CONFIG_CRYPTO_SM4_GENERIC=m
  - CONFIG_SYSTEM_BLACKLIST_AUTH_UPDATE=y
  - Kernel hacking
  - CONFIG_DEBUG_NET=n
  - CONFIG_RCU_EXP_CPU_STALL_TIMEOUT=0
  - Generic Driver Options
  - CONFIG_FW_LOADER_COMPRESS_XZ=y
  - CONFIG_FW_LOADER_COMPRESS_ZSTD=y
  - CONFIG_FW_UPLOAD=y
  - Firmware Drivers
  - CONFIG_EFI_DXE_MEM_ATTRIBUTES=y
  - CONFIG_EFI_DISABLE_RUNTIME=n
  - CONFIG_EFI_COCO_SECRET=y
  - Network device support
  - CONFIG_OCTEON_EP=m
  - CONFIG_SFC_SIENA=m
  - CONFIG_SFC_SIENA_MTD=y
  - CONFIG_SFC_SIENA_MCDI_MON=y
  - CONFIG_SFC_SIENA_SRIOV=y
  - CONFIG_SFC_SIENA_MCDI_LOGGING=y
  - CONFIG_ADIN1100_PHY=m
  - CONFIG_DP83TD510_PHY=m
  - CONFIG_WLAN_VENDOR_PURELIFI=y
  - CONFIG_PLFXLC=m
  - CONFIG_RTW89_8852CE=m
  - CONFIG_WLAN_VENDOR_SILABS=y
  - CONFIG_MTK_T7XX=m
  - Input device support
  - CONFIG_JOYSTICK_SENSEHAT=m
  - CONFIG_INPUT_IQS7222=m
  - Hardware Monitoring support
  - CONFIG_SENSORS_NCT6775_I2C=m
  - CONFIG_SENSORS_XDPE152=m
  - Sound card support
  - CONFIG_SND_SOC_CS35L45_SPI=m
  - CONFIG_SND_SOC_CS35L45_I2C=m
  - CONFIG_SND_SOC_MAX98396=m
  - CONFIG_SND_SOC_WM8731_I2C=n
  - CONFIG_SND_SOC_WM8731_SPI=n
  - CONFIG_SND_SOC_WM8940=n
  - Virtualization drivers
  - CONFIG_EFI_SECRET=m
  - CONFIG_SEV_GUEST=m
  - X86 Platform Specific Device Drivers
  - CONFIG_INTEL_IFS=m
  - CONFIG_WINMATE_FM07_KEYS=m
  - Industrial I/O support
  - CONFIG_DMARD06=n
  - CONFIG_IIO_RESCALE=m
  - CONFIG_DPOT_DAC=n
  - CONFIG_VF610_DAC=n
  - CONFIG_CM3605=n
  - CONFIG_AK8974=n
  - CONFIG_IIO_MUX=m
  - CONFIG_HTE=y
  - CONFIG_HTE=y
  - Misc devices
  - CONFIG_INTEL_MEI_GSC=m
  - CONFIG_MHI_BUS_EP=m
  - CONFIG_REGULATOR_RT5759=m
  - CONFIG_HID_MEGAWORLD_FF=m
  - CONFIG_TYPEC_MUX_FSA4480=m
  - CONFIG_LEDS_PWM_MULTICOLOR=m
  - CONFIG_CHROMEOS_ACPI=m
  - CONFIG_NVSW_SN2201=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - DRM_PANEL_NEWVISION_NV3052C=n
  - DRM_FSL_LDB=n
  - DRM_LONTIUM_LT9211=n
  - SND_SERIAL_GENERIC=m
  - LEDS_QCOM_LPG=m
  - OMAP_GPMC=m
  - OMAP_GPMC_DEBUG=n
  - PWM_XILINX=m
  - i386
  - CAN_CTUCANFD_PLATFORM=m
  - ppc64/ppc64le
  - KASAN=n
  - s390x
  - S390_UV_UAPI=m
  - MUX_ADG792A=n
  - riscv64
  - ERRATA_THEAD=y
  - ERRATA_THEAD_PBMT=y
  - RISCV_ISA_SVPBMT=y
  - KEXEC_FILE=y
  - COMPAT=y
  - ARCH_MMAP_RND_COMPAT_BITS=8 (default)
  - NETFILTER_XTABLES_COMPAT=y
  - CAN_CTUCANFD_PLATFORM=m
  - HW_RANDOM_POLARFIRE_SOC=m
  - DRM_DW_HDMI_GP_AUDIO=n
  - IMA_KEXEC=y
  - STACK_HASH_ORDER=20 (default)
  - PAGE_TABLE_CHECK=y
  - PAGE_TABLE_CHECK_ENFORCED=n
  - */debug
  - DEBUG_NET=y
- commit 515f42c
* Mon Jun  6 2022 jslaby@suse.cz
- Linux 5.18.2 (bsc#1012628).
- netfilter: nf_tables: disallow non-stateful expression in sets
  earlier (bsc#1012628).
- i2c: ismt: prevent memory corruption in ismt_access()
  (bsc#1012628).
- assoc_array: Fix BUG_ON during garbage collect (bsc#1012628).
- pipe: make poll_usage boolean and annotate its access
  (bsc#1012628).
- pipe: Fix missing lock in pipe_resize_ring() (bsc#1012628).
- net: ipa: compute proper aggregation limit (bsc#1012628).
- drm/i915: Fix -Wstringop-overflow warning in call to
  intel_read_wm_latency() (bsc#1012628).
- exfat: check if cluster num is valid (bsc#1012628).
- netfilter: nft_limit: Clone packet limits' cost value
  (bsc#1012628).
- netfilter: nf_tables: sanitize nft_set_desc_concat_parse()
  (bsc#1012628).
- netfilter: nf_tables: hold mutex on netns pre_exit path
  (bsc#1012628).
- netfilter: nf_tables: double hook unregistration in netns path
  (bsc#1012628).
- netfilter: conntrack: re-fetch conntrack after insertion
  (bsc#1012628).
- KVM: PPC: Book3S HV: fix incorrect NULL check on list iterator
  (bsc#1012628).
- x86/fpu: KVM: Set the base guest FPU uABI size to sizeof(struct
  kvm_xsave) (bsc#1012628).
- x86/kvm: Alloc dummy async #PF token outside of raw spinlock
  (bsc#1012628).
- x86, kvm: use correct GFP flags for preemption disabled
  (bsc#1012628).
- x86/uaccess: Implement macros for CMPXCHG on user addresses
  (bsc#1012628).
- KVM: x86: Use __try_cmpxchg_user() to update guest PTE A/D bits
  (bsc#1012628).
- KVM: x86: Use __try_cmpxchg_user() to emulate atomic accesses
  (bsc#1012628).
- KVM: x86: fix typo in __try_cmpxchg_user causing non-atomicness
  (bsc#1012628).
- KVM: x86: avoid loading a vCPU after .vm_destroy was called
  (bsc#1012628).
- KVM: x86: Fix the intel_pt PMI handling wrongly considered
  from guest (bsc#1012628).
- KVM: x86: Drop WARNs that assert a triple fault never "escapes"
  from L2 (bsc#1012628).
- KVM: x86/mmu: Don't rebuild page when the page is synced and
  no tlb flushing is required (bsc#1012628).
- KVM: SVM: Use kzalloc for sev ioctl interfaces to prevent
  kernel data leak (bsc#1012628).
- crypto: caam - fix i.MX6SX entropy delay value (bsc#1012628).
- crypto: ecrdsa - Fix incorrect use of vli_cmp (bsc#1012628).
- crypto: qat - rework the VF2PF interrupt handling logic
  (bsc#1012628).
- zsmalloc: fix races between asynchronous zspage free and page
  migration (bsc#1012628).
- tools/memory-model/README: Update klitmus7 compat table
  (bsc#1012628).
- ALSA: usb-audio: Workaround for clock setup on TEAC devices
  (bsc#1012628).
- ALSA: usb-audio: Add missing ep_idx in fixed EP quirks
  (bsc#1012628).
- ALSA: usb-audio: Configure sync endpoints before data
  (bsc#1012628).
- Bluetooth: hci_qca: Use del_timer_sync() before freeing
  (bsc#1012628).
- ARM: dts: s5pv210: Correct interrupt name for bluetooth in Aries
  (bsc#1012628).
- dm integrity: fix error code in dm_integrity_ctr()
  (bsc#1012628).
- dm crypt: make printing of the key constant-time (bsc#1012628).
- dm stats: add cond_resched when looping over entries
  (bsc#1012628).
- dm verity: set DM_TARGET_IMMUTABLE feature flag (bsc#1012628).
- raid5: introduce MD_BROKEN (bsc#1012628).
- fs/ntfs3: validate BOOT sectors_per_clusters (bsc#1012628).
- HID: multitouch: Add support for Google Whiskers Touchpad
  (bsc#1012628).
- HID: multitouch: add quirks to enable Lenovo X12 trackpoint
  (bsc#1012628).
- x86/sgx: Disconnect backing page references from dirty status
  (bsc#1012628).
- x86/sgx: Mark PCMD page as dirty when modifying contents
  (bsc#1012628).
- x86/sgx: Obtain backing storage page with enclave mutex held
  (bsc#1012628).
- x86/sgx: Fix race between reclaimer and page fault handler
  (bsc#1012628).
- x86/sgx: Ensure no data in PCMD page after truncate
  (bsc#1012628).
- media: i2c: imx412: Fix reset GPIO polarity (bsc#1012628).
- media: i2c: imx412: Fix power_off ordering (bsc#1012628).
- tpm: Fix buffer access in tpm2_get_tpm_pt() (bsc#1012628).
- tpm: ibmvtpm: Correct the return value in tpm_ibmvtpm_probe()
  (bsc#1012628).
- docs: submitting-patches: Fix crossref to 'The canonical patch
  format' (bsc#1012628).
- NFS: Memory allocation failures are not server fatal errors
  (bsc#1012628).
- NFSD: Fix possible sleep during nfsd4_release_lockowner()
  (bsc#1012628).
- bpf: Fill new bpf_prog_pack with illegal instructions
  (bsc#1012628).
- bpf: Fix potential array overflow in bpf_trampoline_get_progs()
  (bsc#1012628).
- bpf: Fix combination of jit blinding and pointers to bpf
  subprogs (bsc#1012628).
- bpf: Enlarge offset check value to INT_MAX in
  bpf_skb_{load,store}_bytes (bsc#1012628).
- bpf: Fix usage of trace RCU in local storage (bsc#1012628).
- bpf: Fix excessive memory allocation in stack_map_alloc()
  (bsc#1012628).
- bpf: Reject writes for PTR_TO_MAP_KEY in check_helper_mem_access
  (bsc#1012628).
- bpf: Check PTR_TO_MEM | MEM_RDONLY in check_helper_mem_access
  (bsc#1012628).
- bpf: Do write access check for kfunc and global func
  (bsc#1012628).
- ALSA: usb-audio: Optimize TEAC clock quirk (bsc#1012628).
- commit b7b9d3b
* Fri Jun  3 2022 jack@suse.cz
- Remove mistakenly enabled CONFIG_JBD2_DEBUG.
- commit 7534680
* Wed Jun  1 2022 jroedel@suse.de
- iommu/amd: Increase timeout waiting for GA log enablement
  (bsc#1199052).
- commit dfccb72
* Wed Jun  1 2022 jroedel@suse.de
- iommu/amd: Increase timeout waiting for GA log enablement
  (bsc#1199052).
- commit 0578d76
* Wed Jun  1 2022 jroedel@suse.de
- KVM: x86: avoid calling x86 emulator without a decoded
  instruction (CVE-2022-1852 bsc#1199875).
- commit b4b07c8
* Wed Jun  1 2022 jroedel@suse.de
- KVM: x86: avoid calling x86 emulator without a decoded
  instruction (CVE-2022-1852 bsc#1199875).
- commit 01a406d
* Mon May 30 2022 jslaby@suse.cz
- Linux 5.18.1 (bsc#1012628).
- ALSA: ctxfi: Add SB046x PCI ID (bsc#1012628).
- ACPI: sysfs: Fix BERT error region memory mapping (bsc#1012628).
- random: check for signals after page of pool writes
  (bsc#1012628).
- random: wire up fops->splice_{read,write}_iter() (bsc#1012628).
- random: convert to using fops->write_iter() (bsc#1012628).
- random: convert to using fops->read_iter() (bsc#1012628).
- random: unify batched entropy implementations (bsc#1012628).
- random: move randomize_page() into mm where it belongs
  (bsc#1012628).
- random: move initialization functions out of hot pages
  (bsc#1012628).
- random: make consistent use of buf and len (bsc#1012628).
- random: use proper return types on get_random_{int,long}_wait()
  (bsc#1012628).
- random: remove extern from functions in header (bsc#1012628).
- random: use static branch for crng_ready() (bsc#1012628).
- random: credit architectural init the exact amount
  (bsc#1012628).
- random: handle latent entropy and command line from
  random_init() (bsc#1012628).
- random: use proper jiffies comparison macro (bsc#1012628).
- random: remove ratelimiting for in-kernel unseeded randomness
  (bsc#1012628).
- random: move initialization out of reseeding hot path
  (bsc#1012628).
- random: avoid initializing twice in credit race (bsc#1012628).
- random: use symbolic constants for crng_init states
  (bsc#1012628).
- siphash: use one source of truth for siphash permutations
  (bsc#1012628).
- random: help compiler out with fast_mix() by using simpler
  arguments (bsc#1012628).
- random: do not use input pool from hard IRQs (bsc#1012628).
- random: order timer entropy functions below interrupt functions
  (bsc#1012628).
- random: do not pretend to handle premature next security model
  (bsc#1012628).
- random: use first 128 bits of input as fast init (bsc#1012628).
- random: do not use batches when !crng_ready() (bsc#1012628).
- random: insist on random_get_entropy() existing in order to
  simplify (bsc#1012628).
- xtensa: use fallback for random_get_entropy() instead of zero
  (bsc#1012628).
- sparc: use fallback for random_get_entropy() instead of zero
  (bsc#1012628).
- um: use fallback for random_get_entropy() instead of zero
  (bsc#1012628).
- x86/tsc: Use fallback for random_get_entropy() instead of zero
  (bsc#1012628).
- nios2: use fallback for random_get_entropy() instead of zero
  (bsc#1012628).
- arm: use fallback for random_get_entropy() instead of zero
  (bsc#1012628).
- mips: use fallback for random_get_entropy() instead of just
  c0 random (bsc#1012628).
- riscv: use fallback for random_get_entropy() instead of zero
  (bsc#1012628).
- m68k: use fallback for random_get_entropy() instead of zero
  (bsc#1012628).
- timekeeping: Add raw clock fallback for random_get_entropy()
  (bsc#1012628).
- powerpc: define get_cycles macro for arch-override
  (bsc#1012628).
- alpha: define get_cycles macro for arch-override (bsc#1012628).
- parisc: define get_cycles macro for arch-override (bsc#1012628).
- s390: define get_cycles macro for arch-override (bsc#1012628).
- ia64: define get_cycles macro for arch-override (bsc#1012628).
- init: call time_init() before rand_initialize() (bsc#1012628).
- random: fix sysctl documentation nits (bsc#1012628).
- HID: amd_sfh: Add support for sensor discovery (bsc#1012628).
- lockdown: also lock down previous kgdb use (bsc#1012628).
- commit df81444
* Fri May 27 2022 msuchanek@suse.de
- Update config files -- DEBUG_INFO_DWARF5 (bsc#1199932)
  Set DEBUG_INFO_DWARF5 which makes use of dwarf5 on gcc-7 and newer.
- commit d1b0a08
* Thu May 26 2022 mkubecek@suse.cz
- Update patches.suse/Revert-net-af_key-add-check-for-pfkey_broadcast-in-f.patch
  Update to upstream version, update upstream reference and move into sorted
  section.
- commit 3ae1db7
* Thu May 26 2022 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and move into sorted section:
  - patches.suse/simplefb-Enable-boot-time-VESA-graphic-mode-selectio.patch
- commit dc762c4
* Thu May 26 2022 msuchanek@suse.de
- kernel-binary.spec: Support radio selection for debuginfo.
  To disable debuginfo on 5.18 kernel a radio selection needs to be
  switched to a different selection. This requires disabling the currently
  active option and selecting NONE as debuginfo type.
- commit 43b5dd3
* Thu May 26 2022 jslaby@suse.cz
- Update config files -- DEBUG_INFO_DWARF_TOOLCHAIN_DEFAULT (bsc#1199932)
  Set DEBUG_INFO_DWARF_TOOLCHAIN_DEFAULT which makes use of dwarf5 on
  gcc-11 and newer.
- commit f439809
* Wed May 25 2022 jslaby@suse.cz
- random: do not use input pool from hard IRQs (bsc#1199803).
- commit 3352b92
* Mon May 23 2022 schwab@suse.de
- Add dtb-starfive
- commit 85335b1
* Mon May 23 2022 mkubecek@suse.cz
- Revert "net: af_key: add check for pfkey_broadcast in function
  pfkey_process" (20220523022438.ofhehjievu2alj3h@lion.mk-sys.cz).
- commit 2023975
* Sun May 22 2022 mkubecek@suse.cz
- Update to 5.18 final
- refresh configs (headers only)
- commit d0f5e4b
* Wed May 18 2022 tonyj@suse.de
- perf: Fix sys_perf_event_open() race against self
  (CVE-2022-1729, bsc#1199507).
- commit c1eda89
* Wed May 18 2022 tiwai@suse.de
- rpm/kernel-binary.spec.in: Fix missing kernel-preempt-devel and KMP Provides (bsc#1199046)
- commit 84d7ba8
* Wed May 18 2022 jslaby@suse.cz
- Linux 5.17.9 (bsc#1012628).
- batman-adv: Don't skb_split skbuffs with frag_list
  (bsc#1012628).
- iwlwifi: iwl-dbg: Use del_timer_sync() before freeing
  (bsc#1012628).
- hwmon: (tmp401) Add OF device ID table (bsc#1012628).
- mac80211: Reset MBSSID parameters upon connection (bsc#1012628).
- net: rds: use maybe_get_net() when acquiring refcount on TCP
  sockets (bsc#1012628).
- net: Fix features skip in for_each_netdev_feature()
  (bsc#1012628).
- net: mscc: ocelot: fix last VCAP IS1/IS2 filter persisting in
  hardware when deleted (bsc#1012628).
- net: mscc: ocelot: fix VCAP IS2 filters matching on both lookups
  (bsc#1012628).
- net: mscc: ocelot: restrict tc-trap actions to VCAP IS2 lookup 0
  (bsc#1012628).
- net: mscc: ocelot: avoid corrupting hardware counters when
  moving VCAP filters (bsc#1012628).
- fbdev: simplefb: Cleanup fb_info in .fb_destroy rather than
  .remove (bsc#1012628).
- fbdev: efifb: Cleanup fb_info in .fb_destroy rather than .remove
  (bsc#1012628).
- fbdev: vesafb: Cleanup fb_info in .fb_destroy rather than
  .remove (bsc#1012628).
- platform/surface: aggregator: Fix initialization order when
  compiling as builtin module (bsc#1012628).
- ice: Fix race during aux device (un)plugging (bsc#1012628).
- ice: clear stale Tx queue settings before configuring
  (bsc#1012628).
- ice: fix PTP stale Tx timestamps cleanup (bsc#1012628).
- ipv4: drop dst in multicast routing path (bsc#1012628).
- drm/nouveau: Fix a potential theorical leak in
  nouveau_get_backlight_name() (bsc#1012628).
- netlink: do not reset transport header in netlink_recvmsg()
  (bsc#1012628).
- net: chelsio: cxgb4: Avoid potential negative array offset
  (bsc#1012628).
- fbdev: efifb: Fix a use-after-free due early fb_info cleanup
  (bsc#1012628).
- net: sfc: fix memory leak due to ptp channel (bsc#1012628).
- fanotify: do not allow setting dirent events in mask of non-dir
  (bsc#1012628).
- mac80211_hwsim: call ieee80211_tx_prepare_skb under RCU
  protection (bsc#1012628).
- nfs: fix broken handling of the softreval mount option
  (bsc#1012628).
- ionic: fix missing pci_release_regions() on error in
  ionic_probe() (bsc#1012628).
- dim: initialize all struct fields (bsc#1012628).
- hwmon: (ltq-cputemp) restrict it to SOC_XWAY (bsc#1012628).
- procfs: prevent unprivileged processes accessing fdinfo dir
  (bsc#1012628).
- selftests: vm: Makefile: rename TARGETS to VMTARGETS
  (bsc#1012628).
- net: dsa: flush switchdev workqueue on bridge join error path
  (bsc#1012628).
- arm64: vdso: fix makefile dependency on vdso.so (bsc#1012628).
- virtio: fix virtio transitional ids (bsc#1012628).
- s390/ctcm: fix variable dereferenced before check (bsc#1012628).
- s390/ctcm: fix potential memory leak (bsc#1012628).
- s390/lcs: fix variable dereferenced before check (bsc#1012628).
- net/sched: act_pedit: really ensure the skb is writable
  (bsc#1012628).
- net: ethernet: mediatek: ppe: fix wrong size passed to memset()
  (bsc#1012628).
- net: bcmgenet: Check for Wake-on-LAN interrupt probe deferral
  (bsc#1012628).
- drm/vc4: hdmi: Fix build error for implicit function declaration
  (bsc#1012628).
- mlxsw: Avoid warning during ip6gre device removal (bsc#1012628).
- net: dsa: bcm_sf2: Fix Wake-on-LAN with mac_link_down()
  (bsc#1012628).
- net/smc: non blocking recvmsg() return -EAGAIN when no data
  and signal_pending (bsc#1012628).
- net: sfc: ef10: fix memory leak in efx_ef10_mtd_probe()
  (bsc#1012628).
- tls: Fix context leak on tls_device_down (bsc#1012628).
- drm/vmwgfx: Fix fencing on SVGAv3 (bsc#1012628).
- gfs2: Fix filesystem block deallocation for short writes
  (bsc#1012628).
- hwmon: (asus_wmi_sensors) Fix CROSSHAIR VI HERO name
  (bsc#1012628).
- hwmon: (f71882fg) Fix negative temperature (bsc#1012628).
- RDMA/irdma: Fix deadlock in irdma_cleanup_cm_core()
  (bsc#1012628).
- iommu: arm-smmu: disable large page mappings for Nvidia arm-smmu
  (bsc#1012628).
- ASoC: max98090: Reject invalid values in custom control put()
  (bsc#1012628).
- ASoC: max98090: Generate notifications on changes for custom
  control (bsc#1012628).
- ASoC: ops: Validate input values in snd_soc_put_volsw_range()
  (bsc#1012628).
- s390: disable -Warray-bounds (bsc#1012628).
- ASoC: SOF: Fix NULL pointer exception in sof_pci_probe callback
  (bsc#1012628).
- io_uring: assign non-fixed early for async work (bsc#1012628).
- net: emaclite: Don't advertise 1000BASE-T and do auto
  negotiation (bsc#1012628).
- net: sfp: Add tx-fault workaround for Huawei MA5671A SFP ONT
  (bsc#1012628).
- secure_seq: use the 64 bits of the siphash for port offset
  calculation (bsc#1012628).
- tcp: use different parts of the port_offset for index and offset
  (bsc#1012628).
- tcp: resalt the secret every 10 seconds (bsc#1012628).
- tcp: add small random increments to the source port
  (bsc#1012628).
- tcp: dynamically allocate the perturb table used by source ports
  (bsc#1012628).
- tcp: increase source port perturb table to 2^16 (bsc#1012628).
- tcp: drop the hash_32() part from the index calculation
  (bsc#1012628).
- block: Do not call folio_next() on an unreferenced folio
  (bsc#1012628).
- interconnect: Restore sync state by ignoring ipa-virt in
  provider count (bsc#1012628).
- perf tests: Fix coresight `perf test` failure (bsc#1012628).
- firmware_loader: use kernel credentials when reading firmware
  (bsc#1012628).
- KVM: PPC: Book3S PR: Enable MSR_DR for switch_mmu_context()
  (bsc#1012628).
- usb: xhci-mtk: fix fs isoc's transfer error (bsc#1012628).
- x86/mm: Fix marking of unused sub-pmd ranges (bsc#1012628).
- tty/serial: digicolor: fix possible null-ptr-deref in
  digicolor_uart_probe() (bsc#1012628).
- tty: n_gsm: fix buffer over-read in gsm_dlci_data()
  (bsc#1012628).
- tty: n_gsm: fix mux activation issues in gsm_config()
  (bsc#1012628).
- tty: n_gsm: fix invalid gsmtty_write_room() result
  (bsc#1012628).
- usb: gadget: uvc: allow for application to cleanly shutdown
  (bsc#1012628).
- usb: cdc-wdm: fix reading stuck on device close (bsc#1012628).
- usb: typec: tcpci: Don't skip cleanup in .remove() on error
  (bsc#1012628).
- usb: typec: tcpci_mt6360: Update for BMC PHY setting
  (bsc#1012628).
- USB: serial: pl2303: add device id for HP LM930 Display
  (bsc#1012628).
- USB: serial: qcserial: add support for Sierra Wireless EM7590
  (bsc#1012628).
- USB: serial: option: add Fibocom L610 modem (bsc#1012628).
- USB: serial: option: add Fibocom MA510 modem (bsc#1012628).
- slimbus: qcom: Fix IRQ check in qcom_slim_probe (bsc#1012628).
- fsl_lpuart: Don't enable interrupts too early (bsc#1012628).
- genirq: Remove WARN_ON_ONCE() in generic_handle_domain_irq()
  (bsc#1012628).
- serial: 8250_mtk: Fix UART_EFR register address (bsc#1012628).
- serial: 8250_mtk: Fix register address for XON/XOFF character
  (bsc#1012628).
- ceph: fix setting of xattrs on async created inodes
  (bsc#1012628).
- Revert "mm/memory-failure.c: skip huge_zero_page in
  memory_failure()" (bsc#1012628).
- mm/huge_memory: do not overkill when splitting huge_zero_page
  (bsc#1012628).
- mm: mremap: fix sign for EFAULT error return value
  (bsc#1012628).
- drm/vmwgfx: Disable command buffers on svga3 without gbobjects
  (bsc#1012628).
- drm/nouveau/tegra: Stop using iommu_present() (bsc#1012628).
- i40e: i40e_main: fix a missing check on list iterator
  (bsc#1012628).
- net: phy: Fix race condition on link status change
  (bsc#1012628).
- writeback: Avoid skipping inode writeback (bsc#1012628).
- cgroup/cpuset: Remove cpus_allowed/mems_allowed setup in
  cpuset_init_smp() (bsc#1012628).
- ping: fix address binding wrt vrf (bsc#1012628).
- ath11k: reduce the wait time of 11d scan and hw scan while
  add interface (bsc#1012628).
- arm[64]/memremap: don't abuse pfn_valid() to ensure presence
  of linear map (bsc#1012628).
- net: phy: micrel: Do not use kszphy_suspend/resume for KSZ8061
  (bsc#1012628).
- net: phy: micrel: Pass .probe for KS8737 (bsc#1012628).
- SUNRPC: Ensure that the gssproxy client can start in a connected
  state (bsc#1012628).
- drm/vmwgfx: Initialize drm_mode_fb_cmd2 (bsc#1012628).
- Revert "drm/amd/pm: keep the BACO feature enabled for suspend"
  (bsc#1012628).
- dma-buf: call dma_buf_stats_setup after dmabuf is in valid list
  (bsc#1012628).
- mm/hwpoison: use pr_err() instead of dump_page() in
  get_any_page() (bsc#1012628).
- net: phy: micrel: Fix incorrect variable type in micrel
  (bsc#1012628).
- mm/kfence: reset PG_slab and memcg_data before freeing
  __kfence_pool (bsc#1012628).
- commit eab1a2c
* Mon May 16 2022 jslaby@suse.cz
- Linux 5.17.8 (bsc#1012628).
- mm: fix invalid page pointer returned with FOLL_PIN gups
  (bsc#1012628).
- mm,migrate: fix establishing demotion target (bsc#1012628).
- mm/mlock: fix potential imbalanced rlimit ucounts adjustment
  (bsc#1012628).
- mm/hwpoison: fix error page recovered but reported "not
  recovered" (bsc#1012628).
- mm: userfaultfd: fix missing cache flush in mcopy_atomic_pte()
  and __mcopy_atomic() (bsc#1012628).
- mm: shmem: fix missing cache flush in shmem_mfill_atomic_pte()
  (bsc#1012628).
- mm: hugetlb: fix missing cache flush in
  hugetlb_mcopy_atomic_pte() (bsc#1012628).
- mm: hugetlb: fix missing cache flush in
  copy_huge_page_from_user() (bsc#1012628).
- mm: fix missing cache flush for all tail pages of compound page
  (bsc#1012628).
- udf: Avoid using stale lengthOfImpUse (bsc#1012628).
- rfkill: uapi: fix RFKILL_IOCTL_MAX_SIZE ioctl request definition
  (bsc#1012628).
- Bluetooth: Fix the creation of hdev->name (bsc#1012628).
- commit 718e8e9
* Mon May 16 2022 mkubecek@suse.cz
- Update to 5.18-rc7
- commit 1778f40
* Thu May 12 2022 jslaby@suse.cz
- Linux 5.17.7 (bsc#1012628).
- PCI: aardvark: Update comment about link going down after
  link-up (bsc#1012628).
- PCI: aardvark: Drop __maybe_unused from advk_pcie_disable_phy()
  (bsc#1012628).
- PCI: aardvark: Don't mask irq when mapping (bsc#1012628).
- PCI: aardvark: Remove irq_mask_ack() callback for INTx
  interrupts (bsc#1012628).
- PCI: aardvark: Use separate INTA interrupt for emulated root
  bridge (bsc#1012628).
- PCI: aardvark: Fix support for PME requester on emulated bridge
  (bsc#1012628).
- PCI: aardvark: Add support for PME interrupts (bsc#1012628).
- PCI: aardvark: Optimize writing PCI_EXP_RTCTL_PMEIE and
  PCI_EXP_RTSTA_PME on emulated bridge (bsc#1012628).
- PCI: aardvark: Add support for ERR interrupt on emulated bridge
  (bsc#1012628).
- PCI: aardvark: Enable MSI-X support (bsc#1012628).
- PCI: aardvark: Fix setting MSI address (bsc#1012628).
- PCI: aardvark: Add support for masking MSI interrupts
  (bsc#1012628).
- PCI: aardvark: Refactor unmasking summary MSI interrupt
  (bsc#1012628).
- PCI: aardvark: Use dev_fwnode() instead of
  of_node_to_fwnode(dev->of_node) (bsc#1012628).
- PCI: aardvark: Make msi_domain_info structure a static driver
  structure (bsc#1012628).
- PCI: aardvark: Make MSI irq_chip structures static driver
  structures (bsc#1012628).
- PCI: aardvark: Check return value of generic_handle_domain_irq()
  when processing INTx IRQ (bsc#1012628).
- PCI: aardvark: Rewrite IRQ code to chained IRQ handler
  (bsc#1012628).
- PCI: aardvark: Replace custom PCIE_CORE_INT_* macros with
  PCI_INTERRUPT_* (bsc#1012628).
- mmc: rtsx: add 74 Clocks in power on flow (bsc#1012628).
- selftest/vm: verify remap destination address in mremap_test
  (bsc#1012628).
- selftest/vm: verify mmap addr in mremap_test (bsc#1012628).
- KVM: LAPIC: Enable timer posted-interrupt only when mwait/hlt
  is advertised (bsc#1012628).
- KVM: x86/mmu: avoid NULL-pointer dereference on page freeing
  bugs (bsc#1012628).
- KVM: x86: Do not change ICR on write to APIC_SELF_IPI
  (bsc#1012628).
- x86/kvm: Preserve BSP MSR_KVM_POLL_CONTROL across suspend/resume
  (bsc#1012628).
- KVM: selftests: Silence compiler warning in the
  kvm_page_table_test (bsc#1012628).
- kvm: selftests: do not use bitfields larger than 32-bits for
  PTEs (bsc#1012628).
- KVM: VMX: Exit to userspace if vCPU has injected exception
  and invalid state (bsc#1012628).
- KVM: SEV: Mark nested locking of vcpu->lock (bsc#1012628).
- iommu/dart: Add missing module owner to ops structure
  (bsc#1012628).
- fbdev: Make fb_release() return -ENODEV if fbdev was
  unregistered (bsc#1012628).
- kvm: x86/cpuid: Only provide CPUID leaf 0xA if host has
  architectural PMU (bsc#1012628).
- net: rds: acquire refcount on TCP sockets (bsc#1012628).
- gpio: mvebu: drop pwm base assignment (bsc#1012628).
- parisc: Mark cr16 clock unstable on all SMP machines
  (bsc#1012628).
- btrfs: always log symlinks in full mode (bsc#1012628).
- smsc911x: allow using IRQ0 (bsc#1012628).
- selftests: ocelot: tc_flower_chains: specify conform-exceed
  action for policer (bsc#1012628).
- bnxt_en: Fix unnecessary dropping of RX packets (bsc#1012628).
- bnxt_en: Fix possible bnxt_open() failure caused by wrong RFS
  flag (bsc#1012628).
- dt-bindings: pci: apple,pcie: Drop max-link-speed from example
  (bsc#1012628).
- selftests: mirror_gre_bridge_1q: Avoid changing PVID while
  interface is operational (bsc#1012628).
- rxrpc: Enable IPv6 checksums on transport socket (bsc#1012628).
- mld: respect RCU rules in ip6_mc_source() and ip6_mc_msfilter()
  (bsc#1012628).
- SUNRPC: Don't leak sockets in xs_local_connect() (bsc#1012628).
- hinic: fix bug of wq out of bound access (bsc#1012628).
- drm/msm/dp: remove fail safe mode related code (bsc#1012628).
- selftests/net: so_txtime: usage(): fix documentation of default
  clock (bsc#1012628).
- selftests/net: so_txtime: fix parsing of start time stamp on
  32 bit systems (bsc#1012628).
- net: emaclite: Add error handling for of_address_to_resource()
  (bsc#1012628).
- net: igmp: respect RCU rules in ip_mc_source() and
  ip_mc_msfilter() (bsc#1012628).
- net: cpsw: add missing of_node_put() in cpsw_probe_dt()
  (bsc#1012628).
- net: mdio: Fix ENOMEM return value in BCM6368 mux bus controller
  (bsc#1012628).
- net: stmmac: dwmac-sun8i: add missing of_node_put() in
  sun8i_dwmac_register_mdio_mux() (bsc#1012628).
- net: dsa: mt7530: add missing of_node_put() in mt7530_setup()
  (bsc#1012628).
- net: ethernet: mediatek: add missing of_node_put() in
  mtk_sgmii_init() (bsc#1012628).
- NFSv4: Don't invalidate inode attributes on delegation return
  (bsc#1012628).
- RDMA/irdma: Fix possible crash due to NULL netdev in notifier
  (bsc#1012628).
- RDMA/irdma: Reduce iWARP QP destroy time (bsc#1012628).
- RDMA/irdma: Flush iWARP QP if modified to ERR from RTR state
  (bsc#1012628).
- RDMA/siw: Fix a condition race issue in MPA request processing
  (bsc#1012628).
- SUNRPC release the transport of a relocated task with an
  assigned transport (bsc#1012628).
- ALSA: hda/realtek: Fix mute led issue on thinkpad with cs35l41
  s-codec (bsc#1012628).
- selftests/seccomp: Don't call read() on TTY from background pgrp
  (bsc#1012628).
- net/mlx5e: TC, fix decap fallback to uplink when int port not
  supported (bsc#1012628).
- net/mlx5e: Lag, Don't skip fib events on current dst
  (bsc#1012628).
- net/mlx5e: Lag, Fix fib_info pointer assignment (bsc#1012628).
- net/mlx5e: Lag, Fix use-after-free in fib event handler
  (bsc#1012628).
- net/mlx5: Fix deadlock in sync reset flow (bsc#1012628).
- net/mlx5: Avoid double clear or set of sync reset requested
  (bsc#1012628).
- net/mlx5: Fix matching on inner TTC (bsc#1012628).
- net/mlx5e: Fix the calling of update_buffer_lossy() API
  (bsc#1012628).
- net/mlx5e: CT: Fix queued up restore put() executing after
  relevant ft release (bsc#1012628).
- net/mlx5e: Don't match double-vlan packets if cvlan is not set
  (bsc#1012628).
- net/mlx5e: Fix wrong source vport matching on tunnel rule
  (bsc#1012628).
- net/mlx5: Fix slab-out-of-bounds while reading resource dump
  menu (bsc#1012628).
- net/mlx5e: Fix trust state reset in reload (bsc#1012628).
- iommu/dart: check return value after calling
  platform_get_resource() (bsc#1012628).
- iommu/vt-d: Drop stop marker messages (bsc#1012628).
- ASoC: soc-ops: fix error handling (bsc#1012628).
- ASoC: meson: axg-card: Fix nonatomic links (bsc#1012628).
- ASoC: meson: axg-tdm-interface: Fix formatters in trigger"
  (bsc#1012628).
- ASoC: dmaengine: Restore NULL prepare_slave_config() callback
  (bsc#1012628).
- hwmon: (pmbus) disable PEC if not enabled (bsc#1012628).
- hwmon: (adt7470) Fix warning on module removal (bsc#1012628).
- gpio: pca953x: fix irq_stat not updated when irq is disabled
  (irq_mask not set) (bsc#1012628).
- gpio: visconti: Fix fwnode of GPIO IRQ (bsc#1012628).
- NFC: netlink: fix sleep in atomic bug when firmware download
  timeout (bsc#1012628).
- nfc: nfcmrvl: main: reorder destructive operations in
  nfcmrvl_nci_unregister_dev to avoid bugs (bsc#1012628).
- nfc: replace improper check device_is_registered() in netlink
  related functions (bsc#1012628).
- can: grcan: only use the NAPI poll budget for RX (bsc#1012628).
- can: grcan: grcan_probe(): fix broken system id check for
  errata workaround needs (bsc#1012628).
- can: grcan: use ofdev->dev when allocating DMA memory
  (bsc#1012628).
- can: isotp: remove re-binding of bound socket (bsc#1012628).
- can: grcan: grcan_close(): fix deadlock (bsc#1012628).
- s390/dasd: Fix read inconsistency for ESE DASD devices
  (bsc#1012628).
- s390/dasd: Fix read for ESE with blksize < 4k (bsc#1012628).
- s390/dasd: prevent double format of tracks for ESE devices
  (bsc#1012628).
- s390/dasd: fix data corruption for ESE devices (bsc#1012628).
- ASoC: meson: Fix event generation for AUI CODEC mux
  (bsc#1012628).
- ASoC: meson: Fix event generation for G12A tohdmi mux
  (bsc#1012628).
- ASoC: meson: Fix event generation for AUI ACODEC mux
  (bsc#1012628).
- ASoC: wm8958: Fix change notifications for DSP controls
  (bsc#1012628).
- ASoC: rt9120: Correct the reg 0x09 size to one byte
  (bsc#1012628).
- ASoC: da7219: Fix change notifications for tone generator
  frequency (bsc#1012628).
- genirq: Synchronize interrupt thread startup (bsc#1012628).
- btrfs: skip compression property for anything other than files
  and dirs (bsc#1012628).
- btrfs: do not allow compression on nodatacow files
  (bsc#1012628).
- btrfs: export a helper for compression hard check (bsc#1012628).
- btrfs: do not BUG_ON() on failure to update inode when setting
  xattr (bsc#1012628).
- btrfs: force v2 space cache usage for subpage mount
  (bsc#1012628).
- btrfs: sysfs: export the balance paused state of exclusive
  operation (bsc#1012628).
- net: stmmac: disable Split Header (SPH) for Intel platforms
  (bsc#1012628).
- firewire: core: extend card->lock in fw_core_handle_bus_reset
  (bsc#1012628).
- firewire: remove check of list iterator against head past the
  loop body (bsc#1012628).
- firewire: fix potential uaf in outbound_phy_packet_callback()
  (bsc#1012628).
- timekeeping: Mark NMI safe time accessors as notrace
  (bsc#1012628).
- Revert "SUNRPC: attempt AF_LOCAL connect on setup"
  (bsc#1012628).
- hwmon: (pmbus) delta-ahe50dc-fan: work around hardware quirk
  (bsc#1012628).
- RISC-V: relocate DTB if it's outside memory region
  (bsc#1012628).
- drm/amdgpu: do not use passthrough mode in Xen dom0
  (bsc#1012628).
- drm/amd/display: Avoid reading audio pattern past
  AUDIO_CHANNELS_COUNT (bsc#1012628).
- iommu/arm-smmu-v3: Fix size calculation in
  arm_smmu_mm_invalidate_range() (bsc#1012628).
- iommu/vt-d: Calculate mask for non-aligned flushes
  (bsc#1012628).
- KVM: x86/svm: Account for family 17h event renumberings in
  amd_pmc_perf_hw_id (bsc#1012628).
- x86/fpu: Prevent FPU state corruption (bsc#1012628).
- gpiolib: of: fix bounds check for 'gpio-reserved-ranges'
  (bsc#1012628).
- mmc: core: Set HS clock speed before sending HS CMD13
  (bsc#1012628).
- mmc: sunxi-mmc: Fix DMA descriptors allocated above 32 bits
  (bsc#1012628).
- mmc: sdhci-msm: Reset GCC_SDCC_BCR register for SDHC
  (bsc#1012628).
- ALSA: fireworks: fix wrong return count shorter than expected
  by 4 bytes (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Yoga Duet 7 13ITL6 speakers
  (bsc#1012628).
- parisc: Merge model and model name into one line in
  /proc/cpuinfo (bsc#1012628).
- Revert "parisc: Mark sched_clock unstable only if clocks are
  not syncronized" (bsc#1012628).
- Revert "parisc: Mark cr16 CPU clocksource unstable on all SMP
  machines" (bsc#1012628).
- MIPS: Fix CP0 counter erratum detection for R4k CPUs
  (bsc#1012628).
- ipmi:ipmi_ipmb: Fix null-ptr-deref in ipmi_unregister_smi()
  (bsc#1012628).
- ipmi: When handling send message responses, don't process the
  message (bsc#1012628).
- pci_irq_vector() can't be used in atomic context any
  longer. This conflicts with the usage of this function
  in nic_mbx_intr_handler(). age of this function in
  nic_mbx_intr_handler() (bsc#1012628).
- commit c9a5fa1
* Mon May  9 2022 jslaby@suse.cz
- Linux 5.17.6 (bsc#1012628).
- usb: mtu3: fix USB 3.0 dual-role-switch from device to host
  (bsc#1012628).
- floppy: disable FDRAWCMD by default (bsc#1012628).
- USB: quirks: add a Realtek card reader (bsc#1012628).
- USB: quirks: add STRING quirk for VCOM device (bsc#1012628).
- USB: serial: whiteheat: fix heap overflow in
  WHITEHEAT_GET_DTR_RTS (bsc#1012628).
- USB: serial: cp210x: add PIDs for Kamstrup USB Meter Reader
  (bsc#1012628).
- USB: serial: option: add support for Cinterion MV32-WA/MV32-WB
  (bsc#1012628).
- USB: serial: option: add Telit 0x1057, 0x1058, 0x1075
  compositions (bsc#1012628).
- usb: xhci: tegra:Fix PM usage reference leak of
  tegra_xusb_unpowergate_partitions (bsc#1012628).
- xhci: Enable runtime PM on second Alderlake controller
  (bsc#1012628).
- xhci: stop polling roothubs after shutdown (bsc#1012628).
- xhci: increase usb U3 -> U0 link resume timeout from 100ms to
  500ms (bsc#1012628).
- iio: dac: ad5592r: Fix the missing return value (bsc#1012628).
- iio: scd4x: check return of scd4x_write_and_fetch (bsc#1012628).
- iio: dac: ad5446: Fix read_raw not returning set value
  (bsc#1012628).
- iio: magnetometer: ak8975: Fix the error handling in
  ak8975_power_on() (bsc#1012628).
- iio: imu: inv_icm42600: Fix I2C init possible nack
  (bsc#1012628).
- usb: misc: fix improper handling of refcount in uss720_probe()
  (bsc#1012628).
- usb: core: Don't hold the device lock while sleeping in
  do_proc_control() (bsc#1012628).
- usb: typec: ucsi: Fix reuse of completion structure
  (bsc#1012628).
- usb: typec: ucsi: Fix role swapping (bsc#1012628).
- usb: gadget: uvc: Fix crash when encoding data for usb request
  (bsc#1012628).
- usb: gadget: configfs: clear deactivation flag in
  configfs_composite_unbind() (bsc#1012628).
- usb: dwc3: Try usb-role-switch first in dwc3_drd_init
  (bsc#1012628).
- usb: dwc3: core: Fix tx/rx threshold settings (bsc#1012628).
- usb: dwc3: core: Only handle soft-reset in DCTL (bsc#1012628).
- usb: dwc3: gadget: Return proper request status (bsc#1012628).
- usb: dwc3: pci: add support for the Intel Meteor Lake-P
  (bsc#1012628).
- usb: cdns3: Fix issue for clear halt endpoint (bsc#1012628).
- usb: phy: generic: Get the vbus supply (bsc#1012628).
- kernfs: fix NULL dereferencing in kernfs_remove (bsc#1012628).
- binder: Gracefully handle BINDER_TYPE_FDA objects with num_fds=0
  (bsc#1012628).
- binder: Address corner cases in deferred copy and fixup
  (bsc#1012628).
- serial: imx: fix overrun interrupts in DMA mode (bsc#1012628).
- serial: amba-pl011: do not time out prematurely when draining
  tx fifo (bsc#1012628).
- serial: 8250: Also set sticky MCR bits in console restoration
  (bsc#1012628).
- serial: 8250: Correct the clock for EndRun PTP/1588 PCIe device
  (bsc#1012628).
- eeprom: at25: Use DMA safe buffers (bsc#1012628).
- arch_topology: Do not set llc_sibling if llc_id is invalid
  (bsc#1012628).
- topology: make core_mask include at least cluster_siblings
  (bsc#1012628).
- ceph: fix possible NULL pointer dereference for req->r_session
  (bsc#1012628).
- bus: mhi: host: pci_generic: Add missing poweroff() PM callback
  (bsc#1012628).
- bus: mhi: host: pci_generic: Flush recovery worker during freeze
  (bsc#1012628).
- arm64: dts: imx8mm-venice: fix spi2 pin configuration
  (bsc#1012628).
- pinctrl: samsung: fix missing GPIOLIB on ARM64 Exynos config
  (bsc#1012628).
- f2fs: should not truncate blocks during roll-forward recovery
  (bsc#1012628).
- hex2bin: make the function hex_to_bin constant-time
  (bsc#1012628).
- hex2bin: fix access beyond string end (bsc#1012628).
- bus: fsl-mc-msi: Fix MSI descriptor mutex lock for
  msi_first_desc() (bsc#1012628).
- riscv: patch_text: Fixup last cpu should be master
  (bsc#1012628).
- x86/cpu: Load microcode during restore_processor_state()
  (bsc#1012628).
- x86/pci/xen: Disable PCI/MSI[-X] masking for XEN_HVM guests
  (bsc#1012628).
- iocost: don't reset the inuse weight of under-weighted debtors
  (bsc#1012628).
- virtio_net: fix wrong buf address calculation when using xdp
  (bsc#1012628).
- cpufreq: qcom-hw: drop affinity hint before freeing the IRQ
  (bsc#1012628).
- cpufreq: qcom-hw: fix the race between LMH worker and cpuhp
  (bsc#1012628).
- cpufreq: qcom-hw: fix the opp entries refcounting (bsc#1012628).
- cpufreq: qcom-cpufreq-hw: Fix throttle frequency value on EPSS
  platforms (bsc#1012628).
- video: fbdev: udlfb: properly check endpoint type (bsc#1012628).
- arm64: dts: meson: remove CPU opps below 1GHz for G12B boards
  (bsc#1012628).
- arm64: dts: meson: remove CPU opps below 1GHz for SM1 boards
  (bsc#1012628).
- iio: dac: ad3552r: fix signedness bug in ad3552r_reset()
  (bsc#1012628).
- iio:imu:bmi160: disable regulator in error path (bsc#1012628).
- iio:filter:admv8818: select REGMAP_SPI for ADMV8818
  (bsc#1012628).
- mtd: rawnand: fix ecc parameters for mt7622 (bsc#1012628).
- tee: optee: add missing mutext_destroy in optee_ffa_probe
  (bsc#1012628).
- xsk: Fix l2fwd for copy mode + busy poll combo (bsc#1012628).
- arm64: dts: imx8qm: Correct SCU clock controller's compatible
  property (bsc#1012628).
- USB: Fix xhci event ring dequeue pointer ERDP update issue
  (bsc#1012628).
- soc: imx: imx8m-blk-ctrl: Fix IMX8MN_DISPBLK_PD_ISI hang
  (bsc#1012628).
- ARM: dts: imx6qdl-apalis: Fix sgtl5000 detection issue
  (bsc#1012628).
- iio:dac:ad3552r: Fix an IS_ERR() vs NULL check (bsc#1012628).
- arm64: dts: imx8mq-tqma8mq: change the spi-nor tx (bsc#1012628).
- arm64: dts: imx8mn: Fix SAI nodes (bsc#1012628).
- arm64: dts: meson-sm1-bananapi-m5: fix wrong GPIO pin labeling
  for CON1 (bsc#1012628).
- phy: samsung: Fix missing of_node_put() in exynos_sata_phy_probe
  (bsc#1012628).
- phy: samsung: exynos5250-sata: fix missing device put in probe
  error paths (bsc#1012628).
- ARM: OMAP2+: Fix refcount leak in omap_gic_of_init
  (bsc#1012628).
- bus: ti-sysc: Make omap3 gpt12 quirk handling SoC specific
  (bsc#1012628).
- ARM: dts: dra7: Fix suspend warning for vpe powerdomain
  (bsc#1012628).
- phy: ti: omap-usb2: Fix error handling in
  omap_usb2_enable_clocks (bsc#1012628).
- ARM: dts: at91: Map MCLK for wm8731 on at91sam9g20ek
  (bsc#1012628).
- ARM: dts: at91: sama5d4_xplained: fix pinctrl phandle name
  (bsc#1012628).
- ARM: dts: at91: fix pinctrl phandles (bsc#1012628).
- phy: mapphone-mdm6600: Fix PM error handling in
  phy_mdm6600_probe (bsc#1012628).
- phy: ti: Add missing pm_runtime_disable() in serdes_am654_probe
  (bsc#1012628).
- interconnect: qcom: sc7180: Drop IP0 interconnects
  (bsc#1012628).
- interconnect: qcom: sdx55: Drop IP0 interconnects (bsc#1012628).
- ARM: dts: Fix mmc order for omap3-gta04 (bsc#1012628).
- ARM: dts: am33xx-l4: Add missing touchscreen clock properties
  (bsc#1012628).
- ARM: dts: am3517-evm: Fix misc pinmuxing (bsc#1012628).
- ARM: dts: logicpd-som-lv: Fix wrong pinmuxing on OMAP35
  (bsc#1012628).
- pinctrl: qcom: sm6350: fix order of UFS & SDC pins
  (bsc#1012628).
- ipvs: correctly print the memory size of ip_vs_conn_tab
  (bsc#1012628).
- phy: amlogic: fix error path in phy_g12a_usb3_pcie_probe()
  (bsc#1012628).
- pinctrl: mediatek: moore: Fix build error (bsc#1012628).
- mtd: rawnand: Fix return value check of
  wait_for_completion_timeout (bsc#1012628).
- mtd: fix 'part' field data corruption in mtd_info (bsc#1012628).
- pinctrl: stm32: Do not call stm32_gpio_get() for edge triggered
  IRQs in EOI (bsc#1012628).
- memory: renesas-rpc-if: Fix HF/OSPI data transfer in Manual Mode
  (bsc#1012628).
- net: dsa: Add missing of_node_put() in dsa_port_link_register_of
  (bsc#1012628).
- netfilter: nft_set_rbtree: overlap detection with element
  re-addition after deletion (bsc#1012628).
- bpf, lwt: Fix crash when using bpf_skb_set_tunnel_key() from
  bpf_xmit lwt hook (bsc#1012628).
- pinctrl: rockchip: fix RK3308 pinmux bits (bsc#1012628).
- tcp: md5: incorrect tcp_header_len for incoming connections
  (bsc#1012628).
- pinctrl: stm32: Keep pinctrl block clock enabled when LEVEL
  IRQ requested (bsc#1012628).
- tcp: ensure to use the most recently sent skb when filling
  the rate sample (bsc#1012628).
- wireguard: device: check for metadata_dst with skb_valid_dst()
  (bsc#1012628).
- sctp: check asoc strreset_chunk in sctp_generate_reconf_event
  (bsc#1012628).
- ARM: dts: imx6ull-colibri: fix vqmmc regulator (bsc#1012628).
- arm64: dts: imx8mn-ddr4-evk: Describe the 32.768 kHz PMIC clock
  (bsc#1012628).
- pinctrl: pistachio: fix use of irq_of_parse_and_map()
  (bsc#1012628).
- cpufreq: fix memory leak in sun50i_cpufreq_nvmem_probe
  (bsc#1012628).
- net: hns3: clear inited state and stop client after failed to
  register netdev (bsc#1012628).
- net: hns3: fix error log of tx/rx tqps stats (bsc#1012628).
- net: hns3: modify the return code of
  hclge_get_ring_chain_from_mbx (bsc#1012628).
- net: hns3: add validity check for message data length
  (bsc#1012628).
- net: hns3: add return value for mailbox handling in PF
  (bsc#1012628).
- net/smc: sync err code when tcp connection was refused
  (bsc#1012628).
- net: lan966x: fix a couple off by one bugs (bsc#1012628).
- ip_gre: Make o_seqno start from 0 in native mode (bsc#1012628).
- ip6_gre: Make o_seqno start from 0 in native mode (bsc#1012628).
- ip_gre, ip6_gre: Fix race condition on o_seqno in collect_md
  mode (bsc#1012628).
- tcp: fix potential xmit stalls caused by TCP_NOTSENT_LOWAT
  (bsc#1012628).
- tcp: make sure treq->af_specific is initialized (bsc#1012628).
- bus: sunxi-rsb: Fix the return value of
  sunxi_rsb_device_create() (bsc#1012628).
- clk: sunxi: sun9i-mmc: check return value after calling
  platform_get_resource() (bsc#1012628).
- cpufreq: qcom-cpufreq-hw: Clear dcvs interrupts (bsc#1012628).
- mctp: defer the kfree of object mdev->addrs (bsc#1012628).
- net: bcmgenet: hide status block before TX timestamping
  (bsc#1012628).
- net: phy: marvell10g: fix return value on error (bsc#1012628).
- net: dsa: mv88e6xxx: Fix port_hidden_wait to account for
  port_base_addr (bsc#1012628).
- drm/sun4i: Remove obsolete references to PHYS_OFFSET
  (bsc#1012628).
- ice: wait 5 s for EMP reset after firmware flash (bsc#1012628).
- Bluetooth: hci_event: Fix checking for invalid handle on error
  status (bsc#1012628).
- net: dsa: lantiq_gswip: Don't set GSWIP_MII_CFG_RMII_CLK
  (bsc#1012628).
- io_uring: check reserved fields for send/sendmsg (bsc#1012628).
- io_uring: check reserved fields for recv/recvmsg (bsc#1012628).
- netfilter: nf_conntrack_tcp: re-init for syn packets only
  (bsc#1012628).
- netfilter: conntrack: fix udp offload timeout sysctl
  (bsc#1012628).
- platform/x86: asus-wmi: Potential buffer overflow in
  asus_wmi_evaluate_method_buf() (bsc#1012628).
- platform/x86: asus-wmi: Fix driver not binding when fan curve
  control probe fails (bsc#1012628).
- drm/amdkfd: Fix GWS queue count (bsc#1012628).
- drm/amd/display: Fix memory leak in dcn21_clock_source_create
  (bsc#1012628).
- tls: Skip tls_append_frag on zero copy size (bsc#1012628).
- bnx2x: fix napi API usage sequence (bsc#1012628).
- net: fec: add missing of_node_put() in fec_enet_init_stop_mode()
  (bsc#1012628).
- gfs2: Minor retry logic cleanup (bsc#1012628).
- gfs2: Make sure not to return short direct writes (bsc#1012628).
- gfs2: No short reads or writes upon glock contention
  (bsc#1012628).
- perf arm-spe: Fix addresses of synthesized SPE events
  (bsc#1012628).
- ixgbe: ensure IPsec VF<->PF compatibility (bsc#1012628).
- net: enetc: allow tc-etf offload even with NETIF_F_CSUM_MASK
  (bsc#1012628).
- Revert "ibmvnic: Add ethtool private flag for driver-defined
  queue limits" (bsc#1012628).
- tcp: fix F-RTO may not work correctly when receiving DSACK
  (bsc#1012628).
- ASoC: soc-pcm: use GFP_KERNEL when the code is sleepable
  (bsc#1012628).
- ASoC: cs35l41: Fix a shift-out-of-bounds warning found by UBSAN
  (bsc#1012628).
- ASoC: rt711/5682: check if bus is active before deferred jack
  detection (bsc#1012628).
- ASoC: Intel: soc-acpi: correct device endpoints for max98373
  (bsc#1012628).
- ASoC: wm8731: Disable the regulator when probing fails
  (bsc#1012628).
- Input: cypress-sf - register a callback to disable the
  regulators (bsc#1012628).
- ext4: fix bug_on in start_this_handle during umount filesystem
  (bsc#1012628).
- arch: xtensa: platforms: Fix deadlock in rs_close()
  (bsc#1012628).
- ksmbd: increment reference count of parent fp (bsc#1012628).
- ksmbd: set fixed sector size to FS_SECTOR_SIZE_INFORMATION
  (bsc#1012628).
- erofs: fix use-after-free of on-stack io[] (bsc#1012628).
- bonding: do not discard lowest hash bit for non layer3+4 hashing
  (bsc#1012628).
- x86: __memcpy_flushcache: fix wrong alignment if size > 2^32
  (bsc#1012628).
- cifs: destage any unwritten data to the server before calling
  copychunk_write (bsc#1012628).
- drivers: net: hippi: Fix deadlock in rr_close() (bsc#1012628).
- powerpc/perf: Fix 32bit compile (bsc#1012628).
- ALSA: hda: intel-dsp-config: Add RaptorLake PCI IDs
  (bsc#1012628).
- selftest/vm: verify mmap addr in mremap_test (bsc#1012628).
- selftest/vm: verify remap destination address in mremap_test
  (bsc#1012628).
- bfq: Fix warning in bfqq_request_over_limit() (bsc#1012628).
- Revert "ACPI: processor: idle: fix lockup regression on 32-bit
  ThinkPad T40" (bsc#1012628).
- Revert "block: inherit request start time from bio for
  BLK_CGROUP" (bsc#1012628).
- zonefs: Fix management of open zones (bsc#1012628).
- zonefs: Clear inode information flags on inode creation
  (bsc#1012628).
- kasan: prevent cpu_quarantine corruption when CPU offline and
  cache shrink occur at same time (bsc#1012628).
- mtd: rawnand: qcom: fix memory corruption that causes panic
  (bsc#1012628).
- netfilter: Update ip6_route_me_harder to consider L3 domain
  (bsc#1012628).
- drm/amdgpu: don't runtime suspend if there are displays attached
  (v3) (bsc#1012628).
- drm/i915: Check EDID for HDR static metadata when choosing blc
  (bsc#1012628).
- drm/i915: Fix SEL_FETCH_PLANE_*(PIPE_B+) register addresses
  (bsc#1012628).
- net: ethernet: stmmac: fix write to sgmii_adapter_base
  (bsc#1012628).
- ACPI: processor: idle: Avoid falling back to C3 type C-states
  (bsc#1012628).
- thermal: int340x: Fix attr.show callback prototype
  (bsc#1012628).
- btrfs: fix direct I/O read repair for split bios (bsc#1012628).
- btrfs: fix direct I/O writes for split bios on zoned devices
  (bsc#1012628).
- btrfs: fix leaked plug after failure syncing log on zoned
  filesystems (bsc#1012628).
- btrfs: zoned: use dedicated lock for data relocation
  (bsc#1012628).
- btrfs: fix assertion failure during scrub due to block group
  reallocation (bsc#1012628).
- ARM: dts: at91: sama7g5ek: enable pull-up on flexcom3 console
  lines (bsc#1012628).
- ARM: dts: imx8mm-venice-gw{71xx,72xx,73xx}: fix OTG controller
  OC mode (bsc#1012628).
- perf symbol: Pass is_kallsyms to symbols__fixup_end()
  (bsc#1012628).
- perf symbol: Update symbols__fixup_end() (bsc#1012628).
- perf symbol: Remove arch__symbols__fixup_end() (bsc#1012628).
- tty: n_gsm: fix missing mux reset on config change at responder
  (bsc#1012628).
- tty: n_gsm: fix restart handling via CLD command (bsc#1012628).
- tty: n_gsm: fix decoupled mux resource (bsc#1012628).
- tty: n_gsm: fix mux cleanup after unregister tty device
  (bsc#1012628).
- tty: n_gsm: fix wrong signal octet encoding in convergence
  layer type 2 (bsc#1012628).
- tty: n_gsm: fix frame reception handling (bsc#1012628).
- tty: n_gsm: fix malformed counter for out of frame data
  (bsc#1012628).
- netfilter: nft_socket: only do sk lookups when indev is
  available (bsc#1012628).
- tty: n_gsm: fix insufficient txframe size (bsc#1012628).
- tty: n_gsm: fix wrong DLCI release order (bsc#1012628).
- tty: n_gsm: fix missing explicit ldisc flush (bsc#1012628).
- tty: n_gsm: fix wrong command retry handling (bsc#1012628).
- tty: n_gsm: fix wrong command frame length field encoding
  (bsc#1012628).
- tty: n_gsm: fix wrong signal octets encoding in MSC
  (bsc#1012628).
- tty: n_gsm: fix missing tty wakeup in convergence layer type 2
  (bsc#1012628).
- tty: n_gsm: fix reset fifo race condition (bsc#1012628).
- tty: n_gsm: fix incorrect UA handling (bsc#1012628).
- tty: n_gsm: fix missing update of modem controls after DLCI open
  (bsc#1012628).
- tty: n_gsm: fix broken virtual tty handling (bsc#1012628).
- tty: n_gsm: fix invalid use of MSC in advanced option
  (bsc#1012628).
- tty: n_gsm: fix software flow control handling (bsc#1012628).
- tty: n_gsm: fix sometimes uninitialized warning in
  gsm_dlci_modem_output() (bsc#1012628).
- objtool: Fix code relocs vs weak symbols (bsc#1012628).
- objtool: Fix type of reloc::addend (bsc#1012628).
- powerpc/64: Add UADDR64 relocation support (bsc#1012628).
- Update config files.
- commit 35de487
* Mon May  9 2022 jslaby@suse.cz
- net: atlantic: always deep reset on pm op, fixing up my null
  deref regression (resume crash).
- commit e2300f2
* Sun May  8 2022 mkubecek@suse.cz
- Update to 5.18-rc6
- commit ed50f8f
* Fri May  6 2022 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: Also depend on dracut-systemd (bsc#1195775)
- commit 5d4e32c
* Thu May  5 2022 jslaby@suse.cz
- Revert "build initrd without systemd" (bsc#1195775)"
  This reverts commit 3a2140fa2acded48224e1438ac9b4775340c94c2. Again,
  this breaks many packages as:
  * iproute2 is missing, and
  * kernel-obs-qa fails with:
  Timed out waiting for device /dev/disk/by-id/virtio-0.
- commit 15dd151
* Wed May  4 2022 jslaby@suse.cz
- io_uring: fix uninitialized field in rw io_kiocb (bsc#1199087
  CVE-2022-29968).
- commit 8ca9274
* Tue May  3 2022 jslaby@suse.cz
- Revert "Revert "build initrd without systemd" (bsc#1195775)"
  This reverts commit e962fefb4c9cd553921cf49c24f9d0e1d16f90b3.
  d9a821b1f81a from packaging should fix this. So let's try.
- commit 3a2140f
* Tue May  3 2022 jslaby@suse.cz
- Revert "Revert "Revert "build initrd without systemd" (bsc#1195775)""
  This reverts commit ac62a28013491cd72dd4a81604454658314e4ba5. It's still
  not ready:
- some packages need iproute2
- osc shell is still defunct
- commit e962fef
* Mon May  2 2022 msuchanek@suse.de
- Update config files.
  No pmem support on s390 - no such device.
- commit 9704fc2
* Mon May  2 2022 dmueller@suse.com
- config.conf: reenable armv7hl configs
- Update config files for armv7hl lpae/default
- Inherit settings from x86_64
- Use =m where available
- stick with CONFIG_UNWINDER_FRAME_POINTER=y
- commit 2821d72
* Sun May  1 2022 mkubecek@suse.cz
- Update to 5.18-rc5
- new config options:
  - BLK_DEV_FD_RAWCMD=n
- commit da18d3b
* Fri Apr 29 2022 mkubecek@suse.cz
- Update
  patches.kernel.org/5.17.2-0822-net-x25-Fix-null-ptr-deref-caused-by-x25_disc.patch
  references (add CVE-2022-1516 bsc#1199012).
- commit af2638d
* Fri Apr 29 2022 msuchanek@suse.de
- Update config files (bsc#1199024).
  arm, i386 LIBNVDIMM y->m
  i386 X86_PMEM_LEGACY y->m
- commit ff4fa9f
* Wed Apr 27 2022 jslaby@suse.cz
- Linux 5.17.5 (bsc#1012628).
- etherdevice: Adjust ether_addr* prototypes to silence
  - Wstringop-overead (bsc#1012628).
- perf tools: Fix segfault accessing sample_id xyarray
  (bsc#1012628).
- drm/amd/display: Only set PSR version when valid (bsc#1012628).
- block/compat_ioctl: fix range check in BLKGETSIZE (bsc#1012628).
- gfs2: assign rgrp glock before compute_bitstructs (bsc#1012628).
- scsi: ufs: core: scsi_get_lba() error fix (bsc#1012628).
- net/sched: cls_u32: fix netns refcount changes in u32_change()
  (bsc#1012628).
- ALSA: usb-audio: Clear MIDI port active flag after draining
  (bsc#1012628).
- ALSA: usb-audio: add mapping for MSI MAG X570S Torpedo MAX
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Clevo NP70PNP (bsc#1012628).
- ASoC: atmel: Remove system clock tree configuration for
  at91sam9g20ek (bsc#1012628).
- ASoC: topology: Correct error handling in
  soc_tplg_dapm_widget_create() (bsc#1012628).
- ASoC: rk817: Use devm_clk_get() in rk817_platform_probe
  (bsc#1012628).
- ASoC: msm8916-wcd-digital: Check failure for
  devm_snd_soc_register_component (bsc#1012628).
- ASoC: codecs: wcd934x: do not switch off SIDO Buck when codec
  is in use (bsc#1012628).
- dmaengine: idxd: fix device cleanup on disable (bsc#1012628).
- dmaengine: imx-sdma: Fix error checking in sdma_event_remap
  (bsc#1012628).
- dmaengine: mediatek:Fix PM usage reference leak of
  mtk_uart_apdma_alloc_chan_resources (bsc#1012628).
- dmaengine: dw-edma: Fix unaligned 64bit access (bsc#1012628).
- spi: spi-mtk-nor: initialize spi controller after resume
  (bsc#1012628).
- firmware: cs_dsp: Fix overrun of unterminated control name
  string (bsc#1012628).
- esp: limit skb_page_frag_refill use to a single page
  (bsc#1012628).
- spi: cadence-quadspi: fix incorrect supports_op() return value
  (bsc#1012628).
- igc: Fix infinite loop in release_swfw_sync (bsc#1012628).
- igc: Fix BUG: scheduling while atomic (bsc#1012628).
- igc: Fix suspending when PTM is active (bsc#1012628).
- ice: allow creating VFs for !CONFIG_NET_SWITCHDEV (bsc#1012628).
- ice: fix crash in switchdev mode (bsc#1012628).
- ice: Fix memory leak in ice_get_orom_civd_data() (bsc#1012628).
- ALSA: hda/hdmi: fix warning about PCM count when used with SOF
  (bsc#1012628).
- rxrpc: Restore removed timer deletion (bsc#1012628).
- net/smc: Fix sock leak when release after smc_shutdown()
  (bsc#1012628).
- net/packet: fix packet_sock xmit return value checking
  (bsc#1012628).
- ip6_gre: Avoid updating tunnel->tun_hlen in __gre6_xmit()
  (bsc#1012628).
- ip6_gre: Fix skb_under_panic in __gre6_xmit() (bsc#1012628).
- net: restore alpha order to Ethernet devices in config
  (bsc#1012628).
- net/sched: cls_u32: fix possible leak in u32_init_knode()
  (bsc#1012628).
- l3mdev: l3mdev_master_upper_ifindex_by_index_rcu should be
  using netdev_master_upper_dev_get_rcu (bsc#1012628).
- ipv6: make ip6_rt_gc_expire an atomic_t (bsc#1012628).
- can: isotp: stop timeout monitoring when no first frame was sent
  (bsc#1012628).
- net: dsa: hellcreek: Calculate checksums in tagger
  (bsc#1012628).
- net: mscc: ocelot: fix broken IP multicast flooding
  (bsc#1012628).
- netlink: reset network and mac headers in netlink_dump()
  (bsc#1012628).
- drm/i915/display/psr: Unset enable_psr2_sel_fetch if other
  checks in intel_psr2_config_valid() fails (bsc#1012628).
- RISC-V: KVM: Remove 's' & 'u' as valid ISA extension
  (bsc#1012628).
- RISC-V: KVM: Restrict the extensions that can be disabled
  (bsc#1012628).
- net: stmmac: Use readl_poll_timeout_atomic() in atomic state
  (bsc#1012628).
- dmaengine: idxd: match type for retries var in idxd_enqcmds()
  (bsc#1012628).
- dmaengine: idxd: fix retry value to be constant for duration
  of function call (bsc#1012628).
- dmaengine: idxd: add RO check for wq max_batch_size write
  (bsc#1012628).
- dmaengine: idxd: add RO check for wq max_transfer_size write
  (bsc#1012628).
- dmaengine: idxd: skip clearing device context when device is
  read-only (bsc#1012628).
- selftests: mlxsw: vxlan_flooding: Prevent flooding of unwanted
  packets (bsc#1012628).
- selftests: mlxsw: vxlan_flooding_ipv6: Prevent flooding of
  unwanted packets (bsc#1012628).
- userfaultfd: mark uffd_wp regardless of VM_WRITE flag
  (bsc#1012628).
- arm64: mm: fix p?d_leaf() (bsc#1012628).
- XArray: Disallow sibling entries of nodes (bsc#1012628).
- drm/msm/gpu: Rename runtime suspend/resume functions
  (bsc#1012628).
- drm/msm/gpu: Remove mutex from wait_event condition
  (bsc#1012628).
- ARM: vexpress/spc: Avoid negative array index when !SMP
  (bsc#1012628).
- reset: renesas: Check return value of reset_control_deassert()
  (bsc#1012628).
- reset: tegra-bpmp: Restore Handle errors in BPMP response
  (bsc#1012628).
- platform/x86: samsung-laptop: Fix an unsigned comparison which
  can never be negative (bsc#1012628).
- ALSA: usb-audio: Fix undefined behavior due to shift overflowing
  the constant (bsc#1012628).
- drm/msm/disp: check the return value of kzalloc() (bsc#1012628).
- selftests: KVM: Free the GIC FD when cleaning up in arch_timer
  (bsc#1012628).
- ALSA: hda: intel-dsp-config: update AlderLake PCI IDs
  (bsc#1012628).
- arm64: dts: imx: Fix imx8*-var-som touchscreen property sizes
  (bsc#1012628).
- vxlan: fix error return code in vxlan_fdb_append (bsc#1012628).
- cifs: Check the IOCB_DIRECT flag, not O_DIRECT (bsc#1012628).
- net: atlantic: Avoid out-of-bounds indexing (bsc#1012628).
- mt76: Fix undefined behavior due to shift overflowing the
  constant (bsc#1012628).
- brcmfmac: sdio: Fix undefined behavior due to shift overflowing
  the constant (bsc#1012628).
- dpaa_eth: Fix missing of_node_put in dpaa_get_ts_info()
  (bsc#1012628).
- drm/msm/mdp5: check the return of kzalloc() (bsc#1012628).
- KVM: x86: hyper-v: Avoid writing to TSC page without an active
  vCPU (bsc#1012628).
- net: macb: Restart tx only if queue pointer is lagging
  (bsc#1012628).
- scsi: iscsi: Release endpoint ID when its freed (bsc#1012628).
- scsi: iscsi: Merge suspend fields (bsc#1012628).
- scsi: iscsi: Fix NOP handling during conn recovery
  (bsc#1012628).
- scsi: qedi: Fix failed disconnect handling (bsc#1012628).
- stat: fix inconsistency between struct stat and struct
  compat_stat (bsc#1012628).
- VFS: filename_create(): fix incorrect intent (bsc#1012628).
- nvme: add a quirk to disable namespace identifiers
  (bsc#1012628).
- nvme-pci: disable namespace identifiers for the MAXIO
  MAP1002/1202 (bsc#1012628).
- nvme-pci: disable namespace identifiers for Qemu controllers
  (bsc#1012628).
- irq_work: use kasan_record_aux_stack_noalloc() record callstack
  (bsc#1012628).
- EDAC/synopsys: Read the error count from the correct register
  (bsc#1012628).
- mm/memory-failure.c: skip huge_zero_page in memory_failure()
  (bsc#1012628).
- memcg: sync flush only if periodic flush is delayed
  (bsc#1012628).
- mm, hugetlb: allow for "high" userspace addresses (bsc#1012628).
- oom_kill.c: futex: delay the OOM reaper to allow time for
  proper futex cleanup (bsc#1012628).
- mm/mmu_notifier.c: fix race in mmu_interval_notifier_remove()
  (bsc#1012628).
- ata: pata_marvell: Check the 'bmdma_addr' beforing reading
  (bsc#1012628).
- dma: at_xdmac: fix a missing check on list iterator
  (bsc#1012628).
- dmaengine: imx-sdma: fix init of uart scripts (bsc#1012628).
- net: atlantic: invert deep par in pm functions, preventing
  null derefs (bsc#1012628).
- drm/radeon: fix logic inversion in radeon_sync_resv
  (bsc#1012628).
- io_uring: free iovec if file assignment fails (bsc#1012628).
- Input: omap4-keypad - fix pm_runtime_get_sync() error checking
  (bsc#1012628).
- scsi: sr: Do not leak information in ioctl (bsc#1012628).
- sched/pelt: Fix attach_entity_load_avg() corner case
  (bsc#1012628).
- perf/core: Fix perf_mmap fail when CONFIG_PERF_USE_VMALLOC
  enabled (bsc#1012628).
- drm/panel/raspberrypi-touchscreen: Avoid NULL deref if not
  initialised (bsc#1012628).
- drm/panel/raspberrypi-touchscreen: Initialise the bridge in
  prepare (bsc#1012628).
- powerpc/time: Always set decrementer in timer_interrupt()
  (bsc#1012628).
- KVM: PPC: Fix TCE handling for VFIO (bsc#1012628).
- drm/vc4: Use pm_runtime_resume_and_get to fix
  pm_runtime_get_sync() usage (bsc#1012628).
- powerpc/perf: Fix power9 event alternatives (bsc#1012628).
- powerpc/perf: Fix power10 event alternatives (bsc#1012628).
- arm/xen: Fix some refcount leaks (bsc#1012628).
- perf script: Always allow field 'data_src' for auxtrace
  (bsc#1012628).
- perf report: Set PERF_SAMPLE_DATA_SRC bit for Arm SPE event
  (bsc#1012628).
- fs: fix acl translation (bsc#1012628).
- cifs: fix NULL ptr dereference in refresh_mounts()
  (bsc#1012628).
- cifs: use correct lock type in cifs_reconnect() (bsc#1012628).
- xtensa: patch_text: Fixup last cpu should be master
  (bsc#1012628).
- xtensa: fix a7 clobbering in coprocessor context load/store
  (bsc#1012628).
- openvswitch: fix OOB access in reserve_sfa_size() (bsc#1012628).
- ASoC: rt5682: fix an incorrect NULL check on list iterator
  (bsc#1012628).
- ASoC: soc-dapm: fix two incorrect uses of list iterator
  (bsc#1012628).
- e1000e: Fix possible overflow in LTR decoding (bsc#1012628).
- codecs: rt5682s: fix an incorrect NULL check on list iterator
  (bsc#1012628).
- ARC: entry: fix syscall_trace_exit argument (bsc#1012628).
- drm/vmwgfx: Fix gem refcounting and memory evictions
  (bsc#1012628).
- arm_pmu: Validate single/group leader events (bsc#1012628).
- KVM: x86/pmu: Update AMD PMC sample period to fix guest
  NMI-watchdog (bsc#1012628).
- KVM: x86: Don't re-acquire SRCU lock in complete_emulated_io()
  (bsc#1012628).
- KVM: x86: Pend KVM_REQ_APICV_UPDATE during vCPU creation to
  fix a race (bsc#1012628).
- KVM: nVMX: Defer APICv updates while L2 is active until L1 is
  active (bsc#1012628).
- KVM: SVM: Simplify and harden helper to flush SEV guest page(s)
  (bsc#1012628).
- KVM: SVM: Flush when freeing encrypted pages even on
  SME_COHERENT CPUs (bsc#1012628).
- ext4: fix fallocate to use file_modified to update permissions
  consistently (bsc#1012628).
- ext4: fix symlink file size not match to file content
  (bsc#1012628).
- ext4: fix use-after-free in ext4_search_dir (bsc#1012628).
- ext4: limit length to bitmap_maxbytes - blocksize in punch_hole
  (bsc#1012628).
- ext4, doc: fix incorrect h_reserved size (bsc#1012628).
- ext4: fix overhead calculation to account for the reserved
  gdt blocks (bsc#1012628).
- ext4: force overhead calculation if the s_overhead_cluster
  makes no sense (bsc#1012628).
- ext4: update the cached overhead value in the superblock
  (bsc#1012628).
- jbd2: fix a potential race while discarding reserved buffers
  after an abort (bsc#1012628).
- spi: atmel-quadspi: Fix the buswidth adjustment between spi-mem
  and controller (bsc#1012628).
- ASoC: SOF: topology: cleanup dailinks on widget unload
  (bsc#1012628).
- io_uring: fix leaks on IOPOLL and CQE_SKIP (bsc#1012628).
- arm64: dts: qcom: add IPA qcom,qmp property (bsc#1012628).
- Update config files.
- commit fd20f5f
* Wed Apr 27 2022 jslaby@suse.cz
- Refresh
  patches.suse/simplefb-Enable-boot-time-VESA-graphic-mode-selectio.patch.
  Update upstream status.
- commit 3b1b874
* Wed Apr 27 2022 jslaby@suse.cz
- Refresh
  patches.suse/gpio-Request-interrupts-after-IRQ-is-initialized.patch.
  Update upstream status.
- commit 90a0e50
* Mon Apr 25 2022 msuchanek@suse.de
- pahole 1.22 required for full BTF features.
  also recommend pahole for kernel-source to make the kernel buildable
  with standard config
- commit 364f54b
* Mon Apr 25 2022 jslaby@suse.cz
- Update config files.
  Just running oldconfig after 5.17.4.
- commit 2e251f8
* Mon Apr 25 2022 jslaby@suse.cz
- Revert "Revert "build initrd without systemd" (bsc#1195775)"
  This reverts commit 5d1f5d2e7552fcd3d37c11eb714944859e92e7b4. A fix is
  to be merged via packaging.
- commit ac62a28
* Mon Apr 25 2022 mkubecek@suse.cz
- Update to 5.18-rc4
- refresh configs
- commit 4ddddbd
* Fri Apr 22 2022 tiwai@suse.de
- gpio: Request interrupts after IRQ is initialized (bsc#1198697).
- commit 283f2c7
* Fri Apr 22 2022 dmueller@suse.com
- use jobs not processors in the constraints
  jobs is the number of vcpus available to the build, while processors
  is the total processor count of the machine the VM is running on.
- commit a6e141d
* Thu Apr 21 2022 dmueller@suse.com
- config.conf: reenable armv6hl config
  Uses same config settings like x86_64
- commit 1fbebaa
* Thu Apr 21 2022 jslaby@suse.cz
- scripts: dummy-tools, add pahole (bsc#1198388).
- scripts: dummy-tools, add pahole (bsc#1198388).
- Update config files.
  The config files now contain the dummy PAHOLE_VERSION (9999).
- commit 1fe0032
* Wed Apr 20 2022 jslaby@suse.cz
- Linux 5.17.4 (bsc#1012628).
- drm/amd/display: Add pstate verification and recovery for DCN31
  (bsc#1012628).
- drm/amd/display: Fix p-state allow debug index on dcn31
  (bsc#1012628).
- cpuidle: PSCI: Move the `has_lpi` check to the beginning of
  the function (bsc#1012628).
- ACPI: processor idle: Check for architectural support for LPI
  (bsc#1012628).
- net: dsa: realtek: allow subdrivers to externally lock regmap
  (bsc#1012628).
- net: dsa: realtek: rtl8365mb: serialize indirect PHY register
  access (bsc#1012628).
- net: dsa: realtek: make interface drivers depend on OF
  (bsc#1012628).
- btrfs: remove no longer used counter when reading data page
  (bsc#1012628).
- btrfs: remove unused variable in
  btrfs_{start,write}_dirty_block_groups() (bsc#1012628).
- RISC-V: KVM: Don't clear hgatp CSR in kvm_arch_vcpu_put()
  (bsc#1012628).
- media: si2157: unknown chip version Si2147-A30 ROM 0x50
  (bsc#1012628).
- uapi/linux/stddef.h: Add include guards (bsc#1012628).
- drm/amdgpu: Ensure HDA function is suspended before ASIC reset
  (bsc#1012628).
- btrfs: release correct delalloc amount in direct IO write path
  (bsc#1012628).
- btrfs: fix btrfs_submit_compressed_write cgroup attribution
  (bsc#1012628).
- btrfs: return allocated block group from do_chunk_alloc()
  (bsc#1012628).
- ALSA: core: Add snd_card_free_on_error() helper (bsc#1012628).
- ALSA: sis7019: Fix the missing error handling (bsc#1012628).
- ALSA: ali5451: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: als300: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: als4000: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: atiixp: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: au88x0: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: aw2: Fix the missing snd_card_free() call at probe error
  (bsc#1012628).
- ALSA: azt3328: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: bt87x: Fix the missing snd_card_free() call at probe error
  (bsc#1012628).
- ALSA: ca0106: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: cmipci: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: cs4281: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: cs5535audio: Fix the missing snd_card_free() call at
  probe error (bsc#1012628).
- ALSA: echoaudio: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: emu10k1x: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: ens137x: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: es1938: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: es1968: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: fm801: Fix the missing snd_card_free() call at probe error
  (bsc#1012628).
- ALSA: galaxy: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: hdsp: Fix the missing snd_card_free() call at probe error
  (bsc#1012628).
- ALSA: hdspm: Fix the missing snd_card_free() call at probe error
  (bsc#1012628).
- ALSA: ice1724: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: intel8x0: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: intel_hdmi: Fix the missing snd_card_free() call at
  probe error (bsc#1012628).
- ALSA: korg1212: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: lola: Fix the missing snd_card_free() call at probe error
  (bsc#1012628).
- ALSA: lx6464es: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: maestro3: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: oxygen: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: riptide: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: rme32: Fix the missing snd_card_free() call at probe error
  (bsc#1012628).
- ALSA: rme9652: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: rme96: Fix the missing snd_card_free() call at probe error
  (bsc#1012628).
- ALSA: sc6000: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: sonicvibes: Fix the missing snd_card_free() call at
  probe error (bsc#1012628).
- ALSA: via82xx: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: usb-audio: Cap upper limits of buffer/period bytes for
  implicit fb (bsc#1012628).
- ALSA: nm256: Don't call card private_free at probe error path
  (bsc#1012628).
- drm/msm: Add missing put_task_struct() in debugfs path
  (bsc#1012628).
- nfsd: Fix a write performance regression (bsc#1012628).
- firmware: arm_scmi: Remove clear channel call on the TX channel
  (bsc#1012628).
- memory: atmel-ebi: Fix missing of_node_put in atmel_ebi_probe
  (bsc#1012628).
- Revert "ath11k: mesh: add support for 256 bitmap in blockack
  frames in 11ax" (bsc#1012628).
- firmware: arm_scmi: Fix sorting of retrieved clock rates
  (bsc#1012628).
- media: rockchip/rga: do proper error checking in probe
  (bsc#1012628).
- KVM: arm64: Generalise VM features into a set of flags
  (bsc#1012628).
- KVM: arm64: mixed-width check should be skipped for
  uninitialized vCPUs (bsc#1012628).
- SUNRPC: Fix the svc_deferred_event trace class (bsc#1012628).
- net/sched: flower: fix parsing of ethertype following VLAN
  header (bsc#1012628).
- veth: Ensure eth header is in skb's linear part (bsc#1012628).
- gpiolib: acpi: use correct format characters (bsc#1012628).
- cifs: release cached dentries only if mount is complete
  (bsc#1012628).
- ice: arfs: fix use-after-free when freeing @rx_cpu_rmap
  (bsc#1012628).
- Revert "iavf: Fix deadlock occurrence during resetting VF
  interface" (bsc#1012628).
- net: mdio: don't defer probe forever if PHY IRQ provider is
  missing (bsc#1012628).
- mlxsw: i2c: Fix initialization error flow (bsc#1012628).
- sctp: use the correct skb for security_sctp_assoc_request
  (bsc#1012628).
- net/sched: fix initialization order when updating chain 0 head
  (bsc#1012628).
- cachefiles: unmark inode in use in error path (bsc#1012628).
- cachefiles: Fix KASAN slab-out-of-bounds in
  cachefiles_set_volume_xattr (bsc#1012628).
- net: dsa: felix: suppress -EPROBE_DEFER errors (bsc#1012628).
- KVM: selftests: riscv: Set PTE A and D bits in VS-stage page
  table (bsc#1012628).
- KVM: selftests: riscv: Fix alignment of the guest_hang()
  function (bsc#1012628).
- RISC-V: KVM: include missing hwcap.h into vcpu_fp (bsc#1012628).
- io_uring: flag the fact that linked file assignment is sane
  (bsc#1012628).
- net: ethernet: stmmac: fix altr_tse_pcs function when using
  a fixed-link (bsc#1012628).
- net/sched: taprio: Check if socket flags are valid
  (bsc#1012628).
- cfg80211: hold bss_lock while updating nontrans_list
  (bsc#1012628).
- mac80211: fix ht_capa printout in debugfs (bsc#1012628).
- netfilter: nft_socket: make cgroup match work in input too
  (bsc#1012628).
- drm/msm: Fix range size vs end confusion (bsc#1012628).
- drm/msm/dsi: Use connector directly in
  msm_dsi_manager_connector_init() (bsc#1012628).
- drm/msm/dp: add fail safe mode outside of event_mutex context
  (bsc#1012628).
- io_uring: stop using io_wq_work as an fd placeholder
  (bsc#1012628).
- net/smc: use memcpy instead of snprintf to avoid out of bounds
  read (bsc#1012628).
- net/smc: Fix NULL pointer dereference in smc_pnet_find_ib()
  (bsc#1012628).
- scsi: pm80xx: Mask and unmask upper interrupt vectors 32-63
  (bsc#1012628).
- scsi: pm80xx: Enable upper inbound, outbound queues
  (bsc#1012628).
- scsi: iscsi: Move iscsi_ep_disconnect() (bsc#1012628).
- scsi: iscsi: Fix offload conn cleanup when iscsid restarts
  (bsc#1012628).
- scsi: iscsi: Fix endpoint reuse regression (bsc#1012628).
- scsi: iscsi: Fix conn cleanup and stop race during iscsid
  restart (bsc#1012628).
- scsi: iscsi: Fix unbound endpoint error handling (bsc#1012628).
- sctp: Initialize daddr on peeled off socket (bsc#1012628).
- net: lan966x: Fix when a port's upper is changed (bsc#1012628).
- net: lan966x: Stop processing the MAC entry is port is wrong
  (bsc#1012628).
- netfilter: nf_tables: nft_parse_register can return a negative
  value (bsc#1012628).
- io_uring: fix assign file locking issue (bsc#1012628).
- ALSA: ad1889: Fix the missing snd_card_free() call at probe
  error (bsc#1012628).
- ALSA: mtpav: Don't call card private_free at probe error path
  (bsc#1012628).
- io_uring: move io_uring_rsrc_update2 validation (bsc#1012628).
- io_uring: verify that resv2 is 0 in io_uring_rsrc_update2
  (bsc#1012628).
- io_uring: verify pad field is 0 in io_get_ext_arg (bsc#1012628).
- testing/selftests/mqueue: Fix mq_perf_tests to free the
  allocated cpu set (bsc#1012628).
- ALSA: usb-audio: Increase max buffer size (bsc#1012628).
- ALSA: usb-audio: Limit max buffer and period sizes per time
  (bsc#1012628).
- perf tools: Fix misleading add event PMU debug message
  (bsc#1012628).
- macvlan: Fix leaking skb in source mode with nodst option
  (bsc#1012628).
- net: ftgmac100: access hardware register after clock ready
  (bsc#1012628).
- nfc: nci: add flush_workqueue to prevent uaf (bsc#1012628).
- cifs: potential buffer overflow in handling symlinks
  (bsc#1012628).
- dm mpath: only use ktime_get_ns() in historical selector
  (bsc#1012628).
- vfio/pci: Fix vf_token mechanism when device-specific VF
  drivers are used (bsc#1012628).
- tun: annotate access to queue->trans_start (bsc#1012628).
- net: dsa: felix: fix tagging protocol changes with multiple
  CPU ports (bsc#1012628).
- net: bcmgenet: Revert "Use stronger register read/writes to
  assure ordering" (bsc#1012628).
- block: fix offset/size check in bio_trim() (bsc#1012628).
- block: null_blk: end timed out poll request (bsc#1012628).
- io_uring: abort file assignment prior to assigning creds
  (bsc#1012628).
- KVM: PPC: Book3S HV P9: Fix "lost kick" race (bsc#1012628).
- drm/amd: Add USBC connector ID (bsc#1012628).
- btrfs: fix fallocate to use file_modified to update permissions
  consistently (bsc#1012628).
- btrfs: do not warn for free space inode in cow_file_range
  (bsc#1012628).
- drm/amdgpu: conduct a proper cleanup of PDB bo (bsc#1012628).
- drm/amdgpu/gmc: use PCI BARs for APUs in passthrough
  (bsc#1012628).
- drm/amd/display: fix audio format not updated after edid updated
  (bsc#1012628).
- drm/amd/display: FEC check in timing validation (bsc#1012628).
- drm/amd/display: Update VTEM Infopacket definition
  (bsc#1012628).
- drm/amdkfd: Fix Incorrect VMIDs passed to HWS (bsc#1012628).
- drm/amdgpu/vcn: improve vcn dpg stop procedure (bsc#1012628).
- drm/amdkfd: Check for potential null return of kmalloc_array()
  (bsc#1012628).
- Drivers: hv: vmbus: Deactivate sysctl_record_panic_msg by
  default in isolated guests (bsc#1012628).
- Drivers: hv: vmbus: Propagate VMbus coherence to each VMbus
  device (bsc#1012628).
- PCI: hv: Propagate coherence from VMbus device to PCI device
  (bsc#1012628).
- Drivers: hv: vmbus: Prevent load re-ordering when reading ring
  buffer (bsc#1012628).
- scsi: target: tcmu: Fix possible page UAF (bsc#1012628).
- scsi: lpfc: Improve PCI EEH Error and Recovery Handling
  (bsc#1012628).
- scsi: lpfc: Fix unload hang after back to back PCI EEH faults
  (bsc#1012628).
- scsi: lpfc: Fix queue failures when recovering from PCI parity
  error (bsc#1012628).
- scsi: ibmvscsis: Increase INITIAL_SRP_LIMIT to 1024
  (bsc#1012628).
- net: micrel: fix KS8851_MLL Kconfig (bsc#1012628).
- ata: libata-core: Disable READ LOG DMA EXT for Samsung 840 EVOs
  (bsc#1012628).
- gpu: ipu-v3: Fix dev_dbg frequency output (bsc#1012628).
- regulator: wm8994: Add an off-on delay for WM8994 variant
  (bsc#1012628).
- static_call: Properly initialise DEFINE_STATIC_CALL_RET0()
  (bsc#1012628).
- arm64: alternatives: mark patch_alternative() as `noinstr`
  (bsc#1012628).
- tlb: hugetlb: Add more sizes to tlb_remove_huge_tlb_entry
  (bsc#1012628).
- net: axienet: setup mdio unconditionally (bsc#1012628).
- Drivers: hv: balloon: Disable balloon and hot-add accordingly
  (bsc#1012628).
- net: usb: aqc111: Fix out-of-bounds accesses in RX fixup
  (bsc#1012628).
- myri10ge: fix an incorrect free for skb in myri10ge_sw_tso
  (bsc#1012628).
- spi: cadence-quadspi: fix protocol setup for non-1-1-X
  operations (bsc#1012628).
- drm/amd/display: Correct Slice reset calculation (bsc#1012628).
- drm/amd/display: Enable power gating before init_pipes
  (bsc#1012628).
- drm/amd/display: Revert FEC check in validation (bsc#1012628).
- drm/amd/display: Fix allocate_mst_payload assert on resume
  (bsc#1012628).
- drbd: set QUEUE_FLAG_STABLE_WRITES (bsc#1012628).
- scsi: mpt3sas: Fail reset operation if config request timed out
  (bsc#1012628).
- scsi: mvsas: Add PCI ID of RocketRaid 2640 (bsc#1012628).
- scsi: megaraid_sas: Target with invalid LUN ID is deleted
  during scan (bsc#1012628).
- drivers: net: slip: fix NPD bug in sl_tx_timeout()
  (bsc#1012628).
- x86,bpf: Avoid IBT objtool warning (bsc#1012628).
- io_uring: zero tag on rsrc removal (bsc#1012628).
- io_uring: use nospec annotation for more indexes (bsc#1012628).
- perf/imx_ddr: Fix undefined behavior due to shift overflowing
  the constant (bsc#1012628).
- mm/secretmem: fix panic when growing a memfd_secret
  (bsc#1012628).
- mm, page_alloc: fix build_zonerefs_node() (bsc#1012628).
- mm: fix unexpected zeroed page mapping with zram swap
  (bsc#1012628).
- mm: kmemleak: take a full lowmem check in kmemleak_*_phys()
  (bsc#1012628).
- hugetlb: do not demote poisoned hugetlb pages (bsc#1012628).
- revert "fs/binfmt_elf: fix PT_LOAD p_align values for loaders"
  (bsc#1012628).
- revert "fs/binfmt_elf: use PT_LOAD p_align values for static
  PIE" (bsc#1012628).
- KVM: x86/mmu: Resolve nx_huge_pages when kvm.ko is loaded
  (bsc#1012628).
- SUNRPC: Fix NFSD's request deferral on RDMA transports
  (bsc#1012628).
- memory: renesas-rpc-if: fix platform-device leak in error path
  (bsc#1012628).
- gcc-plugins: latent_entropy: use /dev/urandom (bsc#1012628).
- cifs: verify that tcon is valid before dereference in
  cifs_kill_sb (bsc#1012628).
- gpio: sim: fix setting and getting multiple lines (bsc#1012628).
- ath9k: Properly clear TX status area before reporting to
  mac80211 (bsc#1012628).
- ath9k: Fix usage of driver-private space in tx_info
  (bsc#1012628).
- btrfs: zoned: activate block group only for extent allocation
  (bsc#1012628).
- btrfs: fix root ref counts in error handling in
  btrfs_get_root_ref (bsc#1012628).
- btrfs: mark resumed async balance as writing (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Clevo PD50PNT (bsc#1012628).
- ALSA: hda/realtek: add quirk for Lenovo Thinkpad X12 speakers
  (bsc#1012628).
- ALSA: pcm: Test for "silence" field in struct "pcm_format_data"
  (bsc#1012628).
- nl80211: correctly check NL80211_ATTR_REG_ALPHA2 size
  (bsc#1012628).
- ipv6: fix panic when forwarding a pkt with no in6 dev
  (bsc#1012628).
- drm/amd/display: don't ignore alpha property on pre-multiplied
  mode (bsc#1012628).
- drm/amdgpu: Enable gfxoff quirk on MacBook Pro (bsc#1012628).
- x86/tsx: Use MSR_TSX_CTRL to clear CPUID bits (bsc#1012628).
- x86/tsx: Disable TSX development mode at boot (bsc#1012628).
- genirq/affinity: Consider that CPUs on nodes can be unbalanced
  (bsc#1012628).
- tick/nohz: Use WARN_ON_ONCE() to prevent console saturation
  (bsc#1012628).
- ARM: davinci: da850-evm: Avoid NULL pointer dereference
  (bsc#1012628).
- ep93xx: clock: Fix UAF in ep93xx_clk_register_gate()
  (bsc#1012628).
- dm integrity: fix memory corruption when tag_size is less than
  digest size (bsc#1012628).
- i2c: dev: check return value when calling dev_set_name()
  (bsc#1012628).
- Revert "net: dsa: setup master before ports" (bsc#1012628).
- smp: Fix offline cpu check in flush_smp_call_function_queue()
  (bsc#1012628).
- dt-bindings: memory: snps,ddrc-3.80a compatible also need
  interrupts (bsc#1012628).
- i2c: pasemi: Wait for write xfers to finish (bsc#1012628).
- dt-bindings: net: snps: remove duplicate name (bsc#1012628).
- timers: Fix warning condition in __run_timers() (bsc#1012628).
- dma-direct: avoid redundant memory sync for swiotlb
  (bsc#1012628).
- mm, kfence: support kmem_dump_obj() for KFENCE objects
  (bsc#1012628).
- drm/i915: Sunset igpu legacy mmap support based on
  GRAPHICS_VER_FULL (bsc#1012628).
- cpu/hotplug: Remove the 'cpu' member of cpuhp_cpu_state
  (bsc#1012628).
- ax25: Fix UAF bugs in ax25 timers (bsc#1012628).
- io_uring: use right issue_flags for splice/tee (bsc#1012628).
- io_uring: fix poll file assign deadlock (bsc#1012628).
- io_uring: fix poll error reporting (bsc#1012628).
- commit 75e9961
* Tue Apr 19 2022 fvogt@suse.de
- rpm/kernel-obs-build.spec.in: Include algif_hash, aegis128 and xts modules
  afgif_hash is needed by some packages (e.g. iwd) for tests, xts is used for
  LUKS2 volumes by default and aegis128 is useful as AEAD cipher for LUKS2.
  Wrap the long line to make it readable.
- commit bfd7db4
* Tue Apr 19 2022 jslaby@suse.cz
- Update config files. (vanilla)
  After commit b76702ae4983 (Update config files.), arm64 vanilla fails.
  Just ran oldconfig.
- commit 2d96192
* Tue Apr 19 2022 jslaby@suse.cz
- Update
  patches.kernel.org/5.17.3-312-SUNRPC-Ensure-we-flush-any-closed-sockets-befo.patch
  (bsc#1012628 bsc#1198330 CVE-2022-28893).
  Update upstream status.
- commit a0f1f93
* Sun Apr 17 2022 mkubecek@suse.cz
- config: enable arm64 builds
- reenable arm64 configs after update to 5.18-rc2
- new arm64 config options:
  - SHADOW_CALL_STACK=n
  - RELR=n
  - KCOV=n
- commit ffb18e4
* Sun Apr 17 2022 mkubecek@suse.cz
- Update to 5.18-rc3
- update configs
  - x86_64
  - NET_DSA_REALTEK_RTL8365MB=m
  - NET_DSA_REALTEK_RTL8366RB=m
- commit 04810ad
* Fri Apr 15 2022 dmueller@suse.com
- Update config files.
  set modprobe path to /usr/sbin/modprobe after usrmerge completion
  in Tumbleweed.
- commit 767eb22
* Fri Apr 15 2022 dmueller@suse.com
- Update config files (bsc#1198722, bsc#1197746).
  Enable compiled in LSMs on boot
  * landlock: optional ability for user land applications to sandbox
  themselves
  * yama: optional restrict of use of ptrace for nonprivileged users
  * default to apparmor, list selinux before bpf to avoid bsc#1197746
  * bpf: create eBPF based LSMs dynamically
- commit 5506937
* Thu Apr 14 2022 dmueller@suse.com
- Update config files.
- set CONFIG_NO_HZ_FULL again on armv7/aarch64 (bsc#1189692)
- commit bfb0c41
* Thu Apr 14 2022 dmueller@suse.com
- Update config files.
  Disable legacy pty support (bsc#1198506)
- commit 295a9c6
* Thu Apr 14 2022 dmueller@suse.com
- Update config files.
  set CONFIG_LSM_MMAP_MIN_ADDR according to upstream default to
  32768/65536 to have a minimum protection against null pointer
  vulnerabilities. This was previously set to 0 to enable dosemu,
  but dosemu no longer requires that setting, especially not on
  non-x86.
- commit 30bf192
* Thu Apr 14 2022 jslaby@suse.cz
- Linux 5.17.3 (bsc#1012628).
- lib/logic_iomem: correct fallback config references
  (bsc#1012628).
- um: fix and optimize xor select template for CONFIG64 and
  timetravel mode (bsc#1012628).
- rtc: wm8350: Handle error for wm8350_register_irq (bsc#1012628).
- net: dsa: felix: fix possible NULL pointer dereference
  (bsc#1012628).
- mm: kfence: fix objcgs vector allocation (bsc#1012628).
- KVM: x86/pmu: Use different raw event masks for AMD and Intel
  (bsc#1012628).
- KVM: SVM: Fix kvm_cache_regs.h inclusions for is_guest_mode()
  (bsc#1012628).
- KVM: x86/svm: Clear reserved bits written to PerfEvtSeln MSRs
  (bsc#1012628).
- KVM: x86/pmu: Fix and isolate TSX-specific performance event
  logic (bsc#1012628).
- KVM: x86/emulator: Emulate RDPID only if it is enabled in guest
  (bsc#1012628).
- drm: Add orientation quirk for GPD Win Max (bsc#1012628).
- Bluetooth: hci_sync: Fix compilation warning (bsc#1012628).
- ath5k: fix OOB in ath5k_eeprom_read_pcal_info_5111
  (bsc#1012628).
- Bluetooth: fix null ptr deref on hci_sync_conn_complete_evt
  (bsc#1012628).
- drm/amd/display: Add signal type check when verify stream
  backends same (bsc#1012628).
- drm/amdkfd: enable heavy-weight TLB flush on Arcturus
  (bsc#1012628).
- drm/edid: remove non_desktop quirk for HPN-3515 and LEN-B800
  (bsc#1012628).
- drm/edid: improve non-desktop quirk logging (bsc#1012628).
- Bluetooth: hci_event: Ignore multiple conn complete events
  (bsc#1012628).
- drm/amd/amdgpu/amdgpu_cs: fix refcount leak of a dma_fence obj
  (bsc#1012628).
- drm/amd/display: Fix memory leak (bsc#1012628).
- drm/amd/display: Use PSR version selected during set_psr_caps
  (bsc#1012628).
- usb: gadget: tegra-xudc: Do not program SPARAM (bsc#1012628).
- usb: gadget: tegra-xudc: Fix control endpoint's definitions
  (bsc#1012628).
- usb: cdnsp: fix cdnsp_decode_trb function to properly handle
  ret value (bsc#1012628).
- ptp: replace snprintf with sysfs_emit (bsc#1012628).
- Bluetooth: hci_sync: Fix queuing commands when HCI_UNREGISTER
  is set (bsc#1012628).
- selftests, xsk: Fix bpf_res cleanup test (bsc#1012628).
- net/mlx5e: TC, Hold sample_attr on stack instead of pointer
  (bsc#1012628).
- drm/amdkfd: Don't take process mutex for svm ioctls
  (bsc#1012628).
- drm/amdkfd: Ensure mm remain valid in svm deferred_list work
  (bsc#1012628).
- drm/amdkfd: svm range restore work deadlock when process exit
  (bsc#1012628).
- drm/amdgpu: Fix an error message in rmmod (bsc#1012628).
- mlxsw: spectrum: Guard against invalid local ports
  (bsc#1012628).
- RDMA/rtrs-clt: Do stop and failover outside reconnect work
  (bsc#1012628).
- powerpc/xive: Export XIVE IPI information for online-only
  processors (bsc#1012628).
- powerpc: dts: t104xrdb: fix phy type for FMAN 4/5 (bsc#1012628).
- ath11k: fix kernel panic during unload/load ath11k modules
  (bsc#1012628).
- ath11k: pci: fix crash on suspend if board file is not found
  (bsc#1012628).
- ath11k: mhi: use mhi_sync_power_up() (bsc#1012628).
- net/smc: Send directly when TCP_CORK is cleared (bsc#1012628).
- drm/bridge: Add missing pm_runtime_put_sync (bsc#1012628).
- bpf: Make dst_port field in struct bpf_sock 16-bit wide
  (bsc#1012628).
- scsi: mvsas: Replace snprintf() with sysfs_emit() (bsc#1012628).
- scsi: bfa: Replace snprintf() with sysfs_emit() (bsc#1012628).
- drm/v3d: fix missing unlock (bsc#1012628).
- power: supply: axp20x_battery: properly report current when
  discharging (bsc#1012628).
- mt76: mt7921: fix crash when startup fails (bsc#1012628).
- mt76: dma: initialize skip_unmap in mt76_dma_rx_fill
  (bsc#1012628).
- i40e: Add sending commands in atomic context (bsc#1012628).
- cfg80211: don't add non transmitted BSS to 6GHz scanned channels
  (bsc#1012628).
- libbpf: Fix build issue with llvm-readelf (bsc#1012628).
- ipv6: make mc_forwarding atomic (bsc#1012628).
- ref_tracker: implement use-after-free detection (bsc#1012628).
- net: initialize init_net earlier (bsc#1012628).
- powerpc: Set crashkernel offset to mid of RMA region
  (bsc#1012628).
- drm/amdgpu: Fix recursive locking warning (bsc#1012628).
- scsi: smartpqi: Fix rmmod stack trace (bsc#1012628).
- scsi: smartpqi: Fix kdump issue when controller is locked up
  (bsc#1012628).
- PCI: aardvark: Fix support for MSI interrupts (bsc#1012628).
- kvm: selftests: aarch64: fix assert in gicv3_access_reg
  (bsc#1012628).
- kvm: selftests: aarch64: pass vgic_irq guest args as a pointer
  (bsc#1012628).
- kvm: selftests: aarch64: fix the failure check in
  kvm_set_gsi_routing_irqchip_check (bsc#1012628).
- kvm: selftests: aarch64: fix some vgic related comments
  (bsc#1012628).
- kvm: selftests: aarch64: use a tighter assert in vgic_poke_irq()
  (bsc#1012628).
- iommu/arm-smmu-v3: fix event handling soft lockup (bsc#1012628).
- usb: ehci: add pci device support for Aspeed platforms
  (bsc#1012628).
- KVM: arm64: Do not change the PMU event filter after a VCPU
  has run (bsc#1012628).
- libbpf: Fix accessing syscall arguments on powerpc
  (bsc#1012628).
- libbpf: Fix accessing the first syscall argument on arm64
  (bsc#1012628).
- libbpf: Fix accessing the first syscall argument on s390
  (bsc#1012628).
- PCI: endpoint: Fix alignment fault error in copy tests
  (bsc#1012628).
- tcp: Don't acquire inet_listen_hashbucket::lock with disabled BH
  (bsc#1012628).
- PCI: pciehp: Add Qualcomm quirk for Command Completed erratum
  (bsc#1012628).
- scsi: mpi3mr: Fix deadlock while canceling the fw event
  (bsc#1012628).
- scsi: mpi3mr: Fix reporting of actual data transfer size
  (bsc#1012628).
- scsi: mpi3mr: Fix memory leaks (bsc#1012628).
- powerpc/set_memory: Avoid spinlock recursion in
  change_page_attr() (bsc#1012628).
- power: supply: axp288-charger: Set Vhold to 4.4V (bsc#1012628).
- drm/sprd: fix potential NULL dereference (bsc#1012628).
- drm/sprd: check the platform_get_resource() return value
  (bsc#1012628).
- drm/amd/display: reset lane settings after each PHY repeater LT
  (bsc#1012628).
- net/mlx5e: Disable TX queues before registering the netdev
  (bsc#1012628).
- HID: apple: Report Magic Keyboard 2021 battery over USB
  (bsc#1012628).
- HID: apple: Report Magic Keyboard 2021 with fingerprint reader
  battery over USB (bsc#1012628).
- usb: dwc3: pci: Set the swnode from inside dwc3_pci_quirks()
  (bsc#1012628).
- iwlwifi: mvm: Correctly set fragmented EBS (bsc#1012628).
- iwlwifi: fix small doc mistake for iwl_fw_ini_addr_val
  (bsc#1012628).
- iwlwifi: mvm: move only to an enabled channel (bsc#1012628).
- ipv6: annotate some data-races around sk->sk_prot (bsc#1012628).
- drm/msm/dsi: Remove spurious IRQF_ONESHOT flag (bsc#1012628).
- x86/mce: Work around an erratum on fast string copy instructions
  (bsc#1012628).
- rtw89: fix RCU usage in rtw89_core_txq_push() (bsc#1012628).
- ath11k: Fix frames flush failure caused by deadlock
  (bsc#1012628).
- ipv4: Invalidate neighbour for broadcast address upon address
  addition (bsc#1012628).
- rtw88: change rtw_info() to proper message level (bsc#1012628).
- dm ioctl: prevent potential spectre v1 gadget (bsc#1012628).
- dm: requeue IO if mapping table not yet available (bsc#1012628).
- drm/amdkfd: make CRAT table missing message informational only
  (bsc#1012628).
- vfio/pci: Stub vfio_pci_vga_rw when !CONFIG_VFIO_PCI_VGA
  (bsc#1012628).
- scsi: pm8001: Fix pm80xx_pci_mem_copy() interface (bsc#1012628).
- scsi: pm8001: Fix pm8001_mpi_task_abort_resp() (bsc#1012628).
- scsi: pm8001: Fix tag values handling (bsc#1012628).
- scsi: pm8001: Fix task leak in pm8001_send_abort_all()
  (bsc#1012628).
- scsi: pm8001: Fix tag leaks on error (bsc#1012628).
- scsi: pm8001: Fix memory leak in
  pm8001_chip_fw_flash_update_req() (bsc#1012628).
- mt76: mt7915: fix injected MPDU transmission to not use HW
  A-MSDU (bsc#1012628).
- mctp: make __mctp_dev_get() take a refcount hold (bsc#1012628).
- powerpc/64s/hash: Make hash faults work in NMI context
  (bsc#1012628).
- mt76: mt7615: Fix assigning negative values to unsigned variable
  (bsc#1012628).
- power: supply: axp288_charger: Use
  acpi_quirk_skip_acpi_ac_and_battery() (bsc#1012628).
- power: supply: axp288_fuel_gauge: Use
  acpi_quirk_skip_acpi_ac_and_battery() (bsc#1012628).
- scsi: aha152x: Fix aha152x_setup() __setup handler return value
  (bsc#1012628).
- scsi: hisi_sas: Free irq vectors in order for v3 HW
  (bsc#1012628).
- scsi: hisi_sas: Limit users changing debugfs BIST count value
  (bsc#1012628).
- net/smc: correct settings of RMB window update limit
  (bsc#1012628).
- mips: ralink: fix a refcount leak in ill_acc_of_setup()
  (bsc#1012628).
- iavf: stop leaking iavf_status as "errno" values (bsc#1012628).
- macvtap: advertise link netns via netlink (bsc#1012628).
- platform/x86: thinkpad_acpi: Add dual fan probe (bsc#1012628).
- tuntap: add sanity checks about msg_controllen in sendmsg
  (bsc#1012628).
- Bluetooth: mediatek: fix the conflict between mtk and msft
  vendor event (bsc#1012628).
- Bluetooth: Fix not checking for valid hdev on
  bt_dev_{info,warn,err,dbg} (bsc#1012628).
- Bluetooth: use memset avoid memory leaks (bsc#1012628).
- bnxt_en: Eliminate unintended link toggle during FW reset
  (bsc#1012628).
- PCI: endpoint: Fix misused goto label (bsc#1012628).
- MIPS: fix fortify panic when copying asm exception handlers
  (bsc#1012628).
- powerpc/code-patching: Pre-map patch area (bsc#1012628).
- powerpc/64e: Tie PPC_BOOK3E_64 to PPC_FSL_BOOK3E (bsc#1012628).
- powerpc/secvar: fix refcount leak in format_show()
  (bsc#1012628).
- scsi: libfc: Fix use after free in fc_exch_abts_resp()
  (bsc#1012628).
- platform/x86: x86-android-tablets: Depend on EFI and SPI
  (bsc#1012628).
- can: isotp: set default value for N_As to 50 micro seconds
  (bsc#1012628).
- can: etas_es58x: es58x_fd_rx_event_msg(): initialize
  rx_event_msg before calling es58x_check_msg_len() (bsc#1012628).
- riscv: Fixed misaligned memory access. Fixed pointer comparison
  (bsc#1012628).
- net: account alternate interface name memory (bsc#1012628).
- net: limit altnames to 64k total (bsc#1012628).
- net/mlx5e: Remove overzealous validations in netlink EEPROM
  query (bsc#1012628).
- platform/x86: hp-wmi: Fix SW_TABLET_MODE detection method
  (bsc#1012628).
- platform/x86: hp-wmi: Fix 0x05 error code reported by several
  WMI calls (bsc#1012628).
- net: sfp: add 2500base-X quirk for Lantech SFP module
  (bsc#1012628).
- usb: dwc3: omap: fix "unbalanced disables for smps10_out1"
  on omap5evm (bsc#1012628).
- xen/usb: harden xen_hcd against malicious backends
  (bsc#1012628).
- mt76: fix monitor mode crash with sdio driver (bsc#1012628).
- xtensa: fix DTC warning unit_address_format (bsc#1012628).
- iwlwifi: mei: fix building iwlmei (bsc#1012628).
- MIPS: ingenic: correct unit node address (bsc#1012628).
- Bluetooth: Fix use after free in hci_send_acl (bsc#1012628).
- netfilter: conntrack: revisit gc autotuning (bsc#1012628).
- netlabel: fix out-of-bounds memory accesses (bsc#1012628).
- ceph: fix inode reference leakage in ceph_get_snapdir()
  (bsc#1012628).
- ceph: fix memory leak in ceph_readdir when note_last_dentry
  returns error (bsc#1012628).
- lib/Kconfig.debug: add ARCH dependency for FUNCTION_ALIGN option
  (bsc#1012628).
- init/main.c: return 1 from handled __setup() functions
  (bsc#1012628).
- minix: fix bug when opening a file with O_DIRECT (bsc#1012628).
- clk: si5341: fix reported clk_rate when output divider is 2
  (bsc#1012628).
- clk: mediatek: Fix memory leaks on probe (bsc#1012628).
- staging: vchiq_arm: Avoid NULL ptr deref in
  vchiq_dump_platform_instances (bsc#1012628).
- staging: vchiq_core: handle NULL result of
  find_service_by_handle (bsc#1012628).
- phy: amlogic: phy-meson-gxl-usb2: fix shared reset controller
  use (bsc#1012628).
- phy: amlogic: meson8b-usb2: Use dev_err_probe() (bsc#1012628).
- phy: amlogic: meson8b-usb2: fix shared reset control use
  (bsc#1012628).
- clk: rockchip: drop CLK_SET_RATE_PARENT from dclk_vop* on rk3568
  (bsc#1012628).
- cpufreq: CPPC: Fix performance/frequency conversion
  (bsc#1012628).
- opp: Expose of-node's name in debugfs (bsc#1012628).
- staging: wfx: apply the necessary SDIO quirks for the Silabs
  WF200 (bsc#1012628).
- staging: wfx: fix an error handling in wfx_init_common()
  (bsc#1012628).
- w1: w1_therm: fixes w1_seq for ds28ea00 sensors (bsc#1012628).
- NFSv4.2: fix reference count leaks in _nfs42_proc_copy_notify()
  (bsc#1012628).
- NFSv4: Protect the state recovery thread against direct reclaim
  (bsc#1012628).
- habanalabs: fix possible memory leak in MMU DR fini
  (bsc#1012628).
- habanalabs: reject host map with mmu disabled (bsc#1012628).
- habanalabs/gaudi: handle axi errors from NIC engines
  (bsc#1012628).
- xen: delay xen_hvm_init_time_ops() if kdump is boot on vcpu>=32
  (bsc#1012628).
- clk: ti: Preserve node in ti_dt_clocks_register() (bsc#1012628).
- clk: Enforce that disjoints limits are invalid (bsc#1012628).
- SUNRPC/xprt: async tasks mustn't block waiting for memory
  (bsc#1012628).
- SUNRPC: remove scheduling boost for "SWAPPER" tasks
  (bsc#1012628).
- NFS: swap IO handling is slightly different for O_DIRECT IO
  (bsc#1012628).
- NFS: swap-out must always use STABLE writes (bsc#1012628).
- x86: Annotate call_on_stack() (bsc#1012628).
- x86/Kconfig: Do not allow CONFIG_X86_X32_ABI=y with llvm-objcopy
  (bsc#1012628).
- serial: samsung_tty: do not unlock port->lock for
  uart_write_wakeup() (bsc#1012628).
- virtio_console: eliminate anonymous module_init & module_exit
  (bsc#1012628).
- jfs: prevent NULL deref in diFree (bsc#1012628).
- SUNRPC: Fix socket waits for write buffer space (bsc#1012628).
- NFS: nfsiod should not block forever in mempool_alloc()
  (bsc#1012628).
- NFS: Avoid writeback threads getting stuck in mempool_alloc()
  (bsc#1012628).
- selftests: net: Add tls config dependency for tls selftests
  (bsc#1012628).
- parisc: Fix CPU affinity for Lasi, WAX and Dino chips
  (bsc#1012628).
- parisc: Fix patch code locking and flushing (bsc#1012628).
- mm: fix race between MADV_FREE reclaim and blkdev direct IO read
  (bsc#1012628).
- drm/amdgpu: fix off by one in amdgpu_gfx_kiq_acquire()
  (bsc#1012628).
- Drivers: hv: vmbus: Fix initialization of device object in
  vmbus_device_register() (bsc#1012628).
- Drivers: hv: vmbus: Fix potential crash on module unload
  (bsc#1012628).
- netfilter: bitwise: fix reduce comparisons (bsc#1012628).
- Revert "NFSv4: Handle the special Linux file open access mode"
  (bsc#1012628).
- NFSv4: fix open failure with O_ACCMODE flag (bsc#1012628).
- scsi: core: scsi_logging: Fix a BUG (bsc#1012628).
- scsi: sr: Fix typo in CDROM(CLOSETRAY|EJECT) handling
  (bsc#1012628).
- scsi: core: Fix sbitmap depth in scsi_realloc_sdev_budget_map()
  (bsc#1012628).
- scsi: zorro7xx: Fix a resource leak in zorro7xx_remove_one()
  (bsc#1012628).
- vdpa: mlx5: prevent cvq work from hogging CPU (bsc#1012628).
- net: sfc: add missing xdp queue reinitialization (bsc#1012628).
- net/tls: fix slab-out-of-bounds bug in decrypt_internal
  (bsc#1012628).
- vrf: fix packet sniffing for traffic originating from ip tunnels
  (bsc#1012628).
- skbuff: fix coalescing for page_pool fragment recycling
  (bsc#1012628).
- Revert "net: dsa: stop updating master MTU from master.c"
  (bsc#1012628).
- ice: Clear default forwarding VSI during VSI release
  (bsc#1012628).
- ice: Fix MAC address setting (bsc#1012628).
- mctp: Fix check for dev_hard_header() result (bsc#1012628).
- mctp: Use output netdev to allocate skb headroom (bsc#1012628).
- net: ipv4: fix route with nexthop object delete warning
  (bsc#1012628).
- net: stmmac: Fix unset max_speed difference between DT and
  non-DT platforms (bsc#1012628).
- drm/imx: imx-ldb: Check for null pointer after calling kmemdup
  (bsc#1012628).
- drm/imx: Fix memory leak in imx_pd_connector_get_modes
  (bsc#1012628).
- drm/imx: dw_hdmi-imx: Fix bailout in error cases of probe
  (bsc#1012628).
- regulator: rtq2134: Fix missing active_discharge_on setting
  (bsc#1012628).
- spi: rpc-if: Fix RPM imbalance in probe error path
  (bsc#1012628).
- regulator: atc260x: Fix missing active_discharge_on setting
  (bsc#1012628).
- arch/arm64: Fix topology initialization for core scheduling
  (bsc#1012628).
- bnxt_en: Synchronize tx when xdp redirects happen on same ring
  (bsc#1012628).
- bnxt_en: reserve space inside receive page for skb_shared_info
  (bsc#1012628).
- bnxt_en: Prevent XDP redirect from running when stopping TX
  queue (bsc#1012628).
- sfc: Do not free an empty page_ring (bsc#1012628).
- RDMA/mlx5: Don't remove cache MRs when a delay is needed
  (bsc#1012628).
- RDMA/mlx5: Add a missing update of cache->last_add
  (bsc#1012628).
- IB/cm: Cancel mad on the DREQ event when the state is
  MRA_REP_RCVD (bsc#1012628).
- cifs: fix potential race with cifsd thread (bsc#1012628).
- IB/rdmavt: add lock to call to rvt_error_qp to prevent a race
  condition (bsc#1012628).
- sctp: count singleton chunks in assoc user stats (bsc#1012628).
- dpaa2-ptp: Fix refcount leak in dpaa2_ptp_probe (bsc#1012628).
- ice: Set txq_teid to ICE_INVAL_TEID on ring creation
  (bsc#1012628).
- ice: Do not skip not enabled queues in ice_vc_dis_qs_msg
  (bsc#1012628).
- ipv6: Fix stats accounting in ip6_pkt_drop (bsc#1012628).
- ice: synchronize_rcu() when terminating rings (bsc#1012628).
- ice: xsk: fix VSI state check in ice_xsk_wakeup() (bsc#1012628).
- ice: clear cmd_type_offset_bsz for TX rings (bsc#1012628).
- net: openvswitch: don't send internal clone attribute to the
  userspace (bsc#1012628).
- net: ethernet: mv643xx: Fix over zealous checking
  of_get_mac_address() (bsc#1012628).
- net: openvswitch: fix leak of nested actions (bsc#1012628).
- rxrpc: fix a race in rxrpc_exit_net() (bsc#1012628).
- net: sfc: fix using uninitialized xdp tx_queue (bsc#1012628).
- net: phy: mscc-miim: reject clause 45 register accesses
  (bsc#1012628).
- qede: confirm skb is allocated before using (bsc#1012628).
- spi: bcm-qspi: fix MSPI only access with bcm_qspi_exec_mem_op()
  (bsc#1012628).
- drm/amd/display: Fix for dmub outbox notification enable
  (bsc#1012628).
- drm/amd/display: Remove redundant dsc power gating from init_hw
  (bsc#1012628).
- bpf: Support dual-stack sockets in bpf_tcp_check_syncookie
  (bsc#1012628).
- drbd: Fix five use after free bugs in get_initial_state
  (bsc#1012628).
- scsi: sd: sd_read_cpr() requires VPD pages (bsc#1012628).
- scsi: ufs: ufshpb: Fix a NULL check on list iterator
  (bsc#1012628).
- io_uring: nospec index for tags on files update (bsc#1012628).
- io_uring: don't touch scm_fp_list after queueing skb
  (bsc#1012628).
- SUNRPC: Handle ENOMEM in call_transmit_status() (bsc#1012628).
- SUNRPC: Handle low memory situations in call_status()
  (bsc#1012628).
- SUNRPC: svc_tcp_sendmsg() should handle errors from
  xdr_alloc_bvec() (bsc#1012628).
- iommu/omap: Fix regression in probe for NULL pointer dereference
  (bsc#1012628).
- perf unwind: Don't show unwind error messages when augmenting
  frame pointer stack (bsc#1012628).
- perf: arm-spe: Fix perf report --mem-mode (bsc#1012628).
- perf tools: Fix perf's libperf_print callback (bsc#1012628).
- perf session: Remap buf if there is no space for event
  (bsc#1012628).
- arm64: Add part number for Arm Cortex-A78AE (bsc#1012628).
- scsi: mpt3sas: Fix use after free in
  _scsih_expander_node_remove() (bsc#1012628).
- scsi: ufs: ufs-pci: Add support for Intel MTL (bsc#1012628).
- Revert "mmc: sdhci-xenon: fix annoying 1.8V regulator warning"
  (bsc#1012628).
- mmc: block: Check for errors after write on SPI (bsc#1012628).
- mmc: mmci: stm32: correctly check all elements of sg list
  (bsc#1012628).
- mmc: renesas_sdhi: special 4tap settings only apply to HS400
  (bsc#1012628).
- mmc: renesas_sdhi: don't overwrite TAP settings when HS400
  tuning is complete (bsc#1012628).
- mmc: core: Fixup support for writeback-cache for eMMC and SD
  (bsc#1012628).
- lz4: fix LZ4_decompress_safe_partial read out of bound
  (bsc#1012628).
- highmem: fix checks in __kmap_local_sched_{in,out}
  (bsc#1012628).
- mmmremap.c: avoid pointless invalidate_range_start/end on
  mremap(old_size=0) (bsc#1012628).
- mm/mempolicy: fix mpol_new leak in shared_policy_replace
  (bsc#1012628).
- io_uring: don't check req->file in io_fsync_prep()
  (bsc#1012628).
- io_uring: defer splice/tee file validity check until command
  issue (bsc#1012628).
- io_uring: implement compat handling for IORING_REGISTER_IOWQ_AFF
  (bsc#1012628).
- io_uring: fix race between timeout flush and removal
  (bsc#1012628).
- perf/x86/intel: Update the FRONTEND MSR mask on Sapphire Rapids
  (bsc#1012628).
- btrfs: fix qgroup reserve overflow the qgroup limit
  (bsc#1012628).
- btrfs: zoned: traverse devices under chunk_mutex in
  btrfs_can_activate_zone (bsc#1012628).
- btrfs: remove device item and update super block in the same
  transaction (bsc#1012628).
- btrfs: avoid defragging extents whose next extents are not
  targets (bsc#1012628).
- btrfs: prevent subvol with swapfile from being deleted
  (bsc#1012628).
- spi: core: add dma_map_dev for __spi_unmap_msg() (bsc#1012628).
- cifs: force new session setup and tcon for dfs (bsc#1012628).
- qed: fix ethtool register dump (bsc#1012628).
- arm64: patch_text: Fixup last cpu should be master
  (bsc#1012628).
- RDMA/hfi1: Fix use-after-free bug for mm struct (bsc#1012628).
- drbd: fix an invalid memory access caused by incorrect use of
  list iterator (bsc#1012628).
- gpio: Restrict usage of GPIO chip irq members before
  initialization (bsc#1012628).
- x86/msi: Fix msi message data shadow struct (bsc#1012628).
- x86/mm/tlb: Revert retpoline avoidance approach (bsc#1012628).
- perf/x86/intel: Don't extend the pseudo-encoding to GP counters
  (bsc#1012628).
- ata: sata_dwc_460ex: Fix crash due to OOB write (bsc#1012628).
- perf: qcom_l2_pmu: fix an incorrect NULL check on list iterator
  (bsc#1012628).
- perf/core: Inherit event_caps (bsc#1012628).
- irqchip/gic-v3: Fix GICR_CTLR.RWP polling (bsc#1012628).
- fbdev: Fix unregistering of framebuffers without device
  (bsc#1012628).
- amd/display: set backlight only if required (bsc#1012628).
- drm/panel: ili9341: fix optional regulator handling
  (bsc#1012628).
- drm/amd/display: Fix by adding FPU protection for
  dcn30_internal_validate_bw (bsc#1012628).
- drm/amdgpu/display: change pipe policy for DCN 2.1
  (bsc#1012628).
- drm/amdgpu/smu10: fix SoC/fclk units in auto mode (bsc#1012628).
- drm/amdgpu/vcn: Fix the register setting for vcn1 (bsc#1012628).
- drm/amdkfd: Create file descriptor after client is added to
  smi_clients list (bsc#1012628).
- drm/amdgpu: don't use BACO for reset in S3 (bsc#1012628).
- SUNRPC: Ensure we flush any closed sockets before xs_xprt_free()
  (bsc#1012628).
- Revert "ACPI: processor: idle: Only flush cache on entering C3"
  (bsc#1012628).
- drm/amdkfd: Fix variable set but not used warning (bsc#1012628).
- net/smc: send directly on setting TCP_NODELAY (bsc#1012628).
- Revert "selftests: net: Add tls config dependency for tls
  selftests" (bsc#1012628).
- bpf: Make remote_port field in struct bpf_sk_lookup 16-bit wide
  (bsc#1012628).
- selftests/bpf: Fix u8 narrow load checks for bpf_sk_lookup
  remote_port (bsc#1012628).
- bpf: Treat bpf_sk_lookup remote_port as a 2-byte field
  (bsc#1012628).
- perf build: Don't use -ffat-lto-objects in the python feature
  test when building with clang-13 (bsc#1012628).
- perf python: Fix probing for some clang command line options
  (bsc#1012628).
- tools build: Filter out options and warnings not supported by
  clang (bsc#1012628).
- tools build: Use $(shell ) instead of `` to get embedded
  libperl's ccopts (bsc#1012628).
- dmaengine: Revert "dmaengine: shdma: Fix runtime PM imbalance
  on error" (bsc#1012628).
- KVM: avoid NULL pointer dereference in kvm_dirty_ring_push
  (bsc#1012628).
- Drivers: hv: vmbus: Replace smp_store_mb() with virt_store_mb()
  (bsc#1012628).
- powerpc: Fix virt_addr_valid() for 64-bit Book3E & 32-bit
  (bsc#1012628).
- Revert "powerpc: Set max_mapnr correctly" (bsc#1012628).
- x86/bug: Prevent shadowing in __WARN_FLAGS (bsc#1012628).
- objtool: Fix SLS validation for kcov tail-call replacement
  (bsc#1012628).
- sched/core: Fix forceidle balancing (bsc#1012628).
- sched: Teach the forced-newidle balancer about CPU affinity
  limitation (bsc#1012628).
- x86,static_call: Fix __static_call_return0 for i386
  (bsc#1012628).
- x86/extable: Prefer local labels in .set directives
  (bsc#1012628).
- irqchip/gic-v4: Wait for GICR_VPENDBASER.Dirty to clear before
  descheduling (bsc#1012628).
- powerpc/64: Fix build failure with allyesconfig in
  book3s_64_entry.S (bsc#1012628).
- irqchip/gic, gic-v3: Prevent GSI to SGI translations
  (bsc#1012628).
- mm/sparsemem: fix 'mem_section' will never be NULL gcc 12
  warning (bsc#1012628).
- static_call: Don't make __static_call_return0 static
  (bsc#1012628).
- io_uring: move read/write file prep state into actual opcode
  handler (bsc#1012628).
- io_uring: propagate issue_flags state down to file assignment
  (bsc#1012628).
- io_uring: defer file assignment (bsc#1012628).
- io_uring: drop the old style inflight file tracking
  (bsc#1012628).
- Update config files.
- commit a63605c
* Wed Apr 13 2022 mbrugger@suse.com
- arm64: Update config files to v5.18-rc2
- commit 2158d93
* Wed Apr 13 2022 tiwai@suse.de
- Update config files: set CONFIG_EFI_VARS_PSTORE_DEFAULT_DISABLE=y (bsc#1198276)
  Using efivars as the pstore default backend is dangerous, as it might fill up
  quickly with dumps, eventually resulting in a non-bootable system.
  The feature can be enabled manually via efi_pstore.pstore_disable=0 option.
- commit 7821031
* Wed Apr 13 2022 tiwai@suse.de
- ALSA: memalloc: Add fallback SG-buffer allocations for x86
  (bsc#1198248).
- commit c87e719
* Tue Apr 12 2022 bp@suse.de
- Update
  patches.suse/x86-pm-save-the-msr-validity-status-at-context-setup.patch
  (bsc#1198400).
- Update
  patches.suse/x86-speculation-restore-speculation-related-msrs-during-s3-resume.patch
  (bsc#1198400).
- commit b1cc750
* Mon Apr 11 2022 tiwai@suse.de
- drm/nouveau/pmu: Add missing callbacks for Tegra devices
  (bsc#1196967).
- commit 0789f15
* Mon Apr 11 2022 mkubecek@suse.cz
- Update to 5.18-rc2
- eliminate 1 patch
  - patches.suse/net-fungible-Fix-reference-to-__udivdi3-on-32b-build.patch
- update configs
  - SATA_LPM_POLICY renamed to SATA_MOBILE_LPM_POLICY
- commit d8f6a40
* Sat Apr  9 2022 jslaby@suse.cz
- Linux 5.17.2 (bsc#1012628).
- USB: serial: pl2303: add IBM device IDs (bsc#1012628).
- dt-bindings: usb: hcd: correct usb-device path (bsc#1012628).
- USB: serial: pl2303: fix GS type detection (bsc#1012628).
- USB: serial: simple: add Nokia phone driver (bsc#1012628).
- mm: kfence: fix missing objcg housekeeping for SLAB
  (bsc#1012628).
- locking/lockdep: Avoid potential access of invalid memory in
  lock_class (bsc#1012628).
- drm/amdgpu: move PX checking into amdgpu_device_ip_early_init
  (bsc#1012628).
- drm/amdgpu: only check for _PR3 on dGPUs (bsc#1012628).
- iommu/iova: Improve 32-bit free space estimate (bsc#1012628).
- block: flush plug based on hardware and software queue order
  (bsc#1012628).
- block: ensure plug merging checks the correct queue at least
  once (bsc#1012628).
- usb: typec: tipd: Forward plug orientation to typec subsystem
  (bsc#1012628).
- USB: usb-storage: Fix use of bitfields for hardware data in
  ene_ub6250.c (bsc#1012628).
- xhci: fix garbage USBSTS being logged in some cases
  (bsc#1012628).
- xhci: fix runtime PM imbalance in USB2 resume (bsc#1012628).
- xhci: make xhci_handshake timeout for xhci_reset() adjustable
  (bsc#1012628).
- xhci: fix uninitialized string returned by
  xhci_decode_ctrl_ctx() (bsc#1012628).
- mei: me: disable driver on the ign firmware (bsc#1012628).
- mei: me: add Alder Lake N device id (bsc#1012628).
- mei: avoid iterator usage outside of list_for_each_entry
  (bsc#1012628).
- bus: mhi: pci_generic: Add mru_default for Quectel EM1xx series
  (bsc#1012628).
- bus: mhi: Fix pm_state conversion to string (bsc#1012628).
- bus: mhi: Fix MHI DMA structure endianness (bsc#1012628).
- docs: sphinx/requirements: Limit jinja2<3.1 (bsc#1012628).
- coresight: Fix TRCCONFIGR.QE sysfs interface (bsc#1012628).
- coresight: syscfg: Fix memleak on registration failure in
  cscfg_create_device (bsc#1012628).
- dt-bindings: iio: adc: zynqmp_ams: Add clock entry
  (bsc#1012628).
- iio: adc: xilinx-ams: Fix single channel switching sequence
  (bsc#1012628).
- iio: accel: mma8452: use the correct logic to get mma8452_data
  (bsc#1012628).
- iio: adc: aspeed: Add divider flag to fix incorrect voltage
  reading (bsc#1012628).
- iio: imu: st_lsm6dsx: use dev_to_iio_dev() to get iio_dev struct
  (bsc#1012628).
- iio: afe: rescale: use s64 for temporary scale calculations
  (bsc#1012628).
- iio: adc: xilinx-ams: Fixed missing PS channels (bsc#1012628).
- iio: adc: xilinx-ams: Fixed wrong sequencer register settings
  (bsc#1012628).
- iio: inkern: apply consumer scale on IIO_VAL_INT cases
  (bsc#1012628).
- iio: inkern: apply consumer scale when no channel scale is
  available (bsc#1012628).
- iio: inkern: make a best effort on offset calculation
  (bsc#1012628).
- greybus: svc: fix an error handling bug in gb_svc_hello()
  (bsc#1012628).
- clk: rockchip: re-add rational best approximation algorithm
  to the fractional divider (bsc#1012628).
- clk: uniphier: Fix fixed-rate initialization (bsc#1012628).
- ptrace: Check PTRACE_O_SUSPEND_SECCOMP permission on
  PTRACE_SEIZE (bsc#1012628).
- cifs: truncate the inode and mapping when we simulate fcollapse
  (bsc#1012628).
- cifs: fix handlecache and multiuser (bsc#1012628).
- cifs: we do not need a spinlock around the tree access during
  umount (bsc#1012628).
- KEYS: fix length validation in keyctl_pkey_params_get_2()
  (bsc#1012628).
- KEYS: asymmetric: enforce that sig algo matches key algo
  (bsc#1012628).
- KEYS: asymmetric: properly validate hash_algo and encoding
  (bsc#1012628).
- Documentation: add link to stable release candidate tree
  (bsc#1012628).
- Documentation: update stable tree link (bsc#1012628).
- firmware: stratix10-svc: add missing callback parameter on RSU
  (bsc#1012628).
- firmware: sysfb: fix platform-device leak in error path
  (bsc#1012628).
- HID: intel-ish-hid: Use dma_alloc_coherent for firmware update
  (bsc#1012628).
- SUNRPC: avoid race between mod_timer() and del_timer_sync()
  (bsc#1012628).
- SUNRPC: Do not dereference non-socket transports in sysfs
  (bsc#1012628).
- NFS: NFSv2/v3 clients should never be setting NFS_CAP_XATTR
  (bsc#1012628).
- NFSD: prevent underflow in nfssvc_decode_writeargs()
  (bsc#1012628).
- NFSD: prevent integer overflow on 32 bit systems (bsc#1012628).
- f2fs: fix to unlock page correctly in error path of is_alive()
  (bsc#1012628).
- f2fs: quota: fix loop condition at f2fs_quota_sync()
  (bsc#1012628).
- f2fs: fix to do sanity check on .cp_pack_total_block_count
  (bsc#1012628).
- remoteproc: Fix count check in rproc_coredump_write()
  (bsc#1012628).
- mm/mlock: fix two bugs in user_shm_lock() (bsc#1012628).
- pinctrl: ingenic: Fix regmap on X series SoCs (bsc#1012628).
- pinctrl: samsung: drop pin banks references on error paths
  (bsc#1012628).
- net: bnxt_ptp: fix compilation error (bsc#1012628).
- spi: mxic: Fix the transmit path (bsc#1012628).
- mtd: spi-nor: Skip erase logic when SPI_NOR_NO_ERASE is set
  (bsc#1012628).
- mtd: rawnand: protect access to rawnand devices while in suspend
  (bsc#1012628).
- can: m_can: m_can_tx_handler(): fix use after free of skb
  (bsc#1012628).
- jffs2: fix use-after-free in jffs2_clear_xattr_subsystem
  (bsc#1012628).
- jffs2: fix memory leak in jffs2_do_mount_fs (bsc#1012628).
- jffs2: fix memory leak in jffs2_scan_medium (bsc#1012628).
- mm: fs: fix lru_cache_disabled race in bh_lru (bsc#1012628).
- mm: don't skip swap entry even if zap_details specified
  (bsc#1012628).
- mm/pages_alloc.c: don't create ZONE_MOVABLE beyond the end of
  a node (bsc#1012628).
- mm: invalidate hwpoison page cache page in fault path
  (bsc#1012628).
- mempolicy: mbind_range() set_policy() after vma_merge()
  (bsc#1012628).
- scsi: core: sd: Add silence_suspend flag to suppress some PM
  messages (bsc#1012628).
- scsi: ufs: Fix runtime PM messages never-ending cycle
  (bsc#1012628).
- scsi: scsi_transport_fc: Fix FPIN Link Integrity statistics
  counters (bsc#1012628).
- scsi: libsas: Fix sas_ata_qc_issue() handling of NCQ NON DATA
  commands (bsc#1012628).
- qed: display VF trust config (bsc#1012628).
- qed: validate and restrict untrusted VFs vlan promisc mode
  (bsc#1012628).
- riscv: dts: canaan: Fix SPI3 bus width (bsc#1012628).
- riscv: Fix fill_callchain return value (bsc#1012628).
- riscv: Increase stack size under KASAN (bsc#1012628).
- RISC-V: Declare per cpu boot data as static (bsc#1012628).
- cifs: do not skip link targets when an I/O fails (bsc#1012628).
- cifs: fix incorrect use of list iterator after the loop
  (bsc#1012628).
- cifs: prevent bad output lengths in smb2_ioctl_query_info()
  (bsc#1012628).
- cifs: fix NULL ptr dereference in smb2_ioctl_query_info()
  (bsc#1012628).
- ALSA: cs4236: fix an incorrect NULL check on list iterator
  (bsc#1012628).
- ALSA: hda: Avoid unsol event during RPM suspending
  (bsc#1012628).
- ALSA: pcm: Fix potential AB/BA lock with buffer_mutex and
  mmap_lock (bsc#1012628).
- ALSA: hda/realtek: Fix audio regression on Mi Notebook Pro 2020
  (bsc#1012628).
- rtc: mc146818-lib: fix locking in mc146818_set_time
  (bsc#1012628).
- rtc: pl031: fix rtc features null pointer dereference
  (bsc#1012628).
- io_uring: ensure that fsnotify is always called (bsc#1012628).
- ocfs2: fix crash when mount with quota enabled (bsc#1012628).
- drm/simpledrm: Add "panel orientation" property on non-upright
  mounted LCD panels (bsc#1012628).
- mm: madvise: skip unmapped vma holes passed to process_madvise
  (bsc#1012628).
- mm: madvise: return correct bytes advised with process_madvise
  (bsc#1012628).
- Revert "mm: madvise: skip unmapped vma holes passed to
  process_madvise" (bsc#1012628).
- mm,hwpoison: unmap poisoned page before invalidation
  (bsc#1012628).
- mm: only re-generate demotion targets when a numa node changes
  its N_CPU state (bsc#1012628).
- mm/kmemleak: reset tag when compare object pointer
  (bsc#1012628).
- dm stats: fix too short end duration_ns when using
  precise_timestamps (bsc#1012628).
- dm: fix use-after-free in dm_cleanup_zoned_dev() (bsc#1012628).
- dm: interlock pending dm_io and dm_wait_for_bios_completion
  (bsc#1012628).
- dm: fix double accounting of flush with data (bsc#1012628).
- dm integrity: set journal entry unused when shrinking device
  (bsc#1012628).
- tracing: Have trace event string test handle zero length strings
  (bsc#1012628).
- drbd: fix potential silent data corruption (bsc#1012628).
- can: isotp: sanitize CAN ID checks in isotp_bind()
  (bsc#1012628).
- PCI: fu740: Force 2.5GT/s for initial device probe
  (bsc#1012628).
- arm64: signal: nofpsimd: Do not allocate fp/simd context when
  not available (bsc#1012628).
- arm64: Do not defer reserve_crashkernel() for platforms with
  no DMA memory zones (bsc#1012628).
- arm64: dts: qcom: sm8250: Fix MSI IRQ for PCIe1 and PCIe2
  (bsc#1012628).
- arm64: dts: ti: k3-am65: Fix gic-v3 compatible regs
  (bsc#1012628).
- arm64: dts: ti: k3-j721e: Fix gic-v3 compatible regs
  (bsc#1012628).
- arm64: dts: ti: k3-j7200: Fix gic-v3 compatible regs
  (bsc#1012628).
- arm64: dts: ti: k3-am64: Fix gic-v3 compatible regs
  (bsc#1012628).
- arm64: dts: ti: k3-j721s2: Fix gic-v3 compatible regs
  (bsc#1012628).
- ASoC: SOF: Intel: Fix NULL ptr dereference when ENOMEM
  (bsc#1012628).
- mmc: core: use sysfs_emit() instead of sprintf() (bsc#1012628).
- Revert "ACPI: Pass the same capabilities to the _OSC regardless
  of the query flag" (bsc#1012628).
- ACPI: properties: Consistently return -ENOENT if there are no
  more references (bsc#1012628).
- coredump: Also dump first pages of non-executable ELF libraries
  (bsc#1012628).
- ext4: fix ext4_fc_stats trace point (bsc#1012628).
- ext4: fix fs corruption when tring to remove a non-empty
  directory with IO error (bsc#1012628).
- ext4: make mb_optimize_scan option work with set/unset mount
  cmd (bsc#1012628).
- ext4: make mb_optimize_scan performance mount option work with
  extents (bsc#1012628).
- samples/landlock: Fix path_list memory leak (bsc#1012628).
- landlock: Use square brackets around "landlock-ruleset"
  (bsc#1012628).
- mailbox: tegra-hsp: Flush whole channel (bsc#1012628).
- btrfs: zoned: put block group after final usage (bsc#1012628).
- block: fix rq-qos breakage from skipping rq_qos_done_bio()
  (bsc#1012628).
- block: limit request dispatch loop duration (bsc#1012628).
- block: don't merge across cgroup boundaries if blkcg is enabled
  (bsc#1012628).
- drm/edid: check basic audio support on CEA extension block
  (bsc#1012628).
- fbdev: Hot-unplug firmware fb devices on forced removal
  (bsc#1012628).
- video: fbdev: sm712fb: Fix crash in smtcfb_read() (bsc#1012628).
- video: fbdev: atari: Atari 2 bpp (STe) palette bugfix
  (bsc#1012628).
- rfkill: make new event layout opt-in (bsc#1012628).
- ARM: dts: at91: sama7g5: Remove unused properties in i2c nodes
  (bsc#1012628).
- ARM: dts: at91: sama5d2: Fix PMERRLOC resource size
  (bsc#1012628).
- ARM: dts: exynos: fix UART3 pins configuration in Exynos5250
  (bsc#1012628).
- ARM: dts: exynos: add missing HDMI supplies on SMDK5250
  (bsc#1012628).
- ARM: dts: exynos: add missing HDMI supplies on SMDK5420
  (bsc#1012628).
- mgag200 fix memmapsl configuration in GCTL6 register
  (bsc#1012628).
- carl9170: fix missing bit-wise or operator for tx_params
  (bsc#1012628).
- pstore: Don't use semaphores in always-atomic-context code
  (bsc#1012628).
- thermal: int340x: Increase bitmap size (bsc#1012628).
- lib/raid6/test: fix multiple definition linking error
  (bsc#1012628).
- exec: Force single empty string when argv is empty
  (bsc#1012628).
- crypto: rsa-pkcs1pad - only allow with rsa (bsc#1012628).
- crypto: rsa-pkcs1pad - correctly get hash from source
  scatterlist (bsc#1012628).
- crypto: rsa-pkcs1pad - restore signature length check
  (bsc#1012628).
- crypto: rsa-pkcs1pad - fix buffer overread in
  pkcs1pad_verify_complete() (bsc#1012628).
- bcache: fixup multiple threads crash (bsc#1012628).
- PM: domains: Fix sleep-in-atomic bug caused by
  genpd_debug_remove() (bsc#1012628).
- DEC: Limit PMAX memory probing to R3k systems (bsc#1012628).
- media: gpio-ir-tx: fix transmit with long spaces on Orange Pi PC
  (bsc#1012628).
- media: omap3isp: Use struct_group() for memcpy() region
  (bsc#1012628).
- media: venus: vdec: fixed possible memory leak issue
  (bsc#1012628).
- media: venus: hfi_cmds: List HDR10 property as unsupported
  for v1 and v3 (bsc#1012628).
- media: venus: venc: Fix h264 8x8 transform control
  (bsc#1012628).
- media: davinci: vpif: fix unbalanced runtime PM get
  (bsc#1012628).
- media: davinci: vpif: fix unbalanced runtime PM enable
  (bsc#1012628).
- media: davinci: vpif: fix use-after-free on driver unbind
  (bsc#1012628).
- mips: Always permit to build u-boot images (bsc#1012628).
- btrfs: zoned: mark relocation as writing (bsc#1012628).
- btrfs: extend locking to all space_info members accesses
  (bsc#1012628).
- btrfs: verify the tranisd of the to-be-written dirty extent
  buffer (bsc#1012628).
- xtensa: define update_mmu_tlb function (bsc#1012628).
- xtensa: fix stop_machine_cpuslocked call in patch_text
  (bsc#1012628).
- xtensa: fix xtensa_wsr always writing 0 (bsc#1012628).
- KVM: s390x: fix SCK locking (bsc#1012628).
- drm/syncobj: flatten dma_fence_chains on transfer (bsc#1012628).
- drm/nouveau/backlight: Fix LVDS backlight detection on some
  laptops (bsc#1012628).
- drm/nouveau/backlight: Just set all backlight types as RAW
  (bsc#1012628).
- drm/fb-helper: Mark screen buffers in system memory with
  FBINFO_VIRTFB (bsc#1012628).
- brcmfmac: firmware: Allocate space for default boardrev in nvram
  (bsc#1012628).
- brcmfmac: pcie: Release firmwares in the brcmf_pcie_setup
  error path (bsc#1012628).
- brcmfmac: pcie: Declare missing firmware files in pcie.c
  (bsc#1012628).
- brcmfmac: pcie: Replace brcmf_pcie_copy_mem_todev with
  memcpy_toio (bsc#1012628).
- brcmfmac: pcie: Fix crashes due to early IRQs (bsc#1012628).
- drm/i915/opregion: check port number bounds for SWSCI display
  power state (bsc#1012628).
- drm/i915/gem: add missing boundary check in vm_access
  (bsc#1012628).
- PCI: imx6: Allow to probe when dw_pcie_wait_for_link() fails
  (bsc#1012628).
- PCI: pciehp: Clear cmd_busy bit in polling mode (bsc#1012628).
- PCI: xgene: Revert "PCI: xgene: Use inbound resources for setup"
  (bsc#1012628).
- PCI: xgene: Revert "PCI: xgene: Fix IB window setup"
  (bsc#1012628).
- regulator: qcom_smd: fix for_each_child.cocci warnings
  (bsc#1012628).
- selinux: access superblock_security_struct in LSM blob way
  (bsc#1012628).
- selinux: check return value of sel_make_avc_files (bsc#1012628).
- crypto: ccp - Ensure psp_ret is always init'd in
  __sev_platform_init_locked() (bsc#1012628).
- crypto: qat - fix a signedness bug in get_service_enabled()
  (bsc#1012628).
- hwrng: cavium - HW_RANDOM_CAVIUM should depend on ARCH_THUNDER
  (bsc#1012628).
- crypto: sun8i-ss - really disable hash on A80 (bsc#1012628).
- crypto: kdf - Select hmac in addition to sha256 (bsc#1012628).
- crypto: qat - fix access to PFVF interrupt registers for GEN4
  (bsc#1012628).
- crypto: authenc - Fix sleep in atomic context in decrypt_tail
  (bsc#1012628).
- crypto: octeontx2 - select CONFIG_NET_DEVLINK (bsc#1012628).
- crypto: mxs-dcp - Fix scatterlist processing (bsc#1012628).
- selinux: Fix selinux_sb_mnt_opts_compat() (bsc#1012628).
- thermal: int340x: Check for NULL after calling kmemdup()
  (bsc#1012628).
- crypto: octeontx2 - remove CONFIG_DM_CRYPT check (bsc#1012628).
- spi: tegra114: Add missing IRQ check in tegra_spi_probe
  (bsc#1012628).
- spi: tegra210-quad: Fix missin IRQ check in tegra_qspi_probe
  (bsc#1012628).
- perf: MARVELL_CN10K_TAD_PMU should depend on ARCH_THUNDER
  (bsc#1012628).
- selftests/sgx: Fix NULL-pointer-dereference upon early test
  failure (bsc#1012628).
- selftests/sgx: Do not attempt enclave build without valid
  enclave (bsc#1012628).
- selftests/sgx: Ensure enclave data available during debug print
  (bsc#1012628).
- stack: Constrain and fix stack offset randomization with Clang
  builds (bsc#1012628).
- arm64/mm: avoid fixmap race condition when create pud mapping
  (bsc#1012628).
- security: add sctp_assoc_established hook (bsc#1012628).
- security: implement sctp_assoc_established hook in selinux
  (bsc#1012628).
- blk-cgroup: set blkg iostat after percpu stat aggregation
  (bsc#1012628).
- selftests/x86: Add validity check and allow field splitting
  (bsc#1012628).
- selftests/sgx: Treat CC as one argument (bsc#1012628).
- crypto: rockchip - ECB does not need IV (bsc#1012628).
- block: update io_ticks when io hang (bsc#1012628).
- audit: log AUDIT_TIME_* records only from rules (bsc#1012628).
- EVM: fix the evm= __setup handler return value (bsc#1012628).
- crypto: ccree - don't attempt 0 len DMA mappings (bsc#1012628).
- crypto: hisilicon/sec - fix the aead software fallback for
  engine (bsc#1012628).
- spi: pxa2xx-pci: Balance reference count for PCI DMA device
  (bsc#1012628).
- hwmon: (pmbus) Add mutex to regulator ops (bsc#1012628).
- hwmon: (sch56xx-common) Replace WDOG_ACTIVE with WDOG_HW_RUNNING
  (bsc#1012628).
- nvme: cleanup __nvme_check_ids (bsc#1012628).
- nvme: fix the check for duplicate unique identifiers
  (bsc#1012628).
- block: don't delete queue kobject before its children
  (bsc#1012628).
- PM: hibernate: fix __setup handler error handling (bsc#1012628).
- PM: suspend: fix return value of __setup handler (bsc#1012628).
- spi: spi-zynqmp-gqspi: Handle error for dma_set_mask
  (bsc#1012628).
- hwrng: atmel - disable trng on failure path (bsc#1012628).
- crypto: sun8i-ss - call finalize with bh disabled (bsc#1012628).
- crypto: sun8i-ce - call finalize with bh disabled (bsc#1012628).
- crypto: amlogic - call finalize with bh disabled (bsc#1012628).
- crypto: gemini - call finalize with bh disabled (bsc#1012628).
- crypto: vmx - add missing dependencies (bsc#1012628).
- clocksource/drivers/timer-ti-dm: Fix regression from errata
  i940 fix (bsc#1012628).
- clocksource/drivers/exynos_mct: Handle DTS with higher number
  of interrupts (bsc#1012628).
- clocksource/drivers/timer-microchip-pit64b: Use notrace
  (bsc#1012628).
- clocksource/drivers/timer-of: Check return value of of_iomap
  in timer_of_base_init() (bsc#1012628).
- arm64: prevent instrumentation of bp hardening callbacks
  (bsc#1012628).
- perf/arm-cmn: Hide XP PUB events for CMN-600 (bsc#1012628).
- perf/arm-cmn: Update watchpoint format (bsc#1012628).
- KEYS: trusted: Fix trusted key backends when building as module
  (bsc#1012628).
- KEYS: trusted: Avoid calling null function trusted_key_exit
  (bsc#1012628).
- ACPI: APEI: fix return value of __setup handlers (bsc#1012628).
- crypto: ccp - ccp_dmaengine_unregister release dma channels
  (bsc#1012628).
- crypto: ccree - Fix use after free in cc_cipher_exit()
  (bsc#1012628).
- crypto: qat - fix initialization of pfvf cap_msg structures
  (bsc#1012628).
- crypto: qat - fix initialization of pfvf rts_map_msg structures
  (bsc#1012628).
- hwrng: nomadik - Change clk_disable to clk_disable_unprepare
  (bsc#1012628).
- hwmon: (pmbus) Add Vin unit off handling (bsc#1012628).
- clocksource: acpi_pm: fix return value of __setup handler
  (bsc#1012628).
- io_uring: don't check unrelated req->open.how in accept request
  (bsc#1012628).
- io_uring: terminate manual loop iterator loop correctly for
  non-vecs (bsc#1012628).
- watch_queue: Fix NULL dereference in error cleanup
  (bsc#1012628).
- watch_queue: Actually free the watch (bsc#1012628).
- f2fs: fix to enable ATGC correctly via gc_idle sysfs interface
  (bsc#1012628).
- sched/debug: Remove mpol_get/put and task_lock/unlock from
  sched_show_numa (bsc#1012628).
- sched/core: Export pelt_thermal_tp (bsc#1012628).
- sched/sugov: Ignore 'busy' filter when rq is capped by
  uclamp_max (bsc#1012628).
- sched/uclamp: Fix iowait boost escaping uclamp restriction
  (bsc#1012628).
- rseq: Remove broken uapi field layout on 32-bit little endian
  (bsc#1012628).
- perf/core: Fix address filter parser for multiple filters
  (bsc#1012628).
- perf/x86/intel/pt: Fix address filter config for 32-bit kernel
  (bsc#1012628).
- sched/fair: Improve consistency of allowed NUMA balance
  calculations (bsc#1012628).
- f2fs: fix missing free nid in f2fs_handle_failed_inode
  (bsc#1012628).
- ext4: fix remount with 'abort' option (bsc#1012628).
- nfsd: more robust allocation failure handling in
  nfsd_file_cache_init (bsc#1012628).
- sched/cpuacct: Fix charge percpu cpuusage (bsc#1012628).
- sched/rt: Plug rt_mutex_setprio() vs push_rt_task() race
  (bsc#1012628).
- f2fs: fix to avoid potential deadlock (bsc#1012628).
- btrfs: fix unexpected error path when reflinking an inline
  extent (bsc#1012628).
- iomap: Fix iomap_invalidatepage tracepoint (bsc#1012628).
- fs: erofs: add sanity check for kobject in
  erofs_unregister_sysfs (bsc#1012628).
- f2fs: fix compressed file start atomic write may cause data
  corruption (bsc#1012628).
- cifs: use a different reconnect helper for non-cifsd threads
  (bsc#1012628).
- selftests, x86: fix how check_cc.sh is being invoked
  (bsc#1012628).
- drivers/base/memory: add memory block to memory group after
  registration succeeded (bsc#1012628).
- kunit: make kunit_test_timeout compatible with comment
  (bsc#1012628).
- pinctrl: samsung: Remove EINT handler for Exynos850 ALIVE and
  CMGP gpios (bsc#1012628).
- media: staging: media: zoran: fix usage of
  vb2_dma_contig_set_max_seg_size (bsc#1012628).
- media: camss: csid-170: fix non-10bit formats (bsc#1012628).
- media: camss: csid-170: don't enable unused irqs (bsc#1012628).
- media: camss: csid-170: set the right HALT_CMD when disabled
  (bsc#1012628).
- media: camss: vfe-170: fix "VFE halt timeout" error
  (bsc#1012628).
- media: staging: media: imx: imx7-mipi-csis: Make subdev name
  unique (bsc#1012628).
- media: v4l2-mem2mem: Apply DST_QUEUE_OFF_BASE on MMAP buffers
  across ioctls (bsc#1012628).
- media: mtk-vcodec: potential dereference of null pointer
  (bsc#1012628).
- media: imx: imx8mq-mipi-csi2: remove wrong irq config write
  operation (bsc#1012628).
- media: imx: imx8mq-mipi_csi2: fix system resume (bsc#1012628).
- media: bttv: fix WARNING regression on tunerless devices
  (bsc#1012628).
- media: atmel: atmel-sama7g5-isc: fix ispck leftover
  (bsc#1012628).
- ASoC: sh: rz-ssi: Drop calling rz_ssi_pio_recv() recursively
  (bsc#1012628).
- ASoC: codecs: Check for error pointer after calling
  devm_regmap_init_mmio (bsc#1012628).
- ASoC: xilinx: xlnx_formatter_pcm: Handle sysclk setting
  (bsc#1012628).
- ASoC: simple-card-utils: Set sysclk on all components
  (bsc#1012628).
- memory: tegra20-emc: Correct memory device mask (bsc#1012628).
- media: coda: Fix missing put_device() call in coda_get_vdoa_data
  (bsc#1012628).
- media: meson: vdec: potential dereference of null pointer
  (bsc#1012628).
- media: hantro: Fix overfill bottom register field name
  (bsc#1012628).
- media: ov6650: Fix set format try processing path (bsc#1012628).
- media: v4l: Avoid unaligned access warnings when printing 4cc
  modifiers (bsc#1012628).
- media: ov5648: Don't pack controls struct (bsc#1012628).
- media: ov2740: identify module after subdev initialisation
  (bsc#1012628).
- media: aspeed: Correct value for h-total-pixels (bsc#1012628).
- video: fbdev: matroxfb: set maxvram of vbG200eW to the same
  as vbG200 to avoid black screen (bsc#1012628).
- video: fbdev: controlfb: Fix COMPILE_TEST build (bsc#1012628).
- video: fbdev: smscufx: Fix null-ptr-deref in ufx_usb_probe()
  (bsc#1012628).
- video: fbdev: atmel_lcdfb: fix an error code in
  atmel_lcdfb_probe() (bsc#1012628).
- video: fbdev: fbcvt.c: fix printing in fb_cvt_print_name()
  (bsc#1012628).
- ARM: dts: Fix OpenBMC flash layout label addresses
  (bsc#1012628).
- ASoC: max98927: add missing header file (bsc#1012628).
- arm64: dts: qcom: sc7280: Fix gmu unit address (bsc#1012628).
- firmware: qcom: scm: Remove reassignment to desc following
  initializer (bsc#1012628).
- ARM: dts: qcom: ipq4019: fix sleep clock (bsc#1012628).
- soc: qcom: rpmpd: Check for null return of devm_kcalloc
  (bsc#1012628).
- soc: qcom: ocmem: Fix missing put_device() call in of_get_ocmem
  (bsc#1012628).
- soc: qcom: aoss: Fix missing put_device call in qmp_get
  (bsc#1012628).
- soc: qcom: aoss: remove spurious IRQF_ONESHOT flags
  (bsc#1012628).
- arm64: dts: qcom: sdm845: fix microphone bias properties and
  values (bsc#1012628).
- arm64: dts: qcom: sm8250: fix PCIe bindings to follow schema
  (bsc#1012628).
- arm64: dts: qcom: msm8916-j5: Fix typo (bsc#1012628).
- arm64: dts: broadcom: bcm4908: use proper TWD binding
  (bsc#1012628).
- arm64: dts: qcom: sm8150: Correct TCS configuration for apps
  rsc (bsc#1012628).
- arm64: dts: qcom: sm8350: Correct TCS configuration for apps
  rsc (bsc#1012628).
- arm64: dts: qcom: sm8450: Update cpuidle states parameters
  (bsc#1012628).
- arm64: dts: qcom: msm8994: Provide missing "xo_board" and
  "sleep_clk" to GCC (bsc#1012628).
- arm64: dts: qcom: ipq6018: fix usb reference period
  (bsc#1012628).
- firmware: ti_sci: Fix compilation failure when
  CONFIG_TI_SCI_PROTOCOL is not defined (bsc#1012628).
- soc: ti: wkup_m3_ipc: Fix IRQ check in wkup_m3_ipc_probe
  (bsc#1012628).
- cpuidle: qcom-spm: Check if any CPU is managed by SPM
  (bsc#1012628).
- ARM: dts: sun8i: v3s: Move the csi1 block to follow address
  order (bsc#1012628).
- ARM: dts: stm32: fix AV96 board SAI2 pin muxing on stm32mp15
  (bsc#1012628).
- vsprintf: Fix potential unaligned access (bsc#1012628).
- ARM: dts: qcom: sdx55: Fix the address used for PCIe EP local
  addr space (bsc#1012628).
- ARM: dts: imx: Add missing LVDS decoder on M53Menlo
  (bsc#1012628).
- media: mexon-ge2d: fixup frames size in registers (bsc#1012628).
- media: video/hdmi: handle short reads of hdmi info frame
  (bsc#1012628).
- media: ti-vpe: cal: Fix a NULL pointer dereference in
  cal_ctx_v4l2_init_formats() (bsc#1012628).
- media: em28xx: initialize refcount before kref_get
  (bsc#1012628).
- media: uapi: Init VP9 stateless decode params (bsc#1012628).
- media: usb: go7007: s2250-board: fix leak in probe()
  (bsc#1012628).
- media: cedrus: H265: Fix neighbour info buffer size
  (bsc#1012628).
- media: cedrus: h264: Fix neighbour info buffer size
  (bsc#1012628).
- arm64: dts: ti: k3-j721s2-mcu-wakeup: Fix the interrupt-parent
  for wkup_gpioX instances (bsc#1012628).
- ASoC: codecs: rx-macro: fix accessing compander for aux
  (bsc#1012628).
- ASoC: codecs: rx-macro: fix accessing array out of bounds for
  enum type (bsc#1012628).
- ASoC: codecs: va-macro: fix accessing array out of bounds for
  enum type (bsc#1012628).
- ASoC: codecs: wc938x: fix accessing array out of bounds for
  enum type (bsc#1012628).
- ASoC: codecs: wcd938x: fix kcontrol max values (bsc#1012628).
- ASoC: codecs: wcd934x: fix kcontrol max values (bsc#1012628).
- ASoC: codecs: wcd934x: fix return value of
  wcd934x_rx_hph_mode_put (bsc#1012628).
- media: v4l2-core: Initialize h264 scaling matrix (bsc#1012628).
- media: hantro: sunxi: Fix VP9 steps (bsc#1012628).
- media: ov5640: Fix set format, v4l2_mbus_pixelcode not updated
  (bsc#1012628).
- selftests: vm: remove dependecy from internal kernel macros
  (bsc#1012628).
- selftests/lkdtm: Add UBSAN config (bsc#1012628).
- vsprintf: Fix %%pK with kptr_restrict == 0 (bsc#1012628).
- uaccess: fix nios2 and microblaze get_user_8() (bsc#1012628).
- ASoC: rt5663: check the return value of devm_kzalloc() in
  rt5663_parse_dp() (bsc#1012628).
- ASoC: acp: check the return value of devm_kzalloc() in
  acp_legacy_dai_links_create() (bsc#1012628).
- soc: mediatek: pm-domains: Add wakeup capacity support in
  power domain (bsc#1012628).
- mmc: sdhci_am654: Fix the driver data of AM64 SoC (bsc#1012628).
- ASoC: ti: davinci-i2s: Add check for clk_enable() (bsc#1012628).
- ALSA: spi: Add check for clk_enable() (bsc#1012628).
- arm64: dts: ns2: Fix spi-cpol and spi-cpha property
  (bsc#1012628).
- arm64: dts: broadcom: Fix sata nodename (bsc#1012628).
- printk: fix return value of printk.devkmsg __setup handler
  (bsc#1012628).
- ASoC: mxs-saif: Handle errors for clk_enable (bsc#1012628).
- ASoC: atmel_ssc_dai: Handle errors for clk_enable (bsc#1012628).
- ASoC: dwc-i2s: Handle errors for clk_enable (bsc#1012628).
- ASoC: soc-compress: prevent the potentially use of null pointer
  (bsc#1012628).
- media: i2c: Fix pixel array positions in ov8865 (bsc#1012628).
- memory: emif: Add check for setup_interrupts (bsc#1012628).
- memory: emif: check the pointer temp in get_device_details()
  (bsc#1012628).
- ALSA: firewire-lib: fix uninitialized flag for AV/C deferred
  transaction (bsc#1012628).
- arm64: dts: rockchip: Fix SDIO regulator supply properties on
  rk3399-firefly (bsc#1012628).
- m68k: coldfire/device.c: only build for MCF_EDMA when h/w
  macros are defined (bsc#1012628).
- media: stk1160: If start stream fails, return buffers with
  VB2_BUF_STATE_QUEUED (bsc#1012628).
- media: vidtv: Check for null return of vzalloc (bsc#1012628).
- ASoC: cs35l41: Fix GPIO2 configuration (bsc#1012628).
- ASoC: cs35l41: Fix max number of TX channels (bsc#1012628).
- ASoC: atmel: Add missing of_node_put() in
  at91sam9g20ek_audio_probe (bsc#1012628).
- ASoC: wm8350: Handle error for wm8350_register_irq
  (bsc#1012628).
- ASoC: fsi: Add check for clk_enable (bsc#1012628).
- video: fbdev: omapfb: Add missing of_node_put() in dvic_probe_of
  (bsc#1012628).
- media: saa7134: fix incorrect use to determine if list is empty
  (bsc#1012628).
- ivtv: fix incorrect device_caps for ivtvfb (bsc#1012628).
- ASoC: atmel: Fix error handling in snd_proto_probe
  (bsc#1012628).
- ASoC: rockchip: i2s: Fix missing clk_disable_unprepare()
  in rockchip_i2s_probe (bsc#1012628).
- ASoC: SOF: Add missing of_node_put() in imx8m_probe
  (bsc#1012628).
- ASoC: mediatek: mt8192-mt6359: Fix error handling in
  mt8192_mt6359_dev_probe (bsc#1012628).
- ASoC: rk817: Fix missing clk_disable_unprepare() in
  rk817_platform_probe (bsc#1012628).
- ASoC: dmaengine: do not use a NULL prepare_slave_config()
  callback (bsc#1012628).
- ASoC: mxs: Fix error handling in mxs_sgtl5000_probe
  (bsc#1012628).
- ASoC: fsl_spdif: Disable TX clock when stop (bsc#1012628).
- ASoC: imx-es8328: Fix error return code in imx_es8328_probe()
  (bsc#1012628).
- ASoC: SOF: Intel: enable DMI L1 for playback streams
  (bsc#1012628).
- ASoC: msm8916-wcd-digital: Fix missing clk_disable_unprepare()
  in msm8916_wcd_digital_probe (bsc#1012628).
- mmc: davinci_mmc: Handle error for clk_enable (bsc#1012628).
- rtla/osnoise: Fix osnoise hist stop tracing message
  (bsc#1012628).
- ASoC: rockchip: Fix PM usage reference of
  rockchip_i2s_tdm_resume (bsc#1012628).
- ASoC: atmel: Fix error handling in sam9x5_wm8731_driver_probe
  (bsc#1012628).
- ASoC: msm8916-wcd-analog: Fix error handling in
  pm8916_wcd_analog_spmi_probe (bsc#1012628).
- ASoC: mediatek: mt8195: Fix error handling in
  mt8195_mt6359_rt1019_rt5682_dev_probe (bsc#1012628).
- ASoC: codecs: wcd934x: Add missing of_node_put() in
  wcd934x_codec_parse_data (bsc#1012628).
- ASoC: amd: Fix reference to PCM buffer address (bsc#1012628).
- ARM: configs: multi_v5_defconfig: re-enable
  CONFIG_V4L_PLATFORM_DRIVERS (bsc#1012628).
- ARM: configs: multi_v5_defconfig: re-enable DRM_PANEL and FB_xxx
  (bsc#1012628).
- drm/bridge: sn65dsi83: Fix an error handling path in
  sn65dsi83_probe() (bsc#1012628).
- drm/meson: osd_afbcd: Add an exit callback to struct
  meson_afbcd_ops (bsc#1012628).
- drm/meson: Fix error handling when afbcd.ops->init fails
  (bsc#1012628).
- drm/bridge: Fix free wrong object in sii8620_init_rcp_input_dev
  (bsc#1012628).
- drm/bridge: Add missing pm_runtime_disable() in
  __dw_mipi_dsi_probe (bsc#1012628).
- drm/bridge: nwl-dsi: Fix PM disable depth imbalance in
  nwl_dsi_probe (bsc#1012628).
- drm: bridge: adv7511: Fix ADV7535 HPD enablement (bsc#1012628).
- ath11k: add missing of_node_put() to avoid leak (bsc#1012628).
- ath10k: fix memory overwrite of the WoWLAN wakeup packet pattern
  (bsc#1012628).
- drm/v3d/v3d_drv: Check for error num after setting mask
  (bsc#1012628).
- Bluetooth: hci_sync: unlock on error in
  hci_inquiry_result_with_rssi_evt() (bsc#1012628).
- ath11k: free peer for station when disconnect from AP for
  QCA6390/WCN6855 (bsc#1012628).
- drm/panfrost: Check for error num after setting mask
  (bsc#1012628).
- bpftool: Fix error check when calling hashmap__new()
  (bsc#1012628).
- libbpf: Fix possible NULL pointer dereference when destroying
  skeleton (bsc#1012628).
- bpftool: Only set obj->skeleton on complete success
  (bsc#1012628).
- ath11k: fix error code in ath11k_qmi_assign_target_mem_chunk()
  (bsc#1012628).
- udmabuf: validate ubuf->pagecount (bsc#1012628).
- bpf: Fix UAF due to race between btf_try_get_module and
  load_module (bsc#1012628).
- drm/selftests/test-drm_dp_mst_helper: Fix memory leak in
  sideband_msg_req_encode_decode (bsc#1012628).
- drm/locking: fix drm_modeset_acquire_ctx kernel-doc
  (bsc#1012628).
- selftests: bpf: Fix bind on used port (bsc#1012628).
- Bluetooth: btintel: Fix WBS setting for Intel legacy ROM
  products (bsc#1012628).
- Bluetooth: hci_serdev: call init_rwsem() before p->open()
  (bsc#1012628).
- Bluetooth: mt7921s: fix firmware coredump retrieve
  (bsc#1012628).
- Bluetooth: mt7921s: fix bus hang with wrong privilege
  (bsc#1012628).
- Bluetooth: btmtksdio: refactor
  btmtksdio_runtime_[suspend|resume]() (bsc#1012628).
- Bluetooth: mt7921s: fix btmtksdio_[drv|fw]_pmctrl()
  (bsc#1012628).
- Bluetooth: btmtksdio: mask out interrupt status (bsc#1012628).
- mtd: onenand: Check for error irq (bsc#1012628).
- mtd: rawnand: gpmi: fix controller timings setting
  (bsc#1012628).
- selftests, xsk: Fix rx_full stats test (bsc#1012628).
- drm/edid: Don't clear formats if using deep color (bsc#1012628).
- drm/edid: Split deep color modes between RGB and YUV444
  (bsc#1012628).
- ionic: fix type complaint in ionic_dev_cmd_clean()
  (bsc#1012628).
- ionic: start watchdog after all is setup (bsc#1012628).
- ionic: Don't send reset commands if FW isn't running
  (bsc#1012628).
- ionic: fix up printing of timeout error (bsc#1012628).
- ionic: Correctly print AQ errors if completions aren't received
  (bsc#1012628).
- net: dsa: Move VLAN filtering syncing out of
  dsa_switch_bridge_leave (bsc#1012628).
- net: dsa: Avoid cross-chip syncing of VLAN filtering
  (bsc#1012628).
- Bluetooth: hci_event: Fix HCI_EV_VENDOR max_len (bsc#1012628).
- drm/nouveau/acr: Fix undefined behavior in
  nvkm_acr_hsfw_load_bl() (bsc#1012628).
- drm/amd/display: Call dc_stream_release for remove link enc
  assignment (bsc#1012628).
- drm/amd/display: Fix a NULL pointer dereference in
  amdgpu_dm_connector_add_common_modes() (bsc#1012628).
- drm/amd/pm: return -ENOTSUPP if there is no
  get_dpm_ultimate_freq function (bsc#1012628).
- net: phy: at803x: move page selection fix to config_init
  (bsc#1012628).
- selftests/bpf/test_xdp_redirect_multi: use temp netns for
  testing (bsc#1012628).
- ath9k_htc: fix uninit value bugs (bsc#1012628).
- ath11k: set WMI_PEER_40MHZ while peer assoc for 6 GHz
  (bsc#1012628).
- RDMA/core: Set MR type in ib_reg_user_mr (bsc#1012628).
- KVM: PPC: Fix vmx/vsx mixup in mmio emulation (bsc#1012628).
- selftests/net: timestamping: Fix bind_phc check (bsc#1012628).
- rtw88: check for validity before using a pointer (bsc#1012628).
- rtw88: fix idle mode flow for hw scan (bsc#1012628).
- rtw88: fix memory overrun and memory leak during hw_scan
  (bsc#1012628).
- drm/bridge: lt9611: Fix an error handling path in lt9611_probe()
  (bsc#1012628).
- i40e: don't reserve excessive XDP_PACKET_HEADROOM on XSK Rx
  to skb (bsc#1012628).
- i40e: respect metadata on XSK Rx to skb (bsc#1012628).
- ice: don't reserve excessive XDP_PACKET_HEADROOM on XSK Rx to
  skb (bsc#1012628).
- ice: respect metadata on XSK Rx to skb (bsc#1012628).
- igc: don't reserve excessive XDP_PACKET_HEADROOM on XSK Rx to
  skb (bsc#1012628).
- ixgbe: pass bi->xdp to ixgbe_construct_skb_zc() directly
  (bsc#1012628).
- ixgbe: don't reserve excessive XDP_PACKET_HEADROOM on XSK Rx
  to skb (bsc#1012628).
- ixgbe: respect metadata on XSK Rx to skb (bsc#1012628).
- power: reset: gemini-poweroff: Fix IRQ check in
  gemini_poweroff_probe (bsc#1012628).
- ray_cs: Check ioremap return value (bsc#1012628).
- powerpc: dts: t1040rdb: fix ports names for Seville Ethernet
  switch (bsc#1012628).
- KVM: PPC: Book3S HV: Check return value of kvmppc_radix_init
  (bsc#1012628).
- powerpc/perf: Don't use perf_hw_context for trace IMC PMU
  (bsc#1012628).
- mt76: connac: fix sta_rec_wtbl tag len (bsc#1012628).
- mt76: mt7915: use proper aid value in
  mt7915_mcu_wtbl_generic_tlv in sta mode (bsc#1012628).
- mt76: mt7915: use proper aid value in mt7915_mcu_sta_basic_tlv
  (bsc#1012628).
- mt76: mt76_connac: fix MCU_CE_CMD_SET_ROC definition error
  (bsc#1012628).
- mt76: mt7921: set EDCA parameters with the MCU CE command
  (bsc#1012628).
- mt76: mt7921: do not always disable fw runtime-pm (bsc#1012628).
- mt76: mt7921: fix a leftover race in runtime-pm (bsc#1012628).
- mt76: mt7615: fix a leftover race in runtime-pm (bsc#1012628).
- mt76: mt7915: fix ht mcs in mt7915_mac_add_txs_skb()
  (bsc#1012628).
- mt76: mt7921: fix ht mcs in mt7921_mac_add_txs_skb()
  (bsc#1012628).
- mt76: mt7921s: fix mt7921s_mcu_[fw|drv]_pmctrl (bsc#1012628).
- mt76: mt7921e: fix possible probe failure after reboot
  (bsc#1012628).
- mt76: mt7603: check sta_rates pointer in
  mt7603_sta_rate_tbl_update (bsc#1012628).
- mt76: mt7615: check sta_rates pointer in
  mt7615_sta_rate_tbl_update (bsc#1012628).
- mt76: mt7915: fix possible memory leak in mt7915_mcu_add_sta
  (bsc#1012628).
- mt76: mt7921s: fix a possible memory leak in mt7921_load_patch
  (bsc#1012628).
- mt76: mt7915: fix mcs_map in mt7915_mcu_set_sta_he_mcs()
  (bsc#1012628).
- mt76: mt7915: fix the nss setting in bitrates (bsc#1012628).
- ptp: unregister virtual clocks when unregistering physical clock
  (bsc#1012628).
- net: dsa: mv88e6xxx: Enable port policy support on 6097
  (bsc#1012628).
- bpf: Fix a btf decl_tag bug when tagging a function
  (bsc#1012628).
- mac80211: limit bandwidth in HE capabilities (bsc#1012628).
- scripts/dtc: Call pkg-config POSIXly correct (bsc#1012628).
- livepatch: Fix build failure on 32 bits processors
  (bsc#1012628).
- net: asix: add proper error handling of usb read errors
  (bsc#1012628).
- i2c: bcm2835: Fix the error handling in 'bcm2835_i2c_probe()'
  (bsc#1012628).
- mtd: mchp23k256: Add SPI ID table (bsc#1012628).
- mtd: mchp48l640: Add SPI ID table (bsc#1012628).
- selftests/bpf: Extract syscall wrapper (bsc#1012628).
- selftests/bpf: Use "__se_" prefix on architectures without
  syscall wrapper (bsc#1012628).
- igc: avoid kernel warning when changing RX ring parameters
  (bsc#1012628).
- igb: refactor XDP registration (bsc#1012628).
- drm/amdgpu: Don't offset by 2 in FRU EEPROM (bsc#1012628).
- PCI: aardvark: Fix reading MSI interrupt number (bsc#1012628).
- PCI: aardvark: Fix reading PCI_EXP_RTSTA_PME bit on emulated
  bridge (bsc#1012628).
- RDMA/rxe: Check the last packet by RXE_END_MASK (bsc#1012628).
- libbpf: Fix signedness bug in btf_dump_array_data()
  (bsc#1012628).
- libbpf: Fix riscv register names (bsc#1012628).
- cxl/core: Fix cxl_probe_component_regs() error message
  (bsc#1012628).
- tools/testing/cxl: Fix root port to host bridge assignment
  (bsc#1012628).
- cxl/regs: Fix size of CXL Capability Header Register
  (bsc#1012628).
- Netvsc: Call hv_unmap_memory() in the netvsc_device_remove()
  (bsc#1012628).
- net:enetc: allocate CBD ring data memory using DMA coherent
  methods (bsc#1012628).
- libbpf: Fix compilation warning due to mismatched printf format
  (bsc#1012628).
- rtw88: fix use after free in rtw_hw_scan_update_probe_req()
  (bsc#1012628).
- drm/bridge: dw-hdmi: use safe format when first in bridge chain
  (bsc#1012628).
- power: supply: ab8500: Swap max and overvoltage (bsc#1012628).
- libbpf: Fix libbpf.map inheritance chain for LIBBPF_0.7.0
  (bsc#1012628).
- libbpf: Use dynamically allocated buffer when receiving netlink
  messages (bsc#1012628).
- power: supply: ab8500: Fix memory leak in ab8500_fg_sysfs_init
  (bsc#1012628).
- HID: i2c-hid: fix GET/SET_REPORT for unnumbered reports
  (bsc#1012628).
- iommu/ipmmu-vmsa: Check for error num after setting mask
  (bsc#1012628).
- drm/bridge: anx7625: Fix overflow issue on reading EDID
  (bsc#1012628).
- ath11k: fix uninitialized rate_idx in
  ath11k_dp_tx_update_txcompl() (bsc#1012628).
- i2c: pasemi: Drop I2C classes from platform driver variant
  (bsc#1012628).
- bpftool: Fix the error when lookup in no-btf maps (bsc#1012628).
- drm/amd/pm: enable pm sysfs write for one VF mode (bsc#1012628).
- drm/amd/display: Add affected crtcs to atomic state for dsc
  mst unplug (bsc#1012628).
- bpftool: Fix pretty print dump for maps without BTF loaded
  (bsc#1012628).
- libbpf: Fix memleak in libbpf_netlink_recv() (bsc#1012628).
- IB/cma: Allow XRC INI QPs to set their local ACK timeout
  (bsc#1012628).
- cxl/core/port: Rename bus.c to port.c (bsc#1012628).
- cxl/port: Hold port reference until decoder release
  (bsc#1012628).
- dax: make sure inodes are flushed before destroy cache
  (bsc#1012628).
- selftests: mptcp: add csum mib check for mptcp_connect
  (bsc#1012628).
- iwlwifi: mvm: Don't call iwl_mvm_sta_from_mac80211() with NULL
  sta (bsc#1012628).
- iwlwifi: mvm: don't iterate unadded vifs when handling FW SMPS
  req (bsc#1012628).
- iwlwifi: mvm: align locking in D3 test debugfs (bsc#1012628).
- iwlwifi: yoyo: remove DBGI_SRAM address reset writing
  (bsc#1012628).
- iwlwifi: yoyo: Avoid using dram data if allocation failed
  (bsc#1012628).
- iwlwifi: mvm: fix off by one in iwl_mvm_stat_iterator_all_macs()
  (bsc#1012628).
- iwlwifi: Fix -EIO error code that is never returned
  (bsc#1012628).
- iwlwifi: mvm: Fix an error code in iwl_mvm_up() (bsc#1012628).
- mtd: rawnand: pl353: Set the nand chip node as the flash node
  (bsc#1012628).
- drm/msm/dp: do not initialize phy until plugin interrupt
  received (bsc#1012628).
- drm/msm/dp: populate connector of struct dp_panel (bsc#1012628).
- drm/msm/dp: stop link training after link training 2 failed
  (bsc#1012628).
- drm/msm/dp: always add fail-safe mode into connector mode list
  (bsc#1012628).
- drm/msm/dsi: Use "ref" fw clock instead of global name for
  VCO parent (bsc#1012628).
- drm/msm/dsi/phy: fix 7nm v4.0 settings for C-PHY mode
  (bsc#1012628).
- drm/msm/dpu: add DSPP blocks teardown (bsc#1012628).
- drm/msm/dpu: fix dp audio condition (bsc#1012628).
- drm/msm/dpu: remove msm_dp cached in dpu_encoder_virt
  (bsc#1012628).
- drm/msm/dp: fix panel bridge attachment (bsc#1012628).
- i40e: remove dead stores on XSK hotpath (bsc#1012628).
- ath11k: Invalidate cached reo ring entry before accessing it
  (bsc#1012628).
- mips: Enable KCSAN (bsc#1012628).
- dm crypt: fix get_key_size compiler warning if !CONFIG_KEYS
  (bsc#1012628).
- vfio/pci: fix memory leak during D3hot to D0 transition
  (bsc#1012628).
- vfio/pci: wake-up devices around reset functions (bsc#1012628).
- scsi: fnic: Fix a tracing statement (bsc#1012628).
- scsi: pm8001: Fix command initialization in
  pm80XX_send_read_log() (bsc#1012628).
- scsi: pm8001: Fix command initialization in
  pm8001_chip_ssp_tm_req() (bsc#1012628).
- scsi: pm8001: Fix payload initialization in
  pm80xx_set_thermal_config() (bsc#1012628).
- scsi: pm8001: Fix le32 values handling in
  pm80xx_set_sas_protocol_timer_config() (bsc#1012628).
- scsi: pm8001: Fix payload initialization in
  pm80xx_encrypt_update() (bsc#1012628).
- scsi: pm8001: Fix le32 values handling in
  pm80xx_chip_ssp_io_req() (bsc#1012628).
- scsi: pm8001: Fix le32 values handling in pm80xx_chip_sata_req()
  (bsc#1012628).
- scsi: pm8001: Fix NCQ NON DATA command task initialization
  (bsc#1012628).
- scsi: pm8001: Fix NCQ NON DATA command completion handling
  (bsc#1012628).
- scsi: pm8001: Fix abort all task initialization (bsc#1012628).
- mt76: do not always copy ethhdr in reverse_frag0_hdr_trans
  (bsc#1012628).
- mt76: fix endianness errors in reverse_frag0_hdr_trans
  (bsc#1012628).
- mt76: mt7921s: fix missing fc type/sub-type for 802.11 pkts
  (bsc#1012628).
- net: dsa: realtek-smi: fix kdoc warnings (bsc#1012628).
- net: dsa: realtek-smi: move to subdirectory (bsc#1012628).
- RDMA/mlx5: Fix the flow of a miss in the allocation of a cache
  ODP MR (bsc#1012628).
- drm/amd/display: Remove vupdate_int_entry definition
  (bsc#1012628).
- TOMOYO: fix __setup handlers return values (bsc#1012628).
- power: supply: sbs-charger: Don't cancel work that is not
  initialized (bsc#1012628).
- mt76: mt7915: enlarge wcid size to 544 (bsc#1012628).
- mt76: mt7915: fix the muru tlv issue (bsc#1012628).
- drm/dp: Fix OOB read when handling Post Cursor2 register
  (bsc#1012628).
- ext2: correct max file size computing (bsc#1012628).
- drm/tegra: Fix reference leak in tegra_dsi_ganged_probe
  (bsc#1012628).
- power: supply: bq24190_charger: Fix bq24190_vbus_is_enabled()
  wrong false return (bsc#1012628).
- scsi: hisi_sas: Change permission of parameter prot_mask
  (bsc#1012628).
- drm/bridge: cdns-dsi: Make sure to to create proper aliases
  for dt (bsc#1012628).
- bpf, arm64: Call build_prologue() first in first JIT pass
  (bsc#1012628).
- bpf, arm64: Feed byte-offset into bpf line info (bsc#1012628).
- xsk: Fix race at socket teardown (bsc#1012628).
- RDMA/irdma: Fix netdev notifications for vlan's (bsc#1012628).
- RDMA/irdma: Fix Passthrough mode in VM (bsc#1012628).
- RDMA/irdma: Remove incorrect masking of PD (bsc#1012628).
- libbpf: Fix BPF_MAP_TYPE_PERF_EVENT_ARRAY auto-pinning
  (bsc#1012628).
- gpu: host1x: Fix an error handling path in 'host1x_probe()'
  (bsc#1012628).
- gpu: host1x: Fix a memory leak in 'host1x_remove()'
  (bsc#1012628).
- libbpf: Skip forward declaration when counting duplicated type
  names (bsc#1012628).
- powerpc/mm/numa: skip NUMA_NO_NODE onlining in
  parse_numa_properties() (bsc#1012628).
- powerpc/Makefile: Don't pass -mcpu=powerpc64 when building
  32-bit (bsc#1012628).
- KVM: x86: Fix emulation in writing cr8 (bsc#1012628).
- KVM: x86/emulator: Defer not-present segment check in
  __load_segment_descriptor() (bsc#1012628).
- KVM: SVM: Exit to userspace on ENOMEM/EFAULT GHCB errors
  (bsc#1012628).
- hv_balloon: rate-limit "Unhandled message" warning
  (bsc#1012628).
- KVM: arm64: Enable Cortex-A510 erratum 2077057 by default
  (bsc#1012628).
- i2c: xiic: Make bus names unique (bsc#1012628).
- net: phy: micrel: Fix concurrent register access (bsc#1012628).
- Bluetooth: hci_sync: fix undefined return of
  hci_disconnect_all_sync() (bsc#1012628).
- Bluetooth: Fix skb allocation in mgmt_remote_name() &
  mgmt_device_connected() (bsc#1012628).
- power: supply: wm8350-power: Handle error for
  wm8350_register_irq (bsc#1012628).
- power: supply: wm8350-power: Add missing free in
  free_charger_irq (bsc#1012628).
- IB/hfi1: Allow larger MTU without AIP (bsc#1012628).
- RDMA/core: Fix ib_qp_usecnt_dec() called when error
  (bsc#1012628).
- PCI: Reduce warnings on possible RW1C corruption (bsc#1012628).
- net: axienet: fix RX ring refill allocation failure handling
  (bsc#1012628).
- drm/msm/a6xx: Fix missing ARRAY_SIZE() check (bsc#1012628).
- mips: DEC: honor CONFIG_MIPS_FP_SUPPORT=n (bsc#1012628).
- MIPS: Sanitise Cavium switch cases in TLB handler synthesizers
  (bsc#1012628).
- powerpc/sysdev: fix incorrect use to determine if list is empty
  (bsc#1012628).
- powerpc/64s: Don't use DSISR for SLB faults (bsc#1012628).
- mfd: mc13xxx: Add check for mc13xxx_irq_request (bsc#1012628).
- libbpf: Unmap rings when umem deleted (bsc#1012628).
- selftests/bpf: Make test_lwt_ip_encap more stable and faster
  (bsc#1012628).
- platform/x86: huawei-wmi: check the return value of
  device_create_file() (bsc#1012628).
- scsi: mpt3sas: Fix incorrect 4GB boundary check (bsc#1012628).
- powerpc: 8xx: fix a return value error in mpc8xx_pic_init
  (bsc#1012628).
- xtensa: add missing XCHAL_HAVE_WINDOWED check (bsc#1012628).
- iwlwifi: pcie: fix SW error MSI-X mapping (bsc#1012628).
- vxcan: enable local echo for sent CAN frames (bsc#1012628).
- ath10k: Fix error handling in ath10k_setup_msa_resources
  (bsc#1012628).
- mips: cdmm: Fix refcount leak in mips_cdmm_phys_base
  (bsc#1012628).
- MIPS: RB532: fix return value of __setup handler (bsc#1012628).
- MIPS: pgalloc: fix memory leak caused by pgd_free()
  (bsc#1012628).
- mtd: rawnand: atmel: fix refcount issue in
  atmel_nand_controller_init (bsc#1012628).
- power: ab8500_chargalg: Use CLOCK_MONOTONIC (bsc#1012628).
- RDMA/irdma: Prevent some integer underflows (bsc#1012628).
- Revert "RDMA/core: Fix ib_qp_usecnt_dec() called when error"
  (bsc#1012628).
- RDMA/mlx5: Fix memory leak in error flow for subscribe event
  routine (bsc#1012628).
- bpf, sockmap: Fix memleak in sk_psock_queue_msg (bsc#1012628).
- bpf, sockmap: Fix memleak in tcp_bpf_sendmsg while sk msg is
  full (bsc#1012628).
- bpf, sockmap: Fix more uncharged while msg has more_data
  (bsc#1012628).
- bpf, sockmap: Fix double uncharge the mem of sk_msg
  (bsc#1012628).
- samples/bpf, xdpsock: Fix race when running for fix duration
  of time (bsc#1012628).
- USB: storage: ums-realtek: fix error code in rts51x_read_mem()
  (bsc#1012628).
- drm/amd/display: Fix double free during GPU reset on DC streams
  (bsc#1012628).
- RDMA/rxe: Change variable and function argument to proper type
  (bsc#1012628).
- RDMA/rxe: Fix ref error in rxe_av.c (bsc#1012628).
- powerpc/xive: fix return value of __setup handler (bsc#1012628).
- powerpc/time: Fix KVM host re-arming a timer beyond decrementer
  range (bsc#1012628).
- drm/i915/display: Fix HPD short pulse handling for eDP
  (bsc#1012628).
- drm/i915/display: Do not re-enable PSR after it was marked as
  not reliable (bsc#1012628).
- netfilter: flowtable: Fix QinQ and pppoe support for inet table
  (bsc#1012628).
- mt76: mt7921: fix mt7921_queues_acq implementation
  (bsc#1012628).
- can: isotp: return -EADDRNOTAVAIL when reading from unbound
  socket (bsc#1012628).
- can: isotp: support MSG_TRUNC flag when reading from socket
  (bsc#1012628).
- bareudp: use ipv6_mod_enabled to check if IPv6 enabled
  (bsc#1012628).
- PCI: imx6: Invoke the PHY exit function after PHY power off
  (bsc#1012628).
- PCI: imx6: Assert i.MX8MM CLKREQ# even if no device present
  (bsc#1012628).
- ibmvnic: fix race between xmit and reset (bsc#1012628).
- af_unix: Fix some data-races around unix_sk(sk)->oob_skb
  (bsc#1012628).
- selftests/bpf: Fix error reporting from sock_fields programs
  (bsc#1012628).
- Bluetooth: hci_uart: add missing NULL check in h5_enqueue
  (bsc#1012628).
- Bluetooth: call hci_le_conn_failed with hdev lock in
  hci_le_conn_failed (bsc#1012628).
- Bluetooth: btmtksdio: Fix kernel oops in btmtksdio_interrupt
  (bsc#1012628).
- RDMA/nldev: Prevent underflow in
  nldev_stat_set_counter_dynamic_doit() (bsc#1012628).
- ipv4: Fix route lookups when handling ICMP redirects and PMTU
  updates (bsc#1012628).
- mptcp: Fix crash due to tcp_tsorted_anchor was initialized
  before release skb (bsc#1012628).
- af_netlink: Fix shift out of bounds in group mask calculation
  (bsc#1012628).
- i2c: meson: Fix wrong speed use from probe (bsc#1012628).
- netfilter: conntrack: Add and use
  nf_ct_set_auto_assign_helper_warned() (bsc#1012628).
- i2c: mux: demux-pinctrl: do not deactivate a master that is
  not active (bsc#1012628).
- powerpc/pseries: Fix use after free in remove_phb_dynamic()
  (bsc#1012628).
- ax25: Fix refcount leaks caused by ax25_cb_del() (bsc#1012628).
- ax25: Fix NULL pointer dereferences in ax25 timers
  (bsc#1012628).
- drm/i915: Fix renamed struct field (bsc#1012628).
- selftests/bpf/test_lirc_mode2.sh: Exit with proper code
  (bsc#1012628).
- bpftool: Fix print error when show bpf map (bsc#1012628).
- PCI: Avoid broken MSI on SB600 USB devices (bsc#1012628).
- net: bcmgenet: Use stronger register read/writes to assure
  ordering (bsc#1012628).
- tcp: ensure PMTU updates are processed during fastopen
  (bsc#1012628).
- openvswitch: always update flow key after nat (bsc#1012628).
- net: dsa: fix panic on shutdown if multi-chip tree failed to
  probe (bsc#1012628).
- net: wwan: qcom_bam_dmux: fix wrong pointer passed to IS_ERR()
  (bsc#1012628).
- tipc: fix the timer expires after interval 100ms (bsc#1012628).
- mfd: asic3: Add missing iounmap() on error asic3_mfd_probe
  (bsc#1012628).
- ice: fix 'scheduling while atomic' on aux critical err interrupt
  (bsc#1012628).
- ice: don't allow to run ice_send_event_to_aux() in atomic ctx
  (bsc#1012628).
- drivers: ethernet: cpsw: fix panic when interrupt coaleceing
  is set via ethtool (bsc#1012628).
- kernel/resource: fix kfree() of bootmem memory again
  (bsc#1012628).
- clk: renesas: r9a07g044: Update multiplier and divider values
  for PLL2/3 (bsc#1012628).
- staging: r8188eu: release_firmware is not called if allocation
  fails (bsc#1012628).
- mxser: fix xmit_buf leak in activate when LSR == 0xff
  (bsc#1012628).
- fsi: scom: Fix error handling (bsc#1012628).
- fsi: scom: Remove retries in indirect scoms (bsc#1012628).
- pwm: lpc18xx-sct: Initialize driver data and hardware before
  pwmchip_add() (bsc#1012628).
- pps: clients: gpio: Propagate return value from pps_gpio_probe
  (bsc#1012628).
- fsi: Aspeed: Fix a potential double free (bsc#1012628).
- misc: alcor_pci: Fix an error handling path (bsc#1012628).
- cpufreq: qcom-cpufreq-nvmem: fix reading of PVS Valid fuse
  (bsc#1012628).
- soundwire: intel: fix wrong register name in intel_shim_wake
  (bsc#1012628).
- clk: qcom: ipq8074: fix PCI-E clock oops (bsc#1012628).
- dmaengine: idxd: restore traffic class defaults after wq reset
  (bsc#1012628).
- iio: mma8452: Fix probe failing when an i2c_device_id is used
  (bsc#1012628).
- staging: qlge: add unregister_netdev in qlge_probe
  (bsc#1012628).
- serial: 8250_aspeed_vuart: add PORT_ASPEED_VUART port type
  (bsc#1012628).
- staging:iio:adc:ad7280a: Fix handing of device address bit
  reversing (bsc#1012628).
- clk: renesas: r8a779f0: Fix RSW2 clock divider (bsc#1012628).
- pinctrl: renesas: r8a77470: Reduce size for narrow VIN1 channel
  (bsc#1012628).
- pinctrl: renesas: checker: Fix miscalculation of number of
  states (bsc#1012628).
- clk: qcom: ipq8074: Use floor ops for SDCC1 clock (bsc#1012628).
- phy: dphy: Correct lpx parameter and its
  derivatives(ta_{get,go,sure}) (bsc#1012628).
- phy: phy-brcm-usb: fixup BCM4908 support (bsc#1012628).
- serial: 8250_mid: Balance reference count for PCI DMA device
  (bsc#1012628).
- serial: 8250_lpss: Balance reference count for PCI DMA device
  (bsc#1012628).
- NFS: Use of mapping_set_error() results in spurious errors
  (bsc#1012628).
- serial: 8250: Fix race condition in RTS-after-send handling
  (bsc#1012628).
- iio: adc: Add check for devm_request_threaded_irq (bsc#1012628).
- habanalabs: Add check for pci_enable_device (bsc#1012628).
- NFS: Return valid errors from nfs2/3_decode_dirent()
  (bsc#1012628).
- staging: r8188eu: fix endless loop in recv_func (bsc#1012628).
- dma-debug: fix return value of __setup handlers (bsc#1012628).
- clk: imx7d: Remove audio_mclk_root_clk (bsc#1012628).
- clk: imx: off by one in imx_lpcg_parse_clks_from_dt()
  (bsc#1012628).
- clk: at91: sama7g5: fix parents of PDMCs' GCLK (bsc#1012628).
- clk: qcom: clk-rcg2: Update logic to calculate D value for RCG
  (bsc#1012628).
- clk: qcom: clk-rcg2: Update the frac table for pixel clock
  (bsc#1012628).
- clk: starfive: jh7100: Don't round divisor up twice
  (bsc#1012628).
- clk: starfive: jh7100: Handle audio_div clock properly
  (bsc#1012628).
- dmaengine: hisi_dma: fix MSI allocate fail when reload hisi_dma
  (bsc#1012628).
- remoteproc: qcom: Fix missing of_node_put in
  adsp_alloc_memory_region (bsc#1012628).
- remoteproc: qcom_wcnss: Add missing of_node_put() in
  wcnss_alloc_memory_region (bsc#1012628).
- remoteproc: qcom_q6v5_mss: Fix some leaks in
  q6v5_alloc_memory_region (bsc#1012628).
- nvdimm/region: Fix default alignment for small regions
  (bsc#1012628).
- clk: actions: Terminate clk_div_table with sentinel element
  (bsc#1012628).
- clk: loongson1: Terminate clk_div_table with sentinel element
  (bsc#1012628).
- clk: hisilicon: Terminate clk_div_table with sentinel element
  (bsc#1012628).
- clk: clps711x: Terminate clk_div_table with sentinel element
  (bsc#1012628).
- clk: Fix clk_hw_get_clk() when dev is NULL (bsc#1012628).
- clk: tegra: tegra124-emc: Fix missing put_device() call in
  emc_ensure_emc_driver (bsc#1012628).
- mailbox: imx: fix crash in resume on i.mx8ulp (bsc#1012628).
- NFS: remove unneeded check in decode_devicenotify_args()
  (bsc#1012628).
- staging: mt7621-dts: fix LEDs and pinctrl on GB-PC1 devicetree
  (bsc#1012628).
- staging: mt7621-dts: fix formatting (bsc#1012628).
- staging: mt7621-dts: fix pinctrl properties for ethernet
  (bsc#1012628).
- staging: mt7621-dts: fix GB-PC2 devicetree (bsc#1012628).
- pinctrl: ocelot: fix confops resource index (bsc#1012628).
- pinctrl: ocelot: fix duplicate debugfs entry (bsc#1012628).
- pinctrl: mediatek: Fix missing of_node_put() in mtk_pctrl_init
  (bsc#1012628).
- pinctrl: mediatek: paris: Fix PIN_CONFIG_BIAS_* readback
  (bsc#1012628).
- pinctrl: mediatek: paris: Fix "argument" argument type for
  mtk_pinconf_get() (bsc#1012628).
- pinctrl: mediatek: paris: Fix pingroup pin config state readback
  (bsc#1012628).
- pinctrl: mediatek: paris: Skip custom extra pin config dump
  for virtual GPIOs (bsc#1012628).
- pinctrl: ocelot: Fix interrupt parsing (bsc#1012628).
- pinctrl: microchip-sgpio: lock RMW access (bsc#1012628).
- pinctrl: nomadik: Add missing of_node_put() in nmk_pinctrl_probe
  (bsc#1012628).
- pinctrl/rockchip: Add missing of_node_put() in
  rockchip_pinctrl_probe (bsc#1012628).
- clk: visconti: prevent array overflow in
  visconti_clk_register_gates() (bsc#1012628).
- tty: hvc: fix return value of __setup handler (bsc#1012628).
- kgdboc: fix return value of __setup handler (bsc#1012628).
- serial: 8250: fix XOFF/XON sending when DMA is used
  (bsc#1012628).
- virt: acrn: obtain pa from VMA with PFNMAP flag (bsc#1012628).
- virt: acrn: fix a memory leak in acrn_dev_ioctl() (bsc#1012628).
- kgdbts: fix return value of __setup handler (bsc#1012628).
- firmware: google: Properly state IOMEM dependency (bsc#1012628).
- driver core: dd: fix return value of __setup handler
  (bsc#1012628).
- perf test arm64: Test unwinding using fame-pointer (fp) mode
  (bsc#1012628).
- jfs: fix divide error in dbNextAG (bsc#1012628).
- SUNRPC/call_alloc: async tasks mustn't block waiting for memory
  (bsc#1012628).
- SUNRPC: improve 'swap' handling: scheduling and PF_MEMALLOC
  (bsc#1012628).
- SUNRPC: Don't call connect() more than once on a TCP socket
  (bsc#1012628).
- perf parse-events: Move slots only with topdown (bsc#1012628).
- netfilter: egress: Report interface as outgoing (bsc#1012628).
- netfilter: nf_conntrack_tcp: preserve liberal flag in tcp
  options (bsc#1012628).
- SUNRPC don't resend a task on an offlined transport
  (bsc#1012628).
- NFSv4.1: don't retry BIND_CONN_TO_SESSION on session error
  (bsc#1012628).
- kdb: Fix the putarea helper function (bsc#1012628).
- perf stat: Fix forked applications enablement of counters
  (bsc#1012628).
- net: stmmac: dwmac-qcom-ethqos: Enable RGMII functional clock
  on resume (bsc#1012628).
- clk: qcom: gcc-msm8994: Fix gpll4 width (bsc#1012628).
- vsock/virtio: initialize vdev->priv before using VQs
  (bsc#1012628).
- vsock/virtio: read the negotiated features before using VQs
  (bsc#1012628).
- vsock/virtio: enable VQs early on probe (bsc#1012628).
- clk: Initialize orphan req_rate (bsc#1012628).
- xen: fix is_xen_pmu() (bsc#1012628).
- net: enetc: report software timestamping via SO_TIMESTAMPING
  (bsc#1012628).
- net: hns3: fix bug when PF set the duplicate MAC address for
  VFs (bsc#1012628).
- net: hns3: fix port base vlan add fail when concurrent with
  reset (bsc#1012628).
- net: hns3: add vlan list lock to protect vlan list
  (bsc#1012628).
- net: hns3: refine the process when PF set VF VLAN (bsc#1012628).
- net: phy: broadcom: Fix brcm_fet_config_init() (bsc#1012628).
- selftests: test_vxlan_under_vrf: Fix broken test case
  (bsc#1012628).
- NFS: Don't loop forever in nfs_do_recoalesce() (bsc#1012628).
- libperf tests: Fix typo in perf_evlist__open() failure error
  messages (bsc#1012628).
- net: hns3: fix ethtool tx copybreak buf size indicating not
  aligned issue (bsc#1012628).
- net: hns3: add max order judgement for tx spare buffer
  (bsc#1012628).
- net: hns3: clean residual vf config after disable sriov
  (bsc#1012628).
- net: hns3: add netdev reset check for hns3_set_tunable()
  (bsc#1012628).
- net: hns3: add NULL pointer check for hns3_set/get_ringparam()
  (bsc#1012628).
- net: hns3: fix phy can not link up when autoneg off and reset
  (bsc#1012628).
- net: sparx5: depends on PTP_1588_CLOCK_OPTIONAL (bsc#1012628).
- qlcnic: dcb: default to returning -EOPNOTSUPP (bsc#1012628).
- net/x25: Fix null-ptr-deref caused by x25_disconnect
  (bsc#1012628).
- net: sparx5: switchdev: fix possible NULL pointer dereference
  (bsc#1012628).
- octeontx2-af: initialize action variable (bsc#1012628).
- selftests: tls: skip cmsg_to_pipe tests with TLS=n
  (bsc#1012628).
- net/sched: act_ct: fix ref leak when switching zones
  (bsc#1012628).
- NFSv4/pNFS: Fix another issue with a list iterator pointing
  to the head (bsc#1012628).
- net: dsa: bcm_sf2_cfp: fix an incorrect NULL check on list
  iterator (bsc#1012628).
- fs: fd tables have to be multiples of BITS_PER_LONG
  (bsc#1012628).
- lib/test: use after free in register_test_dev_kmod()
  (bsc#1012628).
- fs: fix fd table size alignment properly (bsc#1012628).
- LSM: general protection fault in legacy_parse_param
  (bsc#1012628).
- regulator: rpi-panel: Handle I2C errors/timing to the Atmel
  (bsc#1012628).
- crypto: hisilicon/qm - cleanup warning in qm_vf_read_qos
  (bsc#1012628).
- crypto: octeontx2 - CN10K CPT to RNM workaround (bsc#1012628).
- gcc-plugins/stackleak: Exactly match strings instead of prefixes
  (bsc#1012628).
- rcu: Kill rnp->ofl_seq and use only rcu_state.ofl_lock for
  exclusion (bsc#1012628).
- pinctrl: npcm: Fix broken references to chip->parent_device
  (bsc#1012628).
- rcu: Mark writes to the rcu_segcblist structure's ->flags field
  (bsc#1012628).
- block: throttle split bio in case of iops limit (bsc#1012628).
- memstick/mspro_block: fix handling of read-only devices
  (bsc#1012628).
- block/bfq_wf2q: correct weight to ioprio (bsc#1012628).
- crypto: xts - Add softdep on ecb (bsc#1012628).
- crypto: hisilicon/sec - not need to enable sm4 extra mode at
  HW V3 (bsc#1012628).
- block, bfq: don't move oom_bfqq (bsc#1012628).
- selinux: use correct type for context length (bsc#1012628).
- powercap/dtpm_cpu: Reset per_cpu variable in the release
  function (bsc#1012628).
- arm64: module: remove (NOLOAD) from linker script (bsc#1012628).
- selinux: allow FIOCLEX and FIONCLEX with policy capability
  (bsc#1012628).
- loop: use sysfs_emit() in the sysfs xxx show() (bsc#1012628).
- Fix incorrect type in assignment of ipv6 port for audit
  (bsc#1012628).
- irqchip/qcom-pdc: Fix broken locking (bsc#1012628).
- irqchip/nvic: Release nvic_base upon failure (bsc#1012628).
- fs/binfmt_elf: Fix AT_PHDR for unusual ELF files (bsc#1012628).
- hwrng: cavium - fix NULL but dereferenced coccicheck error
  (bsc#1012628).
- bfq: fix use-after-free in bfq_dispatch_request (bsc#1012628).
- ACPICA: Avoid walking the ACPI Namespace if it is not there
  (bsc#1012628).
- ACPI / x86: Add skip i2c clients quirk for Nextbook Ares 8
  (bsc#1012628).
- ACPI / x86: Add skip i2c clients quirk for Lenovo Yoga Tablet
  1050F/L (bsc#1012628).
- lib/raid6/test/Makefile: Use $(pound) instead of \# for Make
  4.3 (bsc#1012628).
- Revert "Revert "block, bfq: honor already-setup queue merges""
  (bsc#1012628).
- ACPI/APEI: Limit printable size of BERT table data
  (bsc#1012628).
- PM: core: keep irq flags in device_pm_check_callbacks()
  (bsc#1012628).
- parisc: Fix non-access data TLB cache flush faults
  (bsc#1012628).
- parisc: Fix handling off probe non-access faults (bsc#1012628).
- nvme-tcp: lockdep: annotate in-kernel sockets (bsc#1012628).
- spi: tegra20: Use of_device_get_match_data() (bsc#1012628).
- spi: fsi: Implement a timeout for polling status (bsc#1012628).
- atomics: Fix atomic64_{read_acquire,set_release} fallbacks
  (bsc#1012628).
- locking/lockdep: Iterate lock_classes directly when reading
  lockdep files (bsc#1012628).
- ext4: correct cluster len and clusters changed accounting in
  ext4_mb_mark_bb (bsc#1012628).
- ext4: fix ext4_mb_mark_bb() with flex_bg with fast_commit
  (bsc#1012628).
- sched/tracing: Report TASK_RTLOCK_WAIT tasks as
  TASK_UNINTERRUPTIBLE (bsc#1012628).
- ext4: don't BUG if someone dirty pages without asking ext4 first
  (bsc#1012628).
- f2fs: fix to do sanity check on curseg->alloc_type
  (bsc#1012628).
- NFSD: Fix nfsd_breaker_owns_lease() return values (bsc#1012628).
- f2fs: don't get FREEZE lock in f2fs_evict_inode in frozen fs
  (bsc#1012628).
- btrfs: harden identification of a stale device (bsc#1012628).
- btrfs: make search_csum_tree return 0 if we get -EFBIG
  (bsc#1012628).
- btrfs: handle csum lookup errors properly on reads
  (bsc#1012628).
- btrfs: do not double complete bio on errors during compressed
  reads (bsc#1012628).
- btrfs: do not clean up repair bio if submit fails (bsc#1012628).
- f2fs: use spin_lock to avoid hang (bsc#1012628).
- f2fs: compress: fix to print raw data size in error path of
  lz4 decompression (bsc#1012628).
- Adjust cifssb maximum read size (bsc#1012628).
- ntfs: add sanity check on allocation size (bsc#1012628).
- media: staging: media: zoran: move videodev alloc (bsc#1012628).
- media: staging: media: zoran: calculate the right buffer number
  for zoran_reap_stat_com (bsc#1012628).
- media: staging: media: zoran: fix various V4L2 compliance errors
  (bsc#1012628).
- media: atmel: atmel-isc-base: report frame sizes as full
  supported range (bsc#1012628).
- media: ir_toy: free before error exiting (bsc#1012628).
- ASoC: sh: rz-ssi: Make the data structures available before
  registering the handlers (bsc#1012628).
- ASoC: cs42l42: Report full jack status when plug is detected
  (bsc#1012628).
- ASoC: SOF: Intel: match sdw version on link_slaves_found
  (bsc#1012628).
- media: imx-jpeg: Prevent decoding NV12M jpegs into single-planar
  buffers (bsc#1012628).
- ASoC: SOF: Intel: hda: Remove link assignment limitation
  (bsc#1012628).
- media: iommu/mediatek-v1: Free the existed fwspec if the master
  dev already has (bsc#1012628).
- media: iommu/mediatek: Return ENODEV if the device is NULL
  (bsc#1012628).
- media: iommu/mediatek: Add device_link between the consumer
  and the larb devices (bsc#1012628).
- video: fbdev: nvidiafb: Use strscpy() to prevent buffer overflow
  (bsc#1012628).
- video: fbdev: w100fb: Reset global state (bsc#1012628).
- video: fbdev: cirrusfb: check pixclock to avoid divide by zero
  (bsc#1012628).
- video: fbdev: omapfb: acx565akm: replace snprintf with
  sysfs_emit (bsc#1012628).
- ARM: dts: qcom: fix gic_irq_domain_translate warnings for
  msm8960 (bsc#1012628).
- ARM: dts: bcm2837: Add the missing L1/L2 cache information
  (bsc#1012628).
- ASoC: madera: Add dependencies on MFD (bsc#1012628).
- media: atomisp_gmin_platform: Add DMI quirk to not turn AXP
  ELDO2 regulator off on some boards (bsc#1012628).
- media: atomisp: fix dummy_ptr check to avoid duplicate active_bo
  (bsc#1012628).
- ARM: ftrace: avoid redundant loads or clobbering IP
  (bsc#1012628).
- ALSA: hda: Fix driver index handling at re-binding
  (bsc#1012628).
- ARM: dts: imx7: Use audio_mclk_post_div instead
  audio_mclk_root_clk (bsc#1012628).
- arm64: defconfig: build imx-sdma as a module (bsc#1012628).
- video: fbdev: omapfb: panel-dsi-cm: Use sysfs_emit() instead
  of snprintf() (bsc#1012628).
- video: fbdev: omapfb: panel-tpo-td043mtea1: Use sysfs_emit()
  instead of snprintf() (bsc#1012628).
- video: fbdev: udlfb: replace snprintf in show functions with
  sysfs_emit (bsc#1012628).
- ARM: dts: bcm2711: Add the missing L1/L2 cache information
  (bsc#1012628).
- ASoC: soc-core: skip zero num_dai component in searching dai
  name (bsc#1012628).
- ASoC: Intel: sof_es8336: add quirk for Huawei D15 2021
  (bsc#1012628).
- media: imx-jpeg: fix a bug of accessing array out of bounds
  (bsc#1012628).
- media: cx88-mpeg: clear interrupt status register before
  streaming video (bsc#1012628).
- ASoC: rt5682s: Fix the wrong jack type detected (bsc#1012628).
- ARM: tegra: transformer: Drop reg-shift for Tegra HS UART
  (bsc#1012628).
- uaccess: fix type mismatch warnings from access_ok()
  (bsc#1012628).
- lib/test_lockup: fix kernel pointer check for separate address
  spaces (bsc#1012628).
- ARM: tegra: tamonten: Fix I2C3 pad setting (bsc#1012628).
- ARM: mmp: Fix failure to remove sram device (bsc#1012628).
- ASoC: amd: vg: fix for pm resume callback sequence
  (bsc#1012628).
- ASoC: amd: vangogh: fix uninitialized symbol warning in machine
  driver (bsc#1012628).
- video: fbdev: sm712fb: Fix crash in smtcfb_write()
  (bsc#1012628).
- media: i2c: ov5648: Fix lockdep error (bsc#1012628).
- media: Revert "media: em28xx: add missing
  em28xx_close_extension" (bsc#1012628).
- media: hdpvr: initialize dev->worker at hdpvr_register_videodev
  (bsc#1012628).
- ASoC: SOF: debug: clarify operator precedence (bsc#1012628).
- ASoC: Intel: sof_sdw: fix quirks for 2022 HP Spectre x360 13"
  (bsc#1012628).
- ASoC: SOF: Intel: hda: retrieve DMIC number for I2S boards
  (bsc#1012628).
- ALSA: intel-nhlt: add helper to detect SSP link mask
  (bsc#1012628).
- ALSA: intel-dsp-config: add more ACPI HIDs for ES83x6 devices
  (bsc#1012628).
- ASoC: Intel: soc-acpi: add more ACPI HIDs for ES83x6 devices
  (bsc#1012628).
- ALSA: intel-dspconfig: add ES8336 support for CNL (bsc#1012628).
- ASoC: Intel: Revert "ASoC: Intel: sof_es8336: add quirk for
  Huawei D15 2021" (bsc#1012628).
- ASoC: Intel: sof_es8336: log all quirks (bsc#1012628).
- tracing: Have TRACE_DEFINE_ENUM affect trace event types as well
  (bsc#1012628).
- mmc: host: Return an error when ->enable_sdio_irq() ops is
  missing (bsc#1012628).
- ASoC: mediatek: Fix error handling in
  mt8183_da7219_max98357_dev_probe (bsc#1012628).
- media: atomisp: fix bad usage at error handling logic
  (bsc#1012628).
- ALSA: hda/realtek: Add alc256-samsung-headphone fixup
  (bsc#1012628).
- KVM: SVM: Allow AVIC support on system w/ physical APIC ID >
  255 (bsc#1012628).
- KVM: x86: Reinitialize context if host userspace toggles
  EFER.LME (bsc#1012628).
- KVM: x86/mmu: Use common TDP MMU zap helper for MMU notifier
  unmap hook (bsc#1012628).
- KVM: x86/mmu: Move "invalid" check out of kvm_tdp_mmu_get_root()
  (bsc#1012628).
- KVM: x86/mmu: Zap _all_ roots when unmapping gfn range in TDP
  MMU (bsc#1012628).
- KVM: x86/mmu: Check for present SPTE when clearing dirty bit
  in TDP MMU (bsc#1012628).
- KVM: x86: hyper-v: Drop redundant 'ex' parameter from
  kvm_hv_send_ipi() (bsc#1012628).
- KVM: x86: hyper-v: Drop redundant 'ex' parameter from
  kvm_hv_flush_tlb() (bsc#1012628).
- KVM: x86: hyper-v: Fix the maximum number of sparse banks for
  XMM fast TLB flush hypercalls (bsc#1012628).
- KVM: x86: hyper-v: HVCALL_SEND_IPI_EX is an XMM fast hypercall
  (bsc#1012628).
- powerpc/kasan: Fix early region not updated correctly
  (bsc#1012628).
- powerpc/tm: Fix more userspace r13 corruption (bsc#1012628).
- powerpc/lib/sstep: Fix 'sthcx' instruction (bsc#1012628).
- powerpc/lib/sstep: Fix build errors with newer binutils
  (bsc#1012628).
- powerpc: Add set_memory_{p/np}() and remove set_memory_attr()
  (bsc#1012628).
- powerpc: Fix build errors with newer binutils (bsc#1012628).
- drm/dp: Fix off-by-one in register cache size (bsc#1012628).
- drm/i915: Treat SAGV block time 0 as SAGV disabled
  (bsc#1012628).
- drm/i915: Fix PSF GV point mask when SAGV is not possible
  (bsc#1012628).
- drm/i915: Reject unsupported TMDS rates on ICL+ (bsc#1012628).
- scsi: qla2xxx: Refactor asynchronous command initialization
  (bsc#1012628).
- scsi: qla2xxx: Implement ref count for SRB (bsc#1012628).
- scsi: qla2xxx: Fix stuck session in gpdb (bsc#1012628).
- scsi: qla2xxx: Fix warning message due to adisc being flushed
  (bsc#1012628).
- scsi: qla2xxx: Fix scheduling while atomic (bsc#1012628).
- scsi: qla2xxx: Fix premature hw access after PCI error
  (bsc#1012628).
- scsi: qla2xxx: Fix wrong FDMI data for 64G adapter
  (bsc#1012628).
- scsi: qla2xxx: Fix warning for missing error code (bsc#1012628).
- scsi: qla2xxx: Fix device reconnect in loop topology
  (bsc#1012628).
- scsi: qla2xxx: edif: Fix clang warning (bsc#1012628).
- scsi: qla2xxx: Fix T10 PI tag escape and IP guard options for
  28XX adapters (bsc#1012628).
- scsi: qla2xxx: Add devids and conditionals for 28xx
  (bsc#1012628).
- scsi: qla2xxx: Check for firmware dump already collected
  (bsc#1012628).
- scsi: qla2xxx: Suppress a kernel complaint in qla_create_qpair()
  (bsc#1012628).
- scsi: qla2xxx: Fix disk failure to rediscover (bsc#1012628).
- scsi: qla2xxx: Fix incorrect reporting of task management
  failure (bsc#1012628).
- scsi: qla2xxx: Fix hang due to session stuck (bsc#1012628).
- scsi: qla2xxx: Fix laggy FC remote port session recovery
  (bsc#1012628).
- scsi: qla2xxx: Fix missed DMA unmap for NVMe ls requests
  (bsc#1012628).
- scsi: qla2xxx: Fix crash during module load unload test
  (bsc#1012628).
- scsi: qla2xxx: Fix N2N inconsistent PLOGI (bsc#1012628).
- scsi: qla2xxx: Fix stuck session of PRLI reject (bsc#1012628).
- scsi: qla2xxx: Reduce false trigger to login (bsc#1012628).
- scsi: qla2xxx: Use correct feature type field during RFF_ID
  processing (bsc#1012628).
- platform: chrome: Split trace include file (bsc#1012628).
- MIPS: crypto: Fix CRC32 code (bsc#1012628).
- KVM: x86: Check lapic_in_kernel() before attempting to set a
  SynIC irq (bsc#1012628).
- KVM: x86: Avoid theoretical NULL pointer dereference in
  kvm_irq_delivery_to_apic_fast() (bsc#1012628).
- KVM: x86: Forbid VMM to set SYNIC/STIMER MSRs when SynIC wasn't
  activated (bsc#1012628).
- KVM: x86/mmu: do compare-and-exchange of gPTE via the user
  address (bsc#1012628).
- KVM: Prevent module exit until all VMs are freed (bsc#1012628).
- KVM: x86: fix sending PV IPI (bsc#1012628).
- KVM: SVM: fix panic on out-of-bounds guest IRQ (bsc#1012628).
- KVM: avoid double put_page with gfn-to-pfn cache (bsc#1012628).
- ubifs: rename_whiteout: Fix double free for whiteout_ui->data
  (bsc#1012628).
- ubifs: Fix deadlock in concurrent rename whiteout and inode
  writeback (bsc#1012628).
- ubifs: Add missing iput if do_tmpfile() failed in rename
  whiteout (bsc#1012628).
- ubifs: Rename whiteout atomically (bsc#1012628).
- ubifs: Fix 'ui->dirty' race between do_tmpfile() and writeback
  work (bsc#1012628).
- ubifs: Rectify space amount budget for mkdir/tmpfile operations
  (bsc#1012628).
- ubifs: setflags: Make dirtied_ino_d 8 bytes aligned
  (bsc#1012628).
- ubifs: Fix read out-of-bounds in ubifs_wbuf_write_nolock()
  (bsc#1012628).
- ubifs: Fix to add refcount once page is set private
  (bsc#1012628).
- ubifs: rename_whiteout: correct old_dir size computing
  (bsc#1012628).
- nvme: allow duplicate NSIDs for private namespaces
  (bsc#1012628).
- nvme: fix the read-only state for zoned namespaces with
  unsupposed features (bsc#1012628).
- wireguard: queueing: use CFI-safe ptr_ring cleanup function
  (bsc#1012628).
- wireguard: socket: free skb in send6 when ipv6 is disabled
  (bsc#1012628).
- wireguard: socket: ignore v6 endpoints when ipv6 is disabled
  (bsc#1012628).
- XArray: Fix xas_create_range() when multi-order entry present
  (bsc#1012628).
- can: mcba_usb: properly check endpoint type (bsc#1012628).
- can: mcp251xfd: mcp251xfd_register_get_dev_id(): fix return
  of error value (bsc#1012628).
- XArray: Include bitmap.h from xarray.h (bsc#1012628).
- XArray: Update the LRU list in xas_split() (bsc#1012628).
- modpost: restore the warning message for missing symbol versions
  (bsc#1012628).
- rtc: gamecube: Fix refcount leak in
  gamecube_rtc_read_offset_from_sram (bsc#1012628).
- rtc: check if __rtc_read_time was successful (bsc#1012628).
- loop: fix ioctl calls using compat_loop_info (bsc#1012628).
- gfs2: gfs2_setattr_size error path fix (bsc#1012628).
- gfs2: Fix gfs2_file_buffered_write endless loop workaround
  (bsc#1012628).
- gfs2: Make sure FITRIM minlen is rounded up to fs block size
  (bsc#1012628).
- net: hns3: fix the concurrency between functions reading debugfs
  (bsc#1012628).
- net: hns3: fix software vlan talbe of vlan 0 inconsistent with
  hardware (bsc#1012628).
- rxrpc: fix some null-ptr-deref bugs in server_key.c
  (bsc#1012628).
- rxrpc: Fix call timer start racing with call destruction
  (bsc#1012628).
- mailbox: imx: fix wakeup failure from freeze mode (bsc#1012628).
- crypto: x86/poly1305 - Fixup SLS (bsc#1012628).
- crypto: arm/aes-neonbs-cbc - Select generic cbc and aes
  (bsc#1012628).
- watch_queue: Free the page array when watch_queue is dismantled
  (bsc#1012628).
- pinctrl: pinconf-generic: Print arguments for bias-pull-*
  (bsc#1012628).
- watchdog: rti-wdt: Add missing pm_runtime_disable() in probe
  function (bsc#1012628).
- net: sparx5: uses, depends on BRIDGE or !BRIDGE (bsc#1012628).
- pinctrl: nuvoton: npcm7xx: Rename DS() macro to DSTR()
  (bsc#1012628).
- pinctrl: nuvoton: npcm7xx: Use %%zu printk format for
  ARRAY_SIZE() (bsc#1012628).
- ASoC: rockchip: i2s_tdm: Fixup config for SND_SOC_DAIFMT_DSP_A/B
  (bsc#1012628).
- ASoC: mediatek: mt6358: add missing EXPORT_SYMBOLs
  (bsc#1012628).
- ubi: Fix race condition between ctrl_cdev_ioctl and
  ubi_cdev_ioctl (bsc#1012628).
- ARM: iop32x: offset IRQ numbers by 1 (bsc#1012628).
- block: Fix the maximum minor value is blk_alloc_ext_minor()
  (bsc#1012628).
- Revert "virtio-pci: harden INTX interrupts" (bsc#1012628).
- Revert "virtio_pci: harden MSI-X interrupts" (bsc#1012628).
- virtio: use virtio_device_ready() in virtio_device_restore()
  (bsc#1012628).
- io_uring: remove poll entry from list when canceling all
  (bsc#1012628).
- io_uring: bump poll refs to full 31-bits (bsc#1012628).
- io_uring: fix memory leak of uid in files registration
  (bsc#1012628).
- riscv module: remove (NOLOAD) (bsc#1012628).
- ACPI: CPPC: Avoid out of bounds access when parsing _CPC data
  (bsc#1012628).
- vhost: handle error while adding split ranges to iotlb
  (bsc#1012628).
- spi: Fix Tegra QSPI example (bsc#1012628).
- platform/chrome: cros_ec_typec: Check for EC device
  (bsc#1012628).
- platform/x86: asus-wmi: Fix regression when probing for fan
  curve control (bsc#1012628).
- can: isotp: restore accidentally removed MSG_PEEK feature
  (bsc#1012628).
- proc: bootconfig: Add null pointer check (bsc#1012628).
- x86/fpu/xstate: Fix the ARCH_REQ_XCOMP_PERM implementation
  (bsc#1012628).
- drm/connector: Fix typo in documentation (bsc#1012628).
- scsi: qla2xxx: Add qla2x00_async_done() for async routines
  (bsc#1012628).
- staging: mt7621-dts: fix pinctrl-0 items to be size-1 items
  on ethernet (bsc#1012628).
- docs: fix 'make htmldocs' warning in SCTP.rst (bsc#1012628).
- arm64: mm: Drop 'const' from conditional arm64_dma_phys_limit
  definition (bsc#1012628).
- ASoC: soc-compress: Change the check for codec_dai
  (bsc#1012628).
- KVM: x86: SVM: fix avic spec based definitions again
  (bsc#1012628).
- ax25: fix UAF bug in ax25_send_control() (bsc#1012628).
- Reinstate some of "swiotlb: rework "fix info leak with
  DMA_FROM_DEVICE"" (bsc#1012628).
- tracing: Have type enum modifications copy the strings
  (bsc#1012628).
- mips: Enable KCSAN - take 2 (bsc#1012628).
- net: add skb_set_end_offset() helper (bsc#1012628).
- mm/mmap: return 1 from stack_guard_gap __setup() handler
  (bsc#1012628).
- ARM: 9187/1: JIVE: fix return value of __setup handler
  (bsc#1012628).
- mm/memcontrol: return 1 from cgroup.memory __setup() handler
  (bsc#1012628).
- mm/usercopy: return 1 from hardened_usercopy __setup() handler
  (bsc#1012628).
- af_unix: Support POLLPRI for OOB (bsc#1012628).
- libbpf: Define BTF_KIND_* constants in btf.h to avoid
  compilation errors (bsc#1012628).
- bpf: Adjust BPF stack helper functions to accommodate skip >
  0 (bsc#1012628).
- bpf: Fix comment for helper bpf_current_task_under_cgroup()
  (bsc#1012628).
- nbd: fix possible overflow on 'first_minor' in nbd_dev_add()
  (bsc#1012628).
- mmc: rtsx: Use pm_runtime_{get,put}() to handle runtime PM
  (bsc#1012628).
- dt-bindings: mtd: nand-controller: Fix the reg property
  description (bsc#1012628).
- dt-bindings: mtd: nand-controller: Fix a comment in the examples
  (bsc#1012628).
- dt-bindings: spi: mxic: The interrupt property is not mandatory
  (bsc#1012628).
- media: dt-binding: media: hynix,hi846: use $defs/port-base
  port description (bsc#1012628).
- media: dt-bindings: media: hynix,hi846: add link-frequencies
  description (bsc#1012628).
- dt-bindings: memory: mtk-smi: Rename clock to clocks
  (bsc#1012628).
- dt-bindings: memory: mtk-smi: No need mediatek,larb-id for
  mt8167 (bsc#1012628).
- dt-bindings: memory: mtk-smi: Correct minItems to 2 for the
  gals clocks (bsc#1012628).
- dt-bindings: pinctrl: mt8195: fix bias-pull-{up,down} checks
  (bsc#1012628).
- dt-bindings: pinctrl: pinctrl-microchip-sgpio: Fix example
  (bsc#1012628).
- ubi: fastmap: Return error code if memory allocation fails in
  add_aeb() (bsc#1012628).
- net: preserve skb_end_offset() in skb_unclone_keeptruesize()
  (bsc#1012628).
- ASoC: SOF: Intel: Fix build error without SND_SOC_SOF_PCI_DEV
  (bsc#1012628).
- ASoC: topology: Allow TLV control to be either read or write
  (bsc#1012628).
- perf vendor events: Update metrics for SkyLake Server
  (bsc#1012628).
- media: ov6650: Add try support to selection API operations
  (bsc#1012628).
- media: ov6650: Fix crop rectangle affected by set format
  (bsc#1012628).
- pinctrl: canonical rsel resistance selection property
  (bsc#1012628).
- spi: mediatek: support tick_delay without enhance_timing
  (bsc#1012628).
- ARM: dts: spear1340: Update serial node properties
  (bsc#1012628).
- ARM: dts: spear13xx: Update SPI dma properties (bsc#1012628).
- arm64: dts: ls1043a: Update i2c dma properties (bsc#1012628).
- arm64: dts: ls1046a: Update i2c node dma properties
  (bsc#1012628).
- um: Fix uml_mconsole stop/go (bsc#1012628).
- docs: sysctl/kernel: add missing bit to panic_print
  (bsc#1012628).
- xsk: Do not write NULL in SW ring at allocation failure
  (bsc#1012628).
- ice: xsk: Fix indexing in ice_tx_xsk_pool() (bsc#1012628).
- vdpa/mlx5: Avoid processing works if workqueue was destroyed
  (bsc#1012628).
- openvswitch: Fixed nd target mask field in the flow dump
  (bsc#1012628).
- torture: Make torture.sh help message match reality
  (bsc#1012628).
- n64cart: convert bi_disk to bi_bdev->bd_disk fix build
  (bsc#1012628).
- Revert "nbd: fix possible overflow on 'first_minor' in
  nbd_dev_add()" (bsc#1012628).
- mmc: rtsx: Let MMC core handle runtime PM (bsc#1012628).
- mmc: rtsx: Fix build errors/warnings for unused variable
  (bsc#1012628).
- coredump: Snapshot the vmas in do_coredump (bsc#1012628).
- coredump: Remove the WARN_ON in dump_vma_snapshot (bsc#1012628).
- coredump/elf: Pass coredump_params into fill_note_info
  (bsc#1012628).
- coredump: Use the vma snapshot in fill_files_note (bsc#1012628).
- Update config files.
- commit b49cf22
* Fri Apr  8 2022 jroedel@suse.de
- x86/sev: Unroll string mmio with CC_ATTR_GUEST_UNROLL_STRING_IO
  (bsc#1196961).
- commit 18b6eb8
* Wed Apr  6 2022 bp@suse.de
- x86/speculation: Restore speculation related MSRs during S3
  resume (git-fixes).
- commit ffe3c2b
* Wed Apr  6 2022 bp@suse.de
- x86/pm: Save the MSR validity status at context setup
  (git-fixes).
- commit b756c61
* Mon Apr  4 2022 mkubecek@suse.cz
- net/fungible: Fix reference to __udivdi3 on 32b builds.
  Fix i386 build failure.
- commit 6385d80
* Mon Apr  4 2022 tiwai@suse.de
- can: mcba_usb: mcba_usb_start_xmit(): fix double dev_kfree_skb
  in error path (CVE-2022-28389 bsc#1198033).
- can: usb_8dev: usb_8dev_start_xmit(): fix double dev_kfree_skb()
  in error path (CVE-2022-28388 bsc#1198032).
- can: ems_usb: ems_usb_start_xmit(): fix double dev_kfree_skb()
  in error path (CVE-2022-28390 bsc#1198031).
- commit e456953
* Mon Apr  4 2022 mkubecek@suse.cz
- Update to 5.18-rc1
- eliminate 47 patches (42 stable, 5 mainline)
  - patches.kernel.org/*
  - patches.suse/Bluetooth-btusb-Add-missing-Chicony-device-for-Realt.patch
  - patches.suse/Revert-Input-clear-BTN_RIGHT-MIDDLE-on-buttonpads.patch
  - patches.suse/Revert-swiotlb-rework-fix-info-leak-with-DMA_FROM_DE.patch
  - patches.suse/block-restore-the-old-set_task_ioprio-behaviour-wrt-.patch
  - patches.suse/bpf-add-config-to-allow-loading-modules-with-BTF-mis.patch
- refresh
  - patches.suse/s390-export-symbols-for-crash-kmp.patch
  - patches.suse/vfs-add-super_operations-get_inode_dev
- disable ARM architectures (need config update)
- new config options
  - General setup
    CLOCKSOURCE_WATCHDOG_MAX_SKEW_US=100
  - Processor type and features
    X86_KERNEL_IBT=n
  - Binary Emulations
    X86_X32_ABI=n (renamed X86_X32)
  - General architecture-dependent options
    RANDOMIZE_KSTACK_OFFSET=y
  - Enable the block layer
    BLOCK_LEGACY_AUTOLOAD=y
  - Networking support
    PAGE_POOL_STATS=n
  - File systems
    F2FS_UNFAIR_RWSEM=n
  - Security options
    USER_DECRYPTED_DATA=n
  - Cryptographic API
    CRYPTO_DH_RFC7919_GROUPS=y
    CRYPTO_SM3_AVX_X86_64=m
  - Kernel hacking
    DEBUG_INFO_NONE=n
    DEBUG_INFO_DWARF5=n
    KFENCE_DEFERRABLE=n
    FPROBE=y
  - PCI support
    CXL_PCI=m
  - NVME Support
    NVME_VERBOSE_ERRORS=n
  - Serial ATA and Parallel ATA drivers (libata)
    SATA_LPM_POLICY=0
  - Network device support
    NET_DSA_REALTEK=m
    NET_VENDOR_DAVICOM=y
    DM9051=m
    NET_VENDOR_FUNGIBLE=y
    FUN_ETH=m
    MT7921U=m
  - Input device support
    TOUCHSCREEN_IMAGIS=m
  - Power supply class support
    IP5XXX_POWER=m
    BATTERY_SAMSUNG_SDI=n
    BATTERY_UG3105=m
  - Hardware Monitoring support
    I8K=n
    SENSORS_LM25066_REGULATOR=y
    SENSORS_PLI1209BC=m
    SENSORS_PLI1209BC_REGULATOR=y
    SENSORS_XDPE122_REGULATOR=y
    SENSORS_SY7636A=m
    SENSORS_TMP464=m
    SENSORS_ASUS_EC=m
  - Voltage and Current Regulator Support
    REGULATOR_RT5190A=m
    REGULATOR_SY7636A=m
  - Multimedia support
    VIDEO_HI847=m
    VIDEO_OG01A1B=m
    VIDEO_OV08D10=m
  - Graphics support
    DRM_PANEL_MIPI_DBI=m
    DRM_SSD130X=n
  - Sound card support
    SND_SOC_AMD_ACP_PCI=m
    SND_SOC_INTEL_AVS=m
    SND_SOC_INTEL_SOF_SSP_AMP_MACH=m
    SND_SOC_AW8738=n
    SND_SOC_TAS5805M=n
  - HID support
    HID_RAZER=m
    HID_SIGMAMICRO=m
  - USB support
    TYPEC_RT1719=m
    TYPEC_WUSB3801=m
  - Staging drivers
    VIDEO_ZORAN_DC30=y
    VIDEO_ZORAN_ZR36060=y
    VIDEO_ZORAN_BUZ=y
    VIDEO_ZORAN_DC10=y
    VIDEO_ZORAN_LML33=y
    VIDEO_ZORAN_LML33R10=y
    VIDEO_ZORAN_AVS6EYES=y
  - X86 Platform Specific Device Drivers
    AMD_HSMP=m
    INTEL_CHTWC_INT33FE=m
    INTEL_SDSI=m
    SERIAL_MULTI_INSTANTIATE=m
  - Industrial I/O support
    ADXL367_SPI=n
    ADXL367_I2C=n
    ADA4250=n
    LTC2688=n
    ADMV1014=n
    ADMV4420=n
    SX9324=n
    SX9360=n
    PECI=n
    PECI=n
  - Misc drivers
    MTD_NAND_ECC_MXIC=n
    I2C_DESIGNWARE_AMDPSP=y
    SPI_INTEL_PCI=m
    SPI_INTEL_PLATFORM=m
    INTEL_HFI_THERMAL=y
    MFD_SIMPLE_MFD_I2C=n
    MLX5_VFIO_PCI=m
    VMGENID=y
    CHROMEOS_PRIVACY_SCREEN=m
    RPMSG_CTRL=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - OPEN_DICE=m
  - MFD_MAX77714=n
  - REGULATOR_TPS6286X=m
  - VIDEO_ISL7998X=m
  - DRM_PANEL_ILITEK_ILI9341=n
  - DRM_PANEL_NOVATEK_NT35560=n
  - DRM_ITE_IT6505=n
  - COMMON_CLK_RS9_PCIE=m
  - PHY_CADENCE_DPHY_RX=m
  - i586
  - DTPM_DEVFREQ=y
  - INTEGRITY_MACHINE_KEYRING=y
  - ppc64 / ppc64le
  - NET_DSA_REALTEK_MDIO=m
  - NET_DSA_REALTEK_RTL8365MB=m
  - NET_DSA_REALTEK_RTL8366RB=m
  - MCTP_TRANSPORT_I2C=m
  - CRC64_ROCKSOFT=m
  - s390x
  - EXPOLINE_EXTERN=y
  - CRC64_ROCKSOFT=m
  - riscv64
  - RSEQ=y
  - DEBUG_RSEQ=n
  - CPU_IDLE=y
  - CPU_IDLE_GOV_LADDER=y
  - CPU_IDLE_GOV_TEO=y
  - RISCV_SBI_CPUIDLE=y
  - CPU_IDLE_GOV_MENU=y
  - PARPORT_PC=m
  - PARPORT_SERIAL=m
  - PARPORT_PC_FIFO=y
  - PARPORT_PC_PCMCIA=n
  - PARIDE=m
  - PARIDE_*=m (PARIDE_EPATC8=y
  - SCSI_PPA=m
  - SCSI_IMM=m
  - SCSI_IZIP_EPP16=n
  - SCSI_IZIP_SLOW_CTR=n
  - NET_DSA_REALTEK_MDIO=m
  - NET_DSA_REALTEK_RTL8365MB=m
  - NET_DSA_REALTEK_RTL8366RB=m
  - KS0108=n
  - CLK_STARFIVE_JH7100_AUDIO=m
  - POLARFIRE_SOC_SYS_CTRL=m
  - IDLE_INJECT=y
  - RISCV_PMU=y
  - RISCV_PMU_LEGACY=y
  - RISCV_PMU_SBI=y
  - CPU_IDLE_THERMAL=y
- commit e499f10
* Sun Apr  3 2022 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  - patches.suse/Revert-Input-clear-BTN_RIGHT-MIDDLE-on-buttonpads.patch
  - patches.suse/block-restore-the-old-set_task_ioprio-behaviour-wrt-.patch
- commit 6038bd3
* Thu Mar 31 2022 mkubecek@suse.cz
- Revert "config: Enable BPF LSM" (bsc#1197746)
  This reverts commit c2c25b18721866d6211054f542987036ed6e0a50.
  This config change was reported to break boot if SELinux is enabled. Revert
  until we have a fix.
- commit 0a20128
* Thu Mar 31 2022 jslaby@suse.cz
- Revert "config: Enable BPF LSM" (bsc#1197746)
  This reverts commit c2c25b18721866d6211054f542987036ed6e0a50.
- commit 58205bc
* Wed Mar 30 2022 msuchanek@suse.de
- Refresh patches.rpmify/powerpc-64-BE-option-to-use-ELFv2-ABI-for-big-endian.patch.
- Refresh config files.
- commit bd4767f
* Tue Mar 29 2022 jslaby@suse.cz
- Refresh
  patches.suse/block-restore-the-old-set_task_ioprio-behaviour-wrt-.patch.
  Update to upstream version.
- commit eed8aee
* Mon Mar 28 2022 tiwai@suse.de
- Revert "swiotlb: rework "fix info leak with DMA_FROM_DEVICE""
  (bsc#1197460).
- commit ffd9dce
* Mon Mar 28 2022 jslaby@suse.cz
- block: restore the old set_task_ioprio() behaviour wrt
  PF_EXITING (bsc#1197582).
- commit c349fed
* Mon Mar 28 2022 jslaby@suse.cz
- Linux 5.17.1 (bsc#1012628).
- llc: only change llc->dev when bind() succeeds (bsc#1012628).
- drm/msm/gpu: Fix crash on devices without devfreq support (v2)
  (bsc#1012628).
- nds32: fix access_ok() checks in get/put_user (bsc#1012628).
- m68k: fix access_ok for coldfire (bsc#1012628).
- wcn36xx: Differentiate wcn3660 from wcn3620 (bsc#1012628).
- tpm: use try_get_ops() in tpm-space.c (bsc#1012628).
- tpm: fix reference counting for struct tpm_chip (bsc#1012628).
- mac80211: fix potential double free on mesh join (bsc#1012628).
- uaccess: fix integer overflow on access_ok() (bsc#1012628).
- rcu: Don't deboost before reporting expedited quiescent state
  (bsc#1012628).
- jbd2: fix use-after-free of transaction_t race (bsc#1012628).
- drm/virtio: Ensure that objs is not NULL in
  virtio_gpu_array_put_free() (bsc#1012628).
- Revert "ath: add support for special 0x0 regulatory domain"
  (bsc#1012628).
- Bluetooth: btusb: Use quirk to skip HCI_FLT_CLEAR_ALL on fake
  CSR controllers (bsc#1012628).
- Bluetooth: hci_sync: Add a new quirk to skip HCI_FLT_CLEAR_ALL
  (bsc#1012628).
- Bluetooth: btusb: Add one more Bluetooth part for the Realtek
  RTL8852AE (bsc#1012628).
- crypto: qat - disable registration of algorithms (bsc#1012628).
- ACPI: video: Force backlight native for Clevo NL5xRU and NL5xNU
  (bsc#1012628).
- ACPI: battery: Add device HID and quirk for Microsoft Surface
  Go 3 (bsc#1012628).
- ACPI / x86: Work around broken XSDT on Advantech DAC-BJ01 board
  (bsc#1012628).
- netfilter: nf_tables: validate registers coming from userspace
  (bsc#1012628).
- netfilter: nf_tables: initialize registers in nft_do_chain()
  (bsc#1012628).
- drivers: net: xgene: Fix regression in CRC stripping
  (bsc#1012628).
- ALSA: pci: fix reading of swapped values from pcmreg in AC97
  codec (bsc#1012628).
- ALSA: cmipci: Restore aux vol on suspend/resume (bsc#1012628).
- ALSA: usb-audio: Add mute TLV for playback volumes on RODE
  NT-USB (bsc#1012628).
- ALSA: pcm: Add stream lock during PCM reset ioctl operations
  (bsc#1012628).
- ALSA: pcm: Fix races among concurrent prealloc proc writes
  (bsc#1012628).
- ALSA: pcm: Fix races among concurrent prepare and
  hw_params/hw_free calls (bsc#1012628).
- ALSA: pcm: Fix races among concurrent read/write and buffer
  changes (bsc#1012628).
- ALSA: pcm: Fix races among concurrent hw_params and hw_free
  calls (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ASUS GA402 (bsc#1012628).
- ALSA: hda/realtek - Fix headset mic problem for a HP machine
  with alc671 (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Clevo NP50PNJ (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Clevo NP70PNJ (bsc#1012628).
- ALSA: usb-audio: add mapping for new Corsair Virtuoso SE
  (bsc#1012628).
- ALSA: oss: Fix PCM OSS buffer allocation overflow (bsc#1012628).
- ASoC: sti: Fix deadlock via snd_pcm_stop_xrun() call
  (bsc#1012628).
- llc: fix netdevice reference leaks in llc_ui_bind()
  (bsc#1012628).
- Bluetooth: btusb: Add another Realtek 8761BU (bsc#1012628).
- tpm: Fix error handling in async work (bsc#1012628).
- commit e830013
* Fri Mar 25 2022 mkubecek@suse.cz
- series.conf: cleanup
- update mainline references and move into sorted section:
  - patches.suse/Bluetooth-btusb-Add-missing-Chicony-device-for-Realt.patch
  - patches.suse/bpf-add-config-to-allow-loading-modules-with-BTF-mis.patch
- commit 62d2682
* Fri Mar 25 2022 tiwai@suse.de
- Revert "Input: clear BTN_RIGHT/MIDDLE on buttonpads"
  (bsc#1197243).
- commit 7257225
* Fri Mar 25 2022 tiwai@suse.de
- Drop HID multitouch fix patch (bsc#1197243)
  Delete patches.suse/HID-multitouch-fix-Dell-Precision-7550-and-7750-butt.patch.
  Replaced with another revert patch.
- commit 01821ca
* Mon Mar 21 2022 dmueller@suse.com
- rpm/constraints.in: skip SLOW_DISK workers for kernel-source
- commit e84694f
* Mon Mar 21 2022 msuchanek@suse.de
- Revert "rpm/macros.kernel-source: avoid %%if's and %%define's"
  This reverts commit d0cec50d019c853336e26f5ff5df5a4c9c3ea120.
- commit b20736a
* Mon Mar 21 2022 msuchanek@suse.de
- macros.kernel-source: Fix conditional expansion.
  Fixes: bb95fef3cf19 ("rpm: Use bash for %%() expansion (jsc#SLE-18234).")
- commit 7e857f7
* Mon Mar 21 2022 jslaby@suse.cz
- rpm/macros.kernel-source: avoid %%if's and %%define's
  It's not supported in rpm macros scripts. So for now, resolve
  %%kernel_build_shell_package to bash-sh in stable branch unconditionally.
  When this is fixed in the packaging branch, revert this.
- commit d0cec50
* Mon Mar 21 2022 jslaby@suse.cz
- Refresh
  patches.suse/Bluetooth-btusb-Add-missing-Chicony-device-for-Realt.patch.
  Update upstream status.
- commit 36a1351
* Sun Mar 20 2022 mkubecek@suse.cz
- Update to 5.17 final
- refresh configs (headers only)
- commit be2cbd1
* Sat Mar 19 2022 msuchanek@suse.de
- rpm: Use bash for %%() expansion (jsc#SLE-18234).
  Since 15.4 alternatives for /bin/sh are provided by packages
  <something>-sh. While the interpreter for the build script can be
  selected the interpreter for %%() cannot.
  The kernel spec files use bashisms in %%().
  While this could technically be fixed there is more serious underlying
  problem: neither bash nor any of the alternatives are 100%% POSIX
  compliant nor bug-free.
  It is not my intent to maintain bug compatibility with any number of
  shells for shell scripts embedded in the kernel spec file. The spec file
  syntax is not documented so embedding the shell script in it causes some
  unspecified transformation to be applied to it. That means that
  ultimately any changes must be tested by building the kernel, n times if
  n shells are supported.
  To reduce maintenance effort require that bash is used for kernel build
  always.
- commit bb95fef
* Sat Mar 19 2022 jslaby@suse.cz
- Linux 5.16.16 (bsc#1012628).
- ice: Fix race condition during interface enslave (bsc#1012628).
- kselftest/vm: fix tests build with old libc (bsc#1012628).
- bnx2: Fix an error message (bsc#1012628).
- sfc: extend the locking on mcdi->seqno (bsc#1012628).
- tcp: make tcp_read_sock() more robust (bsc#1012628).
- nl80211: Update bss channel on channel switch for P2P_CLIENT
  (bsc#1012628).
- drm/vrr: Set VRR capable prop only if it is attached to
  connector (bsc#1012628).
- iwlwifi: don't advertise TWT support (bsc#1012628).
- Input: goodix - workaround Cherry Trail devices with a bogus
  ACPI Interrupt() resource (bsc#1012628).
- Input: goodix - use the new soc_intel_is_byt() helper
  (bsc#1012628).
- netfilter: egress: silence egress hook lockdep splats
  (bsc#1012628).
- atm: firestream: check the return value of ioremap() in
  fs_init() (bsc#1012628).
- can: rcar_canfd: rcar_canfd_channel_probe(): register the CAN
  device when fully ready (bsc#1012628).
- Bluetooth: hci_core: Fix leaking sent_cmd skb (bsc#1012628).
- ARM: 9178/1: fix unmet dependency on BITREVERSE for
  HAVE_ARCH_BITREVERSE (bsc#1012628).
- MIPS: smp: fill in sibling and core maps earlier (bsc#1012628).
- mac80211: refuse aggregations sessions before authorized
  (bsc#1012628).
- ARM: dts: rockchip: fix a typo on rk3288 crypto-controller
  (bsc#1012628).
- ARM: dts: rockchip: reorder rk322x hmdi clocks (bsc#1012628).
- arm64: dts: agilex: use the compatible
  "intel,socfpga-agilex-hsotg" (bsc#1012628).
- arm64: dts: rockchip: reorder rk3399 hdmi clocks (bsc#1012628).
- arm64: dts: rockchip: align pl330 node name with dtschema
  (bsc#1012628).
- arm64: dts: rockchip: fix rk3399-puma eMMC HS400 signal
  integrity (bsc#1012628).
- xfrm: Fix xfrm migrate issues when address family changes
  (bsc#1012628).
- xfrm: Check if_id in xfrm_migrate (bsc#1012628).
- arm64: dts: rockchip: fix rk3399-puma-haikou USB OTG mode
  (bsc#1012628).
- arm64: dts: rockchip: fix dma-controller node names on rk356x
  (bsc#1012628).
- Revert "xfrm: state and policy should fail if XFRMA_IF_ID 0"
  (bsc#1012628).
- commit d9656de
* Sat Mar 19 2022 tiwai@suse.de
- HID: multitouch: fix Dell Precision 7550 and 7750 button type
  (bsc#1197243).
- commit 5500e44
* Fri Mar 18 2022 neilb@suse.de
- Disable 5.16.10-026-NFSv4.1-query-for-fs_location-attr-on-a-new-f.patch (boo#1196521)
  This patch causes a regression and probably should not have been
  backported to stable anyway.  Disable it.
  Links to upstream discussions in the bug.
- commit 40a4b1d
* Wed Mar 16 2022 jslaby@suse.cz
- Linux 5.16.15 (bsc#1012628).
- arm64: dts: qcom: sm8350: Describe GCC dependency clocks
  (bsc#1012628).
- arm64: dts: qcom: sm8350: Correct UFS symbol clocks
  (bsc#1012628).
- HID: elo: Revert USB reference counting (bsc#1012628).
- HID: hid-thrustmaster: fix OOB read in thrustmaster_interrupts
  (bsc#1012628).
- ARM: boot: dts: bcm2711: Fix HVS register range (bsc#1012628).
- clk: qcom: gdsc: Add support to update GDSC transition delay
  (bsc#1012628).
- clk: qcom: dispcc: Update the transition delay for MDSS GDSC
  (bsc#1012628).
- soc: mediatek: mt8192-mmsys: Fix dither to dsi0 path's input
  sel (bsc#1012628).
- HID: vivaldi: fix sysfs attributes leak (bsc#1012628).
- HID: nintendo: check the return value of alloc_workqueue()
  (bsc#1012628).
- arm64: dts: armada-3720-turris-mox: Add missing ethernet0 alias
  (bsc#1012628).
- tipc: fix kernel panic when enabling bearer (bsc#1012628).
- vdpa/mlx5: add validation for VIRTIO_NET_CTRL_MQ_VQ_PAIRS_SET
  command (bsc#1012628).
- vduse: Fix returning wrong type in vduse_domain_alloc_iova()
  (bsc#1012628).
- net: phy: meson-gxl: fix interrupt handling in forced mode
  (bsc#1012628).
- mISDN: Fix memory leak in dsp_pipeline_build() (bsc#1012628).
- vhost: fix hung thread due to erroneous iotlb entries
  (bsc#1012628).
- virtio-blk: Don't use MAX_DISCARD_SEGMENTS if max_discard_seg
  is zero (bsc#1012628).
- virtio-blk: Remove BUG_ON() in virtio_queue_rq() (bsc#1012628).
- vdpa: fix use-after-free on vp_vdpa_remove (bsc#1012628).
- isdn: hfcpci: check the return value of dma_set_mask() in
  setup_hw() (bsc#1012628).
- net: qlogic: check the return value of dma_alloc_coherent()
  in qed_vf_hw_prepare() (bsc#1012628).
- esp: Fix BEET mode inter address family tunneling on GSO
  (bsc#1012628).
- net: gro: move skb_gro_receive_list to udp_offload.c
  (bsc#1012628).
- qed: return status of qed_iov_get_link (bsc#1012628).
- smsc95xx: Ignore -ENODEV errors when device is unplugged
  (bsc#1012628).
- gpiolib: acpi: Convert ACPI value of debounce to microseconds
  (bsc#1012628).
- drm/i915/psr: Set "SF Partial Frame Enable" also on full update
  (bsc#1012628).
- drm/sun4i: mixer: Fix P010 and P210 format numbers
  (bsc#1012628).
- net: dsa: mt7530: fix incorrect test in
  mt753x_phylink_validate() (bsc#1012628).
- ARM: dts: aspeed: Fix AST2600 quad spi group (bsc#1012628).
- iavf: Fix handling of vlan strip virtual channel messages
  (bsc#1012628).
- i40e: stop disabling VFs due to PF error responses
  (bsc#1012628).
- ice: stop disabling VFs due to PF error responses (bsc#1012628).
- ice: Fix error with handling of bonding MTU (bsc#1012628).
- ice: Don't use GFP_KERNEL in atomic context (bsc#1012628).
- ice: Fix curr_link_speed advertised speed (bsc#1012628).
- ethernet: Fix error handling in xemaclite_of_probe
  (bsc#1012628).
- tipc: fix incorrect order of state message data sanity check
  (bsc#1012628).
- net: ethernet: ti: cpts: Handle error for clk_enable
  (bsc#1012628).
- net: ethernet: lpc_eth: Handle error for clk_enable
  (bsc#1012628).
- net: marvell: prestera: Add missing of_node_put() in
  prestera_switch_set_base_mac_addr (bsc#1012628).
- ax25: Fix NULL pointer dereference in ax25_kill_by_device
  (bsc#1012628).
- net/mlx5: Fix size field in bufferx_reg struct (bsc#1012628).
- net/mlx5: Fix a race on command flush flow (bsc#1012628).
- net/mlx5e: Lag, Only handle events from highest priority
  multipath entry (bsc#1012628).
- net/mlx5e: SHAMPO, reduce TIR indication (bsc#1012628).
- NFC: port100: fix use-after-free in port100_send_complete
  (bsc#1012628).
- selftests: pmtu.sh: Kill tcpdump processes launched by subshell
  (bsc#1012628).
- selftests: pmtu.sh: Kill nettest processes launched in subshell
  (bsc#1012628).
- gpio: ts4900: Do not set DAT and OE together (bsc#1012628).
- mm: gup: make fault_in_safe_writeable() use fixup_user_fault()
  (bsc#1012628).
- gianfar: ethtool: Fix refcount leak in gfar_get_ts_info
  (bsc#1012628).
- net: phy: DP83822: clear MISR2 register to disable interrupts
  (bsc#1012628).
- sctp: fix kernel-infoleak for SCTP sockets (bsc#1012628).
- net: arc_emac: Fix use after free in arc_mdio_probe()
  (bsc#1012628).
- net: bcmgenet: Don't claim WOL when its not available
  (bsc#1012628).
- net: phy: meson-gxl: improve link-up behavior (bsc#1012628).
- selftests/bpf: Add test for bpf_timer overwriting crash
  (bsc#1012628).
- swiotlb: fix info leak with DMA_FROM_DEVICE (bsc#1012628).
- usb: dwc3: pci: add support for the Intel Raptor Lake-S
  (bsc#1012628).
- pinctrl: tigerlake: Revert "Add Alder Lake-M ACPI ID"
  (bsc#1012628).
- KVM: Fix lockdep false negative during host resume
  (bsc#1012628).
- kvm: x86: Disable KVM_HC_CLOCK_PAIRING if tsc is in always
  catchup mode (bsc#1012628).
- spi: rockchip: Fix error in getting num-cs property
  (bsc#1012628).
- spi: rockchip: terminate dma transmission when slave abort
  (bsc#1012628).
- drm/vc4: hdmi: Unregister codec device on unbind (bsc#1012628).
- of/fdt: move elfcorehdr reservation early for crash dump kernel
  (bsc#1012628).
- x86/kvm: Don't use pv tlb/ipi/sched_yield if on 1 vCPU
  (bsc#1012628).
- drivers: hamradio: 6pack: fix UAF bug caused by mod_timer()
  (bsc#1012628).
- net-sysfs: add check for netdevice being present to speed_show
  (bsc#1012628).
- hwmon: (pmbus) Clear pmbus fault/warning bits after read
  (bsc#1012628).
- nvme-tcp: send H2CData PDUs based on MAXH2CDATA (bsc#1012628).
- PCI: Mark all AMD Navi10 and Navi14 GPU ATS as broken
  (bsc#1012628).
- gpio: Return EPROBE_DEFER if gc->to_irq is NULL (bsc#1012628).
- drm/amdgpu: bypass tiling flag check in virtual display case
  (v2) (bsc#1012628).
- Revert "xen-netback: remove 'hotplug-status' once it has served
  its purpose" (bsc#1012628).
- Revert "xen-netback: Check for hotplug-status existence before
  watching" (bsc#1012628).
- ipv6: prevent a possible race condition with lifetimes
  (bsc#1012628).
- tracing: Ensure trace buffer is at least 4096 bytes large
  (bsc#1012628).
- tracing/osnoise: Make osnoise_main to sleep for microseconds
  (bsc#1012628).
- tracing: Fix selftest config check for function graph start
  up test (bsc#1012628).
- selftest/vm: fix map_fixed_noreplace test failure (bsc#1012628).
- selftests/memfd: clean up mapping in mfd_fail_write
  (bsc#1012628).
- ARM: Spectre-BHB: provide empty stub for non-config
  (bsc#1012628).
- fuse: fix fileattr op failure (bsc#1012628).
- fuse: fix pipe buffer lifetime for direct_io (bsc#1012628).
- staging: rtl8723bs: Fix access-point mode deadlock
  (bsc#1012628).
- staging: gdm724x: fix use after free in gdm_lte_rx()
  (bsc#1012628).
- net: macb: Fix lost RX packet wakeup race in NAPI receive
  (bsc#1012628).
- riscv: alternative only works on !XIP_KERNEL (bsc#1012628).
- mmc: meson: Fix usage of meson_mmc_post_req() (bsc#1012628).
- riscv: Fix auipc+jalr relocation range checks (bsc#1012628).
- tracing/osnoise: Force quiescent states while tracing
  (bsc#1012628).
- tracing/osnoise: Do not unregister events twice (bsc#1012628).
- arm64: dts: marvell: armada-37xx: Remap IO space to bus address
  0x0 (bsc#1012628).
- arm64: Ensure execute-only permissions are not allowed without
  EPAN (bsc#1012628).
- arm64: kasan: fix include error in MTE functions (bsc#1012628).
- swiotlb: rework "fix info leak with DMA_FROM_DEVICE"
  (bsc#1012628).
- virtio: unexport virtio_finalize_features (bsc#1012628).
- virtio: acknowledge all features before access (bsc#1012628).
- net/mlx5: Fix offloading with ESWITCH_IPV4_TTL_MODIFY_ENABLE
  (bsc#1012628).
- ARM: fix Thumb2 regression with Spectre BHB (bsc#1012628).
- watch_queue: Fix filter limit check (bsc#1012628).
- watch_queue, pipe: Free watchqueue state after clearing pipe
  ring (bsc#1012628).
- watch_queue: Fix to release page in ->release() (bsc#1012628).
- watch_queue: Fix to always request a pow-of-2 pipe ring size
  (bsc#1012628).
- watch_queue: Fix the alloc bitmap size to reflect notes
  allocated (bsc#1012628).
- watch_queue: Free the alloc bitmap when the watch_queue is
  torn down (bsc#1012628).
- watch_queue: Fix lack of barrier/sync/lock between post and read
  (bsc#1012628).
- watch_queue: Make comment about setting ->defunct more accurate
  (bsc#1012628).
- x86/boot: Fix memremap of setup_indirect structures
  (bsc#1012628).
- x86/boot: Add setup_indirect support in
  early_memremap_is_setup_data() (bsc#1012628).
- x86/module: Fix the paravirt vs alternative order (bsc#1012628).
- x86/sgx: Free backing memory after faulting the enclave page
  (bsc#1012628).
- x86/traps: Mark do_int3() NOKPROBE_SYMBOL (bsc#1012628).
- drm/panel: Select DRM_DP_HELPER for DRM_PANEL_EDP (bsc#1012628).
- perf parse: Fix event parser error for hybrid systems
  (bsc#1012628).
- btrfs: make send work with concurrent block group relocation
  (bsc#1012628).
- riscv: dts: k210: fix broken IRQs on hart1 (bsc#1012628).
- vhost: allow batching hint without size (bsc#1012628).
- commit 2bd8d63
* Wed Mar 16 2022 ailiop@suse.com
- config: enable XFS_RT (bsc#1197190)
- commit 253c423
* Wed Mar 16 2022 msuchanek@suse.de
- rpm: Run external scriptlets on uninstall only when available
  (bsc#1196514 bsc#1196114 bsc#1196942).
  When dependency cycles are encountered package dependencies may not be
  fulfilled during zypper transaction at the time scriptlets are run.
  This is a problem for kernel scriptlets provided by suse-module-tools
  when migrating to a SLE release that provides these scriptlets only as
  part of LTSS. The suse-module-tools that provides kernel scriptlets may
  be removed early causing migration to fail.
- commit ab8dd2d
* Wed Mar 16 2022 dmueller@suse.com
- rpm/*.spec.in: remove backtick usage
- commit 87ca1fb
* Wed Mar 16 2022 msuchanek@suse.de
- rpm: SC2006: Use $(...) notation instead of legacy backticked `...`.
- commit f0d0e90
* Tue Mar 15 2022 mkubecek@suse.cz
- esp: Fix possible buffer overflow in ESP transformation
  (CVE-2022-0886 bsc#1197131).
- commit f5ed8a3
* Tue Mar 15 2022 dmueller@suse.com
- rpm/kernel-source.spec.in: call fdupes per subpackage
  It is a waste of time to do a global fdupes when we have
  subpackages.
- commit 1da8439
* Mon Mar 14 2022 dmueller@suse.com
- Revert "- rpm/fdupes_relink: dups linking implementation in perl (bsc#1195709)"
  This has been fixed in fdupes directly, and is no longer necessary. Plus
  this causes conflicts with packaging branch, where this should have
  landed.
  This reverts commit 359854d6ca73269851c604addecdd247d01dfbf0.
- commit d0317f8
* Mon Mar 14 2022 mkubecek@suse.cz
- Update to 5.17-rc8
- update configs
  - arm64
  - MITIGATE_SPECTRE_BRANCH_HISTORY=y
  - armv7hl
  - HARDEN_BRANCH_HISTORY=y
- commit 9555b2a
* Fri Mar 11 2022 jslaby@suse.cz
- Linux 5.16.14 (bsc#1012628).
- Revert "ACPI: PM: s2idle: Cancel wakeup before dispatching EC
  GPE" (bsc#1012628).
- xen/netfront: react properly to failing
  gnttab_end_foreign_access_ref() (bsc#1012628).
- xen/gnttab: fix gnttab_end_foreign_access() without page
  specified (bsc#1012628).
- xen/pvcalls: use alloc/free_pages_exact() (bsc#1012628).
- xen/9p: use alloc/free_pages_exact() (bsc#1012628).
- xen: remove gnttab_query_foreign_access() (bsc#1012628).
- xen/gntalloc: don't use gnttab_query_foreign_access()
  (bsc#1012628).
- xen/scsifront: don't use gnttab_query_foreign_access() for
  mapped status (bsc#1012628).
- xen/netfront: don't use gnttab_query_foreign_access() for
  mapped status (bsc#1012628).
- xen/blkfront: don't use gnttab_query_foreign_access() for
  mapped status (bsc#1012628).
- xen/grant-table: add gnttab_try_end_foreign_access()
  (bsc#1012628).
- xen/xenbus: don't let xenbus_grant_ring() remove grants in
  error case (bsc#1012628).
- ARM: fix build warning in proc-v7-bugs.c (bsc#1012628).
- arm64: Do not include __READ_ONCE() block in assembly files
  (bsc#1012628).
- ARM: Do not use NOCROSSREFS directive with ld.lld (bsc#1012628).
- ARM: fix co-processor register typo (bsc#1012628).
- ARM: fix build error when BPF_SYSCALL is disabled (bsc#1012628).
- arm64: proton-pack: Include unprivileged eBPF status in Spectre
  v2 mitigation reporting (bsc#1012628).
- arm64: Use the clearbhb instruction in mitigations
  (bsc#1012628).
- KVM: arm64: Allow SMCCC_ARCH_WORKAROUND_3 to be discovered
  and migrated (bsc#1012628).
- arm64: Mitigate spectre style branch history side channels
  (bsc#1012628).
- Update config files.
- arm64: proton-pack: Report Spectre-BHB vulnerabilities as part
  of Spectre-v2 (bsc#1012628).
- arm64: Add percpu vectors for EL1 (bsc#1012628).
- arm64: entry: Add macro for reading symbol addresses from the
  trampoline (bsc#1012628).
- arm64: entry: Add vectors that have the bhb mitigation sequences
  (bsc#1012628).
- arm64: entry: Add non-kpti __bp_harden_el1_vectors for
  mitigations (bsc#1012628).
- arm64: entry: Allow the trampoline text to occupy multiple pages
  (bsc#1012628).
- arm64: entry: Make the kpti trampoline's kpti sequence optional
  (bsc#1012628).
- arm64: entry: Move trampoline macros out of ifdef'd section
  (bsc#1012628).
- arm64: entry: Don't assume tramp_vectors is the start of the
  vectors (bsc#1012628).
- arm64: entry: Allow tramp_alias to access symbols after the
  4K boundary (bsc#1012628).
- arm64: entry: Move the trampoline data page before the text page
  (bsc#1012628).
- arm64: entry: Free up another register on kpti's tramp_exit path
  (bsc#1012628).
- arm64: entry: Make the trampoline cleanup optional
  (bsc#1012628).
- KVM: arm64: Allow indirect vectors to be used without
  SPECTRE_V3A (bsc#1012628).
- arm64: spectre: Rename spectre_v4_patch_fw_mitigation_conduit
  (bsc#1012628).
- arm64: entry.S: Add ventry overflow sanity checks (bsc#1012628).
- arm64: cpufeature: add HWCAP for FEAT_RPRES (bsc#1012628).
- arm64: cpufeature: add HWCAP for FEAT_AFP (bsc#1012628).
- arm64: add ID_AA64ISAR2_EL1 sys register (bsc#1012628).
- ARM: include unprivileged BPF status in Spectre V2 reporting
  (bsc#1012628).
- ARM: Spectre-BHB workaround (bsc#1012628).
- Update config files.
- ARM: use LOADADDR() to get load address of sections
  (bsc#1012628).
- ARM: early traps initialisation (bsc#1012628).
- ARM: report Spectre v2 status through sysfs (bsc#1012628).
- Update config files.
- x86/speculation: Warn about eIBRS + LFENCE + Unprivileged eBPF +
  SMT (bsc#1012628).
- x86/speculation: Warn about Spectre v2 LFENCE mitigation
  (bsc#1012628).
- x86/speculation: Update link to AMD speculation whitepaper
  (bsc#1012628).
- x86/speculation: Use generic retpoline by default on AMD
  (bsc#1012628).
- x86/speculation: Include unprivileged eBPF status in Spectre
  v2 mitigation reporting (bsc#1012628).
- Documentation/hw-vuln: Update spectre doc (bsc#1012628).
- x86/speculation: Add eIBRS + Retpoline options (bsc#1012628).
- x86/speculation: Rename RETPOLINE_AMD to RETPOLINE_LFENCE
  (bsc#1012628).
- commit 80acc65
* Thu Mar 10 2022 dmueller@suse.com
- rpm/arch-symbols,guards,*driver: Replace Novell with SUSE.
- commit 174a64f
* Thu Mar 10 2022 dmueller@suse.com
- rpm/kernel-docs.spec.in: use %%%%license for license declarations
  Limited to SLE15+ to avoid compatibility nightmares.
- commit 73d560e
* Wed Mar  9 2022 dmueller@suse.com
- rpm/*.spec.in: Use https:// urls
- commit 77b5f8e
* Wed Mar  9 2022 tiwai@suse.de
- Bluetooth: btusb: Add missing Chicony device for Realtek
  RTL8723BE (bsc#1196779).
- commit 47faa85
* Tue Mar  8 2022 jslaby@suse.cz
- Linux 5.16.13 (bsc#1012628).
- mac80211_hwsim: report NOACK frames in tx_status (bsc#1012628).
- mac80211_hwsim: initialize ieee80211_tx_info at hw_scan_work
  (bsc#1012628).
- i2c: bcm2835: Avoid clock stretching timeouts (bsc#1012628).
- ASoC: rt5682s: do not block workqueue if card is unbound
  (bsc#1012628).
- ASoC: rt5668: do not block workqueue if card is unbound
  (bsc#1012628).
- ASoC: rt5682: do not block workqueue if card is unbound
  (bsc#1012628).
- regulator: core: fix false positive in regulator_late_cleanup()
  (bsc#1012628).
- Input: clear BTN_RIGHT/MIDDLE on buttonpads (bsc#1012628).
- btrfs: get rid of warning on transaction commit when using
  flushoncommit (bsc#1012628).
- KVM: arm64: vgic: Read HW interrupt pending state from the HW
  (bsc#1012628).
- block: loop:use kstatfs.f_bsize of backing file to set discard
  granularity (bsc#1012628).
- tipc: fix a bit overflow in tipc_crypto_key_rcv() (bsc#1012628).
- cifs: do not use uninitialized data in the owner/group sid
  (bsc#1012628).
- cifs: fix double free race when mount fails in cifs_get_root()
  (bsc#1012628).
- HID: amd_sfh: Handle amd_sfh work buffer in PM ops
  (bsc#1012628).
- HID: amd_sfh: Add functionality to clear interrupts
  (bsc#1012628).
- HID: amd_sfh: Add interrupt handler to process interrupts
  (bsc#1012628).
- cifs: modefromsids must add an ACE for authenticated users
  (bsc#1012628).
- selftests/seccomp: Fix seccomp failure by adding missing headers
  (bsc#1012628).
- drm/amd/pm: correct UMD pstate clocks for Dimgrey Cavefish
  and Beige Goby (bsc#1012628).
- selftests/ftrace: Do not trace do_softirq because of PREEMPT_RT
  (bsc#1012628).
- dmaengine: shdma: Fix runtime PM imbalance on error
  (bsc#1012628).
- i2c: cadence: allow COMPILE_TEST (bsc#1012628).
- i2c: imx: allow COMPILE_TEST (bsc#1012628).
- i2c: qup: allow COMPILE_TEST (bsc#1012628).
- net: usb: cdc_mbim: avoid altsetting toggling for Telit FN990
  (bsc#1012628).
- block-map: add __GFP_ZERO flag for alloc_page in function
  bio_copy_kern (bsc#1012628).
- exfat: reuse exfat_inode_info variable instead of calling
  EXFAT_I() (bsc#1012628).
- exfat: fix i_blocks for files truncated over 4 GiB
  (bsc#1012628).
- tracing: Add test for user space strings when filtering on
  string pointers (bsc#1012628).
- arm64: Mark start_backtrace() notrace and NOKPROBE_SYMBOL
  (bsc#1012628).
- serial: stm32: prevent TDR register overwrite when sending
  x_char (bsc#1012628).
- KVM: arm64: Workaround Cortex-A510's single-step and PAC trap
  errata (bsc#1012628).
- ext4: drop ineligible txn start stop APIs (bsc#1012628).
- ext4: simplify updating of fast commit stats (bsc#1012628).
- ext4: fast commit may not fallback for ineligible commit
  (bsc#1012628).
- ext4: fast commit may miss file actions (bsc#1012628).
- sched/fair: Fix fault in reweight_entity (bsc#1012628).
- KVM: x86: Add KVM_CAP_ENABLE_CAP to x86 (bsc#1012628).
- ata: pata_hpt37x: fix PCI clock detection (bsc#1012628).
- drm/amdgpu: check vm ready by amdgpu_vm->evicting flag
  (bsc#1012628).
- tracing: Add ustring operation to filtering string pointers
  (bsc#1012628).
- ipv6: fix skb drops in igmp6_event_query() and
  igmp6_event_report() (bsc#1012628).
- btrfs: defrag: bring back the old file extent search behavior
  (bsc#1012628).
- btrfs: defrag: don't use merged extent map for their generation
  check (bsc#1012628).
- ALSA: intel_hdmi: Fix reference to PCM buffer address
  (bsc#1012628).
- ucounts: Fix systemd LimitNPROC with private users regression
  (bsc#1012628).
- binfmt_elf: Avoid total_mapping_size for ET_EXEC (bsc#1012628).
- riscv/efi_stub: Fix get_boot_hartid_from_fdt() return value
  (bsc#1012628).
- riscv: Fix config KASAN && SPARSEMEM && !SPARSE_VMEMMAP
  (bsc#1012628).
- riscv: Fix config KASAN && DEBUG_VIRTUAL (bsc#1012628).
- iwlwifi: mvm: check debugfs_dir ptr before use (bsc#1012628).
- ASoC: ops: Shift tested values in snd_soc_put_volsw() by +min
  (bsc#1012628).
- iommu/vt-d: Fix double list_add when enabling VMD in scalable
  mode (bsc#1012628).
- iommu/amd: Recover from event log overflow (bsc#1012628).
- drm/i915: s/JSP2/ICP2/ PCH (bsc#1012628).
- drm/amd/display: Reduce dmesg error to a debug print
  (bsc#1012628).
- xen/netfront: destroy queues before real_num_tx_queues is zeroed
  (bsc#1012628).
- thermal: core: Fix TZ_GET_TRIP NULL pointer dereference
  (bsc#1012628).
- mac80211: fix EAPoL rekey fail in 802.3 rx path (bsc#1012628).
- blktrace: fix use after free for struct blk_trace (bsc#1012628).
- ntb: intel: fix port config status offset for SPR (bsc#1012628).
- mm: Consider __GFP_NOWARN flag for oversized kvmalloc() calls
  (bsc#1012628).
- xfrm: fix MTU regression (bsc#1012628).
- netfilter: fix use-after-free in __nf_register_net_hook()
  (bsc#1012628).
- bpf, sockmap: Do not ignore orig_len parameter (bsc#1012628).
- xfrm: fix the if_id check in changelink (bsc#1012628).
- xfrm: enforce validity of offload input flags (bsc#1012628).
- e1000e: Correct NVM checksum verification flow (bsc#1012628).
- net: fix up skbs delta_truesize in UDP GRO frag_list
  (bsc#1012628).
- netfilter: nf_queue: don't assume sk is full socket
  (bsc#1012628).
- netfilter: nf_queue: fix possible use-after-free (bsc#1012628).
- netfilter: nf_queue: handle socket prefetch (bsc#1012628).
- batman-adv: Request iflink once in batadv-on-batadv check
  (bsc#1012628).
- batman-adv: Request iflink once in batadv_get_real_netdevice
  (bsc#1012628).
- batman-adv: Don't expect inter-netns unique iflink indices
  (bsc#1012628).
- net: ipv6: ensure we call ipv6_mc_down() at most once
  (bsc#1012628).
- net: dcb: flush lingering app table entries for unregistered
  devices (bsc#1012628).
- net: ipa: fix a build dependency (bsc#1012628).
- net: ipa: add an interconnect dependency (bsc#1012628).
- net/smc: fix connection leak (bsc#1012628).
- net/smc: fix unexpected SMC_CLC_DECL_ERR_REGRMB error generated
  by client (bsc#1012628).
- net/smc: fix unexpected SMC_CLC_DECL_ERR_REGRMB error cause
  by server (bsc#1012628).
- btrfs: fix ENOSPC failure when attempting direct IO write into
  NOCOW range (bsc#1012628).
- platform/x86: amd-pmc: Set QOS during suspend on CZN w/ timer
  wakeup (bsc#1012628).
- net: dsa: microchip: fix bridging with more than two member
  ports (bsc#1012628).
- mac80211: fix forwarded mesh frames AC & queue selection
  (bsc#1012628).
- net: stmmac: fix return value of __setup handler (bsc#1012628).
- mac80211: treat some SAE auth steps as final (bsc#1012628).
- iavf: Fix missing check for running netdev (bsc#1012628).
- net: sxgbe: fix return value of __setup handler (bsc#1012628).
- ibmvnic: register netdev after init of adapter (bsc#1012628).
- net: arcnet: com20020: Fix null-ptr-deref in com20020pci_probe()
  (bsc#1012628).
- ixgbe: xsk: change !netif_carrier_ok() handling in
  ixgbe_xmit_zc() (bsc#1012628).
- iavf: Fix deadlock in iavf_reset_task (bsc#1012628).
- efivars: Respect "block" flag in efivar_entry_set_safe()
  (bsc#1012628).
- auxdisplay: lcd2s: Fix lcd2s_redefine_char() feature
  (bsc#1012628).
- firmware: arm_scmi: Remove space in MODULE_ALIAS name
  (bsc#1012628).
- ASoC: cs4265: Fix the duplicated control name (bsc#1012628).
- auxdisplay: lcd2s: Fix memory leak in ->remove() (bsc#1012628).
- auxdisplay: lcd2s: Use proper API to free the instance of
  charlcd object (bsc#1012628).
- can: gs_usb: change active_channels's type from atomic_t to u8
  (bsc#1012628).
- iommu/tegra-smmu: Fix missing put_device() call in
  tegra_smmu_find (bsc#1012628).
- arm64: dts: rockchip: Switch RK3399-Gru DP to SPDIF output
  (bsc#1012628).
- igc: igc_read_phy_reg_gpy: drop premature return (bsc#1012628).
- ARM: Fix kgdb breakpoint for Thumb2 (bsc#1012628).
- mips: setup: fix setnocoherentio() boolean setting
  (bsc#1012628).
- ARM: 9182/1: mmu: fix returns from early_param() and __setup()
  functions (bsc#1012628).
- mptcp: Correctly set DATA_FIN timeout when number of retransmits
  is large (bsc#1012628).
- selftests: mlxsw: tc_police_scale: Make test more robust
  (bsc#1012628).
- pinctrl: sunxi: Use unique lockdep classes for IRQs
  (bsc#1012628).
- igc: igc_write_phy_reg_gpy: drop premature return (bsc#1012628).
- ibmvnic: free reset-work-item when flushing (bsc#1012628).
- memfd: fix F_SEAL_WRITE after shmem huge page allocated
  (bsc#1012628).
- s390/setup: preserve memory at OLDMEM_BASE and OLDMEM_SIZE
  (bsc#1012628).
- s390/extable: fix exception table sorting (bsc#1012628).
- sched: Fix yet more sched_fork() races (bsc#1012628).
- arm64: dts: rockchip: drop pclk_xpcs from gmac0 on rk3568
  (bsc#1012628).
- arm64: dts: juno: Remove GICv2m dma-range (bsc#1012628).
- arm64: dts: rockchip: fix Quartz64-A ddr regulator voltage
  (bsc#1012628).
- arm64: dts: imx8mm: Fix VPU Hanging (bsc#1012628).
- iommu/amd: Fix I/O page table memory leak (bsc#1012628).
- MIPS: ralink: mt7621: do memory detection on KSEG1
  (bsc#1012628).
- ARM: dts: switch timer config to common devkit8000 devicetree
  (bsc#1012628).
- ARM: dts: Use 32KiHz oscillator on devkit8000 (bsc#1012628).
- soc: fsl: guts: Revert commit 3c0d64e867ed (bsc#1012628).
- soc: fsl: guts: Add a missing memory allocation failure check
  (bsc#1012628).
- soc: fsl: qe: Check of ioremap return value (bsc#1012628).
- soc: imx: gpcv2: Fix clock disabling imbalance in error path
  (bsc#1012628).
- netfilter: nf_tables: prefer kfree_rcu(ptr, rcu) variant
  (bsc#1012628).
- ARM: tegra: Move panels to AUX bus (bsc#1012628).
- Bluetooth: Fix bt_skb_sendmmsg not allocating partial chunks
  (bsc#1012628).
- can: etas_es58x: change opened_channel_cnt's type from atomic_t
  to u8 (bsc#1012628).
- net: stmmac: enhance XDP ZC driver level switching performance
  (bsc#1012628).
- net: stmmac: only enable DMA interrupts when ready
  (bsc#1012628).
- ibmvnic: initialize rc before completing wait (bsc#1012628).
- ibmvnic: define flush_reset_queue helper (bsc#1012628).
- ibmvnic: complete init_done on transport events (bsc#1012628).
- ibmvnic: Update driver return codes (bsc#1012628).
- ibmvnic: init init_done_rc earlier (bsc#1012628).
- ibmvnic: clear fop when retrying probe (bsc#1012628).
- ibmvnic: Allow queueing resets during probe (bsc#1012628).
- net: chelsio: cxgb3: check the return value of
  pci_find_capability() (bsc#1012628).
- net: sparx5: Fix add vlan when invalid operation (bsc#1012628).
- iavf: Add trace while removing device (bsc#1012628).
- iavf: Rework mutexes for better synchronisation (bsc#1012628).
- iavf: Add waiting so the port is initialized in remove
  (bsc#1012628).
- iavf: Fix init state closure on remove (bsc#1012628).
- iavf: Fix locking for VIRTCHNL_OP_GET_OFFLOAD_VLAN_V2_CAPS
  (bsc#1012628).
- iavf: Fix race in init state (bsc#1012628).
- iavf: Fix __IAVF_RESETTING state usage (bsc#1012628).
- drm/i915/guc/slpc: Correct the param count for unset param
  (bsc#1012628).
- drm/bridge: ti-sn65dsi86: Properly undo autosuspend
  (bsc#1012628).
- e1000e: Fix possible HW unit hang after an s0ix exit
  (bsc#1012628).
- MIPS: ralink: mt7621: use bitwise NOT instead of logical
  (bsc#1012628).
- nl80211: Handle nla_memdup failures in handle_nan_filter
  (bsc#1012628).
- ptp: ocp: Add ptp_ocp_adjtime_coarse for large adjustments
  (bsc#1012628).
- drm/amdgpu: fix suspend/resume hang regression (bsc#1012628).
- net: dcb: disable softirqs in dcbnl_flush_dev() (bsc#1012628).
- selftests: mlxsw: resource_scale: Fix return value
  (bsc#1012628).
- net: stmmac: perserve TX and RX coalesce value during XDP setup
  (bsc#1012628).
- Input: elan_i2c - move regulator_[en|dis]able() out of
  elan_[en|dis]able_power() (bsc#1012628).
- Input: elan_i2c - fix regulator enable count imbalance after
  suspend/resume (bsc#1012628).
- Input: samsung-keypad - properly state IOMEM dependency
  (bsc#1012628).
- HID: add mapping for KEY_DICTATE (bsc#1012628).
- HID: add mapping for KEY_ALL_APPLICATIONS (bsc#1012628).
- tracing/histogram: Fix sorting on old "cpu" value (bsc#1012628).
- tracing: Fix return value of __setup handlers (bsc#1012628).
- btrfs: fix lost prealloc extents beyond eof after full fsync
  (bsc#1012628).
- btrfs: fix relocation crash due to premature return from
  btrfs_commit_transaction() (bsc#1012628).
- btrfs: subpage: fix a wrong check on subpage->writers
  (bsc#1012628).
- btrfs: do not WARN_ON() if we have PageError set (bsc#1012628).
- btrfs: qgroup: fix deadlock between rescan worker and remove
  qgroup (bsc#1012628).
- btrfs: add missing run of delayed items after unlink during
  log replay (bsc#1012628).
- btrfs: fallback to blocking mode when doing async dio over
  multiple extents (bsc#1012628).
- btrfs: do not start relocation until in progress drops are done
  (bsc#1012628).
- Revert "xfrm: xfrm_state_mtu should return at least 1280 for
  ipv6" (bsc#1012628).
- proc: fix documentation and description of pagemap
  (bsc#1012628).
- x86/kvmclock: Fix Hyper-V Isolated VM's boot issue when vCPUs >
  64 (bsc#1012628).
- s390/ftrace: fix arch_ftrace_get_regs implementation
  (bsc#1012628).
- s390/ftrace: fix ftrace_caller/ftrace_regs_caller generation
  (bsc#1012628).
- KVM: x86/mmu: Passing up the error state of
  mmu_alloc_shadow_roots() (bsc#1012628).
- Update config files.
- commit bd40cb2
* Tue Mar  8 2022 jslaby@suse.cz
- Update
  patches.kernel.org/5.16.11-207-lib-iov_iter-initialize-flags-in-new-pipe_buf.patch
  (bsc#1012628 bsc#1196584 CVE-2022-0847).
  Add references.
- commit 82f40a9
* Mon Mar  7 2022 tiwai@suse.de
- nfc: st21nfca: Fix potential buffer overflows in EVT_TRANSACTION
  (CVE-2022-26490 bsc#1196830).
- commit b002fe2
* Mon Mar  7 2022 mkubecek@suse.cz
- Update to 5.17-rc7
- commit 04b7727
* Fri Mar  4 2022 mkubecek@suse.cz
- config: refresh
  Since commit bb988d4625a3 ("kernel-binary: Do not include sourcedir in
  certificate path."), MODULE_SIG_HASH config option is mandatory in diff
  configs.
- commit 191d88f
* Thu Mar  3 2022 pvorel@suse.cz
- config: ppc64{,le}: build vmx-crypto as module (bsc#1195768)
  Building CONFIG_CRYPTO_DEV_VMX_ENCRYPT as module is the default in
  mainline since v4.8, we use it in SLES and already in
  config/ppc64/default. Thus unify it in the other configs.
  There are build dependencies which has been fixed in mainline
  647d41d3952d ("crypto: vmx - add missing dependencies")
  (currently still at maintainer herbert/cryptodev-2.6 tree)
  But instead of waiting commit to be accepted or backporting it we just
  unify configs, which is useful anyway
- commit 70a0d71
* Wed Mar  2 2022 msuchanek@suse.de
- kernel-binary.spec: Also exclude the kernel signing key from devel package.
  There is a check in OBS that fails when it is included. Also the key is
  not reproducible.
  Fixes: bb988d4625a3 ("kernel-binary: Do not include sourcedir in certificate path.")
- commit 68fa069
* Wed Mar  2 2022 msuchanek@suse.de
- rpm/check-for-config-changes: Ignore PAHOLE_VERSION.
- commit 88ba5ec
* Wed Mar  2 2022 jslaby@suse.cz
- Linux 5.16.12 (bsc#1012628).
- memblock: use kfree() to release kmalloced memblock regions
  (bsc#1012628).
- gpio: tegra186: Fix chip_data type confusion (bsc#1012628).
- pinctrl: k210: Fix bias-pull-up (bsc#1012628).
- pinctrl: fix loop in k210_pinconf_get_drive() (bsc#1012628).
- tty: n_gsm: fix deadlock in gsmtty_open() (bsc#1012628).
- tty: n_gsm: fix wrong modem processing in convergence layer
  type 2 (bsc#1012628).
- tty: n_gsm: fix wrong tty control line for flow control
  (bsc#1012628).
- tty: n_gsm: fix NULL pointer access due to DLCI release
  (bsc#1012628).
- tty: n_gsm: fix proper link termination after failed open
  (bsc#1012628).
- tty: n_gsm: fix encoding of command/response bit (bsc#1012628).
- tty: n_gsm: fix encoding of control signal octet bit DV
  (bsc#1012628).
- hugetlbfs: fix a truncation issue in hugepages parameter
  (bsc#1012628).
- mm/hugetlb: fix kernel crash with hugetlb mremap (bsc#1012628).
- riscv: fix oops caused by irqsoff latency tracer (bsc#1012628).
- riscv: fix nommu_k210_sdcard_defconfig (bsc#1012628).
- IB/qib: Fix duplicate sysfs directory name (bsc#1012628).
- tps6598x: clear int mask on probe failure (bsc#1012628).
- staging: fbtft: fb_st7789v: reset display before initialization
  (bsc#1012628).
- thermal: int340x: fix memory leak in int3400_notify()
  (bsc#1012628).
- RDMA/cma: Do not change route.addr.src_addr outside state checks
  (bsc#1012628).
- btrfs: reduce extent threshold for autodefrag (bsc#1012628).
- btrfs: autodefrag: only scan one inode once (bsc#1012628).
- btrfs: defrag: allow defrag_one_cluster() to skip large extent
  which is not a target (bsc#1012628).
- btrfs: prevent copying too big compressed lzo segment
  (bsc#1012628).
- btrfs: defrag: remove an ambiguous condition for rejection
  (bsc#1012628).
- btrfs: defrag: don't defrag extents which are already at max
  capacity (bsc#1012628).
- btrfs: defrag: don't try to merge regular extents with
  preallocated extents (bsc#1012628).
- driver core: Free DMA range map when device is released
  (bsc#1012628).
- mtd: core: Fix a conflict between MTD and NVMEM on wp-gpios
  property (bsc#1012628).
- nvmem: core: Fix a conflict between MTD and NVMEM on wp-gpios
  property (bsc#1012628).
- xhci: Prevent futile URB re-submissions due to incorrect return
  value (bsc#1012628).
- xhci: re-initialize the HC during resume if HCE was set
  (bsc#1012628).
- usb: dwc3: gadget: Let the interrupt handler disable bottom
  halves (bsc#1012628).
- usb: dwc3: pci: Fix Bay Trail phy GPIO mappings (bsc#1012628).
- usb: dwc3: pci: Add "snps,dis_u2_susphy_quirk" for Intel Bay
  Trail (bsc#1012628).
- usb: dwc2: drd: fix soft connect when gadget is unconfigured
  (bsc#1012628).
- USB: serial: option: add Telit LE910R1 compositions
  (bsc#1012628).
- USB: serial: option: add support for DW5829e (bsc#1012628).
- tracefs: Set the group ownership in apply_options() not
  parse_options() (bsc#1012628).
- USB: gadget: validate endpoint index for xilinx udc
  (bsc#1012628).
- usb: gadget: rndis: add spinlock for rndis response list
  (bsc#1012628).
- Revert "USB: serial: ch341: add new Product ID for CH341A"
  (bsc#1012628).
- ata: pata_hpt37x: disable primary channel on HPT371
  (bsc#1012628).
- sc16is7xx: Fix for incorrect data being transmitted
  (bsc#1012628).
- iio: Fix error handling for PM (bsc#1012628).
- iio: imu: st_lsm6dsx: wait for settling time in
  st_lsm6dsx_read_oneshot (bsc#1012628).
- iio: accel: fxls8962af: add padding to regmap for SPI
  (bsc#1012628).
- iio: adc: ad7124: fix mask used for setting AIN_BUFP & AIN_BUFM
  bits (bsc#1012628).
- iio: adc: tsc2046: fix memory corruption by preventing array
  overflow (bsc#1012628).
- iio: adc: men_z188_adc: Fix a resource leak in an error handling
  path (bsc#1012628).
- iio:imu:adis16480: fix buffering for devices with no burst mode
  (bsc#1012628).
- tracing: Have traceon and traceoff trigger honor the instance
  (bsc#1012628).
- tracing: Dump stacktrace trigger to the corresponding instance
  (bsc#1012628).
- bpf: Fix crash due to out of bounds access into reg2btf_ids
  (bsc#1012628).
- bpf: Extend kfunc with PTR_TO_CTX, PTR_TO_MEM argument support
  (bsc#1012628).
- RDMA/ib_srp: Fix a deadlock (bsc#1012628).
- configfs: fix a race in configfs_{,un}register_subsystem()
  (bsc#1012628).
- bnxt_en: Increase firmware message response DMA wait time
  (bsc#1012628).
- RDMA/rtrs-clt: Move free_permit from free_clt to rtrs_clt_close
  (bsc#1012628).
- RDMA/rtrs-clt: Fix possible double free in error case
  (bsc#1012628).
- net-timestamp: convert sk->sk_tskey to atomic_t (bsc#1012628).
- net: use sk_is_tcp() in more places (bsc#1012628).
- regmap-irq: Update interrupt clear register for proper reset
  (bsc#1012628).
- gpio: rockchip: Reset int_bothedge when changing trigger
  (bsc#1012628).
- PCI: mvebu: Fix device enumeration regression (bsc#1012628).
- spi: spi-zynq-qspi: Fix a NULL pointer dereference in
  zynq_qspi_exec_mem_op() (bsc#1012628).
- net/mlx5e: Add missing increment of count (bsc#1012628).
- net/mlx5: Update log_max_qp value to be 17 at most
  (bsc#1012628).
- net/mlx5: DR, Fix slab-out-of-bounds in mlx5_cmd_dr_create_fte
  (bsc#1012628).
- net/mlx5e: kTLS, Use CHECKSUM_UNNECESSARY for device-offloaded
  packets (bsc#1012628).
- net/mlx5e: MPLSoUDP decap, fix check for unsupported matches
  (bsc#1012628).
- net/mlx5: DR, Fix the threshold that defines when pool sync
  is initiated (bsc#1012628).
- net/mlx5: Fix wrong limitation of metadata match on ecpf
  (bsc#1012628).
- net/mlx5: Fix possible deadlock on rule deletion (bsc#1012628).
- net/mlx5: DR, Don't allow match on IP w/o matching on full
  ethertype/ip_version (bsc#1012628).
- ibmvnic: schedule failover only if vioctl fails (bsc#1012628).
- net/mlx5: DR, Cache STE shadow memory (bsc#1012628).
- udp_tunnel: Fix end of loop test in udp_tunnel_nic_unregister()
  (bsc#1012628).
- surface: surface3_power: Fix battery readings on batteries
  without a serial number (bsc#1012628).
- net/smc: Use a mutex for locking "struct smc_pnettable"
  (bsc#1012628).
- netfilter: nf_tables: fix memory leak during stateful obj update
  (bsc#1012628).
- net: mdio-ipq4019: add delay after clock enable (bsc#1012628).
- nfp: flower: Fix a potential leak in nfp_tunnel_add_shared_mac()
  (bsc#1012628).
- net: dsa: avoid call to __dev_set_promiscuity() while rtnl_mutex
  isn't held (bsc#1012628).
- netfilter: nf_tables: unregister flowtable hooks on netns exit
  (bsc#1012628).
- net: Force inlining of checksum functions in net/checksum.h
  (bsc#1012628).
- net: ll_temac: check the return value of devm_kmalloc()
  (bsc#1012628).
- net/sched: act_ct: Fix flow table lookup after ct clear or
  switching zones (bsc#1012628).
- drm/amd/display: For vblank_disable_immediate, check PSR is
  really used (bsc#1012628).
- drm/i915/dg2: Print PHY name properly on calibration error
  (bsc#1012628).
- drm/vc4: crtc: Fix runtime_pm reference counting (bsc#1012628).
- block: clear iocb->private in blkdev_bio_end_io_async()
  (bsc#1012628).
- net/mlx5e: TC, Reject rules with drop and modify hdr action
  (bsc#1012628).
- net/mlx5e: TC, Reject rules with forward and drop actions
  (bsc#1012628).
- net/mlx5e: Fix wrong return value on ioctl EEPROM query failure
  (bsc#1012628).
- drm/edid: Always set RGB444 (bsc#1012628).
- openvswitch: Fix setting ipv6 fields causing hw csum failure
  (bsc#1012628).
- net: mv643xx_eth: process retval from of_get_mac_address
  (bsc#1012628).
- gso: do not skip outer ip header in case of ipip and
  net_failover (bsc#1012628).
- clk: qcom: gcc-msm8994: Remove NoC clocks (bsc#1012628).
- tipc: Fix end of loop tests for list_for_each_entry()
  (bsc#1012628).
- nvme: also mark passthrough-only namespaces ready in
  nvme_update_ns_info (bsc#1012628).
- net: __pskb_pull_tail() & pskb_carve_frag_list() drop_monitor
  friends (bsc#1012628).
- io_uring: add a schedule point in io_add_buffers()
  (bsc#1012628).
- bpf: Add schedule points in batch ops (bsc#1012628).
- bpf: Fix a bpf_timer initialization issue (bsc#1012628).
- selftests: bpf: Check bpf_msg_push_data return value
  (bsc#1012628).
- bpf: Do not try bpf_msg_push_data with len 0 (bsc#1012628).
- bpf: Fix crash due to incorrect copy_map_value (bsc#1012628).
- net/mlx5: Update the list of the PCI supported devices
  (bsc#1012628).
- ice: initialize local variable 'tlv' (bsc#1012628).
- ice: check the return of ice_ptp_gettimex64 (bsc#1012628).
- ice: fix concurrent reset and removal of VFs (bsc#1012628).
- ice: fix setting l4 port flag when adding filter (bsc#1012628).
- net/mlx5: Fix tc max supported prio for nic mode (bsc#1012628).
- hwmon: Handle failure to register sensor with thermal zone
  correctly (bsc#1012628).
- bnxt_en: Restore the resets_reliable flag in bnxt_open()
  (bsc#1012628).
- bnxt_en: Fix incorrect multicast rx mask setting when not
  requested (bsc#1012628).
- bnxt_en: Fix occasional ethtool -t loopback test failures
  (bsc#1012628).
- bnxt_en: Fix offline ethtool selftest with RDMA enabled
  (bsc#1012628).
- bnxt_en: Fix active FEC reporting to ethtool (bsc#1012628).
- bnxt_en: Fix devlink fw_activate (bsc#1012628).
- bnx2x: fix driver load from initrd (bsc#1012628).
- selftests: mptcp: be more conservative with cookie MPJ limits
  (bsc#1012628).
- selftests: mptcp: fix diag instability (bsc#1012628).
- mptcp: add mibs counter for ignored incoming options
  (bsc#1012628).
- mptcp: fix race in incoming ADD_ADDR option processing
  (bsc#1012628).
- perf data: Fix double free in perf_session__delete()
  (bsc#1012628).
- perf evlist: Fix failed to use cpu list for uncore events
  (bsc#1012628).
- gpu: host1x: Always return syncpoint value when waiting
  (bsc#1012628).
- Revert "i40e: Fix reset bw limit when DCB enabled with 1 TC"
  (bsc#1012628).
- ping: remove pr_err from ping_lookup (bsc#1012628).
- netfilter: nf_tables_offload: incorrect flow offload action
  array size (bsc#1012628).
- netfilter: xt_socket: missing ifdef CONFIG_IP6_NF_IPTABLES
  dependency (bsc#1012628).
- netfilter: xt_socket: fix a typo in socket_mt_destroy()
  (bsc#1012628).
- CDC-NCM: avoid overflow in sanity checking (bsc#1012628).
- USB: zaurus: support another broken Zaurus (bsc#1012628).
- sr9700: sanity check for packet length (bsc#1012628).
- drm/i915: Fix bw atomic check when switching between SAGV
  vs. no SAGV (bsc#1012628).
- drm/i915: Correctly populate use_sagv_wm for all pipes
  (bsc#1012628).
- drm/i915: Disconnect PHYs left connected by BIOS on disabled
  ports (bsc#1012628).
- drm/i915: Widen the QGV point mask (bsc#1012628).
- drm/amdgpu: do not enable asic reset for raven2 (bsc#1012628).
- drm/amdgpu: disable MMHUB PG for Picasso (bsc#1012628).
- drm/amd: Check if ASPM is enabled from PCIe subsystem
  (bsc#1012628).
- drm/amd/pm: fix some OEM SKU specific stability issues
  (bsc#1012628).
- drm/amd/display: Protect update_bw_bounding_box FPU code
  (bsc#1012628).
- drm/amd/display: Fix stream->link_enc unassigned during stream
  removal (bsc#1012628).
- KVM: x86: nSVM: disallow userspace setting of
  MSR_AMD64_TSC_RATIO to non default value when tsc scaling
  disabled (bsc#1012628).
- KVM: x86/mmu: make apf token non-zero to fix bug (bsc#1012628).
- parisc/unaligned: Fix ldw() and stw() unalignment handlers
  (bsc#1012628).
- parisc/unaligned: Fix fldd and fstd unaligned handlers on
  32-bit kernel (bsc#1012628).
- vhost/vsock: don't check owner in vhost_vsock_stop() while
  releasing (bsc#1012628).
- selinux: fix misuse of mutex_is_locked() (bsc#1012628).
- io_uring: disallow modification of rsrc_data during quiesce
  (bsc#1012628).
- io_uring: don't convert to jiffies for waiting on timeouts
  (bsc#1012628).
- clk: jz4725b: fix mmc0 clock gating (bsc#1012628).
- slab: remove __alloc_size attribute from __kmalloc_track_caller
  (bsc#1012628).
- btrfs: tree-checker: check item_size for dev_item (bsc#1012628).
- btrfs: tree-checker: check item_size for inode_item
  (bsc#1012628).
- cgroup-v1: Correct privileges check in release_agent writes
  (bsc#1012628).
- cgroup/cpuset: Fix a race between cpuset_attach() and cpu
  hotplug (bsc#1012628).
- mm/filemap: Fix handling of THPs in generic_file_buffered_read()
  (bsc#1012628).
- commit 9b89dd3
* Mon Feb 28 2022 mkubecek@suse.cz
- Update to 5.17-rc6
- commit 3bbcd8f
* Sun Feb 27 2022 mkubecek@suse.cz
- config: update vanilla configs
  FB_BOOT_VESA_SUPPORT was replaced BOOT_VESA_SUPPORT by a patch but this
  patch is not applied to vanilla flavor so that we have to keep the option
  in */vanilla configs until the patch reaches mainline.
- commit 22f5560
* Sun Feb 27 2022 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: add systemd-initrd and terminfo dracut module (bsc#1195775)
- commit d9a821b
* Thu Feb 24 2022 jslaby@suse.cz
- Update config files.
  A vanilla fix for commit 17ec1907657a (simplefb: Enable boot time VESA
  graphic mode selection (bsc#1193250).)
- commit 90630c5
* Wed Feb 23 2022 jslaby@suse.cz
- Linux 5.16.11 (bsc#1012628).
- drm/nouveau/pmu/gm200-: use alternate falcon reset sequence
  (bsc#1012628).
- bpf: Introduce composable reg, ret and arg types (bsc#1012628).
- bpf: Replace ARG_XXX_OR_NULL with ARG_XXX | PTR_MAYBE_NULL
  (bsc#1012628).
- bpf: Replace RET_XXX_OR_NULL with RET_XXX | PTR_MAYBE_NULL
  (bsc#1012628).
- bpf: Replace PTR_TO_XXX_OR_NULL with PTR_TO_XXX | PTR_MAYBE_NULL
  (bsc#1012628).
- bpf: Introduce MEM_RDONLY flag (bsc#1012628).
- bpf: Convert PTR_TO_MEM_OR_NULL to composable types
  (bsc#1012628).
- bpf: Make per_cpu_ptr return rdonly PTR_TO_MEM (bsc#1012628).
- bpf: Add MEM_RDONLY for helper args that are pointers to rdonly
  mem (bsc#1012628).
- bpf/selftests: Test PTR_TO_RDONLY_MEM (bsc#1012628).
- HID:Add support for UGTABLET WP5540 (bsc#1012628).
- Revert "svm: Add warning message for AVIC IPI invalid target"
  (bsc#1012628).
- parisc: Show error if wrong 32/64-bit compiler is being used
  (bsc#1012628).
- serial: parisc: GSC: fix build when IOSAPIC is not set
  (bsc#1012628).
- parisc: Drop __init from map_pages declaration (bsc#1012628).
- parisc: Fix data TLB miss in sba_unmap_sg (bsc#1012628).
- parisc: Fix sglist access in ccio-dma.c (bsc#1012628).
- mmc: block: fix read single on recovery logic (bsc#1012628).
- mm: don't try to NUMA-migrate COW pages that have other uses
  (bsc#1012628).
- HID: amd_sfh: Add illuminance mask to limit ALS max value
  (bsc#1012628).
- HID: i2c-hid: goodix: Fix a lockdep splat (bsc#1012628).
- HID: amd_sfh: Increase sensor command timeout (bsc#1012628).
- selftests: kvm: Remove absent target file (bsc#1012628).
- HID: amd_sfh: Correct the structure field name (bsc#1012628).
- PCI: hv: Fix NUMA node assignment when kernel boots with custom
  NUMA topology (bsc#1012628).
- parisc: Add ioread64_lo_hi() and iowrite64_lo_hi()
  (bsc#1012628).
- HID: apple: Set the tilde quirk flag on the Wellspring 5 and
  later (bsc#1012628).
- btrfs: don't hold CPU for too long when defragging a file
  (bsc#1012628).
- btrfs: send: in case of IO error log it (bsc#1012628).
- btrfs: defrag: don't try to defrag extents which are under
  writeback (bsc#1012628).
- ASoC: mediatek: fix unmet dependency on GPIOLIB for SND_SOC_DMIC
  (bsc#1012628).
- platform/x86: touchscreen_dmi: Add info for the RWC NANOTE P8
  AY07J 2-in-1 (bsc#1012628).
- platform/x86: ISST: Fix possible circular locking dependency
  detected (bsc#1012628).
- platform/x86: amd-pmc: Correct usage of SMU version
  (bsc#1012628).
- kunit: tool: Import missing importlib.abc (bsc#1012628).
- selftests: rtc: Increase test timeout so that all tests run
  (bsc#1012628).
- kselftest: signal all child processes (bsc#1012628).
- selftests: netfilter: reduce zone stress test running time
  (bsc#1012628).
- net: ieee802154: at86rf230: Stop leaking skb's (bsc#1012628).
- selftests/zram: Skip max_comp_streams interface on newer kernel
  (bsc#1012628).
- selftests/zram01.sh: Fix compression ratio calculation
  (bsc#1012628).
- selftests/zram: Adapt the situation that /dev/zram0 is being
  used (bsc#1012628).
- selftests: openat2: Print also errno in failure messages
  (bsc#1012628).
- selftests: openat2: Add missing dependency in Makefile
  (bsc#1012628).
- selftests: openat2: Skip testcases that fail with EOPNOTSUPP
  (bsc#1012628).
- selftests: skip mincore.check_file_mmap when fs lacks needed
  support (bsc#1012628).
- ax25: improve the incomplete fix to avoid UAF and NPD bugs
  (bsc#1012628).
- cifs: unlock chan_lock before calling cifs_put_tcp_session
  (bsc#1012628).
- pinctrl: bcm63xx: fix unmet dependency on REGMAP for GPIO_REGMAP
  (bsc#1012628).
- vfs: make freeze_super abort when sync_filesystem returns error
  (bsc#1012628).
- vfs: make sync_filesystem return errors from ->sync_fs
  (bsc#1012628).
- quota: make dquot_quota_sync return errors from ->sync_fs
  (bsc#1012628).
- scsi: pm80xx: Fix double completion for SATA devices
  (bsc#1012628).
- kselftest: Fix vdso_test_abi return status (bsc#1012628).
- scsi: core: Reallocate device's budget map on queue depth change
  (bsc#1012628).
- scsi: pm8001: Fix use-after-free for aborted TMF sas_task
  (bsc#1012628).
- scsi: pm8001: Fix use-after-free for aborted SSP/STP sas_task
  (bsc#1012628).
- drm/amd: Warn users about potential s0ix problems (bsc#1012628).
- mailmap: update Christian Brauner's email address (bsc#1012628).
- nvme: fix a possible use-after-free in controller reset during
  load (bsc#1012628).
- nvme-tcp: fix possible use-after-free in transport
  error_recovery work (bsc#1012628).
- nvme-rdma: fix possible use-after-free in transport
  error_recovery work (bsc#1012628).
- net: sparx5: do not refer to skb after passing it on
  (bsc#1012628).
- drm/amd: add support to check whether the system is set to s3
  (bsc#1012628).
- drm/amd: Only run s3 or s0ix if system is configured properly
  (bsc#1012628).
- drm/amdgpu: fix logic inversion in check (bsc#1012628).
- x86/Xen: streamline (and fix) PV CPU enumeration (bsc#1012628).
- Revert "module, async: async_synchronize_full() on module init
  iff async is used" (bsc#1012628).
- gcc-plugins/stackleak: Use noinstr in favor of notrace
  (bsc#1012628).
- random: wake up /dev/random writers after zap (bsc#1012628).
- KVM: x86/xen: Fix runstate updates to be atomic when preempting
  vCPU (bsc#1012628).
- KVM: x86: nSVM/nVMX: set nested_run_pending on VM entry which
  is a result of RSM (bsc#1012628).
- KVM: x86: SVM: don't passthrough SMAP/SMEP/PKE bits in !NPT &&
  !gCR0.PG case (bsc#1012628).
- KVM: x86: nSVM: fix potential NULL derefernce on nested
  migration (bsc#1012628).
- KVM: x86: nSVM: mark vmcb01 as dirty when restoring SMM saved
  state (bsc#1012628).
- iwlwifi: remove deprecated broadcast filtering feature
  (bsc#1012628).
- iwlwifi: fix use-after-free (bsc#1012628).
- drm/mediatek: mtk_dsi: Avoid EPROBE_DEFER loop with external
  bridge (bsc#1012628).
- drm/radeon: Fix backlight control on iMac 12,1 (bsc#1012628).
- drm/atomic: Don't pollute crtc_state->mode_blob with error
  pointers (bsc#1012628).
- drm/amd/pm: correct the sequence of sending gpu reset msg
  (bsc#1012628).
- drm/amdgpu: skipping SDMA hw_init and hw_fini for S0ix
  (bsc#1012628).
- drm/i915/opregion: check port number bounds for SWSCI display
  power state (bsc#1012628).
- drm/i915: Fix dbuf slice config lookup (bsc#1012628).
- drm/i915: Fix mbus join config lookup (bsc#1012628).
- vsock: remove vsock from connected table when connect is
  interrupted by a signal (bsc#1012628).
- tee: export teedev_open() and teedev_close_context()
  (bsc#1012628).
- optee: use driver internal tee_context for some rpc
  (bsc#1012628).
- drm/cma-helper: Set VM_DONTEXPAND for mmap (bsc#1012628).
- drm/i915/gvt: Make DRM_I915_GVT depend on X86 (bsc#1012628).
- drm/i915/ttm: tweak priority hint selection (bsc#1012628).
- iwlwifi: pcie: fix locking when "HW not ready" (bsc#1012628).
- iwlwifi: pcie: gen2: fix locking when "HW not ready"
  (bsc#1012628).
- iwlwifi: mvm: fix condition which checks the version of
  rate_n_flags (bsc#1012628).
- iwlwifi: fix iwl_legacy_rate_to_fw_idx (bsc#1012628).
- iwlwifi: mvm: don't send SAR GEO command for 3160 devices
  (bsc#1012628).
- selftests: netfilter: fix exit value for nft_concat_range
  (bsc#1012628).
- netfilter: nft_synproxy: unregister hooks on init error path
  (bsc#1012628).
- selftests: netfilter: disable rp_filter on router (bsc#1012628).
- ipv4: fix data races in fib_alias_hw_flags_set (bsc#1012628).
- ipv6: fix data-race in fib6_info_hw_flags_set / fib6_purge_rt
  (bsc#1012628).
- ipv6: mcast: use rcu-safe version of ipv6_get_lladdr()
  (bsc#1012628).
- ipv6: per-netns exclusive flowlabel checks (bsc#1012628).
- Revert "net: ethernet: bgmac: Use
  devm_platform_ioremap_resource_byname" (bsc#1012628).
- mac80211: mlme: check for null after calling kmemdup
  (bsc#1012628).
- brcmfmac: firmware: Fix crash in brcm_alt_fw_path (bsc#1012628).
- cfg80211: fix race in netlink owner interface destruction
  (bsc#1012628).
- net: dsa: lan9303: fix reset on probe (bsc#1012628).
- net: dsa: mv88e6xxx: flush switchdev FDB workqueue before
  removing VLAN (bsc#1012628).
- net: dsa: lantiq_gswip: fix use after free in gswip_remove()
  (bsc#1012628).
- net: dsa: lan9303: handle hwaccel VLAN tags (bsc#1012628).
- net: dsa: lan9303: add VLAN IDs to master device (bsc#1012628).
- net: ieee802154: ca8210: Fix lifs/sifs periods (bsc#1012628).
- ping: fix the dif and sdif check in ping_lookup (bsc#1012628).
- bonding: force carrier update when releasing slave
  (bsc#1012628).
- mctp: fix use after free (bsc#1012628).
- drop_monitor: fix data-race in dropmon_net_event /
  trace_napi_poll_hit (bsc#1012628).
- net_sched: add __rcu annotation to netdev->qdisc (bsc#1012628).
- crypto: af_alg - get rid of alg_memory_allocated (bsc#1012628).
- bonding: fix data-races around agg_select_timer (bsc#1012628).
- nfp: flower: netdev offload check for ip6gretap (bsc#1012628).
- net/smc: Avoid overwriting the copies of clcsock callback
  functions (bsc#1012628).
- net: phy: mediatek: remove PHY mode check on MT7531
  (bsc#1012628).
- atl1c: fix tx timeout after link flap on Mikrotik 10/25G NIC
  (bsc#1012628).
- tipc: fix wrong publisher node address in link publications
  (bsc#1012628).
- dpaa2-switch: fix default return of
  dpaa2_switch_flower_parse_mirror_key (bsc#1012628).
- dpaa2-eth: Initialize mutex used in one step timestamping path
  (bsc#1012628).
- net: mscc: ocelot: fix use-after-free in ocelot_vlan_del()
  (bsc#1012628).
- net: bridge: multicast: notify switchdev driver whenever MC
  processing gets disabled (bsc#1012628).
- perf bpf: Defer freeing string after possible strlen() on it
  (bsc#1012628).
- selftests/exec: Add non-regular to TEST_GEN_PROGS (bsc#1012628).
- arm64: Correct wrong label in macro __init_el2_gicv3
  (bsc#1012628).
- ALSA: usb-audio: revert to IMPLICIT_FB_FIXED_DEV for M-Audio
  FastTrack Ultra (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Legion Y9000X 2019
  (bsc#1012628).
- ALSA: hda: Fix regression on forced probe mask option
  (bsc#1012628).
- ALSA: hda: Fix missing codec probe on Shenker Dock 15
  (bsc#1012628).
- ASoC: ops: Fix stereo change notifications in
  snd_soc_put_volsw() (bsc#1012628).
- ASoC: ops: Fix stereo change notifications in
  snd_soc_put_volsw_range() (bsc#1012628).
- ASoC: ops: Fix stereo change notifications in
  snd_soc_put_volsw_sx() (bsc#1012628).
- ASoC: ops: Fix stereo change notifications in
  snd_soc_put_xr_sx() (bsc#1012628).
- cifs: fix set of group SID via NTSD xattrs (bsc#1012628).
- cifs: fix confusing unneeded warning message on smb2.1 and
  earlier (bsc#1012628).
- ACPI: processor: idle: fix lockup regression on 32-bit ThinkPad
  T40 (bsc#1012628).
- powerpc/603: Fix boot failure with DEBUG_PAGEALLOC and KFENCE
  (bsc#1012628).
- powerpc/lib/sstep: fix 'ptesync' build error (bsc#1012628).
- mtd: rawnand: gpmi: don't leak PM reference in error path
  (bsc#1012628).
- smb3: fix snapshot mount option (bsc#1012628).
- tipc: fix wrong notification node addresses (bsc#1012628).
- scsi: ufs: Remove dead code (bsc#1012628).
- scsi: ufs: Fix a deadlock in the error handler (bsc#1012628).
- ASoC: tas2770: Insert post reset delay (bsc#1012628).
- ASoC: qcom: Actually clear DMA interrupt register for HDMI
  (bsc#1012628).
- block/wbt: fix negative inflight counter when remove scsi device
  (bsc#1012628).
- NFS: Remove an incorrect revalidation in
  nfs4_update_changeattr_locked() (bsc#1012628).
- NFS: LOOKUP_DIRECTORY is also ok with symlinks (bsc#1012628).
- NFS: Do not report writeback errors in nfs_getattr()
  (bsc#1012628).
- tty: n_tty: do not look ahead for EOL character past the end
  of the buffer (bsc#1012628).
- block: fix surprise removal for drivers calling
  blk_set_queue_dying (bsc#1012628).
- mtd: rawnand: qcom: Fix clock sequencing in qcom_nandc_probe()
  (bsc#1012628).
- mtd: parsers: qcom: Fix kernel panic on skipped partition
  (bsc#1012628).
- mtd: parsers: qcom: Fix missing free for pparts in cleanup
  (bsc#1012628).
- mtd: phram: Prevent divide by zero bug in phram_setup()
  (bsc#1012628).
- mtd: rawnand: brcmnand: Fixed incorrect sub-page ECC status
  (bsc#1012628).
- scsi: lpfc: Fix pt2pt NVMe PRLI reject LOGO loop (bsc#1012628).
- EDAC: Fix calculation of returned address and next offset in
  edac_align_ptr() (bsc#1012628).
- x86/ptrace: Fix xfpregs_set()'s incorrect xmm clearing
  (bsc#1012628).
- ucounts: Base set_cred_ucounts changes on the real user
  (bsc#1012628).
- ucounts: Handle wrapping in is_ucounts_overlimit (bsc#1012628).
- ucounts: Enforce RLIMIT_NPROC not RLIMIT_NPROC+1 (bsc#1012628).
- rlimit: Fix RLIMIT_NPROC enforcement failure caused by
  capability calls in set_user (bsc#1012628).
- ucounts: Move RLIMIT_NPROC handling after set_user
  (bsc#1012628).
- net: sched: limit TC_ACT_REPEAT loops (bsc#1012628).
- dmaengine: sh: rcar-dmac: Check for error num after setting mask
  (bsc#1012628).
- dmaengine: stm32-dmamux: Fix PM disable depth imbalance in
  stm32_dmamux_probe (bsc#1012628).
- dmaengine: sh: rcar-dmac: Check for error num after
  dma_set_max_seg_size (bsc#1012628).
- tests: fix idmapped mount_setattr test (bsc#1012628).
- i2c: qcom-cci: don't delete an unregistered adapter
  (bsc#1012628).
- i2c: qcom-cci: don't put a device tree node before
  i2c_add_adapter() (bsc#1012628).
- dmaengine: ptdma: Fix the error handling path in pt_core_init()
  (bsc#1012628).
- copy_process(): Move fd_install() out of sighand->siglock
  critical section (bsc#1012628).
- scsi: qedi: Fix ABBA deadlock in qedi_process_tmf_resp()
  and qedi_process_cmd_cleanup_resp() (bsc#1012628).
- ASoC: wm_adsp: Correct control read size when parsing compressed
  buffer (bsc#1012628).
- ice: enable parsing IPSEC SPI headers for RSS (bsc#1012628).
- i2c: brcmstb: fix support for DSL and CM variants (bsc#1012628).
- lockdep: Correct lock_classes index mapping (bsc#1012628).
- HID: elo: fix memory leak in elo_probe (bsc#1012628).
- mtd: rawnand: ingenic: Fix missing put_device in ingenic_ecc_get
  (bsc#1012628).
- Drivers: hv: vmbus: Fix memory leak in vmbus_add_channel_kobj
  (bsc#1012628).
- KVM: x86/pmu: Refactoring find_arch_event() to pmc_perf_hw_id()
  (bsc#1012628).
- KVM: x86/pmu: Don't truncate the PerfEvtSeln MSR when creating
  a perf event (bsc#1012628).
- KVM: x86/pmu: Use AMD64_RAW_EVENT_MASK for PERF_TYPE_RAW
  (bsc#1012628).
- ARM: OMAP2+: hwmod: Add of_node_put() before break
  (bsc#1012628).
- ARM: OMAP2+: adjust the location of put_device() call in
  omapdss_init_of (bsc#1012628).
- phy: usb: Leave some clocks running during suspend
  (bsc#1012628).
- staging: vc04_services: Fix RCU dereference check (bsc#1012628).
- phy: phy-mtk-tphy: Fix duplicated argument in phy-mtk-tphy
  (bsc#1012628).
- irqchip/sifive-plic: Add missing thead,c900-plic match string
  (bsc#1012628).
- x86/bug: Merge annotate_reachable() into _BUG_FLAGS() asm
  (bsc#1012628).
- netfilter: conntrack: don't refresh sctp entries in closed state
  (bsc#1012628).
- ksmbd: fix same UniqueId for dot and dotdot entries
  (bsc#1012628).
- ksmbd: don't align last entry offset in smb2 query directory
  (bsc#1012628).
- lib/iov_iter: initialize "flags" in new pipe_buffer
  (bsc#1012628).
- arm64: dts: meson-gx: add ATF BL32 reserved-memory region
  (bsc#1012628).
- arm64: dts: meson-g12: add ATF BL32 reserved-memory region
  (bsc#1012628).
- arm64: dts: meson-g12: drop BL32 region from SEI510/SEI610
  (bsc#1012628).
- pidfd: fix test failure due to stack overflow on some arches
  (bsc#1012628).
- selftests: fixup build warnings in pidfd / clone3 tests
  (bsc#1012628).
- mm: io_uring: allow oom-killer from io_uring_setup
  (bsc#1012628).
- ACPI: PM: Revert "Only mark EC GPE for wakeup on Intel systems"
  (bsc#1012628).
- kconfig: let 'shell' return enough output for deep path names
  (bsc#1012628).
- ata: libata-core: Disable TRIM on M88V29 (bsc#1012628).
- soc: aspeed: lpc-ctrl: Block error printing on probe defer cases
  (bsc#1012628).
- xprtrdma: fix pointer derefs in error cases of rpcrdma_ep_create
  (bsc#1012628).
- drm/rockchip: dw_hdmi: Do not leave clock enabled in error case
  (bsc#1012628).
- tracing: Fix tp_printk option related with
  tp_printk_stop_on_boot (bsc#1012628).
- display/amd: decrease message verbosity about watermarks table
  failure (bsc#1012628).
- drm/amdgpu: add utcl2_harvest to gc 10.3.1 (bsc#1012628).
- drm/amd/display: Cap pflip irqs per max otg number
  (bsc#1012628).
- drm/amd/display: fix yellow carp wm clamping (bsc#1012628).
- net: usb: qmi_wwan: Add support for Dell DW5829e (bsc#1012628).
- net: macb: Align the dma and coherent dma masks (bsc#1012628).
- kconfig: fix failing to generate auto.conf (bsc#1012628).
- Update config files.
- commit 607a2b1
* Wed Feb 23 2022 jslaby@suse.cz
- Refresh
  patches.suse/libsubcmd-Fix-use-after-free-for-realloc-.-0.patch.
  Update upstream status.
- commit 1c604e1
* Wed Feb 23 2022 msuchanek@suse.de
- bpf: add config to allow loading modules with BTF mismatches (bsc#1194501).
- Update config files.
- commit 4e672b2
* Wed Feb 23 2022 msuchanek@suse.de
- simplefb: Enable boot time VESA graphic mode selection (bsc#1193250).
- Update config files.
- commit 17ec190
* Mon Feb 21 2022 iivanov@suse.de
- Revert: reset: raspberrypi: Don't reset USB if already up (bsc#1180336)
- commit f3fe985
* Mon Feb 21 2022 jslaby@suse.cz
- libsubcmd: Fix use-after-free for realloc(..., 0) (gcc 12).
- commit 6e98c6d
* Mon Feb 21 2022 mkubecek@suse.cz
- Update to 5.17-rc5
- refresh configs
- commit a9b2c1d
* Wed Feb 16 2022 tzimmermann@suse.de
- Revert "config: x86-64: Enable DRM stack for early-boot graphics (boo#1193472)"
  This reverts commit a6b1e6089c7fbcb3dc149eb1a005a32f0345fa13.
  Going back to efifb/vesafb for now. See boo#1195885 and boo#1195887.
- commit 230a3c7
* Wed Feb 16 2022 tzimmermann@suse.de
- Revert "config: x86-64: Enable DRM stack for early-boot graphics (boo#1193472)"
  This reverts commit 8e500f570e98a3997e9f4bc80b4c45bba2a50789.
  Going back to efifb/vesafb for now. See boo#1195885 and boo#1195887.
- commit 20d1fcf
* Wed Feb 16 2022 jslaby@suse.cz
- Linux 5.16.10 (bsc#1012628).
- integrity: check the return value of audit_log_start()
  (bsc#1012628).
- audit: don't deref the syscall args when checking the openat2
  open_how::flags (bsc#1012628).
- ima: fix reference leak in asymmetric_verify() (bsc#1012628).
- ima: Remove ima_policy file before directory (bsc#1012628).
- ima: Allow template selection with ima_template[_fmt]= after
  ima_hash= (bsc#1012628).
- ima: Do not print policy rule with inactive LSM labels
  (bsc#1012628).
- mmc: sdhci-of-esdhc: Check for error num after setting mask
  (bsc#1012628).
- mmc: core: Wait for command setting 'Power Off Notification'
  bit to complete (bsc#1012628).
- mmc: sh_mmcif: Check for null res pointer (bsc#1012628).
- can: isotp: fix potential CAN frame reception race in
  isotp_rcv() (bsc#1012628).
- can: isotp: fix error path in isotp_sendmsg() to unlock wait
  queue (bsc#1012628).
- net: phy: marvell: Fix RGMII Tx/Rx delays setting in
  88e1121-compatible PHYs (bsc#1012628).
- net: phy: marvell: Fix MDI-x polarity setting in
  88e1118-compatible PHYs (bsc#1012628).
- NFS: Fix initialisation of nfs_client cl_flags field
  (bsc#1012628).
- NFSD: Fix NFSv3 SETATTR/CREATE's handling of large file sizes
  (bsc#1012628).
- NFSD: Fix ia_size underflow (bsc#1012628).
- NFSD: Clamp WRITE offsets (bsc#1012628).
- NFSD: Fix offset type in I/O trace points (bsc#1012628).
- NFSD: Fix the behavior of READ near OFFSET_MAX (bsc#1012628).
- NFS: change nfs_access_get_cached to only report the mask
  (bsc#1012628).
- NFSv4 only print the label when its queried (bsc#1012628).
- nfs: nfs4clinet: check the return value of kstrdup()
  (bsc#1012628).
- NFSv4.1: Fix uninitialised variable in devicenotify
  (bsc#1012628).
- NFSv4 remove zero number of fs_locations entries error check
  (bsc#1012628).
- NFSv4 store server support for fs_location attribute
  (bsc#1012628).
- NFSv4.1 query for fs_location attr on a new file system
  (bsc#1012628).
- NFSv4 expose nfs_parse_server_name function (bsc#1012628).
- NFSv4 handle port presence in fs_location server string
  (bsc#1012628).
- SUNRPC allow for unspecified transport time in rpc_clnt_add_xprt
  (bsc#1012628).
- net/sunrpc: fix reference count leaks in
  rpc_sysfs_xprt_state_change (bsc#1012628).
- sunrpc: Fix potential race conditions in
  rpc_sysfs_xprt_state_change() (bsc#1012628).
- irqchip/realtek-rtl: Service all pending interrupts
  (bsc#1012628).
- perf/x86/rapl: fix AMD event handling (bsc#1012628).
- x86/perf: Avoid warning for Arch LBR without XSAVE
  (bsc#1012628).
- sched: Avoid double preemption in __cond_resched_*lock*()
  (bsc#1012628).
- drm/vc4: Fix deadlock on DSI device attach error (bsc#1012628).
- drm: panel-orientation-quirks: Add quirk for the 1Netbook
  OneXPlayer (bsc#1012628).
- net: sched: Clarify error message when qdisc kind is unknown
  (bsc#1012628).
- powerpc/fixmap: Fix VM debug warning on unmap (bsc#1012628).
- s390/module: test loading modules with a lot of relocations
  (bsc#1012628).
- arm64: Add Cortex-X2 CPU part definition (bsc#1012628).
- arm64: errata: Update ARM64_ERRATUM_[2119858|2224489] with
  Cortex-X2 ranges (bsc#1012628).
- scsi: target: iscsi: Make sure the np under each tpg is unique
  (bsc#1012628).
- scsi: ufs: ufshcd-pltfrm: Check the return value of
  devm_kstrdup() (bsc#1012628).
- scsi: qedf: Add stag_work to all the vports (bsc#1012628).
- scsi: qedf: Fix refcount issue when LOGO is received during TMF
  (bsc#1012628).
- scsi: qedf: Change context reset messages to ratelimited
  (bsc#1012628).
- scsi: pm8001: Fix bogus FW crash for maxcpus=1 (bsc#1012628).
- scsi: ufs: Use generic error code in ufshcd_set_dev_pwr_mode()
  (bsc#1012628).
- scsi: ufs: Treat link loss as fatal error (bsc#1012628).
- scsi: myrs: Fix crash in error case (bsc#1012628).
- net: stmmac: reduce unnecessary wakeups from eee sw timer
  (bsc#1012628).
- PM: hibernate: Remove register_nosave_region_late()
  (bsc#1012628).
- drm/amd/display: Correct MPC split policy for DCN301
  (bsc#1012628).
- drm/amdgpu/display: adjust msleep limit in
  dp_wait_for_training_aux_rd_interval (bsc#1012628).
- drm/amdgpu/display: use msleep rather than udelay for long
  delays (bsc#1012628).
- usb: dwc2: gadget: don't try to disable ep0 in
  dwc2_hsotg_suspend (bsc#1012628).
- perf: Always wake the parent event (bsc#1012628).
- nvme-pci: add the IGNORE_DEV_SUBNQN quirk for Intel P4500/P4600
  SSDs (bsc#1012628).
- MIPS: Fix build error due to PTR used in more places
  (bsc#1012628).
- net: stmmac: dwmac-sun8i: use return val of readl_poll_timeout()
  (bsc#1012628).
- arm64: errata: Add detection for TRBE ignored system register
  writes (bsc#1012628).
- arm64: errata: Add detection for TRBE invalid prohibited states
  (bsc#1012628).
- arm64: errata: Add detection for TRBE trace data corruption
  (bsc#1012628).
- arm64: cpufeature: List early Cortex-A510 parts as having
  broken dbm (bsc#1012628).
- kasan: test: fix compatibility with FORTIFY_SOURCE
  (bsc#1012628).
- KVM: eventfd: Fix false positive RCU usage warning
  (bsc#1012628).
- KVM: nVMX: eVMCS: Filter out VM_EXIT_SAVE_VMX_PREEMPTION_TIMER
  (bsc#1012628).
- KVM: nVMX: Also filter MSR_IA32_VMX_TRUE_PINBASED_CTLS when
  eVMCS (bsc#1012628).
- KVM: SVM: Don't kill SEV guest if SMAP erratum triggers in
  usermode (bsc#1012628).
- KVM: VMX: Set vmcs.PENDING_DBG.BS on #DB in STI/MOVSS blocking
  shadow (bsc#1012628).
- KVM: x86: Report deprecated x87 features in supported CPUID
  (bsc#1012628).
- riscv: fix build with binutils 2.38 (bsc#1012628).
- riscv: Fix XIP_FIXUP_FLASH_OFFSET (bsc#1012628).
- riscv: cpu-hotplug: clear cpu from numa map when teardown
  (bsc#1012628).
- riscv/mm: Add XIP_FIXUP for phys_ram_base (bsc#1012628).
- riscv: eliminate unreliable __builtin_frame_address(1)
  (bsc#1012628).
- gfs2: Fix gfs2_release for non-writers regression (bsc#1012628).
- Revert "gfs2: check context in gfs2_glock_put" (bsc#1012628).
- Revert "PCI/portdrv: Do not setup up IRQs if there are no users"
  (bsc#1012628).
- ARM: dts: imx23-evk: Remove MX23_PAD_SSP1_DETECT from hog group
  (bsc#1012628).
- ARM: dts: Fix boot regression on Skomer (bsc#1012628).
- ARM: socfpga: fix missing RESET_CONTROLLER (bsc#1012628).
- nvme-tcp: fix bogus request completion when failing to send AER
  (bsc#1012628).
- ACPI/IORT: Check node revision for PMCG resources (bsc#1012628).
- PM: s2idle: ACPI: Fix wakeup interrupts handling (bsc#1012628).
- drm/amdgpu/display: change pipe policy for DCN 2.0
  (bsc#1012628).
- drm/rockchip: vop: Correct RK3399 VOP register fields
  (bsc#1012628).
- drm/i915: Disable DRRS on IVB/HSW port != A (bsc#1012628).
- ARM: dts: Fix timer regression for beagleboard revision c
  (bsc#1012628).
- ARM: dts: meson: Fix the UART compatible strings (bsc#1012628).
- ARM: dts: meson8: Fix the UART device-tree schema validation
  (bsc#1012628).
- ARM: dts: meson8b: Fix the UART device-tree schema validation
  (bsc#1012628).
- phy: broadcom: Kconfig: Fix PHY_BRCM_USB config option
  (bsc#1012628).
- tee: optee: do not check memref size on return from Secure World
  (bsc#1012628).
- optee: add error checks in optee_ffa_do_call_with_arg()
  (bsc#1012628).
- staging: fbtft: Fix error path in fbtft_driver_module_init()
  (bsc#1012628).
- ARM: dts: imx6qdl-udoo: Properly describe the SD card detect
  (bsc#1012628).
- phy: xilinx: zynqmp: Fix bus width setting for SGMII
  (bsc#1012628).
- phy: stm32: fix a refcount leak in stm32_usbphyc_pll_enable()
  (bsc#1012628).
- ARM: dts: imx7ulp: Fix 'assigned-clocks-parents' typo
  (bsc#1012628).
- arm64: dts: imx8mq: fix mipi_csi bidirectional port numbers
  (bsc#1012628).
- usb: f_fs: Fix use-after-free for epfile (bsc#1012628).
- arm64: Enable Cortex-A510 erratum 2051678 by default
  (bsc#1012628).
- phy: dphy: Correct clk_pre parameter (bsc#1012628).
- gpio: aggregator: Fix calling into sleeping GPIO controllers
  (bsc#1012628).
- NFS: Don't overfill uncached readdir pages (bsc#1012628).
- NFS: Don't skip directory entries when doing uncached readdir
  (bsc#1012628).
- NFS: Avoid duplicate uncached readdir calls on eof
  (bsc#1012628).
- drm/vc4: hdmi: Allow DBLCLK modes even if horz timing is odd
  (bsc#1012628).
- misc: fastrpc: avoid double fput() on failed usercopy
  (bsc#1012628).
- net: sparx5: Fix get_stat64 crash in tcpdump (bsc#1012628).
- netfilter: nft_payload: don't allow th access for fragments
  (bsc#1012628).
- netfilter: ctnetlink: disable helper autoassign (bsc#1012628).
- arm64: dts: meson-g12b-odroid-n2: fix typo 'dio2133'
  (bsc#1012628).
- arm64: dts: meson-sm1-odroid: use correct enable-gpio pin for
  tf-io regulator (bsc#1012628).
- arm64: dts: meson-sm1-bananapi-m5: fix wrong GPIO domain for
  GPIOE_2 (bsc#1012628).
- arm64: dts: meson-sm1-odroid: fix boot loop after reboot
  (bsc#1012628).
- ixgbevf: Require large buffers for build_skb on 82599VF
  (bsc#1012628).
- tcp: take care of mixed splice()/sendmsg(MSG_ZEROCOPY) case
  (bsc#1012628).
- net: mscc: ocelot: fix all IP traffic getting trapped to CPU
  with PTP over IP (bsc#1012628).
- drm/panel: simple: Assign data from panel_dpi_probe() correctly
  (bsc#1012628).
- s390/module: fix building test_modules_helpers.o with clang
  (bsc#1012628).
- ACPI: PM: s2idle: Cancel wakeup before dispatching EC GPE
  (bsc#1012628).
- gpiolib: Never return internal error codes to user space
  (bsc#1012628).
- gpio: sifive: use the correct register to read output values
  (bsc#1012628).
- fbcon: Avoid 'cap' set but not used warning (bsc#1012628).
- SUNRPC: lock against ->sock changing during sysfs read
  (bsc#1012628).
- gve: Recording rx queue before sending to napi (bsc#1012628).
- bonding: pair enable_port with slave_arr_updates (bsc#1012628).
- net: dsa: mv88e6xxx: don't use devres for mdiobus (bsc#1012628).
- net: dsa: ar9331: register the mdiobus under devres
  (bsc#1012628).
- net: dsa: bcm_sf2: don't use devres for mdiobus (bsc#1012628).
- net: dsa: felix: don't use devres for mdiobus (bsc#1012628).
- net: dsa: ocelot: seville: utilize of_mdiobus_register
  (bsc#1012628).
- net: dsa: seville: register the mdiobus under devres
  (bsc#1012628).
- net: dsa: mt7530: fix kernel bug in mdiobus_free() when
  unbinding (bsc#1012628).
- net: dsa: lantiq_gswip: don't use devres for mdiobus
  (bsc#1012628).
- ibmvnic: don't release napi in __ibmvnic_open() (bsc#1012628).
- net: ethernet: litex: Add the dependency on HAS_IOMEM
  (bsc#1012628).
- ipmr,ip6mr: acquire RTNL before calling ip[6]mr_free_table()
  on failure path (bsc#1012628).
- nfp: flower: fix ida_idx not being released (bsc#1012628).
- net: do not keep the dst cache when uncloning an skb dst and
  its metadata (bsc#1012628).
- net: fix a memleak when uncloning an skb dst and its metadata
  (bsc#1012628).
- veth: fix races around rq->rx_notify_masked (bsc#1012628).
- net: mdio: aspeed: Add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- tipc: rate limit warning for received illegal binding update
  (bsc#1012628).
- net: amd-xgbe: disable interrupts during pci removal
  (bsc#1012628).
- net: dsa: fix panic when DSA master device unbinds on shutdown
  (bsc#1012628).
- drm/amd/pm: fix hwmon node of power1_label create issue
  (bsc#1012628).
- mptcp: netlink: process IPv6 addrs in creating listening sockets
  (bsc#1012628).
- dpaa2-eth: unregister the netdev before disconnecting from
  the PHY (bsc#1012628).
- ice: fix an error code in ice_cfg_phy_fec() (bsc#1012628).
- ice: fix IPIP and SIT TSO offload (bsc#1012628).
- ice: Fix KASAN error in LAG NETDEV_UNREGISTER handler
  (bsc#1012628).
- ice: Avoid RTNL lock when re-creating auxiliary device
  (bsc#1012628).
- net: mscc: ocelot: fix mutex lock error during ethtool stats
  read (bsc#1012628).
- net: dsa: mv88e6xxx: fix use-after-free in
  mv88e6xxx_mdios_unregister (bsc#1012628).
- vt_ioctl: fix array_index_nospec in vt_setactivate
  (bsc#1012628).
- vt_ioctl: add array_index_nospec to VT_ACTIVATE (bsc#1012628).
- n_tty: wake up poll(POLLRDNORM) on receiving data (bsc#1012628).
- eeprom: ee1004: limit i2c reads to I2C_SMBUS_BLOCK_MAX
  (bsc#1012628).
- usb: dwc2: drd: fix soft connect when gadget is unconfigured
  (bsc#1012628).
- Revert "usb: dwc2: drd: fix soft connect when gadget is
  unconfigured" (bsc#1012628).
- net: usb: ax88179_178a: Fix out-of-bounds accesses in RX fixup
  (bsc#1012628).
- usb: ulpi: Move of_node_put to ulpi_dev_release (bsc#1012628).
- usb: ulpi: Call of_node_put correctly (bsc#1012628).
- usb: dwc3: gadget: Prevent core from processing stale TRBs
  (bsc#1012628).
- usb: gadget: udc: renesas_usb3: Fix host to USB_ROLE_NONE
  transition (bsc#1012628).
- USB: gadget: validate interface OS descriptor requests
  (bsc#1012628).
- usb: gadget: rndis: check size of RNDIS_MSG_SET command
  (bsc#1012628).
- usb: gadget: f_uac2: Define specific wTerminalType
  (bsc#1012628).
- usb: raw-gadget: fix handling of dual-direction-capable
  endpoints (bsc#1012628).
- USB: serial: ftdi_sio: add support for Brainboxes US-159/235/320
  (bsc#1012628).
- USB: serial: option: add ZTE MF286D modem (bsc#1012628).
- USB: serial: ch341: add support for GW Instek USB2.0-Serial
  devices (bsc#1012628).
- USB: serial: cp210x: add NCR Retail IO box id (bsc#1012628).
- USB: serial: cp210x: add CPI Bulk Coin Recycler id
  (bsc#1012628).
- speakup-dectlk: Restore pitch setting (bsc#1012628).
- phy: ti: Fix missing sentinel for clk_div_table (bsc#1012628).
- iio: buffer: Fix file related error handling in
  IIO_BUFFER_GET_FD_IOCTL (bsc#1012628).
- fs/proc: task_mmu.c: don't read mapcount for migration entry
  (bsc#1012628).
- mm: vmscan: remove deadlock due to throttling failing to make
  progress (bsc#1012628).
- mm: memcg: synchronize objcg lists with a dedicated spinlock
  (bsc#1012628).
- seccomp: Invalidate seccomp mode to catch death failures
  (bsc#1012628).
- signal: HANDLER_EXIT should clear SIGNAL_UNKILLABLE
  (bsc#1012628).
- s390/cio: verify the driver availability for path_event call
  (bsc#1012628).
- bus: mhi: pci_generic: Add mru_default for Foxconn SDX55
  (bsc#1012628).
- bus: mhi: pci_generic: Add mru_default for Cinterion MV31-W
  (bsc#1012628).
- x86/sgx: Silence softlockup detection when releasing large
  enclaves (bsc#1012628).
- Makefile.extrawarn: Move -Wunaligned-access to W=1
  (bsc#1012628).
- scsi: lpfc: Remove NVMe support if kernel has NVME_FC disabled
  (bsc#1012628).
- scsi: lpfc: Reduce log messages seen after firmware download
  (bsc#1012628).
- MIPS: octeon: Fix missed PTR->PTR_WD conversion (bsc#1012628).
- arm64: dts: imx8mq: fix lcdif port node (bsc#1012628).
- perf: Fix list corruption in perf_cgroup_switch() (bsc#1012628).
- kconfig: fix missing fclose() on error paths (bsc#1012628).
- docs/ABI: testing: aspeed-uart-routing: Escape asterisk
  (bsc#1012628).
- iommu: Fix potential use-after-free during probe (bsc#1012628).
- Update config files.
- commit 3192082
* Wed Feb 16 2022 jslaby@suse.cz
- Refresh
  patches.suse/drm-i915-Workaround-broken-BIOS-DBUF-configuration-o.patch.
  Update upstream status.
- commit 9ffab43
* Wed Feb 16 2022 jslaby@suse.cz
- Refresh
  patches.suse/drm-i915-Populate-pipe-dbuf-slices-more-accurately-d.patch.
  Update upstream status.
- commit ae6fdf3
* Wed Feb 16 2022 jslaby@suse.cz
- Refresh
  patches.suse/drm-i915-Allow-join_mbus-cases-for-adlp-dbuf-configu.patch.
  Update upstream status.
- commit d6e9958
* Wed Feb 16 2022 dmueller@suse.com
- config: Disable CONFIG_READ_ONLY_THP_FOR_FS (bsc#1195774)
- commit 4a5d464
* Wed Feb 16 2022 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: use default dracut modules (bsc#1195926,
  bsc#1198484)
  Let's iron out the reduced initrd optimisation in Tumbleweed.
  Build full blown dracut initrd with systemd for SLE15 SP4.
- commit ea76821
* Tue Feb 15 2022 dmueller@suse.com
- config.conf: reenable armv6hl/armv7hl and aarch64
- Update config files:
  Taken choices from x86_64/default for all new options
  Otherwise =m where possible, =y otherwise unless DEBUG or EXPERIMENTAL
- commit 2ab3225
* Mon Feb 14 2022 tiwai@suse.de
- usb: gadget: clear related members when goto fail
  (CVE-2022-24958 bsc#1195905).
- usb: gadget: don't release an existing dev->buf (CVE-2022-24958
  bsc#1195905).
- commit dedbf20
* Mon Feb 14 2022 tiwai@suse.de
- ALSA: hda/realtek: Fix deadlock by COEF mutex (bsc#1195913).
- ALSA: usb-audio: Don't abort resume upon errors (bsc#1195913).
- ALSA: memalloc: invalidate SG pages before sync (bsc#1195913).
- ALSA: memalloc: Fix dma_need_sync() checks (bsc#1195913).
- commit 86181b2
* Sun Feb 13 2022 mkubecek@suse.cz
- Update to 5.17-rc4
- commit 660988d
* Fri Feb 11 2022 msuchanek@suse.de
- kernel-binary: Do not include sourcedir in certificate path.
  The certs macro runs before build directory is set up so it creates the
  aggregate of supplied certificates in the source directory.
  Using this file directly as the certificate in kernel config works but
  embeds the source directory path in the kernel config.
  To avoid this symlink the certificate to the build directory and use
  relative path to refer to it.
  Also fabricate a certificate in the same location in build directory
  when none is provided.
- commit bb988d4
* Fri Feb 11 2022 msuchanek@suse.de
- BTF: Don't break ABI when debuginfo is disabled.
- commit 9ff5fa4
* Fri Feb 11 2022 msuchanek@suse.de
- constraints: Also adjust disk requirement for x86 and s390.
- commit 9719db0
* Fri Feb 11 2022 msuchanek@suse.de
- constraints: Increase disk space for aarch64
- commit 09c2882
* Fri Feb 11 2022 jslaby@suse.cz
- Linux 5.16.9 (bsc#1012628).
- tipc: improve size validations for received domain records
  (bsc#1012628).
- crypto: api - Move cryptomgr soft dependency into algapi
  (bsc#1012628).
- ksmbd: fix SMB 3.11 posix extension mount failure (bsc#1012628).
- KVM: s390: Return error on SIDA memop on normal guest
  (bsc#1012628).
- moxart: fix potential use-after-free on remove path
  (bsc#1012628).
- ata: libata-core: Fix ata_dev_config_cpr() (bsc#1012628).
- commit 704dc30
* Thu Feb 10 2022 jslaby@suse.cz
- Revert "build initrd without systemd" (bsc#1195775)
  This reverts commit ef4c569b998635a9369390d4e9cfe3a922815c76. systemd is
  needed to at least mount /sys/kernel/security/ during apparmor build.
- commit 5d1f5d2
* Wed Feb  9 2022 jslaby@suse.cz
- rpm/fdupes_relink: dups linking implementation in perl (bsc#1195709)
- rpm/kernel-source.spec.in: use the above
  This is orders of magnitude faster.
- commit 359854d
* Wed Feb  9 2022 jslaby@suse.cz
- Update config files.
  Set CONFIG_FRAMEBUFFER_CONSOLE_LEGACY_ACCELERATION=y on i386. the
  rest to =n. Copied from master branch.
- commit 224cad2
* Wed Feb  9 2022 jslaby@suse.cz
- Linux 5.16.8 (bsc#1012628).
- drm/i915: Disable DSB usage for now (bsc#1012628).
- selinux: fix double free of cond_list on error paths
  (bsc#1012628).
- audit: improve audit queue handling when "audit=1" on cmdline
  (bsc#1012628).
- ipc/sem: do not sleep with a spin lock held (bsc#1012628).
- spi: stm32-qspi: Update spi registering (bsc#1012628).
- ASoC: hdmi-codec: Fix OOB memory accesses (bsc#1012628).
- ASoC: ops: Reject out of bounds values in snd_soc_put_volsw()
  (bsc#1012628).
- ASoC: ops: Reject out of bounds values in snd_soc_put_volsw_sx()
  (bsc#1012628).
- ASoC: ops: Reject out of bounds values in snd_soc_put_xr_sx()
  (bsc#1012628).
- ALSA: usb-audio: Correct quirk for VF0770 (bsc#1012628).
- ALSA: hda: Fix UAF of leds class devs at unbinding
  (bsc#1012628).
- ALSA: hda: realtek: Fix race at concurrent COEF updates
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ASUS GU603 (bsc#1012628).
- ALSA: hda/realtek: Add missing fixup-model entry for Gigabyte
  X570 ALC1220 quirks (bsc#1012628).
- ALSA: hda/realtek: Fix silent output on Gigabyte X570S Aorus
  Master (newer chipset) (bsc#1012628).
- ALSA: hda/realtek: Fix silent output on Gigabyte X570 Aorus
  Xtreme after reboot from Windows (bsc#1012628).
- ata: libata-core: Introduce ATA_HORKAGE_NO_LOG_DIR horkage
  (bsc#1012628).
- btrfs: don't start transaction for scrub if the fs is mounted
  read-only (bsc#1012628).
- btrfs: fix deadlock between quota disable and qgroup rescan
  worker (bsc#1012628).
- btrfs: fix use-after-free after failure to create a snapshot
  (bsc#1012628).
- Revert "fs/9p: search open fids first" (bsc#1012628).
- drm/nouveau: fix off by one in BIOS boundary checking
  (bsc#1012628).
- drm/i915/adlp: Fix TypeC PHY-ready status readout (bsc#1012628).
- drm/amdgpu: fix a potential GPU hang on cyan skillfish
  (bsc#1012628).
- drm/amd/pm: correct the MGpuFanBoost support for Beige Goby
  (bsc#1012628).
- drm/amd/display: Update watermark values for DCN301
  (bsc#1012628).
- drm/amd/display: watermark latencies is not enough on DCN31
  (bsc#1012628).
- drm/amd/display: Force link_rate as LINK_RATE_RBR2 for 2018 15"
  Apple Retina panels (bsc#1012628).
- nvme-fabrics: fix state check in nvmf_ctlr_matches_baseopts()
  (bsc#1012628).
- mm/debug_vm_pgtable: remove pte entry from the page table
  (bsc#1012628).
- mm/pgtable: define pte_index so that preprocessor could
  recognize it (bsc#1012628).
- mm/kmemleak: avoid scanning potential huge holes (bsc#1012628).
- block: bio-integrity: Advance seed correctly for larger interval
  sizes (bsc#1012628).
- dma-buf: heaps: Fix potential spectre v1 gadget (bsc#1012628).
- IB/hfi1: Fix panic with larger ipoib send_queue_size
  (bsc#1012628).
- IB/hfi1: Fix alloc failure with larger txqueuelen (bsc#1012628).
- IB/hfi1: Fix AIP early init panic (bsc#1012628).
- Revert "fbdev: Garbage collect fbdev scrolling acceleration,
  part 1 (from TODO list)" (bsc#1012628).
- Revert "fbcon: Disable accelerated scrolling" (bsc#1012628).
- fbcon: Add option to enable legacy hardware acceleration
  (bsc#1012628).
- mptcp: fix msk traversal in mptcp_nl_cmd_set_flags()
  (bsc#1012628).
- Revert "ASoC: mediatek: Check for error clk pointer"
  (bsc#1012628).
- RISC-V: KVM: make CY, TM, and IR counters accessible in VU mode
  (bsc#1012628).
- KVM: arm64: Avoid consuming a stale esr value when SError occur
  (bsc#1012628).
- KVM: arm64: Stop handle_exit() from handling HVC twice when
  an SError occurs (bsc#1012628).
- arm64: Add Cortex-A510 CPU part definition (bsc#1012628).
- RDMA/cma: Use correct address when leaving multicast group
  (bsc#1012628).
- RDMA/ucma: Protect mc during concurrent multicast leaves
  (bsc#1012628).
- RDMA/siw: Fix refcounting leak in siw_create_qp() (bsc#1012628).
- IB/rdmavt: Validate remote_addr during loopback atomic tests
  (bsc#1012628).
- RDMA/siw: Fix broken RDMA Read Fence/Resume logic (bsc#1012628).
- RDMA/mlx4: Don't continue event handler after memory allocation
  failure (bsc#1012628).
- ALSA: usb-audio: initialize variables that could ignore errors
  (bsc#1012628).
- ALSA: hda: Fix signedness of sscanf() arguments (bsc#1012628).
- ALSA: hda: Skip codec shutdown in case the codec is not
  registered (bsc#1012628).
- iommu/vt-d: Fix potential memory leak in
  intel_setup_irq_remapping() (bsc#1012628).
- iommu/amd: Fix loop timeout issue in iommu_ga_log_enable()
  (bsc#1012628).
- spi: bcm-qspi: check for valid cs before applying chip select
  (bsc#1012628).
- spi: mediatek: Avoid NULL pointer crash in interrupt
  (bsc#1012628).
- spi: meson-spicc: add IRQ check in meson_spicc_probe
  (bsc#1012628).
- spi: uniphier: fix reference count leak in uniphier_spi_probe()
  (bsc#1012628).
- IB/hfi1: Fix tstats alloc and dealloc (bsc#1012628).
- IB/cm: Release previously acquired reference counter in the
  cm_id_priv (bsc#1012628).
- net: ieee802154: hwsim: Ensure proper channel selection at
  probe time (bsc#1012628).
- net: ieee802154: mcr20a: Fix lifs/sifs periods (bsc#1012628).
- net: ieee802154: ca8210: Stop leaking skb's (bsc#1012628).
- netfilter: nft_reject_bridge: Fix for missing reply from
  prerouting (bsc#1012628).
- net: ieee802154: Return meaningful error codes from the netlink
  helpers (bsc#1012628).
- net/smc: Forward wakeup to smc socket waitqueue after fallback
  (bsc#1012628).
- net: stmmac: dwmac-visconti: No change to ETHER_CLOCK_SEL for
  unexpected speed request (bsc#1012628).
- net: stmmac: properly handle with runtime pm in
  stmmac_dvr_remove() (bsc#1012628).
- net: macsec: Fix offload support for NETDEV_UNREGISTER event
  (bsc#1012628).
- net: macsec: Verify that send_sci is on when setting Tx sci
  explicitly (bsc#1012628).
- net: stmmac: dump gmac4 DMA registers correctly (bsc#1012628).
- net, neigh: Do not trigger immediate probes on NUD_FAILED from
  neigh_managed_work (bsc#1012628).
- net: stmmac: ensure PTP time register reads are consistent
  (bsc#1012628).
- drm: mxsfb: Fix NULL pointer dereference (bsc#1012628).
- drm/kmb: Fix for build errors with Warray-bounds (bsc#1012628).
- drm/i915/overlay: Prevent divide by zero bugs in scaling
  (bsc#1012628).
- drm/i915: Lock timeline mutex directly in error path of
  eb_pin_timeline (bsc#1012628).
- drm/amd: avoid suspend on dGPUs w/ s2idle support when runtime
  PM enabled (bsc#1012628).
- ASoC: rt5682: Fix deadlock on resume (bsc#1012628).
- ASoC: fsl: Add missing error handling in pcm030_fabric_probe
  (bsc#1012628).
- ASoC: xilinx: xlnx_formatter_pcm: Make buffer bytes multiple
  of period bytes (bsc#1012628).
- ASoC: simple-card: fix probe failure on platform component
  (bsc#1012628).
- ASoC: cpcap: Check for NULL pointer after calling
  of_get_child_by_name (bsc#1012628).
- ASoC: max9759: fix underflow in speaker_gain_control_put()
  (bsc#1012628).
- ASoC: codecs: wcd938x: fix incorrect used of portid
  (bsc#1012628).
- ASoC: codecs: lpass-rx-macro: fix sidetone register offsets
  (bsc#1012628).
- ASoC: codecs: wcd938x: fix return value of mixer put function
  (bsc#1012628).
- ASoC: qdsp6: q6apm-dai: only stop graphs that are started
  (bsc#1012628).
- pinctrl: sunxi: Fix H616 I2S3 pin data (bsc#1012628).
- pinctrl: intel: Fix a glitch when updating IRQ flags on a
  preconfigured line (bsc#1012628).
- pinctrl: intel: fix unexpected interrupt (bsc#1012628).
- pinctrl: bcm2835: Fix a few error paths (bsc#1012628).
- btrfs: fix use of uninitialized variable at rm device ioctl
  (bsc#1012628).
- scsi: bnx2fc: Make bnx2fc_recv_frame() mp safe (bsc#1012628).
- nfsd: nfsd4_setclientid_confirm mistakenly expires confirmed
  client (bsc#1012628).
- gve: fix the wrong AdminQ buffer queue index check
  (bsc#1012628).
- bpf: Use VM_MAP instead of VM_ALLOC for ringbuf (bsc#1012628).
- selftests/exec: Remove pipe from TEST_GEN_FILES (bsc#1012628).
- selftests: futex: Use variable MAKE instead of make
  (bsc#1012628).
- tools/resolve_btfids: Do not print any commands when building
  silently (bsc#1012628).
- e1000e: Separate ADP board type from TGP (bsc#1012628).
- rtc: cmos: Evaluate century appropriate (bsc#1012628).
- objtool: Fix truncated string warning (bsc#1012628).
- kvm: add guest_state_{enter,exit}_irqoff() (bsc#1012628).
- kvm/arm64: rework guest entry logic (bsc#1012628).
- perf: Copy perf_event_attr::sig_data on modification
  (bsc#1012628).
- perf stat: Fix display of grouped aliased events (bsc#1012628).
- perf/x86/intel/pt: Fix crash with stop filters in single-range
  mode (bsc#1012628).
- x86/perf: Default set FREEZE_ON_SMI for all (bsc#1012628).
- EDAC/altera: Fix deferred probing (bsc#1012628).
- EDAC/xgene: Fix deferred probing (bsc#1012628).
- ext4: prevent used blocks from being allocated during fast
  commit replay (bsc#1012628).
- ext4: modify the logic of ext4_mb_new_blocks_simple
  (bsc#1012628).
- ext4: fix error handling in ext4_restore_inline_data()
  (bsc#1012628).
- ext4: fix error handling in ext4_fc_record_modified_inode()
  (bsc#1012628).
- ext4: fix incorrect type issue during replay_del_range
  (bsc#1012628).
- net: dsa: mt7530: make NET_DSA_MT7530 select MEDIATEK_GE_PHY
  (bsc#1012628).
- cgroup/cpuset: Fix "suspicious RCU usage" lockdep warning
  (bsc#1012628).
- tools include UAPI: Sync sound/asound.h copy with the kernel
  sources (bsc#1012628).
- gpio: idt3243x: Fix an ignored error return from
  platform_get_irq() (bsc#1012628).
- gpio: mpc8xxx: Fix an ignored error return from
  platform_get_irq() (bsc#1012628).
- selftests: nft_concat_range: add test for reload with no
  element add/del (bsc#1012628).
- selftests: netfilter: check stateless nat udp checksum fixup
  (bsc#1012628).
- Update config files.
- commit 1b44d21
* Tue Feb  8 2022 jslaby@suse.cz
- Refresh
  patches.suse/0001-lib-raid6-Use-strict-priority-ranking-for-pq-gen-ben.patch.
- Refresh
  patches.suse/0001-lib-raid6-skip-benchmark-of-non-chosen-xor_syndrome-.patch.
- Refresh
  patches.suse/cifs-fix-workstation_name-for-multiuser-mounts.patch.
  Update upstream status and move to sorted section.
- commit 9ebef3e
* Mon Feb  7 2022 tiwai@suse.de
- drm/i915: Workaround broken BIOS DBUF configuration on TGL/RKL
  (bsc#1193640).
- drm/i915: Populate pipe dbuf slices more accurately during
  readout (bsc#1193640).
- drm/i915: Allow !join_mbus cases for adlp+ dbuf configuration
  (bsc#1193640).
- commit 0503f69
* Sun Feb  6 2022 mkubecek@suse.cz
- Update to 5.17-rc3
- eliminate 1 patch
  - patches.suse/cifs-fix-workstation_name-for-multiuser-mounts.patch
- update configs
  - FRAMEBUFFER_CONSOLE_LEGACY_ACCELERATION=n (y on i386)
- commit 335402f
* Sun Feb  6 2022 jslaby@suse.cz
- Linux 5.16.7 (bsc#1012628).
- Revert "drm/vc4: hdmi: Make sure the device is powered with CEC"
  again (bsc#1012628).
- Revert "drm/vc4: hdmi: Make sure the device is powered with CEC"
  (bsc#1012628).
- commit 37d59fa
* Sat Feb  5 2022 jslaby@suse.cz
- Linux 5.16.6 (bsc#1012628).
- ovl: fix NULL pointer dereference in copy up warning
  (bsc#1012628).
- tcp: add missing tcp_skb_can_collapse() test in
  tcp_shift_skb_data() (bsc#1012628).
- tcp: fix mem under-charging with zerocopy sendmsg()
  (bsc#1012628).
- af_packet: fix data-race in packet_setsockopt /
  packet_setsockopt (bsc#1012628).
- e1000e: Handshake with CSME starts from ADL platforms
  (bsc#1012628).
- cpuset: Fix the bug that subpart_cpus updated wrongly in
  update_cpumask() (bsc#1012628).
- bpf: Fix possible race in inc_misses_counter (bsc#1012628).
- net: ipa: request IPA register values be retained (bsc#1012628).
- rtnetlink: make sure to refresh master_dev/m_ops in
  __rtnl_newlink() (bsc#1012628).
- net: sched: fix use-after-free in tc_new_tfilter()
  (bsc#1012628).
- fanotify: Fix stale file descriptor in copy_event_to_user()
  (bsc#1012628).
- net: amd-xgbe: Fix skb data length underflow (bsc#1012628).
- net: amd-xgbe: ensure to reset the tx_timer_active flag
  (bsc#1012628).
- i40e: Fix reset path while removing the driver (bsc#1012628).
- i40e: Fix reset bw limit when DCB enabled with 1 TC
  (bsc#1012628).
- ipheth: fix EOVERFLOW in ipheth_rcvbulk_callback (bsc#1012628).
- net/mlx5e: Avoid implicit modify hdr for decap drop rule
  (bsc#1012628).
- net/mlx5: E-Switch, Fix uninitialized variable modact
  (bsc#1012628).
- net/mlx5e: Fix broken SKB allocation in HW-GRO (bsc#1012628).
- net/mlx5e: Fix wrong calculation of header index in HW_GRO
  (bsc#1012628).
- net/mlx5e: Avoid field-overflowing memcpy() (bsc#1012628).
- net/mlx5: Bridge, Fix devlink deadlock on net namespace deletion
  (bsc#1012628).
- net/mlx5e: Don't treat small ceil values as unlimited in HTB
  offload (bsc#1012628).
- net/mlx5: Fix offloading with ESWITCH_IPV4_TTL_MODIFY_ENABLE
  (bsc#1012628).
- net/mlx5e: TC, Reject rules with forward and drop actions
  (bsc#1012628).
- net/mlx5e: Fix module EEPROM query (bsc#1012628).
- net/mlx5: Use del_timer_sync in fw reset flow of halting poll
  (bsc#1012628).
- net/mlx5e: Fix handling of wrong devices during bond netevent
  (bsc#1012628).
- net/mlx5: Bridge, ensure dev_name is null-terminated
  (bsc#1012628).
- net/mlx5: Bridge, take rtnl lock in init error handler
  (bsc#1012628).
- net/mlx5e: TC, Reject rules with drop and modify hdr action
  (bsc#1012628).
- net/mlx5e: IPsec: Fix tunnel mode crypto offload for non
  TCP/UDP traffic (bsc#1012628).
- net/mlx5e: IPsec: Fix crypto offload for non TCP/UDP
  encapsulated traffic (bsc#1012628).
- lockd: fix failure to cleanup client locks (bsc#1012628).
- lockd: fix server crash on reboot of client holding lock
  (bsc#1012628).
- ovl: don't fail copy up if no fileattr support on upper
  (bsc#1012628).
- net: phy: Fix qca8081 with speeds lower than 2.5Gb/s
  (bsc#1012628).
- Revert "mm/gup: small refactoring: simplify try_grab_page()"
  (bsc#1012628).
- cgroup-v1: Require capabilities to set release_agent
  (bsc#1012628).
- drm/vc4: hdmi: Make sure the device is powered with CEC
  (bsc#1012628).
- net: ipa: prevent concurrent replenish (bsc#1012628).
- net: ipa: use a bitmap for endpoint replenish_enabled
  (bsc#1012628).
- selftests: mptcp: fix ipv6 routing setup (bsc#1012628).
- PCI: pciehp: Fix infinite loop in IRQ handler upon power fault
  (bsc#1012628).
- commit 1e2a324
* Sat Feb  5 2022 tiwai@suse.de
- Refresh patches.suse/Input-elan_i2c-Add-deny-list-for-Lenovo-Yoga-Slim-7.patch
  Fix section mistmatch warning
- commit 672f0d5
* Wed Feb  2 2022 jslaby@suse.cz
- cifs: fix workstation_name for multiuser mounts (bsc#1195360).
- commit 6d27379
* Wed Feb  2 2022 jslaby@suse.cz
- Linux 5.16.5 (bsc#1012628).
- mtd: rawnand: mpc5121: Remove unused variable in
  ads5121_select_chip() (bsc#1012628).
- block: Fix wrong offset in bio_truncate() (bsc#1012628).
- KVM: nVMX: Allow VMREAD when Enlightened VMCS is in use
  (bsc#1012628).
- KVM: nVMX: Implement evmcs_field_offset() suitable for
  handle_vmread() (bsc#1012628).
- KVM: nVMX: Rename vmcs_to_field_offset{,_table} (bsc#1012628).
- tools/testing/scatterlist: add missing defines (bsc#1012628).
- usr/include/Makefile: add linux/nfc.h to the compile-test
  coverage (bsc#1012628).
- usb: dwc3: xilinx: fix uninitialized return value (bsc#1012628).
- psi: fix "defined but not used" warnings when CONFIG_PROC_FS=n
  (bsc#1012628).
- psi: fix "no previous prototype" warnings when CONFIG_CGROUPS=n
  (bsc#1012628).
- perf/core: Fix cgroup event list management (bsc#1012628).
- PCI: mt7621: Remove unused function pcie_rmw() (bsc#1012628).
- dt-bindings: can: tcan4x5x: fix mram-cfg RX FIFO config
  (bsc#1012628).
- irqchip/realtek-rtl: Fix off-by-one in routing (bsc#1012628).
- irqchip/realtek-rtl: Map control data to virq (bsc#1012628).
- net: bridge: vlan: fix memory leak in __allowed_ingress
  (bsc#1012628).
- ipv4: remove sparse error in ip_neigh_gw4() (bsc#1012628).
- ipv4: tcp: send zero IPID in SYNACK messages (bsc#1012628).
- ipv4: raw: lock the socket in raw_bind() (bsc#1012628).
- net: bridge: vlan: fix single net device option dumping
  (bsc#1012628).
- Revert "ipv6: Honor all IPv6 PIO Valid Lifetime values"
  (bsc#1012628).
- gve: Fix GFP flags when allocing pages (bsc#1012628).
- ceph: put the requests/sessions when it fails to alloc memory
  (bsc#1012628).
- KVM: selftests: Don't skip L2's VMCALL in SMM test for SVM guest
  (bsc#1012628).
- Revert "drm/ast: Support 1600x900 with 108MHz PCLK"
  (bsc#1012628).
- sch_htb: Fail on unsupported parameters when offload is
  requested (bsc#1012628).
- KVM: selftests: Re-enable access_tracking_perf_test
  (bsc#1012628).
- net: hns3: handle empty unknown interrupt for VF (bsc#1012628).
- net: cpsw: Properly initialise struct page_pool_params
  (bsc#1012628).
- yam: fix a memory leak in yam_siocdevprivate() (bsc#1012628).
- drm/msm/a6xx: Add missing suspend_count increment (bsc#1012628).
- drm/msm/dpu: invalid parameter check in dpu_setup_dspp_pcc
  (bsc#1012628).
- drm/msm/hdmi: Fix missing put_device() call in msm_hdmi_get_phy
  (bsc#1012628).
- hwmon: (nct6775) Fix crash in clear_caseopen (bsc#1012628).
- can: tcan4x5x: regmap: fix max register value (bsc#1012628).
- video: hyperv_fb: Fix validation of screen resolution
  (bsc#1012628).
- net/smc: Transitional solution for clcsock race issue
  (bsc#1012628).
- ibmvnic: don't spin in tasklet (bsc#1012628).
- ibmvnic: init ->running_cap_crqs early (bsc#1012628).
- ibmvnic: Allow extra failures before disabling (bsc#1012628).
- ipv4: fix ip option filtering for locally generated fragments
  (bsc#1012628).
- powerpc/perf: Fix power_pmu_disable to call
  clear_pmi_irq_pending only if PMI is pending (bsc#1012628).
- hwmon: (adt7470) Prevent divide by zero in adt7470_fan_write()
  (bsc#1012628).
- hwmon: (lm90) Fix sysfs and udev notifications (bsc#1012628).
- hwmon: (lm90) Mark alert as broken for MAX6654 (bsc#1012628).
- hwmon: (lm90) Re-enable interrupts after alert clears
  (bsc#1012628).
- Drivers: hv: balloon: account for vmbus packet header in
  max_pkt_size (bsc#1012628).
- block: fix memory leak in
  disk_register_independent_access_ranges (bsc#1012628).
- io_uring: fix bug in slow unregistering of nodes (bsc#1012628).
- efi/libstub: arm64: Fix image check alignment at entry
  (bsc#1012628).
- rxrpc: Adjust retransmission backoff (bsc#1012628).
- octeontx2-af: Add KPU changes to parse NGIO as separate layer
  (bsc#1012628).
- octeontx2-pf: Forward error codes to VF (bsc#1012628).
- octeontx2-af: cn10k: Do not enable RPM loopback for LPC
  interfaces (bsc#1012628).
- octeontx2-af: Increase link credit restore polling timeout
  (bsc#1012628).
- octeontx2-pf: cn10k: Ensure valid pointers are freed to aura
  (bsc#1012628).
- octeontx2-af: cn10k: Use appropriate register for LMAC enable
  (bsc#1012628).
- octeontx2-af: Retry until RVU block reset complete
  (bsc#1012628).
- octeontx2-af: Fix LBK backpressure id count (bsc#1012628).
- octeontx2-af: Do not fixup all VF action entries (bsc#1012628).
- phylib: fix potential use-after-free (bsc#1012628).
- net: stmmac: dwmac-visconti: Fix clock configuration for RMII
  mode (bsc#1012628).
- net: stmmac: dwmac-visconti: Fix bit definitions for
  ETHER_CLK_SEL (bsc#1012628).
- ethtool: Fix link extended state for big endian (bsc#1012628).
- net: phy: broadcom: hook up soft_reset for BCM54616S
  (bsc#1012628).
- sched/pelt: Relax the sync of util_sum with util_avg
  (bsc#1012628).
- perf: Fix perf_event_read_local() time (bsc#1012628).
- powerpc/64s: Mask SRR0 before checking against the masked NIP
  (bsc#1012628).
- remoteproc: qcom: q6v5: fix service routines build errors
  (bsc#1012628).
- netfilter: conntrack: don't increment invalid counter on
  NF_REPEAT (bsc#1012628).
- powerpc64/bpf: Limit 'ldbrx' to processors compliant with ISA
  v2.06 (bsc#1012628).
- SUNRPC: Don't dereference xprt->snd_task if it's a cookie
  (bsc#1012628).
- KVM: arm64: pkvm: Use the mm_ops indirection for cache
  maintenance (bsc#1012628).
- NFS: Ensure the server has an up to date ctime before renaming
  (bsc#1012628).
- NFS: Ensure the server has an up to date ctime before
  hardlinking (bsc#1012628).
- ipv6: annotate accesses to fn->fn_sernum (bsc#1012628).
- drm/msm/dsi: invalid parameter check in msm_dsi_phy_enable
  (bsc#1012628).
- drm/msm/dsi: Fix missing put_device() call in dsi_get_phy
  (bsc#1012628).
- drm/msm: Fix wrong size calculation (bsc#1012628).
- net-procfs: show net devices bound packet types (bsc#1012628).
- NFSv4: nfs_atomic_open() can race when looking up a non-regular
  file (bsc#1012628).
- NFSv4: Handle case where the lookup of a directory fails
  (bsc#1012628).
- hwmon: (lm90) Reduce maximum conversion rate for G781
  (bsc#1012628).
- ipv4: avoid using shared IP generator for connected sockets
  (bsc#1012628).
- ping: fix the sk_bound_dev_if match in ping_lookup
  (bsc#1012628).
- hwmon: (lm90) Mark alert as broken for MAX6680 (bsc#1012628).
- hwmon: (lm90) Mark alert as broken for MAX6646/6647/6649
  (bsc#1012628).
- net: fix information leakage in /proc/net/ptype (bsc#1012628).
- ARM: 9170/1: fix panic when kasan and kprobe are enabled
  (bsc#1012628).
- ipv6_tunnel: Rate limit warning messages (bsc#1012628).
- scsi: bnx2fc: Flush destroy_work queue before calling
  bnx2fc_interface_put() (bsc#1012628).
- scsi: elx: efct: Don't use GFP_KERNEL under spin lock
  (bsc#1012628).
- rpmsg: char: Fix race between the release of rpmsg_eptdev and
  cdev (bsc#1012628).
- rpmsg: char: Fix race between the release of rpmsg_ctrldev
  and cdev (bsc#1012628).
- usb: roles: fix include/linux/usb/role.h compile issue
  (bsc#1012628).
- i40e: fix unsigned stat widths (bsc#1012628).
- i40e: Fix for failed to init adminq while VF reset
  (bsc#1012628).
- i40e: Fix queues reservation for XDP (bsc#1012628).
- i40e: Fix issue when maximum queues is exceeded (bsc#1012628).
- i40e: Increase delay to 1 s after global EMP reset
  (bsc#1012628).
- powerpc/32: Fix boot failure with GCC latent entropy plugin
  (bsc#1012628).
- powerpc/32s: Fix kasan_init_region() for KASAN (bsc#1012628).
- powerpc/32s: Allocate one 256k IBAT instead of two consecutives
  128k IBATs (bsc#1012628).
- x86/cpu: Add Xeon Icelake-D to list of CPUs that support PPIN
  (bsc#1012628).
- x86/MCE/AMD: Allow thresholding interface updates after init
  (bsc#1012628).
- PCI/sysfs: Find shadow ROM before static attribute
  initialization (bsc#1012628).
- sched/membarrier: Fix membarrier-rseq fence command missing
  from query bitmask (bsc#1012628).
- ocfs2: fix a deadlock when commit trans (bsc#1012628).
- jbd2: export jbd2_journal_[grab|put]_journal_head (bsc#1012628).
- mm, kasan: use compare-exchange operation to set KASAN page tag
  (bsc#1012628).
- mt76: connac: introduce MCU_CE_CMD macro (bsc#1012628).
- ucsi_ccg: Check DEV_INT bit only when starting CCG4
  (bsc#1012628).
- usb: typec: tcpm: Do not disconnect when receiving VSAFE0V
  (bsc#1012628).
- usb: typec: tcpm: Do not disconnect while receiving VBUS off
  (bsc#1012628).
- usb: typec: tcpci: don't touch CC line if it's Vconn source
  (bsc#1012628).
- USB: core: Fix hang in usb_kill_urb by adding memory barriers
  (bsc#1012628).
- usb: dwc3: xilinx: Fix error handling when getting USB3 PHY
  (bsc#1012628).
- usb: dwc3: xilinx: Skip resets and USB3 register settings for
  USB2.0 mode (bsc#1012628).
- usb: cdnsp: Fix segmentation fault in cdns_lost_power function
  (bsc#1012628).
- usb: gadget: f_sourcesink: Fix isoc transfer for
  USB_SPEED_SUPER_PLUS (bsc#1012628).
- usb: common: ulpi: Fix crash in ulpi_match() (bsc#1012628).
- usb: xhci-plat: fix crash when suspend if remote wake enable
  (bsc#1012628).
- usb-storage: Add unusual-devs entry for VL817 USB-SATA bridge
  (bsc#1012628).
- kbuild: remove include/linux/cyclades.h from header file check
  (bsc#1012628).
- tty: Add support for Brainboxes UC cards (bsc#1012628).
- tty: Partially revert the removal of the Cyclades public API
  (bsc#1012628).
- tty: n_gsm: fix SW flow control encoding/handling (bsc#1012628).
- tty: rpmsg: Fix race condition releasing tty port (bsc#1012628).
- serial: stm32: fix software flow control transfer (bsc#1012628).
- serial: 8250: of: Fix mapped region size when using reg-offset
  property (bsc#1012628).
- serial: pl011: Fix incorrect rs485 RTS polarity on set_mctrl
  (bsc#1012628).
- dm: properly fix redundant bio-based IO accounting
  (bsc#1012628).
- block: add bio_start_io_acct_time() to control start_time
  (bsc#1012628).
- dm: revert partial fix for redundant bio-based IO accounting
  (bsc#1012628).
- arm64: extable: fix load_unaligned_zeropad() reg indices
  (bsc#1012628).
- security, lsm: dentry_init_security() Handle multi LSM
  registration (bsc#1012628).
- KVM: PPC: Book3S HV Nested: Fix nested HFSCR being clobbered
  with multiple vCPUs (bsc#1012628).
- KVM: x86: Sync the states size with the XCR0/IA32_XSS at,
  any time (bsc#1012628).
- KVM: x86: Update vCPU's runtime CPUID on write to MSR_IA32_XSS
  (bsc#1012628).
- KVM: x86: Keep MSR_IA32_XSS unchanged for INIT (bsc#1012628).
- KVM: x86: Check .flags in kvm_cpuid_check_equal() too
  (bsc#1012628).
- KVM: x86: Forcibly leave nested virt when SMM state is toggled
  (bsc#1012628).
- KVM: x86: Free kvm_cpuid_entry2 array on post-KVM_RUN
  KVM_SET_CPUID{,2} (bsc#1012628).
- KVM: x86: Move CPUID.(EAX=0x12,ECX=1) mangling to
  __kvm_update_cpuid_runtime() (bsc#1012628).
- KVM: x86: nSVM: skip eax alignment check for non-SVM
  instructions (bsc#1012628).
- KVM: SVM: Don't intercept #GP for SEV guests (bsc#1012628).
- KVM: SVM: Never reject emulation due to SMAP errata for !SEV
  guests (bsc#1012628).
- KVM: LAPIC: Also cancel preemption timer during SET_LAPIC
  (bsc#1012628).
- drm/amd/display: Wrap dcn301_calculate_wm_and_dlg for FPU
  (bsc#1012628).
- drm/amd/display: Fix FP start/end for dcn30_internal_validate_bw
  (bsc#1012628).
- drm/amdgpu/display: Remove t_srx_delay_us (bsc#1012628).
- drm/amdgpu: filter out radeon secondary ids as well
  (bsc#1012628).
- drm/atomic: Add the crtc to affected crtc only if uapi.enable =
  true (bsc#1012628).
- drm/etnaviv: relax submit size limits (bsc#1012628).
- perf/x86/intel: Add a quirk for the calculation of the number
  of counters on Alder Lake (bsc#1012628).
- perf/x86/intel/uncore: Fix CAS_COUNT_WRITE issue for ICX
  (bsc#1012628).
- powerpc/audit: Fix syscall_get_arch() (bsc#1012628).
- psi: Fix uaf issue when psi trigger is destroyed while being
  polled (bsc#1012628).
- Revert "KVM: SVM: avoid infinite loop on NPF from bad address"
  (bsc#1012628).
- fsnotify: fix fsnotify hooks in pseudo filesystems
  (bsc#1012628).
- fsnotify: invalidate dcache before IN_DELETE event
  (bsc#1012628).
- ceph: set pool_ns in new inode layout for async creates
  (bsc#1012628).
- ceph: properly put ceph_string reference after async create
  attempt (bsc#1012628).
- tracing: Don't inc err_log entry count if entry allocation fails
  (bsc#1012628).
- tracing: Propagate is_signed to expression (bsc#1012628).
- tracing/histogram: Fix a potential memory leak for kstrdup()
  (bsc#1012628).
- PM: wakeup: simplify the output logic of pm_show_wakelocks()
  (bsc#1012628).
- efi: runtime: avoid EFIv2 runtime services on Apple x86 machines
  (bsc#1012628).
- udf: Fix NULL ptr deref when converting from inline format
  (bsc#1012628).
- udf: Restore i_lenAlloc when inode expansion fails
  (bsc#1012628).
- scsi: zfcp: Fix failed recovery on gone remote port with
  non-NPIV FCP devices (bsc#1012628).
- ucount: Make get_ucount a safe get_user replacement
  (bsc#1012628).
- powerpc/bpf: Update ldimm64 instructions during extra pass
  (bsc#1012628).
- powerpc32/bpf: Fix codegen for bpf-to-bpf calls (bsc#1012628).
- bpf: Guard against accessing NULL pt_regs in
  bpf_get_task_stack() (bsc#1012628).
- s390/nmi: handle vector validity failures for KVM guests
  (bsc#1012628).
- s390/nmi: handle guarded storage validity failures for KVM
  guests (bsc#1012628).
- s390/hypfs: include z/VM guests with access control group set
  (bsc#1012628).
- s390/module: fix loading modules with a lot of relocations
  (bsc#1012628).
- KVM: arm64: vgic-v3: Restrict SEIS workaround to known broken
  systems (bsc#1012628).
- KVM: arm64: Use shadow SPSR_EL1 when injecting exceptions on
  !VHE (bsc#1012628).
- ARM: 9180/1: Thumb2: align ALT_UP() sections in modules
  sufficiently (bsc#1012628).
- ARM: 9179/1: uaccess: avoid alignment faults in
  copy_[from|to]_kernel_nofault (bsc#1012628).
- net: stmmac: skip only stmmac_ptp_register when resume from
  suspend (bsc#1012628).
- net: stmmac: configure PTP clock source prior to PTP
  initialization (bsc#1012628).
- net: sfp: ignore disabled SFP node (bsc#1012628).
- can: m_can: m_can_fifo_{read,write}: don't read or write
  from/to FIFO if length is 0 (bsc#1012628).
- btrfs: update writeback index when starting defrag
  (bsc#1012628).
- btrfs: add back missing dirty page rate limiting to defrag
  (bsc#1012628).
- btrfs: fix deadlock when reserving space during defrag
  (bsc#1012628).
- btrfs: defrag: properly update range->start for autodefrag
  (bsc#1012628).
- btrfs: defrag: fix wrong number of defragged sectors
  (bsc#1012628).
- btrfs: allow defrag to be interruptible (bsc#1012628).
- btrfs: fix too long loop when defragging a 1 byte file
  (bsc#1012628).
- Bluetooth: refactor malicious adv data check (bsc#1012628).
- commit 5681efc
* Tue Feb  1 2022 tiwai@suse.de
- Input: synaptics: retry query upon error (bsc#1194086).
- commit cfcc1f5
* Tue Feb  1 2022 tiwai@suse.de
- Input: elan_i2c: Add deny list for Lenovo Yoga Slim 7
  (bsc#1193064).
- commit 26e60ad
* Mon Jan 31 2022 ludwig.nussel@suse.de
- kernel-obs-build: include 9p (boo#1195353)
  To be able to share files between host and the qemu vm of the build
  script, the 9p and 9p_virtio kernel modules need to be included in
  the initrd of kernel-obs-build.
- commit 0cfe67a
* Mon Jan 31 2022 tzimmermann@suse.de
- config: x86-64: Enable DRM stack for early-boot graphics (boo#1193472)
  Replace fbdev's generic drivers with DRM-based simpledrm. Enables the
  DRM graphics stack for early-boot graphics, recovery and unsupported
  chipsets.
- commit 89d164b
* Sun Jan 30 2022 mkubecek@suse.cz
- Update to 5.17-rc2
- eliminate 3 patches
  - patches.suse/s390-uaccess-fix-compile-error.patch
  - patches.suse/tcp-Add-a-stub-for-sk_defer_free_flush.patch
  - patches.suse/tcp-add-a-missing-sk_defer_free_flush-in-tcp_splice_.patch
- refresh configs
- commit e736c55
* Sat Jan 29 2022 jslaby@suse.cz
- Linux 5.16.4 (bsc#1012628).
- drm/amd/display: reset dcn31 SMU mailbox on failures
  (bsc#1012628).
- io_uring: fix not released cached task refs (bsc#1012628).
- bnx2x: Utilize firmware 7.13.21.0 (bsc#1012628).
- bnx2x: Invalidate fastpath HSI version for VFs (bsc#1012628).
- memcg: better bounds on the memcg stats updates (bsc#1012628).
- rcu: Tighten rcu_advance_cbs_nowake() checks (bsc#1012628).
- select: Fix indefinitely sleeping task in
  poll_schedule_timeout() (bsc#1012628).
- arm64/bpf: Remove 128MB limit for BPF JIT programs
  (bsc#1012628).
- commit b146677
* Sat Jan 29 2022 tiwai@suse.de
- drm/vmwgfx: Fix stale file descriptors on failed usercopy
  (CVE-2022-22942 bsc#1195065).
- commit c31491c
* Fri Jan 28 2022 mkubecek@suse.cz
- tcp: add a missing sk_defer_free_flush() in tcp_splice_read()
  (git-fixes).
- commit f8aca60
* Fri Jan 28 2022 mkubecek@suse.cz
- tcp: Add a stub for sk_defer_free_flush().
  Fix another s390x/zfcpdump build failure.
- commit 235f271
* Fri Jan 28 2022 mkubecek@suse.cz
- s390/uaccess: fix compile error.
  Fix s390x/zfcpdump build.
- commit d01fea5
* Fri Jan 28 2022 jslaby@suse.cz
- Linux 5.16.3 (bsc#1012628).
- KVM: x86/mmu: Fix write-protection of PTs mapped by the TDP MMU
  (bsc#1012628).
- KVM: VMX: switch blocked_vcpu_on_cpu_lock to raw spinlock
  (bsc#1012628).
- HID: Ignore battery for Elan touchscreen on HP Envy X360
  15t-dr100 (bsc#1012628).
- HID: uhid: Fix worker destroying device without any protection
  (bsc#1012628).
- ALSA: core: Fix SSID quirk lookup for subvendor=0 (bsc#1012628).
- cifs: free ntlmsspblob allocated in negotiate (bsc#1012628).
- f2fs: fix to do sanity check on inode type during garbage
  collection (bsc#1012628).
- f2fs: fix to do sanity check in is_alive() (bsc#1012628).
- f2fs: fix to do sanity check on last xattr entry in
  __f2fs_setxattr() (bsc#1012628).
- f2fs: avoid EINVAL by SBI_NEED_FSCK when pinning a file
  (bsc#1012628).
- nfc: llcp: fix NULL error pointer dereference on sendmsg()
  after failed bind() (bsc#1012628).
- mtd: rawnand: gpmi: Add ERR007117 protection for
  nfc_apply_timings (bsc#1012628).
- mtd: rawnand: gpmi: Remove explicit default gpmi clock setting
  for i.MX6 (bsc#1012628).
- mtd: Fixed breaking list in __mtd_del_partition (bsc#1012628).
- mtd: rawnand: davinci: Don't calculate ECC when reading page
  (bsc#1012628).
- mtd: rawnand: davinci: Avoid duplicated page read (bsc#1012628).
- mtd: rawnand: davinci: Rewrite function description
  (bsc#1012628).
- mtd: rawnand: Export nand_read_page_hwecc_oob_first()
  (bsc#1012628).
- mtd: rawnand: ingenic: JZ4740 needs 'oob_first' read page
  function (bsc#1012628).
- riscv: Get rid of MAXPHYSMEM configs (bsc#1012628).
- RISC-V: Use common riscv_cpuid_to_hartid_mask() for both SMP=y
  and SMP=n (bsc#1012628).
- riscv: try to allocate crashkern region from 32bit addressible
  memory (bsc#1012628).
- riscv: Don't use va_pa_offset on kdump (bsc#1012628).
- riscv: use hart id instead of cpu id on machine_kexec
  (bsc#1012628).
- riscv: mm: fix wrong phys_ram_base value for RV64 (bsc#1012628).
- x86/gpu: Reserve stolen memory for first integrated Intel GPU
  (bsc#1012628).
- tools/nolibc: x86-64: Fix startup code bug (bsc#1012628).
- crypto: x86/aesni - don't require alignment of data
  (bsc#1012628).
- tools/nolibc: i386: fix initial stack alignment (bsc#1012628).
- tools/nolibc: fix incorrect truncation of exit code
  (bsc#1012628).
- rtc: cmos: take rtc_lock while reading from CMOS (bsc#1012628).
- net: phy: marvell: add Marvell specific PHY loopback
  (bsc#1012628).
- ksmbd: uninitialized variable in create_socket() (bsc#1012628).
- ksmbd: fix guest connection failure with nautilus (bsc#1012628).
- ksmbd: add support for smb2 max credit parameter (bsc#1012628).
- ksmbd: move credit charge deduction under processing request
  (bsc#1012628).
- ksmbd: limits exceeding the maximum allowable outstanding
  requests (bsc#1012628).
- ksmbd: add reserved room in ipc request/response (bsc#1012628).
- media: cec: fix a deadlock situation (bsc#1012628).
- media: ov8865: Disable only enabled regulators on error path
  (bsc#1012628).
- media: v4l2-ioctl.c: readbuffers depends on V4L2_CAP_READWRITE
  (bsc#1012628).
- media: flexcop-usb: fix control-message timeouts (bsc#1012628).
- media: mceusb: fix control-message timeouts (bsc#1012628).
- media: em28xx: fix control-message timeouts (bsc#1012628).
- media: cpia2: fix control-message timeouts (bsc#1012628).
- media: s2255: fix control-message timeouts (bsc#1012628).
- media: dib0700: fix undefined behavior in tuner shutdown
  (bsc#1012628).
- media: redrat3: fix control-message timeouts (bsc#1012628).
- media: pvrusb2: fix control-message timeouts (bsc#1012628).
- media: stk1160: fix control-message timeouts (bsc#1012628).
- media: cec-pin: fix interrupt en/disable handling (bsc#1012628).
- can: softing_cs: softingcs_probe(): fix memleak on registration
  failure (bsc#1012628).
- mei: hbm: fix client dma reply status (bsc#1012628).
- iio: adc: ti-adc081c: Partial revert of removal of ACPI IDs
  (bsc#1012628).
- iio: trigger: Fix a scheduling whilst atomic issue seen on
  tsc2046 (bsc#1012628).
- lkdtm: Fix content of section containing
  lkdtm_rodata_do_nothing() (bsc#1012628).
- bus: mhi: pci_generic: Graceful shutdown on freeze
  (bsc#1012628).
- bus: mhi: core: Fix reading wake_capable channel configuration
  (bsc#1012628).
- bus: mhi: core: Fix race while handling SYS_ERR at power up
  (bsc#1012628).
- cxl/pmem: Fix reference counting for delayed work (bsc#1012628).
- cxl/pmem: Fix module reload vs workqueue state (bsc#1012628).
- thermal/drivers/int340x: Fix RFIM mailbox write commands
  (bsc#1012628).
- arm64: errata: Fix exec handling in erratum 1418040 workaround
  (bsc#1012628).
- ARM: dts: at91: update alternate function of signal PD20
  (bsc#1012628).
- iommu/io-pgtable-arm-v7s: Add error handle for page table
  allocation failure (bsc#1012628).
- gpu: host1x: Add back arm_iommu_detach_device() (bsc#1012628).
- drm/tegra: Add back arm_iommu_detach_device() (bsc#1012628).
- io_uring: fix no lock protection for ctx->cq_extra
  (bsc#1012628).
- virtio/virtio_mem: handle a possible NULL as a memcpy parameter
  (bsc#1012628).
- dma_fence_array: Fix PENDING_ERROR leak in
  dma_fence_array_signaled() (bsc#1012628).
- PCI: Add function 1 DMA alias quirk for Marvell 88SE9125 SATA
  controller (bsc#1012628).
- mm_zone: add function to check if managed dma zone exists
  (bsc#1012628).
- dma/pool: create dma atomic pool only if dma zone has managed
  pages (bsc#1012628).
- mm/page_alloc.c: do not warn allocation failure on zone DMA
  if no managed pages (bsc#1012628).
- ath11k: add string type to search board data in board-2.bin
  for WCN6855 (bsc#1012628).
- shmem: fix a race between shmem_unused_huge_shrink and
  shmem_evict_inode (bsc#1012628).
- drm/rockchip: dsi: Hold pm-runtime across bind/unbind
  (bsc#1012628).
- drm/rockchip: dsi: Reconfigure hardware on resume()
  (bsc#1012628).
- drm/ttm: Put BO in its memory manager's lru list (bsc#1012628).
- Bluetooth: hci_vhci: Fix to set the force_wakeup value
  (bsc#1012628).
- Bluetooth: mgmt: Fix Experimental Feature Changed event
  (bsc#1012628).
- Bluetooth: L2CAP: Fix not initializing sk_peer_pid
  (bsc#1012628).
- drm/bridge: display-connector: fix an uninitialized pointer
  in probe() (bsc#1012628).
- drm: fix null-ptr-deref in drm_dev_init_release() (bsc#1012628).
- drm/panel: kingdisplay-kd097d04: Delete panel on attach()
  failure (bsc#1012628).
- drm/panel: innolux-p079zca: Delete panel on attach() failure
  (bsc#1012628).
- drm/rockchip: dsi: Fix unbalanced clock on probe error
  (bsc#1012628).
- drm/rockchip: dsi: Disable PLL clock on bind error
  (bsc#1012628).
- Bluetooth: virtio_bt: fix memory leak in virtbt_rx_handle()
  (bsc#1012628).
- Bluetooth: cmtp: fix possible panic when cmtp_init_sockets()
  fails (bsc#1012628).
- clk: bcm-2835: Pick the closest clock rate (bsc#1012628).
- clk: bcm-2835: Remove rounding up the dividers (bsc#1012628).
- drm/vc4: hdmi: Set a default HSM rate (bsc#1012628).
- drm/vc4: hdmi: Move the HSM clock enable to runtime_pm
  (bsc#1012628).
- drm/vc4: hdmi: Make sure the controller is powered in detect
  (bsc#1012628).
- drm/vc4: hdmi: Make sure the controller is powered up during
  bind (bsc#1012628).
- drm/vc4: hdmi: Rework the pre_crtc_configure error handling
  (bsc#1012628).
- drm/vc4: crtc: Make sure the HDMI controller is powered when
  disabling (bsc#1012628).
- drm/bridge: sn65dsi83: Fix bridge removal (bsc#1012628).
- drm/virtio: fix potential integer overflow on shift of a int
  (bsc#1012628).
- drm/virtio: fix another potential integer overflow on shift
  of a int (bsc#1012628).
- wcn36xx: ensure pairing of init_scan/finish_scan and
  start_scan/end_scan (bsc#1012628).
- wcn36xx: Indicate beacon not connection loss on
  MISSED_BEACON_IND (bsc#1012628).
- libbpf: Fix section counting logic (bsc#1012628).
- drm/vc4: hdmi: Enable the scrambler on reconnection
  (bsc#1012628).
- libbpf: Fix non-C89 loop variable declaration in gen_loader.c
  (bsc#1012628).
- libbpf: Free up resources used by inner map definition
  (bsc#1012628).
- wcn36xx: Fix DMA channel enable/disable cycle (bsc#1012628).
- wcn36xx: Release DMA channel descriptor allocations
  (bsc#1012628).
- wcn36xx: Put DXE block into reset before freeing memory
  (bsc#1012628).
- wcn36xx: populate band before determining rate on RX
  (bsc#1012628).
- wcn36xx: fix RX BD rate mapping for 5GHz legacy rates
  (bsc#1012628).
- ath11k: Send PPDU_STATS_CFG with proper pdev mask to firmware
  (bsc#1012628).
- bpftool: Fix memory leak in prog_dump() (bsc#1012628).
- mtd: hyperbus: rpc-if: Check return value of rpcif_sw_init()
  (bsc#1012628).
- media: videobuf2: Fix the size printk format (bsc#1012628).
- media: ipu3-cio2: fix error code in cio2_bridge_connect_sensor()
  (bsc#1012628).
- media: atomisp: add missing media_device_cleanup() in
  atomisp_unregister_entities() (bsc#1012628).
- media: atomisp: fix punit_ddr_dvfs_enable() argument for
  mrfld_power up case (bsc#1012628).
- media: atomisp: fix inverted logic in buffers_needed()
  (bsc#1012628).
- media: atomisp: do not use err var when checking port validity
  for ISP2400 (bsc#1012628).
- media: atomisp: fix inverted error check for
  ia_css_mipi_is_source_port_valid() (bsc#1012628).
- media: atomisp: fix ifdefs in sh_css.c (bsc#1012628).
- media: atomisp: add NULL check for asd obtained from
  atomisp_video_pipe (bsc#1012628).
- media: atomisp: fix enum formats logic (bsc#1012628).
- media: atomisp: fix uninitialized bug in
  gmin_get_pmic_id_and_addr() (bsc#1012628).
- media: aspeed: fix mode-detect always time out at 2nd run
  (bsc#1012628).
- media: em28xx: fix memory leak in em28xx_init_dev (bsc#1012628).
- media: aspeed: Update signal status immediately to ensure sane
  hw state (bsc#1012628).
- arm64: dts: amlogic: meson-g12: Fix GPU operating point table
  node name (bsc#1012628).
- arm64: dts: amlogic: Fix SPI NOR flash node name for ODROID
  N2/N2+ (bsc#1012628).
- arm64: dts: meson-gxbb-wetek: fix HDMI in early boot
  (bsc#1012628).
- arm64: dts: meson-gxbb-wetek: fix missing GPIO binding
  (bsc#1012628).
- fs: dlm: don't call kernel_getpeername() in error_report()
  (bsc#1012628).
- memory: renesas-rpc-if: Return error in case
  devm_ioremap_resource() fails (bsc#1012628).
- Bluetooth: stop proccessing malicious adv data (bsc#1012628).
- Bluetooth: fix uninitialized variables notify_evt (bsc#1012628).
- ath11k: Fix ETSI regd with weather radar overlap (bsc#1012628).
- ath11k: clear the keys properly via DISABLE_KEY (bsc#1012628).
- ath11k: reset RSN/WPA present state for open BSS (bsc#1012628).
- spi: hisi-kunpeng: Fix the debugfs directory name incorrect
  (bsc#1012628).
- tee: fix put order in teedev_close_context() (bsc#1012628).
- kernel/locking: Use a pointer in ww_mutex_trylock()
  (bsc#1012628).
- fs: dlm: fix build with CONFIG_IPV6 disabled (bsc#1012628).
- drm/dp: Don't read back backlight mode in
  drm_edp_backlight_enable() (bsc#1012628).
- selftests/bpf: Fix xdpxceiver failures for no hugepages
  (bsc#1012628).
- mctp/test: Update refcount checking in route fragment tests
  (bsc#1012628).
- drm/vboxvideo: fix a NULL vs IS_ERR() check (bsc#1012628).
- ath11k: set correct NL80211_FEATURE_DYNAMIC_SMPS for WCN6855
  (bsc#1012628).
- ath11k: allocate dst ring descriptors from cacheable memory
  (bsc#1012628).
- ath11k: add hw_param for wakeup_mhi (bsc#1012628).
- arm64: dts: renesas: cat875: Add rx/tx delays (bsc#1012628).
- media: dmxdev: fix UAF when dvb_register_device() fails
  (bsc#1012628).
- crypto: atmel-aes - Reestablish the correct tfm context at
  dequeue (bsc#1012628).
- crypto: keembay-ocs-ecc - Fix error return code in
  kmb_ocs_ecc_probe() (bsc#1012628).
- crypto: qce - fix uaf on qce_aead_register_one (bsc#1012628).
- crypto: qce - fix uaf on qce_ahash_register_one (bsc#1012628).
- crypto: qce - fix uaf on qce_skcipher_register_one
  (bsc#1012628).
- arm64: dts: qcom: sc7280: Fix incorrect clock name
  (bsc#1012628).
- arm64: dts: qcom: sc7280: Fix 'interrupt-map' parent address
  cells (bsc#1012628).
- mtd: hyperbus: rpc-if: fix bug in rpcif_hb_remove (bsc#1012628).
- cpufreq: qcom-cpufreq-hw: Update offline CPUs per-cpu thermal
  pressure (bsc#1012628).
- soc: imx: gpcv2: keep i.MX8MM VPU-H1 bus clock active
  (bsc#1012628).
- cpufreq: qcom-hw: Fix probable nested interrupt handling
  (bsc#1012628).
- ARM: dts: stm32: fix dtbs_check warning on ili9341 dts binding
  on stm32f429 disco (bsc#1012628).
- libbpf: Load global data maps lazily on legacy kernels
  (bsc#1012628).
- tools/resolve_btf_ids: Close ELF file on error (bsc#1012628).
- libbpf: Fix potential misaligned memory access in btf_ext__new()
  (bsc#1012628).
- libbpf: Fix glob_syms memory leak in bpf_linker (bsc#1012628).
- libbpf: Fix using invalidated memory in bpf_linker
  (bsc#1012628).
- crypto: qat - fix undetected PFVF timeout in ACK loop
  (bsc#1012628).
- ath11k: Use host CE parameters for CE interrupts configuration
  (bsc#1012628).
- arm64: dts: ti: k3-j721e: correct cache-sets info (bsc#1012628).
- tty: serial: atmel: Check return code of dmaengine_submit()
  (bsc#1012628).
- tty: serial: atmel: Call dma_async_issue_pending()
  (bsc#1012628).
- pinctrl: apple: return an error if pinmux is missing in the DT
  (bsc#1012628).
- net: dsa: rtl8365mb: set RGMII RX delay in steps of 0.3 ns
  (bsc#1012628).
- mfd: atmel-flexcom: Remove #ifdef CONFIG_PM_SLEEP (bsc#1012628).
- mfd: atmel-flexcom: Use .resume_noirq (bsc#1012628).
- bfq: Do not let waker requests skip proper accounting
  (bsc#1012628).
- libbpf: Silence uninitialized warning/error in
  btf_dump_dump_type_data (bsc#1012628).
- media: i2c: imx274: fix s_frame_interval runtime resume not
  requested (bsc#1012628).
- media: i2c: Re-order runtime pm initialisation (bsc#1012628).
- media: i2c: ov8865: Fix lockdep error (bsc#1012628).
- media: rcar-csi2: Correct the selection of hsfreqrange
  (bsc#1012628).
- media: imx-pxp: Initialize the spinlock prior to using it
  (bsc#1012628).
- media: si470x-i2c: fix possible memory leak in
  si470x_i2c_probe() (bsc#1012628).
- media: mtk-vcodec: Fix an error handling path in
  'mtk_vcodec_probe()' (bsc#1012628).
- media: mtk-vcodec: call v4l2_m2m_ctx_release first when file
  is released (bsc#1012628).
- media: hantro: Hook up RK3399 JPEG encoder output (bsc#1012628).
- media: coda: fix CODA960 JPEG encoder buffer overflow
  (bsc#1012628).
- media: venus: correct low power frequency calculation for
  encoder (bsc#1012628).
- media: venus: core: Fix a potential NULL pointer dereference
  in an error handling path (bsc#1012628).
- media: venus: core: Fix a resource leak in the error handling
  path of 'venus_probe()' (bsc#1012628).
- net: stmmac: Add platform level debug register dump feature
  (bsc#1012628).
- net: lantiq: fix missing free_netdev() on error in
  ltq_etop_probe() (bsc#1012628).
- thermal/drivers/imx: Implement runtime PM support (bsc#1012628).
- igc: AF_XDP zero-copy metadata adjust breaks SKBs on XDP_PASS
  (bsc#1012628).
- netfilter: bridge: add support for pppoe filtering
  (bsc#1012628).
- powerpc: Avoid discarding flags in system_call_exception()
  (bsc#1012628).
- rcu: Avoid alloc_pages() when recording stack (bsc#1012628).
- arm64: dts: qcom: msm8916: fix MMC controller aliases
  (bsc#1012628).
- drm/vmwgfx: Remove the deprecated lower mem limit (bsc#1012628).
- drm/vmwgfx: Fail to initialize on broken configs (bsc#1012628).
- cgroup: Trace event cgroup id fields should be u64
  (bsc#1012628).
- ACPI: EC: Rework flushing of EC work while suspended to idle
  (bsc#1012628).
- pinctrl: mediatek: uninitialized variable in
  mtk_pctrl_show_one_pin() (bsc#1012628).
- pinctrl: mediatek: add a check for error in
  mtk_pinconf_bias_get_rsel() (bsc#1012628).
- thermal/drivers/imx8mm: Enable ADC when enabling monitor
  (bsc#1012628).
- drm/amdgpu: Fix a NULL pointer dereference in
  amdgpu_connector_lcd_native_mode() (bsc#1012628).
- drm/radeon/radeon_kms: Fix a NULL pointer dereference in
  radeon_driver_open_kms() (bsc#1012628).
- libbpf: Clean gen_loader's attach kind (bsc#1012628).
- null_blk: allow zero poll queues (bsc#1012628).
- crypto: caam - save caam memory to support crypto engine retry
  mechanism (bsc#1012628).
- arm64: dts: ti: k3-am642: Fix the L2 cache sets (bsc#1012628).
- arm64: dts: ti: k3-j7200: Fix the L2 cache sets (bsc#1012628).
- arm64: dts: ti: k3-j721e: Fix the L2 cache sets (bsc#1012628).
- arm64: dts: ti: k3-j7200: Correct the d-cache-sets info
  (bsc#1012628).
- tty: serial: uartlite: allow 64 bit address (bsc#1012628).
- serial: amba-pl011: do not request memory region twice
  (bsc#1012628).
- mtd: core: provide unique name for nvmem device (bsc#1012628).
- floppy: Fix hang in watchdog when disk is ejected (bsc#1012628).
- staging: rtl8192e: return error code from rtllib_softmac_init()
  (bsc#1012628).
- staging: rtl8192e: rtllib_module: fix error handle case in
  alloc_rtllib() (bsc#1012628).
- Bluetooth: btmtksdio: fix resume failure (bsc#1012628).
- bpf: Fix the test_task_vma selftest to support output shorter
  than 1 kB (bsc#1012628).
- sched/fair: Fix detection of per-CPU kthreads waking a task
  (bsc#1012628).
- sched/fair: Fix per-CPU kthread and wakee stacking for asym
  CPU capacity (bsc#1012628).
- bpf: Adjust BTF log size limit (bsc#1012628).
- bpf: Disallow BPF_LOG_KERNEL log level for bpf(BPF_BTF_LOAD)
  (bsc#1012628).
- bpf: Remove config check to enable bpf support for branch
  records (bsc#1012628).
- drm: rcar-du: Add DSI support to rcar_du_output_name
  (bsc#1012628).
- drm: rcar-du: crtc: Support external DSI dot clock
  (bsc#1012628).
- arm64: clear_page() shouldn't use DC ZVA when DCZID_EL0.DZP ==
  1 (bsc#1012628).
- arm64: mte: DC {GVA,GZVA} shouldn't be used when DCZID_EL0.DZP
  == 1 (bsc#1012628).
- platform/x86: wmi: Replace read_takes_no_args with a flags field
  (bsc#1012628).
- platform/x86: wmi: Fix driver->notify() vs ->probe() race
  (bsc#1012628).
- samples/bpf: Clean up samples/bpf build failes (bsc#1012628).
- samples: bpf: Fix xdp_sample_user.o linking with Clang
  (bsc#1012628).
- samples: bpf: Fix 'unknown warning group' build warning on Clang
  (bsc#1012628).
- media: uvcvideo: Fix memory leak of object map on error exit
  path (bsc#1012628).
- media: uvcvideo: Avoid invalid memory access (bsc#1012628).
- media: uvcvideo: Avoid returning invalid controls (bsc#1012628).
- media: dib8000: Fix a memleak in dib8000_init() (bsc#1012628).
- media: saa7146: mxb: Fix a NULL pointer dereference in
  mxb_attach() (bsc#1012628).
- media: si2157: Fix "warm" tuner state detection (bsc#1012628).
- wireless: iwlwifi: Fix a double free in iwl_txq_dyn_alloc_dma
  (bsc#1012628).
- sched/rt: Try to restart rt period timer when rt runtime
  exceeded (bsc#1012628).
- mtd: spi-nor: Get rid of nor->page_size (bsc#1012628).
- mtd: spi-nor: Fix mtd size for s3an flashes (bsc#1012628).
- ath10k: Fix the MTU size on QCA9377 SDIO (bsc#1012628).
- ath11k: Fix QMI file type enum value (bsc#1012628).
- Bluetooth: MGMT: Use hci_dev_test_and_{set,clear}_flag
  (bsc#1012628).
- Bluetooth: btusb: Handle download_firmware failure cases
  (bsc#1012628).
- drm/amd/display: Fix bug in debugfs crc_win_update entry
  (bsc#1012628).
- drm/amd/display: Fix out of bounds access on DNC31 stream
  encoder regs (bsc#1012628).
- drm/msm/gpu: Don't allow zero fence_id (bsc#1012628).
- drm/msm/dp: displayPort driver need algorithm rational
  (bsc#1012628).
- rcu/exp: Mark current CPU as exp-QS in IPI loop second pass
  (bsc#1012628).
- wcn36xx: Fix max channels retrieval (bsc#1012628).
- drm/msm/dsi: fix initialization in the bonded DSI case
  (bsc#1012628).
- mwifiex: Fix possible ABBA deadlock (bsc#1012628).
- xfrm: fix a small bug in xfrm_sa_len() (bsc#1012628).
- x86/uaccess: Move variable into switch case statement
  (bsc#1012628).
- libbpf: Add "bool skipped" to struct bpf_map (bsc#1012628).
- selftests: clone3: clone3: add case CLONE3_ARGS_NO_TEST
  (bsc#1012628).
- selftests: harness: avoid false negatives if test has no ASSERTs
  (bsc#1012628).
- crypto: stm32/cryp - fix CTR counter carry (bsc#1012628).
- crypto: stm32/cryp - fix xts and race condition in crypto_engine
  requests (bsc#1012628).
- crypto: stm32/cryp - check early input data (bsc#1012628).
- crypto: stm32/cryp - fix double pm exit (bsc#1012628).
- crypto: stm32/cryp - fix lrw chaining mode (bsc#1012628).
- crypto: stm32/cryp - fix bugs and crash in tests (bsc#1012628).
- crypto: stm32 - Revert broken pm_runtime_resume_and_get changes
  (bsc#1012628).
- crypto: hisilicon/qm - fix incorrect return value of
  hisi_qm_resume() (bsc#1012628).
- libbpf: Fix gen_loader assumption on number of programs
  (bsc#1012628).
- ath11k: Fix deleting uninitialized kernel timer during fragment
  cache flush (bsc#1012628).
- spi: Fix incorrect cs_setup delay handling (bsc#1012628).
- kunit: tool: fix --json output for skipped tests (bsc#1012628).
- ARM: dts: gemini: NAS4220-B: fis-index-block with 128 KiB
  sectors (bsc#1012628).
- perf/arm-cmn: Fix CPU hotplug unregistration (bsc#1012628).
- media: dw2102: Fix use after free (bsc#1012628).
- media: msi001: fix possible null-ptr-deref in msi001_probe()
  (bsc#1012628).
- media: coda/imx-vdoa: Handle dma_set_coherent_mask error codes
  (bsc#1012628).
- ath11k: Fix a NULL pointer dereference in
  ath11k_mac_op_hw_scan() (bsc#1012628).
- net: dsa: hellcreek: Fix insertion of static FDB entries
  (bsc#1012628).
- net: dsa: hellcreek: Add STP forwarding rule (bsc#1012628).
- net: dsa: hellcreek: Allow PTP P2P measurements on blocked ports
  (bsc#1012628).
- net: dsa: hellcreek: Add missing PTP via UDP rules
  (bsc#1012628).
- arm64: dts: qcom: c630: Fix soundcard setup (bsc#1012628).
- arm64: dts: qcom: ipq6018: Fix gpio-ranges property
  (bsc#1012628).
- drm/msm/dpu: fix safe status debugfs file (bsc#1012628).
- drm/bridge: ti-sn65dsi86: Set max register for regmap
  (bsc#1012628).
- gpu: host1x: select CONFIG_DMA_SHARED_BUFFER (bsc#1012628).
- drm/tegra: gr2d: Explicitly control module reset (bsc#1012628).
- drm/tegra: vic: Fix DMA API misuse (bsc#1012628).
- media: hantro: Fix probe func error path (bsc#1012628).
- xfrm: interface with if_id 0 should return error (bsc#1012628).
- xfrm: state and policy should fail if XFRMA_IF_ID 0
  (bsc#1012628).
- ARM: 9159/1: decompressor: Avoid UNPREDICTABLE NOP encoding
  (bsc#1012628).
- usb: ftdi-elan: fix memory leak on device disconnect
  (bsc#1012628).
- arm64: dts: marvell: cn9130: add GPIO and SPI aliases
  (bsc#1012628).
- arm64: dts: marvell: cn9130: enable CP0 GPIO controllers
  (bsc#1012628).
- ARM: dts: armada-38x: Add generic compatible to UART nodes
  (bsc#1012628).
- mt76: mt7921: drop offload_flags overwritten (bsc#1012628).
- mt76: mt7921: fix MT7921E reset failure (bsc#1012628).
- mt76: debugfs: fix queue reporting for mt76-usb (bsc#1012628).
- mt76: fix possible OOB issue in mt76_calculate_default_rate
  (bsc#1012628).
- mt76: mt7921: fix possible NULL pointer dereference in
  mt7921_mac_write_txwi (bsc#1012628).
- mt76: mt7921: move mt76_connac_mcu_set_hif_suspend to
  bus-related files (bsc#1012628).
- mt76: mt7921s: fix the device cannot sleep deeply in suspend
  (bsc#1012628).
- mt76: mt7921: use correct iftype data on 6GHz cap init
  (bsc#1012628).
- mt76: mt7921s: fix possible kernel crash due to invalid Rx count
  (bsc#1012628).
- mt76: connac: fix last_chan configuration in
  mt76_connac_mcu_rate_txpower_band (bsc#1012628).
- mt76: mt7921: fix possible resume failure (bsc#1012628).
- mt76: connac: introduce MCU_EXT macros (bsc#1012628).
- mt76: connac: align MCU_EXT definitions with 7915 driver
  (bsc#1012628).
- mt76: connac: remove MCU_FW_PREFIX bit (bsc#1012628).
- mt76: connac: introduce MCU_UNI_CMD macro (bsc#1012628).
- mt76: mt7921s: fix suspend error with enlarging mcu timeout
  value (bsc#1012628).
- wilc1000: fix double free error in probe() (bsc#1012628).
- rtw88: add quirk to disable pci caps on HP 250 G7 Notebook PC
  (bsc#1012628).
- rtw88: Disable PCIe ASPM while doing NAPI poll on 8821CE
  (bsc#1012628).
- iwlwifi: mvm: fix 32-bit build in FTM (bsc#1012628).
- iwlwifi: don't pass actual WGDS revision number in
  table_revision (bsc#1012628).
- iwlwifi: mvm: test roc running status bits before removing
  the sta (bsc#1012628).
- iwlwifi: mvm: perform 6GHz passive scan after suspend
  (bsc#1012628).
- iwlwifi: mvm: set protected flag only for NDP ranging
  (bsc#1012628).
- mmc: meson-mx-sdhc: add IRQ check (bsc#1012628).
- mmc: meson-mx-sdio: add IRQ check (bsc#1012628).
- block: fix error unwinding in device_add_disk (bsc#1012628).
- selinux: fix potential memleak in selinux_add_opt()
  (bsc#1012628).
- um: fix ndelay/udelay defines (bsc#1012628).
- um: rename set_signals() to um_set_signals() (bsc#1012628).
- um: virt-pci: Fix 32-bit compile (bsc#1012628).
- lib/logic_iomem: Fix 32-bit build (bsc#1012628).
- lib/logic_iomem: Fix operation on 32-bit (bsc#1012628).
- um: virtio_uml: Fix time-travel external time propagation
  (bsc#1012628).
- Bluetooth: L2CAP: Fix using wrong mode (bsc#1012628).
- bpftool: Enable line buffering for stdout (bsc#1012628).
- backlight: qcom-wled: Validate enabled string indices in DT
  (bsc#1012628).
- backlight: qcom-wled: Pass number of elements to read to
  read_u32_array (bsc#1012628).
- backlight: qcom-wled: Fix off-by-one maximum with default
  num_strings (bsc#1012628).
- backlight: qcom-wled: Override default length with
  qcom,enabled-strings (bsc#1012628).
- backlight: qcom-wled: Use cpu_to_le16 macro to perform
  conversion (bsc#1012628).
- backlight: qcom-wled: Respect enabled-strings in set_brightness
  (bsc#1012628).
- software node: fix wrong node passed to find nargs_prop
  (bsc#1012628).
- ath11k: Fix unexpected return buffer manager error for QCA6390
  (bsc#1012628).
- mt76: mt7921: fix a possible race enabling/disabling runtime-pm
  (bsc#1012628).
- Bluetooth: hci_qca: Stop IBS timer during BT OFF (bsc#1012628).
- x86/boot/compressed: Move CLANG_FLAGS to beginning of
  KBUILD_CFLAGS (bsc#1012628).
- crypto: octeontx2 - prevent underflow in get_cores_bmap()
  (bsc#1012628).
- block: null_blk: only set set->nr_maps as 3 if active
  poll_queues is > 0 (bsc#1012628).
- regulator: qcom-labibb: OCP interrupts are not a failure while
  disabled (bsc#1012628).
- hwmon: (mr75203) fix wrong power-up delay value (bsc#1012628).
- x86/mce/inject: Avoid out-of-bounds write when setting flags
  (bsc#1012628).
- io_uring: remove double poll on poll update (bsc#1012628).
- bpf: Add missing map_get_next_key method to bloom filter map
  (bsc#1012628).
- serial: 8250_bcm7271: Propagate error codes from
  brcmuart_probe() (bsc#1012628).
- drm/amd/display: fix dereference before NULL check
  (bsc#1012628).
- ACPI: scan: Create platform device for BCM4752 and LNV4752
  ACPI nodes (bsc#1012628).
- pcmcia: rsrc_nonstatic: Fix a NULL pointer dereference in
  __nonstatic_find_io_region() (bsc#1012628).
- pcmcia: rsrc_nonstatic: Fix a NULL pointer dereference in
  nonstatic_find_mem_region() (bsc#1012628).
- power: reset: mt6397: Check for null res pointer (bsc#1012628).
- net/xfrm: IPsec tunnel mode fix inner_ipproto setting in
  sec_path (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix return values and refactor
  MDIO ops (bsc#1012628).
- net: dsa: fix incorrect function pointer check for MRP ring
  roles (bsc#1012628).
- netfilter: ipt_CLUSTERIP: fix refcount leak in
  clusterip_tg_check() (bsc#1012628).
- bpf, arm64: Use emit_addr_mov_i64() for BPF_PSEUDO_FUNC
  (bsc#1012628).
- bpf, sockmap: Fix return codes from tcp_bpf_recvmsg_parser()
  (bsc#1012628).
- bpf, sockmap: Fix double bpf_prog_put on error case in map_link
  (bsc#1012628).
- bpf: Don't promote bogus looking registers after null check
  (bsc#1012628).
- bpf: Fix verifier support for validation of async callbacks
  (bsc#1012628).
- bpf: Fix SO_RCVBUF/SO_SNDBUF handling in _bpf_setsockopt()
  (bsc#1012628).
- libbpf: Use probe_name for legacy kprobe (bsc#1012628).
- netfilter: nft_payload: do not update layer 4 checksum when
  mangling fragments (bsc#1012628).
- netfilter: nft_set_pipapo: allocate pcpu scratch maps on clone
  (bsc#1012628).
- net: fix SOF_TIMESTAMPING_BIND_PHC to work with multiple sockets
  (bsc#1012628).
- ppp: ensure minimum packet size in ppp_write() (bsc#1012628).
- rocker: fix a sleeping in atomic bug (bsc#1012628).
- staging: greybus: audio: Check null pointer (bsc#1012628).
- fsl/fman: Check for null pointer after calling devm_ioremap
  (bsc#1012628).
- Bluetooth: hci_bcm: Check for error irq (bsc#1012628).
- Bluetooth: hci_qca: Fix NULL vs IS_ERR_OR_NULL check in
  qca_serdev_probe (bsc#1012628).
- net/smc: Reset conn->lgr when link group registration fails
  (bsc#1012628).
- usb: dwc3: qcom: Fix NULL vs IS_ERR checking in dwc3_qcom_probe
  (bsc#1012628).
- usb: dwc2: do not gate off the hardware if it does not support
  clock gating (bsc#1012628).
- usb: dwc2: gadget: initialize max_speed from params
  (bsc#1012628).
- usb: gadget: u_audio: fix calculations for small bInterval
  (bsc#1012628).
- usb: gadget: u_audio: Subdevice 0 for capture ctls
  (bsc#1012628).
- HID: hid-uclogic-params: Invalid parameter check in
  uclogic_params_init (bsc#1012628).
- HID: hid-uclogic-params: Invalid parameter check in
  uclogic_params_get_str_desc (bsc#1012628).
- HID: hid-uclogic-params: Invalid parameter check in
  uclogic_params_huion_init (bsc#1012628).
- HID: hid-uclogic-params: Invalid parameter check in
  uclogic_params_frame_init_v1_buttonpad (bsc#1012628).
- debugfs: lockdown: Allow reading debugfs files that are not
  world readable (bsc#1012628).
- drivers/firmware: Add missing platform_device_put() in
  sysfb_create_simplefb (bsc#1012628).
- serial: liteuart: fix MODULE_ALIAS (bsc#1012628).
- serial: stm32: move tx dma terminate DMA to shutdown
  (bsc#1012628).
- spi: qcom: geni: set the error code for gpi transfer
  (bsc#1012628).
- spi: qcom: geni: handle timeout for gpi mode (bsc#1012628).
- x86, sched: Fix undefined reference to
  init_freq_invariance_cppc() build error (bsc#1012628).
- net/mlx5e: Fix page DMA map/unmap attributes (bsc#1012628).
- net/mlx5e: Fix nullptr on deleting mirroring rule (bsc#1012628).
- net/mlx5e: Fix wrong usage of fib_info_nh when routes with
  nexthop objects are used (bsc#1012628).
- net/mlx5e: Don't block routes with nexthop objects in SW
  (bsc#1012628).
- Revert "net/mlx5e: Block offload of outer header csum for UDP
  tunnels" (bsc#1012628).
- Revert "net/mlx5e: Block offload of outer header csum for GRE
  tunnel" (bsc#1012628).
- net/mlx5e: Fix matching on modified inner ip_ecn bits
  (bsc#1012628).
- net/mlx5: Fix access to sf_dev_table on allocation failure
  (bsc#1012628).
- net/mlx5e: Sync VXLAN udp ports during uplink representor
  profile change (bsc#1012628).
- net/mlx5: Set command entry semaphore up once got index free
  (bsc#1012628).
- lib/mpi: Add the return value check of kcalloc() (bsc#1012628).
- Bluetooth: L2CAP: uninitialized variables in
  l2cap_sock_setsockopt() (bsc#1012628).
- Bluetooth: hci_sock: fix endian bug in hci_sock_setsockopt()
  (bsc#1012628).
- mptcp: fix per socket endpoint accounting (bsc#1012628).
- mptcp: fix opt size when sending DSS + MP_FAIL (bsc#1012628).
- mptcp: fix a DSS option writing error (bsc#1012628).
- mptcp: Check reclaim amount before reducing allocation
  (bsc#1012628).
- spi: spi-meson-spifc: Add missing pm_runtime_disable() in
  meson_spifc_probe (bsc#1012628).
- octeontx2-af: Increment ptp refcount before use (bsc#1012628).
- octeontx2-nicvf: Free VF PTP resources (bsc#1012628).
- ax25: uninitialized variable in ax25_setsockopt() (bsc#1012628).
- netrom: fix api breakage in nr_setsockopt() (bsc#1012628).
- regmap: Call regmap_debugfs_exit() prior to _init()
  (bsc#1012628).
- net: mscc: ocelot: fix incorrect balancing with down LAG ports
  (bsc#1012628).
- octeontx2-af: Fix interrupt name strings (bsc#1012628).
- can: mcp251xfd: add missing newline to printed strings
  (bsc#1012628).
- tpm: add request_locality before write TPM_INT_ENABLE
  (bsc#1012628).
- tpm_tis: Fix an error handling path in 'tpm_tis_core_init()'
  (bsc#1012628).
- can: softing: softing_startstop(): fix set but not used variable
  warning (bsc#1012628).
- can: xilinx_can: xcan_probe(): check for error irq
  (bsc#1012628).
- can: rcar_canfd: rcar_canfd_channel_probe(): make sure we free
  CAN network device (bsc#1012628).
- pcmcia: fix setting of kthread task states (bsc#1012628).
- netfilter: egress: avoid a lockdep splat (bsc#1012628).
- net: openvswitch: Fix ct_state nat flags for conns arriving
  from tc (bsc#1012628).
- iwlwifi: mvm: Use div_s64 instead of do_div in
  iwl_mvm_ftm_rtt_smoothing() (bsc#1012628).
- bnxt_en: use firmware provided max timeout for messages
  (bsc#1012628).
- net: mcs7830: handle usb read errors properly (bsc#1012628).
- amt: fix wrong return type of amt_send_membership_update()
  (bsc#1012628).
- ext4: avoid trim error on fs with small groups (bsc#1012628).
- ASoC: Intel: sof_sdw: fix jack detection on HP Spectre x360
  convertible (bsc#1012628).
- ALSA: jack: Add missing rwsem around snd_ctl_remove() calls
  (bsc#1012628).
- ALSA: PCM: Add missing rwsem around snd_ctl_remove() calls
  (bsc#1012628).
- ALSA: hda: Add missing rwsem around snd_ctl_remove() calls
  (bsc#1012628).
- ALSA: hda: Fix potential deadlock at codec unbinding
  (bsc#1012628).
- RDMA/bnxt_re: Scan the whole bitmap when checking if "disabling
  RCFW with pending cmd-bit" (bsc#1012628).
- RDMA/hns: Validate the pkey index (bsc#1012628).
- scsi: pm80xx: Update WARN_ON check in pm8001_mpi_build_cmd()
  (bsc#1012628).
- clk: renesas: rzg2l: Check return value of pm_genpd_init()
  (bsc#1012628).
- clk: renesas: rzg2l: propagate return value
  of_genpd_add_provider_simple() (bsc#1012628).
- clk: imx8mn: Fix imx8mn_clko1_sels (bsc#1012628).
- ASoC: cs42l42: Report initial jack state (bsc#1012628).
- powerpc/prom_init: Fix improper check of prom_getprop()
  (bsc#1012628).
- ASoC: uniphier: drop selecting non-existing
  SND_SOC_UNIPHIER_AIO_DMA (bsc#1012628).
- ASoC: codecs: wcd938x: add SND_SOC_WCD938_SDW to codec list
  instead (bsc#1012628).
- RDMA/rtrs-clt: Fix the initial value of min_latency
  (bsc#1012628).
- ALSA: hda: Make proper use of timecounter (bsc#1012628).
- dt-bindings: thermal: Fix definition of cooling-maps
  contribution property (bsc#1012628).
- powerpc/perf: Fix PMU callbacks to clear pending PMI before
  resetting an overflown PMC (bsc#1012628).
- powerpc/modules: Don't WARN on first module allocation attempt
  (bsc#1012628).
- powerpc/32s: Fix shift-out-of-bounds in KASAN init
  (bsc#1012628).
- clocksource: Avoid accidental unstable marking of clocksources
  (bsc#1012628).
- ALSA: oss: fix compile error when OSS_DEBUG is enabled
  (bsc#1012628).
- ALSA: usb-audio: Drop superfluous '0' in Presonus Studio
  1810c's ID (bsc#1012628).
- ASoC: amd: Fix dependency for SPI master (bsc#1012628).
- misc: at25: Make driver OF independent again (bsc#1012628).
- char/mwave: Adjust io port register size (bsc#1012628).
- binder: fix handling of error during copy (bsc#1012628).
- binder: avoid potential data leakage when copying txn
  (bsc#1012628).
- openrisc: Add clone3 ABI wrapper (bsc#1012628).
- iommu: Extend mutex lock scope in iommu_probe_device()
  (bsc#1012628).
- iommu/io-pgtable-arm: Fix table descriptor paddr formatting
  (bsc#1012628).
- ASoC: SOF: Intel: fix build issue related to CODEC_PROBE_ENTRIES
  (bsc#1012628).
- scsi: core: Fix scsi_device_max_queue_depth() (bsc#1012628).
- scsi: ufs: Fix race conditions related to driver data
  (bsc#1012628).
- RDMA/qedr: Fix reporting max_{send/recv}_wr attrs (bsc#1012628).
- PCI/MSI: Fix pci_irq_vector()/pci_irq_get_affinity()
  (bsc#1012628).
- powerpc/powermac: Add additional missing lockdep_register_key()
  (bsc#1012628).
- iommu/arm-smmu-qcom: Fix TTBR0 read (bsc#1012628).
- RDMA/core: Let ib_find_gid() continue search even after empty
  entry (bsc#1012628).
- RDMA/cma: Let cma_resolve_ib_dev() continue search even after
  empty entry (bsc#1012628).
- ASoC: rt5663: Handle device_property_read_u32_array error codes
  (bsc#1012628).
- of: unittest: fix warning on PowerPC frame size warning
  (bsc#1012628).
- of: unittest: 64 bit dma address test requires arch support
  (bsc#1012628).
- clk: stm32: Fix ltdc's clock turn off by clk_disable_unused()
  after system enter shell (bsc#1012628).
- mips: add SYS_HAS_CPU_MIPS64_R5 config for MIPS Release 5
  support (bsc#1012628).
- mips: fix Kconfig reference to PHYS_ADDR_T_64BIT (bsc#1012628).
- dmaengine: pxa/mmp: stop referencing config->slave_id
  (bsc#1012628).
- iommu/amd: Restore GA log/tail pointer on host resume
  (bsc#1012628).
- iommu/amd: X2apic mode: re-enable after resume (bsc#1012628).
- iommu/amd: X2apic mode: setup the INTX registers on mask/unmask
  (bsc#1012628).
- iommu/amd: X2apic mode: mask/unmask interrupts on suspend/resume
  (bsc#1012628).
- iommu/amd: Remove useless irq affinity notifier (bsc#1012628).
- ASoC: Intel: catpt: Test dmaengine_submit() result before
  moving on (bsc#1012628).
- iommu/iova: Fix race between FQ timeout and teardown
  (bsc#1012628).
- ASoC: mediatek: mt8195: correct default value (bsc#1012628).
- counter: 104-quad-8: Fix persistent enabled events bug
  (bsc#1012628).
- of: fdt: Aggregate the processing of "linux,usable-memory-range"
  (bsc#1012628).
- efi: apply memblock cap after memblock_add() (bsc#1012628).
- scsi: block: pm: Always set request queue runtime active in
  blk_post_runtime_resume() (bsc#1012628).
- phy: uniphier-usb3ss: fix unintended writing zeros to PHY
  register (bsc#1012628).
- ASoC: mediatek: Check for error clk pointer (bsc#1012628).
- powerpc/64s: Mask NIP before checking against SRR0
  (bsc#1012628).
- powerpc/64s: Use EMIT_WARN_ENTRY for SRR debug warnings
  (bsc#1012628).
- phy: cadence: Sierra: Fix to get correct parent for mux clocks
  (bsc#1012628).
- iio: chemical: sunrise_co2: set val parameter only on success
  (bsc#1012628).
- ASoC: samsung: idma: Check of ioremap return value
  (bsc#1012628).
- misc: lattice-ecp3-config: Fix task hung when firmware load
  failed (bsc#1012628).
- ASoC: mediatek: mt8195: correct pcmif BE dai control flow
  (bsc#1012628).
- arm64: tegra: Remove non existent Tegra194 reset (bsc#1012628).
- mips: lantiq: add support for clk_set_parent() (bsc#1012628).
- mips: bcm63xx: add support for clk_set_parent() (bsc#1012628).
- powerpc/xive: Add missing null check after calling kmalloc
  (bsc#1012628).
- ASoC: fsl_mqs: fix MODULE_ALIAS (bsc#1012628).
- ALSA: hda/cs8409: Increase delay during jack detection
  (bsc#1012628).
- ALSA: hda/cs8409: Fix Jack detection after resume (bsc#1012628).
- cxl/core: Remove cxld_const_init in cxl_decoder_alloc()
  (bsc#1012628).
- MIPS: fix local_{add,sub}_return on MIPS64 (bsc#1012628).
- RDMA/cxgb4: Set queue pair state when being queried
  (bsc#1012628).
- clk: qcom: gcc-sc7280: Mark gcc_cfg_noc_lpass_clk always enabled
  (bsc#1012628).
- ASoC: imx-card: Need special setting for ak4497 on i.MX8MQ
  (bsc#1012628).
- ASoC: imx-card: Fix mclk calculation issue for akcodec
  (bsc#1012628).
- ASoC: imx-card: improve the sound quality for low rate
  (bsc#1012628).
- ASoC: fsl_asrc: refine the check of available clock divider
  (bsc#1012628).
- clk: bm1880: remove kfrees on static allocations (bsc#1012628).
- of: base: Fix phandle argument length mismatch error message
  (bsc#1012628).
- of/fdt: Don't worry about non-memory region overlap for no-map
  (bsc#1012628).
- MIPS: compressed: Fix build with ZSTD compression (bsc#1012628).
- mailbox: fix gce_num of mt8192 driver data (bsc#1012628).
- mailbox: imx: Fix an IS_ERR() vs NULL bug (bsc#1012628).
- mailbox: pcc: Avoid using the uninitialized variable 'dev'
  (bsc#1012628).
- mailbox: pcc: Handle all PCC subtypes correctly in pcc_mbox_irq
  (bsc#1012628).
- ARM: dts: omap3-n900: Fix lp5523 for multi color (bsc#1012628).
- leds: lp55xx: initialise output direction from dts
  (bsc#1012628).
- Bluetooth: hci_sock: purge socket queues in the destruct()
  callback (bsc#1012628).
- Bluetooth: Fix debugfs entry leak in hci_register_dev()
  (bsc#1012628).
- Bluetooth: Fix memory leak of hci device (bsc#1012628).
- drm/panel: Delete panel on mipi_dsi_attach() failure
  (bsc#1012628).
- Bluetooth: Fix removing adv when processing cmd complete
  (bsc#1012628).
- drm/sched: Avoid lockdep spalt on killing a processes
  (bsc#1012628).
- fs: dlm: filter user dlm messages for kernel locks
  (bsc#1012628).
- libbpf: Detect corrupted ELF symbols section (bsc#1012628).
- libbpf: Improve sanity checking during BTF fix up (bsc#1012628).
- drm/lima: fix warning when CONFIG_DEBUG_SG=y &
  CONFIG_DMA_API_DEBUG=y (bsc#1012628).
- selftests/bpf: Fix memory leaks in btf_type_c_dump() helper
  (bsc#1012628).
- selftests/bpf: Destroy XDP link correctly (bsc#1012628).
- selftests/bpf: Fix bpf_object leak in skb_ctx selftest
  (bsc#1012628).
- ar5523: Fix null-ptr-deref with unexpected WDCMSG_TARGET_START
  reply (bsc#1012628).
- drm/bridge: dw-hdmi: handle ELD when
  DRM_BRIDGE_ATTACH_NO_CONNECTOR (bsc#1012628).
- drm/nouveau/pmu/gm200-: avoid touching PMU outside of
  DEVINIT/PREOS/ACR (bsc#1012628).
- media: atomisp: fix try_fmt logic (bsc#1012628).
- media: atomisp: set per-device's default mode (bsc#1012628).
- media: atomisp-ov2680: Fix ov2680_set_fmt() clobbering the
  exposure (bsc#1012628).
- media: atomisp: check before deference asd variable
  (bsc#1012628).
- ARM: shmobile: rcar-gen2: Add missing of_node_put()
  (bsc#1012628).
- ath11k: enable IEEE80211_VHT_EXT_NSS_BW_CAPABLE if NSS ratio
  enabled (bsc#1012628).
- batman-adv: allow netlink usage in unprivileged containers
  (bsc#1012628).
- bpf: Change value of MAX_TAIL_CALL_CNT from 32 to 33
  (bsc#1012628).
- media: atomisp: handle errors at sh_css_create_isp_params()
  (bsc#1012628).
- ath11k: Fix crash caused by uninitialized TX ring (bsc#1012628).
- usb: dwc3: meson-g12a: fix shared reset control use
  (bsc#1012628).
- USB: ehci_brcm_hub_control: Improve port index sanitizing
  (bsc#1012628).
- usb: gadget: f_fs: Use stream_open() for endpoint files
  (bsc#1012628).
- psi: Fix PSI_MEM_FULL state when tasks are in memstall and
  doing reclaim (bsc#1012628).
- drm: panel-orientation-quirks: Add quirk for the Lenovo Yoga
  Book X91F/L (bsc#1012628).
- HID: magicmouse: Report battery level over USB (bsc#1012628).
- HID: apple: Do not reset quirks when the Fn key is not found
  (bsc#1012628).
- media: b2c2: Add missing check in flexcop_pci_isr:
  (bsc#1012628).
- libbpf: Accommodate DWARF/compiler bug with duplicated structs
  (bsc#1012628).
- ethernet: renesas: Use div64_ul instead of do_div (bsc#1012628).
- EDAC/synopsys: Use the quirk for version instead of ddr version
  (bsc#1012628).
- arm64: dts: qcom: sm[68]350: Use interrupts-extended with pdc
  interrupts (bsc#1012628).
- arm64: dts: qcom: sm8350: Shorten camera-thermal-bottom name
  (bsc#1012628).
- soc: imx: gpcv2: Synchronously suspend MIX domains
  (bsc#1012628).
- ARM: imx: rename DEBUG_IMX21_IMX27_UART to DEBUG_IMX27_UART
  (bsc#1012628).
- ath11k: Fix mon status ring rx tlv processing (bsc#1012628).
- drm/amd/display: check top_pipe_to_program pointer
  (bsc#1012628).
- drm/amdgpu/display: set vblank_disable_immediate for DC
  (bsc#1012628).
- soc: ti: pruss: fix referenced node in error message
  (bsc#1012628).
- mlxsw: pci: Add shutdown method in PCI driver (bsc#1012628).
- drm/amd/display: add else to avoid double destroy clk_mgr
  (bsc#1012628).
- drm/bridge: megachips: Ensure both bridges are probed before
  registration (bsc#1012628).
- mxser: keep only !tty test in ISR (bsc#1012628).
- mxser: don't throttle manually (bsc#1012628).
- mxser: increase buf_overrun if tty_insert_flip_char() fails
  (bsc#1012628).
- serial: 8250_dw: Add StarFive JH7100 quirk (bsc#1012628).
- tty: serial: imx: disable UCR4_OREN in .stop_rx() instead of
  .shutdown() (bsc#1012628).
- gpiolib: acpi: Do not set the IRQ type if the IRQ is already
  in use (bsc#1012628).
- HSI: core: Fix return freed object in hsi_new_client
  (bsc#1012628).
- crypto: jitter - consider 32 LSB for APT (bsc#1012628).
- rtw89: fix potentially access out of range of RF register array
  (bsc#1012628).
- rsi: Fix use-after-free in rsi_rx_done_handler() (bsc#1012628).
- rsi: Fix out-of-bounds read in rsi_read_pkt() (bsc#1012628).
- ath11k: Avoid NULL ptr access during mgmt tx cleanup
  (bsc#1012628).
- media: venus: avoid calling core_clk_setrate() concurrently
  during concurrent video sessions (bsc#1012628).
- regulator: da9121: Prevent current limit change when enabled
  (bsc#1012628).
- drm/vmwgfx: Release ttm memory if probe fails (bsc#1012628).
- drm/vmwgfx: Introduce a new placement for MOB page tables
  (bsc#1012628).
- ACPI / x86: Drop PWM2 device on Lenovo Yoga Book from always
  present table (bsc#1012628).
- ACPI: Change acpi_device_always_present() into
  acpi_device_override_status() (bsc#1012628).
- ACPI / x86: Allow specifying acpi_device_override_status()
  quirks by path (bsc#1012628).
- ACPI / x86: Add not-present quirk for the PCI0.SDHB.BRC1 device
  on the GPD win (bsc#1012628).
- drm: Return error codes from struct drm_driver.gem_create_object
  (bsc#1012628).
- drm/amd/display: Use oriented source size when checking cursor
  scaling (bsc#1012628).
- arm64: dts: ti: j7200-main: Fix 'dtbs_check' serdes_ln_ctrl node
  (bsc#1012628).
- arm64: dts: ti: j721e-main: Fix 'dtbs_check' in serdes_ln_ctrl
  node (bsc#1012628).
- usb: uhci: add aspeed ast2600 uhci support (bsc#1012628).
- floppy: Add max size check for user space request (bsc#1012628).
- x86/mm: Flush global TLB when switching to trampoline page-table
  (bsc#1012628).
- drm: rcar-du: Fix CRTC timings when CMM is used (bsc#1012628).
- media: uvcvideo: Increase UVC_CTRL_CONTROL_TIMEOUT to 5 seconds
  (bsc#1012628).
- media: rcar-vin: Update format alignment constraints
  (bsc#1012628).
- media: saa7146: hexium_orion: Fix a NULL pointer dereference
  in hexium_attach() (bsc#1012628).
- media: atomisp: fix "variable dereferenced before check 'asd'"
  (bsc#1012628).
- media: m920x: don't use stack on USB reads (bsc#1012628).
- thunderbolt: Runtime PM activate both ends of the device link
  (bsc#1012628).
- arm64: dts: renesas: Fix thermal bindings (bsc#1012628).
- iwlwifi: mvm: synchronize with FW after multicast commands
  (bsc#1012628).
- iwlwifi: mvm: avoid clearing a just saved session protection id
  (bsc#1012628).
- iwlwifi: acpi: fix wgds rev 3 size (bsc#1012628).
- rcutorture: Avoid soft lockup during cpu stall (bsc#1012628).
- ath11k: avoid deadlock by change ieee80211_queue_work for
  regd_update_work (bsc#1012628).
- ath10k: Fix tx hanging (bsc#1012628).
- rtw89: don't kick off TX DMA if failed to write skb
  (bsc#1012628).
- net-sysfs: update the queue counts in the unregistration path
  (bsc#1012628).
- ath10k: drop beacon and probe response which leak from other
  channel (bsc#1012628).
- net: phy: prefer 1000baseT over 1000baseKX (bsc#1012628).
- gpio: aspeed: Convert aspeed_gpio.lock to raw_spinlock
  (bsc#1012628).
- gpio: aspeed-sgpio: Convert aspeed_sgpio.lock to raw_spinlock
  (bsc#1012628).
- selftests/ftrace: make kprobe profile testcase description
  unique (bsc#1012628).
- arm64: dts: rockchip: Fix Bluetooth on ROCK Pi 4 boards
  (bsc#1012628).
- ath11k: Avoid false DEADLOCK warning reported by lockdep
  (bsc#1012628).
- ARM: dts: qcom: sdx55: fix IPA interconnect definitions
  (bsc#1012628).
- x86/mce: Allow instrumentation during task work queueing
  (bsc#1012628).
- x86/mce: Prevent severity computation from being instrumented
  (bsc#1012628).
- x86/mce: Mark mce_panic() noinstr (bsc#1012628).
- x86/mce: Mark mce_end() noinstr (bsc#1012628).
- x86/mce: Mark mce_read_aux() noinstr (bsc#1012628).
- net: bonding: debug: avoid printing debug logs when bond is
  not notifying peers (bsc#1012628).
- kunit: Don't crash if no parameters are generated (bsc#1012628).
- bpf: Do not WARN in bpf_warn_invalid_xdp_action() (bsc#1012628).
- drm/amdkfd: Fix error handling in svm_range_add (bsc#1012628).
- drm/amdgpu: fix amdgpu_ras_mca_query_error_status scope
  (bsc#1012628).
- HID: quirks: Allow inverting the absolute X/Y values
  (bsc#1012628).
- HID: i2c-hid-of: Expose the touchscreen-inverted properties
  (bsc#1012628).
- media: igorplugusb: receiver overflow should be reported
  (bsc#1012628).
- media: rockchip: rkisp1: use device name for debugfs subdir name
  (bsc#1012628).
- media: saa7146: hexium_gemini: Fix a NULL pointer dereference
  in hexium_attach() (bsc#1012628).
- mmc: tmio: reinit card irqs in reset routine (bsc#1012628).
- mmc: core: Fixup storing of OCR for MMC_QUIRK_NONSTD_SDIO
  (bsc#1012628).
- mmc: omap_hsmmc: Revert special init for wl1251 (bsc#1012628).
- drm/amd/amdgpu: fix psp tmr bo pin count leak in SRIOV
  (bsc#1012628).
- drm/amd/amdgpu: fix gmc bo pin count leak in SRIOV
  (bsc#1012628).
- audit: ensure userspace is penalized the same as the kernel
  when under pressure (bsc#1012628).
- arm64: dts: ls1028a-qds: move rtc node to the correct i2c bus
  (bsc#1012628).
- arm64: tegra: Adjust length of CCPLEX cluster MMIO region
  (bsc#1012628).
- crypto: ccp - Move SEV_INIT retry for corrupted data
  (bsc#1012628).
- crypto: hisilicon/hpre - fix memory leak in
  hpre_curve25519_src_init() (bsc#1012628).
- crypto: hisilicon/qm - fix deadlock for remove driver
  (bsc#1012628).
- PM: runtime: Add safety net to supplier device release
  (bsc#1012628).
- cpufreq: Fix initialization of min and max frequency QoS
  requests (bsc#1012628).
- usb: hub: Add delay for SuperSpeed hub resume to let links
  transit to U0 (bsc#1012628).
- mt76: mt7615: fix possible deadlock while
  mt7615_register_ext_phy() (bsc#1012628).
- mt76: mt7915: fix SMPS operation fail (bsc#1012628).
- mt76: connac: fix a theoretical NULL pointer dereference in
  mt76_connac_get_phy_mode (bsc#1012628).
- mt76: do not pass the received frame with decryption error
  (bsc#1012628).
- mt76: mt7615: improve wmm index allocation (bsc#1012628).
- mt76: mt7921: fix network buffer leak by txs missing
  (bsc#1012628).
- ath9k_htc: fix NULL pointer dereference at ath9k_htc_rxep()
  (bsc#1012628).
- ath9k_htc: fix NULL pointer dereference at
  ath9k_htc_tx_get_packet() (bsc#1012628).
- ath9k: Fix out-of-bound memcpy in ath9k_hif_usb_rx_stream
  (bsc#1012628).
- rtw88: 8822c: update rx settings to prevent potential hw
  deadlock (bsc#1012628).
- PM: AVS: qcom-cpr: Use div64_ul instead of do_div (bsc#1012628).
- iwlwifi: recognize missing PNVM data and then log filename
  (bsc#1012628).
- iwlwifi: fix leaks/bad data after failed firmware load
  (bsc#1012628).
- iwlwifi: remove module loading failure message (bsc#1012628).
- iwlwifi: mvm: Fix calculation of frame length (bsc#1012628).
- iwlwifi: mvm: fix AUX ROC removal (bsc#1012628).
- iwlwifi: pcie: make sure prph_info is set when treating wakeup
  IRQ (bsc#1012628).
- mmc: sdhci-pci-gli: GL9755: Support for CD/WP inversion on OF
  platforms (bsc#1012628).
- block: check minor range in device_add_disk() (bsc#1012628).
- um: registers: Rename function names to avoid conflicts and
  build problems (bsc#1012628).
- ath11k: Fix napi related hang (bsc#1012628).
- Bluetooth: btintel: Add missing quirks and msft ext for legacy
  bootloader (bsc#1012628).
- cpufreq: intel_pstate: Update cpuinfo.max_freq on HWP_CAP
  changes (bsc#1012628).
- Bluetooth: vhci: Set HCI_QUIRK_VALID_LE_STATES (bsc#1012628).
- xfrm: rate limit SA mapping change message to user space
  (bsc#1012628).
- drm/etnaviv: consider completed fence seqno in hang check
  (bsc#1012628).
- jffs2: GC deadlock reading a page that is used in
  jffs2_write_begin() (bsc#1012628).
- ACPICA: actypes.h: Expand the ACPI_ACCESS_ definitions
  (bsc#1012628).
- ACPICA: Utilities: Avoid deleting the same object twice in a
  row (bsc#1012628).
- ACPICA: Executer: Fix the REFCLASS_REFOF case in
  acpi_ex_opcode_1A_0T_1R() (bsc#1012628).
- ACPICA: Fix wrong interpretation of PCC address (bsc#1012628).
- ACPICA: Hardware: Do not flush CPU cache when entering S4 and S5
  (bsc#1012628).
- mmc: mtk-sd: Use readl_poll_timeout instead of open-coded
  polling (bsc#1012628).
- drm/amdgpu: fixup bad vram size on gmc v8 (bsc#1012628).
- mfd: intel_soc_pmic: Use CPU-id check instead of _HRV check
  to differentiate variants (bsc#1012628).
- amdgpu/pm: Make sysfs pm attributes as read-only for VFs
  (bsc#1012628).
- ACPI: battery: Add the ThinkPad "Not Charging" quirk
  (bsc#1012628).
- ACPI: CPPC: Check present CPUs for determining _CPC is valid
  (bsc#1012628).
- net/mlx5: DR, Fix error flow in creating matcher (bsc#1012628).
- btrfs: remove BUG_ON() in find_parent_nodes() (bsc#1012628).
- btrfs: remove BUG_ON(!eie) in find_parent_nodes (bsc#1012628).
- net: mdio: Demote probed message to debug print (bsc#1012628).
- dm btree: add a defensive bounds check to insert_at()
  (bsc#1012628).
- dm space map common: add bounds check to sm_ll_lookup_bitmap()
  (bsc#1012628).
- can: do not increase rx statistics when generating a CAN rx
  error message frame (bsc#1012628).
- bpf/selftests: Fix namespace mount setup in tc_redirect
  (bsc#1012628).
- mlxsw: pci: Avoid flow control for EMAD packets (bsc#1012628).
- net: phy: marvell: configure RGMII delays for 88E1118
  (bsc#1012628).
- net: gemini: allow any RGMII interface mode (bsc#1012628).
- regulator: qcom_smd: Align probe function with rpmh-regulator
  (bsc#1012628).
- serial: pl010: Drop CR register reset on set_termios
  (bsc#1012628).
- serial: pl011: Drop CR register reset on set_termios
  (bsc#1012628).
- serial: core: Keep mctrl register state and cached copy in sync
  (bsc#1012628).
- random: do not throw away excess input to crng_fast_load
  (bsc#1012628).
- net/mlx5: Update log_max_qp value to FW max capability
  (bsc#1012628).
- net/mlx5e: Unblock setting vid 0 for VF in case PF isn't
  eswitch manager (bsc#1012628).
- parisc: Avoid calling faulthandler_disabled() twice
  (bsc#1012628).
- can: flexcan: allow to change quirks at runtime (bsc#1012628).
- can: flexcan: rename RX modes (bsc#1012628).
- can: flexcan: add more quirks to describe RX path capabilities
  (bsc#1012628).
- x86/kbuild: Enable CONFIG_KALLSYMS_ALL=y in the defconfigs
  (bsc#1012628).
- clk: samsung: exynos850: Register clocks early (bsc#1012628).
- powerpc/6xx: add missing of_node_put (bsc#1012628).
- powerpc/powernv: add missing of_node_put (bsc#1012628).
- powerpc/cell: add missing of_node_put (bsc#1012628).
- powerpc/btext: add missing of_node_put (bsc#1012628).
- powerpc/watchdog: Fix missed watchdog reset due to memory
  ordering race (bsc#1012628).
- ASoC: imx-hdmi: add put_device() after of_find_device_by_node()
  (bsc#1012628).
- i2c: i801: Don't silently correct invalid transfer size
  (bsc#1012628).
- powerpc/smp: Move setup_profiling_timer() under CONFIG_PROFILING
  (bsc#1012628).
- i2c: mpc: Correct I2C reset procedure (bsc#1012628).
- clk: meson: gxbb: Fix the SDM_EN bit for MPLL0 on GXBB
  (bsc#1012628).
- powerpc/powermac: Add missing lockdep_register_key()
  (bsc#1012628).
- KVM: PPC: Book3S: Suppress warnings when allocating too big
  memory slots (bsc#1012628).
- KVM: PPC: Book3S: Suppress failed alloc warning in
  H_COPY_TOFROM_GUEST (bsc#1012628).
- w1: Misuse of get_user()/put_user() reported by sparse
  (bsc#1012628).
- nvmem: core: set size for sysfs bin file (bsc#1012628).
- dm: fix alloc_dax error handling in alloc_dev (bsc#1012628).
- dm: make the DAX support depend on CONFIG_FS_DAX (bsc#1012628).
- ASoC: test-component: fix null pointer dereference
  (bsc#1012628).
- interconnect: qcom: rpm: Prevent integer overflow in rate
  (bsc#1012628).
- scsi: ufs: Fix a kernel crash during shutdown (bsc#1012628).
- scsi: lpfc: Fix leaked lpfc_dmabuf mbox allocations with NPIV
  (bsc#1012628).
- scsi: lpfc: Trigger SLI4 firmware dump before doing driver
  cleanup (bsc#1012628).
- ALSA: seq: Set upper limit of processed events (bsc#1012628).
- MIPS: Loongson64: Use three arguments for slti (bsc#1012628).
- powerpc/40x: Map 32Mbytes of memory at startup (bsc#1012628).
- selftests/powerpc/spectre_v2: Return skip code when miss_percent
  is high (bsc#1012628).
- powerpc: handle kdump appropriately with
  crash_kexec_post_notifiers option (bsc#1012628).
- powerpc/fadump: Fix inaccurate CPU state info in vmcore
  generated with panic (bsc#1012628).
- ASoC: SOF: Intel: hda: add quirks for HDAudio DMA position
  information (bsc#1012628).
- udf: Fix error handling in udf_new_inode() (bsc#1012628).
- MIPS: OCTEON: add put_device() after of_find_device_by_node()
  (bsc#1012628).
- irqchip/gic-v4: Disable redistributors' view of the VPE table
  at boot time (bsc#1012628).
- i2c: designware-pci: Fix to change data types of hcnt and lcnt
  parameters (bsc#1012628).
- scsi: hisi_sas: Prevent parallel FLR and controller reset
  (bsc#1012628).
- ASoC: SOF: ipc: Add null pointer check for substream->runtime
  (bsc#1012628).
- selftests/powerpc: Add a test of sigreturning to the kernel
  (bsc#1012628).
- MIPS: Octeon: Fix build errors using clang (bsc#1012628).
- scsi: sr: Don't use GFP_DMA (bsc#1012628).
- scsi: mpi3mr: Fixes around reply request queues (bsc#1012628).
- ASoC: mediatek: mt8192-mt6359: fix device_node leak
  (bsc#1012628).
- phy: phy-mtk-tphy: add support efuse setting (bsc#1012628).
- ASoC: mediatek: mt8173: fix device_node leak (bsc#1012628).
- ASoC: mediatek: mt8183: fix device_node leak (bsc#1012628).
- habanalabs: change wait for interrupt timeout to 64 bit
  (bsc#1012628).
- habanalabs: skip read fw errors if dynamic descriptor invalid
  (bsc#1012628).
- phy: mediatek: Fix missing check in mtk_mipi_tx_probe
  (bsc#1012628).
- mailbox: change mailbox-mpfs compatible string (bsc#1012628).
- signal: In get_signal test for signal_group_exit every time
  through the loop (bsc#1012628).
- PCI: mediatek-gen3: Disable DVFSRC voltage request
  (bsc#1012628).
- PCI: qcom: Fix an error handling path in 'qcom_pcie_probe()'
  (bsc#1012628).
- PCI: rcar: Check if device is runtime suspended instead of
  __clk_is_enabled() (bsc#1012628).
- PCI: dwc: Do not remap invalid res (bsc#1012628).
- PCI: aardvark: Fix checking for MEM resource type (bsc#1012628).
- PCI: apple: Fix REFCLK1 enable/poll logic (bsc#1012628).
- KVM: VMX: Don't unblock vCPU w/ Posted IRQ if IRQs are disabled
  in guest (bsc#1012628).
- KVM: s390: Ensure kvm_arch_no_poll() is read once when blocking
  vCPU (bsc#1012628).
- KVM: VMX: Read Posted Interrupt "control" exactly once per
  loop iteration (bsc#1012628).
- KVM: X86: Ensure that dirty PDPTRs are loaded (bsc#1012628).
- KVM: x86: Handle 32-bit wrap of EIP for EMULTYPE_SKIP with
  flat code seg (bsc#1012628).
- KVM: x86: Exit to userspace if emulation prepared a completion
  callback (bsc#1012628).
- i3c: fix incorrect address slot lookup on 64-bit (bsc#1012628).
- i3c/master/mipi-i3c-hci: Fix a potentially infinite loop in
  'hci_dat_v1_get_index()' (bsc#1012628).
- tracing: Do not let synth_events block other dyn_event systems
  during create (bsc#1012628).
- Input: ti_am335x_tsc - set ADCREFM for X configuration
  (bsc#1012628).
- Input: ti_am335x_tsc - fix STEPCONFIG setup for Z2
  (bsc#1012628).
- PCI: mvebu: Check for errors from pci_bridge_emul_init() call
  (bsc#1012628).
- PCI: mvebu: Do not modify PCI IO type bits in conf_write
  (bsc#1012628).
- PCI: mvebu: Fix support for bus mastering and PCI_COMMAND on
  emulated bridge (bsc#1012628).
- PCI: mvebu: Fix configuring secondary bus of PCIe Root Port
  via emulated bridge (bsc#1012628).
- PCI: mvebu: Setup PCIe controller to Root Complex mode
  (bsc#1012628).
- PCI: mvebu: Fix support for PCI_BRIDGE_CTL_BUS_RESET on emulated
  bridge (bsc#1012628).
- PCI: mvebu: Fix support for PCI_EXP_DEVCTL on emulated bridge
  (bsc#1012628).
- PCI: mvebu: Fix support for PCI_EXP_RTSTA on emulated bridge
  (bsc#1012628).
- PCI: mvebu: Fix support for DEVCAP2, DEVCTL2 and LNKCTL2
  registers on emulated bridge (bsc#1012628).
- KVM: RISC-V: Avoid spurious virtual interrupts after clearing
  hideleg CSR (bsc#1012628).
- NFSD: Fix verifier returned in stable WRITEs (bsc#1012628).
- Revert "nfsd: skip some unnecessary stats in the v4 case"
  (bsc#1012628).
- nfsd: fix crash on COPY_NOTIFY with special stateid
  (bsc#1012628).
- x86/hyperv: Properly deal with empty cpumasks in
  hyperv_flush_tlb_multi() (bsc#1012628).
- drm/i915/pxp: Hold RPM wakelock during PXP unbind (bsc#1012628).
- drm/i915: don't call free_mmap_offset when purging
  (bsc#1012628).
- SUNRPC: Fix sockaddr handling in the svc_xprt_create_error
  trace point (bsc#1012628).
- SUNRPC: Fix sockaddr handling in svcsock_accept_class trace
  points (bsc#1012628).
- drm/sun4i: dw-hdmi: Fix missing put_device() call in
  sun8i_hdmi_phy_get (bsc#1012628).
- drm/atomic: Check new_crtc_state->active to determine if CRTC
  needs disable in self refresh mode (bsc#1012628).
- ntb_hw_switchtec: Fix pff ioread to read into mmio_part_cfg_all
  (bsc#1012628).
- ntb_hw_switchtec: Fix bug with more than 32 partitions
  (bsc#1012628).
- drm/amd/display: invalid parameter check in dmub_hpd_callback
  (bsc#1012628).
- drm/amdkfd: Check for null pointer after calling kmemdup
  (bsc#1012628).
- drm/amdgpu: use spin_lock_irqsave to avoid deadlock by local
  interrupt (bsc#1012628).
- PCI: mt7621: Add missing MODULE_LICENSE() (bsc#1012628).
- i3c: master: dw: check return of dw_i3c_master_get_free_pos()
  (bsc#1012628).
- dma-buf: cma_heap: Fix mutex locking section (bsc#1012628).
- tracing/uprobes: Check the return value of kstrdup() for
  tu->filename (bsc#1012628).
- tracing/probes: check the return value of kstrndup() for pbuf
  (bsc#1012628).
- mm: defer kmemleak object creation of module_alloc()
  (bsc#1012628).
- kasan: fix quarantine conflicting with init_on_free
  (bsc#1012628).
- selftests/vm: make charge_reserved_hugetlb.sh work with existing
  cgroup setting (bsc#1012628).
- hugetlbfs: fix off-by-one error in hugetlb_vmdelete_list()
  (bsc#1012628).
- rpmsg: core: Clean up resources on announce_create failure
  (bsc#1012628).
- ifcvf/vDPA: fix misuse virtio-net device config size for blk
  dev (bsc#1012628).
- crypto: omap-aes - Fix broken pm_runtime_and_get() usage
  (bsc#1012628).
- crypto: stm32/crc32 - Fix kernel BUG triggered in probe()
  (bsc#1012628).
- crypto: caam - replace this_cpu_ptr with raw_cpu_ptr
  (bsc#1012628).
- ubifs: Error path in ubifs_remount_rw() seems to wrongly free
  write buffers (bsc#1012628).
- tpm: fix potential NULL pointer access in tpm_del_char_device
  (bsc#1012628).
- tpm: fix NPE on probe for missing device (bsc#1012628).
- mfd: tps65910: Set PWR_OFF bit during driver probe
  (bsc#1012628).
- spi: uniphier: Fix a bug that doesn't point to private data
  correctly (bsc#1012628).
- xen/gntdev: fix unmap notification order (bsc#1012628).
- md: Move alloc/free acct bioset in to personality (bsc#1012628).
- HID: magicmouse: Fix an error handling path in
  magicmouse_probe() (bsc#1012628).
- x86/mce: Check regs before accessing it (bsc#1012628).
- fuse: Pass correct lend value to filemap_write_and_wait_range()
  (bsc#1012628).
- serial: Fix incorrect rs485 polarity on uart open (bsc#1012628).
- cputime, cpuacct: Include guest time in user time in
  cpuacct.stat (bsc#1012628).
- sched/cpuacct: Fix user/system in shown cpuacct.usage*
  (bsc#1012628).
- tracing/osnoise: Properly unhook events if
  start_per_cpu_kthreads() fails (bsc#1012628).
- tracing/kprobes: 'nmissed' not showed correctly for kretprobe
  (bsc#1012628).
- tracing: Have syscall trace events use
  trace_event_buffer_lock_reserve() (bsc#1012628).
- remoteproc: imx_rproc: Fix a resource leak in the remove
  function (bsc#1012628).
- iwlwifi: mvm: Increase the scan timeout guard to 30 seconds
  (bsc#1012628).
- device property: Fix fwnode_graph_devcon_match() fwnode leak
  (bsc#1012628).
- drm/tegra: submit: Add missing pm_runtime_mark_last_busy()
  (bsc#1012628).
- drm/etnaviv: limit submit sizes (bsc#1012628).
- drm/amd/display: Fix the uninitialized variable in
  enable_stream_features() (bsc#1012628).
- drm/nouveau/kms/nv04: use vzalloc for nv04_display
  (bsc#1012628).
- drm/bridge: analogix_dp: Make PSR-exit block less (bsc#1012628).
- parisc: Fix lpa and lpa_user defines (bsc#1012628).
- powerpc/64s/radix: Fix huge vmap false positive (bsc#1012628).
- scsi: lpfc: Fix lpfc_force_rscn ndlp kref imbalance
  (bsc#1012628).
- drm/amdgpu: Use correct VIEWPORT_DIMENSION for DCN2
  (bsc#1012628).
- drm/amdgpu: don't do resets on APUs which don't support it
  (bsc#1012628).
- drm/amd/display: Revert W/A for hard hangs on DCN20/DCN21
  (bsc#1012628).
- drm/i915/display/ehl: Update voltage swing table (bsc#1012628).
- PCI: xgene: Fix IB window setup (bsc#1012628).
- PCI: pciehp: Use down_read/write_nested(reset_lock) to fix
  lockdep errors (bsc#1012628).
- PCI: pci-bridge-emul: Make expansion ROM Base Address register
  read-only (bsc#1012628).
- PCI: pci-bridge-emul: Properly mark reserved PCIe bits in PCI
  config space (bsc#1012628).
- PCI: pci-bridge-emul: Fix definitions of reserved bits
  (bsc#1012628).
- PCI: pci-bridge-emul: Correctly set PCIe capabilities
  (bsc#1012628).
- PCI: pci-bridge-emul: Set PCI_STATUS_CAP_LIST for PCIe device
  (bsc#1012628).
- xfrm: fix policy lookup for ipv6 gre packets (bsc#1012628).
- xfrm: fix dflt policy check when there is no policy configured
  (bsc#1012628).
- btrfs: fix deadlock between quota enable and other quota
  operations (bsc#1012628).
- btrfs: zoned: cache reported zone during mount (bsc#1012628).
- btrfs: check the root node for uptodate before returning it
  (bsc#1012628).
- btrfs: add extent allocator hook to decide to allocate chunk
  or not (bsc#1012628).
- btrfs: zoned: unset dedicated block group on allocation failure
  (bsc#1012628).
- btrfs: zoned: fix chunk allocation condition for zoned allocator
  (bsc#1012628).
- btrfs: respect the max size in the header when activating swap
  file (bsc#1012628).
- ext4: make sure to reset inode lockdep class when quota enabling
  fails (bsc#1012628).
- ext4: make sure quota gets properly shutdown on error
  (bsc#1012628).
- ext4: fix a possible ABBA deadlock due to busy PA (bsc#1012628).
- ext4: initialize err_blk before calling __ext4_get_inode_loc
  (bsc#1012628).
- ext4: fix fast commit may miss tracking range for
  FALLOC_FL_ZERO_RANGE (bsc#1012628).
- ext4: set csum seed in tmp inode while migrating to extents
  (bsc#1012628).
- ext4: Fix BUG_ON in ext4_bread when write quota data
  (bsc#1012628).
- ext4: use ext4_ext_remove_space() for fast commit replay delete
  range (bsc#1012628).
- ext4: fast commit may miss tracking unwritten range during
  ftruncate (bsc#1012628).
- ext4: destroy ext4_fc_dentry_cachep kmemcache on module removal
  (bsc#1012628).
- ext4: fix null-ptr-deref in '__ext4_journal_ensure_credits'
  (bsc#1012628).
- ext4: fix an use-after-free issue about data=journal writeback
  mode (bsc#1012628).
- ext4: don't use the orphan list when migrating an inode
  (bsc#1012628).
- drm/radeon: fix error handling in radeon_driver_open_kms
  (bsc#1012628).
- drm/amdgpu/display: Only set vblank_disable_immediate when
  PSR is not enabled (bsc#1012628).
- firmware: Update Kconfig help text for Google firmware
  (bsc#1012628).
- can: mcp251xfd: mcp251xfd_tef_obj_read(): fix typo in error
  message (bsc#1012628).
- media: rcar-csi2: Optimize the selection PHTW register
  (bsc#1012628).
- drm/vc4: hdmi: Make sure the device is powered with CEC
  (bsc#1012628).
- media: correct MEDIA_TEST_SUPPORT help text (bsc#1012628).
- Documentation: coresight: Fix documentation issue (bsc#1012628).
- Documentation: dmaengine: Correctly describe dmatest with
  channel unset (bsc#1012628).
- Documentation: ACPI: Fix data node reference documentation
  (bsc#1012628).
- Documentation, arch: Remove leftovers from raw device
  (bsc#1012628).
- Documentation, arch: Remove leftovers from CIFS_WEAK_PW_HASH
  (bsc#1012628).
- Documentation: refer to config RANDOMIZE_BASE for kernel
  address-space randomization (bsc#1012628).
- Documentation: fix firewire.rst ABI file path error
  (bsc#1012628).
- Bluetooth: btusb: Return error code when getting patch status
  failed (bsc#1012628).
- net: usb: Correct reset handling of smsc95xx (bsc#1012628).
- Bluetooth: hci_sync: Fix not setting adv set duration
  (bsc#1012628).
- scsi: core: Show SCMD_LAST in text form (bsc#1012628).
- of: base: Improve argument length mismatch error (bsc#1012628).
- scsi: ufs: ufs-mediatek: Fix error checking in
  ufs_mtk_init_va09_pwr_ctrl() (bsc#1012628).
- dmaengine: uniphier-xdmac: Fix type of address variables
  (bsc#1012628).
- dmaengine: idxd: fix wq settings post wq disable (bsc#1012628).
- RDMA/hns: Modify the mapping attribute of doorbell to device
  (bsc#1012628).
- RDMA/rxe: Fix a typo in opcode name (bsc#1012628).
- dmaengine: stm32-mdma: fix STM32_MDMA_CTBR_TSEL_MASK
  (bsc#1012628).
- Revert "net/mlx5: Add retry mechanism to the command entry
  index allocation" (bsc#1012628).
- powerpc/cell: Fix clang -Wimplicit-fallthrough warning
  (bsc#1012628).
- powerpc/fsl/dts: Enable WA for erratum A-009885 on fman3l MDIO
  buses (bsc#1012628).
- block: fix async_depth sysfs interface for mq-deadline
  (bsc#1012628).
- block: Fix fsync always failed if once failed (bsc#1012628).
- drm/vc4: crtc: Drop feed_txp from state (bsc#1012628).
- drm/vc4: Fix non-blocking commit getting stuck forever
  (bsc#1012628).
- drm/vc4: crtc: Copy assigned channel to the CRTC (bsc#1012628).
- libbpf: Remove deprecation attribute from struct
  bpf_prog_prep_result (bsc#1012628).
- bpftool: Remove inclusion of utilities.mak from Makefiles
  (bsc#1012628).
- bpftool: Fix indent in option lists in the documentation
  (bsc#1012628).
- xdp: check prog type before updating BPF link (bsc#1012628).
- bpf: Fix mount source show for bpffs (bsc#1012628).
- bpf: Mark PTR_TO_FUNC register initially with zero offset
  (bsc#1012628).
- perf evsel: Override attr->sample_period for non-libpfm4 events
  (bsc#1012628).
- ipv4: update fib_info_cnt under spinlock protection
  (bsc#1012628).
- ipv4: avoid quadratic behavior in netns dismantle (bsc#1012628).
- mlx5: Don't accidentally set RTO_ONLINK before
  mlx5e_route_lookup_ipv4_get() (bsc#1012628).
- net/fsl: xgmac_mdio: Add workaround for erratum A-009885
  (bsc#1012628).
- net/fsl: xgmac_mdio: Fix incorrect iounmap when removing module
  (bsc#1012628).
- parisc: pdc_stable: Fix memory leak in pdcs_register_pathentries
  (bsc#1012628).
- RISC-V: defconfigs: Set CONFIG_FB=y, for FB console
  (bsc#1012628).
- riscv: dts: microchip: mpfs: Drop empty chosen node
  (bsc#1012628).
- drm/vmwgfx: Remove explicit transparent hugepages support
  (bsc#1012628).
- drm/vmwgfx: Remove unused compile options (bsc#1012628).
- f2fs: fix remove page failed in invalidate compress pages
  (bsc#1012628).
- f2fs: fix to avoid panic in is_alive() if metadata is
  inconsistent (bsc#1012628).
- f2fs: compress: fix potential deadlock of compress file
  (bsc#1012628).
- f2fs: fix to reserve space for IO align feature (bsc#1012628).
- f2fs: fix to check available space of CP area correctly in
  update_ckpt_flags() (bsc#1012628).
- crypto: octeontx2 - uninitialized variable in kvf_limits_store()
  (bsc#1012628).
- af_unix: annote lockless accesses to unix_tot_inflight &
  gc_in_progress (bsc#1012628).
- clk: Emit a stern warning with writable debugfs enabled
  (bsc#1012628).
- clk: si5341: Fix clock HW provider cleanup (bsc#1012628).
- pinctrl/rockchip: fix gpio device creation (bsc#1012628).
- gpio: mpc8xxx: Fix IRQ check in mpc8xxx_probe (bsc#1012628).
- gpio: idt3243x: Fix IRQ check in idt_gpio_probe (bsc#1012628).
- net/smc: Fix hung_task when removing SMC-R devices
  (bsc#1012628).
- net: axienet: increase reset timeout (bsc#1012628).
- net: axienet: Wait for PhyRstCmplt after core reset
  (bsc#1012628).
- net: axienet: reset core on initialization prior to MDIO access
  (bsc#1012628).
- net: axienet: add missing memory barriers (bsc#1012628).
- net: axienet: limit minimum TX ring size (bsc#1012628).
- net: axienet: Fix TX ring slot available check (bsc#1012628).
- net: axienet: fix number of TX ring slots for available check
  (bsc#1012628).
- net: axienet: fix for TX busy handling (bsc#1012628).
- net: axienet: increase default TX ring size to 128
  (bsc#1012628).
- bitops: protect find_first_{,zero}_bit properly (bsc#1012628).
- um: gitignore: Add kernel/capflags.c (bsc#1012628).
- HID: vivaldi: fix handling devices not using numbered reports
  (bsc#1012628).
- mctp: test: zero out sockaddr (bsc#1012628).
- rtc: Move variable into switch case statement (bsc#1012628).
- rtc: pxa: fix null pointer dereference (bsc#1012628).
- vdpa/mlx5: Fix wrong configuration of virtio_version_1_0
  (bsc#1012628).
- virtio_ring: mark ring unused on error (bsc#1012628).
- taskstats: Cleanup the use of task->exit_code (bsc#1012628).
- inet: frags: annotate races around fqdir->dead and
  fqdir->high_thresh (bsc#1012628).
- netns: add schedule point in ops_exit_list() (bsc#1012628).
- iwlwifi: fix Bz NMI behaviour (bsc#1012628).
- xfrm: Don't accidentally set RTO_ONLINK in decode_session4()
  (bsc#1012628).
- vdpa/mlx5: Fix config_attr_mask assignment (bsc#1012628).
- vdpa/mlx5: Restore cur_num_vqs in case of failure in
  change_num_qps() (bsc#1012628).
- gre: Don't accidentally set RTO_ONLINK in
  gre_fill_metadata_dst() (bsc#1012628).
- libcxgb: Don't accidentally set RTO_ONLINK in cxgb_find_route()
  (bsc#1012628).
- perf script: Fix hex dump character output (bsc#1012628).
- dmaengine: at_xdmac: Don't start transactions at tx_submit level
  (bsc#1012628).
- dmaengine: at_xdmac: Start transfer for cyclic channels in
  issue_pending (bsc#1012628).
- dmaengine: at_xdmac: Print debug message after realeasing the
  lock (bsc#1012628).
- dmaengine: at_xdmac: Fix concurrency over xfers_list
  (bsc#1012628).
- dmaengine: at_xdmac: Fix lld view setting (bsc#1012628).
- dmaengine: at_xdmac: Fix at_xdmac_lld struct definition
  (bsc#1012628).
- perf cputopo: Fix CPU topology reading on s/390 (bsc#1012628).
- perf tools: Drop requirement for libstdc++.so for libopencsd
  check (bsc#1012628).
- perf metricgroup: Fix use after free in metric__new()
  (bsc#1012628).
- perf test: Enable system wide for metricgroups test
  (bsc#1012628).
- perf probe: Fix ppc64 'perf probe add events failed' case
  (bsc#1012628).
- perf metric: Fix metric_leader (bsc#1012628).
- devlink: Remove misleading internal_flags from health reporter
  dump (bsc#1012628).
- arm64: dts: qcom: msm8996: drop not documented adreno properties
  (bsc#1012628).
- net: fix sock_timestamping_bind_phc() to release device
  (bsc#1012628).
- net: bonding: fix bond_xmit_broadcast return value error bug
  (bsc#1012628).
- net: ipa: fix atomic update in ipa_endpoint_replenish()
  (bsc#1012628).
- net_sched: restore "mpu xxx" handling (bsc#1012628).
- net: mscc: ocelot: don't let phylink re-enable TX PAUSE on
  the NPI port (bsc#1012628).
- bcmgenet: add WOL IRQ check (bsc#1012628).
- net: mscc: ocelot: don't dereference NULL pointers with shared
  tc filters (bsc#1012628).
- net: wwan: Fix MRU mismatch issue which may lead to data
  connection lost (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix error checking in
  mtk_mac_config() (bsc#1012628).
- net: ocelot: Fix the call to switchdev_bridge_port_offload
  (bsc#1012628).
- net: sfp: fix high power modules without diagnostic monitoring
  (bsc#1012628).
- net: cpsw: avoid alignment faults by taking NET_IP_ALIGN into
  account (bsc#1012628).
- net: phy: micrel: use kszphy_suspend()/kszphy_resume for irq
  aware devices (bsc#1012628).
- net: mscc: ocelot: fix using match before it is set
  (bsc#1012628).
- dt-bindings: display: meson-dw-hdmi: add missing
  sound-name-prefix property (bsc#1012628).
- dt-bindings: display: meson-vpu: Add missing amlogic,canvas
  property (bsc#1012628).
- dt-bindings: watchdog: Require samsung,syscon-phandle for
  Exynos7 (bsc#1012628).
- sch_api: Don't skip qdisc attach on ingress (bsc#1012628).
- scripts/dtc: dtx_diff: remove broken example from help text
  (bsc#1012628).
- lib82596: Fix IRQ check in sni_82596_probe (bsc#1012628).
- mm/hmm.c: allow VM_MIXEDMAP to work with hmm_range_fault
  (bsc#1012628).
- bonding: Fix extraction of ports from the packet headers
  (bsc#1012628).
- lib/test_meminit: destroy cache in kmem_cache_alloc_bulk()
  test (bsc#1012628).
- KVM: x86: Do runtime CPUID update before updating
  vcpu->arch.cpuid_entries (bsc#1012628).
- KVM: x86: Partially allow KVM_SET_CPUID{,2} after KVM_RUN
  (bsc#1012628).
- KVM: selftests: Rename 'get_cpuid_test' to 'cpuid_test'
  (bsc#1012628).
- KVM: selftests: Test KVM_SET_CPUID2 after KVM_RUN (bsc#1012628).
- ASoC: SOF: topology: remove sof_load_pipeline_ipc()
  (bsc#1012628).
- ASoC: SOF: free widgets in sof_tear_down_pipelines() for static
  pipelines (bsc#1012628).
- ASoC: SOF: sof-audio: setup sched widgets during pipeline
  complete step (bsc#1012628).
- ASoC: SOF: handle paused streams during system suspend
  (bsc#1012628).
- scripts: sphinx-pre-install: add required ctex dependency
  (bsc#1012628).
- scripts: sphinx-pre-install: Fix ctex support on Debian
  (bsc#1012628).
- commit c7377e3
* Fri Jan 28 2022 mkubecek@suse.cz
- config: disable REGULATOR_MAX20086 on s390x
  This driver seems to make little sense on s390x and it also fails to build
  due to disabled CONFIG_GPIOLIB.
- commit 5152409
* Thu Jan 27 2022 tiwai@suse.de
- mac80211: allow non-standard VHT MCS-10/11 (bsc#1192891).
- commit f7171e6
* Thu Jan 27 2022 tiwai@suse.de
- Delete patches.suse/Bluetooth-Apply-initial-command-workaround-for-more-.patch
  The upstream had already the fix
- commit 59dcb9d
* Wed Jan 26 2022 tiwai@suse.de
- drm/i915: Flush TLBs before releasing backing store
  (CVE-2022-0330 bsc#1194880).
- commit 32e5616
* Wed Jan 26 2022 tiwai@suse.de
- Update config files: disable CONFIG_INTEL_IDXD_COMPAT (bsc#1194858)
  The compat support is rather unwanted, and this allows us to build
  idxd bus as module, too.
- commit 527268a
* Tue Jan 25 2022 mrostecki@suse.de
- config: Enable BPF LSM
  This LSM might get more adoption both in core system projects and
  container/k8s works and it would be good to be ready to support them.
  BPF LSM is a feature available since kernel 5.7 which allows to write
  BPF programs attached to LSM hooks and allowing/denying a particular
  event.
  BPF LSM is already adopted in a (not yet default) restrict-fs feature in
  systemd[0].
  BPF LSM is also used in the lockc[1] project which we develop at SUSE.
  There should be no functional or performance changes for users who don't
  load any BPF LSM programs. BPF LSM works only if some BPF programs is
  explicitly loaded.
  [0] https://github.com/systemd/systemd/blob/main/src/core/bpf/restrict_fs/restrict-fs.bpf.c
  [1] https://github.com/rancher-sandbox/lockc
- commit c2c25b1
* Tue Jan 25 2022 tiwai@suse.de
- drm/amdgpu: Fix rejecting Tahiti GPUs (bsc#1194906).
- commit 8a4cb35
* Mon Jan 24 2022 jslaby@suse.cz
- Update
  patches.kernel.org/5.16.2-005-vfs-fs_context-fix-up-param-length-parsing-in-.patch
  (bsc#1012628 CVE-2022-0185 bsc#1194517).
  Add CVE reference.
- commit 0d710a8
* Mon Jan 24 2022 msuchanek@suse.de
- kernel-binary.spec.in: Move 20-kernel-default-extra.conf to the correctr
  directory (bsc#1195051).
- commit c80b5de
* Mon Jan 24 2022 tiwai@suse.de
- s390/mm: fix 2KB pgtable release race (bsc#1188896).
- commit 6f62d73
* Mon Jan 24 2022 mkubecek@suse.cz
- Update to 5.17-rc1
- eliminated 73 patches (67 stable, 6 mainline)
  - patches.kernel.org/*
  - patches.suse/0001-usb-Add-Xen-pvUSB-protocol-description.patch
  - patches.suse/0002-usb-Introduce-Xen-pvUSB-frontend-xen-hcd.patch
  - patches.suse/ALSA-usb-audio-Add-minimal-mute-notion-in-dB-mapping.patch
  - patches.suse/ALSA-usb-audio-Fix-dB-level-of-Bose-Revolve-SoundLin.patch
  - patches.suse/ALSA-usb-audio-Use-int-for-dB-map-values.patch
  - patches.suse/mwifiex-Fix-skb_over_panic-in-mwifiex_usb_recv.patch
- refresh
  - patches.rpmify/powerpc-64-BE-option-to-use-ELFv2-ABI-for-big-endian.patch
  - patches.suse/iwlwifi-module-firmware-ucode-fix.patch
  - patches.suse/vfs-add-super_operations-get_inode_dev
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
- disable ARM architectures (need config update)
- new config options
  - Power management and ACPI options
  - ACPI_PFRUT=m
  - ACPI_PCC=y
  - X86_AMD_PSTATE=m
  - Memory Management options
  - ANON_VMA_NAME=y
  - Networking support
  - NET_9P_FD=m
  - File systems
  - CACHEFILES_ERROR_INJECTION=n
  - UNICODE_UTF8_DATA=y
  - Kernel hacking
  - NET_DEV_REFCNT_TRACKER=n
  - NET_NS_REFCNT_TRACKER=n
  - PAGE_TABLE_CHECK=y
  - PAGE_TABLE_CHECK_ENFORCED=n
  - FTRACE_SORT_STARTUP_TEST=n
  - TEST_REF_TRACKER=n
  - TEST_SIPHASH=n
  - Generic Driver Options
  - DEVTMPFS_SAFE=n
  - Network device support
  - NET_VENDOR_ENGLEDER=y
  - TSNEP=m
  - TSNEP_SELFTESTS=n
  - ICE_HWTS=y
  - NET_VENDOR_VERTEXCOM=y
  - MSE102X=m
  - MCTP_SERIAL=m
  - IWLMEI=m
  - WWAN_DEBUGFS=n
  - Hardware Monitoring support
  - SENSORS_NZXT_SMART2=m
  - SENSORS_DELTA_AHE50DC_FAN=m
  - SENSORS_IR38064_REGULATOR=y
  - SENSORS_MP5023=m
  - SENSORS_INA238=m
  - SENSORS_ASUS_WMI=m
  - SENSORS_ASUS_WMI_EC=m
  - Voltage and Current Regulator Support
  - REGULATOR_MAX20086=m
  - REGULATOR_TPS68470=m
  - Graphics support
  - TINYDRM_ILI9163=n
  - Sound card support
  - SND_HDA_SCODEC_CS35L41_I2C=m
  - SND_HDA_SCODEC_CS35L41_SPI=m
  - SND_SOC_INTEL_SOF_NAU8825_MACH=m
  - SND_SOC_SOF_AMD_TOPLEVEL=m
  - SND_SOC_SOF_AMD_RENOIR=m
  - SND_SOC_AK4375=n
  - SND_SOC_TLV320ADC3XXX=n
  - X86 Platform Specific Device Drivers
  - YOGABOOK_WMI=m
  - ASUS_TF103C_DOCK=m
  - INTEL_VSEC=m
  - X86_ANDROID_TABLETS=m
  - SIEMENS_SIMATIC_IPC=m
  - SIEMENS_SIMATIC_IPC_WDT=m
  - Common Clock Framework
  - COMMON_CLK_TPS68470=n
  - COMMON_CLK_LAN966X=n
  - Industrial I/O support
  - TI_ADS8344=n
  - TI_ADS8688=n
  - TI_ADS124S08=n
  - AD74413R=n
  - AD3552R=n
  - AD7293=n
  - MAX5821=n
  - ADMV8818=n
  - ADMV1013=n
  - Misc drivers
  - GNSS_USB=m
  - SERIAL_8250_PERICOM=y
  - GPIO_SIM=m
  - CHARGER_MAX77976=m
  - VIDEO_OV5693=m
  - HID_LETSKETCH=m
  - LEDS_SIEMENS_SIMATIC_IPC=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - DRM_RCAR_USE_LVDS=n
  - DRM_RCAR_MIPI_DSI=n
  - DRM_PANEL_BOE_BF060Y8M_AJ0=n
  - DRM_PANEL_JDI_R63452=n
  - DRM_PANEL_NOVATEK_NT35950=n
  - DRM_PANEL_SONY_TULIP_TRULY_NT35521=n
  - VIDEO_MAX96712=m
  - PHY_FSL_IMX8M_PCIE=m
  - x86_64
  - SLS=y
  - i386
  - PHY_LAN966X_SERDES=m
  - ppc64 / ppc64le
  - KVM_BOOK3S_HV_NESTED_PMU_WORKAROUND=n
  - SURFACE_PLATFORMS=n
  - s390x
  - SURFACE_PLATFORMS=n
  - CRYPTO_CHACHA_S390=m
  - riscv64
  - SOC_STARFIVE=y
  - RISCV_BOOT_SPINWAIT=y
  - PINCTRL_STARFIVE=m
  - SND_AMD_ACP_CONFIG=m
  - CLK_STARFIVE_JH7100=y
  - RESET_STARFIVE_JH7100=y
  - PHY_LAN966X_SERDES=m
- commit 8751a94
* Fri Jan 21 2022 tiwai@suse.de
- HID: wacom: Avoid using stale array indicies to read contact
  count (bsc#1194667).
- HID: wacom: Ignore the confidence flag when a touch is removed
  (bsc#1194667).
- HID: wacom: Reset expected and received contact counts at the
  same time (bsc#1194667).
- commit 07a970c
* Fri Jan 21 2022 jslaby@suse.cz
- Linux 5.16.2 (bsc#1012628).
- ALSA: hda/realtek: Re-order quirk entries for Lenovo
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Legion Y9000X 2020
  (bsc#1012628).
- ALSA: hda/tegra: Fix Tegra194 HDA reset failure (bsc#1012628).
- ALSA: hda: ALC287: Add Lenovo IdeaPad Slim 9i 14ITL5 speaker
  quirk (bsc#1012628).
- ALSA: hda/realtek - Fix silent output on Gigabyte X570 Aorus
  Master after reboot from Windows (bsc#1012628).
- ALSA: hda/realtek: Use ALC285_FIXUP_HP_GPIO_LED on another HP
  laptop (bsc#1012628).
- ALSA: hda/realtek: Add speaker fixup for some Yoga 15ITL5
  devices (bsc#1012628).
- perf annotate: Avoid TUI crash when navigating in the annotation
  of recursive functions (bsc#1012628).
- firmware: qemu_fw_cfg: fix kobject leak in probe error path
  (bsc#1012628).
- firmware: qemu_fw_cfg: fix NULL-pointer deref on duplicate
  entries (bsc#1012628).
- firmware: qemu_fw_cfg: fix sysfs information leak (bsc#1012628).
- rtlwifi: rtl8192cu: Fix WARNING when calling local_irq_restore()
  with interrupts enabled (bsc#1012628).
- media: uvcvideo: fix division by zero at stream start
  (bsc#1012628).
- video: vga16fb: Only probe for EGA and VGA 16 color graphic
  cards (bsc#1012628).
- 9p: fix enodata when reading growing file (bsc#1012628).
- 9p: only copy valid iattrs in 9P2000.L setattr implementation
  (bsc#1012628).
- NFSD: Fix zero-length NFSv3 WRITEs (bsc#1012628).
- remoteproc: qcom: pas: Add missing power-domain "mxc" for CDSP
  (bsc#1012628).
- KVM: s390: Clarify SIGP orders versus STOP/RESTART
  (bsc#1012628).
- KVM: x86: don't print when fail to read/write pv eoi memory
  (bsc#1012628).
- KVM: x86: Register Processor Trace interrupt hook iff PT
  enabled in guest (bsc#1012628).
- KVM: x86: Register perf callbacks after calling vendor's
  hardware_setup() (bsc#1012628).
- perf: Protect perf_guest_cbs with RCU (bsc#1012628).
- vfs: fs_context: fix up param length parsing in
  legacy_parse_param (bsc#1012628).
- remoteproc: qcom: pil_info: Don't memcpy_toio more than is
  provided (bsc#1012628).
- orangefs: Fix the size of a memory allocation in
  orangefs_bufmap_alloc() (bsc#1012628).
- drm/amd/display: explicitly set is_dsc_supported to false
  before use (bsc#1012628).
- devtmpfs regression fix: reconfigure on each mount
  (bsc#1012628).
- commit 6fa29ec
* Thu Jan 20 2022 msuchanek@suse.de
- kernel-binary.spec: Do not use the default certificate path (bsc#1194943).
  Using the the default path is broken since Linux 5.17
- commit 68b36f0
* Thu Jan 20 2022 jslaby@suse.cz
- disable the Bluetooth patch again
  The kernel is currently tested whether the patch is needed at all. As
  95655456e7ce in upstream might fix the issue too (but differently).
- commit c3bbaae
* Wed Jan 19 2022 mkubecek@suse.cz
- series.conf: cleanup
- move mainline patches into sorted section:
  - patches.suse/mwifiex-Fix-skb_over_panic-in-mwifiex_usb_recv.patch
  - patches.suse/0001-usb-Add-Xen-pvUSB-protocol-description.patch
  - patches.suse/0002-usb-Introduce-Xen-pvUSB-frontend-xen-hcd.patch
- update upstream references and move into sorted section:
  - patches.suse/ALSA-usb-audio-Add-minimal-mute-notion-in-dB-mapping.patch
  - patches.suse/ALSA-usb-audio-Fix-dB-level-of-Bose-Revolve-SoundLin.patch
  - patches.suse/ALSA-usb-audio-Use-int-for-dB-map-values.patch
  No effect on expanded tree.
- commit 607f978
* Wed Jan 19 2022 mkubecek@suse.cz
- Refresh and reenable
  patches.suse/Bluetooth-Apply-initial-command-workaround-for-more-.patch.
- commit a7b7c0d
* Tue Jan 18 2022 dmueller@suse.com
- lib/raid6: skip benchmark of non-chosen xor_syndrome (bsc#1195037)
- lib/raid6: Use strict priority ranking for pq gen()
  benchmarking (bsc#1195037).
- commit 3ce1e9c
* Mon Jan 17 2022 jeffm@suse.com
- series.conf: Add sorted section header/footer
  Even though we don't carry many patches in the stable or master
  branches, having the sorted section header/footer allows the automated
  tools to work.
- commit 05f8150
* Sun Jan 16 2022 jslaby@suse.cz
- Linux 5.16.1 (bsc#1012628).
- workqueue: Fix unbind_workers() VS wq_worker_running() race
  (bsc#1012628).
- workqueue: Fix unbind_workers() VS wq_worker_sleeping() race
  (bsc#1012628).
- staging: r8188eu: switch the led off during deinit
  (bsc#1012628).
- bpf: Fix out of bounds access from invalid *_or_null type
  verification (bsc#1012628).
- Bluetooth: btusb: Add one more Bluetooth part for the Realtek
  RTL8852AE (bsc#1012628).
- Bluetooth: btusb: Fix application of sizeof to pointer
  (bsc#1012628).
- Bluetooth: btusb: fix memory leak in
  btusb_mtk_submit_wmt_recv_urb() (bsc#1012628).
- Bluetooth: btusb: enable Mediatek to support AOSP extension
  (bsc#1012628).
- Bluetooth: btusb: Add the new support IDs for WCN6855
  (bsc#1012628).
- Bluetooth: btusb: Add one more Bluetooth part for WCN6855
  (bsc#1012628).
- Bluetooth: btusb: Add two more Bluetooth parts for WCN6855
  (bsc#1012628).
- Bluetooth: btusb: Add support for Foxconn MT7922A (bsc#1012628).
- Bluetooth: btintel: Fix broken LED quirk for legacy ROM devices
  (bsc#1012628).
- Bluetooth: btusb: Add support for Foxconn QCA 0xe0d0
  (bsc#1012628).
- Bluetooth: bfusb: fix division by zero in send path
  (bsc#1012628).
- ARM: dts: exynos: Fix BCM4330 Bluetooth reset polarity in I9100
  (bsc#1012628).
- USB: core: Fix bug in resuming hub's handling of wakeup requests
  (bsc#1012628).
- USB: Fix "slab-out-of-bounds Write" bug in
  usb_hcd_poll_rh_status (bsc#1012628).
- ath11k: Fix buffer overflow when scanning with extraie
  (bsc#1012628).
- mmc: sdhci-pci: Add PCI ID for Intel ADL (bsc#1012628).
- Bluetooth: add quirk disabling LE Read Transmit Power
  (bsc#1012628).
- Bluetooth: btbcm: disable read tx power for some Macs with
  the T2 Security chip (bsc#1012628).
- Bluetooth: btbcm: disable read tx power for MacBook Air 8,1
  and 8,2 (bsc#1012628).
- veth: Do not record rx queue hint in veth_xmit (bsc#1012628).
- mfd: intel-lpss: Fix too early PM enablement in the ACPI
  - >probe() (bsc#1012628).
- mfd: intel-lpss-pci: Fix clock speed for 38a8 UART
  (bsc#1012628).
- can: gs_usb: fix use of uninitialized variable, detach device
  on reception of invalid USB data (bsc#1012628).
- can: isotp: convert struct tpcon::{idx,len} to unsigned int
  (bsc#1012628).
- can: gs_usb: gs_can_start_xmit(): zero-initialize
  hf->{flags,reserved} (bsc#1012628).
- random: fix data race on crng_node_pool (bsc#1012628).
- random: fix data race on crng init time (bsc#1012628).
- platform/x86/intel: hid: add quirk to support Surface Go 3
  (bsc#1012628).
- drm/i915: Avoid bitwise vs logical OR warning in
  snb_wm_latency_quirk() (bsc#1012628).
- staging: greybus: fix stack size warning with UBSAN
  (bsc#1012628).
- parisc: Fix pdc_toc_pim_11 and pdc_toc_pim_20 definitions
  (bsc#1012628).
  Disabled:
  patches.suse/Bluetooth-Apply-initial-command-workaround-for-more-.patch
  as it conflicts with 95655456e7ce. Asked in bsc#1193124.
- commit 13f032a
* Thu Jan 13 2022 tiwai@suse.de
- Refresh patches.suse/iwlwifi-module-firmware-ucode-fix.patch.
  Adapt the uapi version for the latest kernel-firmware-20220111.
- commit 2f088f6
* Thu Jan 13 2022 mkubecek@suse.cz
- Update patches.suse/vfs-add-super_operations-get_inode_dev
  Copy an updated version from SLE15-SP4 with one minor refresh.
- commit c02e2ab
* Thu Jan 13 2022 jgross@suse.com
- Refresh
  patches.suse/0001-usb-Add-Xen-pvUSB-protocol-description.patch.
- Refresh
  patches.suse/0002-usb-Introduce-Xen-pvUSB-frontend-xen-hcd.patch.
- commit 8950040
* Wed Jan 12 2022 mkubecek@suse.cz
- update patches metadata
- update upstream references
  - patches.suse/media-Revert-media-uvcvideo-Set-unique-vdev-name-bas.patch
  - patches.suse/mwifiex-Fix-skb_over_panic-in-mwifiex_usb_recv.patch
  - patches.suse/random-fix-crash-on-multiple-early-calls-to-add_bootloader_randomness.patch
- commit 949bbaa
* Mon Jan 10 2022 jslaby@suse.cz
- Refresh
  patches.suse/random-fix-crash-on-multiple-early-calls-to-add_bootloader_randomness.patch.
  * Update upstream status
  * Update to the latest (upstream) version
  * Move it within series to upstream-soon patches
- commit c4ca5fd
* Mon Jan 10 2022 jslaby@suse.cz
- Refresh
  patches.suse/rtw89-update-partition-size-of-firmware-header-on-sk.patch.
  Update upstream status.
- commit a6f5d1b
* Mon Jan 10 2022 mkubecek@suse.cz
- Update to 5.16 final
- refresh configs (headers only)
- commit b8251b4
* Fri Jan  7 2022 tiwai@suse.de
- rpm/kernel-binary.spec.in: Add Provides of kernel-preempt (jsc#SLE-18857)
  For smooth migration with the former kernel-preempt user, kernel-default
  provides kernel-preempt now when CONFIG_PREEMPT_DYNAMIC is defined.
  [js] this fixes mismerge of this commit (d292a8131079) via 99c510061314.
  It lost this one hunk in there.
- rpm/kernel-binary.spec.in: Add Provides of kernel-preempt (jsc#SLE-18857)
  For smooth migration with the former kernel-preempt user, kernel-default
  provides kernel-preempt now when CONFIG_PREEMPT_DYNAMIC is defined.
- commit 85ebeb0
* Fri Jan  7 2022 tiwai@suse.de
- Refresh BT workaround patch (bsc#1193124)
  Fix yet another broken device 8086:0aa7
- commit 163b552
* Wed Jan  5 2022 jslaby@suse.cz
- Linux 5.15.13 (bsc#1012628).
- Input: i8042 - enable deferred probe quirk for ASUS UM325UA
  (bsc#1012628).
- tomoyo: Check exceeded quota early in
  tomoyo_domain_quota_is_ok() (bsc#1012628).
- tomoyo: use hwight16() in tomoyo_domain_quota_is_ok()
  (bsc#1012628).
- net/sched: Extend qdisc control block with tc control block
  (bsc#1012628).
- parisc: Clear stale IIR value on instruction access rights trap
  (bsc#1012628).
- platform/mellanox: mlxbf-pmc: Fix an IS_ERR() vs NULL bug in
  mlxbf_pmc_map_counters (bsc#1012628).
- platform/x86: apple-gmux: use resource_size() with res
  (bsc#1012628).
- memblock: fix memblock_phys_alloc() section mismatch error
  (bsc#1012628).
- ALSA: hda: intel-sdw-acpi: harden detection of controller
  (bsc#1012628).
- ALSA: hda: intel-sdw-acpi: go through HDAS ACPI at max depth
  of 2 (bsc#1012628).
- recordmcount.pl: fix typo in s390 mcount regex (bsc#1012628).
- powerpc/ptdump: Fix DEBUG_WX since generic ptdump conversion
  (bsc#1012628).
- efi: Move efifb_setup_from_dmi() prototype from arch headers
  (bsc#1012628).
- selinux: initialize proto variable in
  selinux_ip_postroute_compat() (bsc#1012628).
- scsi: lpfc: Terminate string in lpfc_debugfs_nvmeio_trc_write()
  (bsc#1012628).
- net/mlx5: DR, Fix NULL vs IS_ERR checking in
  dr_domain_init_resources (bsc#1012628).
- net/mlx5: Fix error print in case of IRQ request failed
  (bsc#1012628).
- net/mlx5: Fix SF health recovery flow (bsc#1012628).
- net/mlx5: Fix tc max supported prio for nic mode (bsc#1012628).
- net/mlx5e: Wrap the tx reporter dump callback to extract the sq
  (bsc#1012628).
- net/mlx5e: Fix interoperability between XSK and ICOSQ recovery
  flow (bsc#1012628).
- net/mlx5e: Fix ICOSQ recovery flow for XSK (bsc#1012628).
- net/mlx5e: Use tc sample stubs instead of ifdefs in source file
  (bsc#1012628).
- net/mlx5e: Delete forward rule for ct or sample action
  (bsc#1012628).
- udp: using datalen to cap ipv6 udp max gso segments
  (bsc#1012628).
- selftests: Calculate udpgso segment count without header
  adjustment (bsc#1012628).
- sctp: use call_rcu to free endpoint (bsc#1012628).
- net/smc: fix using of uninitialized completions (bsc#1012628).
- net: usb: pegasus: Do not drop long Ethernet frames
  (bsc#1012628).
- net: ag71xx: Fix a potential double free in error handling paths
  (bsc#1012628).
- net: lantiq_xrx200: fix statistics of received bytes
  (bsc#1012628).
- NFC: st21nfca: Fix memory leak in device probe and remove
  (bsc#1012628).
- net/smc: don't send CDC/LLC message if link not ready
  (bsc#1012628).
- net/smc: fix kernel panic caused by race of smc_sock
  (bsc#1012628).
- igc: Fix TX timestamp support for non-MSI-X platforms
  (bsc#1012628).
- drm/amd/display: Send s0i2_rdy in stream_count == 0 optimization
  (bsc#1012628).
- drm/amd/display: Set optimize_pwr_state for DCN31 (bsc#1012628).
- ionic: Initialize the 'lif->dbid_inuse' bitmap (bsc#1012628).
- net/mlx5e: Fix wrong features assignment in case of error
  (bsc#1012628).
- net: bridge: mcast: add and enforce query interval minimum
  (bsc#1012628).
- net: bridge: mcast: add and enforce startup query interval
  minimum (bsc#1012628).
- selftests/net: udpgso_bench_tx: fix dst ip argument
  (bsc#1012628).
- selftests: net: Fix a typo in udpgro_fwd.sh (bsc#1012628).
- net: bridge: mcast: fix br_multicast_ctx_vlan_global_disabled
  helper (bsc#1012628).
- net/ncsi: check for error return from call to nla_put_u32
  (bsc#1012628).
- selftests: net: using ping6 for IPv6 in udpgro_fwd.sh
  (bsc#1012628).
- fsl/fman: Fix missing put_device() call in fman_port_probe
  (bsc#1012628).
- i2c: validate user data in compat ioctl (bsc#1012628).
- nfc: uapi: use kernel size_t to fix user-space builds
  (bsc#1012628).
- uapi: fix linux/nfc.h userspace compilation errors
  (bsc#1012628).
- drm/nouveau: wait for the exclusive fence after the shared
  ones v2 (bsc#1012628).
- drm/amdgpu: When the VCN(1.0) block is suspended, powergating
  is explicitly enabled (bsc#1012628).
- drm/amdgpu: add support for IP discovery gc_info table v2
  (bsc#1012628).
- drm/amd/display: Changed pipe split policy to allow for
  multi-display pipe split (bsc#1012628).
- xhci: Fresco FL1100 controller should not have BROKEN_MSI
  quirk set (bsc#1012628).
- usb: gadget: f_fs: Clear ffs_eventfd in ffs_data_clear
  (bsc#1012628).
- usb: mtu3: add memory barrier before set GPD's HWO
  (bsc#1012628).
- usb: mtu3: fix list_head check warning (bsc#1012628).
- usb: mtu3: set interval of FS intr and isoc endpoint
  (bsc#1012628).
- nitro_enclaves: Use get_user_pages_unlocked() call to handle
  mmap assert (bsc#1012628).
- binder: fix async_free_space accounting for empty parcels
  (bsc#1012628).
- scsi: vmw_pvscsi: Set residual data length conditionally
  (bsc#1012628).
- Input: appletouch - initialize work before device registration
  (bsc#1012628).
- Input: spaceball - fix parsing of movement data packets
  (bsc#1012628).
- mm/damon/dbgfs: fix 'struct pid' leaks in
  'dbgfs_target_ids_write()' (bsc#1012628).
- net: fix use-after-free in tw_timer_handler (bsc#1012628).
- fs/mount_setattr: always cleanup mount_kattr (bsc#1012628).
- perf intel-pt: Fix parsing of VM time correlation arguments
  (bsc#1012628).
- perf script: Fix CPU filtering of a script's switch events
  (bsc#1012628).
- perf scripts python: intel-pt-events.py: Fix printing of switch
  events (bsc#1012628).
- commit 01786ae
* Mon Jan  3 2022 dmueller@suse.com
- Revert "config: disable BTRFS_ASSERT in default kernels"
  This was pushed without enough review, reverting.
- commit e86c2a0
* Mon Jan  3 2022 dmueller@suse.com
- Revert "config: disable BTRFS_ASSERT in default kernels"
  This was pushed without enough review, reverting.
- commit 4fb1cfd
* Mon Jan  3 2022 dsterba@suse.com
- Revert "config: disable BTRFS_ASSERT in default kernels"
  This reverts commit 81985a674cf03fa1ef7c290050be04e57f8490dc.
  This is a change affecting correctness, trading it for some performance.
  This was done without prior discussion with btrfs people, so revert it
  to previous state.
- commit 55f2c08
* Mon Jan  3 2022 tiwai@suse.de
- media: Revert "media: uvcvideo: Set unique vdev name based in
  type" (bsc#1193255).
- commit b3f1eb0
* Mon Jan  3 2022 mkubecek@suse.cz
- Update to 5.16-rc8
- commit b59b474
* Fri Dec 31 2021 schwab@suse.de
- config: Enable CONFIG_CMA on riscv64
  Non-default dependent config changes:
- DMA_CMA=y
- commit c0aa71e
* Thu Dec 30 2021 tiwai@suse.de
- igc: Do not enable crosstimestamping for i225-V models
  (bsc#1193039).
- commit a77f415
* Thu Dec 30 2021 dmueller@suse.com
- fix rpm build warning
  tumbleweed rpm is adding these warnings to the log:
  It's not recommended to have unversioned Obsoletes: Obsoletes:      microcode_ctl
- commit 3ba8941
* Wed Dec 29 2021 jslaby@suse.cz
- Update config files.
- commit 375fcb8
* Wed Dec 29 2021 jslaby@suse.cz
- Linux 5.15.12 (bsc#1012628).
- arm64: vdso32: require CROSS_COMPILE_COMPAT for gcc+bfd
  (bsc#1012628).
- net: usb: lan78xx: add Allied Telesis AT29M2-AF (bsc#1012628).
- ext4: prevent partial update of the extent blocks (bsc#1012628).
- ext4: check for out-of-order index extents in
  ext4_valid_extent_entries() (bsc#1012628).
- ext4: check for inconsistent extents between index and leaf
  block (bsc#1012628).
- selftests: KVM: Fix non-x86 compiling (bsc#1012628).
- HID: holtek: fix mouse probing (bsc#1012628).
- HID: potential dereference of null pointer (bsc#1012628).
- NFSD: Fix READDIR buffer overflow (bsc#1012628).
- PM: sleep: Fix error handling in dpm_prepare() (bsc#1012628).
- arm64: dts: allwinner: orangepi-zero-plus: fix PHY mode
  (bsc#1012628).
- bus: sunxi-rsb: Fix shutdown (bsc#1012628).
- spi: change clk_disable_unprepare to clk_unprepare
  (bsc#1012628).
- ucounts: Fix rlimit max values check (bsc#1012628).
- drm/mediatek: hdmi: Perform NULL pointer check for mtk_hdmi_conf
  (bsc#1012628).
- ASoC: meson: aiu: fifo: Add missing
  dma_coerce_mask_and_coherent() (bsc#1012628).
- RDMA/hns: Fix RNR retransmission issue for HIP08 (bsc#1012628).
- IB/qib: Fix memory leak in qib_user_sdma_queue_pkts()
  (bsc#1012628).
- RDMA/hns: Replace kfree() with kvfree() (bsc#1012628).
- netfilter: nf_tables: fix use-after-free in
  nft_set_catchall_destroy() (bsc#1012628).
- netfilter: fix regression in looped (broad|multi)cast's MAC
  handling (bsc#1012628).
- ARM: dts: imx6qdl-wandboard: Fix Ethernet support (bsc#1012628).
- ice: Use xdp_buf instead of rx_buf for xsk zero-copy
  (bsc#1012628).
- ice: xsk: return xsk buffers back to pool when cleaning the ring
  (bsc#1012628).
- net: marvell: prestera: fix incorrect return of port_find
  (bsc#1012628).
- net: marvell: prestera: fix incorrect structure access
  (bsc#1012628).
- qlcnic: potential dereference null pointer of
  rx_queue->page_ring (bsc#1012628).
- tcp: move inet->rx_dst_ifindex to sk->sk_rx_dst_ifindex
  (bsc#1012628).
- ipv6: move inet6_sk(sk)->rx_dst_cookie to sk->sk_rx_dst_cookie
  (bsc#1012628).
- inet: fully convert sk->sk_rx_dst to RCU rules (bsc#1012628).
- net: accept UFOv6 packages in virtio_net_hdr_to_skb
  (bsc#1012628).
- net: skip virtio_net_hdr_set_proto if protocol already set
  (bsc#1012628).
- igb: fix deadlock caused by taking RTNL in RPM resume path
  (bsc#1012628).
- ipmi: Fix UAF when uninstall ipmi_si and ipmi_msghandler module
  (bsc#1012628).
- gpio: virtio: remove timeout (bsc#1012628).
- bonding: fix ad_actor_system option setting to default
  (bsc#1012628).
- fjes: Check for error irq (bsc#1012628).
- drivers: net: smc911x: Check for error irq (bsc#1012628).
- net: ks8851: Check for error irq (bsc#1012628).
- sfc: Check null pointer of rx_queue->page_ring (bsc#1012628).
- sfc: falcon: Check null pointer of rx_queue->page_ring
  (bsc#1012628).
- asix: fix uninit-value in asix_mdio_read() (bsc#1012628).
- asix: fix wrong return value in asix_check_host_enable()
  (bsc#1012628).
- io_uring: zero iocb->ki_pos for stream file types (bsc#1012628).
- veth: ensure skb entering GRO are not cloned (bsc#1012628).
- net: stmmac: ptp: fix potentially overflowing expression
  (bsc#1012628).
- net: bridge: Use array_size() helper in copy_to_user()
  (bsc#1012628).
- net: bridge: fix ioctl old_deviceless bridge argument
  (bsc#1012628).
- r8152: fix the force speed doesn't work for RTL8156
  (bsc#1012628).
- net: stmmac: dwmac-visconti: Fix value of
  ETHER_CLK_SEL_FREQ_SEL_2P5M (bsc#1012628).
- Input: elantech - fix stack out of bound access in
  elantech_change_report_id() (bsc#1012628).
- pinctrl: bcm2835: Change init order for gpio hogs (bsc#1012628).
- hwmon: (lm90) Fix usage of CONFIG2 register in detect function
  (bsc#1012628).
- hwmon: (lm90) Prevent integer overflow/underflow in hysteresis
  calculations (bsc#1012628).
- hwmon: (lm90) Introduce flag indicating extended temperature
  support (bsc#1012628).
- hwmon: (lm90) Add basic support for TI TMP461 (bsc#1012628).
- hwmon: (lm90) Drop critical attribute support for MAX6654
  (bsc#1012628).
- ARM: 9160/1: NOMMU: Reload __secondary_data after
  PROCINFO_INITFUNC (bsc#1012628).
- uapi: Fix undefined __always_inline on non-glibc systems
  (bsc#1012628).
- compiler.h: Fix annotation macro misplacement with Clang
  (bsc#1012628).
- platform/x86/intel: Remove X86_PLATFORM_DRIVERS_INTEL
  (bsc#1012628).
- kernel/crash_core: suppress unknown crashkernel parameter
  warning (bsc#1012628).
- Revert "x86/boot: Pull up cmdline preparation and early param
  parsing" (bsc#1012628).
- x86/boot: Move EFI range reservation after cmdline parsing
  (bsc#1012628).
- ALSA: jack: Check the return value of kstrdup() (bsc#1012628).
- ALSA: drivers: opl3: Fix incorrect use of vp->state
  (bsc#1012628).
- ALSA: rawmidi - fix the uninitalized user_pversion
  (bsc#1012628).
- ALSA: hda/hdmi: Disable silent stream on GLK (bsc#1012628).
- ALSA: hda/realtek: Amp init fixup for HP ZBook 15 G6
  (bsc#1012628).
- ALSA: hda/realtek: Add new alc285-hp-amp-init model
  (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs for a HP ProBook
  (bsc#1012628).
- ALSA: hda/realtek: Fix quirk for Clevo NJ51CU (bsc#1012628).
- ASoC: meson: aiu: Move AIU_I2S_MISC hold setting to aiu-fifo-i2s
  (bsc#1012628).
- ASoC: tegra: Add DAPM switches for headphones and mic jack
  (bsc#1012628).
- ASoC: tegra: Restore headphones jack name on Nyan Big
  (bsc#1012628).
- Input: atmel_mxt_ts - fix double free in mxt_read_info_block
  (bsc#1012628).
- ipmi: bail out if init_srcu_struct fails (bsc#1012628).
- ipmi: ssif: initialize ssif_info->client early (bsc#1012628).
- ipmi: fix initialization when workqueue allocation fails
  (bsc#1012628).
- parisc: Correct completer in lws start (bsc#1012628).
- parisc: Fix mask used to select futex spinlock (bsc#1012628).
- tee: handle lookup of shm with reference count 0 (bsc#1012628).
- x86/pkey: Fix undefined behaviour with PKRU_WD_BIT
  (bsc#1012628).
- platform/x86: amd-pmc: only use callbacks for suspend
  (bsc#1012628).
- platform/x86: intel_pmc_core: fix memleak on registration
  failure (bsc#1012628).
- KVM: x86: Always set kvm_run->if_flag (bsc#1012628).
- KVM: x86/mmu: Don't advance iterator after restart due to
  yielding (bsc#1012628).
- KVM: nVMX: Synthesize TRIPLE_FAULT for L2 if emulation is
  required (bsc#1012628).
- KVM: VMX: Always clear vmx->fail on emulation_required
  (bsc#1012628).
- KVM: VMX: Wake vCPU when delivering posted IRQ even if vCPU ==
  this vCPU (bsc#1012628).
- pinctrl: stm32: consider the GPIO offset to expose all the
  GPIO lines (bsc#1012628).
- gpio: dln2: Fix interrupts when replugging the device
  (bsc#1012628).
- mmc: sdhci-tegra: Fix switch to HS400ES mode (bsc#1012628).
- mmc: meson-mx-sdhc: Set MANUAL_STOP for multi-block SDIO
  commands (bsc#1012628).
- mmc: core: Disable card detect during shutdown (bsc#1012628).
- mmc: mmci: stm32: clear DLYB_CR after sending tuning command
  (bsc#1012628).
- ARM: 9169/1: entry: fix Thumb2 bug in iWMMXt exception handling
  (bsc#1012628).
- ksmbd: fix error code in ndr_read_int32() (bsc#1012628).
- ksmbd: fix uninitialized symbol 'pntsd_size' (bsc#1012628).
- ksmbd: disable SMB2_GLOBAL_CAP_ENCRYPTION for SMB 3.1.1
  (bsc#1012628).
- mac80211: fix locking in ieee80211_start_ap error path
  (bsc#1012628).
- mm: mempolicy: fix THP allocations escaping mempolicy
  restrictions (bsc#1012628).
- mm, hwpoison: fix condition in free hugetlb page path
  (bsc#1012628).
- mm/hwpoison: clear MF_COUNT_INCREASED before retrying
  get_any_page() (bsc#1012628).
- mm/damon/dbgfs: protect targets destructions with kdamond_lock
  (bsc#1012628).
- tee: optee: Fix incorrect page free bug (bsc#1012628).
- f2fs: fix to do sanity check on last xattr entry in
  __f2fs_setxattr() (bsc#1012628).
- netfs: fix parameter of cleanup() (bsc#1012628).
- KVM: VMX: Fix stale docs for
  kvm-intel.emulate_invalid_guest_state (bsc#1012628).
- arm64: dts: lx2160a: fix scl-gpios property name (bsc#1012628).
- kfence: fix memory leak when cat kfence objects (bsc#1012628).
- Input: iqs626a - prohibit inlining of channel parsing functions
  (bsc#1012628).
- Input: elants_i2c - do not check Remark ID on eKTH3900/eKTH5312
  (bsc#1012628).
- Input: goodix - add id->model mapping for the "9111" model
  (bsc#1012628).
- ASoC: tas2770: Fix setting of high sample rates (bsc#1012628).
- ASoC: SOF: Intel: pci-tgl: add new ADL-P variant (bsc#1012628).
- ASoC: SOF: Intel: pci-tgl: add ADL-N support (bsc#1012628).
- ASoC: rt5682: fix the wrong jack type detected (bsc#1012628).
- pinctrl: mediatek: fix global-out-of-bounds issue (bsc#1012628).
- hwmom: (lm90) Fix citical alarm status for MAX6680/MAX6681
  (bsc#1012628).
- hwmon: (lm90) Do not report 'busy' status bit as alarm
  (bsc#1012628).
- r8152: sync ocp base (bsc#1012628).
- ax25: NPD bug when detaching AX25 device (bsc#1012628).
- hamradio: defer ax25 kfree after unregister_netdev
  (bsc#1012628).
- hamradio: improve the incomplete fix to avoid NPD (bsc#1012628).
- tun: avoid double free in tun_free_netdev (bsc#1012628).
- phonet/pep: refuse to enable an unbound pipe (bsc#1012628).
- Refresh
  patches.suse/add-product-identifying-information-to-vmcoreinfo.patch.
- commit 202eb92
* Mon Dec 27 2021 mkubecek@suse.cz
- Update to 5.16-rc7
- refresh
  - patches.suse/add-product-identifying-information-to-vmcoreinfo.patch
- refresh configs
- commit cce91fd
* Thu Dec 23 2021 jslaby@suse.cz
- Disable patches.suse/btrfs-use-the-new-VFS-super_block_dev.patch (bsc#1194007)
  Better to disable it completely.
- commit 730a488
* Wed Dec 22 2021 dmueller@suse.com
- build initrd without systemd
  This reduces the size of the initrd by over 25%%, which
  improves startup time of the virtual machine by 0.5-0.6s on
  very fast machines, more on slower ones.
- commit ef4c569
* Wed Dec 22 2021 dmueller@suse.com
- config: disable BTRFS_ASSERT in default kernels
  BTRFS_ASSERT is marked as developer only option and hence
  shouldn't be enabled in the default kernel. we enable it
  in the debug flavor now.
  This improves performance of a fio randrw run by over 21%% and
  reduces code size by 25%%.
- commit 6567403
* Wed Dec 22 2021 jslaby@suse.cz
- Linux 5.15.11 (bsc#1012628).
- xen/netback: don't queue unlimited number of packages
  (bsc#1012628).
- xen/netback: fix rx queue stall detection (bsc#1012628).
- xen/console: harden hvc_xen against event channel storms
  (bsc#1012628).
- xen/netfront: harden netfront against event channel storms
  (bsc#1012628).
- xen/blkfront: harden blkfront against event channel storms
  (bsc#1012628).
- Revert "xsk: Do not sleep in poll() when need_wakeup set"
  (bsc#1012628).
- selftests/damon: test debugfs file reads/writes with huge count
  (bsc#1012628).
- bus: ti-sysc: Fix variable set but not used warning for
  reinit_modules (bsc#1012628).
- io-wq: drop wqe lock before creating new worker (bsc#1012628).
- rcu: Mark accesses to rcu_state.n_force_qs (bsc#1012628).
- io-wq: check for wq exit after adding new worker task_work
  (bsc#1012628).
- io-wq: remove spurious bit clear on task_work addition
  (bsc#1012628).
- scsi: scsi_debug: Sanity check block descriptor length in
  resp_mode_select() (bsc#1012628).
- scsi: scsi_debug: Fix type in min_t to avoid stack OOB
  (bsc#1012628).
- scsi: scsi_debug: Don't call kcalloc() if size arg is zero
  (bsc#1012628).
- ovl: fix warning in ovl_create_real() (bsc#1012628).
- fuse: annotate lock in fuse_reverse_inval_entry() (bsc#1012628).
- media: mxl111sf: change mutex_init() location (bsc#1012628).
- USB: core: Make do_proc_control() and do_proc_bulk() killable
  (bsc#1012628).
- bpf: Fix extable address check (bsc#1012628).
- bpf, x64: Factor out emission of REX byte in more cases
  (bsc#1012628).
- mptcp: add missing documented NL params (bsc#1012628).
- xsk: Do not sleep in poll() when need_wakeup set (bsc#1012628).
- ARM: dts: imx6ull-pinfunc: Fix CSI_DATA07__ESAI_TX0 pad name
  (bsc#1012628).
- can: m_can: pci: use custom bit timings for Elkhart Lake
  (bsc#1012628).
- can: m_can: make custom bittiming fields const (bsc#1012628).
- Revert "can: m_can: remove support for custom bit timing"
  (bsc#1012628).
- drm/amd/pm: fix reading SMU FW version from amdgpu_firmware_info
  on YC (bsc#1012628).
- drm/amdgpu: don't override default ECO_BITs setting
  (bsc#1012628).
- drm/amdgpu: correct register access for RLC_JUMP_TABLE_RESTORE
  (bsc#1012628).
- powerpc/module_64: Fix livepatching for RO modules
  (bsc#1012628).
- libata: if T_LENGTH is zero, dma direction should be DMA_NONE
  (bsc#1012628).
- perf inject: Fix segfault due to perf_data__fd() without open
  (bsc#1012628).
- perf inject: Fix segfault due to close without open
  (bsc#1012628).
- riscv: dts: unmatched: Add gpio card detect to mmc-spi-slot
  (bsc#1012628).
- riscv: dts: unleashed: Add gpio card detect to mmc-spi-slot
  (bsc#1012628).
- locking/rtmutex: Fix incorrect condition in
  rtmutex_spin_on_owner() (bsc#1012628).
- cifs: sanitize multiple delimiters in prepath (bsc#1012628).
- timekeeping: Really make sure wall_to_monotonic isn't positive
  (bsc#1012628).
- serial: 8250_fintek: Fix garbled text for console (bsc#1012628).
- iocost: Fix divide-by-zero on donation from low hweight cgroup
  (bsc#1012628).
- zonefs: add MODULE_ALIAS_FS (bsc#1012628).
- btrfs: fix missing blkdev_put() call in btrfs_scan_one_device()
  (bsc#1012628).
- btrfs: check WRITE_ERR when trying to read an extent buffer
  (bsc#1012628).
- btrfs: fix double free of anon_dev after failure to create
  subvolume (bsc#1012628).
- Refresh
  patches.suse/btrfs-use-the-new-VFS-super_block_dev.patch.
- btrfs: fix memory leak in __add_inode_ref() (bsc#1012628).
- selinux: fix sleeping function called from invalid context
  (bsc#1012628).
- USB: serial: option: add Telit FN990 compositions (bsc#1012628).
- USB: serial: cp210x: fix CP2105 GPIO registration (bsc#1012628).
- usb: gadget: u_ether: fix race in setting MAC address in setup
  phase (bsc#1012628).
- usb: typec: tcpm: fix tcpm unregister port but leave a pending
  timer (bsc#1012628).
- usb: cdnsp: Fix lack of spin_lock_irqsave/spin_lock_restore
  (bsc#1012628).
- usb: cdnsp: Fix issue in cdnsp_log_ep trace event (bsc#1012628).
- usb: cdnsp: Fix incorrect calling of cdnsp_died function
  (bsc#1012628).
- usb: cdnsp: Fix incorrect status for control request
  (bsc#1012628).
- usb: xhci: Extend support for runtime power management for
  AMD's Yellow carp (bsc#1012628).
- usb: xhci-mtk: fix list_del warning when enable list debug
  (bsc#1012628).
- PCI/MSI: Mask MSI-X vectors only on success (bsc#1012628).
- PCI/MSI: Clear PCI_MSIX_FLAGS_MASKALL on error (bsc#1012628).
- usb: dwc2: fix STM ID/VBUS detection startup delay in
  dwc2_driver_probe (bsc#1012628).
- USB: NO_LPM quirk Lenovo USB-C to Ethernet Adapher(RTL8153-04)
  (bsc#1012628).
- tty: n_hdlc: make n_hdlc_tty_wakeup() asynchronous
  (bsc#1012628).
- KVM: x86: Drop guest CPUID check for host initiated writes to
  MSR_IA32_PERF_CAPABILITIES (bsc#1012628).
- Revert "usb: early: convert to readl_poll_timeout_atomic()"
  (bsc#1012628).
- USB: gadget: bRequestType is a bitfield, not a enum
  (bsc#1012628).
- powerpc/85xx: Fix oops when CONFIG_FSL_PMC=n (bsc#1012628).
- bpf, selftests: Fix racing issue in btf_skc_cls_ingress test
  (bsc#1012628).
- bpf: Fix extable fixup offset (bsc#1012628).
- arm64: kexec: Fix missing error code 'ret' warning in
  load_other_segments() (bsc#1012628).
- afs: Fix mmap (bsc#1012628).
- sit: do not call ipip6_dev_free() from sit_init_net()
  (bsc#1012628).
- net: systemport: Add global locking for descriptor lifecycle
  (bsc#1012628).
- net/smc: Prevent smc_release() from long blocking (bsc#1012628).
- net: Fix double 0x prefix print in SKB dump (bsc#1012628).
- dsa: mv88e6xxx: fix debug print for SPEED_UNFORCED
  (bsc#1012628).
- sfc_ef100: potential dereference of null pointer (bsc#1012628).
- net: stmmac: dwmac-rk: fix oob read in rk_gmac_setup
  (bsc#1012628).
- net/packet: rx_owner_map depends on pg_vec (bsc#1012628).
- netdevsim: Zero-initialize memory for new map's value in
  function nsim_bpf_map_alloc (bsc#1012628).
- ixgbe: set X550 MDIO speed before talking to PHY (bsc#1012628).
- ixgbe: Document how to enable NBASE-T support (bsc#1012628).
- igc: Fix typo in i225 LTR functions (bsc#1012628).
- igbvf: fix double free in `igbvf_probe` (bsc#1012628).
- igb: Fix removal of unicast MAC filters of VFs (bsc#1012628).
- soc/tegra: fuse: Fix bitwise vs. logical OR warning
  (bsc#1012628).
- mptcp: fix deadlock in __mptcp_push_pending() (bsc#1012628).
- mptcp: clear 'kern' flag from fallback sockets (bsc#1012628).
- mptcp: remove tcp ulp setsockopt support (bsc#1012628).
- drm/amd/pm: fix a potential gpu_metrics_table memory leak
  (bsc#1012628).
- drm/amd/display: Set exit_optimized_pwr_state for DCN31
  (bsc#1012628).
- ice: Don't put stale timestamps in the skb (bsc#1012628).
- ice: Use div64_u64 instead of div_u64 in adjfine (bsc#1012628).
- rds: memory leak in __rds_conn_create() (bsc#1012628).
- flow_offload: return EOPNOTSUPP for the unsupported mpls action
  type (bsc#1012628).
- net: stmmac: fix tc flower deletion for VLAN priority Rx
  steering (bsc#1012628).
- mac80211: fix lookup when adding AddBA extension element
  (bsc#1012628).
- cfg80211: Acquire wiphy mutex on regulatory work (bsc#1012628).
- mac80211: agg-tx: don't schedule_and_wake_txq() under sta->lock
  (bsc#1012628).
- drm/i915/display: Fix an unsigned subtraction which can never
  be negative (bsc#1012628).
- drm/ast: potential dereference of null pointer (bsc#1012628).
- mptcp: never allow the PM to close a listener subflow
  (bsc#1012628).
- selftest/net/forwarding: declare NETIFS p9 p10 (bsc#1012628).
- net: dsa: mv88e6xxx: Unforce speed & duplex in mac_link_down()
  (bsc#1012628).
- selftests/net: toeplitz: fix udp option (bsc#1012628).
- net/sched: sch_ets: don't remove idle classes from the
  round-robin list (bsc#1012628).
- drm: simpledrm: fix wrong unit with pixel clock (bsc#1012628).
- dmaengine: st_fdma: fix MODULE_ALIAS (bsc#1012628).
- dmaengine: idxd: fix missed completion on abort path
  (bsc#1012628).
- selftests: Fix IPv6 address bind tests (bsc#1012628).
- selftests: Fix raw socket bind tests with VRF (bsc#1012628).
- selftests: Add duplicate config only for MD5 VRF tests
  (bsc#1012628).
- net: hns3: fix race condition in debugfs (bsc#1012628).
- net: hns3: fix use-after-free bug in hclgevf_send_mbx_msg
  (bsc#1012628).
- selftests: icmp_redirect: pass xfail=0 to log_test()
  (bsc#1012628).
- netdevsim: don't overwrite read only ethtool parms
  (bsc#1012628).
- inet_diag: fix kernel-infoleak for UDP sockets (bsc#1012628).
- sch_cake: do not call cake_destroy() from cake_init()
  (bsc#1012628).
- s390/kexec_file: fix error handling when applying relocations
  (bsc#1012628).
- selftests: net: Correct ping6 expected rc from 2 to 1
  (bsc#1012628).
- Revert "drm/fb-helper: improve DRM fbdev emulation device names"
  (bsc#1012628).
- vdpa: Consider device id larger than 31 (bsc#1012628).
- virtio/vsock: fix the transport to work with VMADDR_CID_ANY
  (bsc#1012628).
- virtio: always enter drivers/virtio/ (bsc#1012628).
- iwlwifi: mvm: don't crash on invalid rate w/o STA (bsc#1012628).
- soc: imx: Register SoC device only on i.MX boards (bsc#1012628).
- clk: Don't parent clks until the parent is fully registered
  (bsc#1012628).
- arm64: dts: imx8mq: remove interconnect property from lcdif
  (bsc#1012628).
- ARM: socfpga: dts: fix qspi node compatible (bsc#1012628).
- ceph: initialize pathlen variable in reconnect_caps_cb
  (bsc#1012628).
- ceph: fix duplicate increment of opened_inodes metric
  (bsc#1012628).
- tee: amdtee: fix an IS_ERR() vs NULL bug (bsc#1012628).
- mac80211: track only QoS data frames for admission control
  (bsc#1012628).
- dmaengine: idxd: fix calling wq quiesce inside spinlock
  (bsc#1012628).
- dmaengine: idxd: add halt interrupt support (bsc#1012628).
- arm64: dts: rockchip: fix poweroff on helios64 (bsc#1012628).
- arm64: dts: rockchip: fix audio-supply for Rock Pi 4
  (bsc#1012628).
- arm64: dts: rockchip: fix rk3399-leez-p710 vcc3v3-lan supply
  (bsc#1012628).
- arm64: dts: rockchip: fix rk3308-roc-cc vcc-sd supply
  (bsc#1012628).
- arm64: dts: rockchip: remove mmc-hs400-enhanced-strobe from
  rk3399-khadas-edge (bsc#1012628).
- pinctrl: amd: Fix wakeups when IRQ is shared with SCI
  (bsc#1012628).
- drm/i915/hdmi: Turn DP++ TMDS output buffers back on in
  encoder->shutdown() (bsc#1012628).
- drm/i915/hdmi: convert intel_hdmi_to_dev to intel_hdmi_to_i915
  (bsc#1012628).
- scsi: ufs: core: Retry START_STOP on UNIT_ATTENTION
  (bsc#1012628).
- btrfs: remove stale comment about the btrfs_show_devname
  (bsc#1012628).
- btrfs: update latest_dev when we create a sprout device
  (bsc#1012628).
- btrfs: use latest_dev in btrfs_show_devname (bsc#1012628).
- btrfs: convert latest_bdev type to btrfs_device and rename
  (bsc#1012628).
- audit: improve robustness of the audit queue handling
  (bsc#1012628).
- dm btree remove: fix use after free in rebalance_children()
  (bsc#1012628).
- ceph: fix up non-directory creation in SGID directories
  (bsc#1012628).
- arm64: dts: ten64: remove redundant interrupt declaration for
  gpio-keys (bsc#1012628).
- recordmcount.pl: look for jgnop instruction as well as bcrl
  on s390 (bsc#1012628).
- s390/entry: fix duplicate tracking of irq nesting level
  (bsc#1012628).
- vdpa: check that offsets are within bounds (bsc#1012628).
- virtio_ring: Fix querying of maximum DMA mapping size for
  virtio device (bsc#1012628).
- vduse: check that offset is within bounds in get_config()
  (bsc#1012628).
- vduse: fix memory corruption in vduse_dev_ioctl() (bsc#1012628).
- bpf, selftests: Update test case for atomic cmpxchg on r0 with
  pointer (bsc#1012628).
- bpf: Fix kernel address leakage in atomic cmpxchg's r0 aux reg
  (bsc#1012628).
- bpf, selftests: Add test case trying to taint map value pointer
  (bsc#1012628).
- bpf: Make 32->64 bounds propagation slightly more robust
  (bsc#1012628).
- bpf: Fix signed bounds propagation after mov32 (bsc#1012628).
- bpf, selftests: Add test case for atomic fetch on spilled
  pointer (bsc#1012628).
- bpf: Fix kernel address leakage in atomic fetch (bsc#1012628).
- firmware: arm_scpi: Fix string overflow in SCPI genpd driver
  (bsc#1012628).
- mac80211: validate extended element ID is present (bsc#1012628).
- mac80211: send ADDBA requests using the tid/queue of the
  aggregation session (bsc#1012628).
- mac80211: mark TX-during-stop for TX in in_reconfig
  (bsc#1012628).
- mac80211: fix regression in SSN handling of addba tx
  (bsc#1012628).
- mac80211: fix rate control for retransmitted frames
  (bsc#1012628).
- KVM: X86: Fix tlb flush for tdp in kvm_invalidate_pcid()
  (bsc#1012628).
- x86/kvm: remove unused ack_notifier callbacks (bsc#1012628).
- KVM: downgrade two BUG_ONs to WARN_ON_ONCE (bsc#1012628).
- KVM: selftests: Make sure kvm_create_max_vcpus test won't hit
  RLIMIT_NOFILE (bsc#1012628).
- KVM: VMX: clear vmx_x86_ops.sync_pir_to_irr if APICv is disabled
  (bsc#1012628).
- reset: tegra-bpmp: Revert Handle errors in BPMP response
  (bsc#1012628).
- commit 9903b31
* Mon Dec 20 2021 dmueller@suse.com
- add kvmsmall flavor for aarch64
- commit 1775f8c
* Mon Dec 20 2021 mkubecek@suse.cz
- Update to 5.16-rc6
- refresh configs
- disable
  patches.suse/btrfs-use-the-new-VFS-super_block_dev.patch
  - needs an update after mainline commit 33fab972497a ("btrfs: fix double
    free of anon_dev after failure to create subvolume")
- commit ccebb20
* Mon Dec 20 2021 mkubecek@suse.cz
- config: enable and refresh arm architectures
- commit 487d839
* Fri Dec 17 2021 dmueller@suse.com
- kernel-obs-build: remove duplicated/unused parameters
  lbs=0 - this parameters is just giving "unused parameter" and it looks
  like I can not find any version that implemented this.
  rd.driver.pre=binfmt_misc is not needed when setup_obs is used, it
  alread loads the kernel module.
  quiet and panic=1 will now be also always added by OBS, so we don't have
  to set it here anymore.
- commit 972c692
* Fri Dec 17 2021 jslaby@suse.cz
- Linux 5.15.10 (bsc#1012628).
- perf inject: Fix itrace space allowed for new attributes
  (bsc#1012628).
- fuse: make sure reclaim doesn't write the inode (bsc#1012628).
- staging: most: dim2: use device release method (bsc#1012628).
- tracing: Fix a kmemleak false positive in tracing_map
  (bsc#1012628).
- drm/amdkfd: process_info lock not needed for svm (bsc#1012628).
- drm/amd/display: add connector type check for CRC source set
  (bsc#1012628).
- drm/amdkfd: fix double free mem structure (bsc#1012628).
- drm/amd/display: Fix for the no Audio bug with Tiled Displays
  (bsc#1012628).
- drm/amdgpu: check atomic flag to differeniate with legacy path
  (bsc#1012628).
- drm/amdgpu: cancel the correct hrtimer on exit (bsc#1012628).
- net: netlink: af_netlink: Prevent empty skb by adding a check
  on len (bsc#1012628).
- i2c: rk3x: Handle a spurious start completion interrupt flag
  (bsc#1012628).
- parisc/agp: Annotate parisc agp init functions with __init
  (bsc#1012628).
- ALSA: hda/hdmi: fix HDA codec entry table order for ADL-P
  (bsc#1012628).
- ALSA: hda: Add Intel DG2 PCI ID and HDMI codec vid
  (bsc#1012628).
- loop: Use pr_warn_once() for loop_control_remove() warning
  (bsc#1012628).
- net/mlx4_en: Update reported link modes for 1/10G (bsc#1012628).
- Revert "tty: serial: fsl_lpuart: drop earlycon entry for
  i.MX8QXP" (bsc#1012628).
- s390/test_unwind: use raw opcode instead of invalid instruction
  (bsc#1012628).
- KVM: arm64: Save PSTATE early on exit (bsc#1012628).
- drm/msm/dp: Avoid unpowered AUX xfers that caused crashes
  (bsc#1012628).
- drm/msm/dsi: set default num_data_lanes (bsc#1012628).
- drm/msm/a6xx: Fix uinitialized use of gpu_scid (bsc#1012628).
- drm/msm: Fix null ptr access msm_ioctl_gem_submit()
  (bsc#1012628).
- i2c: virtio: fix completion handling (bsc#1012628).
- vmxnet3: fix minimum vectors alloc issue (bsc#1012628).
- ice: fix FDIR init missing when reset VF (bsc#1012628).
- RDMA/irdma: Don't arm the CQ more than two times if no CE for
  this CQ (bsc#1012628).
- RDMA/irdma: Report correct WC errors (bsc#1012628).
- RDMA/irdma: Fix a potential memory allocation issue in
  'irdma_prm_add_pble_mem()' (bsc#1012628).
- RDMA/irdma: Fix a user-after-free in add_pble_prm (bsc#1012628).
- netfs: Fix lockdep warning from taking sb_writers whilst
  holding mmap_lock (bsc#1012628).
- perf bpf_skel: Do not use typedef to avoid error on old clang
  (bsc#1012628).
- clk: qcom: sm6125-gcc: Swap ops of ice and apps on sdcc1
  (bsc#1012628).
- dt-bindings: media: nxp,imx7-mipi-csi2: Drop bad if/then schema
  (bsc#1012628).
- inet: use #ifdef CONFIG_SOCK_RX_QUEUE_MAPPING consistently
  (bsc#1012628).
- mtd: rawnand: Fix nand_choose_best_timings() on unsupported
  interface (bsc#1012628).
- mtd: rawnand: Fix nand_erase_op delay (bsc#1012628).
- RDMA/mlx5: Fix releasing unallocated memory in dereg MR flow
  (bsc#1012628).
- RDMA: Fix use-after-free in rxe_queue_cleanup (bsc#1012628).
- hwmon: (corsair-psu) fix plain integer used as NULL pointer
  (bsc#1012628).
- nfc: fix segfault in nfc_genl_dump_devices_done (bsc#1012628).
- commit 85804f3
* Thu Dec 16 2021 jslaby@suse.cz
- Linux 5.15.9 (bsc#1012628).
- netfilter: selftest: conntrack_vrf.sh: fix file permission
  (bsc#1012628).
- commit edf812e
* Thu Dec 16 2021 mbrugger@suse.com
- armv6hl: Update config files.
  Update config to v5.16-rc5
- commit fcea0c3
* Thu Dec 16 2021 mbrugger@suse.com
- armv7hl: Update config files.
  Update config to v5.16-rc3
- commit 36ef1bb
* Thu Dec 16 2021 mbrugger@suse.com
- arm64: Update config files.
  Update configs to v5.16-rc5
- commit 99d3870
* Tue Dec 14 2021 dmueller@suse.com
- Revert "- rpm/*build: use buildroot macro instead of env variable"
  buildroot macro is not being expanded inside a shell script. go
  back to the environment variable usage. This reverts parts of
  commit e2f60269b9330d7225b2547e057ef0859ccec155.
- commit fe85f96
* Tue Dec 14 2021 dmueller@suse.com
- kernel-obs-build: include the preferred kernel parameters
  Currently the Open Build Service hardcodes the kernel boot parameters
  globally. Recently functionality was added to control the parameters
  by the kernel-obs-build package, so make use of that. parameters here
  will overwrite what is used by OBS otherwise.
- commit a631240
* Tue Dec 14 2021 jslaby@suse.cz
- Linux 5.15.8 (bsc#1012628).
- bpf: Add selftests to cover packet access corner cases
  (bsc#1012628).
- clocksource/drivers/dw_apb_timer_of: Fix probe failure
  (bsc#1012628).
- misc: fastrpc: fix improper packet size calculation
  (bsc#1012628).
- irqchip: nvic: Fix offset for Interrupt Priority Offsets
  (bsc#1012628).
- irqchip/irq-gic-v3-its.c: Force synchronisation when issuing
  INVALL (bsc#1012628).
- aio: Fix incorrect usage of eventfd_signal_allowed()
  (bsc#1012628).
- irqchip/armada-370-xp: Fix support for Multi-MSI interrupts
  (bsc#1012628).
- irqchip/armada-370-xp: Fix return value of
  armada_370_xp_msi_alloc() (bsc#1012628).
- irqchip/aspeed-scu: Replace update_bits with write_bits
  (bsc#1012628).
- csky: fix typo of fpu config macro (bsc#1012628).
- bus: mhi: core: Add support for forced PM resume (bsc#1012628).
- bus: mhi: pci_generic: Fix device recovery failed issue
  (bsc#1012628).
- nvmem: eeprom: at25: fix FRAM byte_len (bsc#1012628).
- misc: rtsx: Avoid mangling IRQ during runtime PM (bsc#1012628).
- iio: accel: kxcjk-1013: Fix possible memory leak in probe and
  remove (bsc#1012628).
- iio: ad7768-1: Call iio_trigger_notify_done() on error
  (bsc#1012628).
- iio: adc: axp20x_adc: fix charging current reporting on AXP22x
  (bsc#1012628).
- iio: adc: stm32: fix a current leak by resetting pcsel before
  disabling vdda (bsc#1012628).
- iio: at91-sama5d2: Fix incorrect sign extension (bsc#1012628).
- iio: dln2: Check return value of devm_iio_trigger_register()
  (bsc#1012628).
- iio: dln2-adc: Fix lockdep complaint (bsc#1012628).
- iio: itg3200: Call iio_trigger_notify_done() on error
  (bsc#1012628).
- iio: kxsd9: Don't return error code in trigger handler
  (bsc#1012628).
- iio: ltr501: Don't return error code in trigger handler
  (bsc#1012628).
- iio: mma8452: Fix trigger reference couting (bsc#1012628).
- iio: stk3310: Don't return error code in interrupt handler
  (bsc#1012628).
- iio: trigger: stm32-timer: fix MODULE_ALIAS (bsc#1012628).
- iio: trigger: Fix reference counting (bsc#1012628).
- iio: gyro: adxrs290: fix data signedness (bsc#1012628).
- xhci: avoid race between disable slot command and host runtime
  suspend (bsc#1012628).
- usb: core: config: using bit mask instead of individual bits
  (bsc#1012628).
- xhci: Remove CONFIG_USB_DEFAULT_PERSIST to prevent xHCI from
  runtime suspending (bsc#1012628).
- usb: core: config: fix validation of wMaxPacketValue entries
  (bsc#1012628).
- Revert "usb: dwc3: dwc3-qcom: Enable tx-fifo-resize property
  by default" (bsc#1012628).
- USB: gadget: zero allocate endpoint 0 buffers (bsc#1012628).
- USB: gadget: detect too-big endpoint 0 requests (bsc#1012628).
- selftests/fib_tests: Rework fib_rp_filter_test() (bsc#1012628).
- net/qla3xxx: fix an error code in ql_adapter_up() (bsc#1012628).
- net, neigh: clear whole pneigh_entry at alloc time
  (bsc#1012628).
- net: fec: only clear interrupt of handling queue in
  fec_enet_rx_queue() (bsc#1012628).
- net: altera: set a couple error code in probe() (bsc#1012628).
- net: cdc_ncm: Allow for dwNtbOutMaxSize to be unset or zero
  (bsc#1012628).
- tools build: Remove needless libpython-version feature check
  that breaks test-all fast path (bsc#1012628).
- dt-bindings: net: Reintroduce PHY no lane swap binding
  (bsc#1012628).
- Documentation/locking/locktypes: Update migrate_disable() bits
  (bsc#1012628).
- perf tools: Fix SMT detection fast read path (bsc#1012628).
- drm/amd/display: Fix DPIA outbox timeout after S3/S4/reset
  (bsc#1012628).
- Revert "PCI: aardvark: Fix support for PCI_ROM_ADDRESS1 on
  emulated bridge" (bsc#1012628).
- i40e: Fix NULL pointer dereference in i40e_dbg_dump_desc
  (bsc#1012628).
- bpf, sockmap: Re-evaluate proto ops when psock is removed from
  sockmap (bsc#1012628).
- mtd: rawnand: fsmc: Fix timing computation (bsc#1012628).
- mtd: rawnand: fsmc: Take instruction delay into account
  (bsc#1012628).
- i40e: Fix pre-set max number of queues for VF (bsc#1012628).
- i40e: Fix failed opcode appearing if handling messages from VF
  (bsc#1012628).
- clk: qcom: clk-alpha-pll: Don't reconfigure running Trion
  (bsc#1012628).
- clk: imx: use module_platform_driver (bsc#1012628).
- hwmon: (dell-smm) Fix warning on /proc/i8k creation error
  (bsc#1012628).
- RDMA/hns: Do not destroy QP resources in the hw resetting phase
  (bsc#1012628).
- RDMA/hns: Do not halt commands during reset until later
  (bsc#1012628).
- ASoC: codecs: wcd934x: return correct value from mixer put
  (bsc#1012628).
- ASoC: codecs: wcd934x: handle channel mappping list correctly
  (bsc#1012628).
- ASoC: codecs: wsa881x: fix return values from kcontrol put
  (bsc#1012628).
- ASoC: qdsp6: q6routing: Fix return value from
  msm_routing_put_audio_mixer (bsc#1012628).
- ASoC: rt5682: Fix crash due to out of scope stack vars
  (bsc#1012628).
- PM: runtime: Fix pm_runtime_active() kerneldoc comment
  (bsc#1012628).
- qede: validate non LSO skb length (bsc#1012628).
- ALSA: usb-audio: Reorder snd_djm_devices[] entries
  (bsc#1012628).
- scsi: scsi_debug: Fix buffer size of REPORT ZONES command
  (bsc#1012628).
- scsi: pm80xx: Do not call scsi_remove_host() in pm8001_alloc()
  (bsc#1012628).
- block: fix ioprio_get(IOPRIO_WHO_PGRP) vs setuid(2)
  (bsc#1012628).
- i2c: mpc: Use atomic read and fix break condition (bsc#1012628).
- tracefs: Set all files to the same group ownership as the
  mount option (bsc#1012628).
- aio: fix use-after-free due to missing POLLFREE handling
  (bsc#1012628).
- aio: keep poll requests on waitqueue until completed
  (bsc#1012628).
- signalfd: use wake_up_pollfree() (bsc#1012628).
- binder: use wake_up_pollfree() (bsc#1012628).
- wait: add wake_up_pollfree() (bsc#1012628).
- io_uring: ensure task_work gets run as part of cancelations
  (bsc#1012628).
- libata: add horkage for ASMedia 1092 (bsc#1012628).
- drm/syncobj: Deal with signalled fences in
  drm_syncobj_find_fence (bsc#1012628).
- thermal: int340x: Fix VCoRefLow MMIO bit offset for TGL
  (bsc#1012628).
- clk: qcom: regmap-mux: fix parent clock lookup (bsc#1012628).
- mmc: renesas_sdhi: initialize variable properly when tuning
  (bsc#1012628).
- hwmon: (pwm-fan) Ensure the fan going on in .probe()
  (bsc#1012628).
- selftests: KVM: avoid failures due to reserved HyperTransport
  region (bsc#1012628).
- tracefs: Have new files inherit the ownership of their parent
  (bsc#1012628).
- nfsd: Fix nsfd startup race (again) (bsc#1012628).
- nfsd: fix use-after-free due to delegation race (bsc#1012628).
- md: fix update super 1.0 on rdev size change (bsc#1012628).
- perf intel-pt: Fix error timestamp setting on the decoder
  error path (bsc#1012628).
- perf intel-pt: Fix missing 'instruction' events with 'q' option
  (bsc#1012628).
- perf intel-pt: Fix next 'err' value, walking trace
  (bsc#1012628).
- perf intel-pt: Fix state setting when receiving overflow (OVF)
  packet (bsc#1012628).
- perf intel-pt: Fix intel_pt_fup_event() assumptions about
  setting state type (bsc#1012628).
- perf intel-pt: Fix sync state when a PSB (synchronization)
  packet is found (bsc#1012628).
- perf intel-pt: Fix some PGE (packet generation enable/control
  flow packets) usage (bsc#1012628).
- btrfs: free exchange changeset on failures (bsc#1012628).
- btrfs: replace the BUG_ON in btrfs_del_root_ref with proper
  error handling (bsc#1012628).
- btrfs: fix re-dirty process of tree-log nodes (bsc#1012628).
- btrfs: clear extent buffer uptodate when we fail to write it
  (bsc#1012628).
- scsi: qla2xxx: Format log strings only if needed (bsc#1012628).
- cifs: Fix crash on unload of cifs_arc4.ko (bsc#1012628).
- ALSA: pcm: oss: Handle missing errors in
  snd_pcm_oss_change_params*() (bsc#1012628).
- ALSA: pcm: oss: Limit the period size to 16MB (bsc#1012628).
- ALSA: pcm: oss: Fix negative period/buffer sizes (bsc#1012628).
- ALSA: hda/realtek: Fix quirk for TongFang PHxTxX1 (bsc#1012628).
- ALSA: hda/realtek - Add headset Mic support for Lenovo ALC897
  platform (bsc#1012628).
- ALSA: ctl: Fix copy of updated id with element read/write
  (bsc#1012628).
- mm: bdi: initialize bdi_min_ratio when bdi is unregistered
  (bsc#1012628).
- mm/slub: fix endianness bug for alloc/free_traces attributes
  (bsc#1012628).
- mm/damon/core: fix fake load reports due to uninterruptible
  sleeps (bsc#1012628).
- timers: implement usleep_idle_range() (bsc#1012628).
- KVM: x86: Wait for IPIs to be delivered when handling Hyper-V
  TLB flush hypercall (bsc#1012628).
- KVM: x86: Ignore sparse banks size for an "all CPUs", non-sparse
  IPI req (bsc#1012628).
- KVM: x86: Don't WARN if userspace mucks with RCX during string
  I/O exit (bsc#1012628).
- net: mvpp2: fix XDP rx queues registering (bsc#1012628).
- net/sched: fq_pie: prevent dismantle issue (bsc#1012628).
- net: dsa: felix: Fix memory leak in felix_setup_mmio_filtering
  (bsc#1012628).
- net: dsa: mv88e6xxx: error handling for serdes_power functions
  (bsc#1012628).
- net: bcm4908: Handle dma_set_coherent_mask error codes
  (bsc#1012628).
- devlink: fix netns refcount leak in devlink_nl_cmd_reload()
  (bsc#1012628).
- IB/hfi1: Correct guard on eager buffer deallocation
  (bsc#1012628).
- iavf: Fix reporting when setting descriptor count (bsc#1012628).
- iavf: restore MSI state on reset (bsc#1012628).
- netfilter: conntrack: annotate data-races around ct->timeout
  (bsc#1012628).
- netfilter: nft_exthdr: break evaluation if setting TCP option
  fails (bsc#1012628).
- udp: using datalen to cap max gso segments (bsc#1012628).
- seg6: fix the iif in the IPv6 socket control block
  (bsc#1012628).
- nfp: Fix memory leak in nfp_cpp_area_cache_add() (bsc#1012628).
- bonding: make tx_rebalance_counter an atomic (bsc#1012628).
- ethtool: do not perform operations on net devices being
  unregistered (bsc#1012628).
- ice: ignore dropped packets during init (bsc#1012628).
- bpf: Fix the off-by-two error in range markings (bsc#1012628).
- bpf: Make sure bpf_disable_instrumentation() is safe vs
  preemption (bsc#1012628).
- bpf, sockmap: Attach map progs to psock early for feature probes
  (bsc#1012628).
- bpf, x86: Fix "no previous prototype" warning (bsc#1012628).
- vrf: don't run conntrack on vrf with !dflt qdisc (bsc#1012628).
- selftests: netfilter: add a vrf+conntrack testcase
  (bsc#1012628).
- nfc: fix potential NULL pointer deref in nfc_genl_dump_ses_done
  (bsc#1012628).
- platform/x86: amd-pmc: Fix s2idle failures on certain AMD
  laptops (bsc#1012628).
- x86/sme: Explicitly map new EFI memmap table as encrypted
  (bsc#1012628).
- net: dsa: mv88e6xxx: allow use of PHYs on CPU and DSA ports
  (bsc#1012628).
- net: dsa: mv88e6xxx: fix "don't use PHY_DETECT on internal
  PHY's" (bsc#1012628).
- can: m_can: Disable and ignore ELO interrupt (bsc#1012628).
- can: m_can: pci: fix iomap_read_fifo() and iomap_write_fifo()
  (bsc#1012628).
- can: m_can: pci: fix incorrect reference clock rate
  (bsc#1012628).
- can: m_can: m_can_read_fifo: fix memory leak in error branch
  (bsc#1012628).
- can: pch_can: pch_can_rx_normal: fix use after free
  (bsc#1012628).
- can: sja1000: fix use after free in ems_pcmcia_add_card()
  (bsc#1012628).
- can: kvaser_pciefd: kvaser_pciefd_rx_error_frame(): increase
  correct stats->{rx,tx}_errors counter (bsc#1012628).
- can: kvaser_usb: get CAN clock frequency from device
  (bsc#1012628).
- IB/hfi1: Fix leak of rcvhdrtail_dummy_kvaddr (bsc#1012628).
- IB/hfi1: Fix early init panic (bsc#1012628).
- IB/hfi1: Insure use of smp_processor_id() is preempt disabled
  (bsc#1012628).
- nft_set_pipapo: Fix bucket load in AVX2 lookup routine for
  six 8-bit groups (bsc#1012628).
- platform/x86/intel: hid: add quirk to support Surface Go 3
  (bsc#1012628).
- HID: Ignore battery for Elan touchscreen on Asus UX550VE
  (bsc#1012628).
- HID: sony: fix error path in probe (bsc#1012628).
- mmc: spi: Add device-tree SPI IDs (bsc#1012628).
- mtd: dataflash: Add device-tree SPI IDs (bsc#1012628).
- HID: check for valid USB device for many HID drivers
  (bsc#1012628).
- HID: wacom: fix problems when device is not a valid USB device
  (bsc#1012628).
- HID: bigbenff: prevent null pointer dereference (bsc#1012628).
- HID: add USB_HID dependancy on some USB HID drivers
  (bsc#1012628).
- HID: add USB_HID dependancy to hid-chicony (bsc#1012628).
- HID: add USB_HID dependancy to hid-prodikeys (bsc#1012628).
- HID: add hid_is_usb() function to make it simpler for USB
  detection (bsc#1012628).
- HID: intel-ish-hid: ipc: only enable IRQ wakeup when requested
  (bsc#1012628).
- HID: google: add eel USB id (bsc#1012628).
- HID: quirks: Add quirk for the Microsoft Surface 3 type-cover
  (bsc#1012628).
- usb: gadget: uvc: fix multiple opens (bsc#1012628).
- commit 3f92609
* Mon Dec 13 2021 msuchanek@suse.de
- config: INPUT_EVBUG=n (bsc#1192974).
  Debug driver unsuitable for production, only enabled on ppc64.
- commit 4e0adba
* Mon Dec 13 2021 dmueller@suse.com
- kernel-obs-build: inform build service about virtio-serial
  Inform the build worker code that this kernel supports virtio-serial,
  which improves performance and relability of logging.
- commit 301a3a7
* Mon Dec 13 2021 dmueller@suse.com
- rpm/*.spec.in: use buildroot macro instead of env variable
  The RPM_BUILD_ROOT variable is considered deprecated over
  a buildroot macro. future proof the spec files.
- commit e2f6026
* Mon Dec 13 2021 mkubecek@suse.cz
- Update to 5.16-rc5
- commit c317c11
* Fri Dec 10 2021 tiwai@suse.de
- Update BT fix patch for regression with 8087:0026 device (bsc#1193124)
  Also corrected the references and patch description
- commit ee06149
* Thu Dec  9 2021 ohering@suse.de
- Disable hyperv_fb in favour of hyperv_drm (jsc#SLE-19733)
- commit f85f403
* Wed Dec  8 2021 jslaby@suse.cz
- Linux 5.15.7 (bsc#1012628).
- ALSA: usb-audio: Rename early_playback_start flag with
  lowlatency_playback (bsc#1012628).
- ALSA: usb-audio: Disable low-latency playback for free-wheel
  mode (bsc#1012628).
- ALSA: usb-audio: Disable low-latency mode for implicit feedback
  sync (bsc#1012628).
- ALSA: usb-audio: Check available frames for the next packet size
  (bsc#1012628).
- ALSA: usb-audio: Add spinlock to stop_urbs() (bsc#1012628).
- ALSA: usb-audio: Improved lowlatency playback support
  (bsc#1012628).
- ALSA: usb-audio: Avoid killing in-flight URBs during draining
  (bsc#1012628).
- ALSA: usb-audio: Fix packet size calculation regression
  (bsc#1012628).
- ALSA: usb-audio: Less restriction for low-latency playback mode
  (bsc#1012628).
- ALSA: usb-audio: Switch back to non-latency mode at a later
  point (bsc#1012628).
- ALSA: usb-audio: Don't start stream for capture at prepare
  (bsc#1012628).
- gfs2: release iopen glock early in evict (bsc#1012628).
- gfs2: Fix length of holes reported at end-of-file (bsc#1012628).
- powerpc/pseries/ddw: Revert "Extend upper limit for huge DMA
  window for persistent memory" (bsc#1012628).
- powerpc/pseries/ddw: Do not try direct mapping with persistent
  memory and one window (bsc#1012628).
- drm/sun4i: fix unmet dependency on RESET_CONTROLLER for
  PHY_SUN6I_MIPI_DPHY (bsc#1012628).
- mac80211: do not access the IV when it was stripped
  (bsc#1012628).
- mac80211: fix throughput LED trigger (bsc#1012628).
- x86/hyperv: Move required MSRs check to initial platform probing
  (bsc#1012628).
- net/smc: Transfer remaining wait queue entries during fallback
  (bsc#1012628).
- atlantic: Fix OOB read and write in hw_atl_utils_fw_rpc_wait
  (bsc#1012628).
- net: return correct error code (bsc#1012628).
- pinctrl: qcom: fix unmet dependencies on GPIOLIB for
  GPIOLIB_IRQCHIP (bsc#1012628).
- platform/x86: dell-wmi-descriptor: disable by default
  (bsc#1012628).
- platform/x86: thinkpad_acpi: Add support for dual fan control
  (bsc#1012628).
- platform/x86: thinkpad_acpi: Fix WWAN device disabled issue
  after S3 deep (bsc#1012628).
- s390/setup: avoid using memblock_enforce_memory_limit
  (bsc#1012628).
- btrfs: silence lockdep when reading chunk tree during mount
  (bsc#1012628).
- btrfs: check-integrity: fix a warning on write caching disabled
  disk (bsc#1012628).
- thermal: core: Reset previous low and high trip during thermal
  zone init (bsc#1012628).
- scsi: iscsi: Unblock session then wake up error handler
  (bsc#1012628).
- net: usb: r8152: Add MAC passthrough support for more Lenovo
  Docks (bsc#1012628).
- drm/amd/pm: Remove artificial freq level on Navi1x
  (bsc#1012628).
- drm/amd/amdkfd: Fix kernel panic when reset failed and been
  triggered again (bsc#1012628).
- drm/amd/amdgpu: fix potential memleak (bsc#1012628).
- ata: ahci: Add Green Sardine vendor ID as board_ahci_mobile
  (bsc#1012628).
- ata: libahci: Adjust behavior when StorageD3Enable _DSD is set
  (bsc#1012628).
- ethernet: hisilicon: hns: hns_dsaf_misc: fix a possible array
  overflow in hns_dsaf_ge_srst_by_port() (bsc#1012628).
- ipv6: check return value of ipv6_skip_exthdr (bsc#1012628).
- net: tulip: de4x5: fix the problem that the array 'lp->phy[8]'
  may be out of bound (bsc#1012628).
- net: ethernet: dec: tulip: de4x5: fix possible array overflows
  in type3_infoblock() (bsc#1012628).
- perf sort: Fix the 'weight' sort key behavior (bsc#1012628).
- perf sort: Fix the 'ins_lat' sort key behavior (bsc#1012628).
- perf sort: Fix the 'p_stage_cyc' sort key behavior
  (bsc#1012628).
- perf inject: Fix ARM SPE handling (bsc#1012628).
- perf hist: Fix memory leak of a perf_hpp_fmt (bsc#1012628).
- perf report: Fix memory leaks around perf_tip() (bsc#1012628).
- tracing: Don't use out-of-sync va_list in event printing
  (bsc#1012628).
- net/smc: Avoid warning of possible recursive locking
  (bsc#1012628).
- ACPI: Add stubs for wakeup handler functions (bsc#1012628).
- net/tls: Fix authentication failure in CCM mode (bsc#1012628).
- vrf: Reset IPCB/IP6CB when processing outbound pkts in vrf
  dev xmit (bsc#1012628).
- kprobes: Limit max data_size of the kretprobe instances
  (bsc#1012628).
- ALSA: hda/cs8409: Set PMSG_ON earlier inside cs8409 driver
  (bsc#1012628).
- rt2x00: do not mark device gone on EPROTO errors during start
  (bsc#1012628).
- ipmi: Move remove_work to dedicated workqueue (bsc#1012628).
- cpufreq: Fix get_cpu_device() failure in add_cpu_dev_symlink()
  (bsc#1012628).
- iwlwifi: mvm: retry init flow if failed (bsc#1012628).
- dma-buf: system_heap: Use 'for_each_sgtable_sg' in pages free
  flow (bsc#1012628).
- s390/pci: move pseudo-MMIO to prevent MIO overlap (bsc#1012628).
- fget: check that the fd still exists after getting a ref to it
  (bsc#1012628).
- sata_fsl: fix UAF in sata_fsl_port_stop when rmmod sata_fsl
  (bsc#1012628).
- sata_fsl: fix warning in remove_proc_entry when rmmod sata_fsl
  (bsc#1012628).
- scsi: lpfc: Fix non-recovery of remote ports following an
  unsolicited LOGO (bsc#1012628).
- scsi: ufs: ufs-pci: Add support for Intel ADL (bsc#1012628).
- ipv6: fix memory leak in fib6_rule_suppress (bsc#1012628).
- drm/amd/display: Allow DSC on supported MST branch devices
  (bsc#1012628).
- drm/i915/dp: Perform 30ms delay after source OUI write
  (bsc#1012628).
- KVM: fix avic_set_running for preemptable kernels (bsc#1012628).
- KVM: Disallow user memslot with size that exceeds "unsigned
  long" (bsc#1012628).
- KVM: x86/mmu: Fix TLB flush range when handling disconnected pt
  (bsc#1012628).
- KVM: Ensure local memslot copies operate on up-to-date
  arch-specific data (bsc#1012628).
- KVM: x86: ignore APICv if LAPIC is not enabled (bsc#1012628).
- KVM: nVMX: Emulate guest TLB flush on nested VM-Enter with
  new vpid12 (bsc#1012628).
- KVM: nVMX: Flush current VPID (L1 vs. L2) for
  KVM_REQ_TLB_FLUSH_GUEST (bsc#1012628).
- KVM: nVMX: Abide to KVM_REQ_TLB_FLUSH_GUEST request on nested
  vmentry/vmexit (bsc#1012628).
- KVM: VMX: prepare sync_pir_to_irr for running with APICv
  disabled (bsc#1012628).
- KVM: x86: Use a stable condition around all VT-d PI paths
  (bsc#1012628).
- KVM: MMU: shadow nested paging does not have PKU (bsc#1012628).
- KVM: arm64: Avoid setting the upper 32 bits of TCR_EL2 and
  CPTR_EL2 to 1 (bsc#1012628).
- KVM: X86: Use vcpu->arch.walk_mmu for kvm_mmu_invlpg()
  (bsc#1012628).
- KVM: x86: check PIR even for vCPUs with disabled APICv
  (bsc#1012628).
- tracing/histograms: String compares should not care about
  signed values (bsc#1012628).
- net: dsa: mv88e6xxx: Fix application of erratum 4.8 for 88E6393X
  (bsc#1012628).
- net: dsa: mv88e6xxx: Drop unnecessary check in
  mv88e6393x_serdes_erratum_4_6() (bsc#1012628).
- net: dsa: mv88e6xxx: Save power by disabling SerDes trasmitter
  and receiver (bsc#1012628).
- net: dsa: mv88e6xxx: Add fix for erratum 5.2 of 88E6393X family
  (bsc#1012628).
- net: dsa: mv88e6xxx: Fix inband AN for 2500base-x on 88E6393X
  family (bsc#1012628).
- net: dsa: mv88e6xxx: Link in pcs_get_state() if AN is bypassed
  (bsc#1012628).
- wireguard: selftests: increase default dmesg log size
  (bsc#1012628).
- wireguard: allowedips: add missing __rcu annotation to satisfy
  sparse (bsc#1012628).
- wireguard: selftests: actually test for routing loops
  (bsc#1012628).
- wireguard: selftests: rename DEBUG_PI_LIST to DEBUG_PLIST
  (bsc#1012628).
- wireguard: device: reset peer src endpoint when netns exits
  (bsc#1012628).
- wireguard: receive: use ring buffer for incoming handshakes
  (bsc#1012628).
- wireguard: receive: drop handshakes if queue lock is contended
  (bsc#1012628).
- wireguard: ratelimiter: use kvcalloc() instead of kvzalloc()
  (bsc#1012628).
- i2c: stm32f7: flush TX FIFO upon transfer errors (bsc#1012628).
- i2c: stm32f7: recover the bus on access timeout (bsc#1012628).
- i2c: stm32f7: stop dma transfer in case of NACK (bsc#1012628).
- i2c: cbus-gpio: set atomic transfer callback (bsc#1012628).
- natsemi: xtensa: fix section mismatch warnings (bsc#1012628).
- tcp: fix page frag corruption on page fault (bsc#1012628).
- net: qlogic: qlcnic: Fix a NULL pointer dereference in
  qlcnic_83xx_add_rings() (bsc#1012628).
- net: mpls: Fix notifications when deleting a device
  (bsc#1012628).
- siphash: use _unaligned version by default (bsc#1012628).
- arm64: ftrace: add missing BTIs (bsc#1012628).
- iwlwifi: fix warnings produced by kernel debug options
  (bsc#1012628).
- net/mlx5e: IPsec: Fix Software parser inner l3 type setting
  in case of encapsulation (bsc#1012628).
- net/mlx4_en: Fix an use-after-free bug in
  mlx4_en_try_alloc_resources() (bsc#1012628).
- selftests: net: Correct case name (bsc#1012628).
- net: dsa: b53: Add SPI ID table (bsc#1012628).
- mt76: mt7915: fix NULL pointer dereference in
  mt7915_get_phy_mode (bsc#1012628).
- ASoC: tegra: Fix wrong value type in ADMAIF (bsc#1012628).
- ASoC: tegra: Fix wrong value type in I2S (bsc#1012628).
- ASoC: tegra: Fix wrong value type in DMIC (bsc#1012628).
- ASoC: tegra: Fix wrong value type in DSPK (bsc#1012628).
- ASoC: tegra: Fix kcontrol put callback in ADMAIF (bsc#1012628).
- ASoC: tegra: Fix kcontrol put callback in I2S (bsc#1012628).
- ASoC: tegra: Fix kcontrol put callback in DMIC (bsc#1012628).
- ASoC: tegra: Fix kcontrol put callback in DSPK (bsc#1012628).
- ASoC: tegra: Fix kcontrol put callback in AHUB (bsc#1012628).
- rxrpc: Fix rxrpc_peer leak in rxrpc_look_up_bundle()
  (bsc#1012628).
- rxrpc: Fix rxrpc_local leak in rxrpc_lookup_peer()
  (bsc#1012628).
- ALSA: intel-dsp-config: add quirk for CML devices based on
  ES8336 codec (bsc#1012628).
- net: stmmac: Avoid DMA_CHAN_CONTROL write if no Split Header
  support (bsc#1012628).
- net: usb: lan78xx: lan78xx_phy_init(): use PHY_POLL instead of
  "0" if no IRQ is available (bsc#1012628).
- net: marvell: mvpp2: Fix the computation of shared CPUs
  (bsc#1012628).
- dpaa2-eth: destroy workqueue at the end of remove function
  (bsc#1012628).
- octeontx2-af: Fix a memleak bug in rvu_mbox_init()
  (bsc#1012628).
- net: annotate data-races on txq->xmit_lock_owner (bsc#1012628).
- ipv4: convert fib_num_tclassid_users to atomic_t (bsc#1012628).
- net/smc: fix wrong list_del in smc_lgr_cleanup_early
  (bsc#1012628).
- net/rds: correct socket tunable error in rds_tcp_tune()
  (bsc#1012628).
- net/smc: Keep smc_close_final rc during active close
  (bsc#1012628).
- drm/msm/a6xx: Allocate enough space for GMU registers
  (bsc#1012628).
- drm/msm: Do hw_init() before capturing GPU state (bsc#1012628).
- drm/vc4: kms: Wait for the commit before increasing our clock
  rate (bsc#1012628).
- drm/vc4: kms: Fix return code check (bsc#1012628).
- drm/vc4: kms: Add missing drm_crtc_commit_put (bsc#1012628).
- drm/vc4: kms: Clear the HVS FIFO commit pointer once done
  (bsc#1012628).
- drm/vc4: kms: Don't duplicate pending commit (bsc#1012628).
- drm/vc4: kms: Fix previous HVS commit wait (bsc#1012628).
- atlantic: Increase delay for fw transactions (bsc#1012628).
- atlatnic: enable Nbase-t speeds with base-t (bsc#1012628).
- atlantic: Fix to display FW bundle version instead of FW mac
  version (bsc#1012628).
- atlantic: Add missing DIDs and fix 115c (bsc#1012628).
- Remove Half duplex mode speed capabilities (bsc#1012628).
- atlantic: Fix statistics logic for production hardware
  (bsc#1012628).
- atlantic: Remove warn trace message (bsc#1012628).
- KVM: x86/mmu: Skip tlb flush if it has been done in
  zap_gfn_range() (bsc#1012628).
- KVM: x86/mmu: Pass parameter flush as false in
  kvm_tdp_mmu_zap_collapsible_sptes() (bsc#1012628).
- drm/msm/devfreq: Fix OPP refcnt leak (bsc#1012628).
- drm/msm: Fix mmap to include VM_IO and VM_DONTDUMP
  (bsc#1012628).
- drm/msm: Fix wait_fence submitqueue leak (bsc#1012628).
- drm/msm: Restore error return on invalid fence (bsc#1012628).
- ASoC: rk817: Add module alias for rk817-codec (bsc#1012628).
- iwlwifi: Fix memory leaks in error handling path (bsc#1012628).
- KVM: X86: Fix when shadow_root_level=5 && guest root_level<4
  (bsc#1012628).
- KVM: SEV: initialize regions_list of a mirror VM (bsc#1012628).
- net/mlx5e: Fix missing IPsec statistics on uplink representor
  (bsc#1012628).
- net/mlx5: Move MODIFY_RQT command to ignore list in internal
  error state (bsc#1012628).
- net/mlx5: E-switch, Respect BW share of the new group
  (bsc#1012628).
- net/mlx5: E-Switch, fix single FDB creation on BlueField
  (bsc#1012628).
- net/mlx5: E-Switch, Check group pointer before reading bw_share
  value (bsc#1012628).
- KVM: x86/pmu: Fix reserved bits for AMD PerfEvtSeln register
  (bsc#1012628).
- KVM: VMX: Set failure code in prepare_vmcs02() (bsc#1012628).
- mctp: Don't let RTM_DELROUTE delete local routes (bsc#1012628).
- Revert "drm/i915: Implement Wa_1508744258" (bsc#1012628).
- io-wq: don't retry task_work creation failure on fatal
  conditions (bsc#1012628).
- x86/sev: Fix SEV-ES INS/OUTS instructions for word, dword,
  and qword (bsc#1012628).
- x86/entry: Add a fence for kernel entry SWAPGS in
  paranoid_entry() (bsc#1012628).
- x86/entry: Use the correct fence macro after swapgs in kernel
  CR3 (bsc#1012628).
- x86/xen: Add xenpv_restore_regs_and_return_to_usermode()
  (bsc#1012628).
- preempt/dynamic: Fix setup_preempt_mode() return value
  (bsc#1012628).
- sched/uclamp: Fix rq->uclamp_max not set on first enqueue
  (bsc#1012628).
- KVM: SEV: Return appropriate error codes if SEV-ES scratch
  setup fails (bsc#1012628).
- KVM: x86/mmu: Rename slot_handle_leaf to slot_handle_level_4k
  (bsc#1012628).
- KVM: x86/mmu: Remove spurious TLB flushes in TDP MMU zap
  collapsible path (bsc#1012628).
- net/mlx5e: Rename lro_timeout to packet_merge_timeout
  (bsc#1012628).
- net/mlx5e: Rename TIR lro functions to TIR packet merge
  functions (bsc#1012628).
- net/mlx5e: Sync TIR params updates against concurrent
  create/modify (bsc#1012628).
- serial: 8250_bcm7271: UART errors after resuming from S2
  (bsc#1012628).
- parisc: Fix KBUILD_IMAGE for self-extracting kernel
  (bsc#1012628).
- parisc: Fix "make install" on newer debian releases
  (bsc#1012628).
- parisc: Mark cr16 CPU clocksource unstable on all SMP machines
  (bsc#1012628).
- vgacon: Propagate console boot parameters before calling
  `vc_resize' (bsc#1012628).
- USB: NO_LPM quirk Lenovo Powered USB-C Travel Hub (bsc#1012628).
- usb: typec: tcpm: Wait in SNK_DEBOUNCED until disconnect
  (bsc#1012628).
- usb: cdns3: gadget: fix new urb never complete if ep cancel
  previous requests (bsc#1012628).
- usb: cdnsp: Fix a NULL pointer dereference in
  cdnsp_endpoint_init() (bsc#1012628).
- x86/tsc: Add a timer to make sure TSC_adjust is always checked
  (bsc#1012628).
- x86/tsc: Disable clocksource watchdog for TSC on qualified
  platorms (bsc#1012628).
- x86/64/mm: Map all kernel memory into trampoline_pgd
  (bsc#1012628).
- tty: serial: msm_serial: Deactivate RX DMA for polling support
  (bsc#1012628).
- serial: pl011: Add ACPI SBSA UART match id (bsc#1012628).
- serial: tegra: Change lower tolerance baud rate limit for
  tegra20 and tegra30 (bsc#1012628).
- serial: core: fix transmit-buffer reset and memleak
  (bsc#1012628).
- serial: 8250_pci: Fix ACCES entries in pci_serial_quirks array
  (bsc#1012628).
- serial: 8250_pci: rewrite pericom_do_set_divisor()
  (bsc#1012628).
- serial: 8250: Fix RTS modem control while in rs485 mode
  (bsc#1012628).
- serial: liteuart: Fix NULL pointer dereference in ->remove()
  (bsc#1012628).
- serial: liteuart: fix use-after-free and memleak on unbind
  (bsc#1012628).
- serial: liteuart: fix minor-number leak on probe errors
  (bsc#1012628).
- ipmi: msghandler: Make symbol 'remove_work_wq' static
  (bsc#1012628).
- Refresh patches.suse/suse-hv-guest-os-id.patch.
- commit b92986a
* Mon Dec  6 2021 mkubecek@suse.cz
- Update to 5.16-rc4
- eliminated 1 patch:
  - patches.suse/rtw89-update-partition-size-of-firmware-header-on-sk.patch
- commit d1dc164
* Fri Dec  3 2021 tiwai@suse.de
- xhci: Fix commad ring abort, write all 64 bits to CRCR register
  (bsc#1192569).
- commit 0f8ae34
* Thu Dec  2 2021 tiwai@suse.de
- Bluetooth: Apply initial command workaround for more Intel chips
  (bsc#83f2dafe2a62).
- commit 9c66401
* Thu Dec  2 2021 jslaby@suse.cz
- rpm/kernel-binary.spec.in: don't strip vmlinux again (bsc#1193306)
  After usrmerge, vmlinux file is not named vmlinux-<version>, but simply
  vmlinux. And this is not reflected in STRIP_KEEP_SYMTAB we set.
  So fix this by removing the dash...
- commit 83af88d
* Wed Dec  1 2021 jslaby@suse.cz
- Linux 5.15.6 (bsc#1012628).
- drm/amdgpu/gfx9: switch to golden tsc registers for renoir+
  (bsc#1012628).
- drm/amdgpu/gfx10: add wraparound gpu counter check for APUs
  as well (bsc#1012628).
- block: avoid to quiesce queue in elevator_init_mq (bsc#1012628).
- blk-mq: cancel blk-mq dispatch work in both blk_cleanup_queue
  and disk_release() (bsc#1012628).
- docs: accounting: update delay-accounting.rst reference
  (bsc#1012628).
- firmware: arm_scmi: Fix type error in sensor protocol
  (bsc#1012628).
- firmware: arm_scmi: Fix type error assignment in voltage
  protocol (bsc#1012628).
- io_uring: fix soft lockup when call __io_remove_buffers
  (bsc#1012628).
- cifs: nosharesock should be set on new server (bsc#1012628).
- tracing: Check pid filtering when creating events (bsc#1012628).
- ksmbd: Fix an error handling path in 'smb2_sess_setup()'
  (bsc#1012628).
- vhost/vsock: fix incorrect used length reported to the guest
  (bsc#1012628).
- vdpa_sim: avoid putting an uninitialized iova_domain
  (bsc#1012628).
- iommu/amd: Clarify AMD IOMMUv2 initialization messages
  (bsc#1012628).
- ceph: properly handle statfs on multifs setups (bsc#1012628).
- cifs: nosharesock should not share socket with future sessions
  (bsc#1012628).
- riscv: dts: microchip: drop duplicated MMC/SDHC node
  (bsc#1012628).
- riscv: dts: microchip: fix board compatible (bsc#1012628).
- f2fs: set SBI_NEED_FSCK flag when inconsistent node block found
  (bsc#1012628).
- f2fs: quota: fix potential deadlock (bsc#1012628).
- iommu/vt-d: Fix unmap_pages support (bsc#1012628).
- iommu/rockchip: Fix PAGE_DESC_HI_MASKs for RK3568 (bsc#1012628).
- sched/scs: Reset task stack state in bringup_cpu()
  (bsc#1012628).
- perf: Ignore sigtrap for tracepoints destined for other tasks
  (bsc#1012628).
- locking/rwsem: Make handoff bit handling more consistent
  (bsc#1012628).
- net: mscc: ocelot: correctly report the timestamping RX filters
  in ethtool (bsc#1012628).
- net: mscc: ocelot: don't downgrade timestamping RX filters in
  SIOCSHWTSTAMP (bsc#1012628).
- net: hns3: fix incorrect components info of ethtool --reset
  command (bsc#1012628).
- net: hns3: fix VF RSS failed problem after PF enable multi-TCs
  (bsc#1012628).
- net/smc: Don't call clcsock shutdown twice when smc shutdown
  (bsc#1012628).
- net: vlan: fix underflow for the real_dev refcnt (bsc#1012628).
- ethtool: ioctl: fix potential NULL deref in
  ethtool_set_coalesce() (bsc#1012628).
- net/sched: sch_ets: don't peek at classes beyond 'nbands'
  (bsc#1012628).
- net: stmmac: Disable Tx queues when reconfiguring the interface
  (bsc#1012628).
- tls: fix replacing proto_ops (bsc#1012628).
- tls: splice_read: fix accessing pre-processed records
  (bsc#1012628).
- tls: splice_read: fix record type check (bsc#1012628).
- MIPS: use 3-level pgtable for 64KB page size on MIPS_VA_BITS_48
  (bsc#1012628).
- MIPS: loongson64: fix FTLB configuration (bsc#1012628).
- igb: fix netpoll exit with traffic (bsc#1012628).
- nvmet: use IOCB_NOWAIT only if the filesystem supports it
  (bsc#1012628).
- net/smc: Fix loop in smc_listen (bsc#1012628).
- net/smc: Fix NULL pointer dereferencing in smc_vlan_by_tcpsk()
  (bsc#1012628).
- net: phylink: Force retrigger in case of latched link-fail
  indicator (bsc#1012628).
- net: phylink: Force link down and retrigger resolve on interface
  change (bsc#1012628).
- lan743x: fix deadlock in lan743x_phy_link_status_change()
  (bsc#1012628).
- tcp_cubic: fix spurious Hystart ACK train detections for
  not-cwnd-limited flows (bsc#1012628).
- drm/amd/display: Set plane update flags for all planes in reset
  (bsc#1012628).
- drm/amd/display: Fix DPIA outbox timeout after GPU reset
  (bsc#1012628).
- PM: hibernate: use correct mode for swsusp_close()
  (bsc#1012628).
- net/ncsi : Add payload to be 32-bit aligned to fix dropped
  packets (bsc#1012628).
- arm64: uaccess: avoid blocking within critical sections
  (bsc#1012628).
- drm/hyperv: Fix device removal on Gen1 VMs (bsc#1012628).
- nvmet-tcp: fix incomplete data digest send (bsc#1012628).
- cpufreq: intel_pstate: Add Ice Lake server to out-of-band IDs
  (bsc#1012628).
- net: marvell: mvpp2: increase MTU limit when XDP enabled
  (bsc#1012628).
- net: ipa: kill ipa_cmd_pipeline_clear() (bsc#1012628).
- net: ipa: separate disabling setup from modem stop
  (bsc#1012628).
- net: ipa: directly disable ipa-setup-ready interrupt
  (bsc#1012628).
- mlxsw: spectrum: Protect driver from buggy firmware
  (bsc#1012628).
- net/smc: Ensure the active closing peer first closes clcsock
  (bsc#1012628).
- i2c: virtio: disable timeout handling (bsc#1012628).
- erofs: fix deadlock when shrink erofs slab (bsc#1012628).
- scsi: scsi_debug: Zero clear zones at reset write pointer
  (bsc#1012628).
- scsi: core: sysfs: Fix setting device state to SDEV_RUNNING
  (bsc#1012628).
- ice: avoid bpf_prog refcount underflow (bsc#1012628).
- ice: fix vsi->txq_map sizing (bsc#1012628).
- net: nexthop: release IPv6 per-cpu dsts when replacing a
  nexthop group (bsc#1012628).
- net: ipv6: add fib6_nh_release_dsts stub (bsc#1012628).
- net: stmmac: retain PTP clock time during SIOCSHWTSTAMP ioctls
  (bsc#1012628).
- nfp: checking parameter process for rx-usecs/tx-usecs is invalid
  (bsc#1012628).
- ipv6: fix typos in __ip6_finish_output() (bsc#1012628).
- firmware: smccc: Fix check for ARCH_SOC_ID not implemented
  (bsc#1012628).
- af_unix: fix regression in read after shutdown (bsc#1012628).
- mptcp: use delegate action to schedule 3rd ack retrans
  (bsc#1012628).
- mptcp: fix delack timer (bsc#1012628).
- ALSA: intel-dsp-config: add quirk for JSL devices based on
  ES8336 codec (bsc#1012628).
- xen/pvh: add missing prototype to header (bsc#1012628).
- x86/pvh: add prototype for xen_pvh_init() (bsc#1012628).
- iavf: Fix VLAN feature flags after VFR (bsc#1012628).
- iavf: Fix refreshing iavf adapter stats on ethtool request
  (bsc#1012628).
- iavf: Prevent changing static ITR values if adaptive moderation
  is on (bsc#1012628).
- HID: magicmouse: prevent division by 0 on scroll (bsc#1012628).
- HID: input: set usage type to key on keycode remap
  (bsc#1012628).
- HID: input: Fix parsing of HID_CP_CONSUMER_CONTROL fields
  (bsc#1012628).
- net: marvell: prestera: fix double free issue on err path
  (bsc#1012628).
- net: marvell: prestera: fix brige port operation (bsc#1012628).
- drm/aspeed: Fix vga_pw sysfs output (bsc#1012628).
- drm/vc4: fix error code in vc4_create_object() (bsc#1012628).
- scsi: mpt3sas: Fix incorrect system timestamp (bsc#1012628).
- scsi: mpt3sas: Fix system going into read-only mode
  (bsc#1012628).
- scsi: mpt3sas: Fix kernel panic during drive powercycle test
  (bsc#1012628).
- scsi: qla2xxx: edif: Fix off by one bug in
  qla_edif_app_getfcinfo() (bsc#1012628).
- drm/nouveau/acr: fix a couple NULL vs IS_ERR() checks
  (bsc#1012628).
- ARM: socfpga: Fix crash with CONFIG_FORTIRY_SOURCE
  (bsc#1012628).
- NFSv42: Don't fail clone() unless the OP_CLONE operation failed
  (bsc#1012628).
- ASoC: stm32: i2s: fix 32 bits channel length without mclk
  (bsc#1012628).
- firmware: arm_scmi: pm: Propagate return value to caller
  (bsc#1012628).
- firmware: arm_scmi: Fix base agent discover response
  (bsc#1012628).
- net: ieee802154: handle iftypes as u32 (bsc#1012628).
- ASoC: codecs: lpass-rx-macro: fix HPHR setting CLSH mask
  (bsc#1012628).
- ASoC: codecs: wcd934x: return error code correctly from
  hw_params (bsc#1012628).
- ASoC: codecs: wcd938x: fix volatile register range
  (bsc#1012628).
- ASoC: topology: Add missing rwsem around snd_ctl_remove()
  calls (bsc#1012628).
- ASoC: qdsp6: q6asm: fix q6asm_dai_prepare error handling
  (bsc#1012628).
- ASoC: qdsp6: q6routing: Conditionally reset FrontEnd Mixer
  (bsc#1012628).
- ARM: dts: bcm2711: Fix PCIe interrupts (bsc#1012628).
- ARM: dts: BCM5301X: Add interrupt properties to GPIO node
  (bsc#1012628).
- ARM: dts: BCM5301X: Fix I2C controller interrupt (bsc#1012628).
- firmware: arm_scmi: Fix null de-reference on error path
  (bsc#1012628).
- media: v4l2-core: fix VIDIOC_DQEVENT handling on non-x86
  (bsc#1012628).
- netfilter: flowtable: fix IPv6 tunnel addr match (bsc#1012628).
- netfilter: ipvs: Fix reuse connection if RS weight is 0
  (bsc#1012628).
- netfilter: ctnetlink: do not erase error code with EINVAL
  (bsc#1012628).
- netfilter: ctnetlink: fix filtering with CTA_TUPLE_REPLY
  (bsc#1012628).
- ASoC: SOF: Intel: hda: fix hotplug when only codec is suspended
  (bsc#1012628).
- proc/vmcore: fix clearing user buffer by properly using
  clear_user() (bsc#1012628).
- drm/amd/display: Fix OLED brightness control on eDP
  (bsc#1012628).
- PCI: aardvark: Fix link training (bsc#1012628).
- PCI: aardvark: Simplify initialization of rootcap on virtual
  bridge (bsc#1012628).
- PCI: aardvark: Implement re-issuing config requests on CRS
  response (bsc#1012628).
- PCI: aardvark: Deduplicate code in advk_pcie_rd_conf()
  (bsc#1012628).
- NFSv42: Fix pagecache invalidation after COPY/CLONE
  (bsc#1012628).
- iomap: Fix inline extent handling in iomap_readpage
  (bsc#1012628).
- powerpc/32: Fix hardlockup on vmap stack overflow (bsc#1012628).
- cpufreq: intel_pstate: Fix active mode offline/online EPP
  handling (bsc#1012628).
- arm64: mm: Fix VM_BUG_ON(mm != &init_mm) for trans_pgd
  (bsc#1012628).
- mdio: aspeed: Fix "Link is Down" issue (bsc#1012628).
- mmc: sdhci: Fix ADMA for PAGE_SIZE >= 64KiB (bsc#1012628).
- mmc: sdhci-esdhc-imx: disable CMDQ support (bsc#1012628).
- tracing: Fix pid filtering when triggers are attached
  (bsc#1012628).
- tracing/uprobe: Fix uprobe_perf_open probes iteration
  (bsc#1012628).
- KVM: PPC: Book3S HV: Prevent POWER7/8 TLB flush flushing SLB
  (bsc#1012628).
- ksmbd: fix memleak in get_file_stream_info() (bsc#1012628).
- ksmbd: contain default data stream even if xattr is empty
  (bsc#1012628).
- ksmbd: downgrade addition info error msg to debug in
  smb2_get_info_sec() (bsc#1012628).
- drm/nouveau: recognise GA106 (bsc#1012628).
- drm/amdgpu/pm: fix powerplay OD interface (bsc#1012628).
- drm/amdgpu: IH process reset count when restart (bsc#1012628).
- io_uring: fix link traversal locking (bsc#1012628).
- io_uring: fail cancellation for EXITING tasks (bsc#1012628).
- io_uring: correct link-list traversal locking (bsc#1012628).
- xen: detect uninitialized xenbus in xenbus_init (bsc#1012628).
- xen: don't continue xenstore initialization in case of errors
  (bsc#1012628).
- fuse: release pipe buf after last use (bsc#1012628).
- staging: r8188eu: fix a memory leak in rtw_wx_read32()
  (bsc#1012628).
- staging: r8188eu: use GFP_ATOMIC under spinlock (bsc#1012628).
- staging: r8188eu: Fix breakage introduced when 5G code was
  removed (bsc#1012628).
- staging: r8188eu: Use kzalloc() with GFP_ATOMIC in atomic
  context (bsc#1012628).
- staging: rtl8192e: Fix use after free in
  _rtl92e_pci_disconnect() (bsc#1012628).
- staging: greybus: Add missing rwsem around snd_ctl_remove()
  calls (bsc#1012628).
- staging/fbtft: Fix backlight (bsc#1012628).
- HID: wacom: Use "Confidence" flag to prevent reporting invalid
  contacts (bsc#1012628).
- Revert "parisc: Fix backtrace to always include init funtion
  names" (bsc#1012628).
- media: cec: copy sequence field for the reply (bsc#1012628).
- ALSA: hda/realtek: Fix LED on HP ProBook 435 G7 (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ASRock NUC Box 1100
  (bsc#1012628).
- ALSA: ctxfi: Fix out-of-range access (bsc#1012628).
- binder: fix test regression due to sender_euid change
  (bsc#1012628).
- usb: hub: Fix locking issues with address0_mutex (bsc#1012628).
- usb: hub: Fix usb enumeration issue due to address0 race
  (bsc#1012628).
- usb: xhci: tegra: Check padctrl interrupt presence in device
  tree (bsc#1012628).
- usb: typec: fusb302: Fix masking of comparator and bc_lvl
  interrupts (bsc#1012628).
- usb: chipidea: ci_hdrc_imx: fix potential error pointer
  dereference in probe (bsc#1012628).
- net: nexthop: fix null pointer dereference when IPv6 is not
  enabled (bsc#1012628).
- net: usb: Correct PHY handling of smsc95xx (bsc#1012628).
- usb: dwc3: gadget: Fix null pointer exception (bsc#1012628).
- usb: dwc3: gadget: Check for L1/L2/U3 for Start Transfer
  (bsc#1012628).
- usb: dwc3: gadget: Ignore NoStream after End Transfer
  (bsc#1012628).
- usb: dwc3: core: Revise GHWPARAMS9 offset (bsc#1012628).
- usb: dwc3: leave default DMA for PCI devices (bsc#1012628).
- usb: dwc2: hcd_queue: Fix use of floating point literal
  (bsc#1012628).
- usb: dwc2: gadget: Fix ISOC flow for elapsed frames
  (bsc#1012628).
- USB: serial: option: add Fibocom FM101-GL variants
  (bsc#1012628).
- USB: serial: option: add Telit LE910S1 0x9200 composition
  (bsc#1012628).
- USB: serial: pl2303: fix GC type detection (bsc#1012628).
- ACPI: CPPC: Add NULL pointer check to cppc_get_perf()
  (bsc#1012628).
- ACPI: Get acpi_device's parent from the parent field
  (bsc#1012628).
- scsi: sd: Fix sd_do_mode_sense() buffer length handling
  (bsc#1012628).
- commit 30c5f4d
* Wed Dec  1 2021 tiwai@suse.de
- mwifiex: Fix skb_over_panic in mwifiex_usb_recv()
  (CVE-2021-43976 bsc#1192847).
- commit 62666c5
* Mon Nov 29 2021 mkubecek@suse.cz
- Update to 5.16-rc3
- refresh configs
- commit e8ae228
* Fri Nov 26 2021 msuchanek@suse.de
- constraints: Build aarch64 on recent ARMv8.1 builders.
  Request asimdrdm feature which is available only on recent ARMv8.1 CPUs.
  This should prevent scheduling the kernel on an older slower builder.
- commit 60fc53f
* Thu Nov 25 2021 jslaby@suse.cz
- Linux 5.15.5 (bsc#1012628).
- arm64: zynqmp: Do not duplicate flash partition label property
  (bsc#1012628).
- arm64: zynqmp: Fix serial compatible string (bsc#1012628).
- clk: sunxi-ng: Unregister clocks/resets when unbinding
  (bsc#1012628).
- ARM: dts: sunxi: Fix OPPs node name (bsc#1012628).
- arm64: dts: allwinner: h5: Fix GPU thermal zone node name
  (bsc#1012628).
- arm64: dts: allwinner: a100: Fix thermal zone node name
  (bsc#1012628).
- staging: wfx: ensure IRQ is ready before enabling it
  (bsc#1012628).
- ARM: dts: BCM5301X: Fix nodes names (bsc#1012628).
- ARM: dts: BCM5301X: Fix MDIO mux binding (bsc#1012628).
- ARM: dts: NSP: Fix mpcore, mmc node names (bsc#1012628).
- arm64: dts: broadcom: bcm4908: Move reboot syscon out of bus
  (bsc#1012628).
- scsi: pm80xx: Fix memory leak during rmmod (bsc#1012628).
- scsi: lpfc: Fix list_add() corruption in lpfc_drain_txq()
  (bsc#1012628).
- ASoC: mediatek: mt8195: Add missing of_node_put() (bsc#1012628).
- arm64: dts: hisilicon: fix arm,sp805 compatible string
  (bsc#1012628).
- RDMA/bnxt_re: Check if the vlan is valid before reporting
  (bsc#1012628).
- bus: ti-sysc: Add quirk handling for reinit on context lost
  (bsc#1012628).
- bus: ti-sysc: Use context lost quirk for otg (bsc#1012628).
- usb: musb: tusb6010: check return value after calling
  platform_get_resource() (bsc#1012628).
- usb: typec: tipd: Remove WARN_ON in tps6598x_block_read
  (bsc#1012628).
- ARM: dts: ux500: Skomer regulator fixes (bsc#1012628).
- staging: rtl8723bs: remove possible deadlock when disconnect
  (v2) (bsc#1012628).
- staging: rtl8723bs: remove a second possible deadlock
  (bsc#1012628).
- staging: rtl8723bs: remove a third possible deadlock
  (bsc#1012628).
- ARM: BCM53016: Specify switch ports for Meraki MR32
  (bsc#1012628).
- arm64: dts: qcom: msm8998: Fix CPU/L2 idle state latency and
  residency (bsc#1012628).
- arm64: dts: qcom: ipq6018: Fix qcom,controlled-remotely property
  (bsc#1012628).
- arm64: dts: qcom: ipq8074: Fix qcom,controlled-remotely property
  (bsc#1012628).
- arm64: dts: qcom: sdm845: Fix qcom,controlled-remotely property
  (bsc#1012628).
- arm64: dts: freescale: fix arm,sp805 compatible string
  (bsc#1012628).
- arm64: dts: ls1012a: Add serial alias for ls1012a-rdb
  (bsc#1012628).
- RDMA/rxe: Separate HW and SW l/rkeys (bsc#1012628).
- ASoC: SOF: Intel: hda-dai: fix potential locking issue
  (bsc#1012628).
- scsi: core: Fix scsi_mode_sense() buffer length handling
  (bsc#1012628).
- ALSA: usb-audio: disable implicit feedback sync for Behringer
  UFX1204 and UFX1604 (bsc#1012628).
- clk: imx: imx6ul: Move csi_sel mux to correct base register
  (bsc#1012628).
- ASoC: es8316: Use IRQF_NO_AUTOEN when requesting the IRQ
  (bsc#1012628).
- ASoC: rt5651: Use IRQF_NO_AUTOEN when requesting the IRQ
  (bsc#1012628).
- ASoC: nau8824: Add DMI quirk mechanism for active-high
  jack-detect (bsc#1012628).
- scsi: advansys: Fix kernel pointer leak (bsc#1012628).
- scsi: smartpqi: Add controller handshake during kdump
  (bsc#1012628).
- arm64: dts: imx8mm-kontron: Fix reset delays for ethernet PHY
  (bsc#1012628).
- ALSA: intel-dsp-config: add quirk for APL/GLK/TGL devices
  based on ES8336 codec (bsc#1012628).
- ASoC: Intel: soc-acpi: add missing quirk for TGL SDCA single
  amp (bsc#1012628).
- ASoC: Intel: sof_sdw: add missing quirk for Dell SKU 0A45
  (bsc#1012628).
- firmware_loader: fix pre-allocated buf built-in firmware use
  (bsc#1012628).
- HID: multitouch: disable sticky fingers for UPERFECT Y
  (bsc#1012628).
- ALSA: usb-audio: Add support for the Pioneer DJM 750MK2
  Mixer/Soundcard (bsc#1012628).
- ARM: dts: omap: fix gpmc,mux-add-data type (bsc#1012628).
- usb: host: ohci-tmio: check return value after calling
  platform_get_resource() (bsc#1012628).
- ASoC: rt5682: fix a little pop while playback (bsc#1012628).
- ARM: dts: ls1021a: move thermal-zones node out of soc/
  (bsc#1012628).
- ARM: dts: ls1021a-tsn: use generic "jedec,spi-nor" compatible
  for flash (bsc#1012628).
- ALSA: ISA: not for M68K (bsc#1012628).
- iommu/vt-d: Do not falsely log intel_iommu is unsupported
  kernel option (bsc#1012628).
- tty: tty_buffer: Fix the softlockup issue in flush_to_ldisc
  (bsc#1012628).
- MIPS: sni: Fix the build (bsc#1012628).
- scsi: scsi_debug: Fix out-of-bound read in resp_readcap16()
  (bsc#1012628).
- scsi: scsi_debug: Fix out-of-bound read in resp_report_tgtpgs()
  (bsc#1012628).
- scsi: target: Fix ordered tag handling (bsc#1012628).
- scsi: target: Fix alua_tg_pt_gps_count tracking (bsc#1012628).
- iio: imu: st_lsm6dsx: Avoid potential array overflow in
  st_lsm6dsx_set_odr() (bsc#1012628).
- RDMA/core: Use kvzalloc when allocating the struct ib_port
  (bsc#1012628).
- scsi: lpfc: Fix use-after-free in lpfc_unreg_rpi() routine
  (bsc#1012628).
- scsi: lpfc: Fix link down processing to address NULL pointer
  dereference (bsc#1012628).
- scsi: lpfc: Allow fabric node recovery if recovery is in
  progress before devloss (bsc#1012628).
- memory: tegra20-emc: Add runtime dependency on devfreq governor
  module (bsc#1012628).
- powerpc/5200: dts: fix memory node unit name (bsc#1012628).
- ARM: dts: qcom: fix memory and mdio nodes naming for RB3011
  (bsc#1012628).
- arm64: dts: qcom: Fix node name of rpm-msg-ram device nodes
  (bsc#1012628).
- ALSA: gus: fix null pointer dereference on pointer block
  (bsc#1012628).
- ALSA: usb-audio: fix null pointer dereference on pointer cs_desc
  (bsc#1012628).
- clk: at91: sama7g5: remove prescaler part of master clock
  (bsc#1012628).
- iommu/dart: Initialize DART_STREAMS_ENABLE (bsc#1012628).
- powerpc/dcr: Use cmplwi instead of 3-argument cmpli
  (bsc#1012628).
- powerpc/8xx: Fix Oops with STRICT_KERNEL_RWX without
  DEBUG_RODATA_TEST (bsc#1012628).
- sh: check return code of request_irq (bsc#1012628).
- maple: fix wrong return value of maple_bus_init() (bsc#1012628).
- f2fs: fix up f2fs_lookup tracepoints (bsc#1012628).
- f2fs: fix to use WHINT_MODE (bsc#1012628).
- f2fs: fix wrong condition to trigger background checkpoint
  correctly (bsc#1012628).
- sh: fix kconfig unmet dependency warning for FRAME_POINTER
  (bsc#1012628).
- sh: math-emu: drop unused functions (bsc#1012628).
- sh: define __BIG_ENDIAN for math-emu (bsc#1012628).
- f2fs: compress: disallow disabling compress on non-empty
  compressed file (bsc#1012628).
- f2fs: fix incorrect return value in f2fs_sanity_check_ckpt()
  (bsc#1012628).
- clk: ingenic: Fix bugs with divided dividers (bsc#1012628).
- clk/ast2600: Fix soc revision for AHB (bsc#1012628).
- clk: qcom: gcc-msm8996: Drop (again) gcc_aggre1_pnoc_ahb_clk
  (bsc#1012628).
- KVM: arm64: Fix host stage-2 finalization (bsc#1012628).
- mips: BCM63XX: ensure that CPU_SUPPORTS_32BIT_KERNEL is set
  (bsc#1012628).
- MIPS: boot/compressed/: add __bswapdi2() to target for ZSTD
  decompression (bsc#1012628).
- sched/core: Mitigate race
  cpus_share_cache()/update_top_cache_domain() (bsc#1012628).
- sched/fair: Prevent dead task groups from regaining cfs_rq's
  (bsc#1012628).
- perf/x86/vlbr: Add c->flags to vlbr event constraints
  (bsc#1012628).
- blkcg: Remove extra blkcg_bio_issue_init (bsc#1012628).
- tracing/histogram: Do not copy the fixed-size char array field
  over the field size (bsc#1012628).
- perf bpf: Avoid memory leak from perf_env__insert_btf()
  (bsc#1012628).
- perf bench futex: Fix memory leak of perf_cpu_map__new()
  (bsc#1012628).
- perf tests: Remove bash construct from
  record+zstd_comp_decomp.sh (bsc#1012628).
- drm/nouveau: hdmigv100.c: fix corrupted HDMI Vendor InfoFrame
  (bsc#1012628).
- bpf: Fix inner map state pruning regression (bsc#1012628).
- samples/bpf: Fix summary per-sec stats in xdp_sample_user
  (bsc#1012628).
- net/ipa: ipa_resource: Fix wrong for loop range (bsc#1012628).
- tcp: Fix uninitialized access in skb frags array for Rx 0cp
  (bsc#1012628).
- tracing: Add length protection to histogram string copies
  (bsc#1012628).
- nl80211: fix radio statistics in survey dump (bsc#1012628).
- mac80211: fix monitor_sdata RCU/locking assertions
  (bsc#1012628).
- net: ipa: HOLB register sometimes must be written twice
  (bsc#1012628).
- net: ipa: disable HOLB drop when updating timer (bsc#1012628).
- selftests: gpio: fix gpio compiling error (bsc#1012628).
- net: bnx2x: fix variable dereferenced before check
  (bsc#1012628).
- bnxt_en: reject indirect blk offload when hw-tc-offload is off
  (bsc#1012628).
- tipc: only accept encrypted MSG_CRYPTO msgs (bsc#1012628).
- sock: fix /proc/net/sockstat underflow in sk_clone_lock()
  (bsc#1012628).
- net/smc: Make sure the link_id is unique (bsc#1012628).
- NFSD: Fix exposure in nfsd4_decode_bitmap() (bsc#1012628).
- iavf: Fix return of set the new channel count (bsc#1012628).
- iavf: check for null in iavf_fix_features (bsc#1012628).
- iavf: free q_vectors before queues in iavf_disable_vf
  (bsc#1012628).
- iavf: don't clear a lock we don't hold (bsc#1012628).
- iavf: Fix failure to exit out from last all-multicast mode
  (bsc#1012628).
- iavf: prevent accidental free of filter structure (bsc#1012628).
- iavf: validate pointers (bsc#1012628).
- iavf: Fix for the false positive ASQ/ARQ errors while issuing
  VF reset (bsc#1012628).
- iavf: Fix for setting queues to 0 (bsc#1012628).
- iavf: Restore VLAN filters after link down (bsc#1012628).
- bpf: Fix toctou on read-only map's constant scalar tracking
  (bsc#1012628).
- MIPS: generic/yamon-dt: fix uninitialized variable error
  (bsc#1012628).
- mips: bcm63xx: add support for clk_get_parent() (bsc#1012628).
- mips: lantiq: add support for clk_get_parent() (bsc#1012628).
- gpio: rockchip: needs GENERIC_IRQ_CHIP to fix build errors
  (bsc#1012628).
- platform/x86: hp_accel: Fix an error handling path in
  'lis3lv02d_probe()' (bsc#1012628).
- platform/x86: think-lmi: Abort probe on analyze failure
  (bsc#1012628).
- udp: Validate checksum in udp_read_sock() (bsc#1012628).
- btrfs: make 1-bit bit-fields of scrub_page unsigned int
  (bsc#1012628).
- RDMA/core: Set send and receive CQ before forwarding to the
  driver (bsc#1012628).
- net/mlx5e: kTLS, Fix crash in RX resync flow (bsc#1012628).
- net/mlx5e: Wait for concurrent flow deletion during neigh/fib
  events (bsc#1012628).
- net/mlx5: E-Switch, Fix resetting of encap mode when entering
  switchdev (bsc#1012628).
- net/mlx5e: nullify cq->dbg pointer in mlx5_debug_cq_remove()
  (bsc#1012628).
- net/mlx5: Update error handler for UCTX and UMEM (bsc#1012628).
- net/mlx5: E-Switch, rebuild lag only when needed (bsc#1012628).
- net/mlx5e: CT, Fix multiple allocations and memleak of mod acts
  (bsc#1012628).
- net/mlx5: Lag, update tracker when state change event received
  (bsc#1012628).
- net/mlx5: E-Switch, return error if encap isn't supported
  (bsc#1012628).
- scsi: ufs: core: Improve SCSI abort handling (bsc#1012628).
- scsi: core: sysfs: Fix hang when device state is set via sysfs
  (bsc#1012628).
- scsi: ufs: core: Fix task management completion timeout race
  (bsc#1012628).
- scsi: ufs: core: Fix another task management completion race
  (bsc#1012628).
- net: mvmdio: fix compilation warning (bsc#1012628).
- net: sched: act_mirred: drop dst for the direction from egress
  to ingress (bsc#1012628).
- net: dpaa2-eth: fix use-after-free in dpaa2_eth_remove
  (bsc#1012628).
- net: virtio_net_hdr_to_skb: count transport header in UFO
  (bsc#1012628).
- i40e: Fix correct max_pkt_size on VF RX queue (bsc#1012628).
- i40e: Fix NULL ptr dereference on VSI filter sync (bsc#1012628).
- i40e: Fix changing previously set num_queue_pairs for PFs
  (bsc#1012628).
- i40e: Fix ping is lost after configuring ADq on VF
  (bsc#1012628).
- RDMA/mlx4: Do not fail the registration on port stats
  (bsc#1012628).
- i40e: Fix warning message and call stack during rmmod i40e
  driver (bsc#1012628).
- i40e: Fix creation of first queue by omitting it if is not
  power of two (bsc#1012628).
- i40e: Fix display error code in dmesg (bsc#1012628).
- NFC: reorganize the functions in nci_request (bsc#1012628).
- NFC: reorder the logic in nfc_{un,}register_device
  (bsc#1012628).
- NFC: add NCI_UNREG flag to eliminate the race (bsc#1012628).
- e100: fix device suspend/resume (bsc#1012628).
- ptp: ocp: Fix a couple NULL vs IS_ERR() checks (bsc#1012628).
- tools build: Fix removal of feature-sync-compare-and-swap
  feature detection (bsc#1012628).
- riscv: fix building external modules (bsc#1012628).
- KVM: PPC: Book3S HV: Use GLOBAL_TOC for
  kvmppc_h_set_dabr/xdabr() (bsc#1012628).
- powerpc: clean vdso32 and vdso64 directories (bsc#1012628).
- powerpc/pseries: rename numa_dist_table to form2_distances
  (bsc#1012628).
- powerpc/pseries: Fix numa FORM2 parsing fallback code
  (bsc#1012628).
- pinctrl: qcom: sdm845: Enable dual edge errata (bsc#1012628).
- pinctrl: qcom: sm8350: Correct UFS and SDC offsets
  (bsc#1012628).
- perf/x86/intel/uncore: Fix filter_tid mask for CHA events on
  Skylake Server (bsc#1012628).
- perf/x86/intel/uncore: Fix IIO event constraints for Skylake
  Server (bsc#1012628).
- perf/x86/intel/uncore: Fix IIO event constraints for Snowridge
  (bsc#1012628).
- s390/kexec: fix return code handling (bsc#1012628).
- blk-cgroup: fix missing put device in error path from
  blkg_conf_pref() (bsc#1012628).
- dmaengine: remove debugfs #ifdef (bsc#1012628).
- tun: fix bonding active backup with arp monitoring
  (bsc#1012628).
- Revert "mark pstore-blk as broken" (bsc#1012628).
- pstore/blk: Use "%%lu" to format unsigned long (bsc#1012628).
- hexagon: export raw I/O routines for modules (bsc#1012628).
- hexagon: clean up timer-regs.h (bsc#1012628).
- tipc: check for null after calling kmemdup (bsc#1012628).
- ipc: WARN if trying to remove ipc object which is absent
  (bsc#1012628).
- shm: extend forced shm destroy to support objects from several
  IPC nses (bsc#1012628).
- mm: kmemleak: slob: respect SLAB_NOLEAKTRACE flag (bsc#1012628).
- hugetlb, userfaultfd: fix reservation restore on userfaultfd
  error (bsc#1012628).
- kmap_local: don't assume kmap PTEs are linear arrays in memory
  (bsc#1012628).
- mm/damon/dbgfs: use '__GFP_NOWARN' for user-specified size
  buffer allocation (bsc#1012628).
- mm/damon/dbgfs: fix missed use of damon_dbgfs_lock
  (bsc#1012628).
- x86/boot: Pull up cmdline preparation and early param parsing
  (bsc#1012628).
- x86/sgx: Fix free page accounting (bsc#1012628).
- x86/hyperv: Fix NULL deref in set_hv_tscchange_cb() if Hyper-V
  setup fails (bsc#1012628).
- KVM: x86: Assume a 64-bit hypercall for guests with protected
  state (bsc#1012628).
- KVM: x86: Fix uninitialized eoi_exit_bitmap usage in
  vcpu_load_eoi_exitmap() (bsc#1012628).
- KVM: x86/mmu: include EFER.LMA in extended mmu role
  (bsc#1012628).
- KVM: x86/xen: Fix get_attr of KVM_XEN_ATTR_TYPE_SHARED_INFO
  (bsc#1012628).
- powerpc/signal32: Fix sigset_t copy (bsc#1012628).
- powerpc/xive: Change IRQ domain to a tree domain (bsc#1012628).
- powerpc/8xx: Fix pinned TLBs with CONFIG_STRICT_KERNEL_RWX
  (bsc#1012628).
- Revert "drm/i915/tgl/dsi: Gate the ddi clocks after pll mapping"
  (bsc#1012628).
- Revert "parisc: Reduce sigreturn trampoline to 3 instructions"
  (bsc#1012628).
- ata: libata: improve ata_read_log_page() error message
  (bsc#1012628).
- ata: libata: add missing ata_identify_page_supported() calls
  (bsc#1012628).
- scsi: qla2xxx: Fix mailbox direction flags in
  qla2xxx_get_adapter_id() (bsc#1012628).
- pinctrl: ralink: include 'ralink_regs.h' in 'pinctrl-mt7620.c'
  (bsc#1012628).
- s390/setup: avoid reserving memory above identity mapping
  (bsc#1012628).
- s390/boot: simplify and fix kernel memory layout setup
  (bsc#1012628).
- s390/vdso: filter out -mstack-guard and -mstack-size
  (bsc#1012628).
- s390/kexec: fix memory leak of ipl report buffer (bsc#1012628).
- s390/dump: fix copying to user-space of swapped kdump oldmem
  (bsc#1012628).
- block: Check ADMIN before NICE for IOPRIO_CLASS_RT
  (bsc#1012628).
- fbdev: Prevent probing generic drivers if a FB is already
  registered (bsc#1012628).
- KVM: SEV: Disallow COPY_ENC_CONTEXT_FROM if target has created
  vCPUs (bsc#1012628).
- KVM: nVMX: don't use vcpu->arch.efer when checking host state
  on nested state load (bsc#1012628).
- drm/cma-helper: Release non-coherent memory with
  dma_free_noncoherent() (bsc#1012628).
- printk: restore flushing of NMI buffers on remote CPUs after
  NMI backtraces (bsc#1012628).
- udf: Fix crash after seekdir (bsc#1012628).
- spi: fix use-after-free of the add_lock mutex (bsc#1012628).
- net: stmmac: socfpga: add runtime suspend/resume callback for
  stratix10 platform (bsc#1012628).
- Drivers: hv: balloon: Use VMBUS_RING_SIZE() wrapper for
  dm_ring_size (bsc#1012628).
- btrfs: fix memory ordering between normal and ordered work
  functions (bsc#1012628).
- fs: handle circular mappings correctly (bsc#1012628).
- net: stmmac: Fix signed/unsigned wreckage (bsc#1012628).
- parisc/sticon: fix reverse colors (bsc#1012628).
- cfg80211: call cfg80211_stop_ap when switch from P2P_GO type
  (bsc#1012628).
- mac80211: fix radiotap header generation (bsc#1012628).
- mac80211: drop check for DONT_REORDER in
  __ieee80211_select_queue (bsc#1012628).
- drm/amd/display: Update swizzle mode enums (bsc#1012628).
- drm/amd/display: Limit max DSC target bpp for specific monitors
  (bsc#1012628).
- drm/i915/guc: Fix outstanding G2H accounting (bsc#1012628).
- drm/i915/guc: Don't enable scheduling on a banned context,
  guc_id invalid, not registered (bsc#1012628).
- drm/i915/guc: Workaround reset G2H is received after schedule
  done G2H (bsc#1012628).
- drm/i915/guc: Don't drop ce->guc_active.lock when unwinding
  context (bsc#1012628).
- drm/i915/guc: Unwind context requests in reverse order
  (bsc#1012628).
- drm/udl: fix control-message timeout (bsc#1012628).
- drm/prime: Fix use after free in mmap with drm_gem_ttm_mmap
  (bsc#1012628).
- drm/nouveau: Add a dedicated mutex for the clients list
  (bsc#1012628).
- drm/nouveau: use drm_dev_unplug() during device removal
  (bsc#1012628).
- drm/nouveau: clean up all clients on device removal
  (bsc#1012628).
- drm/i915/dp: Ensure sink rate values are always valid
  (bsc#1012628).
- drm/i915/dp: Ensure max link params are always valid
  (bsc#1012628).
- drm/i915: Fix type1 DVI DP dual mode adapter heuristic for
  modern platforms (bsc#1012628).
- drm/amdgpu: fix set scaling mode Full/Full aspect/Center not
  works on vga and dvi connectors (bsc#1012628).
- drm/amd/pm: avoid duplicate powergate/ungate setting
  (bsc#1012628).
- signal: Implement force_fatal_sig (bsc#1012628).
- exit/syscall_user_dispatch: Send ordinary signals on failure
  (bsc#1012628).
- signal/powerpc: On swapcontext failure force SIGSEGV
  (bsc#1012628).
- signal/s390: Use force_sigsegv in default_trap_handler
  (bsc#1012628).
- signal/sparc32: Exit with a fatal signal when
  try_to_clear_window_buffer fails (bsc#1012628).
- signal/sparc32: In setup_rt_frame and setup_fram use
  force_fatal_sig (bsc#1012628).
- signal/vm86_32: Properly send SIGSEGV when the vm86 state
  cannot be saved (bsc#1012628).
- signal/x86: In emulate_vsyscall force a signal instead of
  calling do_exit (bsc#1012628).
- signal: Replace force_sigsegv(SIGSEGV) with
  force_fatal_sig(SIGSEGV) (bsc#1012628).
- signal: Don't always set SA_IMMUTABLE for forced signals
  (bsc#1012628).
- signal: Replace force_fatal_sig with force_exit_sig when in
  doubt (bsc#1012628).
- hugetlbfs: flush TLBs correctly after huge_pmd_unshare
  (bsc#1012628).
- RDMA/netlink: Add __maybe_unused to static inline in C file
  (bsc#1012628).
- bpf: Forbid bpf_ktime_get_coarse_ns and bpf_timer_* in tracing
  progs (bsc#1012628).
- selinux: fix NULL-pointer dereference when hashtab allocation
  fails (bsc#1012628).
- ASoC: DAPM: Cover regression by kctl change notification fix
  (bsc#1012628).
- ASoC: rsnd: fixup DMAEngine API (bsc#1012628).
- usb: max-3421: Use driver data instead of maintaining a list
  of bound devices (bsc#1012628).
- ice: Fix VF true promiscuous mode (bsc#1012628).
- ice: Delete always true check of PF pointer (bsc#1012628).
- fs: export an inode_update_time helper (bsc#1012628).
- btrfs: update device path inode time instead of bd_inode
  (bsc#1012628).
- net: add and use skb_unclone_keeptruesize() helper
  (bsc#1012628).
- x86/Kconfig: Fix an unused variable error in dell-smm-hwmon
  (bsc#1012628).
- ALSA: hda: hdac_ext_stream: fix potential locking issues
  (bsc#1012628).
- ALSA: hda: hdac_stream: fix potential locking issue in
  snd_hdac_stream_assign() (bsc#1012628).
- Update config files.
- commit 83fc974
* Tue Nov 23 2021 msuchanek@suse.de
- kernel-source.spec: install-kernel-tools also required on 15.4
- commit 6cefb55
* Mon Nov 22 2021 mkubecek@suse.cz
- config: disable unprivileged BPF by default (jsc#SLE-22573)
  Backport of mainline commit 8a03e56b253e ("bpf: Disallow unprivileged bpf
  by default") only changes kconfig default, used e.g. for "make oldconfig"
  when the config option is missing, but does not update our kernel configs
  used for build. Update also these to make sure unprivileged BPF is really
  disabled by default.
  [ddiss: extend to all tumbleweed kernel configs]
- commit 61d2576
* Mon Nov 22 2021 jslaby@suse.cz
- Linux 5.15.4 (bsc#1012628).
- string: uninline memcpy_and_pad (bsc#1012628).
- Revert "drm: fb_helper: improve CONFIG_FB dependency"
  (bsc#1012628).
- Revert "drm: fb_helper: fix CONFIG_FB dependency" (bsc#1012628).
- btrfs: introduce btrfs_is_data_reloc_root (bsc#1012628).
- btrfs: zoned: add a dedicated data relocation block group
  (bsc#1012628).
- btrfs: zoned: only allow one process to add pages to a
  relocation inode (bsc#1012628).
- btrfs: zoned: use regular writes for relocation (bsc#1012628).
- btrfs: check for relocation inodes on zoned btrfs in
  should_nocow (bsc#1012628).
- btrfs: zoned: allow preallocation for relocation inodes
  (bsc#1012628).
- fortify: Explicitly disable Clang support (bsc#1012628).
- block: Add a helper to validate the block size (bsc#1012628).
- loop: Use blk_validate_block_size() to validate block size
  (bsc#1012628).
- Bluetooth: btusb: Add support for TP-Link UB500 Adapter
  (bsc#1012628).
- parisc/entry: fix trace test in syscall exit path (bsc#1012628).
- PCI/MSI: Deal with devices lying about their MSI mask capability
  (bsc#1012628).
- PCI: Add MSI masking quirk for Nvidia ION AHCI (bsc#1012628).
- perf/core: Avoid put_page() when GUP fails (bsc#1012628).
- thermal: Fix NULL pointer dereferences in of_thermal_ functions
  (bsc#1012628).
- Revert "ACPI: scan: Release PM resources blocked by unused
  objects" (bsc#1012628).
- Update config files.
- commit f51b3ce
* Mon Nov 22 2021 mkubecek@suse.cz
- update to 5.16-rc2
- refresh
  - patches.suse/suse-hv-guest-os-id.patch
- update configs (restore values before 5.14-rc1)
  - PSTORE_ZONE=m
  - PSTORE_BLK=m
  - PSTORE_BLK_BLKDEV=""
  - PSTORE_BLK_KMSG_SIZE=64
  - PSTORE_BLK_MAX_REASON=2
  - MTD_PSTORE=m
- commit 696d453
* Fri Nov 19 2021 jslaby@suse.cz
- blacklist.conf: add one arm64's w/o prerequisites
- commit 404f576
* Fri Nov 19 2021 jslaby@suse.cz
- samples/bpf: Fix incorrect use of strlen in xdp_redirect_cpu
  (git-fixes).
- commit a48a8e6
* Fri Nov 19 2021 jslaby@suse.cz
- selftests: net: switch to socat in the GSO GRE test (git-fixes).
- KVM: Fix steal time asm constraints (git-fixes).
- commit 24aa787
* Thu Nov 18 2021 jslaby@suse.cz
- Linux 5.15.3 (bsc#1012628).
- xhci: Fix USB 3.1 enumeration issues by increasing roothub
  power-on-good delay (bsc#1012628).
- usb: xhci: Enable runtime-pm by default on AMD Yellow Carp
  platform (bsc#1012628).
- Input: iforce - fix control-message timeout (bsc#1012628).
- Input: elantench - fix misreporting trackpoint coordinates
  (bsc#1012628).
- libata: fix read log timeout value (bsc#1012628).
- ocfs2: fix data corruption on truncate (bsc#1012628).
- scsi: scsi_ioctl: Validate command size (bsc#1012628).
- scsi: core: Avoid leaving shost->last_reset with stale value
  if EH does not run (bsc#1012628).
- scsi: core: Remove command size deduction from
  scsi_setup_scsi_cmnd() (bsc#1012628).
- scsi: lpfc: Don't release final kref on Fport node while ABTS
  outstanding (bsc#1012628).
- scsi: lpfc: Fix FCP I/O flush functionality for TMF routines
  (bsc#1012628).
- scsi: qla2xxx: Fix crash in NVMe abort path (bsc#1012628).
- scsi: qla2xxx: Fix kernel crash when accessing port_speed
  sysfs file (bsc#1012628).
- scsi: qla2xxx: Fix use after free in eh_abort path
  (bsc#1012628).
- ce/gf100: fix incorrect CE0 address calculation on some GPUs
  (bsc#1012628).
- char: xillybus: fix msg_ep UAF in xillyusb_probe()
  (bsc#1012628).
- mmc: mtk-sd: Add wait dma stop done flow (bsc#1012628).
- mmc: dw_mmc: Dont wait for DRTO on Write RSP error
  (bsc#1012628).
- exfat: fix incorrect loading of i_blocks for large files
  (bsc#1012628).
- io-wq: remove worker to owner tw dependency (bsc#1012628).
- parisc: Fix set_fixmap() on PA1.x CPUs (bsc#1012628).
- parisc: Fix ptrace check on syscall return (bsc#1012628).
- tpm: Check for integer overflow in tpm2_map_response_body()
  (bsc#1012628).
- firmware/psci: fix application of sizeof to pointer
  (bsc#1012628).
- crypto: s5p-sss - Add error handling in s5p_aes_probe()
  (bsc#1012628).
- media: rkvdec: Do not override sizeimage for output format
  (bsc#1012628).
- media: ite-cir: IR receiver stop working after receive overflow
  (bsc#1012628).
- media: rkvdec: Support dynamic resolution changes (bsc#1012628).
- media: ir-kbd-i2c: improve responsiveness of hauppauge zilog
  receivers (bsc#1012628).
- media: v4l2-ioctl: Fix check_ext_ctrls (bsc#1012628).
- ALSA: hda/realtek: Fix mic mute LED for the HP Spectre x360 14
  (bsc#1012628).
- ALSA: hda/realtek: Add a quirk for HP OMEN 15 mute LED
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Clevo PC70HS (bsc#1012628).
- ALSA: hda/realtek: Headset fixup for Clevo NH77HJQ
  (bsc#1012628).
- ALSA: hda/realtek: Add a quirk for Acer Spin SP513-54N
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for ASUS UX550VE (bsc#1012628).
- ALSA: hda/realtek: Add quirk for HP EliteBook 840 G7 mute LED
  (bsc#1012628).
- ALSA: ua101: fix division by zero at probe (bsc#1012628).
- ALSA: 6fire: fix control and bulk message timeouts
  (bsc#1012628).
- ALSA: line6: fix control and interrupt message timeouts
  (bsc#1012628).
- ALSA: mixer: oss: Fix racy access to slots (bsc#1012628).
- ALSA: mixer: fix deadlock in snd_mixer_oss_set_volume
  (bsc#1012628).
- ALSA: usb-audio: Line6 HX-Stomp XL USB_ID for 48k-fixed quirk
  (bsc#1012628).
- ALSA: usb-audio: Add registration quirk for JBL Quantum 400
  (bsc#1012628).
- ALSA: hda: Free card instance properly at probe errors
  (bsc#1012628).
- ALSA: synth: missing check for possible NULL after the call
  to kstrdup (bsc#1012628).
- ALSA: pci: rme: Fix unaligned buffer addresses (bsc#1012628).
- ALSA: PCM: Fix NULL dereference at mmap checks (bsc#1012628).
- ALSA: timer: Fix use-after-free problem (bsc#1012628).
- ALSA: timer: Unconditionally unlink slave instances, too
  (bsc#1012628).
- Revert "ext4: enforce buffer head state assertion in
  ext4_da_map_blocks" (bsc#1012628).
- ext4: fix lazy initialization next schedule time computation
  in more granular unit (bsc#1012628).
- ext4: ensure enough credits in ext4_ext_shift_path_extents
  (bsc#1012628).
- ext4: refresh the ext4_ext_path struct after dropping i_data_sem
  (bsc#1012628).
- fuse: fix page stealing (bsc#1012628).
- x86/sme: Use #define USE_EARLY_PGTABLE_L5 in
  mem_encrypt_identity.c (bsc#1012628).
- x86/cpu: Fix migration safety with X86_BUG_NULL_SEL
  (bsc#1012628).
- x86/irq: Ensure PI wakeup handler is unregistered before module
  unload (bsc#1012628).
- x86/iopl: Fake iopl(3) CLI/STI usage (bsc#1012628).
- btrfs: clear MISSING device status bit in btrfs_close_one_device
  (bsc#1012628).
- btrfs: fix lost error handling when replaying directory deletes
  (bsc#1012628).
- btrfs: call btrfs_check_rw_degradable only if there is a
  missing device (bsc#1012628).
- KVM: x86/mmu: Drop a redundant, broken remote TLB flush
  (bsc#1012628).
- KVM: VMX: Unregister posted interrupt wakeup handler on hardware
  unsetup (bsc#1012628).
- KVM: PPC: Tick accounting should defer vtime accounting 'til
  after IRQ handling (bsc#1012628).
- ia64: kprobes: Fix to pass correct trampoline address to the
  handler (bsc#1012628).
- selinux: fix race condition when computing ocontext SIDs
  (bsc#1012628).
- ipmi:watchdog: Set panic count to proper value on a panic
  (bsc#1012628).
- md/raid1: only allocate write behind bio for WriteMostly device
  (bsc#1012628).
- hwmon: (pmbus/lm25066) Add offset coefficients (bsc#1012628).
- regulator: s5m8767: do not use reset value as DVS voltage if
  GPIO DVS is disabled (bsc#1012628).
- regulator: dt-bindings: samsung,s5m8767: correct
  s5m8767,pmic-buck-default-dvs-idx property (bsc#1012628).
- EDAC/sb_edac: Fix top-of-high-memory value for Broadwell/Haswell
  (bsc#1012628).
- mwifiex: fix division by zero in fw download path (bsc#1012628).
- ath6kl: fix division by zero in send path (bsc#1012628).
- ath6kl: fix control-message timeout (bsc#1012628).
- ath10k: fix control-message timeout (bsc#1012628).
- ath10k: fix division by zero in send path (bsc#1012628).
- PCI: Mark Atheros QCA6174 to avoid bus reset (bsc#1012628).
- rtl8187: fix control-message timeouts (bsc#1012628).
- evm: mark evm_fixmode as __ro_after_init (bsc#1012628).
- ifb: Depend on netfilter alternatively to tc (bsc#1012628).
- platform/surface: aggregator_registry: Add support for Surface
  Laptop Studio (bsc#1012628).
- mt76: mt7615: fix skb use-after-free on mac reset (bsc#1012628).
- HID: surface-hid: Use correct event registry for managing HID
  events (bsc#1012628).
- HID: surface-hid: Allow driver matching for target ID 1 devices
  (bsc#1012628).
- wcn36xx: Fix HT40 capability for 2Ghz band (bsc#1012628).
- wcn36xx: Fix tx_status mechanism (bsc#1012628).
- wcn36xx: Fix (QoS) null data frame bitrate/modulation
  (bsc#1012628).
- PM: sleep: Do not let "syscore" devices runtime-suspend during
  system transitions (bsc#1012628).
- mwifiex: Read a PCI register after writing the TX ring write
  pointer (bsc#1012628).
- mwifiex: Try waking the firmware until we get an interrupt
  (bsc#1012628).
- libata: fix checking of DMA state (bsc#1012628).
- dma-buf: fix and rework dma_buf_poll v7 (bsc#1012628).
- wcn36xx: handle connection loss indication (bsc#1012628).
- rsi: fix occasional initialisation failure with BT coex
  (bsc#1012628).
- rsi: fix key enabled check causing unwanted encryption for
  vap_id > 0 (bsc#1012628).
- rsi: fix rate mask set leading to P2P failure (bsc#1012628).
- rsi: Fix module dev_oper_mode parameter description
  (bsc#1012628).
- perf/x86/intel/uncore: Support extra IMC channel on Ice Lake
  server (bsc#1012628).
- perf/x86/intel/uncore: Fix invalid unit check (bsc#1012628).
- perf/x86/intel/uncore: Fix Intel ICX IIO event constraints
  (bsc#1012628).
- RDMA/qedr: Fix NULL deref for query_qp on the GSI QP
  (bsc#1012628).
- ASoC: tegra: Set default card name for Trimslice (bsc#1012628).
- ASoC: tegra: Restore AC97 support (bsc#1012628).
- signal: Remove the bogus sigkill_pending in ptrace_stop
  (bsc#1012628).
- memory: renesas-rpc-if: Correct QSPI data transfer in Manual
  mode (bsc#1012628).
- signal/mips: Update (_save|_restore)_fp_context to fail with
  - EFAULT (bsc#1012628).
- signal: Add SA_IMMUTABLE to ensure forced siganls do not get
  changed (bsc#1012628).
- soc: samsung: exynos-pmu: Fix compilation when nothing selects
  CONFIG_MFD_CORE (bsc#1012628).
- soc: fsl: dpio: replace smp_processor_id with
  raw_smp_processor_id (bsc#1012628).
- soc: fsl: dpio: use the combined functions to protect critical
  zone (bsc#1012628).
- mtd: rawnand: socrates: Keep the driver compatible with on-die
  ECC engines (bsc#1012628).
- mctp: handle the struct sockaddr_mctp padding fields
  (bsc#1012628).
- power: supply: max17042_battery: Prevent int underflow in
  set_soc_threshold (bsc#1012628).
- power: supply: max17042_battery: use VFSOC for capacity when
  no rsns (bsc#1012628).
- iio: core: fix double free in iio_device_unregister_sysfs()
  (bsc#1012628).
- iio: core: check return value when calling dev_set_name()
  (bsc#1012628).
- KVM: arm64: Extract ESR_ELx.EC only (bsc#1012628).
- KVM: x86: Fix recording of guest steal time / preempted status
  (bsc#1012628).
- KVM: x86: Add helper to consolidate core logic of SET_CPUID{2}
  flows (bsc#1012628).
- KVM: nVMX: Query current VMCS when determining if MSR bitmaps
  are in use (bsc#1012628).
- KVM: nVMX: Handle dynamic MSR intercept toggling (bsc#1012628).
- can: peak_usb: always ask for BERR reporting for PCAN-USB
  devices (bsc#1012628).
- can: mcp251xfd: mcp251xfd_irq(): add missing
  can_rx_offload_threaded_irq_finish() in case of bus off
  (bsc#1012628).
- can: j1939: j1939_tp_cmd_recv(): ignore abort message in the
  BAM transport (bsc#1012628).
- can: j1939: j1939_can_recv(): ignore messages with invalid
  source address (bsc#1012628).
- can: j1939: j1939_tp_cmd_recv(): check the dst address of
  TP.CM_BAM (bsc#1012628).
- iio: adc: tsc2046: fix scan interval warning (bsc#1012628).
- powerpc/85xx: Fix oops when mpc85xx_smp_guts_ids node cannot
  be found (bsc#1012628).
- io_uring: honour zeroes as io-wq worker limits (bsc#1012628).
- ring-buffer: Protect ring_buffer_reset() from reentrancy
  (bsc#1012628).
- serial: core: Fix initializing and restoring termios speed
  (bsc#1012628).
- ifb: fix building without CONFIG_NET_CLS_ACT (bsc#1012628).
- xen/balloon: add late_initcall_sync() for initial ballooning
  done (bsc#1012628).
- ovl: fix use after free in struct ovl_aio_req (bsc#1012628).
- ovl: fix filattr copy-up failure (bsc#1012628).
- PCI: pci-bridge-emul: Fix emulation of W1C bits (bsc#1012628).
- PCI: cadence: Add cdns_plat_pcie_probe() missing return
  (bsc#1012628).
- cxl/pci: Fix NULL vs ERR_PTR confusion (bsc#1012628).
- PCI: aardvark: Do not clear status bits of masked interrupts
  (bsc#1012628).
- PCI: aardvark: Fix checking for link up via LTSSM state
  (bsc#1012628).
- PCI: aardvark: Do not unmask unused interrupts (bsc#1012628).
- PCI: aardvark: Fix reporting Data Link Layer Link Active
  (bsc#1012628).
- PCI: aardvark: Fix configuring Reference clock (bsc#1012628).
- PCI: aardvark: Fix return value of MSI domain .alloc() method
  (bsc#1012628).
- PCI: aardvark: Read all 16-bits from PCIE_MSI_PAYLOAD_REG
  (bsc#1012628).
- PCI: aardvark: Fix support for bus mastering and PCI_COMMAND
  on emulated bridge (bsc#1012628).
- PCI: aardvark: Fix support for PCI_BRIDGE_CTL_BUS_RESET on
  emulated bridge (bsc#1012628).
- PCI: aardvark: Set PCI Bridge Class Code to PCI Bridge
  (bsc#1012628).
- PCI: aardvark: Fix support for PCI_ROM_ADDRESS1 on emulated
  bridge (bsc#1012628).
- quota: check block number when reading the block in quota file
  (bsc#1012628).
- quota: correct error number in free_dqentry() (bsc#1012628).
- cifs: To match file servers, make sure the server hostname
  matches (bsc#1012628).
- cifs: set a minimum of 120s for next dns resolution
  (bsc#1012628).
- mfd: simple-mfd-i2c: Select MFD_CORE to fix build error
  (bsc#1012628).
- pinctrl: core: fix possible memory leak in pinctrl_enable()
  (bsc#1012628).
- coresight: cti: Correct the parameter for pm_runtime_put
  (bsc#1012628).
- coresight: trbe: Fix incorrect access of the sink specific data
  (bsc#1012628).
- coresight: trbe: Defer the probe on offline CPUs (bsc#1012628).
- iio: buffer: check return value of kstrdup_const()
  (bsc#1012628).
- iio: buffer: Fix memory leak in
  iio_buffers_alloc_sysfs_and_mask() (bsc#1012628).
- iio: buffer: Fix memory leak in
  __iio_buffer_alloc_sysfs_and_mask() (bsc#1012628).
- iio: buffer: Fix memory leak in
  iio_buffer_register_legacy_sysfs_groups() (bsc#1012628).
- drivers: iio: dac: ad5766: Fix dt property name (bsc#1012628).
- iio: dac: ad5446: Fix ad5622_write() return value (bsc#1012628).
- iio: ad5770r: make devicetree property reading consistent
  (bsc#1012628).
- Documentation:devicetree:bindings:iio:dac: Fix val
  (bsc#1012628).
- USB: serial: keyspan: fix memleak on probe errors (bsc#1012628).
- serial: 8250: fix racy uartclk update (bsc#1012628).
- ksmbd: set unique value to volume serial field in
  FS_VOLUME_INFORMATION (bsc#1012628).
- io-wq: serialize hash clear with wakeup (bsc#1012628).
- serial: 8250: Fix reporting real baudrate value in c_ospeed
  field (bsc#1012628).
- Revert "serial: 8250: Fix reporting real baudrate value in
  c_ospeed field" (bsc#1012628).
- most: fix control-message timeouts (bsc#1012628).
- USB: iowarrior: fix control-message timeouts (bsc#1012628).
- USB: chipidea: fix interrupt deadlock (bsc#1012628).
- power: supply: max17042_battery: Clear status bits in interrupt
  handler (bsc#1012628).
- component: do not leave master devres group open after bind
  (bsc#1012628).
- dma-buf: WARN on dmabuf release with pending attachments
  (bsc#1012628).
- drm: panel-orientation-quirks: Update the Lenovo Ideapad D330
  quirk (v2) (bsc#1012628).
- drm: panel-orientation-quirks: Add quirk for KD Kurio Smart
  C15200 2-in-1 (bsc#1012628).
- drm: panel-orientation-quirks: Add quirk for the Samsung Galaxy
  Book 10.6 (bsc#1012628).
- Bluetooth: fix use-after-free error in lock_sock_nested()
  (bsc#1012628).
- Bluetooth: call sock_hold earlier in sco_conn_del (bsc#1012628).
- drm/panel-orientation-quirks: add Valve Steam Deck
  (bsc#1012628).
- rcutorture: Avoid problematic critical section nesting on
  PREEMPT_RT (bsc#1012628).
- platform/x86: wmi: do not fail if disabling fails (bsc#1012628).
- drm/amdgpu: move iommu_resume before ip init/resume
  (bsc#1012628).
- MIPS: lantiq: dma: add small delay after reset (bsc#1012628).
- MIPS: lantiq: dma: reset correct number of channel
  (bsc#1012628).
- locking/lockdep: Avoid RCU-induced noinstr fail (bsc#1012628).
- net: sched: update default qdisc visibility after Tx queue
  cnt changes (bsc#1012628).
- ACPI: resources: Add DMI-based legacy IRQ override quirk
  (bsc#1012628).
- rcu-tasks: Move RTGS_WAIT_CBS to beginning of
  rcu_tasks_kthread() loop (bsc#1012628).
- smackfs: Fix use-after-free in netlbl_catmap_walk()
  (bsc#1012628).
- ath11k: Align bss_chan_info structure with firmware
  (bsc#1012628).
- crypto: aesni - check walk.nbytes instead of err (bsc#1012628).
- x86/mm/64: Improve stack overflow warnings (bsc#1012628).
- x86: Increase exception stack sizes (bsc#1012628).
- mwifiex: Run SET_BSS_MODE when changing from P2P to STATION
  vif-type (bsc#1012628).
- mwifiex: Properly initialize private structure on interface
  type changes (bsc#1012628).
- spi: Check we have a spi_device_id for each DT compatible
  (bsc#1012628).
- fscrypt: allow 256-bit master keys with AES-256-XTS
  (bsc#1012628).
- drm/amdgpu: Fix MMIO access page fault (bsc#1012628).
- drm/amd/display: Fix null pointer dereference for encoders
  (bsc#1012628).
- selftests: net: fib_nexthops: Wait before checking reported
  idle time (bsc#1012628).
- ath11k: Avoid reg rules update during firmware recovery
  (bsc#1012628).
- ath11k: add handler for scan event WMI_SCAN_EVENT_DEQUEUED
  (bsc#1012628).
- ath11k: Change DMA_FROM_DEVICE to DMA_TO_DEVICE when map
  reinjected packets (bsc#1012628).
- ath10k: high latency fixes for beacon buffer (bsc#1012628).
- octeontx2-pf: Enable promisc/allmulti match MCAM entries
  (bsc#1012628).
- media: mt9p031: Fix corrupted frame after restarting stream
  (bsc#1012628).
- media: netup_unidvb: handle interrupt properly according to
  the firmware (bsc#1012628).
- media: atomisp: Fix error handling in probe (bsc#1012628).
- media: stm32: Potential NULL pointer dereference in
  dcmi_irq_thread() (bsc#1012628).
- media: uvcvideo: Set capability in s_param (bsc#1012628).
- media: uvcvideo: Return -EIO for control errors (bsc#1012628).
- media: uvcvideo: Set unique vdev name based in type
  (bsc#1012628).
- media: vidtv: Fix memory leak in remove (bsc#1012628).
- media: s5p-mfc: fix possible null-pointer dereference in
  s5p_mfc_probe() (bsc#1012628).
- media: s5p-mfc: Add checking to s5p_mfc_probe() (bsc#1012628).
- media: videobuf2: rework vb2_mem_ops API (bsc#1012628).
- media: imx: set a media_device bus_info string (bsc#1012628).
- media: rcar-vin: Use user provided buffers when starting
  (bsc#1012628).
- media: mceusb: return without resubmitting URB in case of
  - EPROTO error (bsc#1012628).
- ia64: don't do IA64_CMPXCHG_DEBUG without CONFIG_PRINTK
  (bsc#1012628).
- rtw88: fix RX clock gate setting while fifo dump (bsc#1012628).
- brcmfmac: Add DMI nvram filename quirk for Cyberbook T116 tablet
  (bsc#1012628).
- media: rcar-csi2: Add checking to rcsi2_start_receiver()
  (bsc#1012628).
- ipmi: Disable some operations during a panic (bsc#1012628).
- fs/proc/uptime.c: Fix idle time reporting in /proc/uptime
  (bsc#1012628).
- kselftests/sched: cleanup the child processes (bsc#1012628).
- ACPICA: Avoid evaluating methods too early during system resume
  (bsc#1012628).
- cpufreq: Make policy min/max hard requirements (bsc#1012628).
- ice: Move devlink port to PF/VF struct (bsc#1012628).
- media: imx-jpeg: Fix possible null pointer dereference
  (bsc#1012628).
- media: ipu3-imgu: imgu_fmt: Handle properly try (bsc#1012628).
- media: ipu3-imgu: VIDIOC_QUERYCAP: Fix bus_info (bsc#1012628).
- media: usb: dvd-usb: fix uninit-value bug in
  dibusb_read_eeprom_byte() (bsc#1012628).
- net-sysfs: try not to restart the syscall if it will fail
  eventually (bsc#1012628).
- drm/amdkfd: rm BO resv on validation to avoid deadlock
  (bsc#1012628).
- tracefs: Have tracefs directories not set OTH permission bits
  by default (bsc#1012628).
- tracing: Disable "other" permission bits in the tracefs files
  (bsc#1012628).
- ath: dfs_pattern_detector: Fix possible null-pointer dereference
  in channel_detector_create() (bsc#1012628).
- KVM: arm64: Propagate errors from __pkvm_prot_finalize hypercall
  (bsc#1012628).
- mmc: moxart: Fix reference count leaks in moxart_probe
  (bsc#1012628).
- iov_iter: Fix iov_iter_get_pages{,_alloc} page fault return
  value (bsc#1012628).
- ACPI: battery: Accept charges over the design capacity as full
  (bsc#1012628).
- ACPI: scan: Release PM resources blocked by unused objects
  (bsc#1012628).
- drm/amd/display: fix null pointer deref when plugging in display
  (bsc#1012628).
- drm/amdkfd: fix resume error when iommu disabled in Picasso
  (bsc#1012628).
- net: phy: micrel: make *-skew-ps check more lenient
  (bsc#1012628).
- leaking_addresses: Always print a trailing newline
  (bsc#1012628).
- thermal/core: Fix null pointer dereference in thermal_release()
  (bsc#1012628).
- drm/msm: prevent NULL dereference in
  msm_gpu_crashstate_capture() (bsc#1012628).
- thermal/drivers/tsens: Add timeout to get_temp_tsens_valid
  (bsc#1012628).
- block: bump max plugged deferred size from 16 to 32
  (bsc#1012628).
- floppy: fix calling platform_device_unregister() on invalid
  drives (bsc#1012628).
- md: update superblock after changing rdev flags in state_store
  (bsc#1012628).
- memstick: r592: Fix a UAF bug when removing the driver
  (bsc#1012628).
- locking/rwsem: Disable preemption for spinning region
  (bsc#1012628).
- lib/xz: Avoid overlapping memcpy() with invalid input with
  in-place decompression (bsc#1012628).
- lib/xz: Validate the value before assigning it to an enum
  variable (bsc#1012628).
- workqueue: make sysfs of unbound kworker cpumask more clever
  (bsc#1012628).
- tracing/cfi: Fix cmp_entries_* functions signature mismatch
  (bsc#1012628).
- mt76: mt7915: fix an off-by-one bound check (bsc#1012628).
- mwl8k: Fix use-after-free in mwl8k_fw_state_machine()
  (bsc#1012628).
- iwlwifi: change all JnP to NO-160 configuration (bsc#1012628).
- block: remove inaccurate requeue check (bsc#1012628).
- media: allegro: ignore interrupt if mailbox is not initialized
  (bsc#1012628).
- drm/amdgpu/pm: properly handle sclk for profiling modes on
  vangogh (bsc#1012628).
- nvmet: fix use-after-free when a port is removed (bsc#1012628).
- nvmet-rdma: fix use-after-free when a port is removed
  (bsc#1012628).
- nvmet-tcp: fix use-after-free when a port is removed
  (bsc#1012628).
- nvme: drop scan_lock and always kick requeue list when removing
  namespaces (bsc#1012628).
- samples/bpf: Fix application of sizeof to pointer (bsc#1012628).
- arm64: vdso32: suppress error message for 'make mrproper'
  (bsc#1012628).
- PM: hibernate: Get block device exclusively in swsusp_check()
  (bsc#1012628).
- selftests: kvm: fix mismatched fclose() after popen()
  (bsc#1012628).
- selftests/bpf: Fix perf_buffer test on system with offline cpus
  (bsc#1012628).
- iwlwifi: mvm: disable RX-diversity in powersave (bsc#1012628).
- smackfs: use __GFP_NOFAIL for smk_cipso_doi() (bsc#1012628).
- ARM: clang: Do not rely on lr register for stacktrace
  (bsc#1012628).
- gre/sit: Don't generate link-local addr if addr_gen_mode is
  IN6_ADDR_GEN_MODE_NONE (bsc#1012628).
- can: bittiming: can_fixup_bittiming(): change type of tseg1
  and alltseg to unsigned int (bsc#1012628).
- gfs2: Cancel remote delete work asynchronously (bsc#1012628).
- gfs2: Fix glock_hash_walk bugs (bsc#1012628).
- ARM: 9136/1: ARMv7-M uses BE-8, not BE-32 (bsc#1012628).
- tools/latency-collector: Use correct size when writing
  queue_full_warning (bsc#1012628).
- vrf: run conntrack only in context of lower/physdev for locally
  generated packets (bsc#1012628).
- net: annotate data-race in neigh_output() (bsc#1012628).
- ACPI: AC: Quirk GK45 to skip reading _PSR (bsc#1012628).
- ACPI: resources: Add one more Medion model in IRQ override quirk
  (bsc#1012628).
- btrfs: reflink: initialize return value to 0 in
  btrfs_extent_same() (bsc#1012628).
- btrfs: do not take the uuid_mutex in btrfs_rm_device
  (bsc#1012628).
- spi: bcm-qspi: Fix missing clk_disable_unprepare() on error
  in bcm_qspi_probe() (bsc#1012628).
- wcn36xx: Correct band/freq reporting on RX (bsc#1012628).
- wcn36xx: Fix packet drop on resume (bsc#1012628).
- Revert "wcn36xx: Enable firmware link monitoring" (bsc#1012628).
- ftrace: do CPU checking after preemption disabled (bsc#1012628).
- inet: remove races in inet{6}_getname() (bsc#1012628).
- x86/hyperv: Protect set_hv_tscchange_cb() against getting
  preempted (bsc#1012628).
- drm/amd/display: dcn20_resource_construct reduce scope of FPU
  enabled (bsc#1012628).
- selftests/core: fix conflicting types compile error for
  close_range() (bsc#1012628).
- perf/x86/intel: Fix ICL/SPR INST_RETIRED.PREC_DIST encodings
  (bsc#1012628).
- parisc: fix warning in flush_tlb_all (bsc#1012628).
- task_stack: Fix end_of_stack() for architectures with
  upwards-growing stack (bsc#1012628).
- erofs: don't trigger WARN() when decompression fails
  (bsc#1012628).
- parisc/unwind: fix unwinder when CONFIG_64BIT is enabled
  (bsc#1012628).
- parisc/kgdb: add kgdb_roundup() to make kgdb work with idle
  polling (bsc#1012628).
- netfilter: conntrack: set on IPS_ASSURED if flows enters
  internal stream state (bsc#1012628).
- selftests/bpf: Fix strobemeta selftest regression (bsc#1012628).
- fbdev/efifb: Release PCI device's runtime PM ref during FB
  destroy (bsc#1012628).
- drm/bridge: anx7625: Propagate errors from sp_tx_rst_aux()
  (bsc#1012628).
- perf/x86/intel/uncore: Fix Intel SPR CHA event constraints
  (bsc#1012628).
- perf/x86/intel/uncore: Fix Intel SPR IIO event constraints
  (bsc#1012628).
- perf/x86/intel/uncore: Fix Intel SPR M2PCIE event constraints
  (bsc#1012628).
- perf/x86/intel/uncore: Fix Intel SPR M3UPI event constraints
  (bsc#1012628).
- drm/bridge: it66121: Initialize {device,vendor}_ids
  (bsc#1012628).
- drm/bridge: it66121: Wait for next bridge to be probed
  (bsc#1012628).
- Bluetooth: fix init and cleanup of sco_conn.timeout_work
  (bsc#1012628).
- libbpf: Don't crash on object files with no symbol tables
  (bsc#1012628).
- Bluetooth: hci_uart: fix GPF in h5_recv (bsc#1012628).
- rcu: Fix existing exp request check in
  sync_sched_exp_online_cleanup() (bsc#1012628).
- MIPS: lantiq: dma: fix burst length for DEU (bsc#1012628).
- x86/xen: Mark cpu_bringup_and_idle() as dead_end_function
  (bsc#1012628).
- objtool: Handle __sanitize_cov*() tail calls (bsc#1012628).
- net/mlx5: Publish and unpublish all devlink parameters at once
  (bsc#1012628).
- drm/v3d: fix wait for TMU write combiner flush (bsc#1012628).
- crypto: sm4 - Do not change section of ck and sbox
  (bsc#1012628).
- virtio-gpu: fix possible memory allocation failure
  (bsc#1012628).
- lockdep: Let lock_is_held_type() detect recursive read as read
  (bsc#1012628).
- net: net_namespace: Fix undefined member in key_remove_domain()
  (bsc#1012628).
- net: phylink: don't call netif_carrier_off() with NULL netdev
  (bsc#1012628).
- drm: bridge: it66121: Fix return value it66121_probe
  (bsc#1012628).
- spi: Fixed division by zero warning (bsc#1012628).
- cgroup: Make rebind_subsystems() disable v2 controllers all
  at once (bsc#1012628).
- wcn36xx: Fix Antenna Diversity Switching (bsc#1012628).
- wilc1000: fix possible memory leak in cfg_scan_result()
  (bsc#1012628).
- Bluetooth: btmtkuart: fix a memleak in mtk_hci_wmt_sync
  (bsc#1012628).
- drm/amdgpu: Fix crash on device remove/driver unload
  (bsc#1012628).
- drm/amd/display: Pass display_pipe_params_st as const in DML
  (bsc#1012628).
- drm/amdgpu: move amdgpu_virt_release_full_gpu to fini_early
  stage (bsc#1012628).
- crypto: caam - disable pkc for non-E SoCs (bsc#1012628).
- crypto: qat - power up 4xxx device (bsc#1012628).
- Bluetooth: hci_h5: Fix (runtime)suspend issues on RTL8723BS HCIs
  (bsc#1012628).
- bnxt_en: Check devlink allocation and registration status
  (bsc#1012628).
- qed: Don't ignore devlink allocation failures (bsc#1012628).
- rxrpc: Fix _usecs_to_jiffies() by using usecs_to_jiffies()
  (bsc#1012628).
- mptcp: do not shrink snd_nxt when recovering (bsc#1012628).
- fortify: Fix dropped strcpy() compile-time write overflow check
  (bsc#1012628).
- mac80211: twt: don't use potentially unaligned pointer
  (bsc#1012628).
- cfg80211: always free wiphy specific regdomain (bsc#1012628).
- net/mlx5: Accept devlink user input after driver initialization
  complete (bsc#1012628).
- net: dsa: rtl8366rb: Fix off-by-one bug (bsc#1012628).
- net: dsa: rtl8366: Fix a bug in deleting VLANs (bsc#1012628).
- bpf/tests: Fix error in tail call limit tests (bsc#1012628).
- ath11k: fix some sleeping in atomic bugs (bsc#1012628).
- ath11k: Avoid race during regd updates (bsc#1012628).
- ath11k: fix packet drops due to incorrect 6 GHz freq value in
  rx status (bsc#1012628).
- ath11k: Fix memory leak in ath11k_qmi_driver_event_work
  (bsc#1012628).
- gve: DQO: avoid unused variable warnings (bsc#1012628).
- ath10k: Fix missing frame timestamp for beacon/probe-resp
  (bsc#1012628).
- ath10k: sdio: Add missing BH locking around napi_schdule()
  (bsc#1012628).
- drm/ttm: stop calling tt_swapin in vm_access (bsc#1012628).
- arm64: mm: update max_pfn after memory hotplug (bsc#1012628).
- drm/amdgpu: fix warning for overflow check (bsc#1012628).
- libbpf: Fix skel_internal.h to set errno on loader retval <
  0 (bsc#1012628).
- media: em28xx: add missing em28xx_close_extension (bsc#1012628).
- media: meson-ge2d: Fix rotation parameter changes detection in
  'ge2d_s_ctrl()' (bsc#1012628).
- media: cxd2880-spi: Fix a null pointer dereference on error
  handling path (bsc#1012628).
- media: ttusb-dec: avoid release of non-acquired mutex
  (bsc#1012628).
- media: dvb-usb: fix ununit-value in az6027_rc_query
  (bsc#1012628).
- media: imx258: Fix getting clock frequency (bsc#1012628).
- media: v4l2-ioctl: S_CTRL output the right value (bsc#1012628).
- media: mtk-vcodec: venc: fix return value when start_streaming
  fails (bsc#1012628).
- media: TDA1997x: handle short reads of hdmi info frame
  (bsc#1012628).
- media: mtk-vpu: Fix a resource leak in the error handling path
  of 'mtk_vpu_probe()' (bsc#1012628).
- media: imx-jpeg: Fix the error handling path of
  'mxc_jpeg_probe()' (bsc#1012628).
- media: i2c: ths8200 needs V4L2_ASYNC (bsc#1012628).
- media: sun6i-csi: Allow the video device to be open multiple
  times (bsc#1012628).
- media: radio-wl1273: Avoid card name truncation (bsc#1012628).
- media: si470x: Avoid card name truncation (bsc#1012628).
- media: tm6000: Avoid card name truncation (bsc#1012628).
- media: cx23885: Fix snd_card_free call on null card pointer
  (bsc#1012628).
- media: atmel: fix the ispck initialization (bsc#1012628).
- scs: Release kasan vmalloc poison in scs_free process
  (bsc#1012628).
- kprobes: Do not use local variable when creating debugfs file
  (bsc#1012628).
- crypto: ecc - fix CRYPTO_DEFAULT_RNG dependency (bsc#1012628).
- drm: fb_helper: fix CONFIG_FB dependency (bsc#1012628).
- cpuidle: Fix kobject memory leaks in error paths (bsc#1012628).
- media: em28xx: Don't use ops->suspend if it is NULL
  (bsc#1012628).
- ath10k: Don't always treat modem stop events as crashes
  (bsc#1012628).
- ath9k: Fix potential interrupt storm on queue reset
  (bsc#1012628).
- PM: EM: Fix inefficient states detection (bsc#1012628).
- x86/insn: Use get_unaligned() instead of memcpy() (bsc#1012628).
- EDAC/amd64: Handle three rank interleaving mode (bsc#1012628).
- rcu: Always inline rcu_dynticks_task*_{enter,exit}()
  (bsc#1012628).
- rcu: Fix rcu_dynticks_curr_cpu_in_eqs() vs noinstr
  (bsc#1012628).
- netfilter: nft_dynset: relax superfluous check on set updates
  (bsc#1012628).
- media: venus: fix vpp frequency calculation for decoder
  (bsc#1012628).
- media: dvb-frontends: mn88443x: Handle errors of
  clk_prepare_enable() (bsc#1012628).
- crypto: ccree - avoid out-of-range warnings from clang
  (bsc#1012628).
- crypto: qat - detect PFVF collision after ACK (bsc#1012628).
- crypto: qat - disregard spurious PFVF interrupts (bsc#1012628).
- hwrng: mtk - Force runtime pm ops for sleep ops (bsc#1012628).
- ima: fix deadlock when traversing "ima_default_rules"
  (bsc#1012628).
- b43legacy: fix a lower bounds test (bsc#1012628).
- b43: fix a lower bounds test (bsc#1012628).
- gve: Recover from queue stall due to missed IRQ (bsc#1012628).
- gve: Track RX buffer allocation failures (bsc#1012628).
- mmc: sdhci-omap: Fix NULL pointer exception if regulator is
  not configured (bsc#1012628).
- mmc: sdhci-omap: Fix context restore (bsc#1012628).
- memstick: avoid out-of-range warning (bsc#1012628).
- memstick: jmb38x_ms: use appropriate free function in
  jmb38x_ms_alloc_host() (bsc#1012628).
- net, neigh: Fix NTF_EXT_LEARNED in combination with NTF_USE
  (bsc#1012628).
- hwmon: Fix possible memleak in __hwmon_device_register()
  (bsc#1012628).
- hwmon: (pmbus/lm25066) Let compiler determine outer dimension
  of lm25066_coeff (bsc#1012628).
- ath10k: fix max antenna gain unit (bsc#1012628).
- kernel/sched: Fix sched_fork() access an invalid
  sched_task_group (bsc#1012628).
- net: fealnx: fix build for UML (bsc#1012628).
- net: intel: igc_ptp: fix build for UML (bsc#1012628).
- net: tulip: winbond-840: fix build for UML (bsc#1012628).
- tcp: switch orphan_count to bare per-cpu counters (bsc#1012628).
- crypto: octeontx2 - set assoclen in aead_do_fallback()
  (bsc#1012628).
- thermal/core: fix a UAF bug in
  __thermal_cooling_device_register() (bsc#1012628).
- drm/msm/dsi: do not enable irq handler before powering up the
  host (bsc#1012628).
- drm/msm: Fix potential Oops in a6xx_gmu_rpmh_init()
  (bsc#1012628).
- drm/msm: potential error pointer dereference in init()
  (bsc#1012628).
- drm/msm: unlock on error in get_sched_entity() (bsc#1012628).
- drm/msm: fix potential NULL dereference in cleanup
  (bsc#1012628).
- drm/msm: uninitialized variable in msm_gem_import()
  (bsc#1012628).
- net: stream: don't purge sk_error_queue in
  sk_stream_kill_queues() (bsc#1012628).
- thermal/drivers/qcom/lmh: make QCOM_LMH depends on QCOM_SCM
  (bsc#1012628).
- mailbox: Remove WARN_ON for async_cb.cb in cmdq_exec_done
  (bsc#1012628).
- media: ivtv: fix build for UML (bsc#1012628).
- media: ir_toy: assignment to be16 should be of correct type
  (bsc#1012628).
- mmc: mxs-mmc: disable regulator on error and in the remove
  function (bsc#1012628).
- io-wq: Remove duplicate code in io_workqueue_create()
  (bsc#1012628).
- block: ataflop: fix breakage introduced at blk-mq refactoring
  (bsc#1012628).
- blk-wbt: prevent NULL pointer dereference in wb_timer_fn
  (bsc#1012628).
- platform/x86: thinkpad_acpi: Fix bitwise vs. logical warning
  (bsc#1012628).
- mailbox: mtk-cmdq: Validate alias_id on probe (bsc#1012628).
- mailbox: mtk-cmdq: Fix local clock ID usage (bsc#1012628).
- ACPI: PM: Turn off unused wakeup power resources (bsc#1012628).
- ACPI: PM: Fix sharing of wakeup power resources (bsc#1012628).
- drm/amdkfd: Fix an inappropriate error handling in allloc
  memory of gpu (bsc#1012628).
- mt76: mt7921: fix endianness in mt7921_mcu_tx_done_event
  (bsc#1012628).
- mt76: mt7915: fix endianness warning in mt7915_mac_add_txs_skb
  (bsc#1012628).
- mt76: mt7921: fix endianness warning in mt7921_update_txs
  (bsc#1012628).
- mt76: mt7615: fix endianness warning in mt7615_mac_write_txwi
  (bsc#1012628).
- mt76: mt7915: fix info leak in mt7915_mcu_set_pre_cal()
  (bsc#1012628).
- mt76: connac: fix mt76_connac_gtk_rekey_tlv usage (bsc#1012628).
- mt76: fix build error implicit enumeration conversion
  (bsc#1012628).
- mt76: mt7921: fix survey-dump reporting (bsc#1012628).
- mt76: mt76x02: fix endianness warnings in mt76x02_mac.c
  (bsc#1012628).
- mt76: mt7921: Fix out of order process by invalid event pkt
  (bsc#1012628).
- mt76: mt7915: fix potential overflow of eeprom page index
  (bsc#1012628).
- mt76: mt7915: fix bit fields for HT rate idx (bsc#1012628).
- mt76: mt7921: fix dma hang in rmmod (bsc#1012628).
- mt76: connac: fix GTK rekey offload failure on WPA mixed mode
  (bsc#1012628).
- mt76: overwrite default reg_ops if necessary (bsc#1012628).
- mt76: mt7921: report HE MU radiotap (bsc#1012628).
- mt76: mt7921: fix firmware usage of RA info using legacy rates
  (bsc#1012628).
- mt76: mt7921: fix kernel warning from cfg80211_calculate_bitrate
  (bsc#1012628).
- mt76: mt7921: always wake device if necessary in debugfs
  (bsc#1012628).
- mt76: mt7915: fix hwmon temp sensor mem use-after-free
  (bsc#1012628).
- mt76: mt7615: fix hwmon temp sensor mem use-after-free
  (bsc#1012628).
- mt76: mt7915: fix possible infinite loop release semaphore
  (bsc#1012628).
- mt76: mt7921: fix retrying release semaphore without end
  (bsc#1012628).
- mt76: mt7615: fix monitor mode tear down crash (bsc#1012628).
- mt76: connac: fix possible NULL pointer dereference in
  mt76_connac_get_phy_mode_v2 (bsc#1012628).
- mt76: mt7915: fix sta_rec_wtbl tag len (bsc#1012628).
- mt76: mt7915: fix muar_idx in mt7915_mcu_alloc_sta_req()
  (bsc#1012628).
- rsi: stop thread firstly in rsi_91x_init() error handling
  (bsc#1012628).
- mwifiex: Send DELBA requests according to spec (bsc#1012628).
- iwlwifi: mvm: reset PM state on unsuccessful resume
  (bsc#1012628).
- iwlwifi: pnvm: don't kmemdup() more than we have (bsc#1012628).
- iwlwifi: pnvm: read EFI data only if long enough (bsc#1012628).
- net: enetc: unmap DMA in enetc_send_cmd() (bsc#1012628).
- phy: micrel: ksz8041nl: do not use power down mode
  (bsc#1012628).
- nbd: Fix use-after-free in pid_show (bsc#1012628).
- nvme-rdma: fix error code in nvme_rdma_setup_ctrl (bsc#1012628).
- PM: hibernate: fix sparse warnings (bsc#1012628).
- clocksource/drivers/timer-ti-dm: Select TIMER_OF (bsc#1012628).
- x86/sev: Fix stack type check in vc_switch_off_ist()
  (bsc#1012628).
- drm/msm: Fix potential NULL dereference in DPU SSPP
  (bsc#1012628).
- drm/msm/dsi: fix wrong type in msm_dsi_host (bsc#1012628).
- crypto: tcrypt - fix skcipher multi-buffer tests for 1420B
  blocks (bsc#1012628).
- smackfs: use netlbl_cfg_cipsov4_del() for deleting cipso_v4_doi
  (bsc#1012628).
- KVM: selftests: Fix nested SVM tests when built with clang
  (bsc#1012628).
- libbpf: Fix memory leak in btf__dedup() (bsc#1012628).
- bpftool: Avoid leaking the JSON writer prepared for program
  metadata (bsc#1012628).
- libbpf: Fix overflow in BTF sanity checks (bsc#1012628).
- libbpf: Fix BTF header parsing checks (bsc#1012628).
- mt76: mt7615: mt7622: fix ibss and meshpoint (bsc#1012628).
- s390/gmap: validate VMA in __gmap_zap() (bsc#1012628).
- s390/gmap: don't unconditionally call pte_unmap_unlock()
  in __gmap_zap() (bsc#1012628).
- s390/mm: validate VMA in PGSTE manipulation functions
  (bsc#1012628).
- s390/mm: fix VMA and page table handling code in storage key
  handling functions (bsc#1012628).
- s390/uv: fully validate the VMA before calling follow_page()
  (bsc#1012628).
- KVM: s390: pv: avoid double free of sida page (bsc#1012628).
- KVM: s390: pv: avoid stalls for kvm_s390_pv_init_vm
  (bsc#1012628).
- irq: mips: avoid nested irq_enter() (bsc#1012628).
- net: dsa: avoid refcount warnings when ->port_{fdb,mdb}_del
  returns error (bsc#1012628).
- ARM: 9142/1: kasan: work around LPAE build warning
  (bsc#1012628).
- ath10k: fix module load regression with iram-recovery feature
  (bsc#1012628).
- block: ataflop: more blk-mq refactoring fixes (bsc#1012628).
- blk-cgroup: synchronize blkg creation against policy
  deactivation (bsc#1012628).
- libbpf: Fix off-by-one bug in bpf_core_apply_relo()
  (bsc#1012628).
- tpm: fix Atmel TPM crash caused by too frequent queries
  (bsc#1012628).
- tpm_tis_spi: Add missing SPI ID (bsc#1012628).
- libbpf: Fix endianness detection in
  BPF_CORE_READ_BITFIELD_PROBED() (bsc#1012628).
- tcp: don't free a FIN sk_buff in tcp_remove_empty_skb()
  (bsc#1012628).
- tracing: Fix missing trace_boot_init_histograms kstrdup NULL
  checks (bsc#1012628).
- cpufreq: intel_pstate: Fix cpu->pstate.turbo_freq initialization
  (bsc#1012628).
- spi: spi-rpc-if: Check return value of rpcif_sw_init()
  (bsc#1012628).
- samples/kretprobes: Fix return value if register_kretprobe()
  failed (bsc#1012628).
- KVM: s390: Fix handle_sske page fault handling (bsc#1012628).
- libertas_tf: Fix possible memory leak in probe and disconnect
  (bsc#1012628).
- libertas: Fix possible memory leak in probe and disconnect
  (bsc#1012628).
- wcn36xx: add proper DMA memory barriers in rx path
  (bsc#1012628).
- wcn36xx: Fix discarded frames due to wrong sequence number
  (bsc#1012628).
- bpf: Avoid races in __bpf_prog_run() for 32bit arches
  (bsc#1012628).
- bpf: Fixes possible race in update_prog_stats() for 32bit arches
  (bsc#1012628).
- wcn36xx: Channel list update before hardware scan (bsc#1012628).
- drm/amdgpu: fix a potential memory leak in
  amdgpu_device_fini_sw() (bsc#1012628).
- drm/amdgpu/gmc6: fix DMA mask from 44 to 40 bits (bsc#1012628).
- selftests/bpf: Fix fd cleanup in sk_lookup test (bsc#1012628).
- selftests/bpf: Fix memory leak in test_ima (bsc#1012628).
- sctp: allow IP fragmentation when PLPMTUD enters Error state
  (bsc#1012628).
- sctp: reset probe_timer in sctp_transport_pl_update
  (bsc#1012628).
- sctp: subtract sctphdr len in sctp_transport_pl_hlen
  (bsc#1012628).
- sctp: return true only for pathmtu update in
  sctp_transport_pl_toobig (bsc#1012628).
- net: amd-xgbe: Toggle PLL settings during rate change
  (bsc#1012628).
- ipmi: kcs_bmc: Fix a memory leak in the error handling path of
  'kcs_bmc_serio_add_device()' (bsc#1012628).
- nfp: fix NULL pointer access when scheduling dim work
  (bsc#1012628).
- nfp: fix potential deadlock when canceling dim work
  (bsc#1012628).
- net: phylink: avoid mvneta warning when setting pause parameters
  (bsc#1012628).
- net: bridge: fix uninitialized variables when BRIDGE_CFM is
  disabled (bsc#1012628).
- selftests: net: bridge: update IGMP/MLD membership interval
  value (bsc#1012628).
- crypto: pcrypt - Delay write to padata->info (bsc#1012628).
- selftests/bpf: Fix fclose/pclose mismatch in test_progs
  (bsc#1012628).
- udp6: allow SO_MARK ctrl msg to affect routing (bsc#1012628).
- ibmvnic: don't stop queue in xmit (bsc#1012628).
- ibmvnic: Process crqs after enabling interrupts (bsc#1012628).
- ibmvnic: delay complete() (bsc#1012628).
- selftests: mptcp: fix proto type in link_failure tests
  (bsc#1012628).
- skmsg: Lose offset info in sk_psock_skb_ingress (bsc#1012628).
- cgroup: Fix rootcg cpu.stat guest double counting (bsc#1012628).
- bpf: Fix propagation of bounds from 64-bit min/max into 32-bit
  and var_off (bsc#1012628).
- bpf: Fix propagation of signed bounds from 64-bit min/max into
  32-bit (bsc#1012628).
- of: unittest: fix EXPECT text for gpio hog errors (bsc#1012628).
- cpufreq: Fix parameter in parse_perf_domain() (bsc#1012628).
- staging: r8188eu: fix memory leak in rtw_set_key (bsc#1012628).
- arm64: dts: meson: sm1: add Ethernet PHY reset line for
  ODROID-C4/HC4 (bsc#1012628).
- iio: st_sensors: disable regulators after device unregistration
  (bsc#1012628).
- RDMA/rxe: Fix wrong port_cap_flags (bsc#1012628).
- ARM: dts: BCM5301X: Fix memory nodes names (bsc#1012628).
- arm64: dts: broadcom: bcm4908: Fix UART clock name
  (bsc#1012628).
- clk: mvebu: ap-cpu-clk: Fix a memory leak in error handling
  paths (bsc#1012628).
- scsi: pm80xx: Fix lockup in outbound queue management
  (bsc#1012628).
- scsi: qla2xxx: edif: Use link event to wake up app
  (bsc#1012628).
- scsi: lpfc: Fix NVMe I/O failover to non-optimized path
  (bsc#1012628).
- ARM: s3c: irq-s3c24xx: Fix return value check for
  s3c24xx_init_intc() (bsc#1012628).
- arm64: dts: rockchip: Fix GPU register width for RK3328
  (bsc#1012628).
- ARM: dts: qcom: msm8974: Add xo_board reference clock to DSI0
  PHY (bsc#1012628).
- RDMA/bnxt_re: Fix query SRQ failure (bsc#1012628).
- arm64: dts: ti: k3-j721e-main: Fix "max-virtual-functions"
  in PCIe EP nodes (bsc#1012628).
- arm64: dts: ti: k3-j721e-main: Fix "bus-range" upto 256 bus
  number for PCIe (bsc#1012628).
- arm64: dts: ti: j7200-main: Fix "vendor-id"/"device-id"
  properties of pcie node (bsc#1012628).
- arm64: dts: ti: j7200-main: Fix "bus-range" upto 256 bus number
  for PCIe (bsc#1012628).
- arm64: dts: meson-g12a: Fix the pwm regulator supply properties
  (bsc#1012628).
- arm64: dts: meson-g12b: Fix the pwm regulator supply properties
  (bsc#1012628).
- arm64: dts: meson-sm1: Fix the pwm regulator supply properties
  (bsc#1012628).
- bus: ti-sysc: Fix timekeeping_suspended warning on resume
  (bsc#1012628).
- ARM: dts: at91: tse850: the emac<->phy interface is rmii
  (bsc#1012628).
- arm64: dts: qcom: sc7180: Base dynamic CPU power coefficients
  in reality (bsc#1012628).
- soc: qcom: llcc: Disable MMUHWT retention (bsc#1012628).
- arm64: dts: qcom: sc7280: fix display port phy reg property
  (bsc#1012628).
- scsi: dc395: Fix error case unwinding (bsc#1012628).
- MIPS: loongson64: make CPU_LOONGSON64 depends on MIPS_FP_SUPPORT
  (bsc#1012628).
- JFS: fix memleak in jfs_mount (bsc#1012628).
- pinctrl: renesas: rzg2l: Fix missing port register 21h
  (bsc#1012628).
- ASoC: wcd9335: Use correct version to initialize Class H
  (bsc#1012628).
- arm64: dts: qcom: msm8916: Fix Secondary MI2S bit clock
  (bsc#1012628).
- arm64: dts: renesas: beacon: Fix Ethernet PHY mode
  (bsc#1012628).
- iommu/mediatek: Fix out-of-range warning with clang
  (bsc#1012628).
- arm64: dts: qcom: pm8916: Remove wrong reg-names for rtc@6000
  (bsc#1012628).
- iommu/dma: Fix sync_sg with swiotlb (bsc#1012628).
- iommu/dma: Fix arch_sync_dma for map (bsc#1012628).
- ALSA: hda: Reduce udelay() at SKL+ position reporting
  (bsc#1012628).
- ALSA: hda: Use position buffer for SKL+ again (bsc#1012628).
- ALSA: usb-audio: Fix possible race at sync of urb completions
  (bsc#1012628).
- soundwire: debugfs: use controller id and link_id for debugfs
  (bsc#1012628).
- power: reset: at91-reset: check properly the return value of
  devm_of_iomap (bsc#1012628).
- scsi: ufs: core: Fix ufshcd_probe_hba() prototype to match
  the definition (bsc#1012628).
- scsi: ufs: core: Stop clearing UNIT ATTENTIONS (bsc#1012628).
- scsi: megaraid_sas: Fix concurrent access to ISR between IRQ
  polling and real interrupt (bsc#1012628).
- scsi: pm80xx: Fix misleading log statement in
  pm8001_mpi_get_nvmd_resp() (bsc#1012628).
- driver core: Fix possible memory leak in device_link_add()
  (bsc#1012628).
- arm: dts: omap3-gta04a4: accelerometer irq fix (bsc#1012628).
- ASoC: SOF: topology: do not power down primary core during
  topology removal (bsc#1012628).
- iio: st_pressure_spi: Add missing entries SPI to device ID table
  (bsc#1012628).
- soc/tegra: Fix an error handling path in
  tegra_powergate_power_up() (bsc#1012628).
- memory: fsl_ifc: fix leak of irq and nand_irq in
  fsl_ifc_ctrl_probe (bsc#1012628).
- clk: at91: check pmc node status before registering syscore ops
  (bsc#1012628).
- powerpc/mem: Fix arch/powerpc/mm/mem.c:53:12: error: no previous
  prototype for 'create_section_mapping' (bsc#1012628).
- video: fbdev: chipsfb: use memset_io() instead of memset()
  (bsc#1012628).
- powerpc: fix unbalanced node refcount in check_kvm_guest()
  (bsc#1012628).
- powerpc/paravirt: correct preempt debug splat in
  vcpu_is_preempted() (bsc#1012628).
- serial: 8250_dw: Drop wrong use of ACPI_PTR() (bsc#1012628).
- usb: gadget: hid: fix error code in do_config() (bsc#1012628).
- =?UTF-8?q?power:=20supply:=20rt5033=5Fbattery:=20Change?=
  =?UTF-8?q?=20voltage=20values=20to=20=C2=B5V?= (bsc#1012628).
- power: supply: max17040: fix null-ptr-deref in max17040_probe()
  (bsc#1012628).
- scsi: csiostor: Uninitialized data in csio_ln_vnp_read_cbfn()
  (bsc#1012628).
- RDMA/mlx4: Return missed an error if device doesn't support
  steering (bsc#1012628).
- usb: musb: select GENERIC_PHY instead of depending on it
  (bsc#1012628).
- staging: most: dim2: do not double-register the same device
  (bsc#1012628).
- staging: ks7010: select CRYPTO_HASH/CRYPTO_MICHAEL_MIC
  (bsc#1012628).
- RDMA/core: Set sgtable nents when using ib_dma_virt_map_sg()
  (bsc#1012628).
- dyndbg: make dyndbg a known cli param (bsc#1012628).
- powerpc/perf: Fix cycles/instructions as PM_CYC/PM_INST_CMPL
  in power10 (bsc#1012628).
- pinctrl: renesas: checker: Fix off-by-one bug in drive register
  check (bsc#1012628).
- ARM: dts: stm32: Reduce DHCOR SPI NOR frequency to 50 MHz
  (bsc#1012628).
- ARM: dts: stm32: fix STUSB1600 Type-C irq level on
  stm32mp15xx-dkx (bsc#1012628).
- ARM: dts: stm32: fix SAI sub nodes register range (bsc#1012628).
- ARM: dts: stm32: fix AV96 board SAI2 pin muxing on stm32mp15
  (bsc#1012628).
- ASoC: cs42l42: Always configure both ASP TX channels
  (bsc#1012628).
- ASoC: cs42l42: Correct some register default values
  (bsc#1012628).
- ASoC: cs42l42: Defer probe if request_threaded_irq() returns
  EPROBE_DEFER (bsc#1012628).
- soc: qcom: rpmhpd: Make power_on actually enable the domain
  (bsc#1012628).
- soc: qcom: socinfo: add two missing PMIC IDs (bsc#1012628).
- iio: buffer: Fix double-free in
  iio_buffers_alloc_sysfs_and_mask() (bsc#1012628).
- usb: typec: STUSB160X should select REGMAP_I2C (bsc#1012628).
- iio: adis: do not disabe IRQs in 'adis_init()' (bsc#1012628).
- soundwire: bus: stop dereferencing invalid slave pointer
  (bsc#1012628).
- scsi: ufs: ufshcd-pltfrm: Fix memory leak due to probe defer
  (bsc#1012628).
- scsi: lpfc: Wait for successful restart of SLI3 adapter during
  host sg_reset (bsc#1012628).
- serial: imx: fix detach/attach of serial console (bsc#1012628).
- usb: dwc2: drd: fix dwc2_force_mode call in dwc2_ovr_init
  (bsc#1012628).
- usb: dwc2: drd: fix dwc2_drd_role_sw_set when clock could be
  disabled (bsc#1012628).
- usb: dwc2: drd: reset current session before setting the new
  one (bsc#1012628).
- powerpc/booke: Disable STRICT_KERNEL_RWX, DEBUG_PAGEALLOC and
  KFENCE (bsc#1012628).
- usb: dwc3: gadget: Skip resizing EP's TX FIFO if already resized
  (bsc#1012628).
- firmware: qcom_scm: Fix error retval in
  __qcom_scm_is_call_available() (bsc#1012628).
- soc: qcom: rpmhpd: fix sm8350_mxc's peer domain (bsc#1012628).
- soc: qcom: apr: Add of_node_put() before return (bsc#1012628).
- arm64: dts: qcom: pmi8994: Fix "eternal"->"external" typo in
  WLED node (bsc#1012628).
- arm64: dts: qcom: sdm845: Use RPMH_CE_CLK macro directly
  (bsc#1012628).
- arm64: dts: qcom: sdm845: Fix Qualcomm crypto engine bus clock
  (bsc#1012628).
- pinctrl: equilibrium: Fix function addition in multiple groups
  (bsc#1012628).
- ASoC: topology: Fix stub for snd_soc_tplg_component_remove()
  (bsc#1012628).
- phy: qcom-qusb2: Fix a memory leak on probe (bsc#1012628).
- phy: ti: gmii-sel: check of_get_address() for failure
  (bsc#1012628).
- phy: qcom-qmp: another fix for the sc8180x PCIe definition
  (bsc#1012628).
- phy: qcom-snps: Correct the FSEL_MASK (bsc#1012628).
- phy: Sparx5 Eth SerDes: Fix return value check in
  sparx5_serdes_probe() (bsc#1012628).
- serial: xilinx_uartps: Fix race condition causing stuck TX
  (bsc#1012628).
- clk: at91: sam9x60-pll: use DIV_ROUND_CLOSEST_ULL (bsc#1012628).
- clk: at91: clk-master: check if div or pres is zero
  (bsc#1012628).
- clk: at91: clk-master: fix prescaler logic (bsc#1012628).
- HID: u2fzero: clarify error check and length calculations
  (bsc#1012628).
- HID: u2fzero: properly handle timeouts in usb_submit_urb
  (bsc#1012628).
- powerpc/nohash: Fix __ptep_set_access_flags() and
  ptep_set_wrprotect() (bsc#1012628).
- powerpc/book3e: Fix set_memory_x() and set_memory_nx()
  (bsc#1012628).
- powerpc/44x/fsp2: add missing of_node_put (bsc#1012628).
- powerpc/xmon: fix task state output (bsc#1012628).
- ALSA: oxfw: fix functional regression for Mackie Onyx 1640i
  in v5.14 or later (bsc#1012628).
- iommu/dma: Fix incorrect error return on iommu deferred attach
  (bsc#1012628).
- powerpc: Don't provide __kernel_map_pages() without
  ARCH_SUPPORTS_DEBUG_PAGEALLOC (bsc#1012628).
- ASoC: cs42l42: Correct configuring of switch inversion from
  ts-inv (bsc#1012628).
- RDMA/hns: Fix initial arm_st of CQ (bsc#1012628).
- RDMA/hns: Modify the value of MAX_LP_MSG_LEN to meet hardware
  compatibility (bsc#1012628).
- ASoC: rsnd: Fix an error handling path in 'rsnd_node_count()'
  (bsc#1012628).
- serial: cpm_uart: Protect udbg definitions by
  CONFIG_SERIAL_CPM_CONSOLE (bsc#1012628).
- virtio_ring: check desc == NULL when using indirect with packed
  (bsc#1012628).
- vdpa/mlx5: Fix clearing of VIRTIO_NET_F_MAC feature bit
  (bsc#1012628).
- mips: cm: Convert to bitfield API to fix out-of-bounds access
  (bsc#1012628).
- power: supply: bq27xxx: Fix kernel crash on IRQ handler register
  error (bsc#1012628).
- RDMA/core: Require the driver to set the IOVA correctly during
  rereg_mr (bsc#1012628).
- apparmor: fix error check (bsc#1012628).
- rpmsg: Fix rpmsg_create_ept return when RPMSG config is not
  defined (bsc#1012628).
- mtd: rawnand: intel: Fix potential buffer overflow in probe
  (bsc#1012628).
- nfsd: don't alloc under spinlock in rpc_parse_scope_id
  (bsc#1012628).
- rtc: ds1302: Add SPI ID table (bsc#1012628).
- rtc: ds1390: Add SPI ID table (bsc#1012628).
- rtc: pcf2123: Add SPI ID table (bsc#1012628).
- remoteproc: imx_rproc: Fix TCM io memory type (bsc#1012628).
- i2c: i801: Use PCI bus rescan mutex to protect P2SB access
  (bsc#1012628).
- dmaengine: idxd: move out percpu_ref_exit() to ensure it's
  outside submission (bsc#1012628).
- rtc: mcp795: Add SPI ID table (bsc#1012628).
- Input: ariel-pwrbutton - add SPI device ID table (bsc#1012628).
- i2c: mediatek: fixing the incorrect register offset
  (bsc#1012628).
- NFS: Default change_attr_type to NFS4_CHANGE_TYPE_IS_UNDEFINED
  (bsc#1012628).
- NFS: Don't set NFS_INO_DATA_INVAL_DEFER and NFS_INO_INVALID_DATA
  (bsc#1012628).
- NFS: Ignore the directory size when marking for revalidation
  (bsc#1012628).
- NFS: Fix dentry verifier races (bsc#1012628).
- pnfs/flexfiles: Fix misplaced barrier in
  nfs4_ff_layout_prepare_ds (bsc#1012628).
- drm/bridge/lontium-lt9611uxc: fix provided connector suport
  (bsc#1012628).
- drm/plane-helper: fix uninitialized variable reference
  (bsc#1012628).
- PCI: aardvark: Don't spam about PIO Response Status
  (bsc#1012628).
- PCI: aardvark: Fix preserving PCI_EXP_RTCTL_CRSSVE flag on
  emulated bridge (bsc#1012628).
- opp: Fix return in _opp_add_static_v2() (bsc#1012628).
- NFS: Fix deadlocks in nfs_scan_commit_list() (bsc#1012628).
- sparc: Add missing "FORCE" target when using if_changed
  (bsc#1012628).
- fs: orangefs: fix error return code of
  orangefs_revalidate_lookup() (bsc#1012628).
- Input: st1232 - increase "wait ready" timeout (bsc#1012628).
- drm/bridge: nwl-dsi: Add atomic_get_input_bus_fmts
  (bsc#1012628).
- mtd: spi-nor: hisi-sfc: Remove excessive clk_disable_unprepare()
  (bsc#1012628).
- PCI: uniphier: Serialize INTx masking/unmasking and fix the
  bit operation (bsc#1012628).
- mtd: rawnand: arasan: Prevent an unsupported configuration
  (bsc#1012628).
- mtd: core: don't remove debugfs directory if device is in use
  (bsc#1012628).
- remoteproc: Fix a memory leak in an error handling path in
  'rproc_handle_vdev()' (bsc#1012628).
- rtc: rv3032: fix error handling in rv3032_clkout_set_rate()
  (bsc#1012628).
- dmaengine: at_xdmac: call at_xdmac_axi_config() on resume path
  (bsc#1012628).
- dmaengine: at_xdmac: fix AT_XDMAC_CC_PERID() macro
  (bsc#1012628).
- dmaengine: stm32-dma: fix stm32_dma_get_max_width (bsc#1012628).
- NFS: Fix up commit deadlocks (bsc#1012628).
- NFS: Fix an Oops in pnfs_mark_request_commit() (bsc#1012628).
- Fix user namespace leak (bsc#1012628).
- auxdisplay: img-ascii-lcd: Fix lock-up when displaying empty
  string (bsc#1012628).
- auxdisplay: ht16k33: Connect backlight to fbdev (bsc#1012628).
- auxdisplay: ht16k33: Fix frame buffer device blanking
  (bsc#1012628).
- soc: fsl: dpaa2-console: free buffer before returning from
  dpaa2_console_read (bsc#1012628).
- netfilter: nfnetlink_queue: fix OOB when mac header was cleared
  (bsc#1012628).
- dmaengine: dmaengine_desc_callback_valid(): Check for
  `callback_result` (bsc#1012628).
- dmaengine: tegra210-adma: fix pm runtime unbalance
  (bsc#1012628).
- dmanegine: idxd: fix resource free ordering on driver removal
  (bsc#1012628).
- dmaengine: idxd: reconfig device after device reset command
  (bsc#1012628).
- signal/sh: Use force_sig(SIGKILL) instead of
  do_group_exit(SIGKILL) (bsc#1012628).
- m68k: set a default value for MEMORY_RESERVE (bsc#1012628).
- watchdog: f71808e_wdt: fix inaccurate report in WDIOC_GETTIMEOUT
  (bsc#1012628).
- ar7: fix kernel builds for compiler test (bsc#1012628).
- scsi: target: core: Remove from tmr_list during LUN unlink
  (bsc#1012628).
- scsi: qla2xxx: Relogin during fabric disturbance (bsc#1012628).
- scsi: qla2xxx: Fix gnl list corruption (bsc#1012628).
- scsi: qla2xxx: Turn off target reset during issue_lip
  (bsc#1012628).
- scsi: qla2xxx: edif: Fix app start fail (bsc#1012628).
- scsi: qla2xxx: edif: Fix app start delay (bsc#1012628).
- scsi: qla2xxx: edif: Flush stale events and msgs on session down
  (bsc#1012628).
- scsi: qla2xxx: edif: Increase ELS payload (bsc#1012628).
- scsi: qla2xxx: edif: Fix EDIF bsg (bsc#1012628).
- NFSv4: Fix a regression in nfs_set_open_stateid_locked()
  (bsc#1012628).
- dmaengine: idxd: fix resource leak on dmaengine driver disable
  (bsc#1012628).
- i2c: xlr: Fix a resource leak in the error handling path of
  'xlr_i2c_probe()' (bsc#1012628).
- gpio: realtek-otto: fix GPIO line IRQ offset (bsc#1012628).
- xen-pciback: Fix return in pm_ctrl_init() (bsc#1012628).
- nbd: fix max value for 'first_minor' (bsc#1012628).
- nbd: fix possible overflow for 'first_minor' in nbd_dev_add()
  (bsc#1012628).
- io-wq: fix max-workers not correctly set on multi-node system
  (bsc#1012628).
- net: davinci_emac: Fix interrupt pacing disable (bsc#1012628).
- kselftests/net: add missed icmp.sh test to Makefile
  (bsc#1012628).
- kselftests/net: add missed setup_loopback.sh/setup_veth.sh to
  Makefile (bsc#1012628).
- kselftests/net: add missed SRv6 tests (bsc#1012628).
- kselftests/net: add missed vrf_strict_mode_test.sh test to
  Makefile (bsc#1012628).
- kselftests/net: add missed toeplitz.sh/toeplitz_client.sh to
  Makefile (bsc#1012628).
- ethtool: fix ethtool msg len calculation for pause stats
  (bsc#1012628).
- openrisc: fix SMP tlb flush NULL pointer dereference
  (bsc#1012628).
- net: vlan: fix a UAF in vlan_dev_real_dev() (bsc#1012628).
- net: dsa: felix: fix broken VLAN-tagged PTP under VLAN-aware
  bridge (bsc#1012628).
- ice: Fix replacing VF hardware MAC to existing MAC filter
  (bsc#1012628).
- ice: Fix not stopping Tx queues for VFs (bsc#1012628).
- kdb: Adopt scheduler's task classification (bsc#1012628).
- ACPI: PMIC: Fix intel_pmic_regs_handler() read accesses
  (bsc#1012628).
- PCI: j721e: Fix j721e_pcie_probe() error path (bsc#1012628).
- nvdimm/btt: do not call del_gendisk() if not needed
  (bsc#1012628).
- scsi: bsg: Fix errno when scsi_bsg_register_queue() fails
  (bsc#1012628).
- scsi: ufs: ufshpb: Use proper power management API
  (bsc#1012628).
- scsi: ufs: core: Fix NULL pointer dereference (bsc#1012628).
- scsi: ufs: ufshpb: Properly handle max-single-cmd (bsc#1012628).
- selftests: net: properly support IPv6 in GSO GRE test
  (bsc#1012628).
- drm/nouveau/svm: Fix refcount leak bug and missing check
  against null bug (bsc#1012628).
- nvdimm/pmem: cleanup the disk if pmem_release_disk() is yet
  assigned (bsc#1012628).
- block/ataflop: use the blk_cleanup_disk() helper (bsc#1012628).
- block/ataflop: add registration bool before calling
  del_gendisk() (bsc#1012628).
- block/ataflop: provide a helper for cleanup up an atari disk
  (bsc#1012628).
- ataflop: remove ataflop_probe_lock mutex (bsc#1012628).
- PCI: Do not enable AtomicOps on VFs (bsc#1012628).
- cpufreq: intel_pstate: Clear HWP desired on suspend/shutdown
  and offline (bsc#1012628).
- net: phy: fix duplex out of sync problem while changing settings
  (bsc#1012628).
- block: fix device_add_disk() kobject_create_and_add() error
  handling (bsc#1012628).
- drm/ttm: remove ttm_bo_vm_insert_huge() (bsc#1012628).
- bonding: Fix a use-after-free problem when
  bond_sysfs_slave_add() failed (bsc#1012628).
- octeontx2-pf: select CONFIG_NET_DEVLINK (bsc#1012628).
- ALSA: memalloc: Catch call with NULL snd_dma_buffer pointer
  (bsc#1012628).
- mfd: core: Add missing of_node_put for loop iteration
  (bsc#1012628).
- mfd: cpcap: Add SPI device ID table (bsc#1012628).
- mfd: sprd: Add SPI device ID table (bsc#1012628).
- mfd: altera-sysmgr: Fix a mistake caused by resource_size
  conversion (bsc#1012628).
- ACPI: PM: Fix device wakeup power reference counting error
  (bsc#1012628).
- libbpf: Fix lookup_and_delete_elem_flags error reporting
  (bsc#1012628).
- selftests/bpf/xdp_redirect_multi: Put the logs to tmp folder
  (bsc#1012628).
- selftests/bpf/xdp_redirect_multi: Use arping to accurate the
  arp number (bsc#1012628).
- selftests/bpf/xdp_redirect_multi: Give tcpdump a chance to
  terminate cleanly (bsc#1012628).
- selftests/bpf/xdp_redirect_multi: Limit the tests in netns
  (bsc#1012628).
- drm: fb_helper: improve CONFIG_FB dependency (bsc#1012628).
- Revert "drm/imx: Annotate dma-fence critical section in commit
  path" (bsc#1012628).
- drm/amdgpu/powerplay: fix sysfs_emit/sysfs_emit_at handling
  (bsc#1012628).
- can: etas_es58x: es58x_rx_err_msg(): fix memory leak in error
  path (bsc#1012628).
- can: mcp251xfd: mcp251xfd_chip_start(): fix error handling
  for mcp251xfd_chip_rx_int_enable() (bsc#1012628).
- mm/zsmalloc.c: close race window between zs_pool_dec_isolated()
  and zs_unregister_migration() (bsc#1012628).
- zram: off by one in read_block_state() (bsc#1012628).
- perf bpf: Add missing free to bpf_event__print_bpf_prog_info()
  (bsc#1012628).
- llc: fix out-of-bound array index in llc_sk_dev_hash()
  (bsc#1012628).
- nfc: pn533: Fix double free when pn533_fill_fragment_skbs()
  fails (bsc#1012628).
- litex_liteeth: Fix a double free in the remove function
  (bsc#1012628).
- arm64: arm64_ftr_reg->name may not be a human-readable string
  (bsc#1012628).
- arm64: pgtable: make __pte_to_phys/__phys_to_pte_val inline
  functions (bsc#1012628).
- bpf, sockmap: Remove unhash handler for BPF sockmap usage
  (bsc#1012628).
- bpf, sockmap: Fix race in ingress receive verdict with redirect
  to self (bsc#1012628).
- bpf: sockmap, strparser, and tls are reusing qdisc_skb_cb and
  colliding (bsc#1012628).
- bpf, sockmap: sk_skb data_end access incorrect when src_reg =
  dst_reg (bsc#1012628).
- dmaengine: stm32-dma: fix burst in case of unaligned memory
  address (bsc#1012628).
- dmaengine: stm32-dma: avoid 64-bit division in
  stm32_dma_get_max_width (bsc#1012628).
- gve: Fix off by one in gve_tx_timeout() (bsc#1012628).
- drm/i915/fb: Fix rounding error in subsampled plane size
  calculation (bsc#1012628).
- init: make unknown command line param message clearer
  (bsc#1012628).
- seq_file: fix passing wrong private data (bsc#1012628).
- drm/amdgpu: fix uvd crash on Polaris12 during driver unloading
  (bsc#1012628).
- net: dsa: mv88e6xxx: Don't support >1G speeds on 6191X on
  ports other than 10 (bsc#1012628).
- net/sched: sch_taprio: fix undefined behavior in
  ktime_mono_to_any (bsc#1012628).
- net: hns3: fix ROCE base interrupt vector initialization bug
  (bsc#1012628).
- net: hns3: fix pfc packet number incorrect after querying pfc
  parameters (bsc#1012628).
- net: hns3: fix kernel crash when unload VF while it is being
  reset (bsc#1012628).
- net: hns3: allow configure ETS bandwidth of all TCs
  (bsc#1012628).
- net: stmmac: allow a tc-taprio base-time of zero (bsc#1012628).
- net: ethernet: ti: cpsw_ale: Fix access to un-initialized memory
  (bsc#1012628).
- net: marvell: mvpp2: Fix wrong SerDes reconfiguration order
  (bsc#1012628).
- vsock: prevent unnecessary refcnt inc for nonblocking connect
  (bsc#1012628).
- net/smc: fix sk_refcnt underflow on linkdown and fallback
  (bsc#1012628).
- cxgb4: fix eeprom len when diagnostics not implemented
  (bsc#1012628).
- selftests/net: udpgso_bench_rx: fix port argument (bsc#1012628).
- thermal: int340x: fix build on 32-bit targets (bsc#1012628).
- smb3: do not error on fsync when readonly (bsc#1012628).
- ARM: 9155/1: fix early early_iounmap() (bsc#1012628).
- ARM: 9156/1: drop cc-option fallbacks for architecture selection
  (bsc#1012628).
- parisc: Fix backtrace to always include init funtion names
  (bsc#1012628).
- parisc: Flush kernel data mapping in set_pte_at() when
  installing pte for user page (bsc#1012628).
- MIPS: fix duplicated slashes for Platform file path
  (bsc#1012628).
- MIPS: fix *-pkg builds for loongson2ef platform (bsc#1012628).
- MIPS: Fix assembly error from MIPSr2 code used within
  MIPS_ISA_ARCH_LEVEL (bsc#1012628).
- x86/mce: Add errata workaround for Skylake SKX37 (bsc#1012628).
- PCI/MSI: Move non-mask check back into low level accessors
  (bsc#1012628).
- PCI/MSI: Destroy sysfs before freeing entries (bsc#1012628).
- KVM: x86: move guest_pv_has out of user_access section
  (bsc#1012628).
- posix-cpu-timers: Clear task::posix_cputimers_work in
  copy_process() (bsc#1012628).
- irqchip/sifive-plic: Fixup EOI failed when masked (bsc#1012628).
- f2fs: should use GFP_NOFS for directory inodes (bsc#1012628).
- f2fs: include non-compressed blocks in compr_written_block
  (bsc#1012628).
- f2fs: fix UAF in f2fs_available_free_memory (bsc#1012628).
- ceph: fix mdsmap decode when there are MDS's beyond max_mds
  (bsc#1012628).
- erofs: fix unsafe pagevec reuse of hooked pclusters
  (bsc#1012628).
- drm/i915/guc: Fix blocked context accounting (bsc#1012628).
- block: Hold invalidate_lock in BLKDISCARD ioctl (bsc#1012628).
- block: Hold invalidate_lock in BLKZEROOUT ioctl (bsc#1012628).
- block: Hold invalidate_lock in BLKRESETZONE ioctl (bsc#1012628).
- ksmbd: Fix buffer length check in
  fsctl_validate_negotiate_info() (bsc#1012628).
- ksmbd: don't need 8byte alignment for request length in
  ksmbd_check_message (bsc#1012628).
- dmaengine: ti: k3-udma: Set bchan to NULL if a channel request
  fail (bsc#1012628).
- dmaengine: ti: k3-udma: Set r/tchan or rflow to NULL if request
  fail (bsc#1012628).
- dmaengine: bestcomm: fix system boot lockups (bsc#1012628).
- net, neigh: Enable state migration between NUD_PERMANENT and
  NTF_USE (bsc#1012628).
- 9p/net: fix missing error check in p9_check_errors
  (bsc#1012628).
- mm/filemap.c: remove bogus VM_BUG_ON (bsc#1012628).
- memcg: prohibit unconditional exceeding the limit of dying tasks
  (bsc#1012628).
- mm, oom: pagefault_out_of_memory: don't force global OOM for
  dying tasks (bsc#1012628).
- mm, oom: do not trigger out_of_memory from the #PF
  (bsc#1012628).
- mm, thp: lock filemap when truncating page cache (bsc#1012628).
- mm, thp: fix incorrect unmap behavior for private pages
  (bsc#1012628).
- mfd: dln2: Add cell for initializing DLN2 ADC (bsc#1012628).
- video: backlight: Drop maximum brightness override for
  brightness zero (bsc#1012628).
- bcache: fix use-after-free problem in bcache_device_free()
  (bsc#1012628).
- bcache: Revert "bcache: use bvec_virt" (bsc#1012628).
- PM: sleep: Avoid calling put_device() under dpm_list_mtx
  (bsc#1012628).
- s390/cpumf: cpum_cf PMU displays invalid value after hotplug
  remove (bsc#1012628).
- s390/cio: check the subchannel validity for dev_busid
  (bsc#1012628).
- s390/tape: fix timer initialization in tape_std_assign()
  (bsc#1012628).
- s390/ap: Fix hanging ioctl caused by orphaned replies
  (bsc#1012628).
- s390/cio: make ccw_device_dma_* more robust (bsc#1012628).
- remoteproc: elf_loader: Fix loading segment when is_iomem true
  (bsc#1012628).
- remoteproc: Fix the wrong default value of is_iomem
  (bsc#1012628).
- remoteproc: imx_rproc: Fix ignoring mapping vdev regions
  (bsc#1012628).
- remoteproc: imx_rproc: Fix rsc-table name (bsc#1012628).
- mtd: rawnand: fsmc: Fix use of SM ORDER (bsc#1012628).
- mtd: rawnand: ams-delta: Keep the driver compatible with on-die
  ECC engines (bsc#1012628).
- mtd: rawnand: xway: Keep the driver compatible with on-die
  ECC engines (bsc#1012628).
- mtd: rawnand: mpc5121: Keep the driver compatible with on-die
  ECC engines (bsc#1012628).
- mtd: rawnand: gpio: Keep the driver compatible with on-die
  ECC engines (bsc#1012628).
- mtd: rawnand: pasemi: Keep the driver compatible with on-die
  ECC engines (bsc#1012628).
- mtd: rawnand: orion: Keep the driver compatible with on-die
  ECC engines (bsc#1012628).
- mtd: rawnand: plat_nand: Keep the driver compatible with on-die
  ECC engines (bsc#1012628).
- mtd: rawnand: au1550nd: Keep the driver compatible with on-die
  ECC engines (bsc#1012628).
- powerpc/vas: Fix potential NULL pointer dereference
  (bsc#1012628).
- powerpc/bpf: Fix write protecting JIT code (bsc#1012628).
- powerpc/32e: Ignore ESR in instruction storage interrupt handler
  (bsc#1012628).
- powerpc/powernv/prd: Unregister OPAL_MSG_PRD2 notifier during
  module unload (bsc#1012628).
- powerpc/security: Use a mutex for interrupt exit code patching
  (bsc#1012628).
- powerpc/64s/interrupt: Fix check_return_regs_valid() false
  positive (bsc#1012628).
- powerpc/pseries/mobility: ignore ibm, platform-facilities
  updates (bsc#1012628).
- powerpc/85xx: fix timebase sync issue when CONFIG_HOTPLUG_CPU=n
  (bsc#1012628).
- drm/sun4i: Fix macros in sun8i_csc.h (bsc#1012628).
- PCI: Add PCI_EXP_DEVCTL_PAYLOAD_* macros (bsc#1012628).
- PCI: aardvark: Fix PCIe Max Payload Size setting (bsc#1012628).
- SUNRPC: Partial revert of commit 6f9f17287e78 (bsc#1012628).
- drm/amd/display: Look at firmware version to determine using
  dmub on dcn21 (bsc#1012628).
- media: vidtv: move kfree(dvb) to vidtv_bridge_dev_release()
  (bsc#1012628).
- cifs: fix memory leak of smb3_fs_context_dup::server_hostname
  (bsc#1012628).
- ath10k: fix invalid dma_addr_t token assignment (bsc#1012628).
- mmc: moxart: Fix null pointer dereference on pointer host
  (bsc#1012628).
- selftests/x86/iopl: Adjust to the faked iopl CLI/STI usage
  (bsc#1012628).
- selftests/bpf: Fix also no-alu32 strobemeta selftest
  (bsc#1012628).
- arch/cc: Introduce a function to check for confidential
  computing features (bsc#1012628).
- x86/sev: Add an x86 version of cc_platform_has() (bsc#1012628).
- x86/sev: Make the #VC exception stacks part of the default
  stacks storage (bsc#1012628).
- media: videobuf2: always set buffer vb2 pointer (bsc#1012628).
- media: videobuf2-dma-sg: Fix buf->vb NULL pointer dereference
  (bsc#1012628).
- Update config files.
  On armv7hl, set DRM_PANEL_SIMPLE=m to fix link error caused by
  9d6366e743f3.
- commit 60fa139
* Wed Nov 17 2021 jslaby@suse.cz
- Refresh
  patches.suse/Input-i8042-Add-deferred-probe-support.patch.
  Fix cut & paste error in param description.
- commit 6d1d038
* Tue Nov 16 2021 iivanov@suse.de
- random: fix crash on multiple early calls to add_bootloader_randomness() (bsc#1184924)
- commit e24ee9e
* Tue Nov 16 2021 tiwai@suse.de
- ALSA: usb-audio: Fix dB level of Bose Revolve+ SoundLink
  (bsc#1192375).
- ALSA: usb-audio: Add minimal-mute notion in dB mapping table
  (bsc#1192375).
- ALSA: usb-audio: Use int for dB map values (bsc#1192375).
- ALSA: usb-audio: Fix dB level of Bose Revolve+ SoundLink
  (bsc#1192375).
- ALSA: usb-audio: Add minimal-mute notion in dB mapping table
  (bsc#1192375).
- ALSA: usb-audio: Use int for dB map values (bsc#1192375).
- commit 7a21313
* Tue Nov 16 2021 tiwai@suse.de
- rtw89: update partition size of firmware header on skb->data
  (bsc#1188303).
- commit 4e4f5f9
* Tue Nov 16 2021 tiwai@suse.de
- rtw89: update partition size of firmware header on skb->data
  (bsc#1188303).
- commit d879057
* Tue Nov 16 2021 msuchanek@suse.de
- kernel-*-subpackage: Add dependency on kernel scriptlets (bsc#1192740).
- commit a133bf4
* Tue Nov 16 2021 tiwai@suse.de
- Drop downstream rtw89 fix patch, to be replaced with the upstream fix
- commit 9ba8358
* Mon Nov 15 2021 mkubecek@suse.cz
- Update to 5.16-rc1
- eliminated 26 patches (13 stable, 13 mainline)
  - patches.kernel.org/*
  - patches.suse/ALSA-usb-audio-Restrict-rates-for-the-shared-clocks.patch
  - patches.suse/Bluetooth-sco-Fix-lock_sock-blockage-by-memcpy_from_.patch
  - patches.suse/Input-i8042-Add-quirk-for-Fujitsu-Lifebook-T725.patch
  - patches.suse/arm64-dts-rockchip-Disable-CDN-DP-on-Pinebook-Pro.patch
  - patches.suse/rtw89-Fix-two-spelling-mistakes-in-debug-messages.patch
  - patches.suse/rtw89-Fix-variable-dereferenced-before-check-sta.patch
  - patches.suse/rtw89-Remove-redundant-check-of-ret-after-call-to-rt.patch
  - patches.suse/rtw89-add-Realtek-802.11ax-driver.patch
  - patches.suse/rtw89-fix-error-function-parameter.patch
  - patches.suse/rtw89-fix-return-value-check-in-rtw89_cam_send_sec_k.patch
  - patches.suse/rtw89-fix-return-value-in-hfc_pub_cfg_chk.patch
  - patches.suse/rtw89-remove-duplicate-register-definitions.patch
  - patches.suse/rtw89-remove-unneeded-semicolon.patch
- refresh
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/suse-hv-guest-os-id.patch
- disable ARM architectures (need config update)
- new config options
  - General setup
  - PREEMPT_DYNAMIC=y
  - Processor type and features
  - SCHED_CLUSTER=y
  - STRICT_SIGALTSTACK_SIZE=n
  - Networking support
  - NETFILTER_EGRESS=y
  - MCTP=y
  - File systems
  - EROFS_FS_ZIP_LZMA=y
  - Library routines
  - XZ_DEC_MICROLZMA=y
  - Kernel hacking
  - DEBUG_PREEMPT=n
  - PREEMPT_TRACER=n
  - SCSI device support
  - SCSI_UFS_HWMON=y
  - Network device support
  - AMT=m
  - NET_VENDOR_ASIX=y
  - SPI_AX88796C=m
  - SPI_AX88796C_COMPRESSION=y
  - ICE_SWITCHDEV=y
  - MT7921S=m
  - Character devices
  - RPMSG_TTY=m
  - CEC support
  - CEC_GPIO=m
  - CEC_PIN_ERROR_INJ=n
  - Multimedia support
  - VIDEO_HI846=m
  - VIDEO_OV13B10=m
  - Graphics support
  - DRM_DEBUG_MODESET_LOCK=n
  - DRM_I915_PXP=y
  - Sound card support
  - SND_SOC_AMD_VANGOGH_MACH=m
  - SND_SOC_AMD_ACP6x=m
  - SND_SOC_AMD_ACP_COMMON=m
  - SND_SOC_AMD_YC_MACH=m
  - SND_AMD_ASOC_RENOIR=m
  - SND_SOC_AMD_LEGACY_MACH=m
  - SND_SOC_AMD_SOF_MACH=m
  - SND_SOC_INTEL_SOF_ES8336_MACH=m
  - SND_SOC_CS35L41_SPI=m
  - SND_SOC_CS35L41_I2C=m
  - SND_SOC_MAX98520=m
  - SND_SOC_RT9120=m
  - SND_SOC_NAU8821=m
  - HID support
  - HID_XIAOMI=m
  - HID_NINTENDO=m
  - NINTENDO_FF=y
  - X86 Platform Specific Device Drivers
  - NVIDIA_WMI_EC_BACKLIGHT=m
  - INTEL_ISHTP_ECLITE=m
  - BARCO_P50_GPIO=m
  - Industrial I/O support
  - ADXL313_I2C=n
  - ADXL313_SPI=n
  - ADXL355_I2C=n
  - ADXL355_SPI=n
  - SCD4X=n
  - SENSEAIR_SUNRISE_CO2=n
  - ADRF6780=n
  - MAX31865=m
  - Misc devices
  - INTEL_MEI_PXP=m
  - KEYBOARD_CYPRESS_SF=m
  - SENSORS_MAX6620=m
  - HT16K33=n
  - ALIBABA_ENI_VDPA=m
  - MLXREG_LC=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - SPI_CADENCE_XSPI=m
  - DRM_PANEL_EDP=m
  - DRM_PANEL_SAMSUNG_S6D27A1=n
  - DRM_PANEL_SHARP_LS060T1SX01=n
  - i386
    SND_AUDIO_GRAPH_CARD2=n
    SND_TEST_COMPONENT=m
  - ppc64
  - IPMI_IPMB=m
  - s390x
  - COMMAND_LINE_SIZE=4096 (default)
  - riscv64
  - TIME_NS=y
  - VIRTUALIZATION=y
  - KVM=m
  - SND_AUDIO_GRAPH_CARD2=n
  - SND_TEST_COMPONENT=m
  - */debug
  - DRM_DEBUG_MODESET_LOCK=y
- commit 2e30d30
* Sat Nov 13 2021 jslaby@suse.cz
- Linux 5.15.2 (bsc#1012628).
- rsi: fix control-message timeout (bsc#1012628).
- media: staging/intel-ipu3: css: Fix wrong size comparison
  imgu_css_fw_init (bsc#1012628).
- staging: r8188eu: fix memleak in rtw_wx_set_enc_ext
  (bsc#1012628).
- staging: rtl8192u: fix control-message timeouts (bsc#1012628).
- staging: r8712u: fix control-message timeout (bsc#1012628).
- comedi: vmk80xx: fix bulk and interrupt message timeouts
  (bsc#1012628).
- comedi: vmk80xx: fix bulk-buffer overflow (bsc#1012628).
- comedi: vmk80xx: fix transfer-buffer overflows (bsc#1012628).
- comedi: ni_usb6501: fix NULL-deref in command paths
  (bsc#1012628).
- comedi: dt9812: fix DMA buffers on stack (bsc#1012628).
- isofs: Fix out of bound access for corrupted isofs image
  (bsc#1012628).
- staging: rtl8712: fix use-after-free in rtl8712_dl_fw
  (bsc#1012628).
- btrfs: fix lzo_decompress_bio() kmap leakage (bsc#1012628).
- kfence: default to dynamic branch instead of static keys mode
  (bsc#1012628).
- kfence: always use static branches to guard kfence_alloc()
  (bsc#1012628).
- binder: don't detect sender/target during buffer cleanup
  (bsc#1012628).
- binder: use cred instead of task for getsecid (bsc#1012628).
- binder: use cred instead of task for selinux checks
  (bsc#1012628).
- binder: use euid from cred instead of using task (bsc#1012628).
- Revert "proc/wchan: use printk format instead of
  lookup_symbol_name()" (bsc#1012628).
- usb-storage: Add compatibility quirk flags for iODD 2531/2541
  (bsc#1012628).
- usb: musb: Balance list entry in musb_gadget_queue
  (bsc#1012628).
- usb: gadget: Mark USB_FSL_QE broken on 64-bit (bsc#1012628).
- usb: ehci: handshake CMD_RUN instead of STS_HALT (bsc#1012628).
- Revert "x86/kvm: fix vcpu-id indexed array sizes" (bsc#1012628).
- KVM: x86: avoid warning with -Wbitwise-instead-of-logical
  (bsc#1012628).
- commit 26a203b
* Thu Nov 11 2021 msuchanek@suse.de
- Fix problem with missing installkernel on Tumbleweed.
- commit 2ed6686
* Thu Nov 11 2021 mkubecek@suse.cz
- config: refresh
- drop PROFILE_ALL_BRANCHES where not available any more
- commit d11f2e4
* Tue Nov  9 2021 jeyu@suse.de
- Revert "rpm/config.sh: Compress modules with zstd (jsc#SLE-21256)."
  This reverts commit 648b5c7cb84366056aed609528029ae9c75c3d37.
  Reported to cause build problems in IBS (boo#1192457).
- commit dcfd611
* Tue Nov  9 2021 tiwai@suse.de
- Update config files: set CONFIG_FORTIFY_SOURCE=y consistently (bsc#1192476)
- commit 3837451
* Mon Nov  8 2021 msuchanek@suse.de
- Update config files (bsc#1192456).
  CONFIG_IMA_TRUSTED_KEYRING=y
- commit 2251920
* Sun Nov  7 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and move to appropriate section
  - patches.suse/ALSA-usb-audio-Restrict-rates-for-the-shared-clocks.patch
- commit 651a971
* Sat Nov  6 2021 jslaby@suse.cz
- Linux 5.15.1 (bsc#1012628).
- sfc: Fix reading non-legacy supported link modes (bsc#1012628).
- Revert "xhci: Set HCD flag to defer primary roothub
  registration" (bsc#1012628).
- Revert "usb: core: hcd: Add support for deferring roothub
  registration" (bsc#1012628).
- drm/amdkfd: fix boot failure when iommu is disabled in Picasso
  (bsc#1012628).
- Revert "soc: imx: gpcv2: move reset assert after requesting
  domain power up" (bsc#1012628).
- ARM: 9120/1: Revert "amba: make use of -1 IRQs warn"
  (bsc#1012628).
- Revert "wcn36xx: Disable bmps when encryption is disabled"
  (bsc#1012628).
- drm/amdgpu: revert "Add autodump debugfs node for gpu reset v8"
  (bsc#1012628).
- drm/amd/display: Revert "Directly retrain link from debugfs"
  (bsc#1012628).
- Revert "drm/i915/gt: Propagate change in error status to
  children on unhold" (bsc#1012628).
- ALSA: usb-audio: Add quirk for Audient iD14 (bsc#1012628).
- commit 7ecebb2
* Fri Nov  5 2021 tiwai@suse.de
- Input: i8042 - Add deferred probe support (bsc#1190256).
- commit 5a246e6
* Fri Nov  5 2021 mkubecek@suse.cz
- update patch metadata
- update upstream reference
  - patches.suse/arm64-dts-rockchip-Disable-CDN-DP-on-Pinebook-Pro.patch
- commit aa05ab3
* Fri Nov  5 2021 mkubecek@suse.cz
- series.conf: cleanup
- move to the section for short lived patches:
  - patches.suse/rtw89-Fix-crash-by-loading-compressed-firmware-file.patch
- commit 1fb2e08
* Fri Nov  5 2021 tiwai@suse.de
- rtw89: Fix crash by loading compressed firmware file
  (bsc#1188303).
- commit 42e1103
* Wed Nov  3 2021 mkubecek@suse.cz
- supported-flag: consolidate a bit more
  patches.suse/revert-modpost-remove-get_next_text-and-make-grab-release_-file-s.patch
  is a partial revert of mainline commit 75893572d453 ("modpost: remove
  get_next_text() and make {grab,release_}file static"); it restores function
  get_next_line() which was removed in mainline but we still need it.
  As the function is static and only used in code built only with
  CONFIG_SUSE_KERNEL_SUPPORTED enabled, compiler issues a warning when
  building with CONFIG_SUSE_KERNEL_SUPPORTED disabled. Merge the patch into
  patches.suse/add-suse-supported-flag.patch and move the function into
  an #ifdef CONFIG_SUSE_KERNEL_SUPPORTED block.
  The only effect on expanded tree is moving get_next_line() lower so that it
  is only compiled when CONFIG_SUSE_KERNEL_SUPPORTED=n.
- commit 0c612fa
* Wed Nov  3 2021 tiwai@suse.de
- Input: i8042 - Add quirk for Fujitsu Lifebook T725
  (bsc#1191980).
- commit 44f2754
* Wed Nov  3 2021 mkubecek@suse.cz
- update patch metadata
- update upstream references:
  - patches.suse/Bluetooth-sco-Fix-lock_sock-blockage-by-memcpy_from_.patch
  - patches.suse/media-firewire-firedtv-avc-fix-a-buffer-overflow-in-.patch
  - patches.suse/rtw89-Fix-two-spelling-mistakes-in-debug-messages.patch
  - patches.suse/rtw89-Fix-variable-dereferenced-before-check-sta.patch
  - patches.suse/rtw89-Remove-redundant-check-of-ret-after-call-to-rt.patch
  - patches.suse/rtw89-add-Realtek-802.11ax-driver.patch
  - patches.suse/rtw89-fix-error-function-parameter.patch
  - patches.suse/rtw89-fix-return-value-check-in-rtw89_cam_send_sec_k.patch
  - patches.suse/rtw89-fix-return-value-in-hfc_pub_cfg_chk.patch
  - patches.suse/rtw89-remove-duplicate-register-definitions.patch
  - patches.suse/rtw89-remove-unneeded-semicolon.patch
- commit 2e35b89
* Mon Nov  1 2021 mcgrof@suse.com
- Drop patches where were added for ustat()
  glibc doesn't expose this system call anymore, and so no point in
  carrying this delta. LTP does test for this but the test uses its
  own headers instead of libc for it. It is not worth carrying this
  delta for a deprecated call.
  This patch set was tested with kernel-ci and found no new regressions
  with btrfs.
- Delete
  patches.suse/btrfs-fs-super.c-add-new-super-block-devices-super_block_d.patch.
- Delete patches.suse/btrfs-use-the-new-VFS-super_block_dev.patch.
  (Cherry picked from commit ea7c7f6bd63bd560c95f994b1aff269fa53bfc8d)
- commit 9fa259a
* Mon Nov  1 2021 tiwai@suse.de
- Refresh patches.suse/iwlwifi-module-firmware-ucode-fix.patch (boo#1191417)
  There is one model that contains *-66.ucode.  Add the exception.
- commit f0d7a09
* Mon Nov  1 2021 mkubecek@suse.cz
- Update to 5.15 final
- refresh configs
  - drop CONFIG_RESET_PISTACHIO
- commit 2ab31e7
* Mon Nov  1 2021 mkubecek@suse.cz
- config: update and enable armv6hl
  Update armv6hl configs to 5.15-rc7 and enable them. Where possible, values
  are taken from armv7hl, the rest is guesswork based on values of similar
  config options.
- commit 22c5286
* Mon Nov  1 2021 mkubecek@suse.cz
- config: update and enable armv7hl
  Update armv7hl configs to 5.15-rc7 and enable them. Where possible, values
  are taken from arm64, the rest is guesswork based on values of similar
  config options.
- commit 3b362e7
* Mon Nov  1 2021 mkubecek@suse.cz
- config: update and enable arm64
  Update arm64 configs to 5.15-rc7 and enable them. Where possible, values
  are taken from x86_64, the rest is guesswork based on values of similar
  config options.
- commit 482d5b4
* Fri Oct 29 2021 tiwai@suse.de
- rtw89: Fix variable dereferenced before check 'sta'
  (bsc#1191321).
- rtw89: fix return value in hfc_pub_cfg_chk (bsc#1191321).
- rtw89: remove duplicate register definitions (bsc#1191321).
- rtw89: fix error function parameter (bsc#1191321).
- rtw89: remove unneeded semicolon (bsc#1191321).
- rtw89: fix return value check in rtw89_cam_send_sec_key_cmd()
  (bsc#1191321).
- rtw89: Remove redundant check of ret after call to
  rtw89_mac_enable_bb_rf (bsc#1191321).
- rtw89: Fix two spelling mistakes in debug messages
  (bsc#1191321).
- rtw89: Fix variable dereferenced before check 'sta'
  (bsc#1191321).
- rtw89: fix return value in hfc_pub_cfg_chk (bsc#1191321).
- rtw89: remove duplicate register definitions (bsc#1191321).
- rtw89: fix error function parameter (bsc#1191321).
- rtw89: remove unneeded semicolon (bsc#1191321).
- rtw89: fix return value check in rtw89_cam_send_sec_key_cmd()
  (bsc#1191321).
- rtw89: Remove redundant check of ret after call to
  rtw89_mac_enable_bb_rf (bsc#1191321).
- rtw89: Fix two spelling mistakes in debug messages
  (bsc#1191321).
- commit 719bb03
* Thu Oct 28 2021 ykaukab@suse.de
- config: arm64: enable dpaa2 restool support
  References: bsc#1191190
- commit c86f145
* Wed Oct 27 2021 jslaby@suse.cz
- Linux 5.14.15 (bsc#1012628).
- block/mq-deadline: Move dd_queued() to fix defined but not
  used warning (bsc#1012628).
- parisc: math-emu: Fix fall-through warnings (bsc#1012628).
- sh: pgtable-3level: fix cast to pointer from integer of
  different size (bsc#1012628).
- arm: dts: vexpress-v2p-ca9: Fix the SMB unit-address
  (bsc#1012628).
- ARM: dts: at91: sama5d2_som1_ek: disable ISC node by default
  (bsc#1012628).
- block: decode QUEUE_FLAG_HCTX_ACTIVE in debugfs output
  (bsc#1012628).
- xen/x86: prevent PVH type from getting clobbered (bsc#1012628).
- r8152: avoid to resubmit rx immediately (bsc#1012628).
- drm/amdgpu/display: fix dependencies for DRM_AMD_DC_SI
  (bsc#1012628).
- drm/amdgpu: init iommu after amdkfd device init (bsc#1012628).
- xtensa: xtfpga: use CONFIG_USE_OF instead of CONFIG_OF
  (bsc#1012628).
- xtensa: xtfpga: Try software restart before simulating CPU reset
  (bsc#1012628).
- NFSD: Keep existing listeners on portlist error (bsc#1012628).
- powerpc/lib: Add helper to check if offset is within conditional
  branch range (bsc#1012628).
- powerpc/bpf: Validate branch ranges (bsc#1012628).
- powerpc/security: Add a helper to query stf_barrier type
  (bsc#1012628).
- powerpc/bpf: Emit stf barrier instruction sequences for
  BPF_NOSPEC (bsc#1012628).
- ASoC: pcm512x: Mend accesses to the I2S_1 and I2S_2 registers
  (bsc#1012628).
- ASoC: fsl_xcvr: Fix channel swap issue with ARC (bsc#1012628).
- ASoC: pcm179x: Add missing entries SPI to device ID table
  (bsc#1012628).
- ASoC: cs4341: Add SPI device ID table (bsc#1012628).
- KVM: arm64: Fix host stage-2 PGD refcount (bsc#1012628).
- KVM: arm64: Release mmap_lock when using VM_SHARED with MTE
  (bsc#1012628).
- netfilter: xt_IDLETIMER: fix panic that occurs when timer_type
  has garbage value (bsc#1012628).
- netfilter: nf_tables: skip netdev events generated on netns
  removal (bsc#1012628).
- dma-debug: fix sg checks in debug_dma_map_sg() (bsc#1012628).
- ASoC: wm8960: Fix clock configuration on slave mode
  (bsc#1012628).
- ice: Fix failure to re-add LAN/RDMA Tx queues (bsc#1012628).
- ice: Avoid crash from unnecessary IDA free (bsc#1012628).
- ice: fix getting UDP tunnel entry (bsc#1012628).
- ice: Print the api_patch as part of the fw.mgmt.api
  (bsc#1012628).
- netfilter: ip6t_rt: fix rt0_hdr parsing in rt_mt6 (bsc#1012628).
- netfilter: ipvs: make global sysctl readonly in non-init netns
  (bsc#1012628).
- sctp: fix transport encap_port update in sctp_vtag_verify
  (bsc#1012628).
- lan78xx: select CRC32 (bsc#1012628).
- tcp: md5: Fix overlap between vrf and non-vrf keys
  (bsc#1012628).
- ipv6: When forwarding count rx stats on the orig netdev
  (bsc#1012628).
- hamradio: baycom_epp: fix build for UML (bsc#1012628).
- net: dsa: lantiq_gswip: fix register definition (bsc#1012628).
- net/sched: act_ct: Fix byte count on fragmented packets
  (bsc#1012628).
- NIOS2: irqflags: rename a redefined register name (bsc#1012628).
- net: dsa: Fix an error handling path in
  'dsa_switch_parse_ports_of()' (bsc#1012628).
- powerpc/smp: do not decrement idle task preempt count in CPU
  offline (bsc#1012628).
- net: hns3: Add configuration of TM QCN error event
  (bsc#1012628).
- net: hns3: reset DWRR of unused tc to zero (bsc#1012628).
- net: hns3: add limit ets dwrr bandwidth cannot be 0
  (bsc#1012628).
- net: hns3: schedule the polling again when allocation fails
  (bsc#1012628).
- net: hns3: fix vf reset workqueue cannot exit (bsc#1012628).
- net: hns3: disable sriov before unload hclge layer
  (bsc#1012628).
- net: stmmac: Fix E2E delay mechanism (bsc#1012628).
- ptp: Fix possible memory leak in ptp_clock_register()
  (bsc#1012628).
- e1000e: Fix packet loss on Tiger Lake and later (bsc#1012628).
- igc: Update I226_K device ID (bsc#1012628).
- ice: Add missing E810 device ids (bsc#1012628).
- net/mlx5e: IPsec: Fix a misuse of the software parser's fields
  (bsc#1012628).
- net/mlx5e: IPsec: Fix work queue entry ethernet segment checksum
  flags (bsc#1012628).
- drm/panel: ilitek-ili9881c: Fix sync for Feixin K101-IM2BYL02
  panel (bsc#1012628).
- drm/kmb: Work around for higher system clock (bsc#1012628).
- drm/kmb: Remove clearing DPHY regs (bsc#1012628).
- drm/kmb: Disable change of plane parameters (bsc#1012628).
- drm/kmb: Corrected typo in handle_lcd_irq (bsc#1012628).
- drm/kmb: Enable ADV bridge after modeset (bsc#1012628).
- net: enetc: fix ethtool counter name for PM0_TERR (bsc#1012628).
- net: enetc: make sure all traffic classes can send large frames
  (bsc#1012628).
- can: rcar_can: fix suspend/resume (bsc#1012628).
- can: peak_usb: pcan_usb_fd_decode_status(): fix back to
  ERROR_ACTIVE state notification (bsc#1012628).
- can: peak_pci: peak_pci_remove(): fix UAF (bsc#1012628).
- can: isotp: isotp_sendmsg(): fix return error on FC timeout
  on TX path (bsc#1012628).
- can: isotp: isotp_sendmsg(): add result check for
  wait_event_interruptible() (bsc#1012628).
- can: isotp: isotp_sendmsg(): fix TX buffer concurrent access
  in isotp_sendmsg() (bsc#1012628).
- can: j1939: j1939_tp_rxtimer(): fix errant alert in
  j1939_tp_rxtimer (bsc#1012628).
- can: j1939: j1939_netdev_start(): fix UAF for rx_kref of
  j1939_priv (bsc#1012628).
- can: j1939: j1939_xtp_rx_dat_one(): cancel session if receive
  TP.DT with error length (bsc#1012628).
- can: j1939: j1939_xtp_rx_rts_session_new(): abort TP less than
  9 bytes (bsc#1012628).
- ceph: skip existing superblocks that are blocklisted or shut
  down when mounting (bsc#1012628).
- ceph: fix handling of "meta" errors (bsc#1012628).
- tracing: Have all levels of checks prevent recursion
  (bsc#1012628).
- ocfs2: fix data corruption after conversion from inline format
  (bsc#1012628).
- ocfs2: mount fails with buffer overflow in strlen (bsc#1012628).
- mm/userfaultfd: selftests: fix memory corruption with thp
  enabled (bsc#1012628).
- userfaultfd: fix a race between writeprotect and exit_mmap()
  (bsc#1012628).
- mm/mempolicy: do not allow illegal MPOL_F_NUMA_BALANCING |
  MPOL_LOCAL in mbind() (bsc#1012628).
- elfcore: correct reference to CONFIG_UML (bsc#1012628).
- vfs: check fd has read access in kernel_read_file_from_fd()
  (bsc#1012628).
- mm/secretmem: fix NULL page->mapping dereference in
  page_is_secretmem() (bsc#1012628).
- ALSA: usb-audio: Provide quirk for Sennheiser GSP670 Headset
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Clevo PC50HS (bsc#1012628).
- ASoC: DAPM: Fix missing kctl change notifications (bsc#1012628).
- ASoC: nau8824: Fix headphone vs headset, button-press detection
  no longer working (bsc#1012628).
- blk-cgroup: blk_cgroup_bio_start() should use irq-safe
  operations on blkg->iostat_cpu (bsc#1012628).
- audit: fix possible null-pointer dereference in
  audit_filter_rules (bsc#1012628).
- net: dsa: mt7530: correct ds->num_ports (bsc#1012628).
- ucounts: Move get_ucounts from cred_alloc_blank to
  key_change_session_keyring (bsc#1012628).
- ucounts: Pair inc_rlimit_ucounts with dec_rlimit_ucoutns in
  commit_creds (bsc#1012628).
- ucounts: Proper error handling in set_cred_ucounts
  (bsc#1012628).
- ucounts: Fix signal ucount refcounting (bsc#1012628).
- KVM: PPC: Book3S HV: Fix stack handling in
  idle_kvm_start_guest() (bsc#1012628).
- KVM: PPC: Book3S HV: Make idle_kvm_start_guest() return 0 if
  it went to guest (bsc#1012628).
- powerpc/idle: Don't corrupt back chain when going idle
  (bsc#1012628).
- mm, slub: fix mismatch between reconstructed freelist depth
  and cnt (bsc#1012628).
- mm, slub: fix potential memoryleak in kmem_cache_open()
  (bsc#1012628).
- mm, slub: fix potential use-after-free in slab_debugfs_fops
  (bsc#1012628).
- mm, slub: fix incorrect memcg slab count for bulk free
  (bsc#1012628).
- KVM: nVMX: promptly process interrupts delivered while in
  guest mode (bsc#1012628).
- KVM: SEV: Flush cache on non-coherent systems before
  RECEIVE_UPDATE_DATA (bsc#1012628).
- KVM: SEV-ES: rename guest_ins_data to sev_pio_data
  (bsc#1012628).
- KVM: SEV-ES: clean up kvm_sev_es_ins/outs (bsc#1012628).
- KVM: SEV-ES: keep INS functions together (bsc#1012628).
- KVM: SEV-ES: fix length of string I/O (bsc#1012628).
- KVM: SEV-ES: go over the sev_pio_data buffer in multiple passes
  if needed (bsc#1012628).
- KVM: SEV-ES: reduce ghcb_sa_len to 32 bits (bsc#1012628).
- KVM: x86: leave vcpu->arch.pio.count alone in
  emulator_pio_in_out (bsc#1012628).
- KVM: x86: check for interrupts before deciding whether to exit
  the fast path (bsc#1012628).
- KVM: x86: split the two parts of emulator_pio_in (bsc#1012628).
- KVM: x86: remove unnecessary arguments from
  complete_emulator_pio_in (bsc#1012628).
- nfc: nci: fix the UAF of rf_conn_info object (bsc#1012628).
- isdn: cpai: check ctr->cnr to avoid array index out of bound
  (bsc#1012628).
- netfilter: Kconfig: use 'default y' instead of 'm' for bool
  config option (bsc#1012628).
- selftests: netfilter: remove stray bash debug line
  (bsc#1012628).
- net: bridge: mcast: use multicast_membership_interval for IGMPv3
  (bsc#1012628).
- KVM: SEV-ES: Set guest_state_protected after VMSA update
  (bsc#1012628).
- drm: mxsfb: Fix NULL pointer dereference crash on unload
  (bsc#1012628).
- net: hns3: fix the max tx size according to user manual
  (bsc#1012628).
- KVM: MMU: Reset mmu->pkru_mask to avoid stale data
  (bsc#1012628).
- kunit: fix reference count leak in kfree_at_end (bsc#1012628).
- drm/msm/a6xx: Serialize GMU communication (bsc#1012628).
- gcc-plugins/structleak: add makefile var for disabling
  structleak (bsc#1012628).
- iio/test-format: build kunit tests without structleak plugin
  (bsc#1012628).
- device property: build kunit tests without structleak plugin
  (bsc#1012628).
- thunderbolt: build kunit tests without structleak plugin
  (bsc#1012628).
- bitfield: build kunit tests without structleak plugin
  (bsc#1012628).
- objtool: Check for gelf_update_rel[a] failures (bsc#1012628).
- objtool: Update section header before relocations (bsc#1012628).
- btrfs: deal with errors when checking if a dir entry exists
  during log replay (bsc#1012628).
- net: stmmac: add support for dwmac 3.40a (bsc#1012628).
- ARM: dts: spear3xx: Fix gmac node (bsc#1012628).
- isdn: mISDN: Fix sleeping function called from invalid context
  (bsc#1012628).
- platform/x86: intel_scu_ipc: Increase virtual timeout to 10s
  (bsc#1012628).
- platform/x86: intel_scu_ipc: Update timeout value in comment
  (bsc#1012628).
- ALSA: hda: avoid write to STATESTS if controller is in reset
  (bsc#1012628).
- spi: Fix deadlock when adding SPI controllers on SPI buses
  (bsc#1012628).
- spi-mux: Fix false-positive lockdep splats (bsc#1012628).
- libperf test evsel: Fix build error on !x86 architectures
  (bsc#1012628).
- libperf tests: Fix test_stat_cpu (bsc#1012628).
- perf/x86/msr: Add Sapphire Rapids CPU support (bsc#1012628).
- Input: snvs_pwrkey - add clk handling (bsc#1012628).
- ASoC: codec: wcd938x: Add irq config support (bsc#1012628).
- scsi: iscsi: Fix set_param() handling (bsc#1012628).
- scsi: storvsc: Fix validation for unsolicited incoming packets
  (bsc#1012628).
- scsi: mpi3mr: Fix duplicate device entries when scanning
  through sysfs (bsc#1012628).
- scsi: qla2xxx: Fix a memory leak in an error path of
  qla2x00_process_els() (bsc#1012628).
- mm/thp: decrease nr_thps in file's mapping on THP split
  (bsc#1012628).
- sched/scs: Reset the shadow stack when idle_task_exit
  (bsc#1012628).
- net: hns3: fix for miscalculation of rx unused desc
  (bsc#1012628).
- net/mlx5: Lag, move lag destruction to a workqueue
  (bsc#1012628).
- net/mlx5: Lag, change multipath and bonding to be mutually
  exclusive (bsc#1012628).
- drm/kmb: Enable alpha blended second plane (bsc#1012628).
- drm/kmb: Limit supported mode to 1080p (bsc#1012628).
- autofs: fix wait name hash calculation in autofs_wait()
  (bsc#1012628).
- scsi: core: Fix shost->cmd_per_lun calculation in
  scsi_add_host_with_dma() (bsc#1012628).
- s390/pci: cleanup resources only if necessary (bsc#1012628).
- s390/pci: fix zpci_zdev_put() on reserve (bsc#1012628).
- bpf, test, cgroup: Use sk_{alloc,free} for test cases
  (bsc#1012628).
- net: mdiobus: Fix memory leak in __mdiobus_register
  (bsc#1012628).
- e1000e: Separate TGP board type from SPT (bsc#1012628).
- ARM: 9122/1: select HAVE_FUTEX_CMPXCHG (bsc#1012628).
- pinctrl: stm32: use valid pin identifier in
  stm32_pinctrl_resume() (bsc#1012628).
- Update config files.
- commit 3416a5a
* Mon Oct 25 2021 mkubecek@suse.cz
- Update to 5.15-rc7
- commit 89a05b7
* Thu Oct 21 2021 jslaby@suse.cz
- Update
  patches.kernel.org/5.14.14-060-x86-fpu-Mask-out-the-invalid-MXCSR-bits-prope.patch
  (bsc#1012628 bsc#1191855).
- commit 2b5383f
* Thu Oct 21 2021 jslaby@suse.cz
- Linux 5.14.14 (bsc#1012628).
- ALSA: usb-audio: Add quirk for VF0770 (bsc#1012628).
- ALSA: pcm: Workaround for a wrong offset in SYNC_PTR compat
  ioctl (bsc#1012628).
- ALSA: usb-audio: Fix a missing error check in scarlett gen2
  mixer (bsc#1012628).
- ALSA: seq: Fix a potential UAF by wrong private_free call order
  (bsc#1012628).
- ALSA: hda/realtek: Enable 4-speaker output for Dell Precision
  5560 laptop (bsc#1012628).
- ALSA: hda - Enable headphone mic on Dell Latitude laptops with
  ALC3254 (bsc#1012628).
- ALSA: hda/realtek: Complete partial device name to avoid
  ambiguity (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Clevo X170KM-G (bsc#1012628).
- ALSA: hda/realtek - ALC236 headset MIC recording issue
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for TongFang PHxTxX1 (bsc#1012628).
- ALSA: hda/realtek: Fix for quirk to enable speaker output on
  the Lenovo 13s Gen2 (bsc#1012628).
- ALSA: hda/realtek: Fix the mic type detection issue for ASUS
  G551JW (bsc#1012628).
- platform/x86: gigabyte-wmi: add support for B550 AORUS ELITE
  AX V2 (bsc#1012628).
- platform/x86: amd-pmc: Add alternative acpi id for PMC
  controller (bsc#1012628).
- spi: atmel: Fix PDC transfer setup bug (bsc#1012628).
- mtd: rawnand: qcom: Update code word value for raw read
  (bsc#1012628).
- nds32/ftrace: Fix Error: invalid operands (*UND* and *UND*
  sections) for `^' (bsc#1012628).
- dm: fix mempool NULL pointer race when completing IO
  (bsc#1012628).
- ACPI: PM: Include alternate AMDI0005 id in special behaviour
  (bsc#1012628).
- dm rq: don't queue request to blk-mq during DM suspend
  (bsc#1012628).
- s390: fix strrchr() implementation (bsc#1012628).
- clk: socfpga: agilex: fix duplicate s2f_user0_clk (bsc#1012628).
- csky: don't let sigreturn play with priveleged bits of status
  register (bsc#1012628).
- csky: Fixup regs.sr broken in ptrace (bsc#1012628).
- drm/fbdev: Clamp fbdev surface size if too large (bsc#1012628).
- arm64/hugetlb: fix CMA gigantic page order for non-4K PAGE_SIZE
  (bsc#1012628).
- drm/nouveau/fifo: Reinstate the correct engine bit programming
  (bsc#1012628).
- drm/msm: Do not run snapshot on non-DPU devices (bsc#1012628).
- drm/msm: Avoid potential overflow in timeout_to_jiffies()
  (bsc#1012628).
- btrfs: unlock newly allocated extent buffer after error
  (bsc#1012628).
- btrfs: deal with errors when replaying dir entry during log
  replay (bsc#1012628).
- btrfs: deal with errors when adding inode reference during
  log replay (bsc#1012628).
- btrfs: check for error when looking up inode during dir entry
  replay (bsc#1012628).
- btrfs: update refs for any root except tree log roots
  (bsc#1012628).
- btrfs: fix abort logic in btrfs_replace_file_extents
  (bsc#1012628).
- module: fix clang CFI with MODULE_UNLOAD=n (bsc#1012628).
- x86/resctrl: Free the ctrlval arrays when
  domain_setup_mon_state() fails (bsc#1012628).
- mei: me: add Ice Lake-N device id (bsc#1012628).
- mei: hbm: drop hbm responses on early shutdown (bsc#1012628).
- USB: xhci: dbc: fix tty registration race (bsc#1012628).
- xhci: guard accesses to ep_state in xhci_endpoint_reset()
  (bsc#1012628).
- xhci: add quirk for host controllers that don't update endpoint
  DCS (bsc#1012628).
- xhci: Fix command ring pointer corruption while aborting a
  command (bsc#1012628).
- xhci: Enable trust tx length quirk for Fresco FL11 USB
  controller (bsc#1012628).
- cb710: avoid NULL pointer subtraction (bsc#1012628).
- efi/cper: use stack buffer for error record decoding
  (bsc#1012628).
- efi: Change down_interruptible() in virt_efi_reset_system()
  to down_trylock() (bsc#1012628).
- usb: musb: dsps: Fix the probe error path (bsc#1012628).
- Input: xpad - add support for another USB ID of Nacon GC-100
  (bsc#1012628).
- USB: serial: qcserial: add EM9191 QDL support (bsc#1012628).
- USB: serial: option: add Quectel EC200S-CN module support
  (bsc#1012628).
- USB: serial: option: add Telit LE910Cx composition 0x1204
  (bsc#1012628).
- USB: serial: option: add prod. id for Quectel EG91
  (bsc#1012628).
- misc: fastrpc: Add missing lock before accessing find_vma()
  (bsc#1012628).
- virtio: write back F_VERSION_1 before validate (bsc#1012628).
- EDAC/armada-xp: Fix output of uncorrectable error counter
  (bsc#1012628).
- nvmem: Fix shift-out-of-bound (UBSAN) with byte size cells
  (bsc#1012628).
- virtio-blk: remove unneeded "likely" statements (bsc#1012628).
- Revert "virtio-blk: Add validation for block size in config
  space" (bsc#1012628).
- x86/Kconfig: Do not enable AMD_MEM_ENCRYPT_ACTIVE_BY_DEFAULT
  automatically (bsc#1012628).
- powerpc/xive: Discard disabled interrupts in get_irqchip_state()
  (bsc#1012628).
- iio: adc: aspeed: set driver data when adc probe (bsc#1012628).
- drivers: bus: simple-pm-bus: Add support for probing simple
  bus only devices (bsc#1012628).
- driver core: Reject pointless SYNC_STATE_ONLY device links
  (bsc#1012628).
- iio: adc: ad7192: Add IRQ flag (bsc#1012628).
- iio: adc: ad7780: Fix IRQ flag (bsc#1012628).
- iio: adc: ad7793: Fix IRQ flag (bsc#1012628).
- iio: adis16480: fix devices that do not support sleep mode
  (bsc#1012628).
- iio: adc128s052: Fix the error handling path of 'adc128_probe()'
  (bsc#1012628).
- iio: adc: max1027: Fix wrong shift with 12-bit devices
  (bsc#1012628).
- iio: adis16475: fix deadlock on frequency set (bsc#1012628).
- iio: mtk-auxadc: fix case IIO_CHAN_INFO_PROCESSED (bsc#1012628).
- iio: light: opt3001: Fixed timeout error when 0 lux
  (bsc#1012628).
- iio: accel: fxls8962af: return IRQ_HANDLED when fifo is flushed
  (bsc#1012628).
- iio: adc: max1027: Fix the number of max1X31 channels
  (bsc#1012628).
- iio: ssp_sensors: add more range checking in
  ssp_parse_dataframe() (bsc#1012628).
- iio: ssp_sensors: fix error code in ssp_print_mcu_debug()
  (bsc#1012628).
- Input: resistive-adc-touch - fix division by zero error on z1 ==
  0 (bsc#1012628).
- eeprom: 93xx46: Add SPI device ID table (bsc#1012628).
- eeprom: 93xx46: fix MODULE_DEVICE_TABLE (bsc#1012628).
- eeprom: at25: Add SPI ID table (bsc#1012628).
- fpga: ice40-spi: Add SPI device ID table (bsc#1012628).
- iio: dac: ti-dac5571: fix an error code in probe()
  (bsc#1012628).
- tracing: Fix missing osnoise tracer on max_latency
  (bsc#1012628).
- tee: optee: Fix missing devices unregister during optee_remove
  (bsc#1012628).
- ARM: dts: bcm2711-rpi-4-b: Fix usb's unit address (bsc#1012628).
- ARM: dts: bcm283x: Fix VEC address for BCM2711 (bsc#1012628).
- ARM: dts: bcm2711: fix MDIO #address- and #size-cells
  (bsc#1012628).
- firmware: arm_ffa: Fix __ffa_devices_unregister (bsc#1012628).
- firmware: arm_ffa: Add missing remove callback to ffa_bus_type
  (bsc#1012628).
- ARM: dts: bcm2711-rpi-4-b: fix sd_io_1v8_reg regulator states
  (bsc#1012628).
- ARM: dts: bcm2711-rpi-4-b: Fix pcie0's unit address formatting
  (bsc#1012628).
- clk: renesas: rzg2l: Fix clk status function (bsc#1012628).
- nvme-pci: Fix abort command id (bsc#1012628).
- sctp: account stream padding length for reconf chunk
  (bsc#1012628).
- gpio: 74x164: Add SPI device ID table (bsc#1012628).
- gpio: pca953x: Improve bias setting (bsc#1012628).
- net: arc: select CRC32 (bsc#1012628).
- net: korina: select CRC32 (bsc#1012628).
- net/smc: improved fix wait on already cleared link
  (bsc#1012628).
- net/mlx5e: Fix memory leak in mlx5_core_destroy_cq() error path
  (bsc#1012628).
- net/mlx5e: Mutually exclude RX-FCS and RX-port-timestamp
  (bsc#1012628).
- net/mlx5e: Switchdev representors are not vlan challenged
  (bsc#1012628).
- net: stmmac: fix get_hw_feature() on old hardware (bsc#1012628).
- net: phy: Do not shutdown PHYs in READY state (bsc#1012628).
- net: dsa: mv88e6xxx: don't use PHY_DETECT on internal PHY's
  (bsc#1012628).
- net: dsa: microchip: Added the condition for scheduling
  ksz_mib_read_work (bsc#1012628).
- net: dsa: fix spurious error message when unoffloaded port
  leaves bridge (bsc#1012628).
- net: encx24j600: check error in devm_regmap_init_encx24j600
  (bsc#1012628).
- ethernet: s2io: fix setting mac address during resume
  (bsc#1012628).
- vhost-vdpa: Fix the wrong input in config_cb (bsc#1012628).
- nfc: fix error handling of nfc_proto_register() (bsc#1012628).
- NFC: digital: fix possible memory leak in
  digital_tg_listen_mdaa() (bsc#1012628).
- NFC: digital: fix possible memory leak in
  digital_in_send_sdd_req() (bsc#1012628).
- pata_legacy: fix a couple uninitialized variable bugs
  (bsc#1012628).
- ata: ahci_platform: fix null-ptr-deref in
  ahci_platform_enable_regulators() (bsc#1012628).
- mlxsw: thermal: Fix out-of-bounds memory accesses (bsc#1012628).
- platform/mellanox: mlxreg-io: Fix argument base in kstrtou32()
  call (bsc#1012628).
- platform/mellanox: mlxreg-io: Fix read access of n-bytes size
  attributes (bsc#1012628).
- spi: spidev: Add SPI ID table (bsc#1012628).
- spi: bcm-qspi: clear MSPI spifie interrupt during probe
  (bsc#1012628).
- drm/panel: olimex-lcd-olinuxino: select CRC32 (bsc#1012628).
- drm/edid: In connector_bad_edid() cap num_of_ext by num_blocks
  read (bsc#1012628).
- drm/msm: Fix null pointer dereference on pointer edp
  (bsc#1012628).
- drm/msm/mdp5: fix cursor-related warnings (bsc#1012628).
- drm/msm/submit: fix overflow check on 64-bit architectures
  (bsc#1012628).
- drm/msm/a6xx: Track current ctx by seqno (bsc#1012628).
- drm/msm/a4xx: fix error handling in a4xx_gpu_init()
  (bsc#1012628).
- drm/msm/a3xx: fix error handling in a3xx_gpu_init()
  (bsc#1012628).
- drm/msm/dsi: dsi_phy_14nm: Take ready-bit into account in
  poll_for_ready (bsc#1012628).
- drm/msm/dsi: Fix an error code in msm_dsi_modeset_init()
  (bsc#1012628).
- drm/msm/dsi: fix off by one in dsi_bus_clk_enable error handling
  (bsc#1012628).
- acpi/arm64: fix next_platform_timer() section mismatch error
  (bsc#1012628).
- platform/x86: intel_scu_ipc: Fix busy loop expiry time
  (bsc#1012628).
- mqprio: Correct stats in mqprio_dump_class_stats()
  (bsc#1012628).
- mptcp: fix possible stall on recvmsg() (bsc#1012628).
- qed: Fix missing error code in qed_slowpath_start()
  (bsc#1012628).
- r8152: select CRC32 and CRYPTO/CRYPTO_HASH/CRYPTO_SHA256
  (bsc#1012628).
- ice: fix locking for Tx timestamp tracking flush (bsc#1012628).
- block/rnbd-clt-sysfs: fix a couple uninitialized variable bugs
  (bsc#1012628).
- nfp: flow_offload: move flow_indr_dev_register from app init
  to app start (bsc#1012628).
- net: mscc: ocelot: make use of all 63 PTP timestamp identifiers
  (bsc#1012628).
- net: mscc: ocelot: avoid overflowing the PTP timestamp FIFO
  (bsc#1012628).
- net: mscc: ocelot: warn when a PTP IRQ is raised for an unknown
  skb (bsc#1012628).
- net: mscc: ocelot: deny TX timestamping of non-PTP packets
  (bsc#1012628).
- net: mscc: ocelot: cross-check the sequence id from the
  timestamp FIFO with the skb PTP header (bsc#1012628).
- net: dsa: felix: break at first CPU port during init and
  teardown (bsc#1012628).
- ionic: don't remove netdev->dev_addr when syncing uc list
  (bsc#1012628).
- commit 6859230
* Wed Oct 20 2021 jack@suse.cz
- Update tags in patches.suse/readahead-request-tunables.patch (VM
  Performance, bsc#548529 bsc#1189955).
- commit b531271
* Wed Oct 20 2021 tiwai@suse.de
- media: firewire: firedtv-avc: fix a buffer overflow in
  avc_ca_pmt() (CVE-2021-3542 bsc#1184673).
- commit 45f5ddd
* Wed Oct 20 2021 jslaby@suse.cz
- x86/fpu: Mask out the invalid MXCSR bits properly (x86_32
  breakage).
- commit 565cd48
* Wed Oct 20 2021 msuchanek@suse.de
- kernel-binary.spec: Bump dwarves requirement to 1.22.
  1.22 is finally released, and it is required for functionality.
- commit c88d345
* Tue Oct 19 2021 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: move to zstd for the initrd
  Newer distros have capability to decompress zstd, which
  provides a 2-5%% better compression ratio at very similar
  cpu overhead. Plus this tests the zstd codepaths now as well.
- commit 3d53a5b
* Tue Oct 19 2021 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: reduce initrd functionality
  For building in OBS, we always build inside a virtual machine
  that gets a new, freshly created scratch filesystem image. So
  we do not need to handle fscks because that ain't gonna happen,
  as well as not we do not need to handle microcode update in the
  initrd as these only can be run on the host system anyway. We
  can also strip and hardlink as an additional optimisation that
  should not significantly hurt.
- commit c72c6fc
* Mon Oct 18 2021 tiwai@suse.de
- Update upstream commit id for rtw89 patch (bsc#1191321)
- commit 9587a7b
* Mon Oct 18 2021 mkubecek@suse.cz
- Update to 5.15-rc6
- refresh configs
  - drop SIMPLE_PM_BUS
- commit b7fe390
* Sun Oct 17 2021 jslaby@suse.cz
- Linux 5.14.13 (bsc#1012628).
- hwmon: (pmbus/ibm-cffps) max_power_out swap changes
  (bsc#1012628).
- io_uring: kill fasync (bsc#1012628).
- sched: Always inline is_percpu_thread() (bsc#1012628).
- perf/core: fix userpage->time_enabled of inactive events
  (bsc#1012628).
- scsi: qla2xxx: Fix excessive messages during device logout
  (bsc#1012628).
- scsi: virtio_scsi: Fix spelling mistake "Unsupport" ->
  "Unsupported" (bsc#1012628).
- scsi: ses: Fix unsigned comparison with less than zero
  (bsc#1012628).
- drm/amdgpu: fix gart.bo pin_count leak (bsc#1012628).
- net: sun: SUNVNET_COMMON should depend on INET (bsc#1012628).
- vboxfs: fix broken legacy mount signature checking
  (bsc#1012628).
- net: bgmac-platform: handle mac-address deferral (bsc#1012628).
- mac80211: check return value of rhashtable_init (bsc#1012628).
- net: prevent user from passing illegal stab size (bsc#1012628).
- hwmon: (ltc2947) Properly handle errors when looking for the
  external clock (bsc#1012628).
- m68k: Handle arrivals of multiple signals correctly
  (bsc#1012628).
- pinctrl: qcom: sc7280: Add PM suspend callbacks (bsc#1012628).
- mac80211: Drop frames from invalid MAC address in ad-hoc mode
  (bsc#1012628).
- netfilter: nf_nat_masquerade: defer conntrack walk to work queue
  (bsc#1012628).
- netfilter: nf_nat_masquerade: make async masq_inet6_event
  handling generic (bsc#1012628).
- KVM: arm64: nvhe: Fix missing FORCE for hyp-reloc.S build rule
  (bsc#1012628).
- ASoC: SOF: loader: release_firmware() on load failure to avoid
  batching (bsc#1012628).
- HID: wacom: Add new Intuos BT (CTL-4100WL/CTL-6100WL) device
  IDs (bsc#1012628).
- netfilter: ip6_tables: zero-initialize fragment offset
  (bsc#1012628).
- HID: apple: Fix logical maximum and usage maximum of Magic
  Keyboard JIS (bsc#1012628).
- ALSA: usb-audio: Unify mixer resume and reset_resume procedure
  (bsc#1012628).
- ALSA: oxfw: fix transmission method for Loud models based on
  OXFW971 (bsc#1012628).
- ASoC: Intel: sof_sdw: tag SoundWire BEs as non-atomic
  (bsc#1012628).
- ext4: correct the error path of ext4_write_inline_data_end()
  (bsc#1012628).
- ext4: check and update i_disksize properly (bsc#1012628).
- commit ab3ca44
* Wed Oct 13 2021 msuchanek@suse.de
- kernel-spec-macros: Since rpm 4.17 %%verbose is unusable (bsc#1191229).
  The semantic changed in an incompatible way so invoking the macro now
  causes a build failure.
- commit 3e55f55
* Wed Oct 13 2021 jslaby@suse.cz
- Linux 5.14.12 (bsc#1012628).
- dsa: tag_dsa: Fix mask for trunked packets (bsc#1012628).
- x86/hpet: Use another crystalball to evaluate HPET usability
  (bsc#1012628).
- x86/entry: Clear X86_FEATURE_SMAP when CONFIG_X86_SMAP=n
  (bsc#1012628).
- x86/entry: Correct reference to intended CONFIG_64_BIT
  (bsc#1012628).
- x86/fpu: Restore the masking out of reserved MXCSR bits
  (bsc#1012628).
- x86/sev: Return an error on a returned non-zero
  SW_EXITINFO1[31:0] (bsc#1012628).
- x86/Kconfig: Correct reference to MWINCHIP3D (bsc#1012628).
- x86/platform/olpc: Correct ifdef symbol to intended
  CONFIG_OLPC_XO15_SCI (bsc#1012628).
- pseries/eeh: Fix the kdump kernel crash during eeh_pseries_init
  (bsc#1012628).
- powerpc/32s: Fix kuap_kernel_restore() (bsc#1012628).
- powerpc/64s: Fix unrecoverable MCE calling async handler from
  NMI (bsc#1012628).
- powerpc/traps: do not enable irqs in _exception (bsc#1012628).
- powerpc/64s: fix program check interrupt emergency stack path
  (bsc#1012628).
- powerpc/bpf ppc32: Fix BPF_SUB when imm == 0x80000000
  (bsc#1012628).
- powerpc/bpf ppc32: Do not emit zero extend instruction for
  64-bit BPF_END (bsc#1012628).
- powerpc/bpf ppc32: Fix JMP32_JSET_K (bsc#1012628).
- powerpc/bpf ppc32: Fix ALU32 BPF_ARSH operation (bsc#1012628).
- powerpc/bpf: Fix BPF_SUB when imm == 0x80000000 (bsc#1012628).
- powerpc/bpf: Fix BPF_MOD when imm == 1 (bsc#1012628).
- objtool: Make .altinstructions section entry size consistent
  (bsc#1012628).
- objtool: Remove reloc symbol type checks in get_alt_entry()
  (bsc#1012628).
- scsi: iscsi: Fix iscsi_task use after free (bsc#1012628).
- RISC-V: Include clone3() on rv32 (bsc#1012628).
- i2c: mlxcpld: Modify register setting for 400KHz frequency
  (bsc#1012628).
- i2c: mlxcpld: Fix criteria for frequency setting (bsc#1012628).
- bpf, s390: Fix potential memory leak about jit_data
  (bsc#1012628).
- riscv/vdso: make arch_setup_additional_pages wait for mmap_sem
  for write killable (bsc#1012628).
- riscv/vdso: Move vdso data page up front (bsc#1012628).
- riscv/vdso: Refactor asm/vdso.h (bsc#1012628).
- RISC-V: Fix VDSO build for !MMU (bsc#1012628).
- riscv: explicitly use symbol offsets for VDSO (bsc#1012628).
- i2c: mediatek: Add OFFSET_EXT_CONF setting back (bsc#1012628).
- i2c: acpi: fix resource leak in reconfiguration device addition
  (bsc#1012628).
- powerpc/iommu: Report the correct most efficient DMA mask for
  PCI devices (bsc#1012628).
- net: prefer socket bound to interface when not in VRF
  (bsc#1012628).
- iavf: fix double unlock of crit_lock (bsc#1012628).
- i40e: Fix freeing of uninitialized misc IRQ vector
  (bsc#1012628).
- i40e: fix endless loop under rtnl (bsc#1012628).
- gve: report 64bit tx_bytes counter from
  gve_handle_report_stats() (bsc#1012628).
- gve: fix gve_get_stats() (bsc#1012628).
- rtnetlink: fix if_nlmsg_stats_size() under estimation
  (bsc#1012628).
- gve: Properly handle errors in gve_assign_qpl (bsc#1012628).
- gve: Avoid freeing NULL pointer (bsc#1012628).
- gve: Correct available tx qpl check (bsc#1012628).
- net: stmmac: trigger PCS EEE to turn off on link down
  (bsc#1012628).
- net: pcs: xpcs: fix incorrect steps on disable EEE
  (bsc#1012628).
- drm/nouveau/debugfs: fix file release memory leak (bsc#1012628).
- drm/nouveau/kms/nv50-: fix file release memory leak
  (bsc#1012628).
- drm/nouveau: avoid a use-after-free when BO init fails
  (bsc#1012628).
- video: fbdev: gbefb: Only instantiate device when built for IP32
  (bsc#1012628).
- drm/panel: abt-y030xx067a: yellow tint fix (bsc#1012628).
- drm/nouveau/fifo/ga102: initialise chid on return from channel
  creation (bsc#1012628).
- drm/sun4i: dw-hdmi: Fix HDMI PHY clock setup (bsc#1012628).
- bus: ti-sysc: Use CLKDM_NOAUTO for dra7 dcan1 for errata i893
  (bsc#1012628).
- perf jevents: Free the sys_event_tables list after processing
  entries (bsc#1012628).
- drm/amdgpu: handle the case of pci_channel_io_frozen only in
  amdgpu_pci_resume (bsc#1012628).
- drm/amdkfd: fix a potential ttm->sg memory leak (bsc#1012628).
- ARM: defconfig: gemini: Restore framebuffer (bsc#1012628).
- netlink: annotate data races around nlk->bound (bsc#1012628).
- net: pcs: xpcs: fix incorrect CL37 AN sequence (bsc#1012628).
- net: sfp: Fix typo in state machine debug string (bsc#1012628).
- net/sched: sch_taprio: properly cancel timer from
  taprio_destroy() (bsc#1012628).
- net: bridge: fix under estimation in br_get_linkxstats_size()
  (bsc#1012628).
- net: bridge: use nla_total_size_64bit() in
  br_get_linkxstats_size() (bsc#1012628).
- afs: Fix afs_launder_page() to set correct start file position
  (bsc#1012628).
- netfs: Fix READ/WRITE confusion when calling iov_iter_xarray()
  (bsc#1012628).
- drm/i915/bdb: Fix version check (bsc#1012628).
- drm/i915/tc: Fix TypeC port init/resume time sanitization
  (bsc#1012628).
- drm/i915/jsl: Add W/A 1409054076 for JSL (bsc#1012628).
- drm/i915/audio: Use BIOS provided value for RKL HDA link
  (bsc#1012628).
- ARM: imx6: disable the GIC CPU interface before calling
  stby-poweroff sequence (bsc#1012628).
- dt-bindings: drm/bridge: ti-sn65dsi86: Fix reg value
  (bsc#1012628).
- arm64: dts: ls1028a: fix eSDHC2 node (bsc#1012628).
- arm64: dts: imx8mm-kontron-n801x-som: do not allow to switch
  off buck2 (bsc#1012628).
- arm64: dts: imx8: change the spi-nor tx (bsc#1012628).
- ARM: dts: imx: change the spi-nor tx (bsc#1012628).
- ptp_pch: Load module automatically if ID matches (bsc#1012628).
- powerpc/fsl/dts: Fix phy-connection-type for fm1mac3
  (bsc#1012628).
- netfilter: nf_tables: honor NLM_F_CREATE and NLM_F_EXCL in
  event notification (bsc#1012628).
- MIPS: Revert "add support for buggy MT7621S core detection"
  (bsc#1012628).
- net: stmmac: dwmac-rk: Fix ethernet on rk3399 based devices
  (bsc#1012628).
- net: mscc: ocelot: fix VCAP filters remaining active after
  being deleted (bsc#1012628).
- net_sched: fix NULL deref in fifo_set_limit() (bsc#1012628).
- libbpf: Fix memory leak in strset (bsc#1012628).
- phy: mdio: fix memory leak (bsc#1012628).
- libbpf: Fix segfault in light skeleton for objects without BTF
  (bsc#1012628).
- net/mlx5e: Fix the presented RQ index in PTP stats
  (bsc#1012628).
- net/mlx5: Fix setting number of EQs of SFs (bsc#1012628).
- net/mlx5: Fix length of irq_index in chars (bsc#1012628).
- net/mlx5: Avoid generating event after PPS out in Real time mode
  (bsc#1012628).
- net/mlx5: Force round second at 1PPS out start time
  (bsc#1012628).
- net/mlx5: E-Switch, Fix double allocation of acl flow counter
  (bsc#1012628).
- net/mlx5e: Keep the value for maximum number of channels in-sync
  (bsc#1012628).
- net/mlx5e: IPSEC RX, enable checksum complete (bsc#1012628).
- bpf: Fix integer overflow in prealloc_elems_and_freelist()
  (bsc#1012628).
- soc: ti: omap-prm: Fix external abort for am335x pruss
  (bsc#1012628).
- bpf, arm: Fix register clobbering in div/mod implementation
  (bsc#1012628).
- netfilter: nf_tables: reverse order in rule replacement
  expansion (bsc#1012628).
- netfilter: nf_tables: add position handle in event notification
  (bsc#1012628).
- netfilter: conntrack: fix boot failure with
  nf_conntrack.enable_hooks=1 (bsc#1012628).
- iwlwifi: pcie: add configuration of a Wi-Fi adapter on Dell
  XPS 15 (bsc#1012628).
- xtensa: call irqchip_init only when CONFIG_USE_OF is selected
  (bsc#1012628).
- xtensa: use CONFIG_USE_OF instead of CONFIG_OF (bsc#1012628).
- arm64: dts: qcom: pm8150: use qcom,pm8998-pon binding
  (bsc#1012628).
- ath5k: fix building with LEDS=m (bsc#1012628).
- PCI: hv: Fix sleep while in non-sleep context when removing
  child devices from the bus (bsc#1012628).
- ARM: dts: imx6qdl-pico: Fix Ethernet support (bsc#1012628).
- ARM: dts: imx: Fix USB host power regulator polarity on M53Menlo
  (bsc#1012628).
- ARM: dts: imx: Add missing pinctrl-names for panel on M53Menlo
  (bsc#1012628).
- soc: qcom: mdt_loader: Drop PT_LOAD check on hash segment
  (bsc#1012628).
- iwlwifi: mvm: Fix possible NULL dereference (bsc#1012628).
- ARM: at91: pm: do not panic if ram controllers are not enabled
  (bsc#1012628).
- Revert "arm64: dts: qcom: sc7280: Fixup the cpufreq node"
  (bsc#1012628).
- ARM: dts: qcom: apq8064: Use 27MHz PXO clock as DSI PLL
  reference (bsc#1012628).
- soc: qcom: socinfo: Fixed argument passed to platform_set_data()
  (bsc#1012628).
- bus: ti-sysc: Add break in switch statement in sysc_init_soc()
  (bsc#1012628).
- riscv: Flush current cpu icache before other cpus (bsc#1012628).
- scsi: ufs: core: Fix task management completion (bsc#1012628).
- ARM: dts: qcom: apq8064: use compatible which contains chipid
  (bsc#1012628).
- ARM: dts: imx6dl-yapp4: Fix lp5562 LED driver probe
  (bsc#1012628).
- ARM: dts: omap3430-sdp: Fix NAND device node (bsc#1012628).
- xen/balloon: fix cancelled balloon action (bsc#1012628).
- SUNRPC: fix sign error causing rpcsec_gss drops (bsc#1012628).
- nfsd4: Handle the NFSv4 READDIR 'dircount' hint being zero
  (bsc#1012628).
- nfsd: fix error handling of register_pernet_subsys() in
  init_nfsd() (bsc#1012628).
- ovl: fix IOCB_DIRECT if underlying fs doesn't support direct IO
  (bsc#1012628).
- ovl: fix missing negative dentry check in ovl_rename()
  (bsc#1012628).
- fbdev: simplefb: fix Kconfig dependencies (bsc#1012628).
- Update config files.
- mmc: sdhci-of-at91: replace while loop with read_poll_timeout
  (bsc#1012628).
- mmc: sdhci-of-at91: wait for calibration done before proceed
  (bsc#1012628).
- mmc: meson-gx: do not use memcpy_to/fromio for dram-access-quirk
  (bsc#1012628).
- xen/privcmd: fix error handling in mmap-resource processing
  (bsc#1012628).
- drm/i915: Extend the async flip VT-d w/a to skl/bxt
  (bsc#1012628).
- drm/i915: Fix runtime pm handling in i915_gem_shrink
  (bsc#1012628).
- drm/amd/display: Fix DCN3 B0 DP Alt Mapping (bsc#1012628).
- drm/amd/display: Fix detection of 4 lane for DPALT
  (bsc#1012628).
- drm/amd/display: Limit display scaling to up to 4k for DCN 3.1
  (bsc#1012628).
- drm/nouveau/ga102-: support ttm buffer moves via copy engine
  (bsc#1012628).
- drm/nouveau/kms/tu102-: delay enabling cursor until after
  assign_windows (bsc#1012628).
- drm/amdgpu: During s0ix don't wait to signal GFXOFF
  (bsc#1012628).
- drm/amd/display: USB4 bring up set correct address
  (bsc#1012628).
- drm/amd/display: Fix B0 USB-C DP Alt mode (bsc#1012628).
- usb: typec: tipd: Remove dependency on "connector" child fwnode
  (bsc#1012628).
- usb: typec: tcpm: handle SRC_STARTUP state if cc changes
  (bsc#1012628).
- usb: typec: tcpci: don't handle vSafe0V event if it's not
  enabled (bsc#1012628).
- USB: cdc-acm: fix break reporting (bsc#1012628).
- USB: cdc-acm: fix racy tty buffer accesses (bsc#1012628).
- usb: gadget: f_uac2: fixed EP-IN wMaxPacketSize (bsc#1012628).
- usb: chipidea: ci_hdrc_imx: Also search for 'phys' phandle
  (bsc#1012628).
- usb: cdc-wdm: Fix check for WWAN (bsc#1012628).
- Partially revert "usb: Kconfig: using select for USB_COMMON
  dependency" (bsc#1012628).
- Update config files.
- commit 7246625
* Mon Oct 11 2021 mbrugger@suse.com
- rtw89: add Realtek 802.11ax driver (bsc#1191321).
- commit 4c399ab
* Mon Oct 11 2021 tiwai@suse.de
- Enable CONFIG_RTW88_DEBUG and CONFIG_RTW89_DEBUG on debug flavors (bsc#1191321)
- commit d98701e
* Mon Oct 11 2021 mkubecek@suse.cz
- Update to 5.15-rc5
- update configs
  - FIRMWARE_MEMMAP=y (ppc64, ppc64le, s390x)
  - FW_CFG_SYSFS=m (ppc64)
  - FB_SIMPLE=n (s390x)
- commit f616781
* Sun Oct 10 2021 jslaby@suse.cz
- Linux 5.14.11 (bsc#1012628).
- Revert "ARM: imx6q: drop of_platform_default_populate() from
  init_machine" (bsc#1012628).
- Revert "brcmfmac: use ISO3166 country code and 0 rev as
  fallback" (bsc#1012628).
- libata: Add ATA_HORKAGE_NO_NCQ_ON_ATI for Samsung 860 and 870
  SSD (bsc#1012628).
- perf/x86: Reset destroy callback on event init failure
  (bsc#1012628).
- KVM: x86: nSVM: restore int_vector in svm_clear_vintr
  (bsc#1012628).
- kvm: x86: Add AMD PMU MSRs to msrs_to_save_all[] (bsc#1012628).
- KVM: x86: reset pdptrs_from_userspace when exiting smm
  (bsc#1012628).
- KVM: do not shrink halt_poll_ns below grow_start (bsc#1012628).
- selftests: KVM: Align SMCCC call with the spec in steal_time
  (bsc#1012628).
- kasan: always respect CONFIG_KASAN_STACK (bsc#1012628).
- tools/vm/page-types: remove dependency on opt_file for idle
  page tracking (bsc#1012628).
- block: don't call rq_qos_ops->done_bio if the bio isn't tracked
  (bsc#1012628).
- io_uring: allow conditional reschedule for intensive iterators
  (bsc#1012628).
- x86/insn, tools/x86: Fix undefined behavior due to potential
  unaligned accesses (bsc#1012628).
- smb3: correct smb3 ACL security descriptor (bsc#1012628).
- irqchip/gic: Work around broken Renesas integration
  (bsc#1012628).
- scsi: ses: Retry failed Send/Receive Diagnostic commands
  (bsc#1012628).
- thermal/drivers/tsens: Fix wrong check for tzd in irq handlers
  (bsc#1012628).
- nvme-fc: avoid race between time out and tear down
  (bsc#1012628).
- nvme-fc: update hardware queues before using them (bsc#1012628).
- swiotlb-xen: ensure to issue well-formed XENMEM_exchange
  requests (bsc#1012628).
- Xen/gntdev: don't ignore kernel unmapping error (bsc#1012628).
- selftests: kvm: fix get_run_delay() ignoring fscanf() return
  warn (bsc#1012628).
- selftests: kvm: move get_run_delay() into lib/test_util
  (bsc#1012628).
- selftests:kvm: fix get_trans_hugepagesz() ignoring fscanf()
  return warn (bsc#1012628).
- selftests:kvm: fix get_warnings_count() ignoring fscanf()
  return warn (bsc#1012628).
- selftests: be sure to make khdr before other targets
  (bsc#1012628).
- habanalabs/gaudi: fix LBW RR configuration (bsc#1012628).
- habanalabs: fail collective wait when not supported
  (bsc#1012628).
- habanalabs/gaudi: use direct MSI in single mode (bsc#1012628).
- usb: dwc2: check return value after calling
  platform_get_resource() (bsc#1012628).
- usb: testusb: Fix for showing the connection speed
  (bsc#1012628).
- scsi: elx: efct: Do not hold lock while calling
  fc_vport_terminate() (bsc#1012628).
- scsi: sd: Free scsi_disk device via put_device() (bsc#1012628).
- drm/amdkfd: fix svm_migrate_fini warning (bsc#1012628).
- drm/amdkfd: handle svm migrate init error (bsc#1012628).
- ext2: fix sleeping in atomic bugs on error (bsc#1012628).
- platform/x86: gigabyte-wmi: add support for B550I Aorus Pro AX
  (bsc#1012628).
- sparc64: fix pci_iounmap() when CONFIG_PCI is not set
  (bsc#1012628).
- xen-netback: correct success/error reporting for the
  SKB-with-fraglist case (bsc#1012628).
- net: mdio: introduce a shutdown method to mdio device drivers
  (bsc#1012628).
- btrfs: fix mount failure due to past and transient device
  flush error (bsc#1012628).
- btrfs: replace BUG_ON() in btrfs_csum_one_bio() with proper
  error handling (bsc#1012628).
- nfsd: back channel stuck in SEQ4_STATUS_CB_PATH_DOWN
  (bsc#1012628).
- platform/x86: touchscreen_dmi: Update info for the Chuwi Hi10
  Plus (CWI527) tablet (bsc#1012628).
- platform/x86: touchscreen_dmi: Add info for the Chuwi HiBook
  (CWI514) tablet (bsc#1012628).
- afs: Add missing vnode validation checks (bsc#1012628).
- spi: rockchip: handle zero length transfers without timing out
  (bsc#1012628).
- commit 834dddd
* Fri Oct  8 2021 tiwai@suse.de
- iwlwifi: Fix MODULE_FIRMWARE() for non-existing ucode version
  (boo#1191417).
- commit b3fa747
* Thu Oct  7 2021 jslaby@suse.cz
- Linux 5.14.10 (bsc#1012628).
- media: hantro: Fix check for single irq (bsc#1012628).
- media: cedrus: Fix SUNXI tile size calculation (bsc#1012628).
- media: s5p-jpeg: rename JPEG marker constants to prevent build
  warnings (bsc#1012628).
- ASoC: fsl_sai: register platform component before registering
  cpu dai (bsc#1012628).
- ASoC: fsl_esai: register platform component before registering
  cpu dai (bsc#1012628).
- ASoC: fsl_micfil: register platform component before registering
  cpu dai (bsc#1012628).
- ASoC: fsl_spdif: register platform component before registering
  cpu dai (bsc#1012628).
- ASoC: fsl_xcvr: register platform component before registering
  cpu dai (bsc#1012628).
- ASoC: mediatek: common: handle NULL case in suspend/resume
  function (bsc#1012628).
- scsi: elx: efct: Fix void-pointer-to-enum-cast warning for
  efc_nport_topology (bsc#1012628).
- ASoC: SOF: Fix DSP oops stack dump output contents
  (bsc#1012628).
- ASoC: SOF: imx: imx8: Bar index is only valid for IRAM and
  SRAM types (bsc#1012628).
- ASoC: SOF: imx: imx8m: Bar index is only valid for IRAM and
  SRAM types (bsc#1012628).
- pinctrl: qcom: spmi-gpio: correct parent irqspec translation
  (bsc#1012628).
- net/mlx4_en: Resolve bad operstate value (bsc#1012628).
- s390/qeth: Fix deadlock in remove_discipline (bsc#1012628).
- s390/qeth: fix deadlock during failing recovery (bsc#1012628).
- m68k: Update ->thread.esp0 before calling syscall_trace()
  in ret_from_signal (bsc#1012628).
- NIOS2: fix kconfig unmet dependency warning for
  SERIAL_CORE_CONSOLE (bsc#1012628).
- kasan: fix Kconfig check of CC_HAS_WORKING_NOSANITIZE_ADDRESS
  (bsc#1012628).
- HID: amd_sfh: Fix potential NULL pointer dereference
  (bsc#1012628).
- perf test: Fix DWARF unwind for optimized builds (bsc#1012628).
- perf iostat: Use system-wide mode if the target cpu_list is
  unspecified (bsc#1012628).
- perf iostat: Fix Segmentation fault from NULL 'struct
  perf_counts_values *' (bsc#1012628).
- watchdog/sb_watchdog: fix compilation problem due to
  COMPILE_TEST (bsc#1012628).
- tty: Fix out-of-bound vmalloc access in imageblit (bsc#1012628).
- cpufreq: schedutil: Use kobject release() method to free
  sugov_tunables (bsc#1012628).
- scsi: qla2xxx: Changes to support kdump kernel for NVMe BFS
  (bsc#1012628).
- drm/amdgpu: adjust fence driver enable sequence (bsc#1012628).
- drm/amdgpu: avoid over-handle of fence driver fini in s3 test
  (v2) (bsc#1012628).
- drm/amdgpu: stop scheduler when calling hw_fini (v2)
  (bsc#1012628).
- cpufreq: schedutil: Destroy mutex before kobject_put() frees
  the memory (bsc#1012628).
- scsi: ufs: ufs-pci: Fix Intel LKF link stability (bsc#1012628).
- ALSA: rawmidi: introduce SNDRV_RAWMIDI_IOCTL_USER_PVERSION
  (bsc#1012628).
- ALSA: firewire-motu: fix truncated bytes in message tracepoints
  (bsc#1012628).
- ALSA: hda/realtek: Quirks to enable speaker output for Lenovo
  Legion 7i 15IMHG05, Yoga 7i 14ITL5/15ITL5, and 13s Gen2 laptops
  (bsc#1012628).
- ACPI: NFIT: Use fallback node id when numa info in NFIT table
  is incorrect (bsc#1012628).
- fs-verity: fix signed integer overflow with i_size near S64_MAX
  (bsc#1012628).
- hwmon: (tmp421) handle I2C errors (bsc#1012628).
- hwmon: (w83793) Fix NULL pointer dereference by removing
  unnecessary structure field (bsc#1012628).
- hwmon: (w83792d) Fix NULL pointer dereference by removing
  unnecessary structure field (bsc#1012628).
- hwmon: (w83791d) Fix NULL pointer dereference by removing
  unnecessary structure field (bsc#1012628).
- gpio: pca953x: do not ignore i2c errors (bsc#1012628).
- scsi: ufs: Fix illegal offset in UPIU event trace (bsc#1012628).
- mac80211: fix use-after-free in CCMP/GCMP RX (bsc#1012628).
- platform/x86/intel: hid: Add DMI switches allow list
  (bsc#1012628).
- x86/kvmclock: Move this_cpu_pvti into kvmclock.h (bsc#1012628).
- ptp: Fix ptp_kvm_getcrosststamp issue for x86 ptp_kvm
  (bsc#1012628).
- KVM: x86: Fix stack-out-of-bounds memory access from
  ioapic_write_indirect() (bsc#1012628).
- KVM: x86: nSVM: don't copy virt_ext from vmcb12 (bsc#1012628).
- KVM: x86: Clear KVM's cached guest CR3 at RESET/INIT
  (bsc#1012628).
- KVM: x86: Swap order of CPUID entry "index" vs. "significant
  flag" checks (bsc#1012628).
- KVM: nVMX: Filter out all unsupported controls when eVMCS was
  activated (bsc#1012628).
- KVM: SEV: Update svm_vm_copy_asid_from for SEV-ES (bsc#1012628).
- KVM: SEV: Pin guest memory for write for RECEIVE_UPDATE_DATA
  (bsc#1012628).
- KVM: SEV: Acquire vcpu mutex when updating VMSA (bsc#1012628).
- KVM: SEV: Allow some commands for mirror VM (bsc#1012628).
- KVM: SVM: fix missing sev_decommission in sev_receive_start
  (bsc#1012628).
- KVM: nVMX: Fix nested bus lock VM exit (bsc#1012628).
- KVM: VMX: Fix a TSX_CTRL_CPUID_CLEAR field mask issue
  (bsc#1012628).
- mmc: renesas_sdhi: fix regression with hard reset on old SDHIs
  (bsc#1012628).
- media: ir_toy: prevent device from hanging during transmit
  (bsc#1012628).
- RDMA/cma: Do not change route.addr.src_addr.ss_family
  (bsc#1012628).
- RDMA/cma: Ensure rdma_addr_cancel() happens before issuing
  more requests (bsc#1012628).
- nbd: use shifts rather than multiplies (bsc#1012628).
- drm/amd/display: initialize backlight_ramping_override to false
  (bsc#1012628).
- drm/amd/display: Pass PCI deviceid into DC (bsc#1012628).
- drm/amd/display: Fix Display Flicker on embedded panels
  (bsc#1012628).
- drm/amdgpu: force exit gfxoff on sdma resume for rmb s0ix
  (bsc#1012628).
- drm/amdgpu: check tiling flags when creating FB on GFX8-
  (bsc#1012628).
- drm/amdgpu: correct initial cp_hqd_quantum for gfx9
  (bsc#1012628).
- interconnect: qcom: sdm660: Fix id of slv_cnoc_mnoc_cfg
  (bsc#1012628).
- interconnect: qcom: sdm660: Correct NOC_QOS_PRIORITY shift
  and mask (bsc#1012628).
- drm/i915/gvt: fix the usage of ww lock in gvt scheduler
  (bsc#1012628).
- ipvs: check that ip_vs_conn_tab_bits is between 8 and 20
  (bsc#1012628).
- bpf: Handle return value of BPF_PROG_TYPE_STRUCT_OPS prog
  (bsc#1012628).
- IB/cma: Do not send IGMP leaves for sendonly Multicast groups
  (bsc#1012628).
- RDMA/cma: Fix listener leak in rdma_cma_listen_on_all() failure
  (bsc#1012628).
- bpf, mips: Validate conditional branch offsets (bsc#1012628).
- hwmon: (mlxreg-fan) Return non-zero value when fan current
  state is enforced from sysfs (bsc#1012628).
- RDMA/irdma: Skip CQP ring during a reset (bsc#1012628).
- RDMA/irdma: Validate number of CQ entries on create CQ
  (bsc#1012628).
- RDMA/irdma: Report correct WC error when transport retry
  counter is exceeded (bsc#1012628).
- RDMA/irdma: Report correct WC error when there are MW bind
  errors (bsc#1012628).
- netfilter: nf_tables: unlink table before deleting it
  (bsc#1012628).
- netfilter: log: work around missing softdep backend module
  (bsc#1012628).
- Revert "mac80211: do not use low data rates for data frames
  with no ack flag" (bsc#1012628).
- mac80211: Fix ieee80211_amsdu_aggregate frag_tail bug
  (bsc#1012628).
- mac80211: limit injected vht mcs/nss in
  ieee80211_parse_tx_radiotap (bsc#1012628).
- mac80211: mesh: fix potentially unaligned access (bsc#1012628).
- mac80211-hwsim: fix late beacon hrtimer handling (bsc#1012628).
- driver core: fw_devlink: Add support for
  FWNODE_FLAG_NEEDS_CHILD_BOUND_ON_ADD (bsc#1012628).
- net: mdiobus: Set FWNODE_FLAG_NEEDS_CHILD_BOUND_ON_ADD for
  mdiobus parents (bsc#1012628).
- sctp: break out if skb_header_pointer returns NULL in
  sctp_rcv_ootb (bsc#1012628).
- mptcp: don't return sockets in foreign netns (bsc#1012628).
- mptcp: allow changing the 'backup' bit when no sockets are open
  (bsc#1012628).
- RDMA/hns: Work around broken constant propagation in gcc 8
  (bsc#1012628).
- hwmon: (tmp421) report /PVLD condition as fault (bsc#1012628).
- hwmon: (tmp421) fix rounding for negative values (bsc#1012628).
- net: enetc: fix the incorrect clearing of IF_MODE bits
  (bsc#1012628).
- net: ipv4: Fix rtnexthop len when RTA_FLOW is present
  (bsc#1012628).
- smsc95xx: fix stalled rx after link change (bsc#1012628).
- drm/i915/request: fix early tracepoints (bsc#1012628).
- drm/i915: Remove warning from the rps worker (bsc#1012628).
- dsa: mv88e6xxx: 6161: Use chip wide MAX MTU (bsc#1012628).
- dsa: mv88e6xxx: Fix MTU definition (bsc#1012628).
- dsa: mv88e6xxx: Include tagger overhead when setting MTU for
  DSA and CPU ports (bsc#1012628).
- e100: fix length calculation in e100_get_regs_len (bsc#1012628).
- e100: fix buffer overrun in e100_get_regs (bsc#1012628).
- RDMA/hfi1: Fix kernel pointer leak (bsc#1012628).
- RDMA/hns: Fix the size setting error when copying CQE in
  clean_cq() (bsc#1012628).
- RDMA/hns: Add the check of the CQE size of the user space
  (bsc#1012628).
- bpf: Exempt CAP_BPF from checks against bpf_jit_limit
  (bsc#1012628).
- libbpf: Fix segfault in static linker for objects without BTF
  (bsc#1012628).
- selftests, bpf: Fix makefile dependencies on libbpf
  (bsc#1012628).
- selftests, bpf: test_lwt_ip_encap: Really disable rp_filter
  (bsc#1012628).
- bpf, x86: Fix bpf mapping of atomic fetch implementation
  (bsc#1012628).
- net: ks8851: fix link error (bsc#1012628).
- ionic: fix gathering of debug stats (bsc#1012628).
- Revert "block, bfq: honor already-setup queue merges"
  (bsc#1012628).
- scsi: csiostor: Add module softdep on cxgb4 (bsc#1012628).
- ixgbe: Fix NULL pointer dereference in ixgbe_xdp_setup
  (bsc#1012628).
- net: hns3: do not allow call hns3_nic_net_open repeatedly
  (bsc#1012628).
- net: hns3: remove tc enable checking (bsc#1012628).
- net: hns3: don't rollback when destroy mqprio fail
  (bsc#1012628).
- net: hns3: fix mixed flag HCLGE_FLAG_MQPRIO_ENABLE and
  HCLGE_FLAG_DCB_ENABLE (bsc#1012628).
- net: hns3: fix show wrong state when add existing uc mac address
  (bsc#1012628).
- net: hns3: reconstruct function hns3_self_test (bsc#1012628).
- net: hns3: fix always enable rx vlan filter problem after
  selftest (bsc#1012628).
- net: hns3: disable firmware compatible features when uninstall
  PF (bsc#1012628).
- net: phy: bcm7xxx: Fixed indirect MMD operations (bsc#1012628).
- net: sched: flower: protect fl_walk() with rcu (bsc#1012628).
- net: stmmac: fix EEE init issue when paired with EEE capable
  PHYs (bsc#1012628).
- af_unix: fix races in sk_peer_pid and sk_peer_cred accesses
  (bsc#1012628).
- objtool: Teach get_alt_entry() about more relocation types
  (bsc#1012628).
- perf/x86/intel: Update event constraints for ICX (bsc#1012628).
- sched/fair: Add ancestors of unthrottled undecayed cfs_rq
  (bsc#1012628).
- sched/fair: Null terminate buffer when updating tunable_scaling
  (bsc#1012628).
- hwmon: (occ) Fix P10 VRM temp sensors (bsc#1012628).
- hwmon: (pmbus/mp2975) Add missed POUT attribute for page 1
  mp2975 controller (bsc#1012628).
- kvm: fix objtool relocation warning (bsc#1012628).
- nvme: add command id quirk for apple controllers (bsc#1012628).
- elf: don't use MAP_FIXED_NOREPLACE for elf interpreter mappings
  (bsc#1012628).
- driver core: fw_devlink: Improve handling of cyclic dependencies
  (bsc#1012628).
- debugfs: debugfs_create_file_size(): use IS_ERR to check for
  error (bsc#1012628).
- ipack: ipoctal: fix stack information leak (bsc#1012628).
- ipack: ipoctal: fix tty registration race (bsc#1012628).
- ipack: ipoctal: fix tty-registration error handling
  (bsc#1012628).
- ipack: ipoctal: fix missing allocation-failure check
  (bsc#1012628).
- ipack: ipoctal: fix module reference leak (bsc#1012628).
- ext4: fix loff_t overflow in ext4_max_bitmap_size()
  (bsc#1012628).
- ext4: limit the number of blocks in one ADD_RANGE TLV
  (bsc#1012628).
- ext4: fix reserved space counter leakage (bsc#1012628).
- ext4: add error checking to ext4_ext_replay_set_iblocks()
  (bsc#1012628).
- ext4: fix potential infinite loop in ext4_dx_readdir()
  (bsc#1012628).
- ext4: flush s_error_work before journal destroy in
  ext4_fill_super (bsc#1012628).
- HID: u2fzero: ignore incomplete packets without data
  (bsc#1012628).
- net: udp: annotate data race around udp_sk(sk)->corkflag
  (bsc#1012628).
- NIOS2: setup.c: drop unused variable 'dram_start' (bsc#1012628).
- usb: hso: remove the bailout parameter (bsc#1012628).
- HID: betop: fix slab-out-of-bounds Write in betop_probe
  (bsc#1012628).
- netfilter: ipset: Fix oversized kvmalloc() calls (bsc#1012628).
- mm: don't allow oversized kvmalloc() calls (bsc#1012628).
- HID: usbhid: free raw_report buffers in usbhid_stop
  (bsc#1012628).
- crypto: aesni - xts_crypt() return if walk.nbytes is 0
  (bsc#1012628).
- KVM: x86: Handle SRCU initialization failure during page track
  init (bsc#1012628).
- netfilter: conntrack: serialize hash resizes and cleanups
  (bsc#1012628).
- netfilter: nf_tables: Fix oversized kvmalloc() calls
  (bsc#1012628).
- drivers: net: mhi: fix error path in mhi_net_newlink
  (bsc#1012628).
- objtool: print out the symbol type when complaining about it
  (bsc#1012628).
- HID: amd_sfh: Fix potential NULL pointer dereference - take 2
  (bsc#1012628).
- commit 7c980ba
* Thu Oct  7 2021 tiwai@suse.de
- ALSA: hda: intel: Allow repeatedly probing on codec
  configuration errors (bsc#1190801).
- commit 924f4be
* Tue Oct  5 2021 ludwig.nussel@suse.de
- rpm: use _rpmmacrodir (boo#1191384)
- commit e350c14
* Mon Oct  4 2021 mkubecek@suse.cz
- Update to 5.15-rc4
- commit 01d91cd
* Fri Oct  1 2021 tiwai@suse.de
- ALSA: usb-audio: Restrict rates for the shared clocks
  (bsc#1190418).
- commit ffe0c6a
* Fri Oct  1 2021 jslaby@suse.cz
- Update
  patches.kernel.org/5.14.9-147-Revert-drm-vc4-hdmi-runtime-PM-changes.patch
  (bsc#1012628 bsc#1190469).
- Delete patches.suse/drm-vc4-hdmi-Fix-HPD-GPIO-detection.patch.
  The former superseded the latter.
- commit 2bc4ba2
* Thu Sep 30 2021 jslaby@suse.cz
- Linux 5.14.9 (bsc#1012628).
- mm, hwpoison: add is_free_buddy_page() in HWPoisonHandlable()
  (bsc#1012628).
- ocfs2: drop acl cache for directories too (bsc#1012628).
- mm/debug: sync up MR_CONTIG_RANGE and MR_LONGTERM_PIN
  (bsc#1012628).
- mm: fix uninitialized use in overcommit_policy_handler
  (bsc#1012628).
- usb: gadget: r8a66597: fix a loop in set_feature()
  (bsc#1012628).
- usb: gadget: u_audio: EP-OUT bInterval in fback frequency
  (bsc#1012628).
- usb: dwc2: gadget: Fix ISOC flow for BDMA and Slave
  (bsc#1012628).
- usb: dwc2: gadget: Fix ISOC transfer complete handling for DDMA
  (bsc#1012628).
- usb: musb: tusb6010: uninitialized data in
  tusb_fifo_write_unaligned() (bsc#1012628).
- cifs: Not to defer close on file when lock is set (bsc#1012628).
- cifs: Fix soft lockup during fsstress (bsc#1012628).
- cifs: fix incorrect check for null pointer in header_assemble
  (bsc#1012628).
- xen/x86: fix PV trap handling on secondary processors
  (bsc#1012628).
- usb-storage: Add quirk for ScanLogic SL11R-IDE older than 2.6c
  (bsc#1012628).
- USB: serial: cp210x: add ID for GW Instek GDM-834x Digital
  Multimeter (bsc#1012628).
- USB: cdc-acm: fix minor-number release (bsc#1012628).
- Revert "USB: bcma: Add a check for devm_gpiod_get"
  (bsc#1012628).
- binder: make sure fd closes complete (bsc#1012628).
- binder: fix freeze race (bsc#1012628).
- staging: greybus: uart: fix tty use after free (bsc#1012628).
- usb: isp1760: do not sleep in field register poll (bsc#1012628).
- Re-enable UAS for LaCie Rugged USB3-FW with fk quirk
  (bsc#1012628).
- usb: dwc3: core: balance phy init and exit (bsc#1012628).
- usb: cdns3: fix race condition before setting doorbell
  (bsc#1012628).
- usb: core: hcd: Add support for deferring roothub registration
  (bsc#1012628).
- USB: serial: mos7840: remove duplicated 0xac24 device ID
  (bsc#1012628).
- USB: serial: option: add Telit LN920 compositions (bsc#1012628).
- USB: serial: option: remove duplicate USB device ID
  (bsc#1012628).
- USB: serial: option: add device id for Foxconn T99W265
  (bsc#1012628).
- misc: bcm-vk: fix tty registration race (bsc#1012628).
- misc: genwqe: Fixes DMA mask setting (bsc#1012628).
- mcb: fix error handling in mcb_alloc_bus() (bsc#1012628).
- KVM: rseq: Update rseq when processing NOTIFY_RESUME on xfer
  to KVM guest (bsc#1012628).
- erofs: fix up erofs_lookup tracepoint (bsc#1012628).
- nexthop: Fix division by zero while replacing a resilient group
  (bsc#1012628).
- btrfs: prevent __btrfs_dump_space_info() to underflow its free
  space (bsc#1012628).
- xhci: Set HCD flag to defer primary roothub registration
  (bsc#1012628).
- serial: 8250: 8250_omap: Fix RX_LVL register offset
  (bsc#1012628).
- serial: mvebu-uart: fix driver's tx_empty callback
  (bsc#1012628).
- scsi: sd_zbc: Ensure buffer size is aligned to SECTOR_SIZE
  (bsc#1012628).
- drm/amd/pm: Update intermediate power state for SI
  (bsc#1012628).
- net: hso: fix muxed tty registration (bsc#1012628).
- platform/x86: amd-pmc: Increase the response register timeout
  (bsc#1012628).
- arm64: Restore forced disabling of KPTI on ThunderX
  (bsc#1012628).
- arm64: Mitigate MTE issues with str{n}cmp() (bsc#1012628).
- comedi: Fix memory leak in compat_insnlist() (bsc#1012628).
- regulator: qcom-rpmh-regulator: fix pm8009-1 ldo7 resource name
  (bsc#1012628).
- afs: Fix page leak (bsc#1012628).
- afs: Fix incorrect triggering of sillyrename on 3rd-party
  invalidation (bsc#1012628).
- afs: Fix corruption in reads at fpos 2G-4G from an OpenAFS
  server (bsc#1012628).
- afs: Fix updating of i_blocks on file/dir extension
  (bsc#1012628).
- platform/x86/intel: punit_ipc: Drop wrong use of ACPI_PTR()
  (bsc#1012628).
- regulator: max14577: Revert "regulator: max14577: Add proper
  module aliases strings" (bsc#1012628).
- NLM: Fix svcxdr_encode_owner() (bsc#1012628).
- virtio-net: fix pages leaking when building skb in big mode
  (bsc#1012628).
- enetc: Fix illegal access when reading affinity_hint
  (bsc#1012628).
- enetc: Fix uninitialized struct dim_sample field usage
  (bsc#1012628).
- net: dsa: tear down devlink port regions when tearing down
  the devlink port on error (bsc#1012628).
- net: bgmac-bcma: handle deferred probe error due to mac-address
  (bsc#1012628).
- napi: fix race inside napi_enable (bsc#1012628).
- bnxt_en: Fix TX timeout when TX ring size is set to the smallest
  (bsc#1012628).
- net: hns3: fix change RSS 'hfunc' ineffective issue
  (bsc#1012628).
- net: hns3: fix inconsistent vf id print (bsc#1012628).
- net: hns3: fix misuse vf id and vport id in some logs
  (bsc#1012628).
- net: hns3: check queue id range before using (bsc#1012628).
- net: hns3: check vlan id before using it (bsc#1012628).
- net: hns3: fix a return value error in hclge_get_reset_status()
  (bsc#1012628).
- net/smc: add missing error check in smc_clc_prfx_set()
  (bsc#1012628).
- net/smc: fix 'workqueue leaked lock' in smc_conn_abort_work
  (bsc#1012628).
- net: dsa: fix dsa_tree_setup error path (bsc#1012628).
- net: dsa: don't allocate the slave_mii_bus using devres
  (bsc#1012628).
- net: dsa: realtek: register the MDIO bus under devres
  (bsc#1012628).
- platform/x86: dell: fix DELL_WMI_PRIVACY dependencies & build
  error (bsc#1012628).
- kselftest/arm64: signal: Add SVE to the set of features we
  can check for (bsc#1012628).
- kselftest/arm64: signal: Skip tests if required features are
  missing (bsc#1012628).
- spi: Revert modalias changes (bsc#1012628).
- s390/qeth: fix NULL deref in qeth_clear_working_pool_list()
  (bsc#1012628).
- gpiolib: acpi: Make set-debounce-timeout failures non fatal
  (bsc#1012628).
- gpio: uniphier: Fix void functions to remove return value
  (bsc#1012628).
- qed: rdma - don't wait for resources under hw error recovery
  flow (bsc#1012628).
- mptcp: ensure tx skbs always have the MPTCP ext (bsc#1012628).
- nexthop: Fix memory leaks in nexthop notification chain
  listeners (bsc#1012628).
- nfc: st-nci: Add SPI ID matching DT compatible (bsc#1012628).
- net: ethernet: mtk_eth_soc: avoid creating duplicate offload
  entries (bsc#1012628).
- net: mscc: ocelot: fix forwarding from BLOCKING ports remaining
  enabled (bsc#1012628).
- net/mlx4_en: Don't allow aRFS for encapsulated packets
  (bsc#1012628).
- atlantic: Fix issue in the pm resume flow (bsc#1012628).
- drm/amdkfd: map SVM range with correct access permission
  (bsc#1012628).
- drm/amdkfd: fix dma mapping leaking warning (bsc#1012628).
- scsi: iscsi: Adjust iface sysfs attr detection (bsc#1012628).
- scsi: target: Fix the pgr/alua_support_store functions
  (bsc#1012628).
- tty: synclink_gt: rename a conflicting function name
  (bsc#1012628).
- fpga: machxo2-spi: Return an error on failure (bsc#1012628).
- fpga: machxo2-spi: Fix missing error code in
  machxo2_write_complete() (bsc#1012628).
- x86/fault: Fix wrong signal when vsyscall fails with pkey
  (bsc#1012628).
- nvme-tcp: fix incorrect h2cdata pdu offset accounting
  (bsc#1012628).
- nvme: keep ctrl->namespaces ordered (bsc#1012628).
- thermal/core: Potential buffer overflow in
  thermal_build_list_of_policies() (bsc#1012628).
- cifs: fix a sign extension bug (bsc#1012628).
- scsi: sd_zbc: Support disks with more than 2**32 logical blocks
  (bsc#1012628).
- scsi: ufs: Revert "Utilize Transfer Request List Completion
  Notification Register" (bsc#1012628).
- scsi: ufs: Retry aborted SCSI commands instead of completing
  these successfully (bsc#1012628).
- scsi: ufs: core: Unbreak the reset handler (bsc#1012628).
- scsi: qla2xxx: Restore initiator in dual mode (bsc#1012628).
- scsi: lpfc: Use correct scnprintf() limit (bsc#1012628).
- irqchip/goldfish-pic: Select GENERIC_IRQ_CHIP to fix build
  (bsc#1012628).
- irqchip/gic-v3-its: Fix potential VPE leak on error
  (bsc#1012628).
- md: fix a lock order reversal in md_alloc (bsc#1012628).
- x86/asm: Fix SETZ size enqcmds() build failure (bsc#1012628).
- io_uring: fix race between poll completion and cancel_hash
  insertion (bsc#1012628).
- io_uring: fix missing set of EPOLLONESHOT for CQ ring overflow
  (bsc#1012628).
- io_uring: put provided buffer meta data under memcg accounting
  (bsc#1012628).
- io_uring: don't punt files update to io-wq unconditionally
  (bsc#1012628).
- blktrace: Fix uaf in blk_trace access after removing by sysfs
  (bsc#1012628).
- net: phylink: Update SFP selected interface on advertising
  changes (bsc#1012628).
- net: macb: fix use after free on rmmod (bsc#1012628).
- net: stmmac: allow CSR clock of 300MHz (bsc#1012628).
- blk-mq: avoid to iterate over stale request (bsc#1012628).
- m68k: Double cast io functions to unsigned long (bsc#1012628).
- ipv6: delay fib6_sernum increase in fib6_add (bsc#1012628).
- dma-debug: prevent an error message from causing runtime
  problems (bsc#1012628).
- cpufreq: intel_pstate: Override parameters if HWP forced by BIOS
  (bsc#1012628).
- bpf: Add oversize check before call kvcalloc() (bsc#1012628).
- xen/balloon: use a kernel thread instead a workqueue
  (bsc#1012628).
- nvme-multipath: fix ANA state updates when a namespace is not
  present (bsc#1012628).
- nvme-rdma: destroy cm id before destroy qp to avoid use after
  free (bsc#1012628).
- sparc32: page align size in arch_dma_alloc (bsc#1012628).
- amd/display: downgrade validation failure log level
  (bsc#1012628).
- drm/ttm: fix type mismatch error on sparc64 (bsc#1012628).
- block: check if a profile is actually registered in
  blk_integrity_unregister (bsc#1012628).
- block: flush the integrity workqueue in blk_integrity_unregister
  (bsc#1012628).
- blk-cgroup: fix UAF by grabbing blkcg lock before destroying
  blkg pd (bsc#1012628).
- compiler.h: Introduce absolute_pointer macro (bsc#1012628).
- net: i825xx: Use absolute_pointer for memcpy from fixed memory
  location (bsc#1012628).
- sparc: avoid stringop-overread errors (bsc#1012628).
- qnx4: avoid stringop-overread errors (bsc#1012628).
- parisc: Use absolute_pointer() to define PAGE0 (bsc#1012628).
- drm/amdkfd: make needs_pcie_atomics FW-version dependent
  (bsc#1012628).
- drm/amd/display: Fix unstable HPCP compliance on Chrome Barcelo
  (bsc#1012628).
- drm/amd/display: Link training retry fix for abort case
  (bsc#1012628).
- amd/display: enable panel orientation quirks (bsc#1012628).
- arm64: Mark __stack_chk_guard as __ro_after_init (bsc#1012628).
- alpha: Declare virt_to_phys and virt_to_bus parameter as
  pointer to volatile (bsc#1012628).
- net: 6pack: Fix tx timeout and slot time (bsc#1012628).
- spi: Fix tegra20 build with CONFIG_PM=n (bsc#1012628).
- libperf evsel: Make use of FD robust (bsc#1012628).
- Revert drm/vc4 hdmi runtime PM changes (bsc#1012628).
- EDAC/synopsys: Fix wrong value type assignment for edac_mode
  (bsc#1012628).
- EDAC/dmc520: Assign the proper type to dimm->edac_mode
  (bsc#1012628).
- x86/setup: Call early_reserve_memory() earlier (bsc#1012628).
- thermal/drivers/int340x: Do not set a wrong tcc offset on resume
  (bsc#1012628).
- irqchip/armada-370-xp: Fix ack/eoi breakage (bsc#1012628).
- arm64: add MTE supported check to thread switching and syscall
  entry/exit (bsc#1012628).
- USB: serial: cp210x: fix dropped characters with CP2102
  (bsc#1012628).
- software node: balance refcount for managed software nodes
  (bsc#1012628).
- xen/balloon: fix balloon kthread freezing (bsc#1012628).
- qnx4: work around gcc false positive warning bug (bsc#1012628).
- usb: gadget: f_uac2: Add missing companion descriptor for
  feedback EP (bsc#1012628).
- usb: gadget: f_uac2: Populate SS descriptors' wBytesPerInterval
  (bsc#1012628).
- Refresh patches.suse/drm-vc4-hdmi-Fix-HPD-GPIO-detection.patch.
- commit 85f5318
* Thu Sep 30 2021 mbrugger@suse.com
- arm64: Update config files. (bsc#1185927)
  Set PINCTRL_ZYNQMP as build-in.
- commit 94782db
* Mon Sep 27 2021 trenn@suse.com
- Those are all really old, some of them might have been fixed via BIOS enhancements:
- Delete patches.suse/acpi_thermal_passive_blacklist.patch. (bsc#1189969)
- Delete
  patches.suse/acpi_thinkpad_introduce_acpi_root_table_boot_param.patch. (bsc#1189968)
- Delete patches.suse/perf_timechart_fix_zero_timestamps.patch. (bsc#1189958)
- Delete patches.suse/pstore_disable_efi_backend_by_default.patch. (bsc#1189961)
- Delete
  patches.suse/x86-apic-force-bigsmp-apic-on-IBM-EXA3-4.patch. (bsc#1189956)
- commit c421931
* Mon Sep 27 2021 msuchanek@suse.de
- kernel-binary.spec: Do not sign kernel when no key provided
  (bsc#1187167).
- commit e3309d1
* Mon Sep 27 2021 jslaby@suse.cz
- blacklist.conf: add idxd commit
- commit 06dbf6b
* Sun Sep 26 2021 mkubecek@suse.cz
- Update to 5.15-rc3
- eliminated 3 patches:
  - patches.rpmify/scripts-sorttable-riscv-fix-undelcred-identifier-EM_.patch
  - patches.suse/posix-cpu-timers-Fix-spuriously-armed-0-value-itimer.patch
  - patches.suse/nvmem-nintendo-otp-add-dependency-on-CONFIG_HAS_IOME.patch
    (still meaningful in upstream but no longer needed four our configs)
- refresh configs
  - drop NVMEM_NINTENDO_OTP
  - i386: drop XEN_PCIDEV_FRONTEND and SWIOTLB_XEN
- commit e48f187
* Sun Sep 26 2021 jslaby@suse.cz
- nvmet: fix a width vs precision bug in
  nvmet_subsys_attr_serial_show() (git-fixes).
- commit fef4ef0
* Sun Sep 26 2021 jslaby@suse.cz
- Linux 5.14.8 (bsc#1012628).
- drm/nouveau/nvkm: Replace -ENOSYS with -ENODEV (bsc#1012628).
- selinux,smack: fix subjective/objective credential use mixups
  (bsc#1012628).
- io_uring: fix off-by-one in BUILD_BUG_ON check of
  __REQ_F_LAST_BIT (bsc#1012628).
- cifs: properly invalidate cached root handle when closing it
  (bsc#1012628).
- sched/idle: Make the idle timer expire in hard interrupt context
  (bsc#1012628).
- rtc: rx8010: select REGMAP_I2C (bsc#1012628).
- blk-mq: allow 4x BLK_MAX_REQUEST_COUNT at blk_plug for
  multiple_queues (bsc#1012628).
- blk-throttle: fix UAF by deleteing timer in blk_throtl_exit()
  (bsc#1012628).
- block: genhd: don't call blkdev_show() with major_names_lock
  held (bsc#1012628).
- nvmet: fixup buffer overrun in nvmet_subsys_attr_serial()
  (bsc#1012628).
- pwm: stm32-lp: Don't modify HW state in .remove() callback
  (bsc#1012628).
- pwm: rockchip: Don't modify HW state in .remove() callback
  (bsc#1012628).
- pwm: img: Don't modify HW state in .remove() callback
  (bsc#1012628).
- habanalabs: cannot sleep while holding spinlock (bsc#1012628).
- habanalabs: add "in device creation" status (bsc#1012628).
- habanalabs: fix mmu node address resolution in debugfs
  (bsc#1012628).
- habanalabs: add validity check for event ID received from F/W
  (bsc#1012628).
- drm/amdgpu: fix fdinfo race with process exit (bsc#1012628).
- drm/amd/display: Fix memory leak reported by coverity
  (bsc#1012628).
- drm/amdgpu: Fixes to returning VBIOS RAS EEPROM address
  (bsc#1012628).
- habanalabs: fix nullifying of destroyed mmu pgt pool
  (bsc#1012628).
- thermal/drivers/rcar_gen3_thermal: Store TSC id as unsigned int
  (bsc#1012628).
- nilfs2: fix memory leak in nilfs_sysfs_delete_snapshot_group
  (bsc#1012628).
- nilfs2: fix memory leak in nilfs_sysfs_create_snapshot_group
  (bsc#1012628).
- nilfs2: fix memory leak in nilfs_sysfs_delete_##name##_group
  (bsc#1012628).
- nilfs2: fix memory leak in nilfs_sysfs_create_##name##_group
  (bsc#1012628).
- nilfs2: fix NULL pointer in nilfs_##name##_attr_release
  (bsc#1012628).
- nilfs2: fix memory leak in nilfs_sysfs_create_device_group
  (bsc#1012628).
- btrfs: fix lockdep warning while mounting sprout fs
  (bsc#1012628).
- btrfs: delay blkdev_put until after the device remove
  (bsc#1012628).
- btrfs: update the bdev time directly when closing (bsc#1012628).
- s390/unwind: use current_frame_address() to unwind current task
  (bsc#1012628).
- ceph: lockdep annotations for try_nonblocking_invalidate
  (bsc#1012628).
- ceph: remove the capsnaps when removing caps (bsc#1012628).
- ceph: request Fw caps before updating the mtime in
  ceph_write_iter (bsc#1012628).
- ceph: fix memory leak on decode error in ceph_handle_caps
  (bsc#1012628).
- ACPI: PM: s2idle: Run both AMD and Microsoft methods if both
  are supported (bsc#1012628).
- ASoC: audio-graph: respawn Platform Support (bsc#1012628).
- s390: add kmemleak annotation in stack_alloc() (bsc#1012628).
- dmaengine: xilinx_dma: Set DMA mask for coherent APIs
  (bsc#1012628).
- dmaengine: ioat: depends on !UML (bsc#1012628).
- cxl/pci: Introduce cdevm_file_operations (bsc#1012628).
- cxl: Move cxl_core to new directory (bsc#1012628).
- dmaengine: sprd: Add missing MODULE_DEVICE_TABLE (bsc#1012628).
- dmaengine: idxd: depends on !UML (bsc#1012628).
- riscv: dts: microchip: mpfs-icicle: Fix serial console
  (bsc#1012628).
- of: property: Disable fw_devlink DT support for X86
  (bsc#1012628).
- drm/ttm: Fix a deadlock if the target BO is not idle during swap
  (bsc#1012628).
- arm64: mm: limit linear region to 51 bits for KVM in nVHE mode
  (bsc#1012628).
- iommu/vt-d: Fix a deadlock in intel_svm_drain_prq()
  (bsc#1012628).
- iommu/vt-d: Fix PASID leak in intel_svm_unbind_mm()
  (bsc#1012628).
- iommu/amd: Relocate GAMSup check to early_enable_iommus
  (bsc#1012628).
- parisc: Move pci_dev_is_behind_card_dino to where it is used
  (bsc#1012628).
- dma-buf: DMABUF_DEBUG should depend on DMA_SHARED_BUFFER
  (bsc#1012628).
- Update config files.
- dma-buf: DMABUF_MOVE_NOTIFY should depend on DMA_SHARED_BUFFER
  (bsc#1012628).
- Update config files.
- drivers: base: cacheinfo: Get rid of
  DEFINE_SMP_CALL_CACHE_FUNCTION() (bsc#1012628).
- drm/amdgpu: Disable PCIE_DPM on Intel RKL Platform
  (bsc#1012628).
- thermal/core: Fix thermal_cooling_device_register() prototype
  (bsc#1012628).
- tracing/boot: Fix to loop on only subkeys (bsc#1012628).
- tools/bootconfig: Fix tracing_on option checking in
  ftrace2bconf.sh (bsc#1012628).
- Kconfig.debug: drop selecting non-existing
  HARDLOCKUP_DETECTOR_ARCH (bsc#1012628).
- init: move usermodehelper_enable() to populate_rootfs()
  (bsc#1012628).
- math: RATIONAL_KUNIT_TEST should depend on RATIONAL instead
  of selecting it (bsc#1012628).
- SUNRPC: don't pause on incomplete allocation (bsc#1012628).
- s390/entry: make oklabel within CHKSTG macro local
  (bsc#1012628).
- platform/chrome: cros_ec_trace: Fix format warnings
  (bsc#1012628).
- platform/chrome: sensorhub: Add trace events for sample
  (bsc#1012628).
- dmaengine: idxd: clear block on fault flag when clear wq
  (bsc#1012628).
- dmaengine: idxd: fix abort status check (bsc#1012628).
- dmaengine: idxd: fix wq slot allocation index check
  (bsc#1012628).
- dmaengine: idxd: have command status always set (bsc#1012628).
- dmanegine: idxd: cleanup all device related bits after disabling
  device (bsc#1012628).
- pwm: mxs: Don't modify HW state in .probe() after the PWM chip
  was registered (bsc#1012628).
- pwm: lpc32xx: Don't modify HW state in .probe() after the PWM
  chip was registered (bsc#1012628).
- ceph: cancel delayed work instead of flushing on mdsc teardown
  (bsc#1012628).
- thermal/drivers/qcom/spmi-adc-tm5: Don't abort probing if a
  sensor is not used (bsc#1012628).
- PM: sleep: core: Avoid setting power.must_resume to false
  (bsc#1012628).
- profiling: fix shift-out-of-bounds bugs (bsc#1012628).
- nilfs2: use refcount_dec_and_lock() to fix potential UAF
  (bsc#1012628).
- prctl: allow to setup brk for et_dyn executables (bsc#1012628).
- pwm: ab8500: Fix register offset calculation to not depend on
  probe order (bsc#1012628).
- 9p/trans_virtio: Remove sysfs file on probe failure
  (bsc#1012628).
- thermal/drivers/exynos: Fix an error code in exynos_tmu_probe()
  (bsc#1012628).
- n64cart: fix return value check in n64cart_probe()
  (bsc#1012628).
- staging: rtl8723bs: fix wpa_set_auth_algs() function
  (bsc#1012628).
- perf tools: Allow build-id with trailing zeros (bsc#1012628).
- perf symbol: Look for ImageBase in PE file to compute .text
  offset (bsc#1012628).
- perf test: Fix bpf test sample mismatch reporting (bsc#1012628).
- dmaengine: acpi: Avoid comparison GSI with Linux vIRQ
  (bsc#1012628).
- RDMA/mlx5: Fix xlt_chunk_align calculation (bsc#1012628).
- RDMA/hns: Enable stash feature of HIP09 (bsc#1012628).
- um: virtio_uml: fix memory leak on init failures (bsc#1012628).
- coredump: fix memleak in dump_vma_snapshot() (bsc#1012628).
- um: fix stub location calculation (bsc#1012628).
- staging: rtl8192u: Fix bitwise vs logical operator in
  TranslateRxSignalStuff819xUsb() (bsc#1012628).
- console: consume APC, DM, DCS (bsc#1012628).
- PCI: aardvark: Fix reporting CRS value (bsc#1012628).
- PCI: pci-bridge-emul: Add PCIe Root Capabilities Register
  (bsc#1012628).
- commit 94242c6
* Sat Sep 25 2021 msuchanek@suse.de
- rpm/config.sh: Compress modules with zstd (jsc#SLE-21256, boo#1192457).
- rpm/config.sh: Compress modules with zstd (jsc#SLE-21256).
- commit 0851921
* Wed Sep 22 2021 msuchanek@suse.de
- kernel-binary.spec: suse-kernel-rpm-scriptlets required for uninstall as
  well.
  Fixes: e98096d5cf85 ("rpm: Abolish scritplet templating (bsc#1189841).")
- commit e082fbf
* Wed Sep 22 2021 jslaby@suse.cz
- Linux 5.14.7 (bsc#1012628).
- net: stmmac: fix MAC not working when system resume back with
  WoL active (bsc#1012628).
- io_uring: ensure symmetry in handling iter types in
  loop_rw_iter() (bsc#1012628).
- swiotlb-xen: avoid double free (bsc#1012628).
- swiotlb-xen: fix late init retry (bsc#1012628).
- xen: reset legacy rtc flag for PV domU (bsc#1012628).
- xen: fix usage of pmd_populate in mremap for pv guests
  (bsc#1012628).
- bnx2x: Fix enabling network interfaces without VFs
  (bsc#1012628).
- arm64/sve: Use correct size when reinitialising SVE state
  (bsc#1012628).
- PM: base: power: don't try to use non-existing RTC for storing
  data (bsc#1012628).
- PCI: Add AMD GPU multi-function power dependencies
  (bsc#1012628).
- drm/amd/display: Get backlight from PWM if DMCU is not
  initialized (bsc#1012628).
- drm/amd/display: dsc mst 2 4K displays go dark with 2 lane HBR3
  (bsc#1012628).
- drm/amd/display: Fix white screen page fault for gpuvm
  (bsc#1012628).
- drm/amd/pm: fix runpm hang when amdgpu loaded prior to sound
  driver (bsc#1012628).
- drm/amd/amdgpu: Increase HWIP_MAX_INSTANCE to 10 (bsc#1012628).
- drm/amdgpu: use IS_ERR for debugfs APIs (bsc#1012628).
- drm/amdgpu: fix use after free during BO move (bsc#1012628).
- drm/amdgpu: add amdgpu_amdkfd_resume_iommu (bsc#1012628).
- drm/amdgpu: move iommu_resume before ip init/resume
  (bsc#1012628).
- drm/amd/pm: fix the issue of uploading powerplay table
  (bsc#1012628).
- drm/amdkfd: separate kfd_iommu_resume from kfd_resume
  (bsc#1012628).
- drm/radeon: pass drm dev radeon_agp_head_init directly
  (bsc#1012628).
- io_uring: allow retry for O_NONBLOCK if async is supported
  (bsc#1012628).
- drm/etnaviv: return context from etnaviv_iommu_context_get
  (bsc#1012628).
- drm/etnaviv: put submit prev MMU context when it exists
  (bsc#1012628).
- drm/etnaviv: stop abusing mmu_context as FE running marker
  (bsc#1012628).
- drm/etnaviv: keep MMU context across runtime suspend/resume
  (bsc#1012628).
- drm/etnaviv: exec and MMU state is lost when resetting the GPU
  (bsc#1012628).
- drm/etnaviv: fix MMU context leak on GPU reset (bsc#1012628).
- drm/etnaviv: reference MMU context when setting up hardware
  state (bsc#1012628).
- drm/etnaviv: add missing MMU context put when reaping MMU
  mapping (bsc#1012628).
- s390/sclp: fix Secure-IPL facility detection (bsc#1012628).
- net: qrtr: revert check in qrtr_endpoint_post() (bsc#1012628).
- x86/pat: Pass valid address to sanitize_phys() (bsc#1012628).
- x86/mm: Fix kern_addr_valid() to cope with existing but not
  present entries (bsc#1012628).
- x86/mce: Avoid infinite loop for copy from user recovery
  (bsc#1012628).
- net: remove the unnecessary check in cipso_v4_doi_free
  (bsc#1012628).
- net/{mlx5|nfp|bnxt}: Remove unnecessary RTNL lock assert
  (bsc#1012628).
- net-caif: avoid user-triggerable WARN_ON(1) (bsc#1012628).
- ptp: dp83640: don't define PAGE0 (bsc#1012628).
- dccp: don't duplicate ccid when cloning dccp sock (bsc#1012628).
- net/l2tp: Fix reference count leak in l2tp_udp_recv_core
  (bsc#1012628).
- r6040: Restore MDIO clock frequency after MAC reset
  (bsc#1012628).
- tipc: increase timeout in tipc_sk_enqueue() (bsc#1012628).
- drm/rockchip: cdn-dp-core: Make cdn_dp_core_resume
  __maybe_unused (bsc#1012628).
- rtc: cmos: Disable irq around direct invocation of
  cmos_interrupt() (bsc#1012628).
- drm/i915/dp: return proper DPRX link training result
  (bsc#1012628).
- perf machine: Initialize srcline string member in add_location
  struct (bsc#1012628).
- net/mlx5: FWTrace, cancel work on alloc pd error flow
  (bsc#1012628).
- net/mlx5: Fix potential sleeping in atomic context
  (bsc#1012628).
- net: stmmac: fix system hang caused by eee_ctrl_timer during
  suspend/resume (bsc#1012628).
- igc: fix tunnel offloading (bsc#1012628).
- nvme-tcp: fix io_work priority inversion (bsc#1012628).
- powerpc/64s: system call scv tabort fix for corrupt irq
  soft-mask state (bsc#1012628).
- events: Reuse value read using READ_ONCE instead of re-reading
  it (bsc#1012628).
- net: ipa: initialize all filter table slots (bsc#1012628).
- gen_compile_commands: fix missing 'sys' package (bsc#1012628).
- vhost_net: fix OoB on sendmsg() failure (bsc#1012628).
- net/af_unix: fix a data-race in unix_dgram_poll (bsc#1012628).
- net: dsa: destroy the phylink instance on any error in
  dsa_slave_phy_setup (bsc#1012628).
- x86/uaccess: Fix 32-bit __get_user_asm_u64() when
  CC_HAS_ASM_GOTO_OUTPUT=y (bsc#1012628).
- tcp: fix tp->undo_retrans accounting in tcp_sacktag_one()
  (bsc#1012628).
- selftest: net: fix typo in altname test (bsc#1012628).
- qed: Handle management FW error (bsc#1012628).
- udp_tunnel: Fix udp_tunnel_nic work-queue type (bsc#1012628).
- dt-bindings: arm: Fix Toradex compatible typo (bsc#1012628).
- ibmvnic: check failover_pending in login response (bsc#1012628).
- KVM: PPC: Book3S HV: Tolerate treclaim. in fake-suspend mode
  changing registers (bsc#1012628).
- powerpc/64s: system call rfscv workaround for TM bugs
  (bsc#1012628).
- powerpc/mce: Fix access error in mce handler (bsc#1012628).
- s390/pci_mmio: fully validate the VMA before calling
  follow_pte() (bsc#1012628).
- bnxt_en: make bnxt_free_skbs() safe to call after
  bnxt_free_mem() (bsc#1012628).
- net: hns3: pad the short tunnel frame before sending to hardware
  (bsc#1012628).
- net: hns3: change affinity_mask to numa node range
  (bsc#1012628).
- net: hns3: disable mac in flr process (bsc#1012628).
- net: hns3: fix the timing issue of VF clearing interrupt sources
  (bsc#1012628).
- net: stmmac: platform: fix build warning when with
  !CONFIG_PM_SLEEP (bsc#1012628).
- Drivers: hv: vmbus: Fix kernel crash upon unbinding a device
  from uio_hv_generic driver (bsc#1012628).
- net/mlx5e: Fix mutual exclusion between CQE compression and
  HW TS (bsc#1012628).
- ice: Correctly deal with PFs that do not support RDMA
  (bsc#1012628).
- net: dsa: qca8k: fix kernel panic with legacy mdio mapping
  (bsc#1012628).
- net: dsa: lantiq_gswip: Add 200ms assert delay (bsc#1012628).
- net: hns3: fix the exception when query imp info (bsc#1012628).
- nvme: avoid race in shutdown namespace removal (bsc#1012628).
- blkcg: fix memory leak in blk_iolatency_init (bsc#1012628).
- net: dsa: flush switchdev workqueue before tearing down CPU/DSA
  ports (bsc#1012628).
- mlxbf_gige: clear valid_polarity upon open (bsc#1012628).
- dt-bindings: mtd: gpmc: Fix the ECC bytes vs. OOB bytes equation
  (bsc#1012628).
- remoteproc: qcom: wcnss: Fix race with iris probe (bsc#1012628).
- mfd: db8500-prcmu: Adjust map to reality (bsc#1012628).
- PCI: Add ACS quirks for NXP LX2xx0 and LX2xx2 platforms
  (bsc#1012628).
- fuse: fix use after free in fuse_read_interrupt() (bsc#1012628).
- PCI: tegra194: Fix handling BME_CHGED event (bsc#1012628).
- PCI: tegra194: Fix MSI-X programming (bsc#1012628).
- PCI: tegra: Fix OF node reference leak (bsc#1012628).
- mfd: Don't use irq_create_mapping() to resolve a mapping
  (bsc#1012628).
- PCI: rcar: Fix runtime PM imbalance in rcar_pcie_ep_probe()
  (bsc#1012628).
- riscv: fix the global name pfn_base confliction error
  (bsc#1012628).
- KVM: arm64: Make hyp_panic() more robust when protected mode
  is enabled (bsc#1012628).
- tracing/probes: Reject events which have the same name of
  existing one (bsc#1012628).
- PCI: cadence: Use bitfield for *quirk_retrain_flag* instead
  of bool (bsc#1012628).
- PCI: cadence: Add quirk flag to set minimum delay in LTSSM
  Detect.Quiet state (bsc#1012628).
- PCI: j721e: Add PCIe support for J7200 (bsc#1012628).
- PCI: j721e: Add PCIe support for AM64 (bsc#1012628).
- PCI: Add ACS quirks for Cavium multi-function devices
  (bsc#1012628).
- watchdog: Start watchdog in watchdog_set_last_hw_keepalive
  only if appropriate (bsc#1012628).
- octeontx2-af: Add additional register check to rvu_poll_reg()
  (bsc#1012628).
- Set fc_nlinfo in nh_create_ipv4, nh_create_ipv6 (bsc#1012628).
- flow: fix object-size-mismatch warning in
  flowi{4,6}_to_flowi_common() (bsc#1012628).
- net: usb: cdc_mbim: avoid altsetting toggling for Telit LN920
  (bsc#1012628).
- block, bfq: honor already-setup queue merges (bsc#1012628).
- PCI: ibmphp: Fix double unmap of io_mem (bsc#1012628).
- loop: reduce the loop_ctl_mutex scope (bsc#1012628).
- ethtool: Fix an error code in cxgb2.c (bsc#1012628).
- NTB: Fix an error code in ntb_msit_probe() (bsc#1012628).
- NTB: perf: Fix an error code in perf_setup_inbuf()
  (bsc#1012628).
- stmmac: dwmac-loongson:Fix missing return value (bsc#1012628).
- net: phylink: add suspend/resume support (bsc#1012628).
- mfd: axp20x: Update AXP288 volatile ranges (bsc#1012628).
- backlight: ktd253: Stabilize backlight (bsc#1012628).
- PCI: controller: PCI_IXP4XX should depend on ARCH_IXP4XX
  (bsc#1012628).
- PCI: of: Don't fail devm_pci_alloc_host_bridge() on missing
  'ranges' (bsc#1012628).
- PCI: iproc: Fix BCMA probe resource handling (bsc#1012628).
- netfilter: nft_ct: protect nft_ct_pcpu_template_refcnt with
  mutex (bsc#1012628).
- KVM: arm64: Restrict IPA size to maximum 48 bits on 4K and
  16K page size (bsc#1012628).
- PCI: Fix pci_dev_str_match_path() alloc while atomic bug
  (bsc#1012628).
- mfd: tqmx86: Clear GPIO IRQ resource when no IRQ is set
  (bsc#1012628).
- tracing/boot: Fix a hist trigger dependency for boot time
  tracing (bsc#1012628).
- mtd: mtdconcat: Judge callback existence based on the master
  (bsc#1012628).
- mtd: mtdconcat: Check _read, _write callbacks existence before
  assignment (bsc#1012628).
- KVM: arm64: Fix read-side race on updates to vcpu reset state
  (bsc#1012628).
- KVM: arm64: Handle PSCI resets before userspace touches vCPU
  state (bsc#1012628).
- PCI/PTM: Remove error message at boot (bsc#1012628).
- PCI: Sync __pci_register_driver() stub for CONFIG_PCI=n
  (bsc#1012628).
- mtd: rawnand: cafe: Fix a resource leak in the error handling
  path of 'cafe_nand_probe()' (bsc#1012628).
- ARC: export clear_user_page() for modules (bsc#1012628).
- perf config: Fix caching and memory leak in
  perf_home_perfconfig() (bsc#1012628).
- perf unwind: Do not overwrite
  FEATURE_CHECK_LDFLAGS-libunwind-{x86,aarch64} (bsc#1012628).
- perf bench inject-buildid: Handle writen() errors (bsc#1012628).
- gpio: mpc8xxx: Fix a resources leak in the error handling path
  of 'mpc8xxx_probe()' (bsc#1012628).
- gpio: mpc8xxx: Fix a potential double iounmap call in
  'mpc8xxx_probe()' (bsc#1012628).
- gpio: mpc8xxx: Use 'devm_gpiochip_add_data()' to simplify the
  code and avoid a leak (bsc#1012628).
- io_uring: retry in case of short read on block device
  (bsc#1012628).
- net: dsa: tag_rtl4_a: Fix egress tags (bsc#1012628).
- tools build: Fix feature detect clean for out of source builds
  (bsc#1012628).
- mptcp: fix possible divide by zero (bsc#1012628).
- selftests: mptcp: clean tmp files in simult_flows (bsc#1012628).
- net: hso: add failure handler for add_net_device (bsc#1012628).
- net: dsa: b53: Fix calculating number of switch ports
  (bsc#1012628).
- net: dsa: b53: Set correct number of ports in the DSA struct
  (bsc#1012628).
- mptcp: Only send extra TCP acks in eligible socket states
  (bsc#1012628).
- netfilter: socket: icmp6: fix use-after-scope (bsc#1012628).
- fq_codel: reject silly quantum parameters (bsc#1012628).
- qlcnic: Remove redundant unlock in qlcnic_pinit_from_rom
  (bsc#1012628).
- iwlwifi: move get pnvm file name to a separate function
  (bsc#1012628).
- iwlwifi: pnvm: Fix a memory leak in 'iwl_pnvm_get_from_fs()'
  (bsc#1012628).
- ip_gre: validate csum_start only on pull (bsc#1012628).
- net: dsa: b53: Fix IMP port setup on BCM5301x (bsc#1012628).
- bnxt_en: fix stored FW_PSID version masks (bsc#1012628).
- bnxt_en: Fix asic.rev in devlink dev info command (bsc#1012628).
- bnxt_en: Fix possible unintended driver initiated error recovery
  (bsc#1012628).
- ip6_gre: Revert "ip6_gre: add validation for csum_start"
  (bsc#1012628).
- mfd: lpc_sch: Rename GPIOBASE to prevent build error
  (bsc#1012628).
- cxgb3: fix oops on module removal (bsc#1012628).
- net: renesas: sh_eth: Fix freeing wrong tx descriptor
  (bsc#1012628).
- bnxt_en: Fix error recovery regression (bsc#1012628).
- net: dsa: bcm_sf2: Fix array overrun in
  bcm_sf2_num_active_ports() (bsc#1012628).
- s390/bpf: Fix optimizing out zero-extensions (bsc#1012628).
- s390/bpf: Fix 64-bit subtraction of the -0x80000000 constant
  (bsc#1012628).
- s390/bpf: Fix branch shortening during codegen pass
  (bsc#1012628).
- Update config files.
- commit aa9b3e1
* Tue Sep 21 2021 jslaby@suse.cz
- Revert "Revert "rpm: Abolish scritplet templating (bsc#1189841).""
  This reverts commit f924054cc523527b52203e352adb073db0962f5f.
  New suse-module-tools were accepted to factory:
  https://build.opensuse.org/request/show/919089
- commit 6abad1e
* Mon Sep 20 2021 mkubecek@suse.cz
- Update to 5.15-rc2
- eliminated 2 patches
  - patches.suse/memblock-introduce-saner-memblock_free_ptr-interface.patch
  - patches.suse/tools-bootconfig-define-memblock_free_ptr-to-fix-build-error.patch
- update configs
  - ARCH_NR_GPIO (1024 on x86_64, 512 on i386)
  - drop WARN_DYNAMIC_STACK on s390x
- commit 05c92eb
* Sat Sep 18 2021 jslaby@suse.cz
- Revert "usb: xhci-mtk: Do not use xhci's virt_dev in drop_endpoint"
  (git-fixes).
- tipc: fix an use-after-free issue in tipc_recvmsg (git-fixes).
- ethtool: Fix rxnfc copy to user buffer overflow (git-fixes).
- commit 6131a3c
* Sat Sep 18 2021 jslaby@suse.cz
- Linux 5.14.6 (bsc#1012628).
- Makefile: use -Wno-main in the full kernel tree (bsc#1012628).
- rtc: tps65910: Correct driver module alias (bsc#1012628).
- io_uring: place fixed tables under memcg limits (bsc#1012628).
- io_uring: add ->splice_fd_in checks (bsc#1012628).
- io_uring: fix io_try_cancel_userdata race for iowq
  (bsc#1012628).
- io-wq: fix wakeup race when adding new work (bsc#1012628).
- io-wq: fix race between adding work and activating a free worker
  (bsc#1012628).
- btrfs: use delalloc_bytes to determine flush amount for
  shrink_delalloc (bsc#1012628).
- btrfs: wake up async_delalloc_pages waiters after submit
  (bsc#1012628).
- btrfs: wait on async extents when flushing delalloc
  (bsc#1012628).
- btrfs: reduce the preemptive flushing threshold to 90%%
  (bsc#1012628).
- btrfs: do not do preemptive flushing if the majority is global
  rsv (bsc#1012628).
- btrfs: zoned: fix block group alloc_offset calculation
  (bsc#1012628).
- btrfs: zoned: suppress reclaim error message on EAGAIN
  (bsc#1012628).
- btrfs: fix upper limit for max_inline for page size 64K
  (bsc#1012628).
- btrfs: reset replace target device to allocation state on close
  (bsc#1012628).
- btrfs: zoned: fix double counting of split ordered extent
  (bsc#1012628).
- blk-zoned: allow zone management send operations without
  CAP_SYS_ADMIN (bsc#1012628).
- blk-zoned: allow BLKREPORTZONE without CAP_SYS_ADMIN
  (bsc#1012628).
- powerpc/perf/hv-gpci: Fix counter value parsing (bsc#1012628).
- xen: fix setting of max_pfn in shared_info (bsc#1012628).
- 9p/xen: Fix end of loop tests for list_for_each_entry
  (bsc#1012628).
- ceph: fix dereference of null pointer cf (bsc#1012628).
- Input: elan_i2c - reduce the resume time for controller in
  Whitebox (bsc#1012628).
- selftests/ftrace: Fix requirement check of README file
  (bsc#1012628).
- tools/thermal/tmon: Add cross compiling support (bsc#1012628).
- clk: socfpga: agilex: fix the parents of the psi_ref_clk
  (bsc#1012628).
- clk: socfpga: agilex: fix up s2f_user0_clk representation
  (bsc#1012628).
- clk: socfpga: agilex: add the bypass register for s2f_usr0 clock
  (bsc#1012628).
- pinctrl: stmfx: Fix hazardous u8[] to unsigned long cast
  (bsc#1012628).
- pinctrl: ingenic: Fix incorrect pull up/down info (bsc#1012628).
- pinctrl: ingenic: Fix bias config for X2000(E) (bsc#1012628).
- soc: mediatek: mmsys: Fix missing UFOE component in mt8173
  table routing (bsc#1012628).
- soc: qcom: aoss: Fix the out of bound usage of cooling_devs
  (bsc#1012628).
- soc: aspeed: lpc-ctrl: Fix boundary check for mmap
  (bsc#1012628).
- soc: aspeed: p2a-ctrl: Fix boundary check for mmap
  (bsc#1012628).
- arm64: Move .hyp.rodata outside of the _sdata.._edata range
  (bsc#1012628).
- arm64: mm: Fix TLBI vs ASID rollover (bsc#1012628).
- arm64: head: avoid over-mapping in map_memory (bsc#1012628).
- arm64: Do not trap PMSNEVFR_EL1 (bsc#1012628).
- iio: ltc2983: fix device probe (bsc#1012628).
- wcn36xx: Ensure finish scan is not requested before start scan
  (bsc#1012628).
- crypto: public_key: fix overflow during implicit conversion
  (bsc#1012628).
- block: bfq: fix bfq_set_next_ioprio_data() (bsc#1012628).
- power: supply: max17042: handle fails of reading status register
  (bsc#1012628).
- dm crypt: Avoid percpu_counter spinlock contention in
  crypt_page_alloc() (bsc#1012628).
- crypto: ccp - shutdown SEV firmware on kexec (bsc#1012628).
- spi: fsi: Reduce max transfer size to 8 bytes (bsc#1012628).
- VMCI: fix NULL pointer dereference when unmapping queue pair
  (bsc#1012628).
- media: uvc: don't do DMA on stack (bsc#1012628).
- media: rc-loopback: return number of emitters rather than error
  (bsc#1012628).
- nvmem: core: fix error handling while validating keepout regions
  (bsc#1012628).
- s390/qdio: fix roll-back after timeout on ESTABLISH ccw
  (bsc#1012628).
- s390/qdio: cancel the ESTABLISH ccw after timeout (bsc#1012628).
- Revert "dmaengine: imx-sdma: refine to load context only once"
  (bsc#1012628).
- dmaengine: imx-sdma: remove duplicated sdma_load_context
  (bsc#1012628).
- watchdog: iTCO_wdt: Fix detection of SMI-off case (bsc#1012628).
- libata: add ATA_HORKAGE_NO_NCQ_TRIM for Samsung 860 and 870 SSDs
  (bsc#1012628).
- ARM: 9105/1: atags_to_fdt: don't warn about stack size
  (bsc#1012628).
- sched: Prevent balance_push() on remote runqueues (bsc#1012628).
- f2fs: let's keep writing IOs on SBI_NEED_FSCK (bsc#1012628).
- f2fs: fix to do sanity check for sb/cp fields correctly
  (bsc#1012628).
- PCI/portdrv: Enable Bandwidth Notification only if port supports
  it (bsc#1012628).
- PCI: Restrict ASMedia ASM1062 SATA Max Payload Size Supported
  (bsc#1012628).
- PCI: Return ~0 data on pciconfig_read() CAP_SYS_ADMIN failure
  (bsc#1012628).
- PCI: xilinx-nwl: Enable the clock through CCF (bsc#1012628).
- PCI: aardvark: Configure PCIe resources from 'ranges' DT
  property (bsc#1012628).
- PCI: aardvark: Fix checking for PIO status (bsc#1012628).
- PCI: aardvark: Increase polling delay to 1.5s while waiting
  for PIO response (bsc#1012628).
- PCI: aardvark: Fix masking and unmasking legacy INTx interrupts
  (bsc#1012628).
- f2fs: compress: fix to set zstd compress level correctly
  (bsc#1012628).
- RDMA/rtrs: move wr_cnt from rtrs_srv_con to rtrs_con
  (bsc#1012628).
- RDMA/rtrs: Enable the same selective signal for heartbeat and IO
  (bsc#1012628).
- RDMA/rtrs: Move sq_wr_avail to rtrs_con (bsc#1012628).
- HID: input: do not report stylus battery state as "full"
  (bsc#1012628).
- clk: renesas: rzg2l: Fix off-by-one check in
  rzg2l_cpg_clk_src_twocell_get() (bsc#1012628).
- f2fs: quota: fix potential deadlock (bsc#1012628).
- pinctrl: armada-37xx: Correct PWM pins definitions
  (bsc#1012628).
- scsi: bsg: Remove support for SCSI_IOCTL_SEND_COMMAND
  (bsc#1012628).
- clk: rockchip: drop GRF dependency for rk3328/rk3036 pll types
  (bsc#1012628).
- IB/hfi1: Adjust pkey entry in index 0 (bsc#1012628).
- RDMA/iwcm: Release resources if iw_cm module initialization
  fails (bsc#1012628).
- docs: Fix infiniband uverbs minor number (bsc#1012628).
- scsi: BusLogic: Use %%X for u32 sized integer rather than %%lX
  (bsc#1012628).
- pinctrl: samsung: Fix pinctrl bank pin count (bsc#1012628).
- f2fs: do not submit NEW_ADDR to read node block (bsc#1012628).
- f2fs: turn back remapped address in compressed page endio
  (bsc#1012628).
- f2fs: fix wrong checkpoint_changed value in f2fs_remount()
  (bsc#1012628).
- vfio: Use config not menuconfig for VFIO_NOIOMMU (bsc#1012628).
- scsi: ufs: Fix memory corruption by ufshcd_read_desc_param()
  (bsc#1012628).
- scsi: ufs: Use DECLARE_COMPLETION_ONSTACK() where appropriate
  (bsc#1012628).
- scsi: ufs: Fix the SCSI abort handler (bsc#1012628).
- cpuidle: pseries: Fixup CEDE0 latency only for POWER10 onwards
  (bsc#1012628).
- powerpc/stacktrace: Include linux/delay.h (bsc#1012628).
- RDMA/hns: Don't overwrite supplied QP attributes (bsc#1012628).
- RDMA/efa: Remove double QP type assignment (bsc#1012628).
- RDMA/mlx5: Delete not-available udata check (bsc#1012628).
- cpuidle: pseries: Mark pseries_idle_proble() as __init
  (bsc#1012628).
- f2fs: reduce the scope of setting fsck tag when de->name_len
  is zero (bsc#1012628).
- openrisc: don't printk() unconditionally (bsc#1012628).
- dma-debug: fix debugfs initialization order (bsc#1012628).
- xprtrdma: Put rpcrdma_reps before waking the tear-down
  completion (bsc#1012628).
- NFSv4/pNFS: Fix a layoutget livelock loop (bsc#1012628).
- NFSv4/pNFS: Always allow update of a zero valued layout barrier
  (bsc#1012628).
- NFSv4/pnfs: The layout barrier indicate a minimal value for
  the seqid (bsc#1012628).
- SUNRPC: Fix potential memory corruption (bsc#1012628).
- SUNRPC/xprtrdma: Fix reconnection locking (bsc#1012628).
- sunrpc: Fix return value of get_srcport() (bsc#1012628).
- scsi: ufs: Fix unsigned int compared with less than zero
  (bsc#1012628).
- scsi: ufshcd: Fix device links when BOOT WLUN fails to probe
  (bsc#1012628).
- scsi: fdomain: Fix error return code in fdomain_probe()
  (bsc#1012628).
- pinctrl: single: Fix error return code in
  pcs_parse_bits_in_pinctrl_entry() (bsc#1012628).
- powerpc/numa: Consider the max NUMA node for migratable LPAR
  (bsc#1012628).
- vfio/mbochs: Fix missing error unwind of mbochs_used_mbytes
  (bsc#1012628).
- platform/x86: ISST: Fix optimization with use of numa
  (bsc#1012628).
- scsi: smartpqi: Fix an error code in pqi_get_raid_map()
  (bsc#1012628).
- scsi: qedi: Fix error codes in qedi_alloc_global_queues()
  (bsc#1012628).
- scsi: qedf: Fix error codes in qedf_alloc_global_queues()
  (bsc#1012628).
- powerpc/config: Fix IPV6 warning in mpc855_ads (bsc#1012628).
- powerpc/config: Renable MTD_PHYSMAP_OF (bsc#1012628).
- f2fs: fix to keep compatibility of fault injection interface
  (bsc#1012628).
- iommu/vt-d: Update the virtual command related registers
  (bsc#1012628).
- RDMA/hns: Fix return in hns_roce_rereg_user_mr() (bsc#1012628).
- HID: amd_sfh: Fix period data field to enable sensor
  (bsc#1012628).
- HID: i2c-hid: Fix Elan touchpad regression (bsc#1012628).
- HID: thrustmaster: clean up Makefile and adapt quirks
  (bsc#1012628).
- RDMA/hns: Ownerbit mode add control field (bsc#1012628).
- clk: imx8mm: use correct mux type for clkout path (bsc#1012628).
- clk: imx8m: fix clock tree update of TF-A managed clocks
  (bsc#1012628).
- KVM: PPC: Book3S HV: Fix copy_tofrom_guest routines
  (bsc#1012628).
- scsi: ufs: ufs-exynos: Fix static checker warning (bsc#1012628).
- KVM: PPC: Book3S HV Nested: Reflect guest PMU in-use to L0
  when guest SPRs are live (bsc#1012628).
- powerpc/perf: Fix the check for SIAR value (bsc#1012628).
- RDMA/hns: Fix incorrect lsn field (bsc#1012628).
- RDMA/hns: Bugfix for data type of dip_idx (bsc#1012628).
- RDMA/hns: Bugfix for the missing assignment for dip_idx
  (bsc#1012628).
- RDMA/hns: Bugfix for incorrect association between dip_idx
  and dgid (bsc#1012628).
- platform/x86: dell-smbios-wmi: Add missing kfree in error-exit
  from run_smbios_call (bsc#1012628).
- powerpc/smp: Fix a crash while booting kvm guest with nr_cpus=2
  (bsc#1012628).
- powerpc/smp: Update cpu_core_map on all PowerPc systems
  (bsc#1012628).
- RDMA/hns: Fix query destination qpn (bsc#1012628).
- RDMA/hns: Fix QP's resp incomplete assignment (bsc#1012628).
- fscache: Fix cookie key hashing (bsc#1012628).
- clk: ralink: avoid to set 'CLK_IS_CRITICAL' flag for gates
  (bsc#1012628).
- clk: at91: clk-generated: Limit the requested rate to our range
  (bsc#1012628).
- KVM: PPC: Fix clearing never mapped TCEs in realmode
  (bsc#1012628).
- soc: mediatek: cmdq: add address shift in jump (bsc#1012628).
- f2fs: fix to account missing .skipped_gc_rwsem (bsc#1012628).
- f2fs: fix unexpected ENOENT comes from f2fs_map_blocks()
  (bsc#1012628).
- f2fs: fix to unmap pages from userspace process in punch_hole()
  (bsc#1012628).
- f2fs: deallocate compressed pages when error happens
  (bsc#1012628).
- f2fs: should put a page beyond EOF when preparing a write
  (bsc#1012628).
- MIPS: Malta: fix alignment of the devicetree buffer
  (bsc#1012628).
- kbuild: Fix 'no symbols' warning when CONFIG_TRIM_UNUSD_KSYMS=y
  (bsc#1012628).
- userfaultfd: prevent concurrent API initialization
  (bsc#1012628).
- drm/vmwgfx: Fix subresource updates with new contexts
  (bsc#1012628).
- drm/vmwgfx: Fix some static checker warnings (bsc#1012628).
- drm/vc4: hdmi: Set HD_CTL_WHOLSMP and HD_CTL_CHALIGN_SET
  (bsc#1012628).
- drm/ttm: Fix multihop assert on eviction (bsc#1012628).
- drm/omap: Follow implicit fencing in prepare_fb (bsc#1012628).
- drm/amdgpu: Fix amdgpu_ras_eeprom_init() (bsc#1012628).
- drm/amdgpu: Fix koops when accessing RAS EEPROM (bsc#1012628).
- drm: vc4: Fix pixel-wrap issue with DVP teardown (bsc#1012628).
- dma-buf: fix dma_resv_test_signaled test_all handling v2
  (bsc#1012628).
- drm/panel: Fix up DT bindings for Samsung lms397kf04
  (bsc#1012628).
- ASoC: ti: davinci-mcasp: Fix DIT mode support (bsc#1012628).
- ASoC: atmel: ATMEL drivers don't need HAS_DMA (bsc#1012628).
- media: dib8000: rewrite the init prbs logic (bsc#1012628).
- media: ti-vpe: cal: fix error handling in cal_camerarx_create
  (bsc#1012628).
- media: ti-vpe: cal: fix queuing of the initial buffer
  (bsc#1012628).
- libbpf: Fix reuse of pinned map on older kernel (bsc#1012628).
- drm/vkms: Let shadow-plane helpers prepare the plane's FB
  (bsc#1012628).
- x86/hyperv: fix for unwanted manipulation of sched_clock when
  TSC marked unstable (bsc#1012628).
- crypto: mxs-dcp - Use sg_mapping_iter to copy data
  (bsc#1012628).
- PCI: Use pci_update_current_state() in pci_enable_device_flags()
  (bsc#1012628).
- tipc: keep the skb in rcv queue until the whole data is read
  (bsc#1012628).
- net: phy: Fix data type in DP83822 dp8382x_disable_wol()
  (bsc#1012628).
- iio: dac: ad5624r: Fix incorrect handling of an optional
  regulator (bsc#1012628).
- iavf: do not override the adapter state in the watchdog task
  (bsc#1012628).
- iavf: fix locking of critical sections (bsc#1012628).
- ARM: dts: qcom: apq8064: correct clock names (bsc#1012628).
- video: fbdev: kyro: fix a DoS bug by restricting user input
  (bsc#1012628).
- drm/ast: Disable fast reset after DRAM initial (bsc#1012628).
- netlink: Deal with ESRCH error in nlmsg_notify() (bsc#1012628).
- arm64: dts: qcom: Fix usb entries for SA8155p adp board
  (bsc#1012628).
- net: ipa: fix IPA v4.11 interconnect data (bsc#1012628).
- Smack: Fix wrong semantics in smk_access_entry() (bsc#1012628).
- drm: avoid blocking in drm_clients_info's rcu section
  (bsc#1012628).
- drm: serialize drm_file.master with a new spinlock
  (bsc#1012628).
- drm: protect drm_master pointers in drm_lease.c (bsc#1012628).
- rcu: Fix macro name CONFIG_TASKS_RCU_TRACE (bsc#1012628).
- igc: Check if num of q_vectors is smaller than max before
  array access (bsc#1012628).
- usb: host: fotg210: fix the endpoint's transactional
  opportunities calculation (bsc#1012628).
- usb: host: fotg210: fix the actual_length of an iso packet
  (bsc#1012628).
- usb: gadget: u_ether: fix a potential null pointer dereference
  (bsc#1012628).
- USB: EHCI: ehci-mv: improve error handling in mv_ehci_enable()
  (bsc#1012628).
- usb: gadget: composite: Allow bMaxPower=0 if self-powered
  (bsc#1012628).
- staging: board: Fix uninitialized spinlock when attaching genpd
  (bsc#1012628).
- staging: hisilicon,hi6421-spmi-pmic.yaml: fix patternProperties
  (bsc#1012628).
- tty: serial: jsm: hold port lock when reporting modem line
  changes (bsc#1012628).
- bus: fsl-mc: fix arg in call to dprc_scan_objects()
  (bsc#1012628).
- bus: fsl-mc: fix mmio base address for child DPRCs
  (bsc#1012628).
- misc/pvpanic-pci: Allow automatic loading (bsc#1012628).
- selftests: firmware: Fix ignored return val of asprintf() warn
  (bsc#1012628).
- drm/amd/display: Fix timer_per_pixel unit error (bsc#1012628).
- media: hantro: vp8: Move noisy WARN_ON to vpu_debug
  (bsc#1012628).
- media: platform: stm32: unprepare clocks at handling errors
  in probe (bsc#1012628).
- media: atomisp: Fix runtime PM imbalance in atomisp_pci_probe
  (bsc#1012628).
- media: atomisp: pci: fix error return code in
  atomisp_pci_probe() (bsc#1012628).
- nfp: fix return statement in nfp_net_parse_meta() (bsc#1012628).
- ethtool: improve compat ioctl handling (bsc#1012628).
- drm/amd/display: Fixed hardware power down bypass during
  headless boot (bsc#1012628).
- drm/amdgpu: Fix a printing message (bsc#1012628).
- drm/amd/amdgpu: Update debugfs link_settings output link_rate
  field in hex (bsc#1012628).
- bpf/tests: Fix copy-and-paste error in double word test
  (bsc#1012628).
- bpf/tests: Do not PASS tests without actually testing the result
  (bsc#1012628).
- drm/bridge: nwl-dsi: Avoid potential multiplication overflow
  on 32-bit (bsc#1012628).
- arm64: dts: allwinner: h6: tanix-tx6: Fix regulator node names
  (bsc#1012628).
- video: fbdev: asiliantfb: Error out if 'pixclock' equals zero
  (bsc#1012628).
- video: fbdev: kyro: Error out if 'pixclock' equals zero
  (bsc#1012628).
- video: fbdev: riva: Error out if 'pixclock' equals zero
  (bsc#1012628).
- net: ipa: fix ipa_cmd_table_valid() (bsc#1012628).
- net: ipa: always validate filter and route tables (bsc#1012628).
- ipv4: ip_output.c: Fix out-of-bounds warning in ip_copy_addrs()
  (bsc#1012628).
- flow_dissector: Fix out-of-bounds warnings (bsc#1012628).
- s390/jump_label: print real address in a case of a jump label
  bug (bsc#1012628).
- s390: make PCI mio support a machine flag (bsc#1012628).
- serial: 8250: Define RX trigger levels for OxSemi 950 devices
  (bsc#1012628).
- serial: max310x: Use clock-names property matching to recognize
  EXTCLK (bsc#1012628).
- xtensa: ISS: don't panic in rs_init (bsc#1012628).
- hvsi: don't panic on tty_register_driver failure (bsc#1012628).
- serial: 8250_pci: make setup_port() parameters explicitly
  unsigned (bsc#1012628).
- vt: keyboard.c: make console an unsigned int (bsc#1012628).
- staging: ks7010: Fix the initialization of the 'sleep_status'
  structure (bsc#1012628).
- drm/amd/display: Fix PSR command version (bsc#1012628).
- samples: bpf: Fix tracex7 error raised on the missing argument
  (bsc#1012628).
- libbpf: Fix race when pinning maps in parallel (bsc#1012628).
- ata: sata_dwc_460ex: No need to call phy_exit() befre phy_init()
  (bsc#1012628).
- drm: rcar-du: Shutdown the display on system shutdown
  (bsc#1012628).
- Bluetooth: skip invalid hci_sync_conn_complete_evt
  (bsc#1012628).
- workqueue: Fix possible memory leaks in wq_numa_init()
  (bsc#1012628).
- ARM: dts: stm32: Set {bitclock,frame}-master phandles on DHCOM
  SoM (bsc#1012628).
- ARM: dts: stm32: Set {bitclock,frame}-master phandles on ST DKx
  (bsc#1012628).
- ARM: dts: stm32: Update AV96 adv7513 node per dtbs_check
  (bsc#1012628).
- drm/msm/a6xx: Fix llcc configuration for a660 gpu (bsc#1012628).
- netfilter: nft_compat: use nfnetlink_unicast() (bsc#1012628).
- bonding: 3ad: fix the concurrency between __bond_release_one()
  and bond_3ad_state_machine_handler() (bsc#1012628).
- ARM: dts: at91: use the right property for shutdown controller
  (bsc#1012628).
- arm64: tegra: Fix Tegra194 PCIe EP compatible string
  (bsc#1012628).
- ASoC: Intel: bytcr_rt5640: Move "Platform Clock" routes to
  the maps for the matching in-/output (bsc#1012628).
- ASoC: Intel: update sof_pcm512x quirks (bsc#1012628).
- Bluetooth: Fix not generating RPA when required (bsc#1012628).
- dpaa2-switch: do not enable the DPSW at probe time
  (bsc#1012628).
- media: imx258: Rectify mismatch of VTS value (bsc#1012628).
- media: imx258: Limit the max analogue gain to 480 (bsc#1012628).
- media: imx: imx7-media-csi: Fix buffer return upon stream
  start failure (bsc#1012628).
- media: v4l2-dv-timings.c: fix wrong condition in two for-loops
  (bsc#1012628).
- media: TDA1997x: fix tda1997x_query_dv_timings() return value
  (bsc#1012628).
- media: tegra-cec: Handle errors of clk_prepare_enable()
  (bsc#1012628).
- gfs2: Fix glock recursion in freeze_go_xmote_bh (bsc#1012628).
- arm64: dts: qcom: sdm630: Rewrite memory map (bsc#1012628).
- arm64: dts: qcom: sdm630: Fix TLMM node and pinctrl
  configuration (bsc#1012628).
- net: ipa: fix IPA v4.9 interconnects (bsc#1012628).
- serial: 8250_omap: Handle optional overrun-throttle-ms property
  (bsc#1012628).
- misc: sram: Only map reserved areas in Tegra SYSRAM
  (bsc#1012628).
- ARM: dts: imx53-ppd: Fix ACHC entry (bsc#1012628).
- arm64: dts: qcom: ipq8074: fix pci node reg property
  (bsc#1012628).
- arm64: dts: qcom: sdm660: use reg value for memory node
  (bsc#1012628).
- arm64: dts: qcom: ipq6018: drop '0x' from unit address
  (bsc#1012628).
- arm64: dts: qcom: sdm630: don't use underscore in node name
  (bsc#1012628).
- arm64: dts: qcom: msm8994: don't use underscore in node name
  (bsc#1012628).
- arm64: dts: qcom: msm8996: don't use underscore in node name
  (bsc#1012628).
- arm64: dts: qcom: sm8250: Fix epss_l3 unit address
  (bsc#1012628).
- nvmem: qfprom: Fix up qfprom_disable_fuse_blowing() ordering
  (bsc#1012628).
- net: ethernet: stmmac: Do not use unreachable() in
  ipq806x_gmac_probe() (bsc#1012628).
- drm/msm: mdp4: drop vblank get/put from prepare/complete_commit
  (bsc#1012628).
- drm/msm/dsi: Fix DSI and DSI PHY regulator config from SDM660
  (bsc#1012628).
- drm: xlnx: zynqmp_dpsub: Call pm_runtime_get_sync before
  setting pixel clock (bsc#1012628).
- drm: xlnx: zynqmp: release reset to DP controller before
  accessing DP registers (bsc#1012628).
- ARM: dts: ixp4xx: Fix up bad interrupt flags (bsc#1012628).
- thunderbolt: Fix port linking by checking all adapters
  (bsc#1012628).
- drm/amd/display: fix missing writeback disablement if plane
  is removed (bsc#1012628).
- drm/amd/display: fix incorrect CM/TF programming sequence in
  dwb (bsc#1012628).
- selftests/bpf: Fix xdp_tx.c prog section name (bsc#1012628).
- drm/vmwgfx: fix potential UAF in vmwgfx_surface.c (bsc#1012628).
- staging: rtl8723bs: fix right side of condition (bsc#1012628).
- drm/msm/dp: reduce link rate if failed at link training 1
  (bsc#1012628).
- drm/msm/dp: reset aux controller after dp_aux_cmd_fifo_tx()
  failed (bsc#1012628).
- drm/msm/dp: return correct edid checksum after corrupted edid
  checksum read (bsc#1012628).
- drm/msm/dp: do not end dp link training until video is ready
  (bsc#1012628).
- net/mlx5: Fix variable type to match 64bit (bsc#1012628).
- gpu: drm: amd: amdgpu: amdgpu_i2c: fix
  possible uninitialized-variable access in
  amdgpu_i2c_router_select_ddc_port() (bsc#1012628).
- drm/display: fix possible null-pointer dereference in
  dcn10_set_clock() (bsc#1012628).
- mac80211: Fix monitor MTU limit so that A-MSDUs get through
  (bsc#1012628).
- ARM: tegra: acer-a500: Remove bogus USB VBUS regulators
  (bsc#1012628).
- ARM: tegra: tamonten: Fix UART pad setting (bsc#1012628).
- arm64: tegra: Fix compatible string for Tegra132 CPUs
  (bsc#1012628).
- arm64: dts: imx8mm-venice-gw700x: fix mp5416 pmic config
  (bsc#1012628).
- arm64: dts: imx8mm-venice-gw700x: fix invalid pmic pin config
  (bsc#1012628).
- arm64: dts: imx8mm-venice-gw71xx: fix USB OTG VBUS
  (bsc#1012628).
- arm64: dts: ls1046a: fix eeprom entries (bsc#1012628).
- nvme-tcp: don't check blk_mq_tag_to_rq when receiving pdu data
  (bsc#1012628).
- nvme: code command_id with a genctr for use-after-free
  validation (bsc#1012628).
- Bluetooth: Fix handling of LE Enhanced Connection Complete
  (bsc#1012628).
- Bluetooth: Fix race condition in handling NOP command
  (bsc#1012628).
- opp: Don't print an error if required-opps is missing
  (bsc#1012628).
- serial: sh-sci: fix break handling for sysrq (bsc#1012628).
- iomap: pass writeback errors to the mapping (bsc#1012628).
- tcp: enable data-less, empty-cookie SYN with
  TFO_SERVER_COOKIE_NOT_REQD (bsc#1012628).
- locking/rtmutex: Set proper wait context for lockdep
  (bsc#1012628).
- rpc: fix gss_svc_init cleanup on failure (bsc#1012628).
- iavf: use mutexes for locking of critical sections
  (bsc#1012628).
- selftests/bpf: Correctly display subtest skip status
  (bsc#1012628).
- selftests/bpf: Fix flaky send_signal test (bsc#1012628).
- hwmon: (pmbus/ibm-cffps) Fix write bits for LED control
  (bsc#1012628).
- staging: rts5208: Fix get_ms_information() heap buffer size
  (bsc#1012628).
- selftests: nci: Fix the code for next nlattr offset
  (bsc#1012628).
- selftests: nci: Fix the wrong condition (bsc#1012628).
- net: Fix offloading indirect devices dependency on qdisc order
  creation (bsc#1012628).
- kselftest/arm64: mte: Fix misleading output when skipping tests
  (bsc#1012628).
- kselftest/arm64: pac: Fix skipping of tests on systems without
  PAC (bsc#1012628).
- ASoC: rsnd: adg: clearly handle clock error / NULL case
  (bsc#1012628).
- gfs2: Don't call dlm after protocol is unmounted (bsc#1012628).
- usb: chipidea: host: fix port index underflow and UBSAN
  complains (bsc#1012628).
- lockd: lockd server-side shouldn't set fl_ops (bsc#1012628).
- drm/exynos: Always initialize mapping in
  exynos_drm_register_dma() (bsc#1012628).
- rtl8xxxu: Fix the handling of TX A-MPDU aggregation
  (bsc#1012628).
- rtw88: use read_poll_timeout instead of fixed sleep
  (bsc#1012628).
- rtw88: wow: build wow function only if CONFIG_PM is on
  (bsc#1012628).
- rtw88: wow: fix size access error of probe request
  (bsc#1012628).
- octeontx2-pf: Fix NIX1_RX interface backpressure (bsc#1012628).
- m68knommu: only set CONFIG_ISA_DMA_API for ColdFire sub-arch
  (bsc#1012628).
- btrfs: remove racy and unnecessary inode transaction update
  when using no-holes (bsc#1012628).
- btrfs: tree-log: check btrfs_lookup_data_extent return value
  (bsc#1012628).
- soundwire: intel: fix potential race condition during power down
  (bsc#1012628).
- ASoC: Intel: Skylake: Fix module configuration for KPB and MIXER
  (bsc#1012628).
- ASoC: Intel: Skylake: Fix passing loadable flag for module
  (bsc#1012628).
- of: Don't allow __of_attached_node_sysfs() without CONFIG_SYSFS
  (bsc#1012628).
- mmc: sdhci-of-arasan: Modified SD default speed to 19MHz for
  ZynqMP (bsc#1012628).
- mmc: sdhci-of-arasan: Check return value of non-void funtions
  (bsc#1012628).
- mmc: core: Avoid hogging the CPU while polling for busy in
  the I/O err path (bsc#1012628).
- mmc: core: Avoid hogging the CPU while polling for busy for
  mmc ioctls (bsc#1012628).
- mmc: core: Avoid hogging the CPU while polling for busy after
  I/O writes (bsc#1012628).
- mmc: rtsx_pci: Fix long reads when clock is prescaled
  (bsc#1012628).
- selftests/bpf: Enlarge select() timeout for test_maps
  (bsc#1012628).
- mmc: core: Return correct emmc response in case of ioctl error
  (bsc#1012628).
- octeontx2-pf: cleanup transmit link deriving logic
  (bsc#1012628).
- samples: pktgen: fix to print when terminated normally
  (bsc#1012628).
- cifs: fix wrong release in sess_alloc_buffer() failed path
  (bsc#1012628).
- Revert "USB: xhci: fix U1/U2 handling for hardware with
  XHCI_INTEL_HOST quirk set" (bsc#1012628).
- usb: dwc3: imx8mp: request irq after initializing dwc3
  (bsc#1012628).
- usb: musb: musb_dsps: request_irq() after initializing musb
  (bsc#1012628).
- usbip: give back URBs for unsent unlink requests during cleanup
  (bsc#1012628).
- usbip:vhci_hcd USB port can get stuck in the disabled state
  (bsc#1012628).
- usb: xhci-mtk: fix use-after-free of mtk->hcd (bsc#1012628).
- usb: xhci-mtk: Do not use xhci's virt_dev in drop_endpoint
  (bsc#1012628).
- ASoC: rockchip: i2s: Fix regmap_ops hang (bsc#1012628).
- ASoC: rockchip: i2s: Fixup config for DAIFMT_DSP_A/B
  (bsc#1012628).
- ASoC: soc-pcm: protect BE dailink state changes in trigger
  (bsc#1012628).
- drm/amdkfd: Account for SH/SE count when setting up cu masks
  (bsc#1012628).
- nfs: don't atempt blocking locks on nfs reexports (bsc#1012628).
- nfsd: fix crash on LOCKT on reexported NFSv3 (bsc#1012628).
- iwlwifi: pcie: free RBs during configure (bsc#1012628).
- iwlwifi: mvm: Do not use full SSIDs in 6GHz scan (bsc#1012628).
- iwlwifi: mvm: fix a memory leak in
  iwl_mvm_mac_ctxt_beacon_changed (bsc#1012628).
- iwlwifi: mvm: avoid static queue number aliasing (bsc#1012628).
- iwlwifi: mvm: Fix umac scan request probe parameters
  (bsc#1012628).
- iwlwifi: mvm: fix access to BSS elements (bsc#1012628).
- iwlwifi: fw: correctly limit to monitor dump (bsc#1012628).
- iwlwifi: mvm: don't schedule the roc_done_wk if it is already
  running (bsc#1012628).
- iwlwifi: mvm: Fix scan channel flags settings (bsc#1012628).
- net/mlx5: DR, fix a potential use-after-free bug (bsc#1012628).
- net/mlx5: DR, Enable QP retransmission (bsc#1012628).
- usb: isp1760: fix memory pool initialization (bsc#1012628).
- usb: isp1760: fix qtd fill length (bsc#1012628).
- usb: isp1760: write to status and address register
  (bsc#1012628).
- usb: isp1760: use the right irq status bit (bsc#1012628).
- usb: isp1760: otg control register access (bsc#1012628).
- parport: remove non-zero check on count (bsc#1012628).
- selftests/bpf: Fix potential unreleased lock (bsc#1012628).
- wcn36xx: Fix missing frame timestamp for beacon/probe-resp
  (bsc#1012628).
- ath9k: fix OOB read ar9300_eeprom_restore_internal
  (bsc#1012628).
- ath9k: fix sleeping in atomic context (bsc#1012628).
- net: fix NULL pointer reference in cipso_v4_doi_free
  (bsc#1012628).
- fix array-index-out-of-bounds in taprio_change (bsc#1012628).
- net: w5100: check return value after calling
  platform_get_resource() (bsc#1012628).
- net: hns3: clean up a type mismatch warning (bsc#1012628).
- parisc: fix crash with signals and alloca (bsc#1012628).
- parisc: Fix compile failure when building 64-bit kernel natively
  (bsc#1012628).
- printk/console: Check consistent sequence number when handling
  race in console_unlock() (bsc#1012628).
- ovl: fix BUG_ON() in may_delete() when called from ovl_cleanup()
  (bsc#1012628).
- scsi: BusLogic: Fix missing pr_cont() use (bsc#1012628).
- scsi: qla2xxx: Changes to support kdump kernel (bsc#1012628).
- scsi: qla2xxx: Sync queue idx with queue_pair_map idx
  (bsc#1012628).
- mtd: rawnand: intel: Fix error handling in probe (bsc#1012628).
- cpufreq: powernv: Fix init_chip_info initialization in numa=off
  (bsc#1012628).
- s390/pv: fix the forcing of the swiotlb (bsc#1012628).
- s390/topology: fix topology information when calling cpu
  hotplug notifiers (bsc#1012628).
- mm: fix panic caused by __page_handle_poison() (bsc#1012628).
- hugetlb: fix hugetlb cgroup refcounting during vma split
  (bsc#1012628).
- mm/memory_hotplug: use "unsigned long" for PFN in
  zone_for_pfn_range() (bsc#1012628).
- mm/hmm: bypass devmap pte when all pfn requested flags are
  fulfilled (bsc#1012628).
- mm/hugetlb: initialize hugetlb_usage in mm_init (bsc#1012628).
- mm,vmscan: fix divide by zero in get_scan_count (bsc#1012628).
- mm/page_alloc.c: avoid accessing uninitialized pcp page
  migratetype (bsc#1012628).
- mm/mempolicy: fix a race between offset_il_node and
  mpol_rebind_task (bsc#1012628).
- memcg: enable accounting for pids in nested pid namespaces
  (bsc#1012628).
- libnvdimm/pmem: Fix crash triggered when I/O in-flight during
  unbind (bsc#1012628).
- platform/chrome: cros_ec_proto: Send command again when timeout
  occurs (bsc#1012628).
- lib/test_stackinit: Fix static initializer test (bsc#1012628).
- net: dsa: lantiq_gswip: fix maximum frame length (bsc#1012628).
- net: stmmac: Fix overall budget calculation for rxtx_napi
  (bsc#1012628).
- drm/mgag200: Select clock in PLL update functions (bsc#1012628).
- drm/msi/mdp4: populate priv->kms in mdp4_kms_init (bsc#1012628).
- drm/dp_mst: Fix return code on sideband message failure
  (bsc#1012628).
- drm/panfrost: Make sure MMU context lifetime is not bound to
  panfrost_priv (bsc#1012628).
- drm/amdgpu: Fix BUG_ON assert (bsc#1012628).
- drm/amdgpu: Enable S/G for Yellow Carp (bsc#1012628).
- drm/amdgpu: Fix a deadlock if previous GEM object allocation
  fails (bsc#1012628).
- drm/amd/display: Update number of DCN3 clock states
  (bsc#1012628).
- drm/amd/display: Update bounding box states (v2) (bsc#1012628).
- drm/amdkfd: drop process ref count when xnack disable
  (bsc#1012628).
- drm/amd/display: setup system context for APUs (bsc#1012628).
- drm/msm/disp/dpu1: add safe lut config in dpu driver
  (bsc#1012628).
- drm/ttm: Fix ttm_bo_move_memcpy() for subclassed struct
  ttm_resource (bsc#1012628).
- drm/panfrost: Simplify lock_region calculation (bsc#1012628).
- drm/panfrost: Use u64 for size in lock_region (bsc#1012628).
- drm/panfrost: Clamp lock region to Bifrost minimum
  (bsc#1012628).
- tracing/osnoise: Fix missed cpus_read_unlock() in
  start_per_cpu_kthreads() (bsc#1012628).
- commit 73a28f9
* Fri Sep 17 2021 msuchanek@suse.de
- kernel-binary.spec: Check for no kernel signing certificates.
  Also remove unused variable.
- commit bdc323e
* Fri Sep 17 2021 msuchanek@suse.de
- Revert "rpm/kernel-binary.spec: Use only non-empty certificates."
  This reverts commit 30360abfb58aec2c9ee7b6a27edebe875c90029d.
- commit 413e05b
* Fri Sep 17 2021 mkubecek@suse.cz
- nvmem: nintendo-otp: add dependency on CONFIG_HAS_IOMEM
  (202108250657.h5CWR7Xf-lkp@intel.com).
  Fix s390x/zfcpdump build.
- refresh configs (s390x/zfcpdump: NVMEM_NINTENDO_OTP=n)
- commit 68ad835
* Fri Sep 17 2021 msuchanek@suse.de
- rpm/kernel-binary.spec: Use only non-empty certificates.
- commit 30360ab
* Fri Sep 17 2021 iivanov@suse.de
- drm/vc4: hdmi: Fix HPD GPIO detection (bsc#1190469)
- commit 4a524d3
* Thu Sep 16 2021 jslaby@suse.cz
- Linux 5.14.5 (bsc#1012628).
- Revert "posix-cpu-timers: Force next expiration recalc after
  itimer reset" (bsc#1012628).
- Revert "time: Handle negative seconds correctly in
  timespec64_to_ns()" (bsc#1012628).
- Delete
  patches.suse/posix-cpu-timers-Fix-spuriously-armed-0-value-itimer.patch.
- commit 048e6c0
* Thu Sep 16 2021 bp@suse.de
- crypto: ccp - fix resource leaks in ccp_run_aes_gcm_cmd()
  (bsc#1189884 CVE-2021-3744 bsc#1190534 CVE-2021-3764).
- commit e7a1776
* Thu Sep 16 2021 jslaby@suse.cz
- posix-cpu-timers: Fix spuriously armed 0-value itimer (timer
  breakage).
- commit 2b37340
* Wed Sep 15 2021 vbabka@suse.cz
- tools/bootconfig: Define memblock_free_ptr() to fix build error
  (Build fix for tools.).
- commit 890a28b
* Wed Sep 15 2021 mkubecek@suse.cz
- scripts/sorttable: riscv: fix undelcred identifier 'EM_RISCV'
  error (e8965b25-f15b-c7b4-748c-d207dda9c8e8@i2se.com).
  Fix build on systems with glibc-devel < 2.24.
- commit 62f1dd0
* Wed Sep 15 2021 mkubecek@suse.cz
- config: disable ZERO_CALL_USED_REGS
  This was enable due to a misunderstanding, I thought it was a workaround
  for a recent CPU vulnerability. Now it rather seems to be just another
  hardening with questionable gain and measurable performance impact.
- commit b09844e
* Wed Sep 15 2021 vbabka@suse.cz
- memblock: introduce saner 'memblock_free_ptr()' interface
  (Fixes memory corruption on boot in 5.15-rc1).
- commit 4311d55
* Wed Sep 15 2021 vbabka@suse.cz
- config: disable CONFIG_SYSFB_SIMPLEFB
  The new option in 5.15 is a rename from CONFIG_X86_SYSFB which we had disabled
  due to bsc#855821. Moreover, enabling CONFIG_SYSFB_SIMPLEFB caused regression
  on my UEFI desktop - no printk output on screen between grub's loading of
  kernel and initrd, and a gpu modesetting driver taking over.
- commit 69dc36e
* Wed Sep 15 2021 jslaby@suse.cz
- Revert "rpm: Abolish scritplet templating (bsc#1189841)."
  This reverts commit e98096d5cf85dbe90f74a930eb1f0e3fe4a70c7f.
  "nothing provides suse-kernel-rpm-scriptlets". This is provided by
  suse-module-tools which are not in TW quite yet. See:
  https://build.opensuse.org/request/show/919012
  So revert this temporarily.
- commit f924054
* Wed Sep 15 2021 jslaby@suse.cz
- Linux 5.14.4 (bsc#1012628).
- locking/mutex: Fix HANDOFF condition (bsc#1012628).
- regmap: fix the offset of register error log (bsc#1012628).
- regulator: tps65910: Silence deferred probe error (bsc#1012628).
- crypto: mxs-dcp - Check for DMA mapping errors (bsc#1012628).
- sched/deadline: Fix reset_on_fork reporting of DL tasks
  (bsc#1012628).
- power: supply: axp288_fuel_gauge: Report register-address on
  readb / writeb errors (bsc#1012628).
- crypto: omap-sham - clear dma flags only after
  omap_sham_update_dma_stop() (bsc#1012628).
- sched/deadline: Fix missing clock update in migrate_task_rq_dl()
  (bsc#1012628).
- rcu/tree: Handle VM stoppage in stall detection (bsc#1012628).
- EDAC/mce_amd: Do not load edac_mce_amd module on guests
  (bsc#1012628).
- posix-cpu-timers: Force next expiration recalc after itimer
  reset (bsc#1012628).
- hrtimer: Avoid double reprogramming in
  __hrtimer_start_range_ns() (bsc#1012628).
- hrtimer: Ensure timerfd notification for HIGHRES=n
  (bsc#1012628).
- udf: Check LVID earlier (bsc#1012628).
- udf: Fix iocharset=utf8 mount option (bsc#1012628).
- isofs: joliet: Fix iocharset=utf8 mount option (bsc#1012628).
- bcache: add proper error unwinding in bcache_device_init
  (bsc#1012628).
- nbd: add the check to prevent overflow in __nbd_ioctl()
  (bsc#1012628).
- blk-throtl: optimize IOPS throttle for large IO scenarios
  (bsc#1012628).
- nvme-tcp: don't update queue count when failing to set io queues
  (bsc#1012628).
- nvme-rdma: don't update queue count when failing to set io
  queues (bsc#1012628).
- nvmet: pass back cntlid on successful completion (bsc#1012628).
- power: supply: smb347-charger: Add missing pin control
  activation (bsc#1012628).
- power: supply: max17042_battery: fix typo in MAx17042_TOFF
  (bsc#1012628).
- s390/cio: add dev_busid sysfs entry for each subchannel
  (bsc#1012628).
- s390/zcrypt: fix wrong offset index for APKA master key valid
  state (bsc#1012628).
- libata: fix ata_host_start() (bsc#1012628).
- sched/topology: Skip updating masks for non-online nodes
  (bsc#1012628).
- crypto: omap - Fix inconsistent locking of device lists
  (bsc#1012628).
- crypto: qat - do not ignore errors from enable_vf2pf_comms()
  (bsc#1012628).
- crypto: qat - handle both source of interrupt in VF ISR
  (bsc#1012628).
- crypto: qat - fix reuse of completion variable (bsc#1012628).
- crypto: qat - fix naming for init/shutdown VF to PF
  notifications (bsc#1012628).
- crypto: qat - do not export adf_iov_putmsg() (bsc#1012628).
- crypto: hisilicon/sec - fix the abnormal exiting process
  (bsc#1012628).
- crypto: hisilicon/sec - modify the hardware endian configuration
  (bsc#1012628).
- crypto: tcrypt - Fix missing return value check (bsc#1012628).
- fcntl: fix potential deadlocks for &fown_struct.lock
  (bsc#1012628).
- fcntl: fix potential deadlock for &fasync_struct.fa_lock
  (bsc#1012628).
- udf_get_extendedattr() had no boundary checks (bsc#1012628).
- io-wq: remove GFP_ATOMIC allocation off schedule out path
  (bsc#1012628).
- s390/kasan: fix large PMD pages address alignment check
  (bsc#1012628).
- s390/pci: fix misleading rc in clp_set_pci_fn() (bsc#1012628).
- s390/debug: keep debug data on resize (bsc#1012628).
- s390/debug: fix debug area life cycle (bsc#1012628).
- s390/ap: fix state machine hang after failure to enable irq
  (bsc#1012628).
- s390/smp: enable DAT before CPU restart callback is called
  (bsc#1012628).
- sched/debug: Don't update sched_domain debug directories before
  sched_debug_init() (bsc#1012628).
- power: supply: cw2015: use dev_err_probe to allow deferred probe
  (bsc#1012628).
- m68k: emu: Fix invalid free in nfeth_cleanup() (bsc#1012628).
- crypto: x86/aes-ni - add missing error checks in XTS code
  (bsc#1012628).
- sched/numa: Fix is_core_idle() (bsc#1012628).
- sched: Fix UCLAMP_FLAG_IDLE setting (bsc#1012628).
- rcu: Fix to include first blocked task in stall warning
  (bsc#1012628).
- rcu: Fix stall-warning deadlock due to non-release of rcu_node
  - >lock (bsc#1012628).
- m68k: Fix invalid RMW_INSNS on CPUs that lack CAS (bsc#1012628).
- block: return ELEVATOR_DISCARD_MERGE if possible (bsc#1012628).
- spi: spi-fsl-dspi: Fix issue with uninitialized dma_slave_config
  (bsc#1012628).
- spi: spi-pic32: Fix issue with uninitialized dma_slave_config
  (bsc#1012628).
- genirq/timings: Fix error return code in irq_timings_test_irqs()
  (bsc#1012628).
- irqchip/loongson-pch-pic: Improve edge triggered interrupt
  support (bsc#1012628).
- lib/mpi: use kcalloc in mpi_resize (bsc#1012628).
- clocksource/drivers/sh_cmt: Fix wrong setting if don't request
  IRQ for clock source channel (bsc#1012628).
- nbd: do del_gendisk() asynchronously for
  NBD_DESTROY_ON_DISCONNECT (bsc#1012628).
- block: nbd: add sanity check for first_minor (bsc#1012628).
- spi: coldfire-qspi: Use clk_disable_unprepare in the remove
  function (bsc#1012628).
- irqchip/apple-aic: Fix irq_disable from within irq handlers
  (bsc#1012628).
- irqchip/gic-v3: Fix priority comparison when non-secure
  priorities are used (bsc#1012628).
- crypto: qat - use proper type for vf_mask (bsc#1012628).
- m68k: Fix asm register constraints for atomic ops (bsc#1012628).
- certs: Trigger creation of RSA module signing key if it's not
  an RSA key (bsc#1012628).
- tpm: ibmvtpm: Avoid error message when process gets signal
  while waiting (bsc#1012628).
- EDAC/i10nm: Fix NVDIMM detection (bsc#1012628).
- x86/mce: Defer processing of early errors (bsc#1012628).
- spi: davinci: invoke chipselect callback (bsc#1012628).
- blk-crypto: fix check for too-large dun_bytes (bsc#1012628).
- regulator: vctrl: Use locked regulator_get_voltage in probe path
  (bsc#1012628).
- regulator: vctrl: Avoid lockdep warning in enable/disable ops
  (bsc#1012628).
- spi: sprd: Fix the wrong WDG_LOAD_VAL (bsc#1012628).
- spi: spi-zynq-qspi: use wait_for_completion_timeout to make
  zynq_qspi_exec_mem_op not interruptible (bsc#1012628).
- drm/panfrost: Fix missing clk_disable_unprepare() on error in
  panfrost_clk_init() (bsc#1012628).
- drm/gma500: Fix end of loop tests for list_for_each_entry
  (bsc#1012628).
- ASoC: mediatek: mt8192:Fix Unbalanced pm_runtime_enable in
  mt8192_afe_pcm_dev_probe (bsc#1012628).
- ASoC: mediatek: mt8183: Fix Unbalanced pm_runtime_enable in
  mt8183_afe_pcm_dev_probe (bsc#1012628).
- ASoC: tlv320aic32x4: Fix TAS2505/TAS2521 channel count
  (bsc#1012628).
- media: atmel: atmel-sama5d2-isc: fix YUYV format (bsc#1012628).
- media: TDA1997x: enable EDID support (bsc#1012628).
- leds: is31fl32xx: Fix missing error code in
  is31fl32xx_parse_dt() (bsc#1012628).
- soc: rockchip: ROCKCHIP_GRF should not default to y,
  unconditionally (bsc#1012628).
- media: cxd2880-spi: Fix an error handling path (bsc#1012628).
- drm/of: free the right object (bsc#1012628).
- bpf: Fix a typo of reuseport map in bpf.h (bsc#1012628).
- bpf: Fix potential memleak and UAF in the verifier
  (bsc#1012628).
- drm/of: free the iterator object on failure (bsc#1012628).
- gve: fix the wrong AdminQ buffer overflow check (bsc#1012628).
- libbpf: Fix the possible memory leak on error (bsc#1012628).
- ARM: dts: aspeed-g6: Fix HVI3C function-group in pinctrl dtsi
  (bsc#1012628).
- ARM: dts: everest: Add phase corrections for eMMC (bsc#1012628).
- arm64: dts: renesas: r8a77995: draak: Remove bogus adv7511w
  properties (bsc#1012628).
- i40e: improve locking of mac_filter_hash (bsc#1012628).
- arm64: dts: qcom: sc7180: Set adau wakeup delay to 80 ms
  (bsc#1012628).
- soc: qcom: rpmhpd: Use corner in power_off (bsc#1012628).
- libbpf: Fix removal of inner map in bpf_object__create_map
  (bsc#1012628).
- gfs2: Fix memory leak of object lsi on error return path
  (bsc#1012628).
- arm64: dts: qcom: sm8250: fix usb2 qmp phy node (bsc#1012628).
- bpf, selftests: Fix test_maps now that sockmap supports UDP
  (bsc#1012628).
- firmware: fix theoretical UAF race with firmware cache and
  resume (bsc#1012628).
- driver core: Fix error return code in really_probe()
  (bsc#1012628).
- ionic: cleanly release devlink instance (bsc#1012628).
- media: dvb-usb: fix uninit-value in dvb_usb_adapter_dvb_init
  (bsc#1012628).
- media: dvb-usb: fix uninit-value in vp702x_read_mac_addr
  (bsc#1012628).
- media: dvb-usb: Fix error handling in dvb_usb_i2c_init
  (bsc#1012628).
- net: usb: asix: ax88772: add missing stop (bsc#1012628).
- media: go7007: fix memory leak in go7007_usb_probe
  (bsc#1012628).
- media: go7007: remove redundant initialization (bsc#1012628).
- media: v4l2-subdev: fix some NULL vs IS_ERR() checks
  (bsc#1012628).
- media: rockchip/rga: fix error handling in probe (bsc#1012628).
- media: coda: fix frame_mem_ctrl for YUV420 and YVU420 formats
  (bsc#1012628).
- media: atomisp: fix the uninitialized use and rename "retvalue"
  (bsc#1012628).
- Bluetooth: sco: prevent information leak in
  sco_conn_defer_accept() (bsc#1012628).
- Bluetooth: btusb: Fix a unspported condition to set available
  debug features (bsc#1012628).
- 6lowpan: iphc: Fix an off-by-one check of array index
  (bsc#1012628).
- drm/amdgpu/acp: Make PM domain really work (bsc#1012628).
- drm/amd/pm: Fix a bug communicating with the SMU (v5)
  (bsc#1012628).
- tcp: seq_file: Avoid skipping sk during tcp_seek_last_pos
  (bsc#1012628).
- ARM: dts: meson8: Use a higher default GPU clock frequency
  (bsc#1012628).
- ARM: dts: meson8b: odroidc1: Fix the pwm regulator supply
  properties (bsc#1012628).
- ARM: dts: meson8b: mxq: Fix the pwm regulator supply properties
  (bsc#1012628).
- ARM: dts: meson8b: ec100: Fix the pwm regulator supply
  properties (bsc#1012628).
- net/mlx5e: Prohibit inner indir TIRs in IPoIB (bsc#1012628).
- net/mlx5e: Block LRO if firmware asks for tunneled LRO
  (bsc#1012628).
- cgroup/cpuset: Fix a partition bug with hotplug (bsc#1012628).
- drm: mxsfb: Enable recovery on underflow (bsc#1012628).
- drm: mxsfb: Increase number of outstanding requests on V4 and
  newer HW (bsc#1012628).
- drm: mxsfb: Clear FIFO_CLEAR bit (bsc#1012628).
- net: cipso: fix warnings in netlbl_cipsov4_add_std
  (bsc#1012628).
- net: ti: am65-cpsw-nuss: fix wrong devlink release order
  (bsc#1012628).
- drm: rcar-du: Don't put reference to drm_device in
  rcar_du_remove() (bsc#1012628).
- Bluetooth: mgmt: Fix wrong opcode in the response for add_adv
  cmd (bsc#1012628).
- drm/amd/pm: Fix a bug in semaphore double-lock (bsc#1012628).
- lib/test_scanf: Handle n_bits == 0 in random tests
  (bsc#1012628).
- libbpf: Return non-null error on failures in
  libbpf_find_prog_btf_id() (bsc#1012628).
- tools: Free BTF objects at various locations (bsc#1012628).
- arm64: dts: renesas: hihope-rzg2-ex: Add EtherAVB internal rx
  delay (bsc#1012628).
- net/mlx5: Fix missing return value in
  mlx5_devlink_eswitch_inline_mode_set() (bsc#1012628).
- i2c: highlander: add IRQ check (bsc#1012628).
- leds: lgm-sso: Put fwnode in any case during ->probe()
  (bsc#1012628).
- leds: lgm-sso: Don't spam logs when probe is deferred
  (bsc#1012628).
- leds: lt3593: Put fwnode in any case during ->probe()
  (bsc#1012628).
- leds: rt8515: Put fwnode in any case during ->probe()
  (bsc#1012628).
- leds: trigger: audio: Add an activate callback to ensure the
  initial brightness is set (bsc#1012628).
- media: em28xx-input: fix refcount bug in em28xx_usb_disconnect
  (bsc#1012628).
- media: omap3isp: Fix missing unlock in
  isp_subdev_notifier_complete() (bsc#1012628).
- media: venus: hfi: fix return value check in
  sys_get_prop_image_version() (bsc#1012628).
- media: venus: venc: Fix potential null pointer dereference on
  pointer fmt (bsc#1012628).
- media: venus: helper: do not set constrained parameters for UBWC
  (bsc#1012628).
- soc: mmsys: mediatek: add mask to mmsys routes (bsc#1012628).
- PCI: PM: Avoid forcing PCI_D0 for wakeup reasons inconsistently
  (bsc#1012628).
- PCI: PM: Enable PME if it can be signaled from D3cold
  (bsc#1012628).
- bpf, samples: Add missing mprog-disable to xdp_redirect_cpu's
  optstring (bsc#1012628).
- soc: qcom: smsm: Fix missed interrupts if state changes while
  masked (bsc#1012628).
- net: dsa: build tag_8021q.c as part of DSA core (bsc#1012628).
- net: dsa: tag_sja1105: optionally build as module when switch
  driver is module if PTP is enabled (bsc#1012628).
- debugfs: Return error during {full/open}_proxy_open() on rmmod
  (bsc#1012628).
- Bluetooth: increase BTNAMSIZ to 21 chars to fix potential
  buffer overflow (bsc#1012628).
- arm64: dts: qcom: sc7280: Fixup the cpufreq node (bsc#1012628).
- arm64: dts: qcom: sm8350: fix IPA interconnects (bsc#1012628).
- drm: bridge: it66121: Check drm_bridge_attach retval
  (bsc#1012628).
- net: ti: am65-cpsw-nuss: fix RX IRQ state after .ndo_stop()
  (bsc#1012628).
- net: dsa: stop syncing the bridge mcast_router attribute at
  join time (bsc#1012628).
- net: dsa: mt7530: remove the .port_set_mrouter implementation
  (bsc#1012628).
- net: dsa: don't disable multicast flooding to the CPU even
  without an IGMP querier (bsc#1012628).
- PM: EM: Increase energy calculation precision (bsc#1012628).
- selftests/bpf: Fix bpf-iter-tcp4 test to print correctly the
  dest IP (bsc#1012628).
- leds: lgm-sso: Propagate error codes from callee to caller
  (bsc#1012628).
- drm/msm: Fix error return code in msm_drm_init() (bsc#1012628).
- drm/msm/mdp4: refactor HW revision detection into
  read_mdp_hw_revision (bsc#1012628).
- drm/msm/mdp4: move HW revision detection to earlier phase
  (bsc#1012628).
- drm/msm/dp: update is_connected status base on sink count at
  dp_pm_resume() (bsc#1012628).
- drm/msm/dpu: make dpu_hw_ctl_clear_all_blendstages clear
  necessary LMs (bsc#1012628).
- arm64: dts: exynos: correct GIC CPU interfaces address range
  on Exynos7 (bsc#1012628).
- counter: 104-quad-8: Return error when invalid mode during
  ceiling_write (bsc#1012628).
- cgroup/cpuset: Miscellaneous code cleanup (bsc#1012628).
- cgroup/cpuset: Fix violation of cpuset locking rule
  (bsc#1012628).
- ASoC: Intel: Fix platform ID matching (bsc#1012628).
- Bluetooth: fix repeated calls to sco_sock_kill (bsc#1012628).
- drm/msm/dsi: Fix some reference counted resource leaks
  (bsc#1012628).
- drm/msm/dp: replug event is converted into an unplug followed
  by an plug events (bsc#1012628).
- net/mlx5: Fix unpublish devlink parameters (bsc#1012628).
- ASoC: rt5682: Properly turn off regulators if wrong device ID
  (bsc#1012628).
- usb: dwc3: meson-g12a: add IRQ check (bsc#1012628).
- usb: dwc3: qcom: add IRQ check (bsc#1012628).
- usb: gadget: udc: at91: add IRQ check (bsc#1012628).
- usb: gadget: udc: s3c2410: add IRQ check (bsc#1012628).
- mac80211: remove unnecessary NULL check in
  ieee80211_register_hw() (bsc#1012628).
- usb: misc: brcmstb-usb-pinmap: add IRQ check (bsc#1012628).
- usb: phy: fsl-usb: add IRQ check (bsc#1012628).
- usb: phy: twl6030: add IRQ checks (bsc#1012628).
- usb: gadget: udc: renesas_usb3: Fix soc_device_match() abuse
  (bsc#1012628).
- selftests/bpf: Fix test_core_autosize on big-endian machines
  (bsc#1012628).
- devlink: Clear whole devlink_flash_notify struct (bsc#1012628).
- samples: pktgen: add missing IPv6 option to pktgen scripts
  (bsc#1012628).
- net: stmmac: fix INTR TBU status affecting irq count statistic
  (bsc#1012628).
- PM: cpu: Make notifier chain use a raw_spinlock_t (bsc#1012628).
- usb: host: ohci-tmio: add IRQ check (bsc#1012628).
- usb: phy: tahvo: add IRQ check (bsc#1012628).
- libbpf: Re-build libbpf.so when libbpf.map changes
  (bsc#1012628).
- mac80211: Fix insufficient headroom issue for AMSDU
  (bsc#1012628).
- locking/local_lock: Add missing owner initialization
  (bsc#1012628).
- lockd: Fix invalid lockowner cast after vfs_test_lock
  (bsc#1012628).
- SUNRPC: Fix a NULL pointer deref in trace_svc_stats_latency()
  (bsc#1012628).
- nfsd4: Fix forced-expiry locking (bsc#1012628).
- arm64: dts: marvell: armada-37xx: Extend PCIe MEM space
  (bsc#1012628).
- clk: staging: correct reference to config IOMEM to config
  HAS_IOMEM (bsc#1012628).
- i2c: synquacer: fix deferred probing (bsc#1012628).
- hwmon: (pmbus/bpa-rs600) Don't use rated limits as warn limits
  (bsc#1012628).
- hwmon: remove amd_energy driver in Makefile (bsc#1012628).
- ASoC: fsl_rpmsg: Check -EPROBE_DEFER for getting clocks
  (bsc#1012628).
- firmware: raspberrypi: Fix a leak in 'rpi_firmware_get()'
  (bsc#1012628).
- usb: gadget: mv_u3d: request_irq() after initializing UDC
  (bsc#1012628).
- mm/swap: consider max pages in iomap_swapfile_add_extent
  (bsc#1012628).
- lkdtm: replace SCSI_DISPATCH_CMD with SCSI_QUEUE_RQ
  (bsc#1012628).
- Bluetooth: add timeout sanity check to hci_inquiry
  (bsc#1012628).
- i2c: iop3xx: fix deferred probing (bsc#1012628).
- i2c: s3c2410: fix IRQ check (bsc#1012628).
- i2c: hix5hd2: fix IRQ check (bsc#1012628).
- gfs2: init system threads before freeze lock (bsc#1012628).
- drm/exynos: g2d: fix missing unlock on error in
  g2d_runqueue_worker() (bsc#1012628).
- rsi: fix error code in rsi_load_9116_firmware() (bsc#1012628).
- rsi: fix an error code in rsi_probe() (bsc#1012628).
- octeontx2-af: cn10k: Fix SDP base channel number (bsc#1012628).
- octeontx2-pf: send correct vlan priority mask to
  npc_install_flow_req (bsc#1012628).
- octeontx2-af: Check capability flag while freeing ipolicer
  memory (bsc#1012628).
- octeontx2-pf: Don't install VLAN offload rule if netdev is down
  (bsc#1012628).
- octeontx2-pf: Fix algorithm index in MCAM rules with RSS action
  (bsc#1012628).
- octeontx2-af: cn10k: Use FLIT0 register instead of FLIT1
  (bsc#1012628).
- m68k: coldfire: return success for clk_enable(NULL)
  (bsc#1012628).
- ASoC: Intel: kbl_da7219_max98927: Fix format selection for
  max98373 (bsc#1012628).
- ASoC: Intel: Skylake: Leave data as is when invoking TLV IPCs
  (bsc#1012628).
- ASoC: Intel: Skylake: Fix module resource and format selection
  (bsc#1012628).
- mmc: sdhci: Fix issue with uninitialized dma_slave_config
  (bsc#1012628).
- mmc: dw_mmc: Fix issue with uninitialized dma_slave_config
  (bsc#1012628).
- mmc: moxart: Fix issue with uninitialized dma_slave_config
  (bsc#1012628).
- ASoC: wm_adsp: Put debugfs_remove_recursive back in
  (bsc#1012628).
- bpf: Fix possible out of bound write in narrow load handling
  (bsc#1012628).
- hv_utils: Set the maximum packet size for VSS driver to the
  length of the receive buffer (bsc#1012628).
- CIFS: Fix a potencially linear read overflow (bsc#1012628).
- i2c: mt65xx: fix IRQ check (bsc#1012628).
- i2c: xlp9xx: fix main IRQ check (bsc#1012628).
- octeontx2-pf: cn10k: Fix error return code in
  otx2_set_flowkey_cfg() (bsc#1012628).
- usb: ehci-orion: Handle errors of clk_prepare_enable() in probe
  (bsc#1012628).
- usb: bdc: Fix an error handling path in 'bdc_probe()' when no
  suitable DMA config is available (bsc#1012628).
- usb: bdc: Fix a resource leak in the error handling path of
  'bdc_probe()' (bsc#1012628).
- tty: serial: fsl_lpuart: fix the wrong mapbase value
  (bsc#1012628).
- ASoC: wcd9335: Fix a double irq free in the remove function
  (bsc#1012628).
- ASoC: wcd9335: Fix a memory leak in the error handling path
  of the probe function (bsc#1012628).
- ASoC: wcd9335: Disable irq on slave ports in the remove function
  (bsc#1012628).
- iwlwifi: skip first element in the WTAS ACPI table
  (bsc#1012628).
- net/mlx5: Lag, fix multipath lag activation (bsc#1012628).
- net/mlx5: Remove all auxiliary devices at the unregister event
  (bsc#1012628).
- net/mlx5e: Fix possible use-after-free deleting fdb rule
  (bsc#1012628).
- net/mlx5: E-Switch, Set vhca id valid flag when creating indir
  fwd group (bsc#1012628).
- net/mlx5e: Use correct eswitch for stack devices with lag
  (bsc#1012628).
- misc/pvpanic: fix set driver data (bsc#1012628).
- ice: fix Tx queue iteration for Tx timestamp enablement
  (bsc#1012628).
- ice: add lock around Tx timestamp tracker flush (bsc#1012628).
- ice: restart periodic outputs around time changes (bsc#1012628).
- ice: Only lock to update netdev dev_addr (bsc#1012628).
- net: phy: marvell10g: fix broken PHY interrupts for anyone
  after us in the driver probe list (bsc#1012628).
- ath6kl: wmi: fix an error code in ath6kl_wmi_sync_point()
  (bsc#1012628).
- ALSA: usb-audio: Add lowlatency module option (bsc#1012628).
- atlantic: Fix driver resume flow (bsc#1012628).
- bcma: Fix memory leak for internally-handled cores
  (bsc#1012628).
- brcmfmac: pcie: fix oops on failure to resume and reprobe
  (bsc#1012628).
- ipv6: make exception cache less predictible (bsc#1012628).
- ipv4: make exception cache less predictible (bsc#1012628).
- net: qrtr: make checks in qrtr_endpoint_post() stricter
  (bsc#1012628).
- sch_htb: Fix inconsistency when leaf qdisc creation fails
  (bsc#1012628).
- net: sched: Fix qdisc_rate_table refcount leak when get
  tcf_block failed (bsc#1012628).
- net: qualcomm: fix QCA7000 checksum handling (bsc#1012628).
- octeontx2-af: Fix loop in free and unmap counter (bsc#1012628).
- octeontx2-af: Fix mailbox errors in nix_rss_flowkey_cfg
  (bsc#1012628).
- octeontx2-af: Fix static code analyzer reported issues
  (bsc#1012628).
- octeontx2-af: Set proper errorcode for IPv4 checksum errors
  (bsc#1012628).
- ipv4: fix endianness issue in inet_rtm_getroute_build_skb()
  (bsc#1012628).
- ASoC: rt5682: Remove unused variable in rt5682_i2c_remove()
  (bsc#1012628).
- iwlwifi Add support for ax201 in Samsung Galaxy Book Flex2 Alpha
  (bsc#1012628).
- f2fs: guarantee to write dirty data when enabling checkpoint
  back (bsc#1012628).
- time: Handle negative seconds correctly in timespec64_to_ns()
  (bsc#1012628).
- auxdisplay: hd44780: Fix oops on module unloading (bsc#1012628).
- io_uring: limit fixed table size by RLIMIT_NOFILE (bsc#1012628).
- io_uring: IORING_OP_WRITE needs hash_reg_file set (bsc#1012628).
- io_uring: io_uring_complete() trace should take an integer
  (bsc#1012628).
- io_uring: fail links of cancelled timeouts (bsc#1012628).
- bio: fix page leak bio_add_hw_page failure (bsc#1012628).
- raid1: ensure write behind bio has less than BIO_MAX_VECS
  sectors (bsc#1012628).
- cifs: Do not leak EDEADLK to dgetents64 for
  STATUS_USER_SESSION_DELETED (bsc#1012628).
- smb3: fix posix extensions mount option (bsc#1012628).
- tty: Fix data race between tiocsti() and flush_to_ldisc()
  (bsc#1012628).
- perf/x86/intel/uncore: Fix IIO cleanup mapping procedure for
  SNR/ICX (bsc#1012628).
- Revert "KVM: x86: mmu: Add guest physical address check in
  translate_gpa()" (bsc#1012628).
- KVM: s390: index kvm->arch.idle_mask by vcpu_idx (bsc#1012628).
- KVM: x86: Update vCPU's hv_clock before back to guest when
  tsc_offset is adjusted (bsc#1012628).
- KVM: x86: clamp host mapping level to max_level in
  kvm_mmu_max_mapping_level (bsc#1012628).
- KVM: x86/mmu: Avoid collision with !PRESENT SPTEs in TDP MMU
  lpage stats (bsc#1012628).
- KVM: VMX: avoid running vmx_handle_exit_irqoff in case of
  emulation (bsc#1012628).
- KVM: nVMX: Unconditionally clear nested.pi_pending on nested
  VM-Enter (bsc#1012628).
- KVM: arm64: Unregister HYP sections from kmemleak in protected
  mode (bsc#1012628).
- KVM: arm64: vgic: Resample HW pending state on deactivation
  (bsc#1012628).
- ARM: dts: at91: add pinctrl-{names, 0} for all gpios
  (bsc#1012628).
- io-wq: check max_worker limits if a worker transitions bound
  state (bsc#1012628).
- md/raid10: Remove unnecessary rcu_dereference in
  raid10_handle_discard (bsc#1012628).
- char: tpm: Kconfig: remove bad i2c cr50 select (bsc#1012628).
- fuse: truncate pagecache on atomic_o_trunc (bsc#1012628).
- fuse: flush extending writes (bsc#1012628).
- fuse: wait for writepages in syncfs (bsc#1012628).
- IMA: remove -Wmissing-prototypes warning (bsc#1012628).
- IMA: remove the dependency on CRYPTO_MD5 (bsc#1012628).
- fbmem: don't allow too huge resolutions (bsc#1012628).
- ACPI: PRM: Find PRMT table before parsing it (bsc#1012628).
- RDMA/mlx5: Fix number of allocated XLT entries (bsc#1012628).
- bootconfig: Fix missing return check of xbc_node_compose_key
  function (bsc#1012628).
- backlight: pwm_bl: Improve bootloader/kernel device handover
  (bsc#1012628).
- parisc: Fix unaligned-access crash in bootloader (bsc#1012628).
- clk: kirkwood: Fix a clocking boot regression (bsc#1012628).
- devlink: Break parameter notification sequence to be
  before/after unload/load driver (bsc#1012628).
- Refresh
  patches.suse/Bluetooth-schedule-SCO-timeouts-with-delayed_work.patch.
- Refresh patches.suse/Bluetooth-switch-to-lock_sock-in-SCO.patch.
- Update config files.
- commit 8706151
* Wed Sep 15 2021 tiwai@suse.de
- drm/i915/dp: Use max params for panels < eDP 1.4 (bsc#1190506).
- commit ca483c1
* Mon Sep 13 2021 rgoldwyn@suse.com
- Delete patches.suse/apparmor-compatibility-with-v2.x-net.patch (bsc#118997)
  Apparmor upgraded to v3.x
- commit a1d1731
* Mon Sep 13 2021 tiwai@suse.de
- Bluetooth: Move shutdown callback before flushing tx and rx
  queue (bsc#1190424).
- commit 40ccc64
* Mon Sep 13 2021 mkubecek@suse.cz
- Update to 5.15-rc1
- eliminated 36 patches (27 stable, 9 mainline)
  - patches.kernel.org/*
  - patches.suse/Bluetooth-avoid-circular-locks-in-sco_sock_connect.patch
  - patches.suse/Bluetooth-btusb-Add-support-for-Foxconn-Mediatek-Chi.patch
  - patches.suse/Bluetooth-btusb-Add-support-for-IMC-Networks-Mediate.patch
  - patches.suse/Bluetooth-schedule-SCO-timeouts-with-delayed_work.patch
  - patches.suse/Bluetooth-switch-to-lock_sock-in-SCO.patch
  - patches.suse/HID-usbhid-Simplify-code-in-hid_submit_ctrl.patch
  - patches.suse/crypto-ecc-handle-unaligned-input-buffer-in-ecc_swap.patch
  - patches.suse/memcg-enable-accounting-of-ipc-resources.patch
  - patches.suse/watchdog-Fix-NULL-pointer-dereference-when-releasing.patch
- refresh
  - patches.suse/add-suse-supported-flag.patch
  - patches.suse/btrfs-use-the-new-VFS-super_block_dev.patch
  - patches.suse/suse-hv-guest-os-id.patch
- disable ARM architectures (need config update)
- new config options
  - General setup
  - CONFIG_WERROR=n
  - CONFIG_PRINTK_INDEX=y
  - Processor type and features
  - CONFIG_PERF_EVENTS_AMD_UNCORE=m
  - Firmware Drivers
  - CONFIG_SYSFB_SIMPLEFB=y
  - Memory Management options
  - CONFIG_DAMON=n
  - Networking support
  - CONFIG_IPV6_IOAM6_LWTUNNEL=n
  - CONFIG_MCTP=m
  - File systems
  - CONFIG_F2FS_IOSTAT=y
  - CONFIG_NTFS3_FS=m
  - CONFIG_NTFS3_64BIT_CLUSTER=n
  - CONFIG_NTFS3_LZX_XPRESS=y
  - CONFIG_NTFS3_FS_POSIX_ACL=y
  - CONFIG_SMB_SERVER=m
  - CONFIG_SMB_SERVER_SMBDIRECT=n
  - CONFIG_SMB_SERVER_CHECK_CAP_NET_ADMIN=y
  - CONFIG_SMB_SERVER_KERBEROS5=y
  - Security options
  - CONFIG_ZERO_CALL_USED_REGS=y
  - Cryptographic API
  - CONFIG_CRYPTO_SM4_AESNI_AVX_X86_64=m
  - CONFIG_CRYPTO_SM4_AESNI_AVX2_X86_64=m
  - CONFIG_MODULE_SIG_KEY_TYPE_RSA=y
  - CONFIG_MODULE_SIG_KEY_TYPE_ECDSA=n
  - Kernel hacking
  - CONFIG_FAIL_SUNRPC=n
  - SCSI device support
  - CONFIG_SCSI_UFS_HPB=y
  - CONFIG_SCSI_UFS_FAULT_INJECTION=n
  - Network device support
  - CONFIG_NET_VENDOR_LITEX=y
  - CONFIG_MAXLINEAR_GPHY=m
  - CONFIG_MHI_WWAN_MBIM=m
  - Power management
  - CONFIG_CHARGER_CROS_PCHG=m
  - CONFIG_SENSORS_AQUACOMPUTER_D5NEXT=m
  - CONFIG_SENSORS_SBRMI=m
  - CONFIG_REGULATOR_RTQ2134=m
  - CONFIG_REGULATOR_RTQ6752=m
  - Graphics support
  - CONFIG_DRM_VMWGFX_MKSSTATS=n
  - CONFIG_DRM_PANEL_WIDECHIPS_WS2401=n
  - Sound card support
  - CONFIG_SND_HDA_CODEC_CS8409=m
  - CONFIG_SND_SOC_AMD_ACP5x=m
  - CONFIG_SND_SOC_ICS43432=n
  - CONFIG_SND_SOC_SDW_MOCKUP=m
  - DMA Engine support
  - CONFIG_INTEL_IDXD_COMPAT=y
  - CONFIG_AMD_PTDMA=m
  - X86 Platform Specific Device Drivers
  - CONFIG_MERAKI_MX100=m
  - CONFIG_INTEL_SAR_INT1092=m
  - IOMMU Hardware Support
  - CONFIG_IOMMU_DEFAULT_DMA_STRICT=n
  - CONFIG_IOMMU_DEFAULT_DMA_LAZY=n
  - Industrial I/O support
  - CONFIG_SENSIRION_SGP40=n
  - CONFIG_AD5110=n
  - Misc devices
  - CONFIG_I2C_VIRTIO=m
  - CONFIG_GPIO_VIRTIO=m
  - CONFIG_DMABUF_SYSFS_STATS=n
  - CONFIG_VDPA_USER=m
  - CONFIG_NVMEM_NINTENDO_OTP=m
  - OF dependent (i386, ppc64/ppc64le, riscv64)
  - HI6421V600_IRQ=m
  - LITEX_LITEETH=m
  - MFD_RSMU_I2C=n
  - MFD_RSMU_SPI=n
  - VIDEO_IMX335=m
  - VIDEO_IMX412=m
  - VIDEO_OV9282=m
  - DRM_PANEL_INNOLUX_EJ030NA=n
  - DRM_PANEL_SAMSUNG_ATNA33XC20=n
  - DRM_PANEL_SAMSUNG_DB7430=n
  - COMMON_CLK_XLNX_CLKWZRD=m
  - DMA_RESTRICTED_POOL=n
  - i386
  - CS89x0_ISA=n
  - ppc64
  - DEBUG_WX=n
  - PTDUMP_DEBUGFS=n
  - s390x
  - KCSAN=n
  - KFENCE=y (=n in zfcpdump)
  - KFENCE_STATIC_KEYS=y
  - KFENCE_SAMPLE_INTERVAL=0
  - KFENCE_NUM_OBJECTS=255
  - KFENCE_STRESS_TEST_FAULTS=0
  - riscv64
  - POWER_RESET_TPS65086=y
  - DRM_PANEL_ILITEK_ILI9341=n
- commit 8787773
* Mon Sep 13 2021 martin.wilck@suse.com
- fixup "rpm: support gz and zst compression methods" once more
  (bsc#1190428, bsc#1190358)
  Fixes: 3b8c4d9bcc24 ("rpm: support gz and zst compression methods")
  Fixes: 23510fce36ec ("fixup "rpm: support gz and zst compression methods"")
- commit 165378a
* Mon Sep 13 2021 jslaby@suse.cz
- Linux 5.14.3 (bsc#1012628).
- cxl/acpi: Do not add DSDT disabled ACPI0016 host bridge ports
  (bsc#1012628).
- cxl/pci: Fix lockdown level (bsc#1012628).
- cxl/pci: Fix debug message in cxl_probe_regs() (bsc#1012628).
- PCI: Call Max Payload Size-related fixup quirks early
  (bsc#1012628).
- x86/reboot: Limit Dell Optiplex 990 quirk to early BIOS versions
  (bsc#1012628).
- staging: mt7621-pci: fix hang when nothing is connected to
  pcie ports (bsc#1012628).
- xhci: Fix failure to give back some cached cancelled URBs
  (bsc#1012628).
- xhci: fix unsafe memory usage in xhci tracing (bsc#1012628).
- xhci: fix even more unsafe memory usage in xhci tracing
  (bsc#1012628).
- usb: mtu3: fix the wrong HS mult value (bsc#1012628).
- usb: mtu3: use @mult for HS isoc or intr (bsc#1012628).
- usb: mtu3: restore HS function when set SS/SSP (bsc#1012628).
- usb: gadget: tegra-xudc: fix the wrong mult value for HS isoc
  or intr (bsc#1012628).
- usb: cdnsp: fix the wrong mult value for HS isoc or intr
  (bsc#1012628).
- usb: xhci-mtk: fix issue of out-of-bounds array access
  (bsc#1012628).
- usb: host: xhci-rcar: Don't reload firmware after the completion
  (bsc#1012628).
- Bluetooth: btusb: Make the CSR clone chip force-suspend
  workaround more generic (bsc#1012628).
- Bluetooth: Add additional Bluetooth part for Realtek 8852AE
  (bsc#1012628).
- ALSA: usb-audio: Add registration quirk for JBL Quantum 800
  (bsc#1012628).
- Revert "r8169: avoid link-up interrupt issue on RTL8106e if
  user enables ASPM" (bsc#1012628).
- igmp: Add ip_mc_list lock in ip_check_mc_rcu (bsc#1012628).
- can: c_can: fix null-ptr-deref on ioctl() (bsc#1012628).
- firmware: dmi: Move product_sku info to the end of the modalias
  (bsc#1012628).
- commit 87c3051
* Sun Sep 12 2021 martin.wilck@suse.com
- fixup "rpm: support gz and zst compression methods" once more
  Fixes: 3b8c4d9bcc24 ("rpm: support gz and zst compression methods")
  Fixes: 23510fce36ec ("fixup "rpm: support gz and zst compression methods"")
- commit 34e68f4
* Sun Sep 12 2021 jeffm@suse.com
- Avoid double printing SUSE specific flags in mod->taint (bsc#1190413).
- commit 3b944fc
* Sun Sep 12 2021 martin.wilck@suse.com
- fixup "rpm: support gz and zst compression methods"
  Fixes: 3b8c4d9bcc24 ("rpm: support gz and zst compression methods")
- commit 23510fc
* Fri Sep 10 2021 msuchanek@suse.de
- kernel-cert-subpackage: Fix certificate location in scriptlets
  (bsc#1189841).
  Fixes: d9a1357edd73 ("rpm: Define $certs as rpm macro (bsc#1189841).")
- commit 8684de8
* Fri Sep 10 2021 msuchanek@suse.de
- kernel-binary.spec.in Stop templating the scriptlets for subpackages
  (bsc#1190358).
  The script part for base package case is completely separate from the
  part for subpackages. Remove the part for subpackages from the base
  package script and use the KMP scripts for subpackages instead.
- commit 5d1f677
* Fri Sep 10 2021 msuchanek@suse.de
- kernel-binary.spec: Do not fail silently when KMP is empty
  (bsc#1190358).
  Copy the code from kernel-module-subpackage that deals with empty KMPs.
- commit d7d2e6e
* Fri Sep 10 2021 ohering@suse.de
- Document suse-hv-guest-os-id.patch (bsc#814005, bsc#1189965).
- commit 6205661
* Thu Sep  9 2021 rgoldwyn@suse.com
- Delete 0001-apparmor-fix-unnecessary-creation-of-net-compat.patch
  (bsc#1189978)
  Compat patch no longer required since userspace is upgraded to v3.x
- commit c28bbe5
* Wed Sep  8 2021 jeffm@suse.com
- supported-flag: consolidate separate patches into one
  The history of the five supported flag patches can be found in the commit
  log.  This commit unifies them and reverts the removal of get_next_line
  from mainline to allow supported() to repeatedly scan the file in memory
  without modifying it.  I looked into using tsearch() to handle the
  lookups and it turns out that it's no faster than just scanning the file
  repeatedly in memory.
- commit d3dcd16
* Wed Sep  8 2021 jeffm@suse.com
- Delete patches.suse/setuid-dumpable-wrongdir (bsc#1189957).
- commit 762368d
* Wed Sep  8 2021 tiwai@suse.de
- Bluetooth: schedule SCO timeouts with delayed_work
  (CVE-2021-3640 bsc#1188172).
- Refresh patches.suse/Bluetooth-switch-to-lock_sock-in-SCO.patch.
- commit 2605fb9
* Wed Sep  8 2021 jslaby@suse.cz
- rpm/kernel-source.spec.in: do some more for vanilla_only
  Make sure:
  * sources are NOT executable
  * env is not used as interpreter
  * timestamps are correct
  We do all this for normal kernel builds, but not for vanilla_only
  kernels (linux-next and vanilla).
- commit b41e4fd
* Wed Sep  8 2021 jslaby@suse.cz
- Linux 5.14.2 (bsc#1012628).
- ext4: fix race writing to an inline_data file while its xattrs
  are changing (bsc#1012628).
- ext4: fix e2fsprogs checksum failure for mounted filesystem
  (bsc#1012628).
- xtensa: fix kconfig unmet dependency warning for
  HAVE_FUTEX_CMPXCHG (bsc#1012628).
- USB: serial: pl2303: fix GL type detection (bsc#1012628).
- USB: serial: cp210x: fix control-characters error handling
  (bsc#1012628).
- USB: serial: cp210x: fix flow-control error handling
  (bsc#1012628).
- ALSA: hda/realtek: Quirk for HP Spectre x360 14 amp setup
  (bsc#1012628).
- ALSA: usb-audio: Fix regression on Sony WALKMAN NW-A45 DAC
  (bsc#1012628).
- ALSA: hda/realtek: Workaround for conflicting SSID on ASUS
  ROG Strix G17 (bsc#1012628).
- ALSA: pcm: fix divide error in snd_pcm_lib_ioctl (bsc#1012628).
- ALSA: usb-audio: Work around for XRUN with low latency playback
  (bsc#1012628).
- media: stkwebcam: fix memory leak in stk_camera_probe
  (bsc#1012628).
- commit b155faa
* Tue Sep  7 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and move to appropriate section:
  - patches.suse/crypto-ecc-handle-unaligned-input-buffer-in-ecc_swap.patch
- commit 1eedbb8
* Tue Sep  7 2021 mbrugger@suse.com
- crypto: ecc - handle unaligned input buffer in ecc_swap_digits
  (bsc#1188327).
- commit f7925a4
* Tue Sep  7 2021 hare@suse.de
- Refresh patches.suse/scsi-retry-alua-transition-in-progress.
- Delete patches.suse/megaraid-mbox-fix-SG_IO.
- commit d1e442c
* Mon Sep  6 2021 mkoutny@suse.com
- memcg: enable accounting of ipc resources (bsc#1190115
  CVE-2021-3759).
- commit 9193235
* Mon Sep  6 2021 msuchanek@suse.de
- rpm: Fold kernel-devel and kernel-source scriptlets into spec files
  (bsc#1189841).
  These are unchanged since 2011 when they were introduced. No need to
  track them separately.
- commit 692d38b
* Mon Sep  6 2021 msuchanek@suse.de
- rpm: Abolish image suffix (bsc#1189841).
  This is used only with vanilla kernel which is not supported in any way.
  The only effect is has is that the image and initrd symlinks are created
  with this suffix.
  These symlinks are not used except on s390 where the unsuffixed symlinks
  are used by zipl.
  There is no reason why a vanilla kernel could not be used with zipl as
  well as it's quite unexpected to not be able to boot when only a vanilla
  kernel is installed.
  Finally we now have a backup zipl kernel so if the vanilla kernel is
  indeed unsuitable the backup kernel can be used.
- commit e2f37db
* Mon Sep  6 2021 msuchanek@suse.de
- kernel-binary.spec: Define $image as rpm macro (bsc#1189841).
- commit e602b0f
* Mon Sep  6 2021 msuchanek@suse.de
- rpm: Define $certs as rpm macro (bsc#1189841).
  Also pass around only the shortened hash rather than full filename.
  As has been discussed in bsc#1124431 comment 51
  https://bugzilla.suse.com/show_bug.cgi?id=1124431#c51 the placement of
  the certificates is an API which cannot be changed unless we can ensure
  that no two kernels that use different certificate location can be built
  with the same certificate.
- commit d9a1357
* Sat Sep  4 2021 jslaby@suse.cz
- watchdog: Fix NULL pointer dereference when releasing cdev
  (bsc#1190093).
- Update config files.
  We can enable the option after this fix again.
- commit 65109d0
* Sat Sep  4 2021 jslaby@suse.cz
- Linux 5.14.1 (bsc#1012628).
- Bluetooth: btusb: check conditions before enabling USB ALT 3
  for WBS (bsc#1012628).
- net: dsa: mt7530: fix VLAN traffic leaks again (bsc#1012628).
- btrfs: fix NULL pointer dereference when deleting device by
  invalid id (bsc#1012628).
- Revert "floppy: reintroduce O_NDELAY fix" (bsc#1012628).
- fscrypt: add fscrypt_symlink_getattr() for computing st_size
  (bsc#1012628).
- ext4: report correct st_size for encrypted symlinks
  (bsc#1012628).
- f2fs: report correct st_size for encrypted symlinks
  (bsc#1012628).
- ubifs: report correct st_size for encrypted symlinks
  (bsc#1012628).
- net: don't unconditionally copy_from_user a struct ifreq for
  socket ioctls (bsc#1012628).
- audit: move put_tree() to avoid trim_trees refcount underflow
  and UAF (bsc#1012628).
- commit 1059c60
* Fri Sep  3 2021 mkubecek@suse.cz
- update patches metadata
- update upstream references:
  - patches.suse/Bluetooth-avoid-circular-locks-in-sco_sock_connect.patch
  - patches.suse/Bluetooth-btusb-Add-support-for-Foxconn-Mediatek-Chi.patch
  - patches.suse/Bluetooth-btusb-Add-support-for-IMC-Networks-Mediate.patch
  - patches.suse/Bluetooth-switch-to-lock_sock-in-SCO.patch
- commit c2e3f15
* Fri Sep  3 2021 mkubecek@suse.cz
- HID: usbhid: Simplify code in hid_submit_ctrl()
  (<cover.1630658591.git.mkubecek@suse.cz>).
- HID: usbhid: Fix warning caused by 0-length input reports
  (<cover.1630658591.git.mkubecek@suse.cz>).
- HID: usbhid: Fix flood of "control queue full" messages
  (<cover.1630658591.git.mkubecek@suse.cz>).
- commit 4552165
* Fri Sep  3 2021 mkubecek@suse.cz
- Delete patches.suse/hid-fix-length-inconsistency.patch.
  To be replaced by a cherry pick of corresponding upstream commits.
- commit ba7e2a2
* Thu Sep  2 2021 mkubecek@suse.cz
- Delete patches.suse/Revert-netfilter-conntrack-remove-helper-hook-again.patch (bsc#1189964)
  The regression addressed by this revert was fixed properly by mainline
  commit ee04805ff54a ("netfilter: conntrack: make conntrack userspace
  helpers work again") in 5.7.
- commit 775ed38
* Thu Sep  2 2021 mkubecek@suse.cz
- series.conf: cleanup
  Move queued patches to "almost mainline" section.
  No effect on expanded tree.
- commit e91bb9d
* Thu Sep  2 2021 jslaby@suse.cz
- vt_kdsetmode: extend console locking (bsc#1190025
  CVE-2021-3753).
- commit 18d6ea3
* Thu Sep  2 2021 jslaby@suse.cz
- Update config files. Disable CONFIG_WATCHDOG_HRTIMER_PRETIMEOUT
  (bsc#1190093)
- commit 55bd270
* Wed Sep  1 2021 tiwai@suse.de
- Bluetooth: sco: Fix lock_sock() blockage by memcpy_from_msg()
  (CVE-2021-3640 bsc#1188172).
- commit b9d15a3
* Tue Aug 31 2021 lduncan@suse.com
- Delete
  patches.suse/uapi-add-a-compatibility-layer-between-linux-uio-h-and-glibc (bsc#1189959).
  No longer needed, since it's upstream now.
- commit b1aeba4
* Tue Aug 31 2021 msuchanek@suse.de
- rpm: Abolish scritplet templating (bsc#1189841).
  Outsource kernel-binary and KMP scriptlets to suse-module-tools.
  This allows fixing bugs in the scriptlets as well as defining initrd
  regeneration policy independent of the kernel packages.
- commit e98096d
* Tue Aug 31 2021 mbrugger@suse.com
- arm64: Update config files. (bsc#1189922)
  Enable ISP1760_DUAL_ROLE
- commit c265161
* Tue Aug 31 2021 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Use kmod-zstd provide.
  This makes it possible to use kmod with ZSTD support on non-Tumbleweed.
- commit 357f09a
* Mon Aug 30 2021 ludwig.nussel@suse.de
- rpm/kernel-binary.spec.in: avoid conflicting suse-release
  suse-release has arbitrary values in staging, we can't use it for
  dependencies. The filesystem one has to be enough (boo#1184804).
- commit 56f2cba
* Mon Aug 30 2021 mkubecek@suse.cz
- Update to 5.14 final
- refresh configs
- commit d419f63
* Mon Aug 30 2021 mkubecek@suse.cz
- config: update and enable armv6hl
  New config option values copied from arvm7hl.
- commit 7224850
* Mon Aug 30 2021 mkubecek@suse.cz
- config: update and enable armv7hl
  New config option values copied from arm64 except:
  - PCI_IXP4XX=n (does not allow module build)
  - MTD_NAND_PL35X=m
  - IPMI_KCS_BMC_CDEV_IPMI=m
  - IPMI_KCS_BMC_SERIO=m
  - MSC313E_WATCHDOG=m
  - REGULATOR_MT6359=m
  - REGULATOR_RT5033=m
  - ARM_GT_INITIAL_PRESCALER_VAL=2 (default)
  - INTEL_QEP=m
- commit 2df785b
* Fri Aug 27 2021 ludwig.nussel@suse.de
- rpm: fix kmp install path
- commit 2d3c7bb
* Thu Aug 26 2021 jslaby@suse.cz
- net: usb: asix: ax88772: Fix less than zero comparison of a u16
  (git-fixes).
- commit 8e5c63f
* Thu Aug 26 2021 jslaby@suse.cz
- Linux 5.13.13 (bsc#1012628).
- mtd: cfi_cmdset_0002: fix crash when erasing/writing AMD cards
  (bsc#1012628).
- io_uring: Use WRITE_ONCE() when writing to sq_flags
  (bsc#1012628).
- USB: core: Avoid WARNings for 0-length descriptor requests
  (bsc#1012628).
- USB: core: Fix incorrect pipe calculation in do_proc_control()
  (bsc#1012628).
- dmaengine: xilinx_dma: Fix read-after-free bug when terminating
  transfers (bsc#1012628).
- dmaengine: usb-dmac: Fix PM reference leak in usb_dmac_probe()
  (bsc#1012628).
- spi: spi-mux: Add module info needed for autoloading
  (bsc#1012628).
- net: xfrm: Fix end of loop tests for list_for_each_entry
  (bsc#1012628).
- ARM: dts: am43x-epos-evm: Reduce i2c0 bus speed for tps65218
  (bsc#1012628).
- dmaengine: of-dma: router_xlate to return -EPROBE_DEFER if
  controller is not yet available (bsc#1012628).
- scsi: pm80xx: Fix TMF task completion race condition
  (bsc#1012628).
- scsi: megaraid_mm: Fix end of loop tests for
  list_for_each_entry() (bsc#1012628).
- scsi: scsi_dh_rdac: Avoid crash during rdac_bus_attach()
  (bsc#1012628).
- scsi: core: Avoid printing an error if target_alloc() returns
  - ENXIO (bsc#1012628).
- scsi: core: Fix capacity set to zero after offlinining device
  (bsc#1012628).
- drm/amdgpu: fix the doorbell missing when in CGPG issue for
  renoir (bsc#1012628).
- qede: fix crash in rmmod qede while automatic debug collection
  (bsc#1012628).
- ARM: dts: nomadik: Fix up interrupt controller node names
  (bsc#1012628).
- net: usb: pegasus: Check the return value of get_geristers()
  and friends; (bsc#1012628).
- perf/x86: Fix out of bound MSR access (bsc#1012628).
- spi: cadence-quadspi: Fix check condition for DTR ops
  (bsc#1012628).
- drm/amd/display: Fix Dynamic bpp issue with 8K30 with Navi 1X
  (bsc#1012628).
- drm/amd/display: workaround for hard hang on HPD on native DP
  (bsc#1012628).
- kyber: make trace_block_rq call consistent with documentation
  (bsc#1012628).
- mtd: rawnand: Add a check in of_get_nand_secure_regions()
  (bsc#1012628).
- arm64: dts: qcom: c630: fix correct powerdown pin for WSA881x
  (bsc#1012628).
- arm64: dts: qcom: msm8992-bullhead: Remove PSCI (bsc#1012628).
- arm64: dts: qcom: msm8992-bullhead: Fix cont_splash_mem mapping
  (bsc#1012628).
- iommu: Check if group is NULL before remove device
  (bsc#1012628).
- cpufreq: arm_scmi: Fix error path when allocation failed
  (bsc#1012628).
- arm64: dts: qcom: msm8994-angler: Disable cont_splash_mem
  (bsc#1012628).
- arm64: dts: qcom: sdm845-oneplus: fix reserved-mem
  (bsc#1012628).
- mt76: fix enum type mismatch (bsc#1012628).
- mtd: rawnand: Fix probe failure due to
  of_get_nand_secure_regions() (bsc#1012628).
- soc: fsl: qe: convert QE interrupt controller to platform_device
  (bsc#1012628).
- cpufreq: armada-37xx: forbid cpufreq for 1.2 GHz variant
  (bsc#1012628).
- dccp: add do-while-0 stubs for dccp_pr_debug macros
  (bsc#1012628).
- virtio: Protect vqs list access (bsc#1012628).
- vhost-vdpa: Fix integer overflow in
  vhost_vdpa_process_iotlb_update() (bsc#1012628).
- bus: ti-sysc: Fix error handling for sysc_check_active_timer()
  (bsc#1012628).
- vhost: Fix the calculation in vhost_overflow() (bsc#1012628).
- vdpa_sim: Fix return value check for vdpa_alloc_device()
  (bsc#1012628).
- vp_vdpa: Fix return value check for vdpa_alloc_device()
  (bsc#1012628).
- vDPA/ifcvf: Fix return value check for vdpa_alloc_device()
  (bsc#1012628).
- vdpa/mlx5: Avoid destroying MR on empty iotlb (bsc#1012628).
- vdpa/mlx5: Fix queue type selection logic (bsc#1012628).
- drm/mediatek: Add AAL output size configuration (bsc#1012628).
- drm/mediatek: Add component_del in OVL and COLOR remove function
  (bsc#1012628).
- bpf: Clear zext_dst of dead insns (bsc#1012628).
- bnxt: don't lock the tx queue from napi poll (bsc#1012628).
- bnxt: disable napi before canceling DIM (bsc#1012628).
- bnxt: make sure xmit_more + errors does not miss doorbells
  (bsc#1012628).
- bnxt: count Tx drops (bsc#1012628).
- soc: fsl: qe: fix static checker warning (bsc#1012628).
- net: 6pack: fix slab-out-of-bounds in decode_data (bsc#1012628).
- ptp_pch: Restore dependency on PCI (bsc#1012628).
- bnxt_en: Disable aRFS if running on 212 firmware (bsc#1012628).
- bnxt_en: Add missing DMA memory barriers (bsc#1012628).
- vrf: Reset skb conntrack connection on VRF rcv (bsc#1012628).
- virtio-net: use NETIF_F_GRO_HW instead of NETIF_F_LRO
  (bsc#1012628).
- mac80211: fix locking in ieee80211_restart_work() (bsc#1012628).
- net: qlcnic: add missed unlock in qlcnic_83xx_flash_read32
  (bsc#1012628).
- ixgbe, xsk: clean up the resources in ixgbe_xsk_pool_enable
  error path (bsc#1012628).
- sch_cake: fix srchost/dsthost hashing mode (bsc#1012628).
- net: mdio-mux: Don't ignore memory allocation errors
  (bsc#1012628).
- net: mdio-mux: Handle -EPROBE_DEFER correctly (bsc#1012628).
- ovs: clear skb->tstamp in forwarding path (bsc#1012628).
- net: usb: asix: refactor asix_read_phy_addr() and handle errors
  on return (bsc#1012628).
- iommu/vt-d: Fix incomplete cache flush in
  intel_pasid_tear_down_entry() (bsc#1012628).
- drm/i915: Skip display interruption setup when display is not
  available (bsc#1012628).
- drm/i915: Tweaked Wa_14010685332 for all PCHs (bsc#1012628).
- drm/amd/display: Use DCN30 watermark calc for DCN301
  (bsc#1012628).
- net: mscc: ocelot: allow forwarding from bridge ports to the
  tag_8021q CPU port (bsc#1012628).
- mptcp: fix memory leak on address flush (bsc#1012628).
- mptcp: full fully established support after ADD_ADDR
  (bsc#1012628).
- r8152: fix writing USB_BP2_EN (bsc#1012628).
- r8152: fix the maximum number of PLA bp for RTL8153C
  (bsc#1012628).
- PCI/sysfs: Use correct variable for the legacy_mem sysfs object
  (bsc#1012628).
- i40e: Fix ATR queue selection (bsc#1012628).
- iavf: Fix ping is lost after untrusted VF had tried to change
  MAC (bsc#1012628).
- Revert "flow_offload: action should not be NULL when it is
  referenced" (bsc#1012628).
- net: dpaa2-switch: disable the control interface on error path
  (bsc#1012628).
- iommu/dma: Fix leak in non-contiguous API (bsc#1012628).
- mmc: dw_mmc: Fix hang on data CRC error (bsc#1012628).
- mmc: mmci: stm32: Check when the voltage switch procedure
  should be done (bsc#1012628).
- mmc: sdhci-msm: Update the software timeout value for sdhc
  (bsc#1012628).
- clk: imx6q: fix uart earlycon unwork (bsc#1012628).
- clk: qcom: gdsc: Ensure regulator init state matches GDSC state
  (bsc#1012628).
- arm64: clean vdso & vdso32 files (bsc#1012628).
- cfi: Use rcu_read_{un}lock_sched_notrace (bsc#1012628).
- ALSA: hda - fix the 'Capture Switch' value change notifications
  (bsc#1012628).
- tracing: define needed config DYNAMIC_FTRACE_WITH_ARGS
  (bsc#1012628).
- tracing / histogram: Fix NULL pointer dereference on strcmp()
  on NULL event name (bsc#1012628).
- slimbus: messaging: start transaction ids from 1 instead of zero
  (bsc#1012628).
- slimbus: messaging: check for valid transaction id
  (bsc#1012628).
- slimbus: ngd: set correct device for pm (bsc#1012628).
- slimbus: ngd: reset dma setup during runtime pm (bsc#1012628).
- ipack: tpci200: fix many double free issues in tpci200_pci_probe
  (bsc#1012628).
- ipack: tpci200: fix memory leak in the tpci200_register
  (bsc#1012628).
- io_uring: fix code style problems (bsc#1012628).
- io_uring: only assign io_uring_enter() SQPOLL error in actual
  error case (bsc#1012628).
- ALSA: hda/realtek: Enable 4-speaker output for Dell XPS 15
  9510 laptop (bsc#1012628).
- opp: Drop empty-table checks from _put functions (bsc#1012628).
- btrfs: prevent rename2 from exchanging a subvol with a directory
  from different parents (bsc#1012628).
- tracing: Apply trace filters on all output channels
  (bsc#1012628).
- ALSA: hda/via: Apply runtime PM workaround for ASUS B23E
  (bsc#1012628).
- s390/pci: fix use after free of zpci_dev (bsc#1012628).
- usb: typec: tcpm: Fix VDMs sometimes not being forwarded to
  alt-mode drivers (bsc#1012628).
- powerpc/32s: Move setup_{kuep/kuap}() into {kuep/kuap}.c
  (bsc#1012628).
- powerpc/32s: Refactor update of user segment registers
  (bsc#1012628).
- powerpc/32s: Fix random crashes by adding isync() after
  locking/unlocking KUEP (bsc#1012628).
- PCI: Increase D3 delay for AMD Renoir/Cezanne XHCI
  (bsc#1012628).
- ALSA: hda/realtek: Limit mic boost on HP ProBook 445 G8
  (bsc#1012628).
- ASoC: intel: atom: Fix breakage for PCM buffer address setup
  (bsc#1012628).
- riscv: Fix a number of free'd resources in init_resources()
  (bsc#1012628).
- mm: memcontrol: fix occasional OOMs due to proportional
  memory.low reclaim (bsc#1012628).
- mm,hwpoison: make get_hwpoison_page() call get_any_page()
  (bsc#1012628).
- mm/hwpoison: retry with shake_page() for unhandlable pages
  (bsc#1012628).
- kfence: fix is_kfence_address() for addresses below
  KFENCE_POOL_SIZE (bsc#1012628).
- hugetlb: don't pass page cache pages to restore_reserve_on_error
  (bsc#1012628).
- io_uring: fix xa_alloc_cycle() error return value check
  (bsc#1012628).
- fs: warn about impending deprecation of mandatory locks
  (bsc#1012628).
- Update config files.
- commit b44f35f
* Thu Aug 26 2021 ludwig.nussel@suse.de
- post.sh: detect /usr mountpoint too
- commit c7b3d74
* Mon Aug 23 2021 jeffm@suse.com
- config: re-modularize CRYPTO_{CTS,ECB,XTS} on arm* (bsc#1189034).
  Now that FS_ENCRYPTION_ALGS is modular, the crypto modules it utilizes
  can be modular as well.  CRYPTO_AES and CRYPTO_CBC are used by
  ENCRYPTED_KEYS and must remain built-in.  CRYPTO_SHA512 and CRYPTO_HMAC
  are used by module signature validation and must also remain built-in.
- commit dbb9dbc
* Mon Aug 23 2021 jeffm@suse.com
- config: re-modularize CRYPTO_{GCM,GHASH,GF128MUL} on arm* (bsc#1189033).
  These modules were selected as built-in due to Kconfig changes between
  4.14-rc3 and 5.8-rc1 selecting them if BIG_KEYS was enabled.  They can
  be built as modules again now.
- commit bb04225
* Mon Aug 23 2021 tiwai@suse.de
- usb: renesas-xhci: Prefer firmware loading on unknown ROM state
  (bsc#1189207).
- commit 0567e80
* Mon Aug 23 2021 martin.wilck@suse.com
- kernel-binary.spec.in: make sure zstd is supported by kmod if used
- commit f36412b
* Mon Aug 23 2021 martin.wilck@suse.com
- kernel-binary.spec.in: add zstd to BuildRequires if used
- commit aa61dba
* Mon Aug 23 2021 jslaby@suse.cz
- Update config files. (vanillas)
  Oldconfig on vanillas.
- commit fc469d6
* Mon Aug 23 2021 mkubecek@suse.cz
- hid: fix length inconsistency
  (20210816130059.3yxtdvu2r7wo4uu3@lion.mk-sys.cz).
- commit 61596f4
* Mon Aug 23 2021 mkubecek@suse.cz
- config: refresh vanilla configs
  Vanilla configs also need to include DEBUG_INFO_BTF_MODULES even if the
  value does not differ from base config.
- commit f317ebc
* Mon Aug 23 2021 jslaby@suse.cz
- Update config files. (arm & epaper drivers and other old graphics)
  Propagate recent epaper drivers and other old graphics changes to arms.
- commit dda8a0c
* Mon Aug 23 2021 jslaby@suse.cz
- Update config files. (arm & CONFIG_GAMEPORT)
  Propagate recent CONFIG_GAMEPORT changes to arms.
- commit dc92f5f
* Mon Aug 23 2021 jslaby@suse.cz
- Update config files. (arm & CONFIG_BT_MSFTEXT)
  Propagate recent CONFIG_BT_MSFTEXT changes to arms.
- commit 408b13b
* Mon Aug 23 2021 jslaby@suse.cz
- Update config files. (arm & ATALK)
  Propagate recent ATALK changes to arms.
- commit 32afa86
* Mon Aug 23 2021 jslaby@suse.cz
- Update config files. (arm & EXT4_FS)
  Propagate recent EXT4_FS changes to arms.
- commit dbd131f
* Mon Aug 23 2021 jslaby@suse.cz
- Update config files.
  Only refresh using scripts/run_oldconfig.sh.
- commit bdb4b85
* Mon Aug 23 2021 mkubecek@suse.cz
- Update to 5.14-rc7
- eliminated 3 patches:
  - patches.suse/mmc-sdhci-iproc-cap-min-clock-frequency-on-bcm2711.patch
  - patches.suse/mmc-sdhci-iproc-set-sdhci_quirk_cap_clock_base_broken-on-bcm2711.patch
  - patches.suse/crypto-drbg-select-SHA512.patch
- refresh configs
  - DYNAMIC_FTRACE_WITH_ARGS=y (x86_64 only)
- commit 3e03413
* Sun Aug 22 2021 jeffm@suse.com
- config: enable CONFIG_NO_HZ_FULL where supported (bsc#1189692).
- commit da75261
* Sun Aug 22 2021 jeffm@suse.com
- config: enable CONFIG_MAXSMP (bsc#1189691).
- commit 7c67b01
* Sat Aug 21 2021 jeffm@suse.com
- config: disable CONFIG_SOUNDWIRE_QCOM on x86 (bsc#1189686).
- commit fb7c80f
* Fri Aug 20 2021 jeffm@suse.com
- config: disable CONFIG_MD_MULTIPATH (bsc#1189678).
  First-class multipath on Linux has used dm-multipath for ages.
- commit 1309089
* Fri Aug 20 2021 jeffm@suse.com
- config: disable CONFIG_PM_AUTOSLEEP and CONFIG_PM_WAKELOCKS (bsc#1189677).
- commit 77c3a63
* Fri Aug 20 2021 jeffm@suse.com
- config: disable CONFIG_ISDN on arm* (bsc#1189675).
  Without CONFIG_ISDN, we no longer need to carry:
- patches.suse/misdn-add-support-for-group-membership-check.
- config: disable CONFIG_ISDN (bsc#1189675).
  Without CONFIG_ISDN, we no longer need to carry:
- patches.suse/misdn-add-support-for-group-membership-check.
- commit 310ae3e
* Fri Aug 20 2021 jeffm@suse.com
- config: enable CONFIG_PRINTK_CALLER on arm* (bsc#1189674).
- config: enable CONFIG_PRINTK_CALLER (bsc#1189674).
- commit 0ba49b0
* Fri Aug 20 2021 afaerber@suse.com
- config: arm64: Update to 5.14-rc6
- commit 1a6db50
* Fri Aug 20 2021 martin.wilck@suse.com
- rpm: support gz and zst compression methods
  Extend commit 18fcdff43a00 ("rpm: support compressed modules") for
  compression methods other than xz.
- commit 3b8c4d9
* Fri Aug 20 2021 tiwai@suse.de
- Update config files: make pinctrl-cherryview built-in (bsc#1189447)
  Otherwise some devices aren't properly intiailized.
- commit b19ed90
* Wed Aug 18 2021 tiwai@suse.de
- Bluetooth: switch to lock_sock in SCO (CVE-2021-3640
  bsc#1188172).
- Bluetooth: avoid circular locks in sco_sock_connect
  (CVE-2021-3640 bsc#1188172).
- Bluetooth: switch to lock_sock in SCO (CVE-2021-3640
  bsc#1188172).
- Bluetooth: avoid circular locks in sco_sock_connect
  (CVE-2021-3640 bsc#1188172).
- commit 9562b07
* Wed Aug 18 2021 jslaby@suse.cz
- driver core: Add missing kernel doc for device::msi_lock
  (git-fixes).
- commit 33709df
* Wed Aug 18 2021 jslaby@suse.cz
- Linux 5.13.12 (bsc#1012628).
- lib: use PFN_PHYS() in devmem_is_allowed() (bsc#1012628).
- Revert "usb: dwc3: gadget: Use list_replace_init() before
  traversing lists" (bsc#1012628).
- iio: adc: ti-ads7950: Ensure CS is deasserted after reading
  channels (bsc#1012628).
- iio: adis: set GPIO reset pin direction (bsc#1012628).
- iio: humidity: hdc100x: Add margin to the conversion time
  (bsc#1012628).
- iio: adc: Fix incorrect exit of for-loop (bsc#1012628).
- ASoC: amd: Fix reference to PCM buffer address (bsc#1012628).
- ASoC: xilinx: Fix reference to PCM buffer address (bsc#1012628).
- ASoC: uniphier: Fix reference to PCM buffer address
  (bsc#1012628).
- ASoC: tlv320aic31xx: Fix jack detection after suspend
  (bsc#1012628).
- ASoC: kirkwood: Fix reference to PCM buffer address
  (bsc#1012628).
- ASoC: intel: atom: Fix reference to PCM buffer address
  (bsc#1012628).
- i2c: dev: zero out array used for i2c reads from userspace
  (bsc#1012628).
- cifs: Handle race conditions during rename (bsc#1012628).
- cifs: create sd context must be a multiple of 8 (bsc#1012628).
- cifs: Call close synchronously during unlink/rename/lease break
  (bsc#1012628).
- cifs: use the correct max-length for dentry_path_raw()
  (bsc#1012628).
- io_uring: drop ctx->uring_lock before flushing work item
  (bsc#1012628).
- io_uring: fix ctx-exit io_rsrc_put_work() deadlock
  (bsc#1012628).
- scsi: lpfc: Move initialization of phba->poll_list earlier to
  avoid crash (bsc#1012628).
- cgroup: rstat: fix A-A deadlock on 32bit around u64_stats_sync
  (bsc#1012628).
- seccomp: Fix setting loaded filter count during TSYNC
  (bsc#1012628).
- net: wwan: mhi_wwan_ctrl: Fix possible deadlock (bsc#1012628).
- net: ethernet: ti: cpsw: fix min eth packet size for non-switch
  use-cases (bsc#1012628).
- ARC: fp: set FPU_STATUS.FWE to enable FPU_STATUS update on
  context switch (bsc#1012628).
- ceph: reduce contention in ceph_check_delayed_caps()
  (bsc#1012628).
- pinctrl: k210: Fix k210_fpioa_probe() (bsc#1012628).
- ACPI: NFIT: Fix support for virtual SPA ranges (bsc#1012628).
- libnvdimm/region: Fix label activation vs errors (bsc#1012628).
- riscv: kexec: do not add '-mno-relax' flag if compiler doesn't
  support it (bsc#1012628).
- vmlinux.lds.h: Handle clang's module.{c,d}tor sections
  (bsc#1012628).
- drm/i915/gvt: Fix cached atomics setting for Windows VM
  (bsc#1012628).
- drm/i915/display: Fix the 12 BPC bits for PIPE_MISC reg
  (bsc#1012628).
- drm/amd/display: Remove invalid assert for ODM + MPC case
  (bsc#1012628).
- drm/amd/display: use GFP_ATOMIC in amdgpu_dm_irq_schedule_work
  (bsc#1012628).
- drm/amdgpu: Add preferred mode in modeset when freesync video
  mode's enabled (bsc#1012628).
- drm/amdgpu: don't enable baco on boco platforms in runpm
  (bsc#1012628).
- drm/amdgpu: handle VCN instances when harvesting (v2)
  (bsc#1012628).
- ieee802154: hwsim: fix GPF in hwsim_set_edge_lqi (bsc#1012628).
- ieee802154: hwsim: fix GPF in hwsim_new_edge_nl (bsc#1012628).
- drm/mediatek: Fix cursor plane no update (bsc#1012628).
- pinctrl: mediatek: Fix fallback behavior for bias_set_combo
  (bsc#1012628).
- ASoC: cs42l42: Correct definition of ADC Volume control
  (bsc#1012628).
- ASoC: cs42l42: Don't allow SND_SOC_DAIFMT_LEFT_J (bsc#1012628).
- ASoC: cs42l42: Fix bclk calculation for mono (bsc#1012628).
- selftests/sgx: Fix Q1 and Q2 calculation in sigstruct.c
  (bsc#1012628).
- ASoC: SOF: Intel: Kconfig: fix SoundWire dependencies
  (bsc#1012628).
- ASoC: SOF: Intel: hda-ipc: fix reply size checking
  (bsc#1012628).
- ASoC: cs42l42: Fix inversion of ADC Notch Switch control
  (bsc#1012628).
- ASoC: cs42l42: Remove duplicate control for WNF filter frequency
  (bsc#1012628).
- netfilter: nf_conntrack_bridge: Fix memory leak when error
  (bsc#1012628).
- pinctrl: tigerlake: Fix GPIO mapping for newer version of
  software (bsc#1012628).
- ASoC: cs42l42: PLL must be running when changing MCLK_SRC_SEL
  (bsc#1012628).
- ASoC: cs42l42: Fix LRCLK frame start edge (bsc#1012628).
- ASoC: cs42l42: Fix mono playback (bsc#1012628).
- net: dsa: mt7530: add the missing RxUnicast MIB counter
  (bsc#1012628).
- net: mvvp2: fix short frame size on s390 (bsc#1012628).
- platform/x86: pcengines-apuv2: Add missing terminating entries
  to gpio-lookup tables (bsc#1012628).
- perf/x86/intel: Apply mid ACK for small core (bsc#1012628).
- drm/amd/pm: Fix a memory leak in an error handling path in
  'vangogh_tables_init()' (bsc#1012628).
- libbpf: Fix probe for BPF_PROG_TYPE_CGROUP_SOCKOPT
  (bsc#1012628).
- libbpf: Do not close un-owned FD 0 on errors (bsc#1012628).
- net: dsa: qca: ar9331: make proper initial port defaults
  (bsc#1012628).
- net: phy: micrel: Fix link detection on ksz87xx switch"
  (bsc#1012628).
- ppp: Fix generating ifname when empty IFLA_IFNAME is specified
  (bsc#1012628).
- io_uring: clear TIF_NOTIFY_SIGNAL when running task work
  (bsc#1012628).
- net/smc: fix wait on already cleared link (bsc#1012628).
- net/smc: Correct smc link connection counter in case of smc
  client (bsc#1012628).
- net: sched: act_mirred: Reset ct info when mirror/redirect skb
  (bsc#1012628).
- ice: Prevent probing virtual functions (bsc#1012628).
- ice: Stop processing VF messages during teardown (bsc#1012628).
- ice: don't remove netdev->dev_addr from uc sync list
  (bsc#1012628).
- iavf: Set RSS LUT and key in reset handle path (bsc#1012628).
- psample: Add a fwd declaration for skbuff (bsc#1012628).
- bareudp: Fix invalid read beyond skb's linear data
  (bsc#1012628).
- io-wq: fix bug of creating io-wokers unconditionally
  (bsc#1012628).
- io-wq: fix IO_WORKER_F_FIXED issue in create_io_worker()
  (bsc#1012628).
- net/mlx5: Don't skip subfunction cleanup in case of error in
  module init (bsc#1012628).
- net/mlx5: DR, Add fail on error check on decap (bsc#1012628).
- net/mlx5e: Avoid creating tunnel headers for local route
  (bsc#1012628).
- net/mlx5e: Destroy page pool after XDP SQ to fix use-after-free
  (bsc#1012628).
- net/mlx5: Block switchdev mode while devlink traps are active
  (bsc#1012628).
- net/mlx5e: TC, Fix error handling memory leak (bsc#1012628).
- net/mlx5: Synchronize correct IRQ when destroying CQ
  (bsc#1012628).
- net/mlx5: Fix return value from tracer initialization
  (bsc#1012628).
- drm/meson: fix colour distortion from HDR set during vendor
  u-boot (bsc#1012628).
- ovl: fix deadlock in splice write (bsc#1012628).
- bpf: Fix potentially incorrect results with
  bpf_get_local_storage() (bsc#1012628).
- net: dsa: microchip: Fix ksz_read64() (bsc#1012628).
- net: dsa: microchip: ksz8795: Fix PVID tag insertion
  (bsc#1012628).
- net: dsa: microchip: ksz8795: Reject unsupported VLAN
  configuration (bsc#1012628).
- net: dsa: microchip: ksz8795: Fix VLAN untagged flag change
  on deletion (bsc#1012628).
- net: dsa: microchip: ksz8795: Use software untagging on CPU port
  (bsc#1012628).
- net: dsa: microchip: ksz8795: Fix VLAN filtering (bsc#1012628).
- net: dsa: microchip: ksz8795: Don't use phy_port_cnt in VLAN
  table lookup (bsc#1012628).
- net: Fix memory leak in ieee802154_raw_deliver (bsc#1012628).
- net: igmp: fix data-race in igmp_ifc_timer_expire()
  (bsc#1012628).
- net: dsa: hellcreek: fix broken backpressure in .port_fdb_dump
  (bsc#1012628).
- net: dsa: lan9303: fix broken backpressure in .port_fdb_dump
  (bsc#1012628).
- net: dsa: lantiq: fix broken backpressure in .port_fdb_dump
  (bsc#1012628).
- net: dsa: sja1105: fix broken backpressure in .port_fdb_dump
  (bsc#1012628).
- pinctrl: sunxi: Don't underestimate number of functions
  (bsc#1012628).
- net: bridge: fix flags interpretation for extern learn fdb
  entries (bsc#1012628).
- net: bridge: fix memleak in br_add_if() (bsc#1012628).
- net: linkwatch: fix failure to restore device state across
  suspend/resume (bsc#1012628).
- tcp_bbr: fix u32 wrap bug in round logic if bbr_init() called
  after 2B packets (bsc#1012628).
- net: igmp: increase size of mr_ifc_count (bsc#1012628).
- drm/i915: Only access SFC_DONE when media domain is not fused
  off (bsc#1012628).
- xen/events: Fix race in set_evtchn_to_irq (bsc#1012628).
- vsock/virtio: avoid potential deadlock when vsock device remove
  (bsc#1012628).
- nbd: Aovid double completion of a request (bsc#1012628).
- arm64: efi: kaslr: Fix occasional random alloc (and boot)
  failure (bsc#1012628).
- KVM: arm64: Fix off-by-one in range_is_memory (bsc#1012628).
- efi/libstub: arm64: Force Image reallocation if BSS was not
  reserved (bsc#1012628).
- efi/libstub: arm64: Relax 2M alignment again for relocatable
  kernels (bsc#1012628).
- powerpc/kprobes: Fix kprobe Oops happens in booke (bsc#1012628).
- i2c: iproc: fix race between client unreg and tasklet
  (bsc#1012628).
- x86/tools: Fix objdump version check again (bsc#1012628).
- genirq: Provide IRQCHIP_AFFINITY_PRE_STARTUP (bsc#1012628).
- x86/msi: Force affinity setup before startup (bsc#1012628).
- x86/ioapic: Force affinity setup before startup (bsc#1012628).
- x86/resctrl: Fix default monitoring groups reporting
  (bsc#1012628).
- genirq/msi: Ensure deactivation on teardown (bsc#1012628).
- genirq/timings: Prevent potential array overflow in
  __irq_timings_store() (bsc#1012628).
- powerpc/interrupt: Fix OOPS by not calling do_IRQ() from
  timer_interrupt() (bsc#1012628).
- PCI/MSI: Enable and mask MSI-X early (bsc#1012628).
- PCI/MSI: Mask all unused MSI-X entries (bsc#1012628).
- PCI/MSI: Enforce that MSI-X table entry is masked for update
  (bsc#1012628).
- PCI/MSI: Enforce MSI[X] entry updates to be visible
  (bsc#1012628).
- PCI/MSI: Do not set invalid bits in MSI mask (bsc#1012628).
- PCI/MSI: Correct misleading comments (bsc#1012628).
- PCI/MSI: Use msi_mask_irq() in pci_msi_shutdown() (bsc#1012628).
- PCI/MSI: Protect msi_desc::masked for multi-MSI (bsc#1012628).
- powerpc/interrupt: Do not call single_step_exception() from
  other exceptions (bsc#1012628).
- powerpc/pseries: Fix update of LPAR security flavor after LPM
  (bsc#1012628).
- powerpc/32s: Fix napping restore in data storage interrupt (DSI)
  (bsc#1012628).
- powerpc/smp: Fix OOPS in topology_init() (bsc#1012628).
- powerpc/xive: Do not skip CPU-less nodes when creating the IPIs
  (bsc#1012628).
- powerpc/32: Fix critical and debug interrupts on BOOKE
  (bsc#1012628).
- efi/libstub: arm64: Double check image alignment at entry
  (bsc#1012628).
- locking/rtmutex: Use the correct rtmutex debugging config option
  (bsc#1012628).
- KVM: VMX: Use current VMCS to query WAITPKG support for MSR
  emulation (bsc#1012628).
- KVM: nVMX: Use vmx_need_pf_intercept() when deciding if L0
  wants a #PF (bsc#1012628).
- KVM: x86/mmu: Don't leak non-leaf SPTEs when zapping all SPTEs
  (bsc#1012628).
- KVM: x86/mmu: Protect marking SPs unsync when using TDP MMU
  with spinlock (bsc#1012628).
- ceph: add some lockdep assertions around snaprealm handling
  (bsc#1012628).
- ceph: clean up locking annotation for ceph_get_snap_realm and
  __lookup_snap_realm (bsc#1012628).
- ceph: take snap_empty_lock atomically with snaprealm refcount
  change (bsc#1012628).
- kasan, slub: reset tag when printing address (bsc#1012628).
- KVM: nSVM: avoid picking up unsupported bits from L2 in int_ctl
  (CVE-2021-3653) (bsc#1012628).
- KVM: nSVM: always intercept VMLOAD/VMSAVE when nested
  (CVE-2021-3656) (bsc#1012628).
- commit e7679db
* Tue Aug 17 2021 tiwai@suse.de
- Bluetooth: btusb: Add support for Foxconn Mediatek Chip
  (bsc#1188064).
- Bluetooth: btusb: Add support for IMC Networks Mediatek Chip
  (bsc#1188064).
- Bluetooth: btusb: Add support for Foxconn Mediatek Chip
  (bsc#1188064).
- Bluetooth: btusb: Add support for IMC Networks Mediatek Chip
  (bsc#1188064).
- Bluetooth: btusb: Add support for Lite-On Mediatek Chip
  (bsc#1188064).
- commit 3cfd9ab
* Mon Aug 16 2021 msuchanek@suse.de
- kernel-binary.spec: Require dwarves for kernel-binary-devel when BTF is
  enabled (jsc#SLE-17288).
  About the pahole version: v1.18 should be bare mnimum, v1.22 should be
  fully functional, for now we ship git snapshot with fixes on top of
  v1.21.
- commit 8ba3382
* Mon Aug 16 2021 mkubecek@suse.cz
- Update to 5.14-rc6
- refresh configs
  - drop MQ_IOSCHED_DEADLINE_CGROUP
- commit 17c8c26
* Sun Aug 15 2021 jslaby@suse.cz
- Linux 5.13.11 (bsc#1012628).
- ovl: prevent private clone if bind mount is not allowed
  (bsc#1012628).
- ppp: Fix generating ppp unit id when ifname is not specified
  (bsc#1012628).
- ALSA: hda: Add quirk for ASUS Flow x13 (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP ProBook 650
  G8 Notebook PC (bsc#1012628).
- ALSA: pcm: Fix mmap breakage without explicit buffer setup
  (bsc#1012628).
- bpf: Add lockdown check for probe_write_user helper
  (bsc#1012628).
- firmware: tee_bnxt: Release TEE shm, session, and context
  during kexec (bsc#1012628).
- commit 97e7098
* Fri Aug 13 2021 tonyj@suse.de
- bpf: Fix integer overflow involving bucket_size (bsc#1189233,
  CVE#CVE-2021-38166).
- commit fcfea2b
* Fri Aug 13 2021 jslaby@suse.cz
- Linux 5.13.10 (bsc#1012628).
- Revert "ACPICA: Fix memory leak caused by _CID repair function"
  (bsc#1012628).
- ALSA: seq: Fix racy deletion of subscriber (bsc#1012628).
- bus: ti-sysc: Fix gpt12 system timer issue with reserved status
  (bsc#1012628).
- net: xfrm: fix memory leak in xfrm_user_rcv_msg (bsc#1012628).
- arm64: dts: ls1028a: fix node name for the sysclk (bsc#1012628).
- dmaengine: idxd: fix array index when int_handles are being used
  (bsc#1012628).
- dmaengine: idxd: fix setup sequence for MSIXPERM table
  (bsc#1012628).
- ARM: imx: add missing iounmap() (bsc#1012628).
- ARM: imx: add missing clk_disable_unprepare() (bsc#1012628).
- ARM: dts: imx6qdl-sr-som: Increase the PHY reset duration to
  10ms (bsc#1012628).
- Revert "soc: imx8m: change to use platform driver"
  (bsc#1012628).
- dmaengine: idxd: fix desc->vector that isn't being updated
  (bsc#1012628).
- dmaengine: idxd: fix sequence for pci driver remove() and
  shutdown() (bsc#1012628).
- dmaengine: idxd: fix submission race window (bsc#1012628).
- arm64: dts: ls1028: sl28: fix networking for variant 2
  (bsc#1012628).
- ARM: dts: colibri-imx6ull: limit SDIO clock to 25MHz
  (bsc#1012628).
- ARM: imx: fix missing 3rd argument in macro imx_mmdc_perf_init
  (bsc#1012628).
- ARM: dts: imx: Swap M53Menlo
  pinctrl_power_button/pinctrl_power_out pins (bsc#1012628).
- arm64: dts: armada-3720-turris-mox: fixed indices for the SDHC
  controllers (bsc#1012628).
- ext4: fix potential uninitialized access to retval in kmmpd
  (bsc#1012628).
- arm64: dts: armada-3720-turris-mox: remove mrvl,i2c-fast-mode
  (bsc#1012628).
- ALSA: usb-audio: fix incorrect clock source setting
  (bsc#1012628).
- riscv: stacktrace: Fix NULL pointer dereference (bsc#1012628).
- clk: stm32f4: fix post divisor setup for I2S/SAI PLLs
  (bsc#1012628).
- ARM: dts: am437x-l4: fix typo in can@0 node (bsc#1012628).
- omap5-board-common: remove not physically existing vdds_1v8_main
  fixed-regulator (bsc#1012628).
- dmaengine: uniphier-xdmac: Use readl_poll_timeout_atomic()
  in atomic state (bsc#1012628).
- clk: tegra: Implement disable_unused() of
  tegra_clk_sdmmc_mux_ops (bsc#1012628).
- dmaengine: stm32-dma: Fix PM usage counter imbalance in stm32
  dma ops (bsc#1012628).
- dmaengine: stm32-dmamux: Fix PM usage counter unbalance in
  stm32 dmamux ops (bsc#1012628).
- spi: imx: mx51-ecspi: Reinstate low-speed CONFIGREG delay
  (bsc#1012628).
- spi: imx: mx51-ecspi: Fix low-speed CONFIGREG delay calculation
  (bsc#1012628).
- drm/kmb: Enable LCD DMA for low TVDDCV (bsc#1012628).
- media: videobuf2-core: dequeue if start_streaming fails
  (bsc#1012628).
- ARM: dts: stm32: Prefer HW RTC on DHCOM SoM (bsc#1012628).
- ARM: dts: stm32: Disable LAN8710 EDPD on DHCOM (bsc#1012628).
- ARM: dts: stm32: Fix touchscreen IRQ line assignment on DHCOM
  (bsc#1012628).
- dmaengine: imx-dma: configure the generic DMA type to make it
  work (bsc#1012628).
- net, gro: Set inner transport header offset in tcp/udp GRO hook
  (bsc#1012628).
- net: dsa: sja1105: overwrite dynamic FDB entries with static
  ones in .port_fdb_add (bsc#1012628).
- net: dsa: sja1105: invalidate dynamic FDB entries learned
  concurrently with statically added ones (bsc#1012628).
- net: dsa: sja1105: ignore the FDB entry for unknown multicast
  when adding a new address (bsc#1012628).
- net: dsa: sja1105: be stateless with FDB entries on
  SJA1105P/Q/R/S/SJA1110 too (bsc#1012628).
- net: dsa: sja1105: match FDB entries regardless of inner/outer
  VLAN tag (bsc#1012628).
- net: phy: micrel: Fix detection of ksz87xx switch (bsc#1012628).
- net: natsemi: Fix missing pci_disable_device() in probe and
  remove (bsc#1012628).
- gpio: tqmx86: really make IRQ optional (bsc#1012628).
- RDMA/mlx5: Delay emptying a cache entry when a new MR is added
  to it recently (bsc#1012628).
- net: bridge: validate the NUD_PERMANENT bit when adding an
  extern_learn FDB entry (bsc#1012628).
- sctp: move the active_key update after sh_keys is added
  (bsc#1012628).
- drm/i915: Call i915_globals_exit() if pci_register_device()
  fails (bsc#1012628).
- nfp: update ethtool reporting of pauseframe control
  (bsc#1012628).
- net: ipv6: fix returned variable type in ip6_skb_dst_mtu
  (bsc#1012628).
- RDMA/hns: Fix the double unlock problem of poll_sem
  (bsc#1012628).
- net: dsa: qca: ar9331: reorder MDIO write sequence
  (bsc#1012628).
- riscv: Disable STACKPROTECTOR_PER_TASK if GCC_PLUGIN_RANDSTRUCT
  is enabled (bsc#1012628).
- net: sched: fix lockdep_set_class() typo error for sch->seqlock
  (bsc#1012628).
- drm/i915: fix i915_globals_exit() section mismatch error
  (bsc#1012628).
- MIPS: check return value of pgtable_pmd_page_ctor (bsc#1012628).
- x86/tools/relocs: Fix non-POSIX regexp (bsc#1012628).
- mips: Fix non-POSIX regexp (bsc#1012628).
- kbuild: cancel sub_make_done for the install target to fix DKMS
  (bsc#1012628).
- bnx2x: fix an error code in bnx2x_nic_load() (bsc#1012628).
- net: ethernet: ti: am65-cpsw: fix crash in
  am65_cpsw_port_offload_fwd_mark_update() (bsc#1012628).
- net: pegasus: fix uninit-value in get_interrupt_interval
  (bsc#1012628).
- net: fec: fix use-after-free in fec_drv_remove (bsc#1012628).
- net: vxge: fix use-after-free in vxge_device_unregister
  (bsc#1012628).
- blk-iolatency: error out if blk_get_queue() failed in
  iolatency_set_limit() (bsc#1012628).
- Bluetooth: defer cleanup of resources in hci_unregister_dev()
  (bsc#1012628).
- io-wq: fix no lock protection of acct->nr_worker (bsc#1012628).
- io-wq: fix lack of acct->nr_workers < acct->max_workers
  judgement (bsc#1012628).
- USB: usbtmc: Fix RCU stall warning (bsc#1012628).
- USB: serial: option: add Telit FD980 composition 0x1056
  (bsc#1012628).
- USB: serial: ch341: fix character loss at high transfer rates
  (bsc#1012628).
- USB: serial: ftdi_sio: add device ID for Auto-M3 OP-COM v2
  (bsc#1012628).
- USB: serial: pl2303: fix HX type detection (bsc#1012628).
- USB: serial: pl2303: fix GT type detection (bsc#1012628).
- firmware_loader: use -ETIMEDOUT instead of -EAGAIN in
  fw_load_sysfs_fallback (bsc#1012628).
- firmware_loader: fix use-after-free in firmware_fallback_sysfs
  (bsc#1012628).
- drm/amdgpu: fix checking pmops when PM_SLEEP is not enabled
  (bsc#1012628).
- drm/amdgpu/display: fix DMUB firmware version info
  (bsc#1012628).
- ALSA: pcm - fix mmap capability check for the snd-dummy driver
  (bsc#1012628).
- ALSA: hda/realtek: add mic quirk for Acer SF314-42
  (bsc#1012628).
- ALSA: hda/realtek: Fix headset mic for Acer SWIFT SF314-56
  (ALC256) (bsc#1012628).
- ALSA: usb-audio: Fix superfluous autosuspend recovery
  (bsc#1012628).
- ALSA: usb-audio: Add registration quirk for JBL Quantum 600
  (bsc#1012628).
- ALSA: usb-audio: Avoid unnecessary or invalid connector
  selection at resume (bsc#1012628).
- usb: dwc3: gadget: Use list_replace_init() before traversing
  lists (bsc#1012628).
- usb: dwc3: gadget: Avoid runtime resume if disabling pullup
  (bsc#1012628).
- usb: gadget: remove leaked entry from udc driver list
  (bsc#1012628).
- usb: cdns3: Fixed incorrect gadget state (bsc#1012628).
- usb: cdnsp: Fixed issue with ZLP (bsc#1012628).
- usb: gadget: f_hid: added GET_IDLE and SET_IDLE handlers
  (bsc#1012628).
- usb: gadget: f_hid: fixed NULL pointer dereference
  (bsc#1012628).
- usb: gadget: f_hid: idle uses the highest byte for duration
  (bsc#1012628).
- usb: host: ohci-at91: suspend/resume ports after/before OHCI
  accesses (bsc#1012628).
- usb: typec: tcpm: Keep other events when receiving FRS and
  Sourcing_vbus events (bsc#1012628).
- usb: otg-fsm: Fix hrtimer list corruption (bsc#1012628).
- clk: fix leak on devm_clk_bulk_get_all() unwind (bsc#1012628).
- scripts/tracing: fix the bug that can't parse raw_trace_func
  (bsc#1012628).
- tracing / histogram: Give calculation hist_fields a size
  (bsc#1012628).
- tracing: Reject string operand in the histogram expression
  (bsc#1012628).
- tracing: Fix NULL pointer dereference in start_creating
  (bsc#1012628).
- tracepoint: static call: Compare data on transition from 2->1
  callees (bsc#1012628).
- tracepoint: Fix static call function vs data state mismatch
  (bsc#1012628).
- tracepoint: Use rcu get state and cond sync for static call
  updates (bsc#1012628).
- arm64: stacktrace: avoid tracing arch_stack_walk()
  (bsc#1012628).
- optee: Clear stale cache entries during initialization
  (bsc#1012628).
- tee: add tee_shm_alloc_kernel_buf() (bsc#1012628).
- tee: Correct inappropriate usage of TEE_SHM_DMA_BUF flag
  (bsc#1012628).
- optee: Fix memory leak when failing to register shm pages
  (bsc#1012628).
- optee: Refuse to load the driver under the kdump kernel
  (bsc#1012628).
- optee: fix tee out of memory failure seen during kexec reboot
  (bsc#1012628).
- tpm_ftpm_tee: Free and unregister TEE shared memory during kexec
  (bsc#1012628).
- staging: rtl8723bs: Fix a resource leak in sd_int_dpc
  (bsc#1012628).
- staging: rtl8712: get rid of flush_scheduled_work (bsc#1012628).
- staging: rtl8712: error handling refactoring (bsc#1012628).
- drivers core: Fix oops when driver probe fails (bsc#1012628).
- media: rtl28xxu: fix zero-length control request (bsc#1012628).
- pipe: increase minimum default pipe size to 2 pages
  (bsc#1012628).
- ext4: fix potential htree corruption when growing large_dir
  directories (bsc#1012628).
- Revert "thunderbolt: Hide authorized attribute if router does
  not support PCIe tunnels" (bsc#1012628).
- serial: tegra: Only print FIFO error message when an error
  occurs (bsc#1012628).
- serial: 8250_mtk: fix uart corruption issue when rx power off
  (bsc#1012628).
- serial: 8250: Mask out floating 16/32-bit bus bits
  (bsc#1012628).
- serial: 8250: fix handle_irq locking (bsc#1012628).
- MIPS: Malta: Do not byte-swap accesses to the CBUS UART
  (bsc#1012628).
- serial: 8250_pci: Enumerate Elkhart Lake UARTs via dedicated
  driver (bsc#1012628).
- serial: 8250_pci: Avoid irq sharing for MSI(-X) interrupts
  (bsc#1012628).
- fpga: dfl: fme: Fix cpu hotplug issue in performance reporting
  (bsc#1012628).
- timers: Move clearing of base::timer_running under base:: Lock
  (bsc#1012628).
- virt: acrn: Do hcall_destroy_vm() before resource release
  (bsc#1012628).
- perf: Fix required permissions if sigtrap is requested
  (bsc#1012628).
- xfrm: Fix RCU vs hash_resize_mutex lock inversion (bsc#1012628).
- net/xfrm/compat: Copy xfrm_spdattr_type_t atributes
  (bsc#1012628).
- pcmcia: i82092: fix a null pointer dereference bug
  (bsc#1012628).
- scsi: ibmvfc: Fix command state accounting and stale response
  detection (bsc#1012628).
- selinux: correct the return value when loads initial sids
  (bsc#1012628).
- bus: ti-sysc: AM3: RNG is GP only (bsc#1012628).
- Revert "gpio: mpc8xxx: change the gpio interrupt
  flags." (bsc#1012628).
- arm64: fix compat syscall return truncation (bsc#1012628).
- ARM: omap2+: hwmod: fix potential NULL pointer access
  (bsc#1012628).
- md/raid10: properly indicate failure when ending a failed
  write request (bsc#1012628).
- io-wq: fix race between worker exiting and activating free
  worker (bsc#1012628).
- s390/dasd: fix use after free in dasd path handling
  (bsc#1012628).
- KVM: x86: accept userspace interrupt only if no event is
  injected (bsc#1012628).
- KVM: SVM: Fix off-by-one indexing when nullifying last used
  SEV VMCB (bsc#1012628).
- KVM: Do not leak memory for duplicate debugfs directories
  (bsc#1012628).
- KVM: x86/mmu: Fix per-cpu counter corruption on 32-bit builds
  (bsc#1012628).
- soc: ixp4xx: fix printing resources (bsc#1012628).
- interconnect: Fix undersized devress_alloc allocation
  (bsc#1012628).
- usb: cdnsp: Fix the IMAN_IE_SET and IMAN_IE_CLEAR macro
  (bsc#1012628).
- usb: cdnsp: Fix incorrect supported maximum speed (bsc#1012628).
- spi: meson-spicc: fix memory leak in meson_spicc_remove
  (bsc#1012628).
- interconnect: Zero initial BW after sync-state (bsc#1012628).
- interconnect: Always call pre_aggregate before aggregate
  (bsc#1012628).
- interconnect: qcom: icc-rpmh: Ensure floor BW is enforced for
  all nodes (bsc#1012628).
- drm/i915: Correct SFC_DONE register offset (bsc#1012628).
- soc: ixp4xx/qmgr: fix invalid __iomem access (bsc#1012628).
- perf/x86/amd: Don't touch the AMD64_EVENTSEL_HOSTONLY bit
  inside the guest (bsc#1012628).
- sched/rt: Fix double enqueue caused by rt_effective_prio
  (bsc#1012628).
- riscv: dts: fix memory size for the SiFive HiFive Unmatched
  (bsc#1012628).
- libata: fix ata_pio_sector for CONFIG_HIGHMEM (bsc#1012628).
- reiserfs: add check for root_inode in reiserfs_fill_super
  (bsc#1012628).
- reiserfs: check directory items on read from disk (bsc#1012628).
- virt_wifi: fix error on connect (bsc#1012628).
- net: qede: Fix end of loop tests for list_for_each_entry
  (bsc#1012628).
- alpha: Send stop IPI to send to online CPUs (bsc#1012628).
- net/qla3xxx: fix schedule while atomic in ql_wait_for_drvr_lock
  and ql_adapter_reset (bsc#1012628).
- smb3: rc uninitialized in one fallocate path (bsc#1012628).
- drm/amdgpu/display: only enable aux backlight control for OLED
  panels (bsc#1012628).
- platform/x86: gigabyte-wmi: add support for B550 Aorus Elite V2
  (bsc#1012628).
- HID: ft260: fix device removal due to USB disconnect
  (bsc#1012628).
- commit 37b568f
* Wed Aug 11 2021 msuchanek@suse.de
- README: Modernize build instructions.
- commit 8cc5c28
* Wed Aug 11 2021 jslaby@suse.cz
- rpm/kernel-obs-build.spec.in: make builds reproducible (bsc#1189305)
- commit 7f9ade7
* Wed Aug 11 2021 jslaby@suse.cz
- Revert "Revert "UsrMerge the kernel (boo#1184804)""
  This reverts commit 999e6048a4cc6accd2653c9dccaaaff2f4ae8f86. By that,
  we reverted the original commit 6f5ed044f52a. But the selinux problem is
  hopefully fixed in the meantime, so it's time to try UsrMerge for kernel
  again.
- Revert "Revert "UsrMerge the kernel (boo#1184804)""
  This reverts commit b6ab3ded319fca797d007c541a190a308f940cf7. By that,
  we reverted the original commit 6f5ed044f52a. But the two problems were
  adressed in the meantime, so it's time to try UsrMerge for kernel again.
- commit 33df9c6
* Tue Aug 10 2021 ykaukab@suse.de
- config: arm64: enable audio support for Nvidia Tegra SOCs
- commit 9983afb
* Mon Aug  9 2021 jeffm@suse.com
- crypto: drbg - select SHA512 (bsc#1189034).
  config: CRYPTO_SHA512 is built-in again.
- commit 80170a0
* Mon Aug  9 2021 ludwig.nussel@suse.de
- Fix filesystem requirement and suse-release requires
  Reduce filesystem conflict to anything less than 16 to allow pulling the
  change into the next major stable version.
  Don't require suse-release as that's not technically required. Conflict
  with a too old one instead.
- commit 913f755
* Mon Aug  9 2021 mkubecek@suse.cz
- Update to 5.14-rc5
- update configs
  - PHYS_RAM_BASE_FIXED=n (riscv64 only, follow upstream revert)
- commit 1838496
* Sun Aug  8 2021 jslaby@suse.cz
- blacklist.conf: add one docs fix
- commit 19b1d90
* Sun Aug  8 2021 jslaby@suse.cz
- Revert "qed: fix possible unpaired spin_{un}lock_bh in
  _qed_mcp_cmd_and_union()" (git-fixes).
- commit 27fe085
* Sun Aug  8 2021 jslaby@suse.cz
- Linux 5.13.9 (bsc#1012628).
- drm/i915: Revert "drm/i915/gem: Asynchronous cmdparser"
  (bsc#1012628).
- Revert "drm/i915: Propagate errors on awaiting already signaled
  fences" (bsc#1012628).
- power: supply: ab8500: Call battery population once
  (bsc#1012628).
- skmsg: Increase sk->sk_drops when dropping packets
  (bsc#1012628).
- skmsg: Pass source psock to sk_psock_skb_redirect()
  (bsc#1012628).
- bpf, sockmap: On cleanup we additionally need to remove cached
  skb (bsc#1012628).
- cifs: use helpers when parsing uid/gid mount options and
  validate them (bsc#1012628).
- cifs: add missing parsing of backupuid (bsc#1012628).
- net: dsa: sja1105: parameterize the number of ports
  (bsc#1012628).
- net: dsa: sja1105: fix address learning getting disabled on
  the CPU port (bsc#1012628).
- ASoC: Intel: boards: handle hda-dsp-common as a module
  (bsc#1012628).
- ASoC: Intel: boards: create sof-maxim-common module
  (bsc#1012628).
- ASoC: Intel: boards: fix xrun issue on platform with max98373
  (bsc#1012628).
- regulator: rtmv20: Fix wrong mask for strobe-polarity-high
  (bsc#1012628).
- regulator: rt5033: Fix n_voltages settings for BUCK and LDO
  (bsc#1012628).
- spi: stm32h7: fix full duplex irq handler handling
  (bsc#1012628).
- ASoC: tlv320aic31xx: fix reversed bclk/wclk master bits
  (bsc#1012628).
- regulator: mtk-dvfsrc: Fix wrong dev pointer for
  devm_regulator_register (bsc#1012628).
- qed: fix possible unpaired spin_{un}lock_bh in
  _qed_mcp_cmd_and_union() (bsc#1012628).
- ASoC: rt5682: Fix the issue of garbled recording after
  powerd_dbus_suspend (bsc#1012628).
- net: Fix zero-copy head len calculation (bsc#1012628).
- ASoC: ti: j721e-evm: Fix unbalanced domain activity tracking
  during startup (bsc#1012628).
- ASoC: ti: j721e-evm: Check for not initialized parent_clk_id
  (bsc#1012628).
- efi/mokvar: Reserve the table only if it is in boot services
  data (bsc#1012628).
- nvme: fix nvme_setup_command metadata trace event (bsc#1012628).
- drm/amd/display: Fix comparison error in dcn21 DML
  (bsc#1012628).
- drm/amd/display: Fix max vstartup calculation for modes with
  borders (bsc#1012628).
- io_uring: never attempt iopoll reissue from release path
  (bsc#1012628).
- io_uring: explicitly catch any illegal async queue attempt
  (bsc#1012628).
- Revert "Bluetooth: Shutdown controller after workqueues are
  flushed or cancelled" (bsc#1012628).
- Revert "watchdog: iTCO_wdt: Account for rebooting on second
  timeout" (bsc#1012628).
- drm/amd/display: Fix ASSR regression on embedded panels
  (bsc#1012628).
- spi: mediatek: Fix fifo transfer (bsc#1012628).
- Update config files.
- commit ed76d57
* Thu Aug  5 2021 jslaby@suse.cz
- rpm/kernel-binary.spec.in: avoid high suse-release requirements
  Not provided in stagings.
- commit 7839440
* Thu Aug  5 2021 jslaby@suse.cz
- rpm/kernel-source.rpmlintrc: ignore new include/config files
  In 5.13, since 0e0345b77ac4, config files have no longer .h suffix.
  Adapt the zero-length check.
  Based on Martin Liska's change.
- commit b6f021b
* Wed Aug  4 2021 jeffm@suse.com
- config: make CONFIG_INTEL_PMC_CORE modular (bsc#1189072).
  When this option was introduced, it was a boolean.  Since then it's
  been changed to a tristate and can be made modular again.
- config: config: disable epaper drivers and other old graphics (bsc#1189116).
- config: disable CONFIG_GAMEPORT (bsc#1189115).
  The last SoundBlaster card to use a Game Port shipped in 2001.  Devices
  that connect via Game Port can still be used with a USB adapter, which
  doesn't use the GAMEPORT driver.
- config: enable CONFIG_BT_MSFTEXT (bsc#1189113).
- config: disable CONFIG_ATALK (bsc#1189112).
  This disables support for native AppleTalk which Apple stopped
  supporting in 2009.  AppleTalk over IP is implemented using the netatalk
  package.
- config: enable CONFIG_CMA on x86_64 (bsc#1189109).
  CMA was enabled in SLE15-SP3 via jsc#SLE-17227.  One difference is that
  v5.10-rc1 (b7176c261cd) upstream added the ability to allocate areas for
  each NUMA node, which changed some of the defaults.
  The default number of areas (19) is used here.
- config: make CONFIG_INTEL_PMC_CORE modular (bsc#1189072).
  When this option was introduced, it was a boolean.  Since then it's
  been changed to a tristate and can be made modular again.
- config: config: disable epaper drivers and other old graphics (bsc#1189116).
- config: disable CONFIG_GAMEPORT (bsc#1189115).
  The last SoundBlaster card to use a Game Port shipped in 2001.  Devices
  that connect via Game Port can still be used with a USB adapter, which
  doesn't use the GAMEPORT driver.
- config: enable CONFIG_BT_MSFTEXT (bsc#1189113).
- config: disable CONFIG_ATALK (bsc#1189112).
  This disables support for native AppleTalk which Apple stopped
  supporting in 2009.  AppleTalk over IP is implemented using the netatalk
  package.
- config: enable CONFIG_CMA on x86_64 (bsc#1189109).
  CMA was enabled in SLE15-SP3 via jsc#SLE-17227.  One difference is that
  v5.10-rc1 (b7176c261cd) upstream added the ability to allocate areas for
  each NUMA node, which changed some of the defaults.
  The default number of areas (19) is used here.
- commit c779dde
* Wed Aug  4 2021 jeffm@suse.com
- config: enable CONFIG_EFI_RCI2_TABLE (bsc#1189108).
- config: disable X86_X32 (bsc#1189069).
  This feature requires a userspace rebuild to use the X32 ABI and that
  hasn't happened.  If that support is eventually added, we can re-enable.
- config: enable CONFIG_EFI_RCI2_TABLE (bsc#1189108).
- config: disable X86_X32 (bsc#1189069).
  This feature requires a userspace rebuild to use the X32 ABI and that
  hasn't happened.  If that support is eventually added, we can re-enable.
- commit 61cb111
* Wed Aug  4 2021 iivanov@suse.de
- net: usb: lan78xx: don't modify phy_device state concurrently (bsc#1188270).
- commit 79524ad
* Wed Aug  4 2021 jslaby@suse.cz
- Linux 5.13.8 (bsc#1012628).
- octeontx2-af: Remove unnecessary devm_kfree (bsc#1012628).
- perf pmu: Fix alias matching (bsc#1012628).
- can: j1939: j1939_session_deactivate(): clarify lifetime of
  session object (bsc#1012628).
- i40e: Add additional info to PHY type error (bsc#1012628).
- io_uring: fix race in unified task_work running (bsc#1012628).
- Revert "perf map: Fix dso->nsinfo refcounting" (bsc#1012628).
- powerpc/pseries: Fix regression while building external modules
  (bsc#1012628).
- powerpc/vdso: Don't use r30 to avoid breaking Go lang
  (bsc#1012628).
- SMB3: fix readpage for large swap cache (bsc#1012628).
- bpf: Fix pointer arithmetic mask tightening under state pruning
  (bsc#1012628).
- bpf: verifier: Allocate idmap scratch in verifier env
  (bsc#1012628).
- bpf: Remove superfluous aux sanitation on subprog rejection
  (bsc#1012628).
- bpf: Fix leakage due to insufficient speculative store bypass
  mitigation (bsc#1012628).
- bpf: Introduce BPF nospec instruction for mitigating Spectre v4
  (bsc#1012628).
- can: hi311x: fix a signedness bug in hi3110_cmd() (bsc#1012628).
- sis900: Fix missing pci_disable_device() in probe and remove
  (bsc#1012628).
- tulip: windbond-840: Fix missing pci_disable_device() in probe
  and remove (bsc#1012628).
- sctp: fix return value check in __sctp_rcv_asconf_lookup
  (bsc#1012628).
- block: delay freeing the gendisk (bsc#1012628).
- net/mlx5: Fix mlx5_vport_tbl_attr chain from u16 to u32
  (bsc#1012628).
- net/mlx5e: Fix nullptr in mlx5e_hairpin_get_mdev()
  (bsc#1012628).
- net/mlx5: Unload device upon firmware fatal error (bsc#1012628).
- net/mlx5e: Fix page allocation failure for ptp-RQ over SF
  (bsc#1012628).
- net/mlx5e: Fix page allocation failure for trap-RQ over SF
  (bsc#1012628).
- net/mlx5e: Add NETIF_F_HW_TC to hw_features when HTB offload
  is available (bsc#1012628).
- net/mlx5e: RX, Avoid possible data corruption when relaxed
  ordering and LRO combined (bsc#1012628).
- net/mlx5: E-Switch, handle devcom events only for ports on
  the same device (bsc#1012628).
- net/mlx5: E-Switch, Set destination vport vhca id only when
  merged eswitch is supported (bsc#1012628).
- net/mlx5e: Disable Rx ntuple offload for uplink representor
  (bsc#1012628).
- net/mlx5: Fix flow table chaining (bsc#1012628).
- bpf, sockmap: Zap ingress queues after stopping strparser
  (bsc#1012628).
- KVM: selftests: Fix missing break in dirty_log_perf_test arg
  parsing (bsc#1012628).
- drm/msm/dp: Initialize the INTF_CONFIG register (bsc#1012628).
- drm/msm/dp: use dp_ctrl_off_link_stream during PHY compliance
  test run (bsc#1012628).
- drm/msm/dpu: Fix sm8250_mdp register length (bsc#1012628).
- net: llc: fix skb_over_panic (bsc#1012628).
- KVM: x86: Check the right feature bit for MSR_KVM_ASYNC_PF_ACK
  access (bsc#1012628).
- drm/i915/bios: Fix ports mask (bsc#1012628).
- drm/panel: panel-simple: Fix proper bpc for ytc700tlag_05_201c
  (bsc#1012628).
- mlx4: Fix missing error code in mlx4_load_one() (bsc#1012628).
- net: phy: broadcom: re-add check for PHY_BRCM_DIS_TXCRXC_NOENRGY
  on the BCM54811 PHY (bsc#1012628).
- octeontx2-pf: Dont enable backpressure on LBK links
  (bsc#1012628).
- octeontx2-pf: Fix interface down flag on error (bsc#1012628).
- tipc: do not write skb_shinfo frags when doing decrytion
  (bsc#1012628).
- can: mcp251xfd: mcp251xfd_irq(): stop timestamping worker in
  case error in IRQ (bsc#1012628).
- ionic: count csum_none when offload enabled (bsc#1012628).
- ionic: fix up dim accounting for tx and rx (bsc#1012628).
- ionic: remove intr coalesce update from napi (bsc#1012628).
- ionic: catch no ptp support earlier (bsc#1012628).
- ionic: make all rx_mode work threadsafe (bsc#1012628).
- net: qrtr: fix memory leaks (bsc#1012628).
- loop: reintroduce global lock for safe loop_validate_file()
  traversal (bsc#1012628).
- net: dsa: mv88e6xxx: silently accept the deletion of VID 0 too
  (bsc#1012628).
- net: Set true network header for ECN decapsulation
  (bsc#1012628).
- tipc: fix sleeping in tipc accept routine (bsc#1012628).
- tipc: fix implicit-connect for SYN+ (bsc#1012628).
- i40e: Fix log TC creation failure when max num of queues is
  exceeded (bsc#1012628).
- i40e: Fix queue-to-TC mapping on Tx (bsc#1012628).
- i40e: Fix firmware LLDP agent related warning (bsc#1012628).
- i40e: Fix logic of disabling queues (bsc#1012628).
- netfilter: nft_nat: allow to specify layer 4 protocol NAT only
  (bsc#1012628).
- netfilter: conntrack: adjust stop timestamp to real expiry value
  (bsc#1012628).
- mac80211: fix enabling 4-address mode on a sta vif after assoc
  (bsc#1012628).
- bpf: Fix OOB read when printing XDP link fdinfo (bsc#1012628).
- netfilter: nf_tables: fix audit memory leak in nf_tables_commit
  (bsc#1012628).
- RDMA/rxe: Fix memory leak in error path code (bsc#1012628).
- platform/x86: amd-pmc: Fix missing unlock on error in
  amd_pmc_send_cmd() (bsc#1012628).
- platform/x86: amd-pmc: Fix SMU firmware reporting mechanism
  (bsc#1012628).
- platform/x86: amd-pmc: Fix command completion code
  (bsc#1012628).
- RDMA/bnxt_re: Fix stats counters (bsc#1012628).
- cfg80211: Fix possible memory leak in function
  cfg80211_bss_update (bsc#1012628).
- io_uring: fix poll requests leaking second poll entries
  (bsc#1012628).
- io_uring: don't block level reissue off completion path
  (bsc#1012628).
- io_uring: fix io_prep_async_link locking (bsc#1012628).
- nfc: nfcsim: fix use after free during module unload
  (bsc#1012628).
- blk-iocost: fix operation ordering in iocg_wake_fn()
  (bsc#1012628).
- drm/amdgpu: Fix resource leak on probe error path (bsc#1012628).
- drm/amdgpu: Avoid printing of stack contents on firmware load
  error (bsc#1012628).
- drm/amdgpu: Check pmops for desired suspend state (bsc#1012628).
- drm/amd/display: ensure dentist display clock update finished
  in DCN20 (bsc#1012628).
- NIU: fix incorrect error return, missed in previous revert
  (bsc#1012628).
- net: stmmac: add est_irq_status callback function for GMAC
  4.10 and 5.10 (bsc#1012628).
- HID: wacom: Re-enable touch by default for Cintiq 24HDT /
  27QHDT (bsc#1012628).
- alpha: register early reserved memory in memblock (bsc#1012628).
- can: esd_usb2: fix memory leak (bsc#1012628).
- can: ems_usb: fix memory leak (bsc#1012628).
- can: usb_8dev: fix memory leak (bsc#1012628).
- can: mcba_usb_start(): add missing urb->transfer_dma
  initialization (bsc#1012628).
- can: peak_usb: pcan_usb_handle_bus_evt(): fix reading
  rxerr/txerr values (bsc#1012628).
- can: raw: raw_setsockopt(): fix raw_rcv panic for sock UAF
  (bsc#1012628).
- can: j1939: j1939_xtp_rx_dat_one(): fix rxtimer value between
  consecutive TP.DT to 750ms (bsc#1012628).
- mm/memcg: fix NULL pointer dereference in memcg_slab_free_hook()
  (bsc#1012628).
- mm: memcontrol: fix blocking rstat function called from atomic
  cgroup1 thresholding code (bsc#1012628).
- ocfs2: issue zeroout to EOF blocks (bsc#1012628).
- ocfs2: fix zero out valid data (bsc#1012628).
- KVM: add missing compat KVM_CLEAR_DIRTY_LOG (bsc#1012628).
- x86/kvm: fix vcpu-id indexed array sizes (bsc#1012628).
- ACPI: DPTF: Fix reading of attributes (bsc#1012628).
- Revert "ACPI: resources: Add checks for ACPI IRQ override"
  (bsc#1012628).
- btrfs: mark compressed range uptodate only if all bio succeed
  (bsc#1012628).
- btrfs: fix rw device counting in __btrfs_free_extra_devids
  (bsc#1012628).
- btrfs: fix lost inode on log replay after mix of fsync, rename
  and inode eviction (bsc#1012628).
- fs/ext2: Avoid page_address on pages returned by ext2_get_page
  (bsc#1012628).
- pipe: make pipe writes always wake up readers (bsc#1012628).
- selftest: fix build error in
  tools/testing/selftests/vm/userfaultfd.c (bsc#1012628).
- commit 14162fe
* Tue Aug  3 2021 jeffm@jeffm.io
- config: re-modularize CRYPTO_{CTS,ECB,HMAC,SHA512,XTS} (bsc#1189034).
  Now that FS_ENCRYPTION_ALGS is modular, the crypto modules it utilizes
  can be modular as well.  CRYPTO_AES and CRYPTO_CBC are used by
  ENCRYPTED_KEYS and must remain built-in.
- commit 263a9fe
* Tue Aug  3 2021 jeffm@jeffm.io
- config: re-modularize CRYPTO_{GCM,GHASH,GF128MUL} (bsc#1189033).
  These modules were selected as built-in due to Kconfig changes between
  4.14-rc3 and 5.8-rc1 selecting them if BIG_KEYS was enabled.  They can
  be built as modules again now.
- commit 4426182
* Tue Aug  3 2021 jeffm@jeffm.io
- config: re-modularize ext4 (bsc#1189032).
  ext2/3/4 hasn't been a default file system for SLE or openSUSE in many
  years.  There is little reason to continue to keep it as a built-in.
- commit 5b1d047
* Tue Aug  3 2021 mbrugger@suse.com
- arm64: Update config files. (bsc#1188702)
- arm63: Update config files. (bsc#1188702)
- commit a293b6e
* Mon Aug  2 2021 mkubecek@suse.cz
- Update to 5.14-rc4
- refresh configs (cosmetic only)
- commit 025a97d
* Sun Aug  1 2021 tiwai@suse.de
- scsi: sr: Return correct event when media event code is 3
  (bsc#1188767 bsc#1188728).
- commit 5794a07
* Sat Jul 31 2021 jslaby@suse.cz
- Linux 5.13.7 (bsc#1012628).
- ipv6: ip6_finish_output2: set sk into newly allocated nskb
  (bsc#1012628).
- ARM: dts: versatile: Fix up interrupt controller node names
  (bsc#1012628).
- iomap: remove the length variable in iomap_seek_hole
  (bsc#1012628).
- iomap: remove the length variable in iomap_seek_data
  (bsc#1012628).
- cifs: fix the out of range assignment to bit fields in
  parse_server_interfaces (bsc#1012628).
- firmware: arm_scmi: Fix range check for the maximum number of
  pending messages (bsc#1012628).
- firmware: arm_scmi: Fix possible scmi_linux_errmap buffer
  overflow (bsc#1012628).
- hfs: add lock nesting notation to hfs_find_init (bsc#1012628).
- hfs: fix high memory mapping in hfs_bnode_read (bsc#1012628).
- hfs: add missing clean-up in hfs_fill_super (bsc#1012628).
- drm/ttm: add a check against null pointer dereference
  (bsc#1012628).
- nvme-pci: fix multiple races in nvme_setup_io_queues
  (bsc#1012628).
- ipv6: allocate enough headroom in ip6_finish_output2()
  (bsc#1012628).
- rcu-tasks: Don't delete holdouts within
  trc_wait_for_one_reader() (bsc#1012628).
- rcu-tasks: Don't delete holdouts within trc_inspect_reader()
  (bsc#1012628).
- sctp: move 198 addresses from unusable to private scope
  (bsc#1012628).
- net: annotate data race around sk_ll_usec (bsc#1012628).
- net/802/garp: fix memleak in garp_request_join() (bsc#1012628).
- net/802/mrp: fix memleak in mrp_request_join() (bsc#1012628).
- cgroup1: fix leaked context root causing sporadic NULL deref
  in LTP (bsc#1012628).
- workqueue: fix UAF in pwq_unbound_release_workfn()
  (bsc#1012628).
- af_unix: fix garbage collect vs MSG_PEEK (bsc#1012628).
- commit b1bb2c4
* Thu Jul 29 2021 jslaby@suse.cz
- Update config files.
  Just refresh.
- commit 2d7b44d
* Thu Jul 29 2021 jslaby@suse.cz
- Linux 5.13.6 (bsc#1012628).
- igc: Fix use-after-free error during reset (bsc#1012628).
- igb: Fix use-after-free error during reset (bsc#1012628).
- igc: change default return of igc_read_phy_reg() (bsc#1012628).
- ixgbe: Fix an error handling path in 'ixgbe_probe()'
  (bsc#1012628).
- igc: Fix an error handling path in 'igc_probe()' (bsc#1012628).
- igb: Fix an error handling path in 'igb_probe()' (bsc#1012628).
- fm10k: Fix an error handling path in 'fm10k_probe()'
  (bsc#1012628).
- e1000e: Fix an error handling path in 'e1000_probe()'
  (bsc#1012628).
- iavf: Fix an error handling path in 'iavf_probe()'
  (bsc#1012628).
- igb: Check if num of q_vectors is smaller than max before
  array access (bsc#1012628).
- igb: Fix position of assignment to *ring (bsc#1012628).
- net: stmmac: Terminate FPE workqueue in suspend (bsc#1012628).
- gve: Fix an error handling path in 'gve_probe()' (bsc#1012628).
- bpf, samples: Fix xdpsock with '-M' parameter missing unload
  process (bsc#1012628).
- bonding: fix suspicious RCU usage in bond_ipsec_add_sa()
  (bsc#1012628).
- bonding: fix null dereference in bond_ipsec_add_sa()
  (bsc#1012628).
- ixgbevf: use xso.real_dev instead of xso.dev in callback
  functions of struct xfrmdev_ops (bsc#1012628).
- bonding: fix suspicious RCU usage in bond_ipsec_del_sa()
  (bsc#1012628).
- bonding: disallow setting nested bonding + ipsec offload
  (bsc#1012628).
- bonding: Add struct bond_ipesc to manage SA (bsc#1012628).
- bonding: fix suspicious RCU usage in bond_ipsec_offload_ok()
  (bsc#1012628).
- bonding: fix incorrect return value of bond_ipsec_offload_ok()
  (bsc#1012628).
- ipv6: fix 'disable_policy' for fwd packets (bsc#1012628).
- stmmac: platform: Fix signedness bug in stmmac_probe_config_dt()
  (bsc#1012628).
- selftests: icmp_redirect: remove from checking for IPv6 route
  get (bsc#1012628).
- selftests: icmp_redirect: IPv6 PMTU info should be cleared
  after redirect (bsc#1012628).
- pwm: sprd: Ensure configuring period and duty_cycle isn't
  wrongly skipped (bsc#1012628).
- cxgb4: fix IRQ free race during driver unload (bsc#1012628).
- drm/vmwgfx: Fix a bad merge in otable batch takedown
  (bsc#1012628).
- mptcp: fix warning in __skb_flow_dissect() when do syn cookie
  for subflow join (bsc#1012628).
- mptcp: remove redundant req destruct in subflow_check_req()
  (bsc#1012628).
- mptcp: fix syncookie process if mptcp can not_accept new subflow
  (bsc#1012628).
- mptcp: add sk parameter for mptcp_get_options (bsc#1012628).
- mptcp: avoid processing packet if a subflow reset (bsc#1012628).
- selftests: mptcp: fix case multiple subflows limited by server
  (bsc#1012628).
- mptcp: use fast lock for subflows when possible (bsc#1012628).
- mptcp: refine mptcp_cleanup_rbuf (bsc#1012628).
- mptcp: properly account bulk freed memory (bsc#1012628).
- net: phy: marvell10g: fix differentiation of 88X3310 from
  88X3340 (bsc#1012628).
- nvme-pci: do not call nvme_dev_remove_admin from nvme_remove
  (bsc#1012628).
- net: ocelot: fix switchdev objects synced for wrong netdev
  with LAG offload (bsc#1012628).
- sfc: fix lack of XDP TX queues - error XDP TX failed (-22)
  (bsc#1012628).
- KVM: x86/pmu: Clear anythread deprecated bit when 0xa leaf is
  unsupported on the SVM (bsc#1012628).
- KVM: SVM: Return -EFAULT if copy_to_user() for SEV mig packet
  header fails (bsc#1012628).
- KVM: SVM: Fix sev_pin_memory() error checks in SEV migration
  utilities (bsc#1012628).
- arm64: mte: fix restoration of GCR_EL1 from suspend
  (bsc#1012628).
- ARM: dts: aspeed: Update e3c246d4i vuart properties
  (bsc#1012628).
- firmware: arm_scmi: Ensure drivers provide a probe function
  (bsc#1012628).
- perf inject: Fix dso->nsinfo refcounting (bsc#1012628).
- perf map: Fix dso->nsinfo refcounting (bsc#1012628).
- perf probe: Fix dso->nsinfo refcounting (bsc#1012628).
- perf env: Fix sibling_dies memory leak (bsc#1012628).
- perf test session_topology: Delete session->evlist
  (bsc#1012628).
- perf test event_update: Fix memory leak of evlist (bsc#1012628).
- perf test event_update: Fix memory leak of unit (bsc#1012628).
- perf dso: Fix memory leak in dso__new_map() (bsc#1012628).
- perf test maps__merge_in: Fix memory leak of maps (bsc#1012628).
- perf env: Fix memory leak of cpu_pmu_caps (bsc#1012628).
- perf report: Free generated help strings for sort option
  (bsc#1012628).
- perf script: Release zstd data (bsc#1012628).
- perf script: Fix memory 'threads' and 'cpus' leaks on exit
  (bsc#1012628).
- perf lzma: Close lzma stream on exit (bsc#1012628).
- perf probe-file: Delete namelist in del_events() on the error
  path (bsc#1012628).
- perf data: Close all files in close_dir() (bsc#1012628).
- perf sched: Fix record failure when CONFIG_SCHEDSTATS is not
  set (bsc#1012628).
- Kbuild: lto: fix module versionings mismatch in GNU make 3.X
  (bsc#1012628).
- ASoC: wm_adsp: Correct wm_coeff_tlv_get handling (bsc#1012628).
- spi: stm32: fixes pm_runtime calls in probe/remove
  (bsc#1012628).
- regulator: hi6421: Use correct variable type for regmap api
  val argument (bsc#1012628).
- regulator: hi6421: Fix getting wrong drvdata (bsc#1012628).
- spi: mediatek: fix fifo rx mode (bsc#1012628).
- ASoC: rt5631: Fix regcache sync errors on resume (bsc#1012628).
- bpf, test: fix NULL pointer dereference on invalid
  expected_attach_type (bsc#1012628).
- bpf: Fix tail_call_reachable rejection for interpreter when
  jit failed (bsc#1012628).
- xdp, net: Fix use-after-free in bpf_xdp_link_release
  (bsc#1012628).
- ASoC: SOF: Intel: Update ADL descriptor to use ACPI power states
  (bsc#1012628).
- timers: Fix get_next_timer_interrupt() with no timers pending
  (bsc#1012628).
- drm/vc4: hdmi: Drop devm interrupt handler for CEC interrupts
  (bsc#1012628).
- net: dsa: mv88e6xxx: NET_DSA_MV88E6XXX_PTP should depend on
  NET_DSA_MV88E6XXX (bsc#1012628).
- liquidio: Fix unintentional sign extension issue on left shift
  of u16 (bsc#1012628).
- s390/bpf: Perform r1 range checking before accessing
  jit->seen_reg[r1] (bsc#1012628).
- bpf, sockmap: Fix potential memory leak on unlikely error case
  (bsc#1012628).
- bpf, sockmap, tcp: sk_prot needs inuse_idx set for proc stats
  (bsc#1012628).
- bpf, sockmap, udp: sk_prot needs inuse_idx set for proc stats
  (bsc#1012628).
- bpftool: Check malloc return value in mount_bpffs_for_pin
  (bsc#1012628).
- net: fix uninit-value in caif_seqpkt_sendmsg (bsc#1012628).
- spi: spi-cadence-quadspi: Fix division by zero warning
  (bsc#1012628).
- usb: hso: fix error handling code of hso_create_net_device
  (bsc#1012628).
- dma-mapping: handle vmalloc addresses in
  dma_common_{mmap,get_sgtable} (bsc#1012628).
- ASoC: soc-pcm: add a flag to reverse the stop sequence
  (bsc#1012628).
- efi/tpm: Differentiate missing and invalid final event log table
  (bsc#1012628).
- net: decnet: Fix sleeping inside in af_decnet (bsc#1012628).
- KVM: PPC: Book3S: Fix CONFIG_TRANSACTIONAL_MEM=n crash
  (bsc#1012628).
- KVM: PPC: Fix kvm_arch_vcpu_ioctl vcpu_load leak (bsc#1012628).
- net: sched: fix memory leak in tcindex_partial_destroy_work
  (bsc#1012628).
- sctp: trim optlen when it's a huge value in sctp_setsockopt
  (bsc#1012628).
- netrom: Decrease sock refcount when sock timers expire
  (bsc#1012628).
- scsi: iscsi: Fix iface sysfs attr detection (bsc#1012628).
- scsi: target: Fix protect handling in WRITE SAME(32)
  (bsc#1012628).
- spi: cadence: Correct initialisation of runtime PM again
  (bsc#1012628).
- ACPI: Kconfig: Fix table override from built-in initrd
  (bsc#1012628).
- efi/dev-path-parser: Switch to use for_each_acpi_dev_match()
  (bsc#1012628).
- ACPI: utils: Fix reference counting in for_each_acpi_dev_match()
  (bsc#1012628).
- bnxt_en: don't disable an already disabled PCI device
  (bsc#1012628).
- bnxt_en: Refresh RoCE capabilities in bnxt_ulp_probe()
  (bsc#1012628).
- bnxt_en: Add missing check for BNXT_STATE_ABORT_ERR in
  bnxt_fw_rset_task() (bsc#1012628).
- bnxt_en: fix error path of FW reset (bsc#1012628).
- bnxt_en: Validate vlan protocol ID on RX packets (bsc#1012628).
- bnxt_en: Check abort error state in bnxt_half_open_nic()
  (bsc#1012628).
- net: hisilicon: rename CACHE_LINE_MASK to avoid redefinition
  (bsc#1012628).
- net/tcp_fastopen: fix data races around tfo_active_disable_stamp
  (bsc#1012628).
- ALSA: hda: intel-dsp-cfg: add missing ElkhartLake PCI ID
  (bsc#1012628).
- net: hns3: fix possible mismatches resp of mailbox
  (bsc#1012628).
- net: hns3: fix rx VLAN offload state inconsistent issue
  (bsc#1012628).
- spi: spi-bcm2835: Fix deadlock (bsc#1012628).
- io_uring: fix memleak in io_init_wq_offload() (bsc#1012628).
- net/sched: act_skbmod: Skip non-Ethernet packets (bsc#1012628).
- ipv6: fix another slab-out-of-bounds in fib6_nh_flush_exceptions
  (bsc#1012628).
- ceph: don't WARN if we're still opening a session to an MDS
  (bsc#1012628).
- i2c: mpc: Poll for MCF (bsc#1012628).
- scsi: target: Fix NULL dereference on XCOPY completion
  (bsc#1012628).
- drm/ttm: Force re-init if ttm_global_init() fails (bsc#1012628).
- nvme-pci: don't WARN_ON in nvme_reset_work if ctrl.state is
  not RESETTING (bsc#1012628).
- Revert "USB: quirks: ignore remote wake-up on Fibocom L850-GL
  LTE modem" (bsc#1012628).
- afs: Fix tracepoint string placement with built-in AFS
  (bsc#1012628).
- afs: check function return (bsc#1012628).
- afs: Fix setting of writeback_index (bsc#1012628).
- r8169: Avoid duplicate sysfs entry creation error (bsc#1012628).
- nvme: set the PRACT bit when using Write Zeroes with T10 PI
  (bsc#1012628).
- sctp: update active_key for asoc when old key is being replaced
  (bsc#1012628).
- udp: check encap socket in __udp_lib_err (bsc#1012628).
- ibmvnic: Remove the proper scrq flush (bsc#1012628).
- riscv: Fix 32-bit RISC-V boot failure (bsc#1012628).
- tcp: disable TFO blackhole logic by default (bsc#1012628).
- net: dsa: sja1105: make VID 4095 a bridge VLAN too
  (bsc#1012628).
- RISC-V: load initrd wherever it fits into memory (bsc#1012628).
- net: sched: cls_api: Fix the the wrong parameter (bsc#1012628).
- drm/panel: raspberrypi-touchscreen: Prevent double-free
  (bsc#1012628).
- dpaa2-switch: seed the buffer pool after allocating the swp
  (bsc#1012628).
- cifs: only write 64kb at a time when fallocating a small region
  of a file (bsc#1012628).
- cifs: fix fallocate when trying to allocate a hole
  (bsc#1012628).
- ACPI: fix NULL pointer dereference (bsc#1012628).
- io_uring: Fix race condition when sqp thread goes to sleep
  (bsc#1012628).
- mmc: core: Don't allocate IDA for OF aliases (bsc#1012628).
- s390/ftrace: fix ftrace_update_ftrace_func implementation
  (bsc#1012628).
- s390/boot: fix use of expolines in the DMA code (bsc#1012628).
- ALSA: usb-audio: Add missing proc text entry for BESPOKEN type
  (bsc#1012628).
- ALSA: usb-audio: Add registration quirk for JBL Quantum headsets
  (bsc#1012628).
- ALSA: sb: Fix potential ABBA deadlock in CSP driver
  (bsc#1012628).
- ALSA: hda/realtek: Fix pop noise and 2 Front Mic issues on a
  machine (bsc#1012628).
- ALSA: hdmi: Expose all pins on MSI MS-7C94 board (bsc#1012628).
- ALSA: pcm: Call substream ack() method upon compat mmap commit
  (bsc#1012628).
- ALSA: pcm: Fix mmap capability check (bsc#1012628).
- usb: xhci: avoid renesas_usb_fw.mem when it's unusable
  (bsc#1012628).
- xhci: Fix lost USB 2 remote wake (bsc#1012628).
- usb: ehci: Prevent missed ehci interrupts with edge-triggered
  MSI (bsc#1012628).
- KVM: PPC: Book3S HV Nested: Sanitise H_ENTER_NESTED TM state
  (bsc#1012628).
- usb: hub: Disable USB 3 device initiated lpm if exit latency
  is too high (bsc#1012628).
- usb: hub: Fix link power management max exit latency (MEL)
  calculations (bsc#1012628).
- USB: usb-storage: Add LaCie Rugged USB3-FW to IGNORE_UAS
  (bsc#1012628).
- usb: max-3421: Prevent corruption of freed memory (bsc#1012628).
- usb: renesas_usbhs: Fix superfluous irqs happen after
  usb_pkt_pop() (bsc#1012628).
- USB: serial: option: add support for u-blox LARA-R6 family
  (bsc#1012628).
- USB: serial: cp210x: fix comments for GE CS1000 (bsc#1012628).
- USB: serial: cp210x: add ID for CEL EM3588 USB ZigBee stick
  (bsc#1012628).
- usb: gadget: Fix Unbalanced pm_runtime_enable in
  tegra_xudc_probe (bsc#1012628).
- usb: dwc2: Skip clock gating on Samsung SoCs (bsc#1012628).
- usb: dwc2: gadget: Fix GOUTNAK flow for Slave mode
  (bsc#1012628).
- usb: dwc2: gadget: Fix sending zero length packet in DDMA mode
  (bsc#1012628).
- usb: typec: tipd: Don't block probing of consumer of "connector"
  nodes (bsc#1012628).
- usb: typec: stusb160x: register role switch before interrupt
  registration (bsc#1012628).
- usb: typec: stusb160x: Don't block probing of consumer of
  "connector" nodes (bsc#1012628).
- firmware/efi: Tell memblock about EFI iomem reservations
  (bsc#1012628).
- tracepoints: Update static_call before tp_funcs when adding
  a tracepoint (bsc#1012628).
- tracing/histogram: Rename "cpu" to "common_cpu" (bsc#1012628).
- tracing: Fix bug in rb_per_cpu_empty() that might cause deadloop
  (bsc#1012628).
- tracing: Synthetic event field_pos is an index not a boolean
  (bsc#1012628).
- btrfs: check for missing device in btrfs_trim_fs (bsc#1012628).
- btrfs: fix unpersisted i_size on fsync after expanding truncate
  (bsc#1012628).
- btrfs: fix lock inversion problem when doing qgroup extent
  tracing (bsc#1012628).
- media: ngene: Fix out-of-bounds bug in
  ngene_command_config_free_buf() (bsc#1012628).
- ixgbe: Fix packet corruption due to missing DMA sync
  (bsc#1012628).
- driver core: auxiliary bus: Fix memory leak when
  driver_register() fail (bsc#1012628).
- bus: mhi: pci_generic: Apply no-op for wake using sideband
  wake boolean (bsc#1012628).
- bus: mhi: core: Validate channel ID when processing command
  completions (bsc#1012628).
- bus: mhi: pci_generic: Fix inbound IPCR channel (bsc#1012628).
- posix-cpu-timers: Fix rearm racing against process tick
  (bsc#1012628).
- selftest: use mmap instead of posix_memalign to allocate memory
  (bsc#1012628).
- io_uring: explicitly count entries for poll reqs (bsc#1012628).
- io_uring: remove double poll entry on arm failure (bsc#1012628).
- io_uring: fix early fdput() of file (bsc#1012628).
- userfaultfd: do not untag user pointers (bsc#1012628).
- kfence: move the size check to the beginning of __kfence_alloc()
  (bsc#1012628).
- kfence: skip all GFP_ZONEMASK allocations (bsc#1012628).
- mm: call flush_dcache_page() in memcpy_to_page() and
  memzero_page() (bsc#1012628).
- mm: page_alloc: fix page_poison=1 / INIT_ON_ALLOC_DEFAULT_ON
  interaction (bsc#1012628).
- memblock: make for_each_mem_range() traverse MEMBLOCK_HOTPLUG
  regions (bsc#1012628).
- mm: fix the deadlock in finish_fault() (bsc#1012628).
- hugetlbfs: fix mount mode command line processing (bsc#1012628).
- rbd: don't hold lock_rwsem while running_list is being drained
  (bsc#1012628).
- rbd: always kick acquire on "acquired" and "released"
  notifications (bsc#1012628).
- misc: eeprom: at24: Always append device id even if label
  property is set (bsc#1012628).
- nds32: fix up stack guard gap (bsc#1012628).
- driver core: Prevent warning when removing a device link from
  unregistered consumer (bsc#1012628).
- drm: Return -ENOTTY for non-drm ioctls (bsc#1012628).
- drm/amdgpu: update gc golden setting for dimgrey_cavefish
  (bsc#1012628).
- drm/amdgpu: update the golden setting for vangogh (bsc#1012628).
- drm/amdgpu: update golden setting for sienna_cichlid
  (bsc#1012628).
- spi: spi-cadence-quadspi: Revert "Fix division by zero warning"
  (bsc#1012628).
- bonding: fix build issue (bsc#1012628).
- mptcp: fix 'masking a bool' warning (bsc#1012628).
- skbuff: Release nfct refcount on napi stolen or re-used skbs
  (bsc#1012628).
- ARM: multi_v7_defconfig: Make NOP_USB_XCEIV driver built-in
  (bsc#1012628).
- Documentation: Fix intiramfs script name (bsc#1012628).
- arm64: entry: fix KCOV suppression (bsc#1012628).
- perf inject: Close inject.output on exit (bsc#1012628).
- drm/i915/gvt: Clear d3_entered on elsp cmd submission
  (bsc#1012628).
- spi: spi-cadence-quadspi: Fix division by zero warning - try2
  (bsc#1012628).
- sfc: ensure correct number of XDP queues (bsc#1012628).
- skbuff: Fix build with SKB extensions disabled (bsc#1012628).
- commit b45358d
* Wed Jul 28 2021 mkubecek@suse.cz
- use 3.0 SPDX identifier in rpm License tags
  As requested by Maintenance, change rpm License tags from "GPL-2.0"
  (SPDX 2.0) to "GPL-2.0-only" (SPDX 3.0) so that their scripts do not have
  to adjust the tags with each maintenance update submission.
- commit f888e0b
* Wed Jul 28 2021 msuchanek@suse.de
- KVM: PPC: Book3S: Fix H_RTAS rets buffer overflow (bsc#1188838
  CVE-2021-37576).
- commit b53c0bd
* Mon Jul 26 2021 mkubecek@suse.cz
- Update to 5.14-rc3
- eliminated 1 patch:
  - patches.suse/seq_file-disallow-extremely-large-seq-buffer-allocat.patch
- update configs
  - SND_SOC_SSM2518=n (x86 and riscv64)
  - drop SND_SOC_ZX_AUD96P22
- commit ee7a475
* Sun Jul 25 2021 jslaby@suse.cz
- Linux 5.13.5 (bsc#1012628).
- mt76: mt7921: continue to probe driver when fw already
  downloaded (bsc#1012628).
- udp: properly flush normal packet at GRO time (bsc#1012628).
- udp: annotate data races around unix_sk(sk)->gso_size
  (bsc#1012628).
- firmware: arm_scmi: Avoid padding in sensor message structure
  (bsc#1012628).
- drm/panel: nt35510: Do not fail if DSI read fails (bsc#1012628).
- perf test bpf: Free obj_buf (bsc#1012628).
- bpf: Track subprog poke descriptors correctly and fix
  use-after-free (bsc#1012628).
- bpftool: Properly close va_list 'ap' by va_end() on error
  (bsc#1012628).
- tools: bpf: Fix error in 'make -C tools/ bpf_install'
  (bsc#1012628).
- tcp: call sk_wmem_schedule before sk_mem_charge in zerocopy path
  (bsc#1012628).
- ipv6: tcp: drop silly ICMPv6 packet too big messages
  (bsc#1012628).
- tcp: fix tcp_init_transfer() to not reset icsk_ca_initialized
  (bsc#1012628).
- tcp: annotate data races around tp->mtu_info (bsc#1012628).
- tcp: consistently disable header prediction for mptcp
  (bsc#1012628).
- ARM: dts: everest: Add phase corrections for eMMC (bsc#1012628).
- ARM: dts: tacoma: Add phase corrections for eMMC (bsc#1012628).
- ARM: dts: aspeed: Fix AST2600 machines line names (bsc#1012628).
- vboxsf: Add support for the atomic_open directory-inode op
  (bsc#1012628).
- vboxsf: Add vboxsf_[create|release]_sf_handle() helpers
  (bsc#1012628).
- vboxsf: Make vboxsf_dir_create() return the handle for the
  created file (bsc#1012628).
- vboxsf: Honor excl flag to the dir-inode create op
  (bsc#1012628).
- kbuild: do not suppress Kconfig prompts for silent build
  (bsc#1012628).
- dma-buf/sync_file: Don't leak fences on merge failure
  (bsc#1012628).
- net: fddi: fix UAF in fza_probe (bsc#1012628).
- net: dsa: properly check for the bridge_leave methods in
  dsa_switch_bridge_leave() (bsc#1012628).
- net: validate lwtstate->data before returning from
  skb_tunnel_info() (bsc#1012628).
- net: do not reuse skbuff allocated from skbuff_fclone_cache
  in the skb cache (bsc#1012628).
- net: send SYNACK packet with accepted fwmark (bsc#1012628).
- net: ti: fix UAF in tlan_remove_one (bsc#1012628).
- net: qcom/emac: fix UAF in emac_remove (bsc#1012628).
- net: moxa: fix UAF in moxart_mac_probe (bsc#1012628).
- net: ip_tunnel: fix mtu calculation for ETHER tunnel devices
  (bsc#1012628).
- net: bcmgenet: Ensure all TX/RX queues DMAs are disabled
  (bsc#1012628).
- net: netdevsim: use xso.real_dev instead of xso.dev in callback
  functions of struct xfrmdev_ops (bsc#1012628).
- net: marvell: always set skb_shared_info in
  mvneta_swbm_add_rx_fragment (bsc#1012628).
- net: bridge: sync fdb to new unicast-filtering ports
  (bsc#1012628).
- net/sched: act_ct: remove and free nf_table callbacks
  (bsc#1012628).
- vmxnet3: fix cksum offload issues for tunnels with non-default
  udp ports (bsc#1012628).
- netfilter: nf_tables: Fix dereference of null pointer flow
  (bsc#1012628).
- net/sched: act_ct: fix err check for nf_conntrack_confirm
  (bsc#1012628).
- netfilter: ctnetlink: suspicious RCU usage in
  ctnetlink_dump_helpinfo (bsc#1012628).
- net: ipv6: fix return value of ip6_skb_dst_mtu (bsc#1012628).
- net: dsa: mv88e6xxx: enable SerDes PCS register dump via
  ethtool -d on Topaz (bsc#1012628).
- net: dsa: mv88e6xxx: enable SerDes RX stats for Topaz
  (bsc#1012628).
- net: dsa: mv88e6xxx: enable devlink ATU hash param for Topaz
  (bsc#1012628).
- net: dsa: mv88e6xxx: enable .rmu_disable() on Topaz
  (bsc#1012628).
- net: dsa: mv88e6xxx: use correct .stats_set_histogram() on Topaz
  (bsc#1012628).
- net: dsa: mv88e6xxx: enable .port_set_policy() on Topaz
  (bsc#1012628).
- net: bcmgenet: ensure EXT_ENERGY_DET_MASK is clear
  (bsc#1012628).
- f2fs: Show casefolding support only when supported
  (bsc#1012628).
- mm/userfaultfd: fix uffd-wp special cases for fork()
  (bsc#1012628).
- mm/thp: simplify copying of huge zero page pmd when fork
  (bsc#1012628).
- Revert "mm/shmem: fix shmem_swapin() race with swapoff"
  (bsc#1012628).
- Revert "swap: fix do_swap_page() race with swapoff"
  (bsc#1012628).
- arm64: dts: marvell: armada-37xx: move firmware node to generic
  dtsi file (bsc#1012628).
- firmware: turris-mox-rwtm: add marvell,armada-3700-rwtm-firmware
  compatible string (bsc#1012628).
- cifs: prevent NULL deref in cifs_compose_mount_options()
  (bsc#1012628).
- s390: introduce proper type handling call_on_stack() macro
  (bsc#1012628).
- s390/traps: do not test MONITOR CALL without CONFIG_BUG
  (bsc#1012628).
- thermal/core/thermal_of: Stop zone device before unregistering
  it (bsc#1012628).
- perf/x86/intel/uncore: Clean up error handling path of iio
  mapping (bsc#1012628).
- sched/fair: Fix CFS bandwidth hrtimer expiry type (bsc#1012628).
- scsi: qedf: Add check to synchronize abort and flush
  (bsc#1012628).
- scsi: libfc: Fix array index out of bound exception
  (bsc#1012628).
- scsi: libsas: Add LUN number check in .slave_alloc callback
  (bsc#1012628).
- scsi: aic7xxx: Fix unintentional sign extension issue on left
  shift of u8 (bsc#1012628).
- rtc: max77686: Do not enforce (incorrect) interrupt trigger type
  (bsc#1012628).
- arch/arm64/boot/dts/marvell: fix NAND partitioning scheme
  (bsc#1012628).
- kbuild: mkcompile_h: consider timestamp if
  KBUILD_BUILD_TIMESTAMP is set (bsc#1012628).
- arm64: dts: qcom: sm8150: Disable Adreno and modem by default
  (bsc#1012628).
- arm64: dts: qcom: sm8250: Fix pcie2_lane unit address
  (bsc#1012628).
- thermal/drivers/sprd: Add missing of_node_put for loop iteration
  (bsc#1012628).
- thermal/drivers/imx_sc: Add missing of_node_put for loop
  iteration (bsc#1012628).
- thermal/drivers/rcar_gen3_thermal: Do not shadow
  rcar_gen3_ths_tj_1 (bsc#1012628).
- thermal/core: Correct function name
  thermal_zone_device_unregister() (bsc#1012628).
- arm64: dts: imx8: conn: fix enet clock setting (bsc#1012628).
- arm64: dts: imx8mq: assign PCIe clocks (bsc#1012628).
- arm64: dts: imx8mn-beacon-som: Assign PMIC clock (bsc#1012628).
- arm64: dts: ls208xa: remove bus-num from dspi node
  (bsc#1012628).
- arm64: dts: rockchip: Update RK3399 PCI host bridge window to
  32-bit address memory (bsc#1012628).
- firmware: tegra: bpmp: Fix Tegra234-only builds (bsc#1012628).
- soc/tegra: fuse: Fix Tegra234-only builds (bsc#1012628).
- ARM: OMAP2+: Block suspend for am3 and am4 if PM is not
  configured (bsc#1012628).
- arm64: dts: qcom: sc7180: Add wakeup delay for adau codec
  (bsc#1012628).
- ARM: dts: stm32: fix stpmic node for stm32mp1 boards
  (bsc#1012628).
- ARM: dts: stm32: Rename spi-flash/mx66l51235l@N to flash@N on
  DHCOM SoM (bsc#1012628).
- ARM: dts: stm32: Rename eth@N to ethernet@N on DHCOM SoM
  (bsc#1012628).
- ARM: dts: stm32: Drop unused linux,wakeup from touchscreen
  node on DHCOM SoM (bsc#1012628).
- ARM: dts: stm32: fix the Odyssey SoM eMMC VQMMC supply
  (bsc#1012628).
- ARM: dts: stm32: fix ltdc pinctrl on microdev2.0-of7
  (bsc#1012628).
- ARM: dts: stm32: move stmmac axi config in ethernet node on
  stm32mp15 (bsc#1012628).
- ARM: dts: stm32: fix i2c node name on stm32f746 to prevent
  warnings (bsc#1012628).
- ARM: dts: rockchip: fix supply properties in io-domains nodes
  (bsc#1012628).
- arm64: dts: juno: Update SCPI nodes as per the YAML schema
  (bsc#1012628).
- i3c: master: svc: drop free_irq of devm_request_irq allocated
  irq (bsc#1012628).
- ARM: dts: bcm283x: Fix up GPIO LED node names (bsc#1012628).
- ARM: dts: bcm283x: Fix up MMC node names (bsc#1012628).
- ARM: dts: aspeed: Everest: Fix cable card PCA chips
  (bsc#1012628).
- firmware: arm_scmi: Fix the build when CONFIG_MAILBOX is not
  selected (bsc#1012628).
- firmware: arm_scmi: Add SMCCC discovery dependency in Kconfig
  (bsc#1012628).
- memory: tegra: Fix compilation warnings on 64bit platforms
  (bsc#1012628).
- ARM: dts: stm32: fix timer nodes on STM32 MCU to prevent
  warnings (bsc#1012628).
- ARM: dts: stm32: fix RCC node name on stm32f429 MCU
  (bsc#1012628).
- ARM: dts: stm32: fix gpio-keys node on STM32 MCU boards
  (bsc#1012628).
- ARM: dts: stm32: fix stm32mp157c-odyssey card detect pin
  (bsc#1012628).
- ARM: dts: stm32: Fix touchscreen node on dhcom-pdk2
  (bsc#1012628).
- ARM: dts: stm32: Remove extra size-cells on dhcom-pdk2
  (bsc#1012628).
- arm64: dts: qcom: sc7180: Move rmtfs memory region
  (bsc#1012628).
- arm64: dts: qcom: sm8250: fix display nodes (bsc#1012628).
- arm64: dts: qcom: sm8350: fix the node unit addresses
  (bsc#1012628).
- ARM: tegra: nexus7: Correct 3v3 regulator GPIO of PM269 variant
  (bsc#1012628).
- ARM: tegra: wm8903: Fix polarity of headphones-detection GPIO
  in device-trees (bsc#1012628).
- arm64: dts: ti: k3-am654x/j721e/j7200-common-proc-board:
  Fix MCU_RGMII1_TXC direction (bsc#1012628).
- arm64: tegra: Add PMU node for Tegra194 (bsc#1012628).
- ARM: dts: OMAP2+: Replace underscores in sub-mailbox node names
  (bsc#1012628).
- ARM: dts: am335x: fix ti,no-reset-on-init flag for gpios
  (bsc#1012628).
- ARM: dts: am437x-gp-evm: fix ti,no-reset-on-init flag for gpios
  (bsc#1012628).
- ARM: dts: am57xx-cl-som-am57x: fix ti,no-reset-on-init flag
  for gpios (bsc#1012628).
- kbuild: sink stdout from cmd for silent build (bsc#1012628).
- arm64: dts: renesas: beacon: Fix USB ref clock references
  (bsc#1012628).
- arm64: dts: renesas: beacon: Fix USB extal reference
  (bsc#1012628).
- rtc: mxc_v2: add missing MODULE_DEVICE_TABLE (bsc#1012628).
- ARM: dts: ux500: Fix orientation of Janice accelerometer
  (bsc#1012628).
- ARM: dts: imx6dl-riotboard: configure PHY clock and set proper
  EEE value (bsc#1012628).
- ARM: dts: ux500: Fix some compatible strings (bsc#1012628).
- ARM: dts: ux500: Fix orientation of accelerometer (bsc#1012628).
- ARM: dts: ux500: Rename gpio-controller node (bsc#1012628).
- ARM: dts: ux500: Fix interrupt cells (bsc#1012628).
- arm64: dts: rockchip: fix regulator-gpio states array
  (bsc#1012628).
- ARM: imx: pm-imx5: Fix references to imx5_cpu_suspend_info
  (bsc#1012628).
- ARM: dts: imx6: phyFLEX: Fix UART hardware flow control
  (bsc#1012628).
- soc: mediatek: add missing MODULE_DEVICE_TABLE (bsc#1012628).
- soc: bcm: brcmstb: remove unused variable
  'brcmstb_machine_match' (bsc#1012628).
- ARM: dts: BCM5301X: Fix pinmux subnodes names (bsc#1012628).
- ARM: dts: Hurricane 2: Fix NAND nodes names (bsc#1012628).
- ARM: dts: BCM63xx: Fix NAND nodes names (bsc#1012628).
- ARM: NSP: dts: fix NAND nodes names (bsc#1012628).
- ARM: Cygnus: dts: fix NAND nodes names (bsc#1012628).
- ARM: brcmstb: dts: fix NAND nodes names (bsc#1012628).
- ARM: dts: BCM5301X: Fix NAND nodes names (bsc#1012628).
- reset: ti-syscon: fix to_ti_syscon_reset_data macro
  (bsc#1012628).
- arm64: dts: rockchip: Fix power-controller node names for rk3399
  (bsc#1012628).
- arm64: dts: rockchip: Fix power-controller node names for rk3328
  (bsc#1012628).
- arm64: dts: rockchip: Fix power-controller node names for px30
  (bsc#1012628).
- ARM: dts: rockchip: Fix power-controller node names for rk3288
  (bsc#1012628).
- ARM: dts: rockchip: Fix power-controller node names for rk3188
  (bsc#1012628).
- ARM: dts: rockchip: Fix power-controller node names for rk3066a
  (bsc#1012628).
- ARM: dts: rockchip: Fix IOMMU nodes properties on rk322x
  (bsc#1012628).
- ARM: dts: rockchip: Fix the timer clocks order (bsc#1012628).
- arm64: dts: rockchip: fix pinctrl sleep nodename for rk3399.dtsi
  (bsc#1012628).
- arm64: dts: rockchip: Use only supported PCIe link speed on
  rk3399 (bsc#1012628).
- ARM: dts: rockchip: fix pinctrl sleep nodename for rk3036-kylin
  and rk3288 (bsc#1012628).
- ARM: dts: rockchip: Fix thermal sensor cells o rk322x
  (bsc#1012628).
- ARM: dts: gemini: add device_type on pci (bsc#1012628).
- ARM: dts: gemini: rename mdio to the right name (bsc#1012628).
- commit d9d5075
* Fri Jul 23 2021 tiwai@suse.de
- r8152: Fix a deadlock by doubly PM resume (bsc#1186194).
- r8152: Fix potential PM refcount imbalance (bsc#1186194).
- commit f6cd057
* Thu Jul 22 2021 jslaby@suse.cz
- Update
  patches.kernel.org/5.13.4-350-seq_file-disallow-extremely-large-seq-buffer-a.patch
  (bsc#1012628 CVE-2021-33909 bsc#1188062).
  Add CVE.
- commit d57f3b6
* Wed Jul 21 2021 mkubecek@suse.cz
- seq_file: disallow extremely large seq buffer allocations
  (CVE-2021-33909 bsc#1188062).
- commit 060b3df
* Wed Jul 21 2021 tiwai@suse.de
- Revert "usb: renesas-xhci: Fix handling of unknown ROM state"
  (bsc#1188485, bsc#1188515).
- commit 871d0f3
* Tue Jul 20 2021 jslaby@suse.cz
- Linux 5.13.4 (bsc#1012628).
- seq_file: disallow extremely large seq buffer allocations
  (bsc#1012628).
- misc: alcor_pci: fix inverted branch condition (bsc#1012628).
- scsi: scsi_dh_alua: Fix signedness bug in alua_rtpg()
  (bsc#1012628).
- cpufreq: CPPC: Fix potential memleak in cppc_cpufreq_cpu_init
  (bsc#1012628).
- perf tools: Fix pattern matching for same substring in different
  PMU type (bsc#1012628).
- MIPS: vdso: Invalid GIC access through VDSO (bsc#1012628).
- s390/irq: remove HAVE_IRQ_EXIT_ON_IRQ_STACK (bsc#1012628).
- perf script python: Fix buffer size to report iregs in perf
  script (bsc#1012628).
- mips: disable branch profiling in boot/decompress.o
  (bsc#1012628).
- mips: always link byteswap helpers into decompressor
  (bsc#1012628).
- kprobe/static_call: Restore missing static_call_text_reserved()
  (bsc#1012628).
- static_call: Fix static_call_text_reserved() vs __init
  (bsc#1012628).
- jump_label: Fix jump_label_text_reserved() vs __init
  (bsc#1012628).
- sched/uclamp: Ignore max aggregation if rq is idle
  (bsc#1012628).
- scsi: be2iscsi: Fix an error handling path in
  beiscsi_dev_probe() (bsc#1012628).
- arm64: dts: rockchip: Re-add regulator-always-on for vcc_sdio
  for rk3399-roc-pc (bsc#1012628).
- arm64: dts: rockchip: Re-add regulator-boot-on,
  regulator-always-on for vdd_gpu on rk3399-roc-pc (bsc#1012628).
- firmware: turris-mox-rwtm: show message about HWRNG registration
  (bsc#1012628).
- firmware: turris-mox-rwtm: fail probing when firmware does
  not support hwrng (bsc#1012628).
- firmware: turris-mox-rwtm: report failures better (bsc#1012628).
- firmware: turris-mox-rwtm: fix reply status decoding function
  (bsc#1012628).
- kbuild: remove trailing slashes from $(KBUILD_EXTMOD)
  (bsc#1012628).
- thermal/drivers/rcar_gen3_thermal: Fix coefficient calculations
  (bsc#1012628).
- arm64: dts: ti: k3-am642-evm: align ti,pindir-d0-out-d1-in
  property with dt-shema (bsc#1012628).
- arm64: dts: ti: am65: align ti,pindir-d0-out-d1-in property
  with dt-shema (bsc#1012628).
- arm64: dts: ti: k3-am642-main: fix ports mac properties
  (bsc#1012628).
- ARM: dts: imx6q-dhcom: Add gpios pinctrl for i2c bus recovery
  (bsc#1012628).
- ARM: dts: imx6q-dhcom: Fix ethernet plugin detection problems
  (bsc#1012628).
- ARM: dts: imx6q-dhcom: Fix ethernet reset time properties
  (bsc#1012628).
- thermal/drivers/sprd: Add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- ARM: dts: am437x: align ti,pindir-d0-out-d1-in property with
  dt-shema (bsc#1012628).
- ARM: dts: am335x: align ti,pindir-d0-out-d1-in property with
  dt-shema (bsc#1012628).
- ARM: dts: dra7: Fix duplicate USB4 target module node
  (bsc#1012628).
- arm64: dts: allwinner: a64-sopine-baseboard: change RGMII mode
  to TXID (bsc#1012628).
- memory: fsl_ifc: fix leak of private memory on probe failure
  (bsc#1012628).
- memory: fsl_ifc: fix leak of IO mapping on probe failure
  (bsc#1012628).
- arm64: dts: ti: k3-j721e-common-proc-board: Re-name "link"
  name as "phy" (bsc#1012628).
- arm64: dts: ti: k3-j721e-common-proc-board: Use external clock
  for SERDES (bsc#1012628).
- arm64: dts: ti: k3-j721e-main: Fix external refclk input to
  SERDES (bsc#1012628).
- firmware: arm_scmi: Add delayed response status check
  (bsc#1012628).
- Revert "ARM: dts: bcm283x: increase dwc2's RX FIFO size"
  (bsc#1012628).
- arm64: dts: renesas: r8a779a0: Drop power-domains property
  from GIC node (bsc#1012628).
- reset: bail if try_module_get() fails (bsc#1012628).
- ARM: dts: BCM5301X: Fixup SPI binding (bsc#1012628).
- dt-bindings: i2c: at91: fix example for scl-gpios (bsc#1012628).
- firmware: arm_scmi: Reset Rx buffer to max size during async
  commands (bsc#1012628).
- soc: mtk-pm-domains: Fix the clock prepared issue (bsc#1012628).
- soc: mtk-pm-domains: do not register smi node as syscon
  (bsc#1012628).
- firmware: tegra: Fix error return code in tegra210_bpmp_init()
  (bsc#1012628).
- arm64: dts: qcom: sc7180: Fix sc7180-qmp-usb3-dp-phy reg sizes
  (bsc#1012628).
- arm64: dts: qcom: c630: Add no-hpd to DSI bridge node
  (bsc#1012628).
- arm64: dts: qcom: trogdor: Add no-hpd to DSI bridge node
  (bsc#1012628).
- ARM: dts: stm32: Rework LAN8710Ai PHY reset on DHCOM SoM
  (bsc#1012628).
- arm64: dts: renesas: r8a7796[01]: Fix OPP table entry voltages
  (bsc#1012628).
- arm64: dts: renesas: Add missing opp-suspend properties
  (bsc#1012628).
- ARM: dts: qcom: sdx55-telit: Represent secure-regions as 64-bit
  elements (bsc#1012628).
- ARM: dts: qcom: sdx55-t55: Represent secure-regions as 64-bit
  elements (bsc#1012628).
- arm64: dts: ti: j7200-main: Enable USB2 PHY RX sensitivity
  workaround (bsc#1012628).
- arm64: dts: ti: k3-j7200: Remove "#address-cells" property
  from GPIO DT nodes (bsc#1012628).
- arm64: dts: ti: k3-am64-mcu: Fix the compatible string in GPIO
  DT node (bsc#1012628).
- arm64: dts: qcom: sdm845-oneplus-common: guard rmtfs-mem
  (bsc#1012628).
- ARM: dts: r8a7779, marzen: Fix DU clock names (bsc#1012628).
- arm64: dts: renesas: v3msk: Fix memory size (bsc#1012628).
- rtc: fix snprintf() checking in is_rtc_hctosys() (bsc#1012628).
- rtc: bd70528: fix BD71815 watchdog dependency (bsc#1012628).
- ARM: dts: sun8i: h3: orangepi-plus: Fix ethernet phy-mode
  (bsc#1012628).
- memory: pl353: Fix error return code in pl353_smc_probe()
  (bsc#1012628).
- arm64: defconfig: Do not override the MTK_PMIC_WRAP symbol
  (bsc#1012628).
- reset: brcmstb: Add missing MODULE_DEVICE_TABLE (bsc#1012628).
- memory: atmel-ebi: add missing of_node_put for loop iteration
  (bsc#1012628).
- memory: stm32-fmc2-ebi: add missing of_node_put for loop
  iteration (bsc#1012628).
- ARM: dts: exynos: fix PWM LED max brightness on Odroid XU4
  (bsc#1012628).
- ARM: dts: exynos: fix PWM LED max brightness on Odroid HC1
  (bsc#1012628).
- ARM: dts: exynos: fix PWM LED max brightness on Odroid XU/XU3
  (bsc#1012628).
- ARM: exynos: add missing of_node_put for loop iteration
  (bsc#1012628).
- reset: a10sr: add missing of_match_table reference
  (bsc#1012628).
- reset: RESET_INTEL_GW should depend on X86 (bsc#1012628).
- Update config files.
- reset: RESET_BRCMSTB_RESCAL should depend on ARCH_BRCMSTB
  (bsc#1012628).
- Update config files.
- arm64: dts: rockchip: Drop fephy pinctrl from gmac2phy on
  rk3328 rock-pi-e (bsc#1012628).
- arm64: dts: rockchip: rename LED label for NanoPi R4S
  (bsc#1012628).
- ARM: dts: gemini-rut1xx: remove duplicate ethernet node
  (bsc#1012628).
- hexagon: use common DISCARDS macro (bsc#1012628).
- hexagon: handle {,SOFT}IRQENTRY_TEXT in linker script
  (bsc#1012628).
- NFSv4/pNFS: Don't call _nfs4_pnfs_v3_ds_connect multiple times
  (bsc#1012628).
- NFSv4/pnfs: Fix layoutget behaviour after invalidation
  (bsc#1012628).
- NFSv4/pnfs: Fix the layout barrier update (bsc#1012628).
- NFS: Fix fscache read from NFS after cache error (bsc#1012628).
- NFS: Ensure nfs_readpage returns promptly when internal error
  occurs (bsc#1012628).
- virtio-mem: don't read big block size in Sub Block Mode
  (bsc#1012628).
- vdpa/mlx5: Clear vq ready indication upon device reset
  (bsc#1012628).
- ALSA: isa: Fix error return code in snd_cmi8330_probe()
  (bsc#1012628).
- nfsd: fix NULL dereference in nfs3svc_encode_getaclres
  (bsc#1012628).
- NFSD: Prevent a possible oops in the nfs_dirent() tracepoint
  (bsc#1012628).
- nfsd: Reduce contention for the nfsd_file nf_rwsem
  (bsc#1012628).
- nfsd: move fsnotify on client creation outside spinlock
  (bsc#1012628).
- NFSD: Add nfsd_clid_confirmed tracepoint (bsc#1012628).
- powerpc/bpf: Fix detecting BPF atomic instructions
  (bsc#1012628).
- nvme-tcp: can't set sk_user_data without write_lock
  (bsc#1012628).
- virtio_net: move tx vq operation under tx queue lock
  (bsc#1012628).
- vdp/mlx5: Fix setting the correct dma_device (bsc#1012628).
- vdpa/mlx5: Fix possible failure in umem size calculation
  (bsc#1012628).
- vdpa/mlx5: Fix umem sizes assignments on VQ create
  (bsc#1012628).
- vp_vdpa: correct the return value when fail to map notification
  (bsc#1012628).
- io_uring: remove not needed PF_EXITING check (bsc#1012628).
- io_uring: inline __tctx_task_work() (bsc#1012628).
- io_uring: move creds from io-wq work to io_kiocb (bsc#1012628).
- io_uring: don't bounce submit_state cachelines (bsc#1012628).
- io_uring: shuffle rarely used ctx fields (bsc#1012628).
- io_uring: get rid of files in exit cancel (bsc#1012628).
- block: grab a device refcount in disk_uevent (bsc#1012628).
- arch_topology: Avoid use-after-free for scale_freq_data
  (bsc#1012628).
- PCI: tegra194: Fix tegra_pcie_ep_raise_msi_irq() ill-defined
  shift (bsc#1012628).
- f2fs: remove false alarm on iget failure during GC
  (bsc#1012628).
- nfs: update has_sec_mnt_opts after cloning lsm options from
  parent (bsc#1012628).
- pwm: imx1: Don't disable clocks at device remove time
  (bsc#1012628).
- PCI: intel-gw: Fix INTx enable (bsc#1012628).
- x86/fpu: Limit xstate copy size in xstateregs_set()
  (bsc#1012628).
- x86/fpu: Fix copy_xstate_to_kernel() gap handling (bsc#1012628).
- f2fs: fix to avoid adding tab before doc section (bsc#1012628).
- PCI: iproc: Support multi-MSI only on uniprocessor kernel
  (bsc#1012628).
- PCI: iproc: Fix multi-MSI base vector number allocation
  (bsc#1012628).
- ubifs: Set/Clear I_LINKABLE under i_lock for whiteout inode
  (bsc#1012628).
- nfs: fix acl memory leak of posix_acl_create() (bsc#1012628).
- SUNRPC: prevent port reuse on transports which don't request it
  (bsc#1012628).
- watchdog: jz4740: Fix return value check in jz4740_wdt_probe()
  (bsc#1012628).
- watchdog: aspeed: fix hardware timeout calculation
  (bsc#1012628).
- watchdog: keembay: Removed timeout update in the TO ISR
  (bsc#1012628).
- watchdog: keembay: Remove timeout update in the WDT start
  function (bsc#1012628).
- watchdog: keembay: Clear either the TO or TH interrupt bit
  (bsc#1012628).
- watchdog: keembay: Update pretimeout to zero in the TH ISR
  (bsc#1012628).
- watchdog: keembay: Upadate WDT pretimeout for every update in
  timeout (bsc#1012628).
- watchdog: keembay: Update WDT pre-timeout during the
  initialization (bsc#1012628).
- ubifs: journal: Fix error return code in ubifs_jnl_write_inode()
  (bsc#1012628).
- um: fix error return code in winch_tramp() (bsc#1012628).
- um: fix error return code in slip_open() (bsc#1012628).
- um: Fix stack pointer alignment (bsc#1012628).
- sunrpc: Avoid a KASAN slab-out-of-bounds bug in
  xdr_set_page_base() (bsc#1012628).
- NFSv4: Fix an Oops in pnfs_mark_request_commit() when doing
  O_DIRECT (bsc#1012628).
- NFSv4: Initialise connection to the server in
  nfs4_alloc_client() (bsc#1012628).
- power: supply: rt5033_battery: Fix device tree enumeration
  (bsc#1012628).
- Update config files.
- PCI/sysfs: Fix dsm_label_utf16s_to_utf8s() buffer overrun
  (bsc#1012628).
- power: supply: surface-charger: Fix type of integer variable
  (bsc#1012628).
- remoteproc: k3-r5: Fix an error message (bsc#1012628).
- remoteproc: stm32: fix phys_addr_t format string (bsc#1012628).
- f2fs: compress: fix to disallow temp extension (bsc#1012628).
- f2fs: add MODULE_SOFTDEP to ensure crc32 is included in the
  initramfs (bsc#1012628).
- module: correctly exit module_kallsyms_on_each_symbol when fn()
  != 0 (bsc#1012628).
- pwm: visconti: Fix and simplify period calculation
  (bsc#1012628).
- cpufreq: scmi: Fix an error message (bsc#1012628).
- x86/signal: Detect and prevent an alternate signal stack
  overflow (bsc#1012628).
- NFSD: Fix TP_printk() format specifier in nfsd_clid_class
  (bsc#1012628).
- f2fs: atgc: fix to set default age threshold (bsc#1012628).
- power: supply: surface_battery: Fix battery event handling
  (bsc#1012628).
- block: fix the problem of io_ticks becoming smaller
  (bsc#1012628).
- virtio_console: Assure used length from device is limited
  (bsc#1012628).
- virtio_net: Fix error handling in virtnet_restore()
  (bsc#1012628).
- virtio-blk: Fix memory leak among suspend/resume procedure
  (bsc#1012628).
- ext4: fix WARN_ON_ONCE(!buffer_uptodate) after an error writing
  the superblock (bsc#1012628).
- PCI: rockchip: Register IRQ handlers after device and data
  are ready (bsc#1012628).
- ACPI: video: Add quirk for the Dell Vostro 3350 (bsc#1012628).
- ACPI: AMBA: Fix resource name in /proc/iomem (bsc#1012628).
- pwm: tegra: Don't modify HW state in .remove callback
  (bsc#1012628).
- pwm: img: Fix PM reference leak in img_pwm_enable()
  (bsc#1012628).
- drm/amdkfd: fix sysfs kobj leak (bsc#1012628).
- drm/amdgpu: fix Navi1x tcp power gating hang when issuing
  lightweight invalidaiton (bsc#1012628).
- power: supply: axp288_fuel_gauge: Make "T3 MRD" no_battery_list
  DMI entry more generic (bsc#1012628).
- power: supply: ab8500: add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- power: supply: charger-manager: add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- power: reset: regulator-poweroff: add missing
  MODULE_DEVICE_TABLE (bsc#1012628).
- NFS: nfs_find_open_context() may only select open files
  (bsc#1012628).
- drm/gma500: Add the missed drm_gem_object_put() in
  psb_user_framebuffer_create() (bsc#1012628).
- ceph: remove bogus checks and WARN_ONs from ceph_set_page_dirty
  (bsc#1012628).
- orangefs: fix orangefs df output (bsc#1012628).
- NFSv4: Fix handling of non-atomic change attrbute updates
  (bsc#1012628).
- NFS: Fix up inode attribute revalidation timeouts (bsc#1012628).
- PCI: tegra: Add missing MODULE_DEVICE_TABLE (bsc#1012628).
- remoteproc: stm32: fix mbox_send_message call (bsc#1012628).
- remoteproc: core: Fix cdev remove and rproc del (bsc#1012628).
- x86/fpu: Return proper error codes from user access functions
  (bsc#1012628).
- PCI: mediatek-gen3: Add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- fuse: fix illegal access to inode with reused nodeid
  (bsc#1012628).
- virtiofs: propagate sync() to file server (bsc#1012628).
- watchdog: iTCO_wdt: Account for rebooting on second timeout
  (bsc#1012628).
- watchdog: imx_sc_wdt: fix pretimeout (bsc#1012628).
- watchdog: Fix possible use-after-free by calling
  del_timer_sync() (bsc#1012628).
- watchdog: sc520_wdt: Fix possible use-after-free in
  wdt_turnoff() (bsc#1012628).
- watchdog: Fix possible use-after-free in wdt_startup()
  (bsc#1012628).
- PCI: Dynamically map ECAM regions (bsc#1012628).
- PCI: pciehp: Ignore Link Down/Up caused by DPC (bsc#1012628).
- NFSv4: Fix delegation return in cases where we have to retry
  (bsc#1012628).
- PCI/P2PDMA: Avoid pci_get_slot(), which may sleep (bsc#1012628).
- ARM: 9087/1: kprobes: test-thumb: fix for LLVM_IAS=1
  (bsc#1012628).
- power: reset: gpio-poweroff: add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- power: supply: max17040: Do not enforce (incorrect) interrupt
  trigger type (bsc#1012628).
- power: supply: max17042: Do not enforce (incorrect) interrupt
  trigger type (bsc#1012628).
- pwm: pca9685: Restrict period change for enabled PWMs
  (bsc#1012628).
- PCI: hv: Fix a race condition when removing the device
  (bsc#1012628).
- power: supply: ab8500: Enable USB and AC (bsc#1012628).
- power: supply: ab8500: Avoid NULL pointers (bsc#1012628).
- power: supply: ab8500: Move to componentized binding
  (bsc#1012628).
- PCI: ftpci100: Rename macro name collision (bsc#1012628).
- pwm: spear: Don't modify HW state in .remove callback
  (bsc#1012628).
- power: supply: sc2731_charger: Add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- power: supply: sc27xx: Add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- kcov: add __no_sanitize_coverage to fix noinstr for all
  architectures (bsc#1012628).
- lib/decompress_unlz4.c: correctly handle zero-padding around
  initrds (bsc#1012628).
- phy: intel: Fix for warnings due to EMMC clock 175Mhz change
  in FIP (bsc#1012628).
- i2c: core: Disable client irq on reboot/shutdown (bsc#1012628).
- intel_th: Wait until port is in reset before programming it
  (bsc#1012628).
- staging: rtl8723bs: fix check allowing 5Ghz settings
  (bsc#1012628).
- staging: rtl8723bs: fix macro value for 2.4Ghz only device
  (bsc#1012628).
- leds: turris-omnia: add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- ALSA: firewire-motu: fix detection for S/PDIF source on optical
  interface in v2 protocol (bsc#1012628).
- ALSA: usb-audio: scarlett2: Fix 6i6 Gen 2 line out descriptions
  (bsc#1012628).
- ALSA: hda: Add IRQ check for platform_get_irq() (bsc#1012628).
- backlight: lm3630a: Fix return code of .update_status() callback
  (bsc#1012628).
- ASoC: Intel: kbl_da7219_max98357a: shrink platform_id below
  20 characters (bsc#1012628).
- ASoC: fsl_xcvr: check return value after calling
  platform_get_resource_byname() (bsc#1012628).
- powerpc/boot: Fixup device-tree on little endian (bsc#1012628).
- usb: gadget: hid: fix error return code in hid_bind()
  (bsc#1012628).
- usb: gadget: f_hid: fix endianness issue with descriptors
  (bsc#1012628).
- ALSA: usb-audio: scarlett2: Fix scarlett2_*_ctl_put() return
  values (bsc#1012628).
- ALSA: usb-audio: scarlett2: Fix data_mutex lock (bsc#1012628).
- ALSA: usb-audio: scarlett2: Fix 18i8 Gen 2 PCM Input count
  (bsc#1012628).
- m68knommu: fix missing LCD splash screen data initializer
  (bsc#1012628).
- ALSA: bebob: add support for ToneWeal FW66 (bsc#1012628).
- Input: hideep - fix the uninitialized use in hideep_nvm_unlock()
  (bsc#1012628).
- s390/mem_detect: fix tprot() program check new psw handling
  (bsc#1012628).
- s390/mem_detect: fix diag260() program check new psw handling
  (bsc#1012628).
- s390/ipl_parm: fix program check new psw handling (bsc#1012628).
- s390/processor: always inline stap() and __load_psw_mask()
  (bsc#1012628).
- habanalabs/gaudi: set the correct rc in case of err
  (bsc#1012628).
- habanalabs: remove node from list before freeing the node
  (bsc#1012628).
- habanalabs: set rc as 'valid' in case of intentional func exit
  (bsc#1012628).
- habanalabs: fix mask to obtain page offset (bsc#1012628).
- habanalabs/gaudi: set the correct cpu_id on MME2_QM failure
  (bsc#1012628).
- habanalabs: check if asic secured with asic type (bsc#1012628).
- xhci: handle failed buffer copy to URB sg list and fix a W=1
  copiler warning (bsc#1012628).
- ASoC: soc-core: Fix the error return code in
  snd_soc_of_parse_audio_routing() (bsc#1012628).
- powerpc/mm/book3s64: Fix possible build error (bsc#1012628).
- gpio: pca953x: Add support for the On Semi pca9655
  (bsc#1012628).
- selftests/powerpc: Fix "no_handler" EBB selftest (bsc#1012628).
- ALSA: ppc: fix error return code in snd_pmac_probe()
  (bsc#1012628).
- scsi: storvsc: Correctly handle multiple flags in srb_status
  (bsc#1012628).
- powerpc/inst: Fix sparse detection on get_user_instr()
  (bsc#1012628).
- thunderbolt: Fix DROM handling for USB4 DROM (bsc#1012628).
- gpio: zynq: Check return value of irq_get_irq_data
  (bsc#1012628).
- gpio: zynq: Check return value of pm_runtime_get_sync
  (bsc#1012628).
- ASoC: soc-pcm: fix the return value in dpcm_apply_symmetry()
  (bsc#1012628).
- ALSA: control_led - fix initialization in the mode show callback
  (bsc#1012628).
- ALSA: n64: check return value after calling
  platform_get_resource() (bsc#1012628).
- iommu/arm-smmu: Fix arm_smmu_device refcount leak in address
  translation (bsc#1012628).
- iommu/arm-smmu: Fix arm_smmu_device refcount leak when
  arm_smmu_rpm_get fails (bsc#1012628).
- powerpc/ps3: Add dma_mask to ps3_dma_region (bsc#1012628).
- ALSA: sb: Fix potential double-free of CSP mixer elements
  (bsc#1012628).
- iommu/arm-smmu-qcom: Skip the TTBR1 quirk for db820c
  (bsc#1012628).
- selftests: timers: rtcpie: skip test if default RTC device
  does not exist (bsc#1012628).
- s390: disable SSP when needed (bsc#1012628).
- s390/sclp_vt220: fix console name to match device (bsc#1012628).
- serial: tty: uartlite: fix console setup (bsc#1012628).
- fsi: Add missing MODULE_DEVICE_TABLE (bsc#1012628).
- iov_iter_advance(): use consistent semantics for move past
  the end (bsc#1012628).
- ASoC: img: Fix PM reference leak in img_i2s_in_probe()
  (bsc#1012628).
- mfd: cpcap: Fix cpcap dmamask not set warnings (bsc#1012628).
- mfd: da9052/stmpe: Add and modify MODULE_DEVICE_TABLE
  (bsc#1012628).
- scsi: qedi: Fix cleanup session block/unblock use (bsc#1012628).
- scsi: qedi: Fix TMF session block/unblock use (bsc#1012628).
- scsi: qedi: Fix race during abort timeouts (bsc#1012628).
- scsi: qedi: Fix null ref during abort handling (bsc#1012628).
- scsi: iscsi: Fix shost->max_id use (bsc#1012628).
- scsi: iscsi: Fix conn use after free during resets
  (bsc#1012628).
- scsi: iscsi: Add iscsi_cls_conn refcount helpers (bsc#1012628).
- scsi: megaraid_sas: Handle missing interrupts while re-enabling
  IRQs (bsc#1012628).
- scsi: megaraid_sas: Early detection of VD deletion through
  RaidMap update (bsc#1012628).
- scsi: megaraid_sas: Fix resource leak in case of probe failure
  (bsc#1012628).
- fs/jfs: Fix missing error code in lmLogInit() (bsc#1012628).
- scsi: scsi_dh_alua: Check for negative result value
  (bsc#1012628).
- scsi: core: Fixup calling convention for scsi_mode_sense()
  (bsc#1012628).
- scsi: mpt3sas: Fix deadlock while cancelling the running
  firmware event (bsc#1012628).
- tty: serial: 8250: serial_cs: Fix a memory leak in error
  handling path (bsc#1012628).
- ASoC: cs42l42: Fix 1536000 Bit Clock instability (bsc#1012628).
- ALSA: ac97: fix PM reference leak in ac97_bus_remove()
  (bsc#1012628).
- scsi: core: Cap scsi_host cmd_per_lun at can_queue
  (bsc#1012628).
- scsi: lpfc: Fix crash when lpfc_sli4_hba_setup() fails to
  initialize the SGLs (bsc#1012628).
- scsi: lpfc: Fix "Unexpected timeout" error in direct attach
  topology (bsc#1012628).
- scsi: hisi_sas: Propagate errors in interrupt_init_v1_hw()
  (bsc#1012628).
- scsi: arcmsr: Fix doorbell status being updated late on ARC-1886
  (bsc#1012628).
- w1: ds2438: fixing bug that would always get page0
  (bsc#1012628).
- ASoC: SOF: topology: fix assignment to use le32_to_cpu
  (bsc#1012628).
- usb: common: usb-conn-gpio: fix NULL pointer dereference of
  charger (bsc#1012628).
- Revert "ALSA: bebob/oxfw: fix Kconfig entry for Mackie d.2 Pro"
  (bsc#1012628).
- ALSA: usx2y: Don't call free_pages_exact() with NULL address
  (bsc#1012628).
- ALSA: usx2y: Avoid camelCase (bsc#1012628).
- iio: magn: bmc150: Balance runtime pm + use
  pm_runtime_resume_and_get() (bsc#1012628).
- iio: gyro: fxa21002c: Balance runtime pm + use
  pm_runtime_resume_and_get() (bsc#1012628).
- iio: imu: st_lsm6dsx: correct ODR in header (bsc#1012628).
- partitions: msdos: fix one-byte get_unaligned() (bsc#1012628).
- ASoC: intel/boards: add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- misc: alcor_pci: fix null-ptr-deref when there is no PCI bridge
  (bsc#1012628).
- misc/libmasm/module: Fix two use after free in ibmasm_init_one
  (bsc#1012628).
- serial: 8250: of: Check for CONFIG_SERIAL_8250_BCM7271
  (bsc#1012628).
- serial: fsl_lpuart: disable DMA for console and fix sysrq
  (bsc#1012628).
- tty: serial: fsl_lpuart: fix the potential risk of division
  or modulo by zero (bsc#1012628).
- usb: dwc3: pci: Fix DEFINE for Intel Elkhart Lake (bsc#1012628).
- soundwire: bus: handle -ENODATA errors in clock stop/start
  sequences (bsc#1012628).
- soundwire: bus: only use CLOCK_STOP_MODE0 and fix confusions
  (bsc#1012628).
- rcu: Reject RCU_LOCKDEP_WARN() false positives (bsc#1012628).
- srcu: Fix broken node geometry after early ssp init
  (bsc#1012628).
- scsi: arcmsr: Fix the wrong CDB payload report to IOP
  (bsc#1012628).
- dmaengine: fsl-qdma: check dma_set_mask return value
  (bsc#1012628).
- ASoC: Intel: sof_sdw: add mutual exclusion between PCH DMIC
  and RT715 (bsc#1012628).
- leds: tlc591xx: fix return value check in tlc591xx_probe()
  (bsc#1012628).
- net: bridge: multicast: fix MRD advertisement router port
  marking race (bsc#1012628).
- net: bridge: multicast: fix PIM hello router port marking race
  (bsc#1012628).
- drm/dp_mst: Add missing drm parameters to recently added call
  to drm_dbg_kms() (bsc#1012628).
- drm/dp_mst: Avoid to mess up payload table by ports in stale
  topology (bsc#1012628).
- drm/dp_mst: Do not set proposed vcpi directly (bsc#1012628).
- btrfs: zoned: fix wrong mutex unlock on failure to allocate
  log root tree (bsc#1012628).
- btrfs: don't block if we can't acquire the reclaim lock
  (bsc#1012628).
- btrfs: rework chunk allocation to avoid exhaustion of the
  system chunk array (bsc#1012628).
- btrfs: fix deadlock with concurrent chunk allocations involving
  system chunks (bsc#1012628).
- btrfs: zoned: fix types for u64 division in
  btrfs_reclaim_bgs_work (bsc#1012628).
- btrfs: properly split extent_map for REQ_OP_ZONE_APPEND
  (bsc#1012628).
- io_uring: use right task for exiting checks (bsc#1012628).
- arm64: Avoid premature usercopy failure (bsc#1012628).
- mm/hugetlb: fix refs calculation from unaligned @vaddr
  (bsc#1012628).
- EDAC/igen6: fix core dependency AGAIN (bsc#1012628).
- Update config files.
- fbmem: Do not delete the mode that is still in use
  (bsc#1012628).
- cgroup: verify that source is a string (bsc#1012628).
- drm/i915/gt: Fix -EDEADLK handling regression (bsc#1012628).
- drm/i915/gtt: drop the page table optimisation (bsc#1012628).
- drm/amdgpu: add another Renoir DID (bsc#1012628).
- tracing: Do not reference char * as a string in histograms
  (bsc#1012628).
- iommu/vt-d: Fix clearing real DMA device's scalable-mode
  context entries (bsc#1012628).
- iommu/vt-d: Global devTLB flush when present context entry
  changed (bsc#1012628).
- scsi: zfcp: Report port fc_security as unknown early during
  remote cable pull (bsc#1012628).
- scsi: core: Fix bad pointer dereference when ehandler kthread
  is invalid (bsc#1012628).
- KVM: SVM: remove INIT intercept handler (bsc#1012628).
- KVM: SVM: #SMI interception must not skip the instruction
  (bsc#1012628).
- KVM: X86: Disable hardware breakpoints unconditionally before
  kvm_x86->run() (bsc#1012628).
- KVM: nSVM: Check the value written to MSR_VM_HSAVE_PA
  (bsc#1012628).
- KVM: SVM: Revert clearing of C-bit on GPA in #NPF handler
  (bsc#1012628).
- KVM: x86/mmu: Do not apply HPA (memory encryption) mask to GPAs
  (bsc#1012628).
- KVM: x86: Use kernel's x86_phys_bits to handle reduced
  MAXPHYADDR (bsc#1012628).
- KVM: x86: Use guest MAXPHYADDR from CPUID.0x8000_0008 iff TDP
  is enabled (bsc#1012628).
- KVM: selftests: do not require 64GB in set_memory_region_test
  (bsc#1012628).
- KVM: mmio: Fix use-after-free Read in
  kvm_vm_ioctl_unregister_coalesced_mmio (bsc#1012628).
- cifs: Do not use the original cruid when following DFS links
  for multiuser mounts (bsc#1012628).
- cifs: handle reconnect of tcon when there is no cached dfs
  referral (bsc#1012628).
- cifs: use the expiry output of dns_query to schedule next
  resolution (bsc#1012628).
- commit da86d62
* Mon Jul 19 2021 dmueller@suse.com
- armv6hl/v7hl: temporarily disable FIPS to workaround crash (bsc#1188327)
- commit 91a0cca
* Mon Jul 19 2021 jslaby@suse.cz
- Linux 5.13.3 (bsc#1012628).
- f2fs: fix to avoid racing on fsync_entry_slab by multi
  filesystem instances (bsc#1012628).
- smackfs: restrict bytes count in smk_set_cipso() (bsc#1012628).
- media: v4l2-core: explicitly clear ioctl input data
  (bsc#1012628).
- jfs: fix GPF in diFree (bsc#1012628).
- ext4: fix possible UAF when remounting r/o a mmp-protected
  file system (bsc#1012628).
- drm/ast: Remove reference to struct drm_device.pdev
  (bsc#1012628).
- pinctrl: mcp23s08: Fix missing unlock on error in mcp23s08_irq()
  (bsc#1012628).
- dm writecache: write at least 4k when committing (bsc#1012628).
- media: uvcvideo: Fix pixel format change for Elgato Cam Link 4K
  (bsc#1012628).
- media: gspca/sunplus: fix zero-length control requests
  (bsc#1012628).
- media: gspca/sq905: fix control-request direction (bsc#1012628).
- media: ccs: Fix the op_pll_multiplier address (bsc#1012628).
- media: zr364xx: fix memory leak in zr364xx_start_readpipe
  (bsc#1012628).
- media: dtv5100: fix control-request directions (bsc#1012628).
- media: i2c: ccs-core: fix pm_runtime_get_sync() usage count
  (bsc#1012628).
- media: subdev: disallow ioctl for saa6588/davinci (bsc#1012628).
- PCI: aardvark: Implement workaround for the readback value of
  VEND_ID (bsc#1012628).
- PCI: aardvark: Fix checking for PIO Non-posted Request
  (bsc#1012628).
- PCI: Leave Apple Thunderbolt controllers on for s2idle or
  standby (bsc#1012628).
- dm btree remove: assign new_root only when removal succeeds
  (bsc#1012628).
- dm writecache: flush origin device when writing and cache is
  full (bsc#1012628).
- dm zoned: check zone capacity (bsc#1012628).
- coresight: tmc-etf: Fix global-out-of-bounds in
  tmc_update_etf_buffer() (bsc#1012628).
- coresight: Propagate symlink failure (bsc#1012628).
- ipack/carriers/tpci200: Fix a double free in tpci200_pci_probe
  (bsc#1012628).
- tracing: Resize tgid_map to pid_max, not PID_MAX_DEFAULT
  (bsc#1012628).
- tracing: Simplify & fix saved_tgids logic (bsc#1012628).
- rq-qos: fix missed wake-ups in rq_qos_throttle try two
  (bsc#1012628).
- seq_buf: Fix overflow in seq_buf_putmem_hex() (bsc#1012628).
- lkdtm: Enable DOUBLE_FAULT on all architectures (bsc#1012628).
- extcon: intel-mrfld: Sync hardware and software state on init
  (bsc#1012628).
- selftests/lkdtm: Fix expected text for CR4 pinning
  (bsc#1012628).
- lkdtm/bugs: XFAIL UNALIGNED_LOAD_STORE_WRITE (bsc#1012628).
- nvmem: core: add a missing of_node_put (bsc#1012628).
- mfd: syscon: Free the allocated name field of struct
  regmap_config (bsc#1012628).
- power: supply: ab8500: Fix an old bug (bsc#1012628).
- ubifs: Fix races between xattr_{set|get} and listxattr
  operations (bsc#1012628).
- thermal/drivers/int340x/processor_thermal: Fix tcc setting
  (bsc#1012628).
- ipmi/watchdog: Stop watchdog timer when the current action is
  'none' (bsc#1012628).
- qemu_fw_cfg: Make fw_cfg_rev_attr a proper kobj_attribute
  (bsc#1012628).
- i40e: fix PTP on 5Gb links (bsc#1012628).
- mwifiex: bring down link before deleting interface
  (bsc#1012628).
- ASoC: tegra: Set driver_name=tegra for all machine drivers
  (bsc#1012628).
- fpga: stratix10-soc: Add missing fpga_mgr_free() call
  (bsc#1012628).
- clocksource/arm_arch_timer: Improve Allwinner A64 timer
  workaround (bsc#1012628).
- cpu/hotplug: Cure the cpusets trainwreck (bsc#1012628).
- arm64: tlb: fix the TTL value of tlb_get_level (bsc#1012628).
- ata: ahci_sunxi: Disable DIPM (bsc#1012628).
- docs: Makefile: Use CONFIG_SHELL not SHELL (bsc#1012628).
- mmc: core: Allow UHS-I voltage switch for SDSC cards if
  supported (bsc#1012628).
- mmc: core: clear flags before allowing to retune (bsc#1012628).
- mmc: sdhci: Fix warning message when accessing RPMB in HS400
  mode (bsc#1012628).
- mmc: sdhci-acpi: Disable write protect detection on Toshiba
  Encore 2 WT8-B (bsc#1012628).
- drm/i915/display: Do not zero past infoframes.vsc (bsc#1012628).
- drm/ingenic: Switch IPU plane to type OVERLAY (bsc#1012628).
- drm/nouveau: Don't set allow_fb_modifiers explicitly
  (bsc#1012628).
- drm/arm/malidp: Always list modifiers (bsc#1012628).
- drm/msm/mdp4: Fix modifier support enabling (bsc#1012628).
- drm/tegra: Don't set allow_fb_modifiers explicitly
  (bsc#1012628).
- drm/ingenic: Fix pixclock rate for 24-bit serial panels
  (bsc#1012628).
- drm/amd/display: Reject non-zero src_y and src_x for video
  planes (bsc#1012628).
- pinctrl/amd: Add device HID for new AMD GPIO controller
  (bsc#1012628).
- drm/amd/display: fix incorrrect valid irq check (bsc#1012628).
- drm/rockchip: dsi: remove extra component_del() call
  (bsc#1012628).
- drm/dp: Handle zeroed port counts in
  drm_dp_read_downstream_info() (bsc#1012628).
- drm/vc4: hdmi: Prevent clock unbalance (bsc#1012628).
- drm/vc4: crtc: Skip the TXP (bsc#1012628).
- drm/vc4: txp: Properly set the possible_crtcs mask
  (bsc#1012628).
- drm/radeon: Call radeon_suspend_kms() in radeon_pci_shutdown()
  for Loongson64 (bsc#1012628).
- drm/radeon: Add the missed drm_gem_object_put() in
  radeon_user_framebuffer_create() (bsc#1012628).
- drm/amdgpu: fix the hang caused by PCIe link width switch
  (bsc#1012628).
- drm/amdgpu: fix NAK-G generation during PCI-e link width switch
  (bsc#1012628).
- drm/amdgpu: enable sdma0 tmz for Raven/Renoir(V2) (bsc#1012628).
- drm/amdgpu: Update NV SIMD-per-CU to 2 (bsc#1012628).
- drm/amdgpu: add new dimgrey cavefish DID (bsc#1012628).
- powerpc/powernv/vas: Release reference to tgid during window
  close (bsc#1012628).
- powerpc/barrier: Avoid collision with clang's __lwsync macro
  (bsc#1012628).
- powerpc/xive: Fix error handling when allocating an IPI
  (bsc#1012628).
- powerpc/bpf: Reject atomic ops in ppc32 JIT (bsc#1012628).
- powerpc/mm: Fix lockup on kernel exec fault (bsc#1012628).
- mm/mremap: hold the rmap lock in write mode when moving page
  table entries (bsc#1012628).
- MIPS: MT extensions are not available on MIPS32r1 (bsc#1012628).
- PCI: tegra194: Fix host initialization during resume
  (bsc#1012628).
- MIPS: CI20: Reduce clocksource to 750 kHz (bsc#1012628).
- MIPS: set mips32r5 for virt extensions (bsc#1012628).
- MIPS: loongsoon64: Reserve memory below starting pfn to prevent
  Oops (bsc#1012628).
- sctp: add size validation when walking chunks (bsc#1012628).
- sctp: validate from_addr_param return (bsc#1012628).
- flow_offload: action should not be NULL when it is referenced
  (bsc#1012628).
- bpf: Fix false positive kmemleak report in
  bpf_ringbuf_area_alloc() (bsc#1012628).
- sched/fair: Ensure _sum and _avg values stay consistent
  (bsc#1012628).
- Bluetooth: btusb: fix bt fiwmare downloading failure issue
  for qca btsoc (bsc#1012628).
- Bluetooth: btusb: use default nvm if boardID is 0 for wcn6855
  (bsc#1012628).
- Bluetooth: mgmt: Fix the command returns garbage parameter value
  (bsc#1012628).
- Bluetooth: btusb: Add support USB ALT 3 for WBS (bsc#1012628).
- Bluetooth: L2CAP: Fix invalid access on ECRED Connection
  response (bsc#1012628).
- Bluetooth: L2CAP: Fix invalid access if ECRED Reconfigure fails
  (bsc#1012628).
- Bluetooth: btusb: Add a new QCA_ROME device (0cf3:e500)
  (bsc#1012628).
- Bluetooth: Shutdown controller after workqueues are flushed
  or cancelled (bsc#1012628).
- Bluetooth: Fix alt settings for incoming SCO with transparent
  coding format (bsc#1012628).
- Bluetooth: Fix the HCI to MGMT status conversion table
  (bsc#1012628).
- Bluetooth: cmtp: fix file refcount when cmtp_attach_device fails
  (bsc#1012628).
- Bluetooth: btusb: Fixed too many in-token issue for Mediatek
  Chip (bsc#1012628).
- RDMA/cma: Fix rdma_resolve_route() memory leak (bsc#1012628).
- net: ip: avoid OOM kills with large UDP sends over loopback
  (bsc#1012628).
- net: retrieve netns cookie via getsocketopt (bsc#1012628).
- media, bpf: Do not copy more entries than user space requested
  (bsc#1012628).
- IB/isert: Align target max I/O size to initiator size
  (bsc#1012628).
- mac80211: Properly WARN on HW scan before restart (bsc#1012628).
- mac80211_hwsim: add concurrent channels scanning support over
  virtio (bsc#1012628).
- mac80211: consider per-CPU statistics if present (bsc#1012628).
- cfg80211: fix default HE tx bitrate mask in 2G band
  (bsc#1012628).
- wireless: wext-spy: Fix out-of-bounds warning (bsc#1012628).
- sfc: error code if SRIOV cannot be disabled (bsc#1012628).
- sfc: avoid double pci_remove of VFs (bsc#1012628).
- rtw88: add quirks to disable pci capabilities (bsc#1012628).
- rtw88: 8822c: update RF parameter tables to v62 (bsc#1012628).
- iwlwifi: pcie: fix context info freeing (bsc#1012628).
- iwlwifi: pcie: free IML DMA memory allocation (bsc#1012628).
- iwlwifi: mvm: fix error print when session protection ends
  (bsc#1012628).
- iwlwifi: mvm: apply RX diversity per PHY context (bsc#1012628).
- iwlwifi: mvm: don't change band on bound PHY contexts
  (bsc#1012628).
- RDMA/rxe: Don't overwrite errno from ib_umem_get()
  (bsc#1012628).
- drm/amd/display: Fix edp_bootup_bl_level initialization issue
  (bsc#1012628).
- vsock: notify server to shutdown when client has pending signal
  (bsc#1012628).
- atm: nicstar: register the interrupt handler in the right place
  (bsc#1012628).
- atm: nicstar: use 'dma_free_coherent' instead of 'kfree'
  (bsc#1012628).
- net: fec: add ndo_select_queue to fix TX bandwidth fluctuations
  (bsc#1012628).
- net: fec: add FEC_QUIRK_HAS_MULTI_QUEUES represents i.MX6SX
  ENET IP (bsc#1012628).
- MIPS: add PMD table accounting into MIPS'pmd_alloc_one
  (bsc#1012628).
- rtl8xxxu: Fix device info for RTL8192EU devices (bsc#1012628).
- mt76: fix iv and CCMP header insertion (bsc#1012628).
- mt76: mt7915: fix IEEE80211_HE_PHY_CAP7_MAX_NC for station mode
  (bsc#1012628).
- mt76: connac: fix the maximum interval schedule scan can support
  (bsc#1012628).
- mt76: connac: fix UC entry is being overwritten (bsc#1012628).
- mt76: mt7921: enable hw offloading for wep keys (bsc#1012628).
- mt76: mt7921: reset wfsys during hw probe (bsc#1012628).
- mt76: mt7921: fix reset under the deep sleep is enabled
  (bsc#1012628).
- mt76: mt7915: fix tssi indication field of DBDC NICs
  (bsc#1012628).
- drm/amdkfd: Walk through list with dqm lock hold (bsc#1012628).
- drm/amdgpu: fix bad address translation for sienna_cichlid
  (bsc#1012628).
- io_uring: fix false WARN_ONCE (bsc#1012628).
- net: sched: fix error return code in tcf_del_walker()
  (bsc#1012628).
- net: ipa: Add missing of_node_put() in ipa_firmware_load()
  (bsc#1012628).
- net: fix mistake path for netdev_features_strings (bsc#1012628).
- mt76: dma: use ieee80211_tx_status_ext to free packets when
  tx fails (bsc#1012628).
- mt76: mt7615: fix fixed-rate tx status reporting (bsc#1012628).
- ice: mark PTYPE 2 as reserved (bsc#1012628).
- ice: fix incorrect payload indicator on PTYPE (bsc#1012628).
- ext4: fix memory leak in ext4_fill_super (bsc#1012628).
- bpf: Fix up register-based shifts in interpreter to silence
  KUBSAN (bsc#1012628).
- net: hsr: don't check sequence number if tag removal is
  offloaded (bsc#1012628).
- drm/amdkfd: Fix circular lock in nocpsch path (bsc#1012628).
- drm/amdkfd: fix circular locking on get_wave_state
  (bsc#1012628).
- cw1200: add missing MODULE_DEVICE_TABLE (bsc#1012628).
- wl1251: Fix possible buffer overflow in wl1251_cmd_scan
  (bsc#1012628).
- net: phy: nxp-c45-tja11xx: enable MDIO write access to the
  master/slave registers (bsc#1012628).
- wlcore/wl12xx: Fix wl12xx get_mac error if device is in ELP
  (bsc#1012628).
- dm writecache: commit just one block, not a full page
  (bsc#1012628).
- xfrm: Fix error reporting in xfrm_state_construct (bsc#1012628).
- ibmvnic: fix kernel build warnings in build_hdr_descs_arr
  (bsc#1012628).
- drm/amd/display: Verify Gamma & Degamma LUT sizes in
  amdgpu_dm_atomic_check (bsc#1012628).
- r8169: avoid link-up interrupt issue on RTL8106e if user
  enables ASPM (bsc#1012628).
- selinux: use __GFP_NOWARN with GFP_NOWAIT in the AVC
  (bsc#1012628).
- net: mido: mdio-mux-bcm-iproc: Use
  devm_platform_get_and_ioremap_resource() (bsc#1012628).
- fjes: check return value after calling platform_get_resource()
  (bsc#1012628).
- drm/amdkfd: use allowed domain for vmbo validation
  (bsc#1012628).
- net: sgi: ioc3-eth: check return value after calling
  platform_get_resource() (bsc#1012628).
- selftests: Clean forgotten resources as part of cleanup()
  (bsc#1012628).
- net: phy: realtek: add delay to fix RXC generation issue
  (bsc#1012628).
- drm/amd/display: Fix crash during MPO + ODM combine mode
  recalculation (bsc#1012628).
- drm/amd/display: Fix off-by-one error in DML (bsc#1012628).
- drm/amd/display: Set DISPCLK_MAX_ERRDET_CYCLES to 7
  (bsc#1012628).
- drm/amd/display: Release MST resources on switch from MST to
  SST (bsc#1012628).
- drm/amd/display: Update scaling settings on modeset
  (bsc#1012628).
- drm/amd/display: Revert "Fix clock table filling logic"
  (bsc#1012628).
- drm/amd/display: Fix DCN 3.01 DSCCLK validation (bsc#1012628).
- net: moxa: Use devm_platform_get_and_ioremap_resource()
  (bsc#1012628).
- net: micrel: check return value after calling
  platform_get_resource() (bsc#1012628).
- net: mvpp2: check return value after calling
  platform_get_resource() (bsc#1012628).
- net: bcmgenet: check return value after calling
  platform_get_resource() (bsc#1012628).
- net: mscc: ocelot: check return value after calling
  platform_get_resource() (bsc#1012628).
- virtio_net: Remove BUG() to avoid machine dead (bsc#1012628).
- ice: fix clang warning regarding deadcode.DeadStores
  (bsc#1012628).
- ice: set the value of global config lock timeout longer
  (bsc#1012628).
- pinctrl: mcp23s08: fix race condition in irq handler
  (bsc#1012628).
- net: bridge: mrp: Update ring transitions (bsc#1012628).
- block: introduce BIO_ZONE_WRITE_LOCKED bio flag (bsc#1012628).
- dm: Fix dm_accept_partial_bio() relative to zone management
  commands (bsc#1012628).
- dm writecache: don't split bios when overwriting contiguous
  cache content (bsc#1012628).
- dm space maps: don't reset space map allocation cursor when
  committing (bsc#1012628).
- RDMA/cxgb4: Fix missing error code in create_qp() (bsc#1012628).
- icmp: fix lib conflict with trinity (bsc#1012628).
- net: tcp better handling of reordering then loss cases
  (bsc#1012628).
- clk: tegra: tegra124-emc: Fix clock imbalance in
  emc_set_timing() (bsc#1012628).
- drm/amdgpu: remove unsafe optimization to drop preamble ib
  (bsc#1012628).
- drm/amd/display: Avoid HDCP over-read and corruption
  (bsc#1012628).
- drm/amdgpu: fix sdma firmware version error in sriov
  (bsc#1012628).
- drm/amdgpu: fix metadata_size for ubo ioctl queries
  (bsc#1012628).
- MIPS: ingenic: Select CPU_SUPPORTS_CPUFREQ &&
  MIPS_EXTERNAL_TIMER (bsc#1012628).
- MIPS: cpu-probe: Fix FPU detection on Ingenic JZ4760(B)
  (bsc#1012628).
- ipv6: use prandom_u32() for ID generation (bsc#1012628).
- virtio-net: Add validation for used length (bsc#1012628).
- drm: bridge: cdns-mhdp8546: Fix PM reference leak in
  (bsc#1012628).
- clk: tegra: Ensure that PLLU configuration is applied properly
  (bsc#1012628).
- clk: tegra: Fix refcounting of gate clocks (bsc#1012628).
- drm/tegra: hub: Fix YUV support (bsc#1012628).
- RDMA/rtrs: Change MAX_SESS_QUEUE_DEPTH (bsc#1012628).
- net: stmmac: the XPCS obscures a potential "PHY not found"
  error (bsc#1012628).
- drm: rockchip: add missing registers for RK3066 (bsc#1012628).
- drm: rockchip: add missing registers for RK3188 (bsc#1012628).
- net/mlx5: Fix lag port remapping logic (bsc#1012628).
- net/mlx5e: IPsec/rep_tc: Fix rep_tc_update_skb drops IPsec
  packet (bsc#1012628).
- drm/amdgpu/swsmu/aldebaran: fix check in is_dpm_running
  (bsc#1012628).
- drm/amd/display: fix odm scaling (bsc#1012628).
- clk: renesas: r8a77995: Add ZA2 clock (bsc#1012628).
- drm/bridge: cdns: Fix PM reference leak in cdns_dsi_transfer()
  (bsc#1012628).
- igb: fix assignment on big endian machines (bsc#1012628).
- igb: handle vlan types with checker enabled (bsc#1012628).
- e100: handle eeprom as little endian (bsc#1012628).
- drm/vc4: hdmi: Fix PM reference leak in
  vc4_hdmi_encoder_pre_crtc_co() (bsc#1012628).
- drm/vc4: Fix clock source for VEC PixelValve on BCM2711
  (bsc#1012628).
- drm/amd/pm: fix return value in aldebaran_set_mp1_state()
  (bsc#1012628).
- net: xilinx_emaclite: Do not print real IOMEM pointer
  (bsc#1012628).
- udf: Fix NULL pointer dereference in udf_symlink function
  (bsc#1012628).
- drm/sched: Avoid data corruptions (bsc#1012628).
- drm/scheduler: Fix hang when sched_entity released
  (bsc#1012628).
- pinctrl: equilibrium: Add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- net: ethernet: ixp4xx: Fix return value check in
  ixp4xx_eth_probe() (bsc#1012628).
- net/sched: cls_api: increase max_reclassify_loop (bsc#1012628).
- net: mdio: provide shim implementation of
  devm_of_mdiobus_register (bsc#1012628).
- drm/virtio: Fix double free on probe failure (bsc#1012628).
- reiserfs: add check for invalid 1st journal block (bsc#1012628).
- drm/bridge: lt9611: Add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- net: mdio: ipq8064: add regmap config to disable REGCACHE
  (bsc#1012628).
- drm/panfrost: devfreq: Disable devfreq when num_supplies > 1
  (bsc#1012628).
- drm/mediatek: Fix PM reference leak in mtk_crtc_ddp_hw_init()
  (bsc#1012628).
- net: Treat __napi_schedule_irqoff() as __napi_schedule()
  on PREEMPT_RT (bsc#1012628).
- atm: nicstar: Fix possible use-after-free in nicstar_cleanup()
  (bsc#1012628).
- mISDN: fix possible use-after-free in HFC_cleanup()
  (bsc#1012628).
- atm: iphase: fix possible use-after-free in ia_module_exit()
  (bsc#1012628).
- hugetlb: clear huge pte during flush function on mips platform
  (bsc#1012628).
- MIPS: Loongson64: Fix build error 'secondary_kexec_args'
  undeclared under !SMP (bsc#1012628).
- clk: renesas: rcar-usb2-clock-sel: Fix error handling in
  .probe() (bsc#1012628).
- drm/amd/display: fix use_max_lb flag for 420 pixel formats
  (bsc#1012628).
- drm/amd/display: Fix clock table filling logic (bsc#1012628).
- drm/amdgpu: change the default timeout for kernel compute queues
  (bsc#1012628).
- net: pch_gbe: Use proper accessors to BE data in pch_ptp_match()
  (bsc#1012628).
- drm/imx: Add 8 pixel alignment fix (bsc#1012628).
- drm/bridge: nwl-dsi: Force a full modeset when
  crtc_state->active is changed to be true (bsc#1012628).
- drm/vc4: fix argument ordering in vc4_crtc_get_margins()
  (bsc#1012628).
- drm/amd/amdgpu/sriov disable all ip hw status by default
  (bsc#1012628).
- drm/amd/display: Fix BSOD with NULL check (bsc#1012628).
- drm/amd/display: Revert wait vblank on update dpp clock
  (bsc#1012628).
- drm/amd/display: fix HDCP reset sequence on reinitialize
  (bsc#1012628).
- drm/ast: Fixed CVE for DP501 (bsc#1012628).
- drm/zte: Don't select DRM_KMS_FB_HELPER (bsc#1012628).
- drm/mxsfb: Don't select DRM_KMS_FB_HELPER (bsc#1012628).
- commit 6e62593
* Mon Jul 19 2021 dmueller@suse.com
- armv6hl/armv7hl: set CRYPTO_ECDSA=m (bsc#1188327)
  This avoids a crash on boot as the ECDSA code relies on unaligned
  accesses.
- commit ccf5b18
* Sun Jul 18 2021 mkubecek@suse.cz
- Update to 5.14-rc2
- update configs
  - NCSI_OEM_CMD_KEEP_PHY=y
  - EDAC_IGEN6=m (x86_64 only)
- commit 1d63327
* Sun Jul 18 2021 mkubecek@suse.cz
- series.conf: cleanup
- move submitted patch to "almost mainline" section:
  - patches.suse/arm64-dts-rockchip-Disable-CDN-DP-on-Pinebook-Pro.patch
- commit df2d619
* Fri Jul 16 2021 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Do not install usrmerged kernel on Leap
  (boo#1184804).
- commit 5b51131
* Thu Jul 15 2021 mbrugger@suse.com
- arm64: dts: rockchip: Disable CDN DP on Pinebook Pro
  (bsc#1188234).
- commit 73020a9
* Wed Jul 14 2021 jslaby@suse.cz
- Linux 5.13.2 (bsc#1012628).
- Bluetooth: hci_qca: fix potential GPF (bsc#1012628).
- Bluetooth: Remove spurious error message (bsc#1012628).
- ALSA: bebob: fix rx packet format for Yamaha GO44/GO46,
  Terratec Phase 24/x24 (bsc#1012628).
- ALSA: usb-audio: fix rate on Ozone Z90 USB headset
  (bsc#1012628).
- ALSA: usb-audio: Fix OOB access at proc output (bsc#1012628).
- ALSA: firewire-motu: fix stream format for MOTU 8pre FireWire
  (bsc#1012628).
- ALSA: usb-audio: scarlett2: Fix wrong resume call (bsc#1012628).
- ALSA: intel8x0: Fix breakage at ac97 clock measurement
  (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP ProBook 450 G8
  (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP ProBook 445 G8
  (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP ProBook 630 G8
  (bsc#1012628).
- ALSA: hda/realtek: Add another ALC236 variant support
  (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP EliteBook x360
  830 G8 (bsc#1012628).
- ALSA: hda/realtek: Improve fixup for HP Spectre x360 15-df0xxx
  (bsc#1012628).
- ALSA: hda/realtek: Fix bass speaker DAC mapping for Asus UM431D
  (bsc#1012628).
- ALSA: hda/realtek: Apply LED fixup for HP Dragonfly G1, too
  (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP EliteBook 830
  G8 Notebook PC (bsc#1012628).
- ALSA: hda/realtek: fix mute led of the HP Pavilion 15-eh1xxx
  series (bsc#1012628).
- media: dvb-usb: fix wrong definition (bsc#1012628).
- Input: usbtouchscreen - fix control-request directions
  (bsc#1012628).
- net: can: ems_usb: fix use-after-free in ems_usb_disconnect()
  (bsc#1012628).
- usb: gadget: eem: fix echo command packet response issue
  (bsc#1012628).
- usb: renesas-xhci: Fix handling of unknown ROM state
  (bsc#1012628).
- USB: cdc-acm: blacklist Heimann USB Appset device (bsc#1012628).
- usb: dwc3: Fix debugfs creation flow (bsc#1012628).
- usb: typec: tcpci: Fix up sink disconnect thresholds for PD
  (bsc#1012628).
- usb: typec: tcpm: Relax disconnect threshold during power
  negotiation (bsc#1012628).
- usb: typec: Add the missed altmode_id_remove() in
  typec_register_altmode() (bsc#1012628).
- xhci: solve a double free problem while doing s4 (bsc#1012628).
- mm/page_alloc: fix memory map initialization for descending
  nodes (bsc#1012628).
- gfs2: Fix underflow in gfs2_page_mkwrite (bsc#1012628).
- gfs2: Fix error handling in init_statfs (bsc#1012628).
- ntfs: fix validity check for file name attribute (bsc#1012628).
- selftests/lkdtm: Avoid needing explicit sub-shell (bsc#1012628).
- copy_page_to_iter(): fix ITER_DISCARD case (bsc#1012628).
- teach copy_page_to_iter() to handle compound pages
  (bsc#1012628).
- iov_iter_fault_in_readable() should do nothing in xarray case
  (bsc#1012628).
- Input: joydev - prevent use of not validated data in
  JSIOCSBTNMAP ioctl (bsc#1012628).
- crypto: nx - Fix memcpy() over-reading in nonce (bsc#1012628).
- arm_pmu: Fix write counter incorrect in ARMv7 big-endian mode
  (bsc#1012628).
- ARM: dts: ux500: Fix LED probing (bsc#1012628).
- ARM: dts: at91: sama5d4: fix pinctrl muxing (bsc#1012628).
- btrfs: zoned: print message when zone sanity check type fails
  (bsc#1012628).
- btrfs: zoned: bail out if we can't read a reliable write pointer
  (bsc#1012628).
- btrfs: send: fix invalid path for unlink operations after
  parent orphanization (bsc#1012628).
- btrfs: compression: don't try to compress if we don't have
  enough pages (bsc#1012628).
- btrfs: fix unbalanced unlock in qgroup_account_snapshot()
  (bsc#1012628).
- btrfs: clear defrag status of a root if starting transaction
  fails (bsc#1012628).
- ext4: cleanup in-core orphan list if ext4_truncate() failed
  to get a transaction handle (bsc#1012628).
- ext4: fix kernel infoleak via ext4_extent_header (bsc#1012628).
- ext4: fix overflow in ext4_iomap_alloc() (bsc#1012628).
- ext4: return error code when ext4_fill_flex_info() fails
  (bsc#1012628).
- ext4: correct the cache_nr in tracepoint ext4_es_shrink_exit
  (bsc#1012628).
- ext4: remove check for zero nr_to_scan in ext4_es_scan()
  (bsc#1012628).
- ext4: fix avefreec in find_group_orlov (bsc#1012628).
- ext4: use ext4_grp_locked_error in mb_find_extent (bsc#1012628).
- can: bcm: delay release of struct bcm_op after synchronize_rcu()
  (bsc#1012628).
- can: gw: synchronize rcu operations before removing gw job entry
  (bsc#1012628).
- can: isotp: isotp_release(): omit unintended hrtimer restart
  on socket release (bsc#1012628).
- can: j1939: j1939_sk_init(): set SOCK_RCU_FREE to call
  sk_destruct() after RCU is done (bsc#1012628).
- can: peak_pciefd: pucan_handle_status(): fix a potential
  starvation issue in TX path (bsc#1012628).
- mac80211: remove iwlwifi specific workaround that broke sta
  NDP tx (bsc#1012628).
- mac80211: fix NULL ptr dereference during mesh peer connection
  for non HE devices (bsc#1012628).
- SUNRPC: Fix the batch tasks count wraparound (bsc#1012628).
- SUNRPC: Should wake up the privileged task firstly
  (bsc#1012628).
- bus: mhi: core: Fix power down latency (bsc#1012628).
- bus: mhi: Wait for M2 state during system resume (bsc#1012628).
- bus: mhi: pci-generic: Add missing
  'pci_disable_pcie_error_reporting()' calls (bsc#1012628).
- mm/gup: fix try_grab_compound_head() race with split_huge_page()
  (bsc#1012628).
- perf/smmuv3: Don't trample existing events with global filter
  (bsc#1012628).
- KVM: nVMX: Handle split-lock #AC exceptions that happen in L2
  (bsc#1012628).
- KVM: PPC: Book3S HV: Workaround high stack usage with clang
  (bsc#1012628).
- KVM: x86/mmu: Remove broken WARN that fires on 32-bit KVM w/
  nested EPT (bsc#1012628).
- KVM: x86/mmu: Treat NX as used (not reserved) for all !TDP
  shadow MMUs (bsc#1012628).
- KVM: x86/mmu: Use MMU's role to detect CR4.SMEP value in nested
  NPT walk (bsc#1012628).
- KVM: x86: Properly reset MMU context at vCPU RESET/INIT
  (bsc#1012628).
- KVM: x86: Force all MMUs to reinitialize if guest CPUID is
  modified (bsc#1012628).
- s390/cio: dont call css_wait_for_slow_path() inside a lock
  (bsc#1012628).
- s390: mm: Fix secure storage access exception handling
  (bsc#1012628).
- f2fs: Advertise encrypted casefolding in sysfs (bsc#1012628).
- f2fs: Prevent swap file in LFS mode (bsc#1012628).
- clk: k210: Fix k210_clk_set_parent() (bsc#1012628).
- clk: agilex/stratix10/n5x: fix how the bypass_reg is handled
  (bsc#1012628).
- clk: agilex/stratix10: remove noc_clk (bsc#1012628).
- clk: agilex/stratix10: fix bypass representation (bsc#1012628).
- clk: agilex/stratix10: add support for the 2nd bypass
  (bsc#1012628).
- rtc: stm32: Fix unbalanced clk_disable_unprepare() on probe
  error path (bsc#1012628).
- iio: frequency: adf4350: disable reg and clk on error in
  adf4350_probe() (bsc#1012628).
- iio: light: tcs3472: do not free unallocated IRQ (bsc#1012628).
- iio: ltr501: mark register holding upper 8 bits of ALS_DATA{0,1}
  and PS_DATA as volatile, too (bsc#1012628).
- iio: ltr501: ltr559: fix initialization of LTR501_ALS_CONTR
  (bsc#1012628).
- iio: ltr501: ltr501_read_ps(): add missing endianness conversion
  (bsc#1012628).
- iio: accel: bma180: Fix BMA25x bandwidth register values
  (bsc#1012628).
- iio: accel: bmc150: Fix bma222 scale unit (bsc#1012628).
- iio: accel: bmc150: Fix dereferencing the wrong pointer in
  bmc150_get/set_second_device (bsc#1012628).
- iio: accel: bmc150: Don't make the remove function of the
  second accelerometer unregister itself (bsc#1012628).
- serial: mvebu-uart: fix calculation of clock divisor
  (bsc#1012628).
- serial: sh-sci: Stop dmaengine transfer in sci_stop_tx()
  (bsc#1012628).
- serial_cs: Add Option International GSM-Ready 56K/ISDN modem
  (bsc#1012628).
- serial_cs: remove wrong GLOBETROTTER.cis entry (bsc#1012628).
- ath9k: Fix kernel NULL pointer dereference during
  ath_reset_internal() (bsc#1012628).
- ssb: sdio: Don't overwrite const buffer if block_write fails
  (bsc#1012628).
- rsi: Assign beacon rate settings to the correct rate_info
  descriptor field (bsc#1012628).
- rsi: fix AP mode with WPA failure due to encrypted EAPOL
  (bsc#1012628).
- selftests/resctrl: Fix incorrect parsing of option "-t"
  (bsc#1012628).
- tracing/histograms: Fix parsing of "sym-offset" modifier
  (bsc#1012628).
- tracepoint: Add tracepoint_probe_register_may_exist() for BPF
  tracing (bsc#1012628).
- seq_buf: Make trace_seq_putmem_hex() support data longer than 8
  (bsc#1012628).
- powerpc/stacktrace: Fix spurious "stale" traces in
  raise_backtrace_ipi() (bsc#1012628).
- x86/gpu: add JasperLake to gen11 early quirks (bsc#1012628).
- perf/x86/intel: Fix fixed counter check warning for some Alder
  Lake (bsc#1012628).
- perf/x86/intel: Add more events requires FRONTEND MSR on
  Sapphire Rapids (bsc#1012628).
- perf/x86/intel: Fix instructions:ppp support in Sapphire Rapids
  (bsc#1012628).
- loop: Fix missing discard support when using LOOP_CONFIGURE
  (bsc#1012628).
- evm: Execute evm_inode_init_security() only when an HMAC key
  is loaded (bsc#1012628).
- evm: Refuse EVM_ALLOW_METADATA_WRITES only if an HMAC key is
  loaded (bsc#1012628).
- fuse: Fix crash in fuse_dentry_automount() error path
  (bsc#1012628).
- fuse: Fix crash if superblock of submount gets killed early
  (bsc#1012628).
- fuse: Fix infinite loop in sget_fc() (bsc#1012628).
- fuse: ignore PG_workingset after stealing (bsc#1012628).
- fuse: check connected before queueing on fpq->io (bsc#1012628).
- fuse: reject internal errno (bsc#1012628).
- thermal/cpufreq_cooling: Update offline CPUs per-cpu
  thermal_pressure (bsc#1012628).
- spi: Make of_register_spi_device also set the fwnode
  (bsc#1012628).
- Add a reference to ucounts for each cred (bsc#1012628).
- staging: media: rkvdec: fix pm_runtime_get_sync() usage count
  (bsc#1012628).
- media: i2c: imx334: fix the pm runtime get logic (bsc#1012628).
- media: marvel-ccic: fix some issues when getting pm_runtime
  (bsc#1012628).
- media: mdk-mdp: fix pm_runtime_get_sync() usage count
  (bsc#1012628).
- media: s5p: fix pm_runtime_get_sync() usage count (bsc#1012628).
- media: am437x: fix pm_runtime_get_sync() usage count
  (bsc#1012628).
- media: sh_vou: fix pm_runtime_get_sync() usage count
  (bsc#1012628).
- media: mtk-vcodec: fix PM runtime get logic (bsc#1012628).
- media: s5p-jpeg: fix pm_runtime_get_sync() usage count
  (bsc#1012628).
- media: sunxi: fix pm_runtime_get_sync() usage count
  (bsc#1012628).
- media: sti/bdisp: fix pm_runtime_get_sync() usage count
  (bsc#1012628).
- media: exynos4-is: fix pm_runtime_get_sync() usage count
  (bsc#1012628).
- media: exynos-gsc: fix pm_runtime_get_sync() usage count
  (bsc#1012628).
- spi: spi-loopback-test: Fix 'tx_buf' might be 'rx_buf'
  (bsc#1012628).
- spi: spi-topcliff-pch: Fix potential double free in
  pch_spi_process_messages() (bsc#1012628).
- spi: omap-100k: Fix the length judgment problem (bsc#1012628).
- regulator: uniphier: Add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- sched/core: Initialize the idle task with preemption disabled
  (bsc#1012628).
- hwrng: exynos - Fix runtime PM imbalance on error (bsc#1012628).
- crypto: nx - add missing MODULE_DEVICE_TABLE (bsc#1012628).
- media: sti: fix obj-$(config) targets (bsc#1012628).
- sched: Make the idle task quack like a per-CPU kthread
  (bsc#1012628).
- media: cpia2: fix memory leak in cpia2_usb_probe (bsc#1012628).
- media: cobalt: fix race condition in setting HPD (bsc#1012628).
- media: hevc: Fix dependent slice segment flags (bsc#1012628).
- media: pvrusb2: fix warning in pvr2_i2c_core_done (bsc#1012628).
- media: imx: imx7_mipi_csis: Fix logging of only error event
  counters (bsc#1012628).
- crypto: qat - check return code of qat_hal_rd_rel_reg()
  (bsc#1012628).
- crypto: qat - remove unused macro in FW loader (bsc#1012628).
- crypto: qce: skcipher: Fix incorrect sg count for dma transfers
  (bsc#1012628).
- crypto: ecdh - fix ecdh-nist-p192's entry in testmgr
  (bsc#1012628).
- crypto: ecdh - fix 'ecdh_init' (bsc#1012628).
- arm64: perf: Convert snprintf to sysfs_emit (bsc#1012628).
- sched/fair: Fix ascii art by relpacing tabs (bsc#1012628).
- ima: Don't remove security.ima if file must not be appraised
  (bsc#1012628).
- media: i2c: ov2659: Use clk_{prepare_enable,disable_unprepare}()
  to set xvclk on/off (bsc#1012628).
- media: bt878: do not schedule tasklet when it is not setup
  (bsc#1012628).
- media: em28xx: Fix possible memory leak of em28xx struct
  (bsc#1012628).
- media: hantro: Fix .buf_prepare (bsc#1012628).
- media: cedrus: Fix .buf_prepare (bsc#1012628).
- media: v4l2-core: Avoid the dangling pointer in v4l2_fh_release
  (bsc#1012628).
- media: bt8xx: Fix a missing check bug in bt878_probe
  (bsc#1012628).
- media: st-hva: Fix potential NULL pointer dereferences
  (bsc#1012628).
- crypto: hisilicon/sec - fixup 3des minimum key size declaration
  (bsc#1012628).
- arm64: entry: don't instrument entry code with KCOV
  (bsc#1012628).
- Makefile: fix GDB warning with CONFIG_RELR (bsc#1012628).
- media: dvd_usb: memory leak in cinergyt2_fe_attach
  (bsc#1012628).
- memstick: rtsx_usb_ms: fix UAF (bsc#1012628).
- mmc: sdhci-sprd: use sdhci_sprd_writew (bsc#1012628).
- mmc: via-sdmmc: add a check against NULL pointer dereference
  (bsc#1012628).
- mmc: sdhci-of-aspeed: Turn down a phase correction warning
  (bsc#1012628).
- spi: meson-spicc: fix a wrong goto jump for avoiding memory leak
  (bsc#1012628).
- spi: meson-spicc: fix memory leak in meson_spicc_probe
  (bsc#1012628).
- regulator: mt6315: Fix checking return value of
  devm_regmap_init_spmi_ext (bsc#1012628).
- crypto: shash - avoid comparing pointers to exported functions
  under CFI (bsc#1012628).
- media: dvb_net: avoid speculation from net slot (bsc#1012628).
- media: dvbdev: fix error logic at dvb_register_device()
  (bsc#1012628).
- media: siano: fix device register error path (bsc#1012628).
- media: imx-csi: Skip first few frames from a BT.656 source
  (bsc#1012628).
- hwmon: (max31790) Report correct current pwm duty cycles
  (bsc#1012628).
- hwmon: (max31790) Fix pwmX_enable attributes (bsc#1012628).
- sched/fair: Take thermal pressure into account while estimating
  energy (bsc#1012628).
- perf/x86: Reset the dirty counter to prevent the leak for an
  RDPMC task (bsc#1012628).
- drivers/perf: fix the missed ida_simple_remove() in
  ddr_perf_probe() (bsc#1012628).
- KVM: arm64: Restore PMU configuration on first run
  (bsc#1012628).
- KVM: PPC: Book3S HV: Fix TLB management on SMT8 POWER9 and
  POWER10 processors (bsc#1012628).
- btrfs: fix error handling in __btrfs_update_delayed_inode
  (bsc#1012628).
- btrfs: abort transaction if we fail to update the delayed inode
  (bsc#1012628).
- btrfs: always abort the transaction if we abort a trans handle
  (bsc#1012628).
- btrfs: sysfs: fix format string for some discard stats
  (bsc#1012628).
- btrfs: don't clear page extent mapped if we're not invalidating
  the full page (bsc#1012628).
- btrfs: disable build on platforms having page size 256K
  (bsc#1012628).
- locking/lockdep: Fix the dep path printing for backwards BFS
  (bsc#1012628).
- lockding/lockdep: Avoid to find wrong lock dep path in
  check_irq_usage() (bsc#1012628).
- KVM: s390: get rid of register asm usage (bsc#1012628).
- regulator: mt6358: Fix vdram2 .vsel_mask (bsc#1012628).
- regulator: da9052: Ensure enough delay time for
  .set_voltage_time_sel (bsc#1012628).
- media: Fix Media Controller API config checks (bsc#1012628).
- seccomp: Support atomic "addfd + send reply" (bsc#1012628).
- HID: do not use down_interruptible() when unbinding devices
  (bsc#1012628).
- EDAC/ti: Add missing MODULE_DEVICE_TABLE (bsc#1012628).
- ACPI: scan: Rearrange dep_unmet initialization (bsc#1012628).
- hv_utils: Fix passing zero to 'PTR_ERR' warning (bsc#1012628).
- lib: vsprintf: Fix handling of number field widths in vsscanf
  (bsc#1012628).
- Input: goodix - platform/x86: touchscreen_dmi - Move upside
  down quirks to touchscreen_dmi.c (bsc#1012628).
- platform/x86: touchscreen_dmi: Add an extra entry for the upside
  down Goodix touchscreen on Teclast X89 tablets (bsc#1012628).
- platform/x86: touchscreen_dmi: Add info for the Goodix GT912
  panel of TM800A550L tablets (bsc#1012628).
- ACPI: EC: Make more Asus laptops use ECDT _GPE (bsc#1012628).
- block_dump: remove block_dump feature in mark_inode_dirty()
  (bsc#1012628).
- blk-mq: grab rq->refcount before calling ->fn in
  blk_mq_tagset_busy_iter (bsc#1012628).
- blk-mq: clear stale request in tags->rq[] before freeing one
  request pool (bsc#1012628).
- fs: dlm: fix srcu read lock usage (bsc#1012628).
- fs: dlm: reconnect if socket error report occurs (bsc#1012628).
- fs: dlm: cancel work sync othercon (bsc#1012628).
- fs: dlm: fix connection tcp EOF handling (bsc#1012628).
- random32: Fix implicit truncation warning in
  prandom_seed_state() (bsc#1012628).
- open: don't silently ignore unknown O-flags in openat2()
  (bsc#1012628).
- drivers: hv: Fix missing error code in vmbus_connect()
  (bsc#1012628).
- fs: dlm: fix lowcomms_start error case (bsc#1012628).
- fs: dlm: fix memory leak when fenced (bsc#1012628).
- ACPICA: Fix memory leak caused by _CID repair function
  (bsc#1012628).
- ACPI: bus: Call kobject_put() in acpi_init() error path
  (bsc#1012628).
- ACPI: resources: Add checks for ACPI IRQ override (bsc#1012628).
- HID: hid-input: add Surface Go battery quirk (bsc#1012628).
- HID: sony: fix freeze when inserting ghlive ps3/wii dongles
  (bsc#1012628).
- block: fix race between adding/removing rq qos and normal IO
  (bsc#1012628).
- platform/x86: asus-nb-wmi: Revert "Drop duplicate DMI quirk
  structures" (bsc#1012628).
- platform/x86: asus-nb-wmi: Revert "add support for ASUS ROG
  Zephyrus G14 and G15" (bsc#1012628).
- platform/x86: toshiba_acpi: Fix missing error code in
  toshiba_acpi_setup_keyboard() (bsc#1012628).
- nvme-pci: fix var. type for increasing cq_head (bsc#1012628).
- nvmet-fc: do not check for invalid target port in
  nvmet_fc_handle_fcp_rqst() (bsc#1012628).
- EDAC/Intel: Do not load EDAC driver when running as a guest
  (bsc#1012628).
- tools/power/x86/intel-speed-select: Fix uncore memory frequency
  display (bsc#1012628).
- PCI: hv: Add check for hyperv_initialized in init_hv_pci_drv()
  (bsc#1012628).
- cifs: improve fallocate emulation (bsc#1012628).
- cifs: fix check of dfs interlinks (bsc#1012628).
- cifs: retry lookup and readdir when EAGAIN is returned
  (bsc#1012628).
- smb3: fix uninitialized value for port in witness protocol move
  (bsc#1012628).
- cifs: fix SMB1 error path in cifs_get_file_info_unix
  (bsc#1012628).
- ACPI: EC: trust DSDT GPE for certain HP laptop (bsc#1012628).
- block, bfq: fix delayed stable merge check (bsc#1012628).
- clocksource: Retry clock read if long delays detected
  (bsc#1012628).
- clocksource: Check per-CPU clock synchronization when marked
  unstable (bsc#1012628).
- tpm_tis_spi: add missing SPI device ID entries (bsc#1012628).
- ACPI: tables: Add custom DSDT file as makefile prerequisite
  (bsc#1012628).
- smb3: fix possible access to uninitialized pointer to DACL
  (bsc#1012628).
- HID: wacom: Correct base usage for capacitive ExpressKey status
  bits (bsc#1012628).
- cifs: fix missing spinlock around update to ses->status
  (bsc#1012628).
- mailbox: qcom: Use PLATFORM_DEVID_AUTO to register platform
  device (bsc#1012628).
- block: fix discard request merge (bsc#1012628).
- kthread_worker: fix return value when kthread_mod_delayed_work()
  races with kthread_cancel_delayed_work_sync() (bsc#1012628).
- ia64: mca_drv: fix incorrect array size calculation
  (bsc#1012628).
- writeback, cgroup: increment isw_nr_in_flight before grabbing
  an inode (bsc#1012628).
- mm: define default MAX_PTRS_PER_* in include/pgtable.h
  (bsc#1012628).
- kbuild: skip per-CPU BTF generation for pahole v1.18-v1.21
  (bsc#1012628).
- spi: Allow to have all native CSs in use along with GPIOs
  (bsc#1012628).
- spi: Avoid undefined behaviour when counting unused native CSs
  (bsc#1012628).
- media: venus: Rework error fail recover logic (bsc#1012628).
- media: s5p_cec: decrement usage count if disabled (bsc#1012628).
- media: i2c: ccs-core: return the right error code at suspend
  (bsc#1012628).
- media: hantro: do a PM resume earlier (bsc#1012628).
- crypto: ixp4xx - dma_unmap the correct address (bsc#1012628).
- crypto: ixp4xx - update IV after requests (bsc#1012628).
- crypto: ux500 - Fix error return code in hash_hw_final()
  (bsc#1012628).
- sata_highbank: fix deferred probing (bsc#1012628).
- pata_rb532_cf: fix deferred probing (bsc#1012628).
- media: I2C: change 'RST' to "RSET" to fix multiple build errors
  (bsc#1012628).
- sched/uclamp: Fix wrong implementation of cpu.uclamp.min
  (bsc#1012628).
- sched/uclamp: Fix locking around cpu_util_update_eff()
  (bsc#1012628).
- kbuild: Fix objtool dependency for
  'OBJECT_FILES_NON_STANDARD_<obj> := n' (bsc#1012628).
- pata_octeon_cf: avoid WARN_ON() in ata_host_activate()
  (bsc#1012628).
- evm: fix writing <securityfs>/evm overflow (bsc#1012628).
- crypto: testmgr - fix initialization of 'secret_size'
  (bsc#1012628).
- crypto: hisilicon/hpre - fix unmapping invalid dma address
  (bsc#1012628).
- x86/elf: Use _BITUL() macro in UAPI headers (bsc#1012628).
- crypto: sa2ul - Fix leaks on failure paths with sa_dma_init()
  (bsc#1012628).
- crypto: sa2ul - Fix pm_runtime enable in sa_ul_probe()
  (bsc#1012628).
- crypto: sa2ul - Use of_device_get_match_data() helper
  (bsc#1012628).
- crypto: ccp - Fix a resource leak in an error handling path
  (bsc#1012628).
- media: rc: i2c: Fix an error message (bsc#1012628).
- regulator: bd71815: add select to fix build (bsc#1012628).
- pata_ep93xx: fix deferred probing (bsc#1012628).
- locking/lockdep: Reduce LOCKDEP dependency list (bsc#1012628).
- sched: Don't defer CPU pick to migration_cpu_stop()
  (bsc#1012628).
- media: ipu3-cio2: Fix reference counting when looping over
  ACPI devices (bsc#1012628).
- media: venus: hfi_cmds: Fix conceal color property
  (bsc#1012628).
- media: rkvdec: Fix .buf_prepare (bsc#1012628).
- media: exynos4-is: Fix a use after free in isp_video_release
  (bsc#1012628).
- media: au0828: fix a NULL vs IS_ERR() check (bsc#1012628).
- media: tc358743: Fix error return code in tc358743_probe_of()
  (bsc#1012628).
- media: vicodec: Use _BITUL() macro in UAPI headers
  (bsc#1012628).
- media: gspca/gl860: fix zero-length control requests
  (bsc#1012628).
- regulator: fan53555: Fix missing slew_reg/mask/shift settings
  for FAN53526 (bsc#1012628).
- drivers/perf: hisi: Fix data source control (bsc#1012628).
- m68k: atari: Fix ATARI_KBD_CORE kconfig unmet dependency warning
  (bsc#1012628).
- media: siano: Fix out-of-bounds warnings in
  smscore_load_firmware_family2() (bsc#1012628).
- regulator: fan53880: Fix vsel_mask setting for FAN53880_BUCK
  (bsc#1012628).
- crypto: nitrox - fix unchecked variable in
  nitrox_register_interrupts (bsc#1012628).
- crypto: omap-sham - Fix PM reference leak in omap sham ops
  (bsc#1012628).
- crypto: x86/curve25519 - fix cpu feature checking logic in
  mod_exit (bsc#1012628).
- crypto: sm2 - fix a memory leak in sm2 (bsc#1012628).
- mmc: usdhi6rol0: fix error return code in usdhi6_probe()
  (bsc#1012628).
- arm64/mm: Fix ttbr0 values stored in struct thread_info for
  software-pan (bsc#1012628).
- media: v4l2-core: ignore native time32 ioctls on 64-bit
  (bsc#1012628).
- media: subdev: remove VIDIOC_DQEVENT_TIME32 handling
  (bsc#1012628).
- media: s5p-g2d: Fix a memory leak on ctx->fh.m2m_ctx
  (bsc#1012628).
- media: i2c: rdacm21: Fix OV10640 powerup (bsc#1012628).
- media: i2c: rdacm21: Power up OV10640 before OV490
  (bsc#1012628).
- hwmon: (pmbus/bpa-rs600) Handle Vin readings >= 256V
  (bsc#1012628).
- hwmon: (lm70) Revert "hwmon: (lm70) Add support for ACPI"
  (bsc#1012628).
- hwmon: (max31722) Remove non-standard ACPI device IDs
  (bsc#1012628).
- hwmon: (max31790) Fix fan speed reporting for fan7..12
  (bsc#1012628).
- KVM: nVMX: Add a return code to
  vmx_complete_nested_posted_interrupt (bsc#1012628).
- KVM: nVMX: Sync all PGDs on nested transition with shadow paging
  (bsc#1012628).
- KVM: nVMX: Ensure 64-bit shift when checking VMFUNC bitmap
  (bsc#1012628).
- KVM: nVMX: Don't clobber nested MMU's A/D status on EPTP switch
  (bsc#1012628).
- KVM: x86/mmu: Fix return value in
  tdp_mmu_map_handle_target_level() (bsc#1012628).
- KVM: x86/mmu: Fix pf_fixed count in
  tdp_mmu_map_handle_target_level() (bsc#1012628).
- perf/arm-cmn: Fix invalid pointer when access dtc object
  sharing the same IRQ number (bsc#1012628).
- KVM: arm64: Don't zero the cycle count register when PMCR_EL0.P
  is set (bsc#1012628).
- regulator: hi655x: Fix pass wrong pointer to config.driver_data
  (bsc#1012628).
- regulator: qcom-rpmh: Add terminator at the end of
  pm7325x_vreg_data[] array (bsc#1012628).
- regulator: hi6421v600: Fix setting idle mode (bsc#1012628).
- regulator: bd9576: Fix the driver name in id table
  (bsc#1012628).
- btrfs: clear log tree recovering status if starting transaction
  fails (bsc#1012628).
- x86/sev: Make sure IRQs are disabled while GHCB is active
  (bsc#1012628).
- x86/sev: Split up runtime #VC handler for correct state tracking
  (bsc#1012628).
- sched/rt: Fix RT utilization tracking during policy change
  (bsc#1012628).
- sched/rt: Fix Deadline utilization tracking during policy change
  (bsc#1012628).
- sched/uclamp: Fix uclamp_tg_restrict() (bsc#1012628).
- lockdep: Fix wait-type for empty stack (bsc#1012628).
- lockdep/selftests: Fix selftests vs PROVE_RAW_LOCK_NESTING
  (bsc#1012628).
- x86/sev: Use "SEV: " prefix for messages from sev.c
  (bsc#1012628).
- spi: spi-sun6i: Fix chipselect/clock bug (bsc#1012628).
- perf: Fix task context PMU for Hetero (bsc#1012628).
- crypto: nx - Fix RCU warning in nx842_OF_upd_status
  (bsc#1012628).
- objtool: Don't make .altinstructions writable (bsc#1012628).
- psi: Fix race between psi_trigger_create/destroy (bsc#1012628).
- KVM: selftests: fix triple fault if ept=0 in dirty_log_test
  (bsc#1012628).
- KVM: selftests: Remove errant asm/barrier.h include to fix
  arm64 build (bsc#1012628).
- media: video-mux: Skip dangling endpoints (bsc#1012628).
- media: mtk-vpu: on suspend, read/write regs only if vpu is
  running (bsc#1012628).
- media: s5p-mfc: Fix display delay control creation
  (bsc#1012628).
- EDAC/aspeed: Use proper format string for printing resource
  (bsc#1012628).
- PM / devfreq: Add missing error code in devfreq_add_device()
  (bsc#1012628).
- ACPI: PM / fan: Put fan device IDs into separate header file
  (bsc#1012628).
- block: avoid double io accounting for flush request
  (bsc#1012628).
- x86/hyperv: fix logical processor creation (bsc#1012628).
- nvme-pci: look for StorageD3Enable on companion ACPI device
  instead (bsc#1012628).
- ACPI: tables: FPDT: Add missing acpi_put_table() in
  acpi_init_fpdt() (bsc#1012628).
- ACPI: sysfs: Fix a buffer overrun problem with
  description_show() (bsc#1012628).
- mark pstore-blk as broken (bsc#1012628).
- md: revert io stats accounting (bsc#1012628).
- HID: surface-hid: Fix get-report request (bsc#1012628).
- clocksource/drivers/timer-ti-dm: Save and restore timer
  TIOCP_CFG (bsc#1012628).
- nvme-tcp: fix error codes in nvme_tcp_setup_ctrl()
  (bsc#1012628).
- extcon: extcon-max8997: Fix IRQ freeing at error path
  (bsc#1012628).
- ACPI: APEI: fix synchronous external aborts in user-mode
  (bsc#1012628).
- EDAC/igen6: fix core dependency (bsc#1012628).
- blk-wbt: introduce a new disable state to prevent false positive
  by rwb_enabled() (bsc#1012628).
- blk-wbt: make sure throttle is enabled properly (bsc#1012628).
- block, bfq: avoid delayed merge of async queues (bsc#1012628).
- block, bfq: reset waker pointer with shared queues
  (bsc#1012628).
- ACPI: bgrt: Fix CFI violation (bsc#1012628).
- cpufreq: Make cpufreq_online() call driver->offline() on errors
  (bsc#1012628).
- PM / devfreq: passive: Fix get_target_freq when not using
  required-opp (bsc#1012628).
- block: fix trace completion for chained bio (bsc#1012628).
- blk-mq: update hctx->dispatch_busy in case of real scheduler
  (bsc#1012628).
- ocfs2: fix snprintf() checking (bsc#1012628).
- dax: fix ENOMEM handling in grab_mapping_entry() (bsc#1012628).
- mm/debug_vm_pgtable: ensure THP availability via
  has_transparent_hugepage() (bsc#1012628).
- mm: mmap_lock: use local locks instead of disabling preemption
  (bsc#1012628).
- swap: fix do_swap_page() race with swapoff (bsc#1012628).
- mm/shmem: fix shmem_swapin() race with swapoff (bsc#1012628).
- mm: memcg/slab: properly set up gfp flags for objcg pointer
  array (bsc#1012628).
- mm/page_alloc: fix counting of managed_pages (bsc#1012628).
- xfrm: xfrm_state_mtu should return at least 1280 for ipv6
  (bsc#1012628).
- drm/bridge/sii8620: fix dependency on extcon (bsc#1012628).
- drm/bridge: Fix the stop condition of
  drm_bridge_chain_pre_enable() (bsc#1012628).
- drm/amd/dc: Fix a missing check bug in dm_dp_mst_detect()
  (bsc#1012628).
- drm/ast: Fix missing conversions to managed API (bsc#1012628).
- drm/bridge: anx7625: Fix power on delay (bsc#1012628).
- drm/bridge: fix LONTIUM_LT8912B dependencies (bsc#1012628).
- video: fbdev: imxfb: Fix an error message (bsc#1012628).
- drm/imx: ipuv3-plane: do not advertise YUV formats on planes
  without CSC (bsc#1012628).
- drm/imx: ipuv3-plane: fix PRG modifiers after drm managed
  resource conversion (bsc#1012628).
- rtnetlink: avoid RCU read lock when holding RTNL (bsc#1012628).
- net: mvpp2: Put fwnode in error case during ->probe()
  (bsc#1012628).
- net: pch_gbe: Propagate error from devm_gpio_request_one()
  (bsc#1012628).
- pinctrl: renesas: r8a7796: Add missing bias for PRESET# pin
  (bsc#1012628).
- pinctrl: renesas: r8a77990: JTAG pins do not have pull-down
  capabilities (bsc#1012628).
- RDMA/hns: Remove the condition of light load for posting DWQE
  (bsc#1012628).
- drm/vmwgfx: Mark a surface gpu-dirty after the
  SVGA3dCmdDXGenMips command (bsc#1012628).
- drm/vmwgfx: Fix cpu updates of coherent multisample surfaces
  (bsc#1012628).
- libbpf: Fix ELF symbol visibility update logic (bsc#1012628).
- drm/i915: Merge fix for "drm: Switch to %%p4cc format modifier"
  (bsc#1012628).
- net: qrtr: ns: Fix error return code in qrtr_ns_init()
  (bsc#1012628).
- clk: meson: g12a: fix gp0 and hifi ranges (bsc#1012628).
- drm/amd/display: fix potential gpu reset deadlock (bsc#1012628).
- drm/amd/display: Avoid HPD IRQ in GPU reset state (bsc#1012628).
- drm/amd/display: take dc_lock in short pulse handler only
  (bsc#1012628).
- net: ftgmac100: add missing error return code in
  ftgmac100_probe() (bsc#1012628).
- clk: rockchip: fix rk3568 cpll clk gate bits (bsc#1012628).
- clk: sunxi-ng: v3s: fix incorrect postdivider on pll-audio
  (bsc#1012628).
- drm/vc4: crtc: Pass the drm_atomic_state to config_pv
  (bsc#1012628).
- drm/vc4: crtc: Fix vc4_get_crtc_encoder logic (bsc#1012628).
- drm/vc4: crtc: Lookup the encoder from the register at boot
  (bsc#1012628).
- drm: rockchip: set alpha_en to 0 if it is not used
  (bsc#1012628).
- drm/rockchip: cdn-dp-core: add missing clk_disable_unprepare()
  on error in cdn_dp_grf_write() (bsc#1012628).
- drm/rockchip: dsi: move all lane config except LCDC mux to
  bind() (bsc#1012628).
- drm/rockchip: lvds: Fix an error handling path (bsc#1012628).
- drm/rockchip: cdn-dp: fix sign extension on an int multiply
  for a u64 result (bsc#1012628).
- mptcp: fix pr_debug in mptcp_token_new_connect (bsc#1012628).
- mptcp: generate subflow hmac after mptcp_finish_join()
  (bsc#1012628).
- mptcp: make sure flag signal is set when add addr with port
  (bsc#1012628).
- RDMA/hns: Fix wrong timer context buffer page size
  (bsc#1012628).
- RDMA/srp: Fix a recently introduced memory leak (bsc#1012628).
- RDMA/rtrs-clt: Check state of the rtrs_clt_sess before reading
  its stats (bsc#1012628).
- RDMA/rtrs: Do not reset hb_missed_max after re-connection
  (bsc#1012628).
- RDMA/rtrs-srv: Fix memory leak of unfreed rtrs_srv_stats object
  (bsc#1012628).
- RDMA/rtrs-srv: Fix memory leak when having multiple sessions
  (bsc#1012628).
- RDMA/rtrs-clt: Check if the queue_depth has changed during a
  reconnection (bsc#1012628).
- RDMA/rtrs-clt: Fix memory leak of not-freed sess->stats and
  stats->pcpu_stats (bsc#1012628).
- ehea: fix error return code in ehea_restart_qps() (bsc#1012628).
- clk: tegra30: Use 300MHz for video decoder by default
  (bsc#1012628).
- xfrm: remove the fragment check for ipv6 beet mode
  (bsc#1012628).
- net/sched: act_vlan: Fix modify to allow 0 (bsc#1012628).
- RDMA/core: Sanitize WQ state received from the userspace
  (bsc#1012628).
- IB/cm: Pair cm_alloc_response_msg() with a
  cm_free_response_msg() (bsc#1012628).
- IB/cm: Split cm_alloc_msg() (bsc#1012628).
- Revert "IB/cm: Mark stale CM id's whenever the mad agent was
  unregistered" (bsc#1012628).
- IB/cm: Improve the calling of cm_init_av_for_lap and
  cm_init_av_by_path (bsc#1012628).
- drm/pl111: depend on CONFIG_VEXPRESS_CONFIG (bsc#1012628).
- RDMA/rxe: Fix failure during driver load (bsc#1012628).
- drm/pl111: Actually fix CONFIG_VEXPRESS_CONFIG depends
  (bsc#1012628).
- drm/vc4: hdmi: Fix error path of hpd-gpios (bsc#1012628).
- clk: vc5: fix output disabling when enabling a FOD
  (bsc#1012628).
- drm: qxl: ensure surf.data is ininitialized (bsc#1012628).
- stmmac: prefetch right address (bsc#1012628).
- net: stmmac: Fix potential integer overflow (bsc#1012628).
- tools/bpftool: Fix error return code in do_batch()
  (bsc#1012628).
- ath10k: go to path err_unsupported when chip id is not supported
  (bsc#1012628).
- ath10k: add missing error return code in ath10k_pci_probe()
  (bsc#1012628).
- wireless: carl9170: fix LEDS build errors & warnings
  (bsc#1012628).
- ieee802154: hwsim: Fix possible memory leak in
  hwsim_subscribe_all_others (bsc#1012628).
- clk: imx8mq: remove SYS PLL 1/2 clock gates (bsc#1012628).
- wcn36xx: Move hal_buf allocation to devm_kmalloc in probe
  (bsc#1012628).
- net: wwan: Fix WWAN config symbols (bsc#1012628).
- drm/i915/selftests: Reorder tasklet_disable vs local_bh_disable
  (bsc#1012628).
- ssb: Fix error return code in ssb_bus_scan() (bsc#1012628).
- brcmfmac: fix setting of station info chains bitmask
  (bsc#1012628).
- brcmfmac: correctly report average RSSI in station info
  (bsc#1012628).
- brcmfmac: Fix a double-free in brcmf_sdio_bus_reset
  (bsc#1012628).
- brcmsmac: mac80211_if: Fix a resource leak in an error handling
  path (bsc#1012628).
- cw1200: Revert unnecessary patches that fix unreal
  use-after-free bugs (bsc#1012628).
- ath11k: Fix an error handling path in
  ath11k_core_fetch_board_data_api_n() (bsc#1012628).
- ath10k: Fix an error code in ath10k_add_interface()
  (bsc#1012628).
- ath11k: send beacon template after vdev_start/restart during
  csa (bsc#1012628).
- wil6210: remove erroneous wiphy locking (bsc#1012628).
- netlabel: Fix memory leak in netlbl_mgmt_add_common
  (bsc#1012628).
- RDMA/mlx5: Don't add slave port to unaffiliated list
  (bsc#1012628).
- netfilter: nft_exthdr: check for IPv6 packet before further
  processing (bsc#1012628).
- netfilter: nft_osf: check for TCP packet before further
  processing (bsc#1012628).
- netfilter: nft_tproxy: restrict support to TCP and UDP transport
  protocols (bsc#1012628).
- RDMA/rxe: Fix qp reference counting for atomic ops
  (bsc#1012628).
- selftests/bpf: Whitelist test_progs.h from .gitignore
  (bsc#1012628).
- selftests/bpf: Fix ringbuf test fetching map FD (bsc#1012628).
- xsk: Fix missing validation for skb and unaligned mode
  (bsc#1012628).
- xsk: Fix broken Tx ring validation (bsc#1012628).
- bpf: Fix libelf endian handling in resolv_btfids (bsc#1012628).
- RDMA/rtrs-srv: Set minimal max_send_wr and max_recv_wr
  (bsc#1012628).
- RDMA/hns: Clear extended doorbell info before using
  (bsc#1012628).
- samples/bpf: Fix Segmentation fault for xdp_redirect command
  (bsc#1012628).
- samples/bpf: Fix the error return code of xdp_redirect's main()
  (bsc#1012628).
- net: pxa168_eth: Fix a potential data race in pxa168_eth_remove
  (bsc#1012628).
- mt76: mt7915: fix a signedness bug in mt7915_mcu_apply_tx_dpd()
  (bsc#1012628).
- mt76: fix possible NULL pointer dereference in mt76_tx
  (bsc#1012628).
- mt76: mt7615: fix NULL pointer dereference in tx_prepare_skb()
  (bsc#1012628).
- mt76: mt7921: fix mt7921_wfsys_reset sequence (bsc#1012628).
- mt76: mt7921: Don't alter Rx path classifier (bsc#1012628).
- mt76: connac: fw_own rely on all packet memory all being free
  (bsc#1012628).
- mt76: connac: fix WoW with disconnetion and bitmap pattern
  (bsc#1012628).
- mt76: mt7921: consider the invalid value for to_rssi
  (bsc#1012628).
- mt76: mt7921: add back connection monitor support (bsc#1012628).
- mt76: mt7921: fix invalid register access in wake_work
  (bsc#1012628).
- mt76: mt7921: fix OMAC idx usage (bsc#1012628).
- mt76: mt7921: avoid unnecessary consecutive WiFi resets
  (bsc#1012628).
- mt76: mt7921: do not schedule hw reset if the device is not
  running (bsc#1012628).
- mt76: testmode: fix memory leak in mt76_testmode_alloc_skb
  (bsc#1012628).
- mt76: testmode: remove undefined behaviour in
  mt76_testmode_alloc_skb (bsc#1012628).
- mt76: mt7615: fix potential overflow on large shift
  (bsc#1012628).
- mt76: mt7915: fix MT_EE_CAL_GROUP_SIZE (bsc#1012628).
- mt76: mt7921: wake the device before dumping power table
  (bsc#1012628).
- mt76: mt7915: fix rx fcs error count in testmode (bsc#1012628).
- mt76: mt7921: fix kernel warning when reset on vif is not sta
  (bsc#1012628).
- mt76: mt7921: fix the coredump is being truncated (bsc#1012628).
- net: ethernet: aeroflex: fix UAF in greth_of_remove
  (bsc#1012628).
- net: ethernet: ezchip: fix UAF in nps_enet_remove (bsc#1012628).
- net: ethernet: ezchip: fix error handling (bsc#1012628).
- selftests/bpf: Retry for EAGAIN in udp_redir_to_connected()
  (bsc#1012628).
- udp: Fix a memory leak in udp_read_sock() (bsc#1012628).
- skmsg: Clear skb redirect pointer before dropping it
  (bsc#1012628).
- skmsg: Fix a memory leak in sk_psock_verdict_apply()
  (bsc#1012628).
- skmsg: Teach sk_psock_verdict_apply() to return errors
  (bsc#1012628).
- vrf: do not push non-ND strict packets with a source LLA
  through packet taps again (bsc#1012628).
- net: sched: add barrier to ensure correct ordering for lockless
  qdisc (bsc#1012628).
- selftests: tls: clean up uninitialized warnings (bsc#1012628).
- selftests: tls: fix chacha+bidir tests (bsc#1012628).
- tls: prevent oversized sendfile() hangs by ignoring MSG_MORE
  (bsc#1012628).
- netfilter: nf_tables: memleak in hw offload abort path
  (bsc#1012628).
- netfilter: nf_tables_offload: check FLOW_DISSECTOR_KEY_BASIC
  in VLAN transfer logic (bsc#1012628).
- mptcp: fix bad handling of 32 bit ack wrap-around (bsc#1012628).
- mptcp: fix 32 bit DSN expansion (bsc#1012628).
- net: mana: Fix a memory leak in an error handling path in
  'mana_create_txq()' (bsc#1012628).
- net: dsa: mv88e6xxx: Fix adding vlan 0 (bsc#1012628).
- pkt_sched: sch_qfq: fix qfq_change_class() error path
  (bsc#1012628).
- xfrm: Fix xfrm offload fallback fail case (bsc#1012628).
- netfilter: nf_tables: skip netlink portID validation if zero
  (bsc#1012628).
- netfilter: nf_tables: do not allow to delete table with owner
  by handle (bsc#1012628).
- iwlwifi: increase PNVM load timeout (bsc#1012628).
- bpf: Fix regression on BPF_OBJ_GET with non-O_RDWR flags
  (bsc#1012628).
- rtw88: 8822c: fix lc calibration timing (bsc#1012628).
- vxlan: add missing rcu_read_lock() in neigh_reduce()
  (bsc#1012628).
- bpf: Fix integer overflow in argument calculation for
  bpf_map_area_alloc (bsc#1012628).
- mptcp: avoid race on msk state changes (bsc#1012628).
- ip6_tunnel: fix GRE6 segmentation (bsc#1012628).
- net/ipv4: swap flow ports when validating source (bsc#1012628).
- net: broadcom: bcm4908_enet: reset DMA rings sw indexes properly
  (bsc#1012628).
- net: ti: am65-cpsw-nuss: Fix crash when changing number of TX
  queues (bsc#1012628).
- tc-testing: fix list handling (bsc#1012628).
- RDMA/hns: Force rewrite inline flag of WQE (bsc#1012628).
- RDMA/hns: Fix uninitialized variable (bsc#1012628).
- ieee802154: hwsim: Fix memory leak in hwsim_add_one
  (bsc#1012628).
- ieee802154: hwsim: avoid possible crash in hwsim_del_edge_nl()
  (bsc#1012628).
- bpf: Fix null ptr deref with mixed tail calls and subprogs
  (bsc#1012628).
- drm/msm/dp: handle irq_hpd with sink_count = 0 correctly
  (bsc#1012628).
- drm/msm/disp/dpu1: avoid perf update in frame done event
  (bsc#1012628).
- drm/msm: Fix error return code in msm_drm_init() (bsc#1012628).
- drm/msm/dpu: Fix error return code in dpu_mdss_init()
  (bsc#1012628).
- mac80211: remove iwlwifi specific workaround NDPs of
  null_response (bsc#1012628).
- net: bcmgenet: Fix attaching to PYH failed on RPi 4B
  (bsc#1012628).
- ipv6: exthdrs: do not blindly use init_net (bsc#1012628).
- can: j1939: j1939_sk_setsockopt(): prevent allocation of j1939
  filter for optlen == 0 (bsc#1012628).
- bpf: Do not change gso_size during bpf_skb_change_proto()
  (bsc#1012628).
- i40e: Fix error handling in i40e_vsi_open (bsc#1012628).
- i40e: Fix autoneg disabling for non-10GBaseT links
  (bsc#1012628).
- i40e: Fix missing rtnl locking when setting up pf switch
  (bsc#1012628).
- RDMA/hns: Add a check to ensure integer mtu is positive
  (bsc#1012628).
- RDMA/hns: Add window selection field of congestion control
  (bsc#1012628).
- Revert "ibmvnic: simplify reset_long_term_buff function"
  (bsc#1012628).
- Revert "ibmvnic: remove duplicate napi_schedule call in open
  function" (bsc#1012628).
- ibmvnic: clean pending indirect buffs during reset
  (bsc#1012628).
- ibmvnic: account for bufs already saved in indir_buf
  (bsc#1012628).
- ibmvnic: set ltb->buff to NULL after freeing (bsc#1012628).
- ibmvnic: free tx_pool if tso_pool alloc fails (bsc#1012628).
- RDMA/cma: Protect RMW with qp_mutex (bsc#1012628).
- net: macsec: fix the length used to copy the key for offloading
  (bsc#1012628).
- net: phy: mscc: fix macsec key length (bsc#1012628).
- net: atlantic: fix the macsec key length (bsc#1012628).
- ipv6: fix out-of-bound access in ip6_parse_tlv() (bsc#1012628).
- e1000e: Check the PCIm state (bsc#1012628).
- net: dsa: sja1105: fix NULL pointer dereference in
  sja1105_reload_cbs() (bsc#1012628).
- bpfilter: Specify the log level for the kmsg message
  (bsc#1012628).
- RDMA/cma: Fix incorrect Packet Lifetime calculation
  (bsc#1012628).
- gve: Fix swapped vars when fetching max queues (bsc#1012628).
- Revert "be2net: disable bh with spin_lock in be_process_mcc"
  (bsc#1012628).
- clk: zynqmp: fix compile testing without ZYNQMP_FIRMWARE
  (bsc#1012628).
- Bluetooth: virtio_bt: add missing null pointer check on
  alloc_skb call return (bsc#1012628).
- Bluetooth: mgmt: Fix slab-out-of-bounds in tlv_data_is_valid
  (bsc#1012628).
- Bluetooth: Fix Set Extended (Scan Response) Data (bsc#1012628).
- Bluetooth: Fix handling of HCI_LE_Advertising_Set_Terminated
  event (bsc#1012628).
- clk: qcom: gcc: Add support for a new frequency for SC7280
  (bsc#1012628).
- clk: actions: Fix UART clock dividers on Owl S500 SoC
  (bsc#1012628).
- clk: actions: Fix SD clocks factor table on Owl S500 SoC
  (bsc#1012628).
- clk: actions: Fix bisp_factor_table based clocks on Owl S500
  SoC (bsc#1012628).
- clk: actions: Fix AHPPREDIV-H-AHB clock chain on Owl S500 SoC
  (bsc#1012628).
- clk: qcom: clk-alpha-pll: fix CAL_L write in
  alpha_pll_fabia_prepare (bsc#1012628).
- clk: si5341: Wait for DEVICE_READY on startup (bsc#1012628).
- clk: si5341: Avoid divide errors due to bogus register contents
  (bsc#1012628).
- clk: si5341: Check for input clock presence and PLL lock on
  startup (bsc#1012628).
- clk: si5341: Update initialization magic (bsc#1012628).
- bpf, x86: Fix extable offset calculation (bsc#1012628).
- writeback: fix obtain a reference to a freeing memcg css
  (bsc#1012628).
- net: lwtunnel: handle MTU calculation in forwading
  (bsc#1012628).
- net: sched: fix warning in tcindex_alloc_perfect_hash
  (bsc#1012628).
- net: tipc: fix FB_MTU eat two pages (bsc#1012628).
- RDMA/mlx5: Don't access NULL-cleared mpi pointer (bsc#1012628).
- RDMA/core: Always release restrack object (bsc#1012628).
- MIPS: Fix PKMAP with 32-bit MIPS huge page support
  (bsc#1012628).
- staging: rtl8712: Fix some tests against some 'data' subtype
  frames (bsc#1012628).
- staging: fbtft: Rectify GPIO handling (bsc#1012628).
- staging: fbtft: Don't spam logs when probe is deferred
  (bsc#1012628).
- ASoC: rt5682: Disable irq on shutdown (bsc#1012628).
- rcu: Invoke rcu_spawn_core_kthreads() from
  rcu_spawn_gp_kthread() (bsc#1012628).
- serial: fsl_lpuart: don't modify arbitrary data on lpuart32
  (bsc#1012628).
- serial: fsl_lpuart: remove RTSCTS handling from get_mctrl()
  (bsc#1012628).
- serial: 8250_omap: fix a timeout loop condition (bsc#1012628).
- tty: nozomi: Fix a resource leak in an error handling function
  (bsc#1012628).
- phy: ralink: phy-mt7621-pci: properly print pointer address
  (bsc#1012628).
- mwifiex: re-fix for unaligned accesses (bsc#1012628).
- iio: adis_buffer: do not return ints in irq handlers
  (bsc#1012628).
- iio: adis16400: do not return ints in irq handlers
  (bsc#1012628).
- iio: adis16475: do not return ints in irq handlers
  (bsc#1012628).
- iio: accel: bma180: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: accel: bma220: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: accel: hid: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: accel: kxcjk-1013: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: accel: mxc4005: Fix overread of data and alignment issue
  (bsc#1012628).
- iio: accel: stk8312: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: accel: stk8ba50: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: adc: ti-ads1015: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: adc: vf610: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: gyro: bmg160: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: humidity: am2315: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: prox: srf08: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: prox: pulsed-light: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: prox: as3935: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: magn: hmc5843: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: magn: bmc150: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: light: isl29125: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: light: tcs3414: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: light: tcs3472: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: chemical: atlas: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: cros_ec_sensors: Fix alignment of buffer in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: potentiostat: lmp91000: Fix alignment of buffer in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- ASoC: rk3328: fix missing clk_disable_unprepare() on error in
  rk3328_platform_probe() (bsc#1012628).
- ASoC: hisilicon: fix missing clk_disable_unprepare() on error
  in hi6210_i2s_startup() (bsc#1012628).
- backlight: lm3630a_bl: Put fwnode in error case during ->probe()
  (bsc#1012628).
- usb: typec: tcpm: Fix up PR_SWAP when vsafe0v is signalled
  (bsc#1012628).
- ASoC: rsnd: tidyup loop on rsnd_adg_clk_query() (bsc#1012628).
- Input: hil_kbd - fix error return code in hil_dev_connect()
  (bsc#1012628).
- perf scripting python: Fix tuple_set_u64() (bsc#1012628).
- mtd: partitions: redboot: seek fis-index-block in the right node
  (bsc#1012628).
- mtd: parsers: qcom: Fix leaking of partition name (bsc#1012628).
- mtd: rawnand: arasan: Ensure proper configuration for the
  asserted target (bsc#1012628).
- staging: mmal-vchiq: Fix incorrect static vchiq_instance
  (bsc#1012628).
- char: pcmcia: error out if 'num_bytes_read' is greater than
  4 in set_protocol() (bsc#1012628).
- misc/pvpanic-pci: Fix error handling in 'pvpanic_pci_probe()'
  (bsc#1012628).
- misc/pvpanic-mmio: Fix error handling in 'pvpanic_mmio_probe()'
  (bsc#1012628).
- firmware: stratix10-svc: Fix a resource leak in an error
  handling path (bsc#1012628).
- tty: nozomi: Fix the error handling path of 'nozomi_card_init()'
  (bsc#1012628).
- leds: class: The -ENOTSUPP should never be seen by user space
  (bsc#1012628).
- leds: lgm-sso: Fix clock handling (bsc#1012628).
- leds: lm3532: select regmap I2C API (bsc#1012628).
- leds: lm36274: Put fwnode in error case during ->probe()
  (bsc#1012628).
- leds: lm3692x: Put fwnode in any case during ->probe()
  (bsc#1012628).
- leds: lm3697: Don't spam logs when probe is deferred
  (bsc#1012628).
- leds: lp50xx: Put fwnode in error case during ->probe()
  (bsc#1012628).
- scsi: FlashPoint: Rename si_flags field (bsc#1012628).
- scsi: iscsi: Stop queueing during ep_disconnect (bsc#1012628).
- scsi: iscsi: Force immediate failure during shutdown
  (bsc#1012628).
- scsi: iscsi: Use system_unbound_wq for destroy_work
  (bsc#1012628).
- scsi: iscsi: Rel ref after iscsi_lookup_endpoint()
  (bsc#1012628).
- scsi: iscsi: Fix in-kernel conn failure handling (bsc#1012628).
- scsi: iscsi: Flush block work before unblock (bsc#1012628).
- mfd: mp2629: Select MFD_CORE to fix build error (bsc#1012628).
- mfd: Remove software node conditionally and locate at right
  place (bsc#1012628).
- mfd: rn5t618: Fix IRQ trigger by changing it to level mode
  (bsc#1012628).
- fsi: core: Fix return of error values on failures (bsc#1012628).
- fsi: scom: Reset the FSI2PIB engine for any error (bsc#1012628).
- fsi: occ: Don't accept response from un-initialized OCC
  (bsc#1012628).
- fsi/sbefifo: Clean up correct FIFO when receiving reset request
  from SBE (bsc#1012628).
- fsi/sbefifo: Fix reset timeout (bsc#1012628).
- visorbus: fix error return code in visorchipset_init()
  (bsc#1012628).
- iommu/amd: Fix extended features logging (bsc#1012628).
- iommu/amd: Tidy up DMA ops init (bsc#1012628).
- s390: enable HAVE_IOREMAP_PROT (bsc#1012628).
- s390: appldata depends on PROC_SYSCTL (bsc#1012628).
- selftests: splice: Adjust for handler fallback removal
  (bsc#1012628).
- iommu/dma: Fix IOVA reserve dma ranges (bsc#1012628).
- ASoC: max98373-sdw: add missing memory allocation check
  (bsc#1012628).
- ASoC: max98373-sdw: use first_hw_init flag on resume
  (bsc#1012628).
- ASoC: rt1308-sdw: use first_hw_init flag on resume
  (bsc#1012628).
- ASoC: rt1316-sdw: use first_hw_init flag on resume
  (bsc#1012628).
- ASoC: rt5682-sdw: use first_hw_init flag on resume
  (bsc#1012628).
- ASoC: rt700-sdw: use first_hw_init flag on resume (bsc#1012628).
- ASoC: rt711-sdca-sdw: use first_hw_init flag on resume
  (bsc#1012628).
- ASoC: rt711-sdw: use first_hw_init flag on resume (bsc#1012628).
- ASoC: rt715-sdca-sdw: use first_hw_init flag on resume
  (bsc#1012628).
- ASoC: rt715-sdw: use first_hw_init flag on resume (bsc#1012628).
- ASoC: rt715-sdca: fix clock stop prepare timeout issue
  (bsc#1012628).
- ASoC: rt5682: Fix a problem with error handling in the io init
  function of the soundwire (bsc#1012628).
- ASoC: rt5682-sdw: set regcache_cache_only false before reading
  RT5682_DEVICE_ID (bsc#1012628).
- ASoC: rt711-sdca-sdw: add readable for SDW_SDCA_CTL() registers
  (bsc#1012628).
- ASoC: rt711-sdca: handle mbq_regmap in rt711_sdca_io_init
  (bsc#1012628).
- ASoC: mediatek: mtk-btcvsd: Fix an error handling path in
  'mtk_btcvsd_snd_probe()' (bsc#1012628).
- usb: gadget: f_fs: Fix setting of device and driver data
  cross-references (bsc#1012628).
- usb: dwc2: Don't reset the core after setting turnaround time
  (bsc#1012628).
- eeprom: idt_89hpesx: Put fwnode in matching case during
  - >probe() (bsc#1012628).
- eeprom: idt_89hpesx: Restore printing the unsupported fwnode
  name (bsc#1012628).
- mtd: spi-nor: otp: fix access to security registers in 4 byte
  mode (bsc#1012628).
- mtd: spi-nor: otp: return -EROFS if region is read-only
  (bsc#1012628).
- thunderbolt: Bond lanes only when dual_link_port != NULL in
  alloc_dev_default() (bsc#1012628).
- mtd: spinand: Fix double counting of ECC stats (bsc#1012628).
- kunit: Fix result propagation for parameterised tests
  (bsc#1012628).
- iio: dummy: Fix build error when CONFIG_IIO_TRIGGERED_BUFFER
  is not set (bsc#1012628).
- iio: adc: at91-sama5d2: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: adc: hx711: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: adc: mxs-lradc: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: adc: ti-ads8688: Fix alignment of buffer in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: magn: rm3100: Fix alignment of buffer in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: light: vcnl4000: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- ASoC: fsl_spdif: Fix error handler with pm_runtime_enable
  (bsc#1012628).
- staging: gdm724x: check for buffer overflow in
  gdm_lte_multi_sdu_pkt() (bsc#1012628).
- staging: gdm724x: check for overflow in gdm_lte_netif_rx()
  (bsc#1012628).
- staging: rtl8712: fix error handling in r871xu_drv_init
  (bsc#1012628).
- staging: rtl8712: fix memory leak in rtl871x_load_fw_cb
  (bsc#1012628).
- coresight: core: Fix use of uninitialized pointer (bsc#1012628).
- staging: mt7621-dts: fix pci address for PCI memory range
  (bsc#1012628).
- usb: phy: tegra: Wait for VBUS wakeup status deassertion on
  suspend (bsc#1012628).
- usb: phy: tegra: Correct definition of B_SESS_VLD_WAKEUP_EN bit
  (bsc#1012628).
- serial: 8250: Actually allow UPF_MAGIC_MULTIPLIER baud rates
  (bsc#1012628).
- iio: light: vcnl4035: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: prox: isl29501: Fix buffer alignment in
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- ASoC: cs42l42: Correct definition of CS42L42_ADC_PDN_MASK
  (bsc#1012628).
- of: Fix truncation of memory sizes on 32-bit platforms
  (bsc#1012628).
- mtd: rawnand: marvell: add missing clk_disable_unprepare()
  on error in marvell_nfc_resume() (bsc#1012628).
- habanalabs: Fix an error handling path in 'hl_pci_probe()'
  (bsc#1012628).
- scsi: mpt3sas: Fix error return value in _scsih_expander_add()
  (bsc#1012628).
- soundwire: stream: Fix test for DP prepare complete
  (bsc#1012628).
- phy: uniphier-pcie: Fix updating phy parameters (bsc#1012628).
- phy: ti: dm816x: Fix the error handling path in
  'dm816x_usb_phy_probe() (bsc#1012628).
- extcon: sm5502: Drop invalid register write in sm5502_reg_data
  (bsc#1012628).
- extcon: max8997: Add missing modalias string (bsc#1012628).
- powerpc/powernv: Fix machine check reporting of async store
  errors (bsc#1012628).
- ASoC: atmel-i2s: Set symmetric sample bits (bsc#1012628).
- ASoC: atmel-i2s: Fix usage of capture and playback at the same
  time (bsc#1012628).
- ASoC: fsl_xcvr: disable all interrupts when suspend happens
  (bsc#1012628).
- configfs: fix memleak in configfs_release_bin_file
  (bsc#1012628).
- ASoC: Intel: sof_sdw: add SOF_RT715_DAI_ID_FIX for AlderLake
  (bsc#1012628).
- ASoC: fsl_spdif: Fix unexpected interrupt after suspend
  (bsc#1012628).
- leds: as3645a: Fix error return code in as3645a_parse_node()
  (bsc#1012628).
- leds: ktd2692: Fix an error handling path (bsc#1012628).
- selftests/ftrace: fix event-no-pid on 1-core machine
  (bsc#1012628).
- selftests/sgx: remove checks for file execute permissions
  (bsc#1012628).
- staging: rtl8723bs: Fix an error handling path (bsc#1012628).
- serial: 8250: 8250_omap: Fix possible interrupt storm on K3 SoCs
  (bsc#1012628).
- powerpc: Offline CPU in stop_this_cpu() (bsc#1012628).
- powerpc/papr_scm: Properly handle UUID types and API
  (bsc#1012628).
- powerpc/64s: Fix copy-paste data exposure into newly created
  tasks (bsc#1012628).
- powerpc/papr_scm: Make 'perf_stats' invisible if perf-stats
  unavailable (bsc#1012628).
- powerpc: Fix is_kvm_guest() / kvm_para_available()
  (bsc#1012628).
- ALSA: firewire-lib: Fix 'amdtp_domain_start()' when no
  AMDTP_OUT_STREAM stream is found (bsc#1012628).
- serial: mvebu-uart: do not allow changing baudrate when uartclk
  is not available (bsc#1012628).
- serial: mvebu-uart: correctly calculate minimal possible
  baudrate (bsc#1012628).
- arm64: dts: marvell: armada-37xx: Fix reg for standard variant
  of UART (bsc#1012628).
- powerpc/64s: fix hash page fault interrupt handler
  (bsc#1012628).
- powerpc/64s/interrupt: preserve regs->softe for NMI interrupts
  (bsc#1012628).
- vfio/pci: Handle concurrent vma faults (bsc#1012628).
- mm/huge_memory.c: remove dedicated macro HPAGE_CACHE_INDEX_MASK
  (bsc#1012628).
- mm/huge_memory.c: add missing read-only THP checking in
  transparent_hugepage_enabled() (bsc#1012628).
- mm/huge_memory.c: don't discard hugepage if other processes
  are mapping it (bsc#1012628).
- hugetlb: remove prep_compound_huge_page cleanup (bsc#1012628).
- mm/z3fold: fix potential memory leak in z3fold_destroy_pool()
  (bsc#1012628).
- mm/z3fold: use release_z3fold_page_locked() to release locked
  z3fold page (bsc#1012628).
- mm: migrate: fix missing update page_private to
  hugetlb_page_subpool (bsc#1012628).
- mm/zswap.c: fix two bugs in zswap_writeback_entry()
  (bsc#1012628).
- kfence: unconditionally use unbound work queue (bsc#1012628).
- lib/math/rational.c: fix divide by zero (bsc#1012628).
- selftests/vm/pkeys: fix alloc_random_pkey() to make it really,
  really random (bsc#1012628).
- selftests/vm/pkeys: handle negative sys_pkey_alloc() return code
  (bsc#1012628).
- selftests/vm/pkeys: refill shadow register after implicit
  kernel write (bsc#1012628).
- perf llvm: Return -ENOMEM when asprintf() fails (bsc#1012628).
- i2c: mpc: Restore reread of I2C status register (bsc#1012628).
- csky: syscache: Fixup duplicate cache flush (bsc#1012628).
- exfat: handle wrong stream entry size in exfat_readdir()
  (bsc#1012628).
- scsi: megaraid_sas: Send all non-RW I/Os for TYPE_ENCLOSURE
  device through firmware (bsc#1012628).
- scsi: fc: Correct RHBA attributes length (bsc#1012628).
- scsi: target: cxgbit: Unmap DMA buffer before calling
  target_execute_cmd() (bsc#1012628).
- scsi: lpfc: Fix unreleased RPIs when NPIV ports are created
  (bsc#1012628).
- scsi: lpfc: Fix Node recovery when driver is handling
  simultaneous PLOGIs (bsc#1012628).
- scsi: libfc: Correct the condition check and invalid argument
  passed (bsc#1012628).
- mailbox: qcom-ipcc: Fix IPCC mbox channel exhaustion
  (bsc#1012628).
- fscrypt: don't ignore minor_hash when hash is 0 (bsc#1012628).
- fscrypt: fix derivation of SipHash keys on big endian CPUs
  (bsc#1012628).
- tpm: Replace WARN_ONCE() with dev_err_once() in tpm_tis_status()
  (bsc#1012628).
- erofs: fix error return code in erofs_read_superblock()
  (bsc#1012628).
- block: return the correct bvec when checking for gaps
  (bsc#1012628).
- io_uring: fix blocking inline submission (bsc#1012628).
- io_uring: add IOPOLL and reserved field checks to
  IORING_OP_RENAMEAT (bsc#1012628).
- io_uring: add IOPOLL and reserved field checks to
  IORING_OP_UNLINKAT (bsc#1012628).
- mmc: block: Disable CMDQ on the ioctl path (bsc#1012628).
- mmc: vub3000: fix control-request direction (bsc#1012628).
- media: exynos4-is: remove a now unused integer (bsc#1012628).
- scsi: core: Retry I/O for Notify (Enable Spinup) Required error
  (bsc#1012628).
- crypto: qce - fix error return code in
  qce_skcipher_async_req_handle() (bsc#1012628).
- s390: preempt: Fix preempt_count initialization (bsc#1012628).
- sched: Stop PF_NO_SETAFFINITY from being inherited by various
  init system threads (bsc#1012628).
- cred: add missing return error code when set_cred_ucounts()
  failed (bsc#1012628).
- iommu/dma: Fix compile warning in 32-bit builds (bsc#1012628).
- powerpc/preempt: Don't touch the idle task's preempt_count
  during hotplug (bsc#1012628).
- Update config files.
  WWAN_CORE is gone by 89212e160b81.
  PSTORE_BLK is broken by d07f3b081ee6.
- commit 89416ca
* Mon Jul 12 2021 mkubecek@suse.cz
- Update to 5.14-rc1
- eliminated 13 patches (3 stable, 9 mainline, 1 obsolete SUSE)
  - patches.kernel.org/5.13.1-001-Revert-KVM-x86-mmu-Drop-kvm_mmu_extended_role..patch
  - patches.kernel.org/5.13.1-002-mm-page_alloc-correct-return-value-of-populate.patch
  - patches.kernel.org/5.13.1-003-Linux-5.13.1.patch
  - patches.rpmify/scripts-mkmakefile-honor-second-argument.patch
  - patches.suse/ACPI-PM-s2idle-Add-missing-LPS0-functions-for-AMD.patch
  - patches.suse/ACPI-processor-idle-Fix-up-C-state-latency-if-not-or.patch
  - patches.suse/Bluetooth-btqca-Don-t-modify-firmware-contents-in-pl.patch
  - patches.suse/Input-elants_i2c-Fix-NULL-dereference-at-probing.patch
  - patches.suse/brcmfmac-Add-clm_blob-firmware-files-to-modinfo.patch
  - patches.suse/brcmfmac-Delete-second-brcm-folder-hierarchy.patch
  - patches.suse/crypto-ccp-Annotate-SEV-Firmware-file-names.patch
  - patches.suse/pinctrl-bcm2835-accept-fewer-than-expected-irqs.patch
  - patches.suse/proc-Avoid-mixing-integer-types-in-mem_rw.patch
- refresh
  - patches.suse/add-product-identifying-information-to-vmcoreinfo.patch
  - patches.suse/dm-table-switch-to-readonly
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/kernel-add-release-status-to-kernel-build.patch
  - patches.suse/supported-flag
- disable ARM architectures (need config update)
- new config options
  - General setup
  - SCHED_CORE=y
  - Power management and ACPI options
  - ACPI_PRMT=y
  - TPS68470_PMIC_OPREGION=y
  - Block layer
  - BLK_CGROUP_FC_APPID=y
  - BLK_CGROUP_IOPRIO=y
  - Networking support
  - NETFILTER_NETLINK_HOOK=m
  - File systems
  - HUGETLB_PAGE_FREE_VMEMMAP_DEFAULT_ON=n
  - Security options
  - IMA_DISABLE_HTABLE=n
  - Kernel hacking
  - STACKTRACE_BUILD_ID=y
  - DEBUG_FORCE_FUNCTION_ALIGN_64B=n
  - OSNOISE_TRACER=y
  - TIMERLAT_TRACER=y
  - TEST_SCANF=n
  - TEST_CLOCKSOURCE_WATCHDOG=n
  - PCI support
  - CXL_ACPI=m
  - CXL_PMEM=m
  - SCSI device support
  - SCSI_MPI3MR=m
  - SCSI_EFCT=m
  - Network device support
  - DWMAC_LOONGSON=m
  - MEDIATEK_GE_PHY=m
  - MOTORCOMM_PHY=m
  - WWAN_HWSIM=m
  - RPMSG_WWAN_CTRL=m
  - IOSM=m
  - PHY_CAN_TRANSCEIVER=m
  - INFINIBAND_IRDMA=m
  - Hardware Monitoring support
  - SENSORS_DPS920AB=m
  - SENSORS_MP2888=m
  - SENSORS_PIM4328=m
  - SENSORS_SHT4x=m
  - Voltage and Current Regulator Support
  - REGULATOR_MAX8893=m
  - REGULATOR_RT6160=m
  - REGULATOR_RT6245=m
  - REGULATOR_RT4831=m
  - Graphics support
  - HSA_AMD_SVM=y
  - DRM_SIMPLEDRM=m
  - DRM_HYPERV=m
  - FB_SSD1307=m
  - BACKLIGHT_RT4831=m
  - Sound card support
  - SND_SOC_INTEL_SOF_CS42L42_MACH=m
  - SND_SOC_TFA989X=n
  - SND_SOC_WCD938X_SDW=n
  - X86 Platform Specific Device Drivers
  - DELL_WMI_PRIVACY=y
  - WIRELESS_HOTKEY=m
  - THINKPAD_LMI=m
  - X86_PLATFORM_DRIVERS_INTEL=y
  - INTEL_SKL_INT3472=m
  - Common Clock Framework
  - ICST=n
  - CLK_SP810=n
  - LMK04832=m
  - IOMMU Hardware Support
  - VIRTIO_IOMMU=m
  - Industrial I/O support
  - FXLS8962AF_I2C=n
  - FXLS8962AF_SPI=n
  - SCA3300=n
  - TI_TSC2046=n
  - SPS30_I2C=n
  - SPS30_SERIAL=n
  - IIO_ST_LSM9DS0=n
  - TSL2591=n
  - TMP117=n
  - Misc devices
  - MTD_MCHP48L640=n
  - JOYSTICK_QWIIC=m
  - XILLYUSB=m
  - GPIO_TPS68470=n
  - BATTERY_RT5033=m
  - WATCHDOG_HRTIMER_PRETIMEOUT=y
  - MFD_RT4831=m
  - VIDEO_IMX208=m
  - LEDS_LT3593=m
  - RESET_MCHP_SPARX5=n
  - OF dependent (i386, ppc64 / ppc64le, riscv64)
  - MFD_QCOM_PM8008=n
  - DRM_ITE_IT66121=n
  - DRM_TI_SN65DSI83=n
  - i386
  - DRM_CROS_EC_ANX7688=n
  - ppc64 / ppc64le
  - STRICT_MODULE_RWX=y
  - PPC_RFI_SRR_DEBUG=n
  - ppc64
  - PS3_VERBOSE_RESULT=n
  - s390x
  - SPARX5_SWITCH=m
  - RESET_TI_SYSCON=n
  - riscv64
  - PHYS_RAM_BASE=0x80000000 (default)
  - VMAP_STACK=y
  - TRANSPARENT_HUGEPAGE=y
  - READ_ONLY_THP_FOR_FS=y
  - SND_SOC_RK817=n
  - SND_SOC_RT5640=m
  - POLARFIRE_SOC_MAILBOX=m
  - DEV_DAX=m
  - STACK_HASH_ORDER=20 (default)
  - KFENCE=y
  - KFENCE_STATIC_KEYS=y
  - KFENCE_SAMPLE_INTERVAL=0 (other archs, see bsc#1185565)
  - KFENCE_NUM_OBJECTS=255 (default)
  - KFENCE_STRESS_TEST_FAULTS=0 (default)
- commit 34fe32a
* Mon Jul 12 2021 jslaby@suse.cz
- Revert "UsrMerge the kernel (boo#1184804)"
  This reverts commit 6f5ed044f52ae3de78db9492d404f9c88d29b938 as it still
  breaks in MicroOS. This time, selinux policies forbid accessing
  sysctl.conf which is now moved from /boot to /usr/lib.
- Revert "UsrMerge the kernel (boo#1184804)"
  This reverts commit 6f5ed044f52ae3de78db9492d404f9c88d29b938 as it:
  1) breaks installation in Leap/SLE -- no initrd is generated.
  2) breaks installation-images -- expecting kernel in /boot and modules
  in /lib.
- commit 999e604
* Sun Jul 11 2021 schwab@suse.de
- config: riscv64: enable DRM_I2C_NXP_TDA998X
  This also selects SND_SOC_HDMI_CODEC, SND_PCM_ELD, SND_PCM_IEC958.
- commit d56d022
* Sun Jul 11 2021 schwab@suse.de
- config: riscv64: enable MFD_TPS65086
  Also enable the related drivers GPIO_TPS65086 and REGULATOR_TPS65086.
- commit ce26f32
* Fri Jul  9 2021 mbrugger@suse.com
- arm64: Update config files. (bsc#1187589)
  Enable PL330 DMA controller.
- commit 0cb8827
* Fri Jul  9 2021 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Remove zdebug define used only once.
- commit 85a9fc2
* Thu Jul  8 2021 msuchanek@suse.de
- Update config files (boo#1187824).
  CRYPTO_FIPS=y
  CRYPTO_MANAGER_DISABLE_TESTS=n
- commit c81d16b
* Thu Jul  8 2021 msuchanek@suse.de
- kernel-binary.spec: Exctract s390 decompression code (jsc#SLE-17042).
- commit 7f97df2
* Thu Jul  8 2021 msuchanek@suse.de
- rpm/config.sh: Build on s390.
- commit 641dff8
* Thu Jul  8 2021 msuchanek@suse.de
- kernel-binary.spec: Fix up usrmerge for non-modular kernels.
- commit d718cd9
* Thu Jul  8 2021 jslaby@suse.cz
- Linux 5.13.1 (bsc#1012628).
- Revert "KVM: x86/mmu: Drop kvm_mmu_extended_role.cr4_la57 hack"
  (bsc#1012628).
- commit bfd7864
* Wed Jul  7 2021 schwab@suse.de
- config: riscv64: enable MFD_DA9063
  Also enable the related drivers DA9063_WATCHDOG, REGULATOR_DA9063,
  RTC_DRV_DA9063.
- commit 40fb687
* Mon Jul  5 2021 mkubecek@suse.cz
- update upstream references
- update upstream references of patches added in 5.14 merge window:
  - patches.suse/pinctrl-bcm2835-accept-fewer-than-expected-irqs.patch
  - patches.suse/proc-Avoid-mixing-integer-types-in-mem_rw.patch
- commit 9510801
* Thu Jul  1 2021 msuchanek@suse.de
- kernel-binary.spec: Remove obsolete and wrong comment
  mkmakefile is repleced by echo on newer kernel
- commit d9209e7
* Thu Jul  1 2021 mkubecek@suse.cz
- update upstream references
- update upstream references of patches added in 5.14 merge window:
  - patches.suse/ACPI-PM-s2idle-Add-missing-LPS0-functions-for-AMD.patch
  - patches.suse/ACPI-processor-idle-Fix-up-C-state-latency-if-not-or.patch
  - patches.suse/Bluetooth-btqca-Don-t-modify-firmware-contents-in-pl.patch
  - patches.suse/brcmfmac-Add-clm_blob-firmware-files-to-modinfo.patch
  - patches.suse/brcmfmac-Delete-second-brcm-folder-hierarchy.patch
  - patches.suse/crypto-ccp-Annotate-SEV-Firmware-file-names.patch
- commit f094788
* Thu Jul  1 2021 ptesarik@suse.cz
- Set CONFIG_SCSI_SNIC_DEBUG_FS=y (bsc#1158776 comment 19).
- commit d8e1777
* Thu Jul  1 2021 ptesarik@suse.cz
- Set CONFIG_BLK_SED_OPAL=y on arm64 (bsc#1158776 comment 16).
- commit 59a8e8d
* Thu Jul  1 2021 ptesarik@suse.cz
- Set CONFIG_SATA_ZPODD=y on arm64 (bsc#1158776 comment 14).
- commit aad226c
* Thu Jul  1 2021 ptesarik@suse.cz
- Disable MANDATORY_FILE_LOCKING on arm and arm64 (bsc#1158776 comment 12).
- commit b10530c
* Thu Jul  1 2021 ptesarik@suse.cz
- Disable 842 compression on arm64 (bsc#1158776 comment 11).
- commit 41a7837
* Thu Jul  1 2021 ptesarik@suse.cz
- Set CONFIG_USB_CHAOSKEY=m on arm64 (bsc#1158776 comment 9).
- commit e652a59
* Thu Jul  1 2021 ptesarik@suse.cz
- Set CONFIG_INET_DIAG_DESTROY=y on arm64 (bsc#1158776 comment 7).
- commit 1a13a0b
* Thu Jul  1 2021 ptesarik@suse.cz
- Set CONFIG_SLAB_FREELIST_RANDOM=y on arm64 (bsc#1158776 comment 6).
- commit 75baa7c
* Thu Jul  1 2021 ptesarik@suse.cz
- Disable CONFIG_PCCARD on arm64 (bsc#1158776 comment 2).
- commit 1c1f5ad
* Thu Jul  1 2021 jslaby@suse.cz
- mm/page_alloc: Correct return value of populated elements if
  bulk array is populated (bsc#1187901).
- commit b48104a
* Mon Jun 28 2021 jslaby@suse.cz
- ACPI: PM: s2idle: Add missing LPS0 functions for AMD
  (bsc#1185840).
- ACPI: processor idle: Fix up C-state latency if not ordered
  (bsc#1185840).
- Bluetooth: btqca: Don't modify firmware contents in-place
  (bsc#1187472).
- Input: elants_i2c - Fix NULL dereference at probing
  (bsc#1186454).
- mmc: sdhci-iproc: Cap min clock frequency on BCM2711
  (bsc#1176576).
- mmc: sdhci-iproc: Set SDHCI_QUIRK_CAP_CLOCK_BASE_BROKEN on
  BCM2711 (bsc#1176576).
- pinctrl: bcm2835: Accept fewer than expected IRQs (bsc#1181942).
- Refresh
  patches.suse/proc-Avoid-mixing-integer-types-in-mem_rw.patch.
  Port post-5.13 patches from the stable branch.
  Note that patches.suse/proc-Avoid-mixing-integer-types-in-mem_rw.patch
  is in the -mmotm tree, so that the updated upstream info (esp. the SHA)
  is subject to change.
- commit bd5babc
* Mon Jun 28 2021 jslaby@suse.cz
- Revert "drm/amdgpu/gfx10: enlarge CP_MEC_DOORBELL_RANGE_UPPER
  to cover full doorbell." (amd gpu reverts).
- Revert "drm/amdgpu/gfx9: fix the doorbell missing when in CGPG
  issue." (amd gpu reverts).
- commit 74bd8c0
* Mon Jun 28 2021 jslaby@suse.cz
- Refresh
  patches.suse/Input-elants_i2c-Fix-NULL-dereference-at-probing.patch.
- Refresh
  patches.suse/mmc-sdhci-iproc-cap-min-clock-frequency-on-bcm2711.patch.
- Refresh
  patches.suse/mmc-sdhci-iproc-set-sdhci_quirk_cap_clock_base_broken-on-bcm2711.patch.
  Update upstream statuses.
- commit 9cef814
* Mon Jun 28 2021 mkubecek@suse.cz
- Update to 5.13 final
- refresh configs
  - update headers
  - armv7hl: drop GPIO_TQMX86
- commit 54fc53e
* Fri Jun 25 2021 msuchanek@suse.de
- Revert "Update config files (bsc#1187167)" (bsc#1187711).
  The key is needed. When a random key is generaeted it is a problem with
  OBS repository setup. OBS should provide a signing key.
- commit 6b7eebf
* Wed Jun 23 2021 jslaby@suse.cz
- Linux 5.12.13 (bsc#1012628).
- dmaengine: idxd: add engine 'struct device' missing bus type
  assignment (bsc#1012628).
- dmaengine: idxd: add missing dsa driver unregister
  (bsc#1012628).
- dmaengine: fsl-dpaa2-qdma: Fix error return code in two
  functions (bsc#1012628).
- dmaengine: xilinx: dpdma: initialize registers before
  request_irq (bsc#1012628).
- dmaengine: ALTERA_MSGDMA depends on HAS_IOMEM (bsc#1012628).
- dmaengine: QCOM_HIDMA_MGMT depends on HAS_IOMEM (bsc#1012628).
- dmaengine: SF_PDMA depends on HAS_IOMEM (bsc#1012628).
- dmaengine: stedma40: add missing iounmap() on error in
  d40_probe() (bsc#1012628).
- afs: Fix an IS_ERR() vs NULL check (bsc#1012628).
- mm/memory-failure: make sure wait for page writeback in
  memory_failure (bsc#1012628).
- kvm: LAPIC: Restore guard to prevent illegal APIC register
  access (bsc#1012628).
- fanotify: fix copy_event_to_user() fid error clean up
  (bsc#1012628).
- batman-adv: Avoid WARN_ON timing related checks (bsc#1012628).
- staging: rtl8723bs: fix monitor netdev register/unregister
  (bsc#1012628).
- mac80211: fix skb length check in ieee80211_scan_rx()
  (bsc#1012628).
- mlxsw: reg: Spectrum-3: Enforce lowest max-shaper burst size
  of 11 (bsc#1012628).
- mlxsw: core: Set thermal zone polling delay argument to real
  value at init (bsc#1012628).
- libbpf: Fixes incorrect rx_ring_setup_done (bsc#1012628).
- net: ipv4: fix memory leak in netlbl_cipsov4_add_std
  (bsc#1012628).
- vrf: fix maximum MTU (bsc#1012628).
- net: rds: fix memory leak in rds_recvmsg (bsc#1012628).
- net: dsa: felix: re-enable TX flow control in
  ocelot_port_flush() (bsc#1012628).
- net: ena: fix DMA mapping function issues in XDP (bsc#1012628).
- net: lantiq: disable interrupt before sheduling NAPI
  (bsc#1012628).
- netfilter: nf_tables: initialize set before expression setup
  (bsc#1012628).
- netfilter: nft_fib_ipv6: skip ipv6 packets from any to
  link-local (bsc#1012628).
- ice: add ndo_bpf callback for safe mode netdev ops
  (bsc#1012628).
- ice: parameterize functions responsible for Tx ring management
  (bsc#1012628).
- udp: fix race between close() and udp_abort() (bsc#1012628).
- rtnetlink: Fix regression in bridge VLAN configuration
  (bsc#1012628).
- net/sched: act_ct: handle DNAT tuple collision (bsc#1012628).
- net/mlx5e: Fix use-after-free of encap entry in neigh update
  handler (bsc#1012628).
- net/mlx5e: Remove dependency in IPsec initialization flows
  (bsc#1012628).
- net/mlx5e: Fix page reclaim for dead peer hairpin (bsc#1012628).
- net/mlx5: Consider RoCE cap before init RDMA resources
  (bsc#1012628).
- net/mlx5: DR, Don't use SW steering when RoCE is not supported
  (bsc#1012628).
- Revert "net/mlx5: Arm only EQs with EQEs" (bsc#1012628).
- net/mlx5e: Block offload of outer header csum for UDP tunnels
  (bsc#1012628).
- net/mlx5e: Block offload of outer header csum for GRE tunnel
  (bsc#1012628).
- skbuff: fix incorrect msg_zerocopy copy notifications
  (bsc#1012628).
- netfilter: synproxy: Fix out of bounds when parsing TCP options
  (bsc#1012628).
- mptcp: Fix out of bounds when parsing TCP options (bsc#1012628).
- sch_cake: Fix out of bounds when parsing TCP options and header
  (bsc#1012628).
- mptcp: try harder to borrow memory from subflow under pressure
  (bsc#1012628).
- mptcp: wake-up readers only for in sequence data (bsc#1012628).
- mptcp: do not warn on bad input from the network (bsc#1012628).
- selftests: mptcp: enable syncookie only in absence of reorders
  (bsc#1012628).
- mptcp: fix soft lookup in subflow_error_report() (bsc#1012628).
- alx: Fix an error handling path in 'alx_probe()' (bsc#1012628).
- cxgb4: fix endianness when flashing boot image (bsc#1012628).
- cxgb4: fix sleep in atomic when flashing PHY firmware
  (bsc#1012628).
- cxgb4: halt chip before flashing PHY firmware image
  (bsc#1012628).
- net: stmmac: dwmac1000: Fix extended MAC address registers
  definition (bsc#1012628).
- net: make get_net_ns return error if NET_NS is disabled
  (bsc#1012628).
- net: qualcomm: rmnet: don't over-count statistics (bsc#1012628).
- ethtool: strset: fix message length calculation (bsc#1012628).
- qlcnic: Fix an error handling path in 'qlcnic_probe()'
  (bsc#1012628).
- netxen_nic: Fix an error handling path in 'netxen_nic_probe()'
  (bsc#1012628).
- cxgb4: fix wrong ethtool n-tuple rule lookup (bsc#1012628).
- ipv4: Fix device used for dst_alloc with local routes
  (bsc#1012628).
- net: qrtr: fix OOB Read in qrtr_endpoint_post (bsc#1012628).
- bpf: Fix leakage under speculation on mispredicted branches
  (bsc#1012628).
- net: mhi_net: Update the transmit handler prototype
  (bsc#1012628).
- ptp: improve max_adj check against unreasonable values
  (bsc#1012628).
- net: cdc_ncm: switch to eth%%d interface naming (bsc#1012628).
- lantiq: net: fix duplicated skb in rx descriptor ring
  (bsc#1012628).
- net: usb: fix possible use-after-free in smsc75xx_bind
  (bsc#1012628).
- net: fec_ptp: fix issue caused by refactor the fec_devtype
  (bsc#1012628).
- net: ipv4: fix memory leak in ip_mc_add1_src (bsc#1012628).
- net/af_unix: fix a data-race in unix_dgram_sendmsg /
  unix_release_sock (bsc#1012628).
- net/mlx5: Fix error path for set HCA defaults (bsc#1012628).
- net/mlx5: Check that driver was probed prior attaching the
  device (bsc#1012628).
- net/mlx5: E-Switch, Read PF mac address (bsc#1012628).
- net/mlx5: E-Switch, Allow setting GUID for host PF vport
  (bsc#1012628).
- net/mlx5: SF_DEV, remove SF device on invalid state
  (bsc#1012628).
- net/mlx5: DR, Fix STEv1 incorrect L3 decapsulation padding
  (bsc#1012628).
- net/mlx5e: Don't create devices during unload flow
  (bsc#1012628).
- net/mlx5: Reset mkey index on creation (bsc#1012628).
- be2net: Fix an error handling path in 'be_probe()'
  (bsc#1012628).
- net: hamradio: fix memory leak in mkiss_close (bsc#1012628).
- net: cdc_eem: fix tx fixup skb leak (bsc#1012628).
- cxgb4: fix wrong shift (bsc#1012628).
- bnxt_en: Rediscover PHY capabilities after firmware reset
  (bsc#1012628).
- bnxt_en: Fix TQM fastpath ring backing store computation
  (bsc#1012628).
- bnxt_en: Call bnxt_ethtool_free() in bnxt_init_one() error path
  (bsc#1012628).
- icmp: don't send out ICMP messages with a source address of
  0.0.0.0 (bsc#1012628).
- net: ethernet: fix potential use-after-free in ec_bhf_remove
  (bsc#1012628).
- regulator: cros-ec: Fix error code in dev_err message
  (bsc#1012628).
- regulator: bd70528: Fix off-by-one for buck123 .n_voltages
  setting (bsc#1012628).
- platform/x86: thinkpad_acpi: Add X1 Carbon Gen 9 second fan
  support (bsc#1012628).
- ASoC: rt5659: Fix the lost powers for the HDA header
  (bsc#1012628).
- phy: phy-mtk-tphy: Fix some resource leaks in mtk_phy_init()
  (bsc#1012628).
- ASoC: fsl-asoc-card: Set .owner attribute when registering card
  (bsc#1012628).
- regulator: mt6315: Fix function prototype for mt6315_map_mode
  (bsc#1012628).
- regulator: rtmv20: Fix to make regcache value first reading
  back from HW (bsc#1012628).
- spi: spi-zynq-qspi: Fix some wrong goto jumps & missing error
  code (bsc#1012628).
- sched/pelt: Ensure that *_sum is always synced with *_avg
  (bsc#1012628).
- ASoC: tas2562: Fix TDM_CFG0_SAMPRATE values (bsc#1012628).
- regulator: hi6421v600: Fix .vsel_mask setting (bsc#1012628).
- spi: stm32-qspi: Always wait BUSY bit to be cleared in
  stm32_qspi_wait_cmd() (bsc#1012628).
- regulator: rt4801: Fix NULL pointer dereference if
  priv->enable_gpios is NULL (bsc#1012628).
- ASoC: rt5682: Fix the fast discharge for headset unplugging
  in soundwire mode (bsc#1012628).
- pinctrl: ralink: rt2880: avoid to error in calls is pin is
  already enabled (bsc#1012628).
- drm/sun4i: dw-hdmi: Make HDMI PHY into a platform device
  (bsc#1012628).
- ASoC: qcom: lpass-cpu: Fix pop noise during audio capture begin
  (bsc#1012628).
- radeon: use memcpy_to/fromio for UVD fw upload (bsc#1012628).
- hwmon: (scpi-hwmon) shows the negative temperature properly
  (bsc#1012628).
- riscv: code patching only works on !XIP_KERNEL (bsc#1012628).
- mm: relocate 'write_protect_seq' in struct mm_struct
  (bsc#1012628).
- irqchip/gic-v3: Workaround inconsistent PMR setting on NMI entry
  (bsc#1012628).
- perf metricgroup: Fix find_evsel_group() event selector
  (bsc#1012628).
- perf metricgroup: Return error code from
  metricgroup__add_metric_sys_event_iter() (bsc#1012628).
- bpf: Inherit expanded/patched seen count from old aux data
  (bsc#1012628).
- bpf: Do not mark insn as seen under speculative path
  verification (bsc#1012628).
- can: bcm: fix infoleak in struct bcm_msg_head (bsc#1012628).
- can: bcm/raw/isotp: use per module netdevice notifier
  (bsc#1012628).
- can: j1939: fix Use-after-Free, hold skb ref while in use
  (bsc#1012628).
- can: mcba_usb: fix memory leak in mcba_usb (bsc#1012628).
- usb: core: hub: Disable autosuspend for Cypress CY7C65632
  (bsc#1012628).
- usb: chipidea: imx: Fix Battery Charger 1.2 CDP detection
  (bsc#1012628).
- tracing: Do not stop recording cmdlines when tracing is off
  (bsc#1012628).
- tracing: Do not stop recording comms if the trace file is
  being read (bsc#1012628).
- tracing: Do no increment trace_clock_global() by one
  (bsc#1012628).
- PCI: Mark TI C667X to avoid bus reset (bsc#1012628).
- PCI: Mark some NVIDIA GPUs to avoid bus reset (bsc#1012628).
- PCI: Mark AMD Navi14 GPU ATS as broken (bsc#1012628).
- PCI: aardvark: Fix kernel panic during PIO transfer
  (bsc#1012628).
- PCI: Add ACS quirk for Broadcom BCM57414 NIC (bsc#1012628).
- PCI: Work around Huawei Intelligent NIC VF FLR erratum
  (bsc#1012628).
- btrfs: zoned: fix negative space_info->bytes_readonly
  (bsc#1012628).
- s390/mcck: fix invalid KVM guest condition check (bsc#1012628).
- KVM: x86: Immediately reset the MMU context when the SMM flag
  is cleared (bsc#1012628).
- KVM: x86/mmu: Calculate and check "full" mmu_role for nested
  MMU (bsc#1012628).
- KVM: X86: Fix x86_emulator slab cache leak (bsc#1012628).
- s390/mcck: fix calculation of SIE critical section size
  (bsc#1012628).
- s390/ap: Fix hanging ioctl caused by wrong msg counter
  (bsc#1012628).
- ARCv2: save ABI registers across signal handling (bsc#1012628).
- x86/mm: Avoid truncating memblocks for SGX memory (bsc#1012628).
- x86/process: Check PF_KTHREAD and not current->mm for kernel
  threads (bsc#1012628).
- x86/ioremap: Map EFI-reserved memory as encrypted for SEV
  (bsc#1012628 bsc#1186884).
- x86/pkru: Write hardware init value to PKRU when xstate is init
  (bsc#1012628).
- x86/fpu: Prevent state corruption in __fpu__restore_sig()
  (bsc#1012628).
- x86/fpu: Invalidate FPU state after a failed XRSTOR from a
  user buffer (bsc#1012628).
- x86/fpu: Reset state for all signal restore failures
  (bsc#1012628).
- powerpc/perf: Fix crash in perf_instruction_pointer() when
  ppmu is not set (bsc#1012628).
- Makefile: lto: Pass -warn-stack-size only on LLD < 13.0.0
  (bsc#1012628).
- crash_core, vmcoreinfo: append 'SECTION_SIZE_BITS' to vmcoreinfo
  (bsc#1012628).
- dmaengine: pl330: fix wrong usage of spinlock flags in dma_cyclc
  (bsc#1012628).
- mac80211: fix deadlock in AP/VLAN handling (bsc#1012628).
- mac80211: Fix NULL ptr deref for injected rate info
  (bsc#1012628).
- mac80211: fix 'reset' debugfs locking (bsc#1012628).
- cfg80211: fix phy80211 symlink creation (bsc#1012628).
- cfg80211: shut down interfaces on failed resume (bsc#1012628).
- mac80211: move interface shutdown out of wiphy lock
  (bsc#1012628).
- mac80211: minstrel_ht: fix sample time check (bsc#1012628).
- cfg80211: make certificate generation more robust (bsc#1012628).
- cfg80211: avoid double free of PMSR request (bsc#1012628).
- drm/amdgpu/gfx10: enlarge CP_MEC_DOORBELL_RANGE_UPPER to cover
  full doorbell (bsc#1012628).
- drm/amdgpu/gfx9: fix the doorbell missing when in CGPG issue
  (bsc#1012628).
- net: ll_temac: Make sure to free skb when it is completely used
  (bsc#1012628).
- net: ll_temac: Fix TX BD buffer overwrite (bsc#1012628).
- net: bridge: fix vlan tunnel dst null pointer dereference
  (bsc#1012628).
- net: bridge: fix vlan tunnel dst refcnt when egressing
  (bsc#1012628).
- mm,hwpoison: fix race with hugetlb page allocation
  (bsc#1012628).
- mm/swap: fix pte_same_as_swp() not removing uffd-wp bit when
  compare (bsc#1012628).
- mm/hugetlb: expand restore_reserve_on_error functionality
  (bsc#1012628).
- mm/slub: clarify verification reporting (bsc#1012628).
- mm/slub: fix redzoning for small allocations (bsc#1012628).
- mm/slub: actually fix freelist pointer vs redzoning
  (bsc#1012628).
- mm/slub.c: include swab.h (bsc#1012628).
- net: stmmac: disable clocks in stmmac_remove_config_dt()
  (bsc#1012628).
- net: fec_ptp: add clock rate zero check (bsc#1012628).
- tools headers UAPI: Sync linux/in.h copy with the kernel sources
  (bsc#1012628).
- perf beauty: Update copy of linux/socket.h with the kernel
  sources (bsc#1012628).
- usb: dwc3: debugfs: Add and remove endpoint dirs dynamically
  (bsc#1012628).
- usb: dwc3: core: fix kernel panic when do reboot (bsc#1012628).
- Delete
  patches.suse/0001-x86-ioremap-Map-efi_mem_reserve-memory-as-encrypted-.patch.
- commit 2ab6e2b
* Wed Jun 23 2021 schwab@suse.de
- Add dtb-microchip
- commit c797107
* Mon Jun 21 2021 mkubecek@suse.cz
- Update to 5.13-rc7
- eliminate 1 patch
  - patches.suse/0001-x86-ioremap-Map-efi_mem_reserve-memory-as-encrypted-.patch
- refresh configs
- commit d808585
* Sat Jun 19 2021 tiwai@suse.de
- Bluetooth: btqca: Don't modify firmware contents in-place
  (bsc#1187472).
- commit 43254cf
* Fri Jun 18 2021 jslaby@suse.cz
- Linux 5.12.12 (bsc#1012628).
- fib: Return the correct errno code (bsc#1012628).
- net: Return the correct errno code (bsc#1012628).
- net/x25: Return the correct errno code (bsc#1012628).
- rtnetlink: Fix missing error code in rtnl_bridge_notify()
  (bsc#1012628).
- drm/amd/amdgpu:save psp ring wptr to avoid attack (bsc#1012628).
- drm/amd/display: Fix potential memory leak in DMUB hw_init
  (bsc#1012628).
- drm/amdgpu: refine amdgpu_fru_get_product_info (bsc#1012628).
- drm/amd/display: Allow bandwidth validation for 0 streams
  (bsc#1012628).
- net: ipconfig: Don't override command-line hostnames or domains
  (bsc#1012628).
- nvme-loop: do not warn for deleted controllers during reset
  (bsc#1012628).
- nvme-loop: check for NVME_LOOP_Q_LIVE in
  nvme_loop_destroy_admin_queue() (bsc#1012628).
- nvme-loop: clear NVME_LOOP_Q_LIVE when
  nvme_loop_configure_admin_queue() fails (bsc#1012628).
- nvme-loop: reset queue count to 1 in
  nvme_loop_destroy_io_queues() (bsc#1012628).
- scsi: scsi_devinfo: Add blacklist entry for HPE OPEN-V
  (bsc#1012628).
- Bluetooth: Add a new USB ID for RTL8822CE (bsc#1012628).
- scsi: qedf: Do not put host in qedf_vport_create()
  unconditionally (bsc#1012628).
- ethernet: myri10ge: Fix missing error code in myri10ge_probe()
  (bsc#1012628).
- scsi: target: core: Fix warning on realtime kernels
  (bsc#1012628).
- gfs2: Fix use-after-free in gfs2_glock_shrink_scan
  (bsc#1012628).
- mt76: mt7921: remove leftover 80+80 HE capability (bsc#1012628).
- ALSA: hda: Add AlderLake-M PCI ID (bsc#1012628).
- riscv: Use -mno-relax when using lld linker (bsc#1012628).
- HID: intel-ish-hid: ipc: Add Alder Lake device IDs
  (bsc#1012628).
- HID: gt683r: add missing MODULE_DEVICE_TABLE (bsc#1012628).
- HID: multitouch: Disable event reporting on suspend on the
  Asus T101HA touchpad (bsc#1012628).
- gfs2: Clean up revokes on normal withdraws (bsc#1012628).
- gfs2: fix a deadlock on withdraw-during-mount (bsc#1012628).
- gfs2: Prevent direct-I/O write fallback errors from getting lost
  (bsc#1012628).
- ARM: OMAP2+: Fix build warning when mmc_omap is not built
  (bsc#1012628).
- ARM: OMAP1: Fix use of possibly uninitialized irq variable
  (bsc#1012628).
- hwmon/pmbus: (q54sj108a2) The PMBUS_MFR_ID is actually 6 chars
  instead of 5 (bsc#1012628).
- drm/tegra: sor: Fully initialize SOR before registration
  (bsc#1012628).
- gpu: host1x: Split up client initalization and registration
  (bsc#1012628).
- drm/tegra: sor: Do not leak runtime PM reference (bsc#1012628).
- mt76: mt7921: fix max aggregation subframes setting
  (bsc#1012628).
- HID: usbhid: fix info leak in hid_submit_ctrl (bsc#1012628).
- HID: Add BUS_VIRTUAL to hid_connect logging (bsc#1012628).
- HID: multitouch: set Stylus suffix for Stylus-application
  devices, too (bsc#1012628).
- HID: quirks: Add quirk for Lenovo optical mouse (bsc#1012628).
- HID: asus: filter G713/G733 key event to prevent shutdown
  (bsc#1012628).
- HID: hid-sensor-hub: Return error for hid_set_field() failure
  (bsc#1012628).
- HID: hid-input: add mapping for emoji picker key (bsc#1012628).
- HID: a4tech: use A4_2WHEEL_MOUSE_HACK_B8 for A4TECH NB-95
  (bsc#1012628).
- HID: quirks: Add HID_QUIRK_NO_INIT_REPORTS quirk for Dell K15A
  keyboard-dock (bsc#1012628).
- HID: quirks: Set INCREMENT_USAGE_ON_DUPLICATE for Saitek X65
  (bsc#1012628).
- HID: asus: Filter keyboard EC for old ROG keyboard
  (bsc#1012628).
- net: ieee802154: fix null deref in parse dev addr (bsc#1012628).
- commit 0e46a2c
* Thu Jun 17 2021 ludwig.nussel@suse.de
- UsrMerge the kernel (boo#1184804)
- Move files in /boot to modules dir
  The file names in /boot are included as %%ghost links. The %%post script
  creates symlinks for the kernel, sysctl.conf and System.map in
  /boot for compatibility. Some tools require adjustments before we
  can drop those links. If boot is a separate partition, a copy is
  used instead of a link.
  The logic for /boot/vmlinuz and /boot/initrd doesn't change with
  this patch.
- Use /usr/lib/modules as module dir when usermerge is active in the
  target distro.
- commit 6f5ed04
* Wed Jun 16 2021 mbrugger@suse.com
- Refresh
  patches.suse/brcmfmac-Add-clm_blob-firmware-files-to-modinfo.patch.
- Refresh
  patches.suse/brcmfmac-Delete-second-brcm-folder-hierarchy.patch.
- commit b5a438c
* Wed Jun 16 2021 mbrugger@suse.com
- Refresh
  patches.suse/brcmfmac-Add-clm_blob-firmware-files-to-modinfo.patch.
- Refresh
  patches.suse/brcmfmac-Delete-second-brcm-folder-hierarchy.patch.
- commit e486bc1
* Wed Jun 16 2021 tiwai@suse.de
- Update config files: CONFIG_SND_HDA_INTEL=m for armv7hl, too (bsc#1187334)
  It's used by openQA.
- commit e752118
* Wed Jun 16 2021 jslaby@suse.cz
- Linux 5.12.11 (bsc#1012628).
- proc: Track /proc/$pid/attr/ opener mm_struct (bsc#1012628).
- ASoC: max98088: fix ni clock divider calculation (bsc#1012628).
- ASoC: amd: fix for pcm_read() error (bsc#1012628).
- spi: Fix spi device unregister flow (bsc#1012628).
- spi: spi-zynq-qspi: Fix stack violation bug (bsc#1012628).
- bpf: Forbid trampoline attach for functions with variable
  arguments (bsc#1012628).
- ASoC: codecs: lpass-rx-macro: add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- ASoC: codecs: lpass-tx-macro: add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- net/nfc/rawsock.c: fix a permission check bug (bsc#1012628).
- usb: cdns3: Fix runtime PM imbalance on error (bsc#1012628).
- ASoC: Intel: bytcr_rt5640: Add quirk for the Glavey TM800A550L
  tablet (bsc#1012628).
- ASoC: Intel: bytcr_rt5640: Add quirk for the Lenovo Miix 3-830
  tablet (bsc#1012628).
- bpf: Add deny list of btf ids check for tracing programs
  (bsc#1012628).
- vfio-ccw: Reset FSM state to IDLE inside FSM (bsc#1012628).
- vfio-ccw: Serialize FSM IDLE state with I/O completion
  (bsc#1012628).
- ASoC: sti-sas: add missing MODULE_DEVICE_TABLE (bsc#1012628).
- spi: sprd: Add missing MODULE_DEVICE_TABLE (bsc#1012628).
- usb: chipidea: udc: assign interrupt number to USB gadget
  structure (bsc#1012628).
- isdn: mISDN: netjet: Fix crash in nj_probe: (bsc#1012628).
- bonding: init notify_work earlier to avoid uninitialized use
  (bsc#1012628).
- netlink: disable IRQs for netlink_lock_table() (bsc#1012628).
- net: mdiobus: get rid of a BUG_ON() (bsc#1012628).
- cgroup: disable controllers at parse time (bsc#1012628).
- wq: handle VM suspension in stall detection (bsc#1012628).
- net/qla3xxx: fix schedule while atomic in ql_sem_spinlock
  (bsc#1012628).
- RDS tcp loopback connection can hang (bsc#1012628).
- net:sfc: fix non-freed irq in legacy irq mode (bsc#1012628).
- scsi: bnx2fc: Return failure if io_req is already in ABTS
  processing (bsc#1012628).
- scsi: vmw_pvscsi: Set correct residual data length
  (bsc#1012628).
- scsi: hisi_sas: Drop free_irq() of devm_request_irq() allocated
  irq (bsc#1012628).
- scsi: target: qla2xxx: Wait for stop_phase1 at WWN removal
  (bsc#1012628).
- net: macb: ensure the device is available before accessing
  GEMGXL control registers (bsc#1012628).
- net: appletalk: cops: Fix data race in cops_probe1
  (bsc#1012628).
- net: dsa: microchip: enable phy errata workaround on 9567
  (bsc#1012628).
- Makefile: LTO: have linker check -Wframe-larger-than
  (bsc#1012628).
- nvme-fabrics: decode host pathing error for connect
  (bsc#1012628).
- MIPS: Fix kernel hang under FUNCTION_GRAPH_TRACER and
  PREEMPT_TRACER (bsc#1012628).
- bpf, selftests: Adjust few selftest result_unpriv outcomes
  (bsc#1012628).
- dm verity: fix require_signatures module_param permissions
  (bsc#1012628).
- bnx2x: Fix missing error code in bnx2x_iov_init_one()
  (bsc#1012628).
- nvme-tcp: remove incorrect Kconfig dep in BLK_DEV_NVME
  (bsc#1012628).
- nvmet: fix false keep-alive timeout when a controller is torn
  down (bsc#1012628).
- powerpc/fsl: set fsl,i2c-erratum-a004447 flag for P2041 i2c
  controllers (bsc#1012628).
- powerpc/fsl: set fsl,i2c-erratum-a004447 flag for P1010 i2c
  controllers (bsc#1012628).
- spi: Don't have controller clean up spi device before driver
  unbind (bsc#1012628).
- spi: Cleanup on failure of initial setup (bsc#1012628).
- i2c: mpc: Make use of i2c_recover_bus() (bsc#1012628).
- i2c: mpc: implement erratum A-004447 workaround (bsc#1012628).
- ALSA: seq: Fix race of snd_seq_timer_open() (bsc#1012628).
- ALSA: firewire-lib: fix the context to call snd_pcm_stop_xrun()
  (bsc#1012628).
- ALSA: hda/realtek: headphone and mic don't work on an Acer
  laptop (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs and speaker for HP
  Elite Dragonfly G2 (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs and speaker for HP
  EliteBook x360 1040 G8 (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP EliteBook 840
  Aero G8 (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP ZBook Power G8
  (bsc#1012628).
- spi: bcm2835: Fix out-of-bounds access with more than 4 slaves
  (bsc#1012628).
- Revert "ACPI: sleep: Put the FACS table after using it"
  (bsc#1012628).
- drm: Fix use-after-free read in drm_getunique() (bsc#1012628).
- drm: Lock pointer access in drm_master_release() (bsc#1012628).
- x86, lto: Pass -stack-alignment only on LLD < 13.0.0
  (bsc#1012628).
- perf/x86/intel/uncore: Fix M2M event umask for Ice Lake server
  (bsc#1012628).
- KVM: x86: Unload MMU on guest TLB flush if TDP disabled to
  force MMU sync (bsc#1012628).
- KVM: X86: MMU: Use the correct inherited permissions to get
  shadow page (bsc#1012628).
- kvm: avoid speculation-based attacks from out-of-range memslot
  accesses (bsc#1012628).
- staging: rtl8723bs: Fix uninitialized variables (bsc#1012628).
- usb: misc: brcmstb-usb-pinmap: check return value after calling
  platform_get_resource() (bsc#1012628).
- misc: rtsx: separate aspm mode into MODE_REG and MODE_CFG
  (bsc#1012628).
- bus: mhi: pci_generic: Fix possible use-after-free in
  mhi_pci_remove() (bsc#1012628).
- tick/nohz: Only check for RCU deferred wakeup on user/guest
  entry when needed (bsc#1012628).
- bcache: remove bcache device self-defined readahead
  (bsc#1012628).
- bcache: avoid oversized read request in cache missing code path
  (bsc#1012628).
- async_xor: check src_offs is not NULL before updating it
  (bsc#1012628).
- btrfs: do not write supers if we have an fs error (bsc#1012628).
- btrfs: zoned: fix zone number to sector/physical calculation
  (bsc#1012628).
- btrfs: return value from btrfs_mark_extent_written() in case
  of error (bsc#1012628).
- btrfs: promote debugging asserts to full-fledged checks in
  validate_super (bsc#1012628).
- coredump: Limit what can interrupt coredumps (bsc#1012628).
- cgroup1: don't allow '\n' in renaming (bsc#1012628).
- ftrace: Do not blindly read the ip address in ftrace_bug()
  (bsc#1012628).
- tracing: Correct the length check which causes memory corruption
  (bsc#1012628).
- tools/bootconfig: Fix a build error accroding to undefined
  fallthrough (bsc#1012628).
- mmc: renesas_sdhi: abort tuning when timeout detected
  (bsc#1012628).
- mmc: renesas_sdhi: Fix HS400 on R-Car M3-W+ (bsc#1012628).
- USB: f_ncm: ncm_bitrate (speed) is unsigned (bsc#1012628).
- usb: f_ncm: only first packet of aggregate needs to start timer
  (bsc#1012628).
- usb: pd: Set PD_T_SINK_WAIT_CAP to 310ms (bsc#1012628).
- usb: dwc3-meson-g12a: fix usb2 PHY glue init when phy0 is
  disabled (bsc#1012628).
- usb: dwc3: meson-g12a: Disable the regulator in the error
  handling path of the probe (bsc#1012628).
- usb: dwc3: gadget: Bail from dwc3_gadget_exit() if dwc->gadget
  is NULL (bsc#1012628).
- usb: dwc3: ep0: fix NULL pointer exception (bsc#1012628).
- usb: musb: fix MUSB_QUIRK_B_DISCONNECT_99 handling
  (bsc#1012628).
- usb: typec: wcove: Use LE to CPU conversion when accessing
  msg->header (bsc#1012628).
- usb: typec: ucsi: Clear PPM capability data in ucsi_init()
  error path (bsc#1012628).
- usb: typec: intel_pmc_mux: Put fwnode in error case during
  - >probe() (bsc#1012628).
- usb: typec: intel_pmc_mux: Add missed error check for
  devm_ioremap_resource() (bsc#1012628).
- usb: gadget: f_fs: Ensure io_completion_wq is idle during unbind
  (bsc#1012628).
- USB: serial: ftdi_sio: add NovaTech OrionMX product ID
  (bsc#1012628).
- USB: serial: omninet: add device id for Zyxel Omni 56K Plus
  (bsc#1012628).
- USB: serial: quatech2: fix control-request directions
  (bsc#1012628).
- USB: serial: cp210x: fix alternate function for CP2102N QFN20
  (bsc#1012628).
- USB: serial: cp210x: fix CP2102N-A01 modem control
  (bsc#1012628).
- usb: cdnsp: Fix deadlock issue in cdnsp_thread_irq_handler
  (bsc#1012628).
- usb: gadget: eem: fix wrong eem header operation (bsc#1012628).
- usb: fix various gadgets null ptr deref on 10gbps cabling
  (bsc#1012628).
- usb: fix various gadget panics on 10gbps cabling (bsc#1012628).
- usb: typec: tcpm: Properly handle Alert and Status Messages
  (bsc#1012628).
- usb: typec: tcpm: cancel vdm and state machine hrtimer when
  unregister tcpm port (bsc#1012628).
- usb: typec: tcpm: cancel frs hrtimer when unregister tcpm port
  (bsc#1012628).
- usb: typec: tcpm: Do not finish VDM AMS for retrying Responses
  (bsc#1012628).
- regulator: core: resolve supply for boot-on/always-on regulators
  (bsc#1012628).
- regulator: max77620: Use device_set_of_node_from_dev()
  (bsc#1012628).
- regulator: bd718x7: Fix the BUCK7 voltage setting on BD71837
  (bsc#1012628).
- regulator: da9121: Return REGULATOR_MODE_INVALID for invalid
  mode (bsc#1012628).
- regulator: fan53880: Fix missing n_voltages setting
  (bsc#1012628).
- regulator: fixed: Ensure enable_counter is correct if
  reg_domain_disable fails (bsc#1012628).
- regulator: scmi: Fix off-by-one for linear regulators
  .n_voltages setting (bsc#1012628).
- regulator: bd71828: Fix .n_voltages settings (bsc#1012628).
- regulator: atc260x: Fix n_voltages and min_sel for pickable
  linear ranges (bsc#1012628).
- regulator: rtmv20: Fix .set_current_limit/.get_current_limit
  callbacks (bsc#1012628).
- phy: usb: Fix misuse of IS_ENABLED (bsc#1012628).
- usb: cdns3: Enable TDL_CHK only for OUT ep (bsc#1012628).
- usb: dwc3: gadget: Disable gadget IRQ during pullup disable
  (bsc#1012628).
- usb: typec: tcpm: Correct the responses in SVDM Version 2.0 DFP
  (bsc#1012628).
- usb: typec: tcpm: Fix misuses of AMS invocation (bsc#1012628).
- usb: typec: mux: Fix copy-paste mistake in typec_mux_match
  (bsc#1012628).
- drm/mcde: Fix off by 10^3 in calculation (bsc#1012628).
- drm/msm/a6xx: fix incorrectly set uavflagprd_inv field for A650
  (bsc#1012628).
- drm/msm/a6xx: update/fix CP_PROTECT initialization
  (bsc#1012628).
- drm/msm/a6xx: avoid shadow NULL reference in failure path
  (bsc#1012628).
- hwmon: (corsair-psu) fix suspend behavior (bsc#1012628).
- hwmon: (tps23861) define regmap max register (bsc#1012628).
- hwmon: (tps23861) set current shunt value (bsc#1012628).
- hwmon: (tps23861) correct shunt LSB values (bsc#1012628).
- RDMA/ipoib: Fix warning caused by destroying non-initial netns
  (bsc#1012628).
- RDMA/mlx5: Use different doorbell memory for different processes
  (bsc#1012628).
- RDMA/mlx4: Do not map the core_clock page to user space unless
  enabled (bsc#1012628).
- RDMA/mlx5: Block FDB rules when not in switchdev mode
  (bsc#1012628).
- RDMA: Verify port when creating flow rule (bsc#1012628).
- ARM: cpuidle: Avoid orphan section warning (bsc#1012628).
- vmlinux.lds.h: Avoid orphan section with !SMP (bsc#1012628).
- tools/bootconfig: Fix error return code in apply_xbc()
  (bsc#1012628).
- phy: cadence: Sierra: Fix error return code in
  cdns_sierra_phy_probe() (bsc#1012628).
- ASoC: core: Fix Null-point-dereference in fmt_single_name()
  (bsc#1012628).
- ASoC: meson: gx-card: fix sound-dai dt schema (bsc#1012628).
- phy: ti: Fix an error code in wiz_probe() (bsc#1012628).
- gpio: wcd934x: Fix shift-out-of-bounds error (bsc#1012628).
- pinctrl: qcom: Fix duplication in gpio_groups (bsc#1012628).
- perf/x86/intel/uncore: Fix a kernel WARNING triggered by
  maxcpus=1 (bsc#1012628).
- perf: Fix data race between pin_count increment/decrement
  (bsc#1012628).
- dt-bindings: connector: Replace BIT macro with generic bit ops
  (bsc#1012628).
- sched/fair: Keep load_avg and load_sum synced (bsc#1012628).
- sched/fair: Make sure to update tg contrib for blocked load
  (bsc#1012628).
- ASoC: SOF: reset enabled_cores state at suspend (bsc#1012628).
- sched/fair: Fix util_est UTIL_AVG_UNCHANGED handling
  (bsc#1012628).
- platform/surface: aggregator: Fix event disable function
  (bsc#1012628).
- x86/nmi_watchdog: Fix old-style NMI watchdog regression on
  old Intel CPUs (bsc#1012628).
- KVM: x86: Ensure liveliness of nested VM-Enter fail tracepoint
  message (bsc#1012628).
- IB/mlx5: Fix initializing CQ fragments buffer (bsc#1012628).
- NFS: Fix a potential NULL dereference in nfs_get_client()
  (bsc#1012628).
- NFSv4: Fix deadlock between nfs4_evict_inode() and
  nfs4_opendata_get_inode() (bsc#1012628).
- pinctrl: qcom: Make it possible to select SC8180x TLMM
  (bsc#1012628).
- perf session: Correct buffer copying when peeking events
  (bsc#1012628).
- kvm: fix previous commit for 32-bit builds (bsc#1012628).
- NFS: Fix use-after-free in nfs4_init_client() (bsc#1012628).
- NFSv4: Fix second deadlock in nfs4_evict_inode() (bsc#1012628).
- NFSv4: nfs4_proc_set_acl needs to restore NFS_CAP_UIDGID_NOMAP
  on error (bsc#1012628).
- scsi: core: Fix error handling of scsi_host_alloc()
  (bsc#1012628).
- scsi: core: Fix failure handling of scsi_add_host_with_dma()
  (bsc#1012628).
- scsi: core: Put .shost_dev in failure path if host state
  changes to RUNNING (bsc#1012628).
- scsi: core: Only put parent device if host state differs from
  SHOST_CREATED (bsc#1012628).
- proc: only require mm_struct for writing (bsc#1012628).
- commit 522e416
* Wed Jun 16 2021 msuchanek@suse.de
- kernel-binary.spec.in: Regenerate makefile when not using mkmakefile.
- commit 6b30fe5
* Tue Jun 15 2021 jlee@suse.com
- ACPI: Pass the same capabilities to the _OSC regardless of
  the query flag (bsc#1185513).
- commit 7354f79
* Mon Jun 14 2021 tiwai@suse.de
- rpm/kernel-binary.spec.in: Fix handling of +arch marker (bsc#1186672)
  The previous commit made a module wrongly into Module.optional.
  Although it didn't influence on the end result, better to fix it.
  Also, add a comment to explain the markers briefly.
- commit 8f79742
* Mon Jun 14 2021 schwab@suse.de
- config: riscv64: enable STMMAC_PLATFORM
  This also makes DWMAC_DWC_QOS_ETH, DWMAC_GENERIC, DWMAC_INTEL_PLAT visible
  which are all enabled.
- commit 617c6b8
* Mon Jun 14 2021 mkubecek@suse.cz
- Update to 5.13-rc6
- commit e91bc34
* Mon Jun 14 2021 mkubecek@suse.cz
- update patch metadata
- update upstream references and move into more appropriate section
  patches.suse/0001-x86-ioremap-Map-efi_mem_reserve-memory-as-encrypted-.patch
- commit 716a407
* Fri Jun 11 2021 tiwai@suse.de
- Add arch-dependent support markers in supported.conf (bsc#1186672)
  We may need to put some modules as supported only on specific archs.
  This extends the supported.conf syntax to allow to put +arch additionally
  after the unsupported marker, then it'll be conditionally supported on
  that arch.
- commit 8cbdb41
* Fri Jun 11 2021 bwiedemann@suse.de
- Create Symbols.list and ipa-clones.list determistically
  without this patch, filesystem readdir order would influence
  order of entries in these files.
  This patch was done while working on reproducible builds for SLE.
- commit a898b6d
* Fri Jun 11 2021 tiwai@suse.de
- Update config files (bsc#1187167)
  Set empty to CONFIG_MODULE_SIG_KEY for reproducible builds
- commit 332b26c
* Fri Jun 11 2021 jslaby@suse.cz
- tipc: fix kernel-doc warnings (git-fixes).
- commit b92eaf7
* Fri Jun 11 2021 jslaby@suse.cz
- Linux 5.12.10 (bsc#1012628).
- mt76: mt7921: add rcu section in mt7921_mcu_tx_rate_report
  (bsc#1012628).
- mt76: mt7921: fix possible AOOB issue in
  mt7921_mcu_tx_rate_report (bsc#1012628).
- mt76: mt76x0e: fix device hang during suspend/resume
  (bsc#1012628).
- hwmon: (dell-smm-hwmon) Fix index values (bsc#1012628).
- hwmon: (pmbus/isl68137) remove READ_TEMPERATURE_3 for RAA228228
  (bsc#1012628).
- netfilter: conntrack: unregister ipv4 sockopts on error unwind
  (bsc#1012628).
- efi/fdt: fix panic when no valid fdt found (bsc#1012628).
- efi: Allow EFI_MEMORY_XP and EFI_MEMORY_RO both to be cleared
  (bsc#1012628).
- efi/libstub: prevent read overflow in find_file_option()
  (bsc#1012628).
- efi: cper: fix snprintf() use in cper_dimm_err_location()
  (bsc#1012628).
- vfio/pci: Fix error return code in vfio_ecap_init()
  (bsc#1012628).
- vfio/pci: zap_vma_ptes() needs MMU (bsc#1012628).
- samples: vfio-mdev: fix error handing in mdpy_fb_probe()
  (bsc#1012628).
- vfio/platform: fix module_put call in error flow (bsc#1012628).
- ipvs: ignore IP_VS_SVC_F_HASHED flag when adding service
  (bsc#1012628).
- HID: logitech-hidpp: initialize level variable (bsc#1012628).
- HID: pidff: fix error return code in hid_pidff_init()
  (bsc#1012628).
- HID: amd_sfh: Fix memory leak in amd_sfh_work (bsc#1012628).
- HID: i2c-hid: fix format string mismatch (bsc#1012628).
- kbuild: Quote OBJCOPY var to avoid a pahole call break the build
  (bsc#1012628).
- devlink: Correct VIRTUAL port to not have phys_port attributes
  (bsc#1012628).
- net/sched: act_ct: Offload connections with commit action
  (bsc#1012628).
- net/sched: act_ct: Fix ct template allocation for zone 0
  (bsc#1012628).
- mptcp: fix sk_forward_memory corruption on retransmission
  (bsc#1012628).
- mptcp: always parse mptcp options for MPC reqsk (bsc#1012628).
- mptcp: do not reset MP_CAPABLE subflow on mapping errors
  (bsc#1012628).
- nvme-rdma: fix in-casule data send for chained sgls
  (bsc#1012628).
- ACPICA: Clean up context mutex during object deletion
  (bsc#1012628).
- perf probe: Fix NULL pointer dereference in
  convert_variable_location() (bsc#1012628).
- net: dsa: tag_8021q: fix the VLAN IDs used for encoding
  sub-VLANs (bsc#1012628).
- net: sock: fix in-kernel mark setting (bsc#1012628).
- net/tls: Replace TLS_RX_SYNC_RUNNING with RCU (bsc#1012628).
- net/tls: Fix use-after-free after the TLS device goes down
  and up (bsc#1012628).
- net/mlx5e: Fix incompatible casting (bsc#1012628).
- net/mlx5: Check firmware sync reset requested is set before
  trying to abort it (bsc#1012628).
- net/mlx5e: Check for needed capability for cvlan matching
  (bsc#1012628).
- net/mlx5e: Fix adding encap rules to slow path (bsc#1012628).
- net/mlx5: DR, Create multi-destination flow table with level
  less than 64 (bsc#1012628).
- nvmet: fix freeing unallocated p2pmem (bsc#1012628).
- netfilter: nft_ct: skip expectations for confirmed conntrack
  (bsc#1012628).
- netfilter: nfnetlink_cthelper: hit EBUSY on updates if size
  mismatches (bsc#1012628).
- drm/i915/selftests: Fix return value check in
  live_breadcrumbs_smoketest() (bsc#1012628).
- bpf, lockdown, audit: Fix buggy SELinux lockdown permission
  checks (bsc#1012628).
- ieee802154: fix error return code in ieee802154_add_iface()
  (bsc#1012628).
- ieee802154: fix error return code in
  ieee802154_llsec_getparams() (bsc#1012628).
- igb: Fix XDP with PTP enabled (bsc#1012628).
- igb: add correct exception tracing for XDP (bsc#1012628).
- ixgbevf: add correct exception tracing for XDP (bsc#1012628).
- ice: track AF_XDP ZC enabled queues in bitmap (bsc#1012628).
- cxgb4: fix regression with HASH tc prio value update
  (bsc#1012628).
- ipv6: Fix KASAN: slab-out-of-bounds Read in
  fib6_nh_flush_exceptions (bsc#1012628).
- ice: Fix allowing VF to request more/less queues via virtchnl
  (bsc#1012628).
- ice: Fix VFR issues for AVF drivers that expect ATQLEN cleared
  (bsc#1012628).
- ice: handle the VF VSI rebuild failure (bsc#1012628).
- ice: report supported and advertised autoneg using PHY
  capabilities (bsc#1012628).
- ice: Allow all LLDP packets from PF to Tx (bsc#1012628).
- i2c: qcom-geni: Add shutdown callback for i2c (bsc#1012628).
- sch_htb: fix refcount leak in htb_parent_to_leaf_offload
  (bsc#1012628).
- cxgb4: avoid link re-train during TC-MQPRIO configuration
  (bsc#1012628).
- i40e: optimize for XDP_REDIRECT in xsk path (bsc#1012628).
- i40e: add correct exception tracing for XDP (bsc#1012628).
- ice: optimize for XDP_REDIRECT in xsk path (bsc#1012628).
- ice: add correct exception tracing for XDP (bsc#1012628).
- ixgbe: optimize for XDP_REDIRECT in xsk path (bsc#1012628).
- ixgbe: add correct exception tracing for XDP (bsc#1012628).
- arm64: dts: ti: j7200-main: Mark Main NAVSS as dma-coherent
  (bsc#1012628).
- optee: use export_uuid() to copy client UUID (bsc#1012628).
- bus: ti-sysc: Fix am335x resume hang for usb otg module
  (bsc#1012628).
- arm64: dts: ls1028a: fix memory node (bsc#1012628).
- arm64: dts: zii-ultra: remove second GEN_3V3 regulator instance
  (bsc#1012628).
- arm64: dts: zii-ultra: fix 12V_MAIN voltage (bsc#1012628).
- arm64: dts: freescale: sl28: var4: fix RGMII clock and voltage
  (bsc#1012628).
- arm64: dts: freescale: sl28: var1: fix RGMII clock and voltage
  (bsc#1012628).
- ARM: dts: imx7d-meerkat96: Fix the 'tuning-step' property
  (bsc#1012628).
- ARM: dts: imx7d-pico: Fix the 'tuning-step' property
  (bsc#1012628).
- ARM: dts: imx: emcon-avari: Fix nxp,pca8574 #gpio-cells
  (bsc#1012628).
- bus: ti-sysc: Fix flakey idling of uarts and stop using
  swsup_sidle_act (bsc#1012628).
- arm64: meson: select COMMON_CLK (bsc#1012628).
- tipc: add extack messages for bearer/media failure
  (bsc#1012628).
- tipc: fix unique bearer names sanity check (bsc#1012628).
- riscv: vdso: fix and clean-up Makefile (bsc#1012628).
- amdgpu: fix GEM obj leak in
  amdgpu_display_user_framebuffer_create (bsc#1012628).
- io_uring: fix link timeout refs (bsc#1012628).
- io_uring: use better types for cflags (bsc#1012628).
- io_uring: wrap io_kiocb reference count manipulation in helpers
  (bsc#1012628).
- io_uring: fix ltout double free on completion race
  (bsc#1012628).
- drm/amdgpu/vcn3: add cancel_delayed_work_sync before power gate
  (bsc#1012628).
- drm/amdgpu/jpeg2.5: add cancel_delayed_work_sync before power
  gate (bsc#1012628).
- drm/amdgpu/jpeg3: add cancel_delayed_work_sync before power gate
  (bsc#1012628).
- Bluetooth: fix the erroneous flush_work() order (bsc#1012628).
- Bluetooth: use correct lock to prevent UAF of hdev object
  (bsc#1012628).
- wireguard: do not use -O3 (bsc#1012628).
- wireguard: peer: allocate in kmem_cache (bsc#1012628).
- wireguard: use synchronize_net rather than synchronize_rcu
  (bsc#1012628).
- wireguard: selftests: remove old conntrack kconfig value
  (bsc#1012628).
- wireguard: selftests: make sure rp_filter is disabled on vethc
  (bsc#1012628).
- wireguard: allowedips: initialize list head in selftest
  (bsc#1012628).
- wireguard: allowedips: remove nodes in O(1) (bsc#1012628).
- wireguard: allowedips: allocate nodes in kmem_cache
  (bsc#1012628).
- wireguard: allowedips: free empty intermediate nodes when
  removing single node (bsc#1012628).
- net: caif: added cfserl_release function (bsc#1012628).
- net: caif: add proper error handling (bsc#1012628).
- net: caif: fix memory leak in caif_device_notify (bsc#1012628).
- net: caif: fix memory leak in cfusbl_device_notify
  (bsc#1012628).
- HID: i2c-hid: Skip ELAN power-on command after reset
  (bsc#1012628).
- HID: magicmouse: fix NULL-deref on disconnect (bsc#1012628).
- HID: multitouch: require Finger field to mark Win8 reports as MT
  (bsc#1012628).
- gfs2: fix scheduling while atomic bug in glocks (bsc#1012628).
- ALSA: timer: Fix master timer notification (bsc#1012628).
- ALSA: hda: Fix for mute key LED for HP Pavilion 15-CK0xx
  (bsc#1012628).
- ALSA: hda: update the power_state during the direct-complete
  (bsc#1012628).
- ARM: dts: imx6dl-yapp4: Fix RGMII connection to QCA8334 switch
  (bsc#1012628).
- ARM: dts: imx6q-dhcom: Add PU,VDD1P1,VDD2P5 regulators
  (bsc#1012628).
- ext4: fix memory leak in ext4_fill_super (bsc#1012628).
- ext4: fix bug on in ext4_es_cache_extent as ext4_split_extent_at
  failed (bsc#1012628).
- ext4: fix fast commit alignment issues (bsc#1012628).
- ext4: fix memory leak in ext4_mb_init_backend on error path
  (bsc#1012628).
- ext4: fix accessing uninit percpu counter variable with
  fast_commit (bsc#1012628).
- usb: dwc2: Fix build in periphal-only mode (bsc#1012628).
- Revert "MIPS: make userspace mapping young by default"
  (bsc#1012628).
- kfence: maximize allocation wait timeout duration (bsc#1012628).
- kfence: use TASK_IDLE when awaiting allocation (bsc#1012628).
- pid: take a reference when initializing `cad_pid` (bsc#1012628).
- ocfs2: fix data corruption by fallocate (bsc#1012628).
- mm/debug_vm_pgtable: fix alignment for pmd/pud_advanced_tests()
  (bsc#1012628).
- mm/page_alloc: fix counting of free pages after take off from
  buddy (bsc#1012628).
- scsi: lpfc: Fix failure to transmit ABTS on FC link
  (bsc#1012628).
- x86/cpufeatures: Force disable X86_FEATURE_ENQCMD and remove
  update_pasid() (bsc#1012628).
- dmaengine: idxd: Use cpu_feature_enabled() (bsc#1012628).
- x86/sev: Check SME/SEV support in CPUID first (bsc#1012628).
- KVM: PPC: Book3S HV: Save host FSCR in the P7/8 path
  (bsc#1012628).
- nfc: fix NULL ptr dereference in llcp_sock_getname() after
  failed connect (bsc#1012628).
- drm/amdgpu: Don't query CE and UE errors (bsc#1012628).
- drm/amdgpu: make sure we unpin the UVD BO (bsc#1012628).
- x86/apic: Mark _all_ legacy interrupts when IO/APIC is missing
  (bsc#1012628).
- x86/thermal: Fix LVT thermal setup for SMI delivery mode
  (bsc#1012628).
- powerpc/kprobes: Fix validation of prefixed instructions across
  page boundary (bsc#1012628).
- btrfs: mark ordered extent and inode with error if we fail to
  finish (bsc#1012628).
- btrfs: fix error handling in btrfs_del_csums (bsc#1012628).
- btrfs: return errors from btrfs_del_csums in cleanup_ref_head
  (bsc#1012628).
- btrfs: fix fsync failure and transaction abort after writes
  to prealloc extents (bsc#1012628).
- btrfs: check error value from btrfs_update_inode in tree log
  (bsc#1012628).
- btrfs: fixup error handling in fixup_inode_link_counts
  (bsc#1012628).
- btrfs: abort in rename_exchange if we fail to insert the second
  ref (bsc#1012628).
- btrfs: fix deadlock when cloning inline extents and low on
  available space (bsc#1012628).
- mm, hugetlb: fix simple resv_huge_pages underflow on UFFDIO_COPY
  (bsc#1012628).
- drm/msm/dpu: always use mdp device to scale bandwidth
  (bsc#1012628).
- KVM: SVM: Truncate GPR value for DR and CR accesses in !64-bit
  mode (bsc#1012628).
- x86/kvm: Teardown PV features on boot CPU as well (bsc#1012628).
- x86/kvm: Disable kvmclock on all CPUs on shutdown (bsc#1012628).
- x86/kvm: Disable all PV features on crash (bsc#1012628).
- KVM: arm64: Commit pending PC adjustemnts before returning to
  userspace (bsc#1012628).
- KVM: arm64: Resolve all pending PC updates before immediate exit
  (bsc#1012628).
- ARM: OMAP1: isp1301-omap: Add missing gpiod_add_lookup_table
  function (bsc#1012628).
- i2c: qcom-geni: Suspend and resume the bus during
  SYSTEM_SLEEP_PM ops (bsc#1012628).
- x86/fault: Don't send SIGSEGV twice on SEGV_PKUERR
  (bsc#1012628).
- netfilter: nf_tables: missing error reporting for not selected
  expressions (bsc#1012628).
- xen-netback: take a reference to the RX task thread
  (bsc#1012628).
- neighbour: allow NUD_NOARP entries to be forced GCed
  (bsc#1012628).
- commit c24c929
* Thu Jun 10 2021 martin.wilck@suse.com
- kernel-binary.spec.in: Add Supplements: for -extra package on Leap
  kernel-$flavor-extra should supplement kernel-$flavor on Leap, like
  it does on SLED, and like the kernel-$flavor-optional package does.
- commit c60d87f
* Tue Jun  8 2021 jroedel@suse.de
- x86/ioremap: Map efi_mem_reserve() memory as encrypted for SEV (bsc#1186884).
- commit e0a9eac
* Tue Jun  8 2021 jroedel@suse.de
- x86/ioremap: Map efi_mem_reserve() memory as encrypted for SEV (bsc#1186884).
- commit c7fb36b
* Mon Jun  7 2021 mbrugger@suse.com
- brcmfmac: Add clm_blob firmware files to modinfo (bsc#1186857).
- commit aeed335
* Mon Jun  7 2021 mbrugger@suse.com
- brcmfmac: Add clm_blob firmware files to modinfo (bsc#1186857).
- commit a0fa2f0
* Mon Jun  7 2021 mkubecek@suse.cz
- Update to 5.13-rc5
- update configs
  - HID_SEMITEK=m
- commit 6828450
* Mon Jun  7 2021 mkubecek@suse.cz
- series.conf: cleanup
  Move submitted patch to "almost mainline" section.
- commit 9f593b6
* Fri Jun  4 2021 mbrugger@suse.com
- brcmfmac: Delete second brcm folder hierarchy (bsc#1186857).
- commit 1d77a5f
* Thu Jun  3 2021 msuchanek@suse.de
- Refresh config files.
  Align across architectures:
  BPFILTER_UMH=m
- commit 39d2f9c
* Thu Jun  3 2021 afaerber@suse.com
- config: armv7hl: Update to 5.13-rc4
- commit f762975
* Thu Jun  3 2021 afaerber@suse.com
- config: armv6hl: Update to 5.13-rc4
- commit e26370d
* Thu Jun  3 2021 afaerber@suse.com
- config: arm64: Update to 5.13-rc4
- commit 22709d7
* Thu Jun  3 2021 msuchanek@suse.de
- kernel-binary.spec.in: build-id check requires elfutils.
- commit 01569b3
* Thu Jun  3 2021 jslaby@suse.cz
- Linux 5.12.9 (bsc#1012628).
- ALSA: hda/realtek: the bass speaker can't output sound on Yoga
  9i (bsc#1012628).
- ALSA: hda/realtek: Headphone volume is controlled by Front mixer
  (bsc#1012628).
- ALSA: hda/realtek: Chain in pop reduction fixup for ThinkStation
  P340 (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP 855 G8
  (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs and speaker for HP
  Zbook G8 (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs and speaker for HP
  Zbook Fury 15 G8 (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs and speaker for HP
  Zbook Fury 17 G8 (bsc#1012628).
- ALSA: usb-audio: fix control-request direction (bsc#1012628).
- ALSA: usb-audio: scarlett2: Fix device hang with ehci-pci
  (bsc#1012628).
- ALSA: usb-audio: scarlett2: Improve driver startup messages
  (bsc#1012628).
- cifs: fix string declarations and assignments in tracepoints
  (bsc#1012628).
- cifs: set server->cipher_type to AES-128-CCM for SMB3.0
  (bsc#1012628).
- mtd: rawnand: cs553x: Fix external use of SW Hamming ECC helper
  (bsc#1012628).
- mtd: rawnand: txx9ndfmc: Fix external use of SW Hamming ECC
  helper (bsc#1012628).
- mtd: rawnand: sharpsl: Fix external use of SW Hamming ECC helper
  (bsc#1012628).
- mtd: rawnand: lpc32xx_slc: Fix external use of SW Hamming ECC
  helper (bsc#1012628).
- mtd: rawnand: ndfc: Fix external use of SW Hamming ECC helper
  (bsc#1012628).
- mtd: rawnand: tmio: Fix external use of SW Hamming ECC helper
  (bsc#1012628).
- mtd: rawnand: fsmc: Fix external use of SW Hamming ECC helper
  (bsc#1012628).
- NFSv4: Fix a NULL pointer dereference in
  pnfs_mark_matching_lsegs_return() (bsc#1012628).
- scsi: target: core: Avoid smp_processor_id() in preemptible code
  (bsc#1012628).
- iommu/vt-d: Fix sysfs leak in alloc_iommu() (bsc#1012628).
- s390/dasd: add missing discipline function (bsc#1012628).
- perf intel-pt: Fix sample instruction bytes (bsc#1012628).
- perf intel-pt: Fix transaction abort handling (bsc#1012628).
- perf scripts python: exported-sql-viewer.py: Fix copy to
  clipboard from Top Calls by elapsed Time report (bsc#1012628).
- perf scripts python: exported-sql-viewer.py: Fix Array TypeError
  (bsc#1012628).
- perf scripts python: exported-sql-viewer.py: Fix warning display
  (bsc#1012628).
- proc: Check /proc/$pid/attr/ writes against file opener
  (bsc#1012628).
- net: hso: fix control-request directions (bsc#1012628).
- net/sched: fq_pie: re-factor fix for fq_pie endless loop
  (bsc#1012628).
- net/sched: fq_pie: fix OOB access in the traffic path
  (bsc#1012628).
- netfilter: nft_set_pipapo_avx2: Add irq_fpu_usable() check,
  fallback to non-AVX2 version (bsc#1012628).
- dm snapshot: properly fix a crash when an origin has no
  snapshots (bsc#1012628).
- md/raid5: remove an incorrect assert in in_chunk_boundary
  (bsc#1012628).
- drm/i915: Reenable LTTPR non-transparent LT mode for
  DPCD_REV<1.4 (bsc#1012628).
- drm/amd/pm: correct MGpuFanBoost setting (bsc#1012628).
- drm/amdgpu/vcn1: add cancel_delayed_work_sync before power gate
  (bsc#1012628).
- drm/amdkfd: correct sienna_cichlid SDMA RLC register offset
  error (bsc#1012628).
- drm/amdgpu/vcn2.0: add cancel_delayed_work_sync before power
  gate (bsc#1012628).
- drm/amdgpu/vcn2.5: add cancel_delayed_work_sync before power
  gate (bsc#1012628).
- drm/amdgpu/jpeg2.0: add cancel_delayed_work_sync before power
  gate (bsc#1012628).
- kgdb: fix gcc-11 warnings harder (bsc#1012628).
- Documentation: seccomp: Fix user notification documentation
  (bsc#1012628).
- riscv: stacktrace: fix the riscv stacktrace when
  CONFIG_FRAME_POINTER enabled (bsc#1012628).
- seccomp: Refactor notification handler to prepare for new
  semantics (bsc#1012628).
- debugfs: fix security_locked_down() call for SELinux
  (bsc#1012628).
- serial: core: fix suspicious security_locked_down() call
  (bsc#1012628).
- misc/uss720: fix memory leak in uss720_probe (bsc#1012628).
- thunderbolt: usb4: Fix NVM read buffer bounds and offset issue
  (bsc#1012628).
- thunderbolt: dma_port: Fix NVM read buffer bounds and offset
  issue (bsc#1012628).
- KVM: X86: Fix vCPU preempted state from guest's point of view
  (bsc#1012628).
- KVM: arm64: Move __adjust_pc out of line (bsc#1012628).
- KVM: arm64: Fix debug register indexing (bsc#1012628).
- KVM: arm64: Prevent mixed-width VM creation (bsc#1012628).
- mei: request autosuspend after sending rx flow control
  (bsc#1012628).
- staging: iio: cdc: ad7746: avoid overwrite of num_channels
  (bsc#1012628).
- iio: gyro: fxas21002c: balance runtime power in error path
  (bsc#1012628).
- iio: dac: ad5770r: Put fwnode in error case during ->probe()
  (bsc#1012628).
- iio: adc: ad7768-1: Fix too small buffer passed to
  iio_push_to_buffers_with_timestamp() (bsc#1012628).
- iio: adc: ad7124: Fix missbalanced regulator enable / disable
  on error (bsc#1012628).
- iio: adc: ad7124: Fix potential overflow due to non sequential
  channel numbers (bsc#1012628).
- iio: adc: ad7923: Fix undersized rx buffer (bsc#1012628).
- iio: adc: ad7793: Add missing error code in ad7793_setup()
  (bsc#1012628).
- iio: adc: ad7192: Avoid disabling a clock that was never enabled
  (bsc#1012628).
- iio: adc: ad7192: handle regulator voltage error first
  (bsc#1012628).
- serial: 8250: Add UART_BUG_TXRACE workaround for Aspeed VUART
  (bsc#1012628).
- serial: 8250_dw: Add device HID for new AMD UART controller
  (bsc#1012628).
- serial: 8250_pci: Add support for new HPE serial device
  (bsc#1012628).
- serial: 8250_pci: handle FL_NOIRQ board flag (bsc#1012628).
- USB: trancevibrator: fix control-request direction
  (bsc#1012628).
- Revert "irqbypass: do not start cons/prod when failed connect"
  (bsc#1012628).
- USB: usbfs: Don't WARN about excessively large memory
  allocations (bsc#1012628).
- xhci: fix giving back URB with incorrect status regression in
  5.12 (bsc#1012628).
- xhci: Fix 5.12 regression of missing xHC cache clearing command
  after a Stall (bsc#1012628).
- drivers: base: Fix device link removal (bsc#1012628).
- serial: tegra: Fix a mask operation that is always true
  (bsc#1012628).
- serial: sh-sci: Fix off-by-one error in FIFO threshold register
  setting (bsc#1012628).
- serial: rp2: use 'request_firmware' instead of
  'request_firmware_nowait' (bsc#1012628).
- USB: serial: ti_usb_3410_5052: add startech.com device id
  (bsc#1012628).
- USB: serial: option: add Telit LE910-S1 compositions 0x7010,
  0x7011 (bsc#1012628).
- USB: serial: ftdi_sio: add IDs for IDS GmbH Products
  (bsc#1012628).
- USB: serial: pl2303: add device id for ADLINK ND-6530 GC
  (bsc#1012628).
- thermal/drivers/intel: Initialize RW trip to
  THERMAL_TEMP_INVALID (bsc#1012628).
- usb: dwc3: gadget: Properly track pending and queued SG
  (bsc#1012628).
- usb: gadget: udc: renesas_usb3: Fix a race in usb3_start_pipen()
  (bsc#1012628).
- usb: typec: mux: Fix matching with typec_altmode_desc
  (bsc#1012628).
- usb: typec: ucsi: Clear pending after acking connector change
  (bsc#1012628).
- usb: typec: tcpm: Use LE to CPU conversion when accessing
  msg->header (bsc#1012628).
- usb: typec: tcpm: Properly interrupt VDM AMS (bsc#1012628).
- usb: typec: tcpm: Respond Not_Supported if no snk_vdo
  (bsc#1012628).
- net: usb: fix memory leak in smsc75xx_bind (bsc#1012628).
- Bluetooth: cmtp: fix file refcount when cmtp_attach_device fails
  (bsc#1012628).
- fs/nfs: Use fatal_signal_pending instead of signal_pending
  (bsc#1012628).
- NFS: fix an incorrect limit in filelayout_decode_layout()
  (bsc#1012628).
- NFS: Fix an Oopsable condition in __nfs_pageio_add_request()
  (bsc#1012628).
- NFS: Don't corrupt the value of pg_bytes_written in
  nfs_do_recoalesce() (bsc#1012628).
- NFSv4: Fix v4.0/v4.1 SEEK_DATA return -ENOTSUPP when set
  NFS_V4_2 config (bsc#1012628).
- drm/meson: fix shutdown crash when component not probed
  (bsc#1012628).
- net/mlx5e: reset XPS on error flow if netdev isn't registered
  yet (bsc#1012628).
- net/mlx5e: Fix multipath lag activation (bsc#1012628).
- net/mlx5e: Fix error path of updating netdev queues
  (bsc#1012628).
- {net,vdpa}/mlx5: Configure interface MAC into mpfs L2 table
  (bsc#1012628).
- net/mlx5e: Fix nullptr in mlx5e_tc_add_fdb_flow() (bsc#1012628).
- net/mlx5e: Fix nullptr in add_vlan_push_action() (bsc#1012628).
- net/mlx5: Set reformat action when needed for termination rules
  (bsc#1012628).
- net/mlx5e: Fix null deref accessing lag dev (bsc#1012628).
- net/mlx4: Fix EEPROM dump support (bsc#1012628).
- {net, RDMA}/mlx5: Fix override of log_max_qp by other device
  (bsc#1012628).
- net/mlx5: Set term table as an unmanaged flow table
  (bsc#1012628).
- KVM: X86: Fix warning caused by stale emulation context
  (bsc#1012628).
- KVM: X86: Use _BITUL() macro in UAPI headers (bsc#1012628).
- KVM: selftests: Fix 32-bit truncation of vm_get_max_gfn()
  (bsc#1012628).
- SUNRPC in case of backlog, hand free slots directly to waiting
  task (bsc#1012628).
- Revert "net:tipc: Fix a double free in tipc_sk_mcast_rcv"
  (bsc#1012628).
- tipc: wait and exit until all work queues are done
  (bsc#1012628).
- tipc: skb_linearize the head skb when reassembling msgs
  (bsc#1012628).
- spi: spi-fsl-dspi: Fix a resource leak in an error handling path
  (bsc#1012628).
- sctp: fix the proc_handler for sysctl encap_port (bsc#1012628).
- sctp: add the missing setting for asoc encap_port (bsc#1012628).
- netfilter: flowtable: Remove redundant hw refresh bit
  (bsc#1012628).
- net: dsa: mt7530: fix VLAN traffic leaks (bsc#1012628).
- net: dsa: bcm_sf2: Fix bcm_sf2_reg_rgmii_cntrl() call for
  non-RGMII port (bsc#1012628).
- net: dsa: fix a crash if ->get_sset_count() fails (bsc#1012628).
- net: dsa: sja1105: update existing VLANs from the bridge VLAN
  list (bsc#1012628).
- net: dsa: sja1105: use 4095 as the private VLAN for untagged
  traffic (bsc#1012628).
- net: dsa: sja1105: error out on unsupported PHY mode
  (bsc#1012628).
- net: dsa: sja1105: add error handling in sja1105_setup()
  (bsc#1012628).
- net: dsa: sja1105: call dsa_unregister_switch when allocating
  memory fails (bsc#1012628).
- net: dsa: sja1105: fix VL lookup command packing for P/Q/R/S
  (bsc#1012628).
- i2c: s3c2410: fix possible NULL pointer deref on read message
  after write (bsc#1012628).
- i2c: mediatek: Disable i2c start_en and clear intr_stat brfore
  reset (bsc#1012628).
- i2c: i801: Don't generate an interrupt on bus reset
  (bsc#1012628).
- i2c: sh_mobile: Use new clock calculation formulas for RZ/G2E
  (bsc#1012628).
- afs: Fix the nlink handling of dir-over-dir rename
  (bsc#1012628).
- perf debug: Move debug initialization earlier (bsc#1012628).
- perf jevents: Fix getting maximum number of fds (bsc#1012628).
- nvmet-tcp: fix inline data size comparison in
  nvmet_tcp_queue_response (bsc#1012628).
- mptcp: avoid error message on infinite mapping (bsc#1012628).
- mptcp: fix data stream corruption (bsc#1012628).
- mptcp: drop unconditional pr_warn on bad opt (bsc#1012628).
- platform/x86: hp_accel: Avoid invoking _INI to speed up resume
  (bsc#1012628).
- gpio: cadence: Add missing MODULE_DEVICE_TABLE (bsc#1012628).
- Revert "crypto: cavium/nitrox - add an error message to explain
  the failure of pci_request_mem_regions" (bsc#1012628).
- Revert "media: usb: gspca: add a missed check for
  goto_low_power" (bsc#1012628).
- Revert "ALSA: sb: fix a missing check of snd_ctl_add"
  (bsc#1012628).
- Revert "serial: max310x: pass return value of
  spi_register_driver" (bsc#1012628).
- serial: max310x: unregister uart driver in case of failure
  and abort (bsc#1012628).
- Revert "net: fujitsu: fix a potential NULL pointer dereference"
  (bsc#1012628).
- net: fujitsu: fix potential null-ptr-deref (bsc#1012628).
- Revert "net/smc: fix a NULL pointer dereference" (bsc#1012628).
- net/smc: properly handle workqueue allocation failure
  (bsc#1012628).
- Revert "net: caif: replace BUG_ON with recovery code"
  (bsc#1012628).
- net: caif: remove BUG_ON(dev == NULL) in caif_xmit
  (bsc#1012628).
- Revert "char: hpet: fix a missing check of ioremap"
  (bsc#1012628).
- char: hpet: add checks after calling ioremap (bsc#1012628).
- Revert "ALSA: gus: add a check of the status of snd_ctl_add"
  (bsc#1012628).
- Revert "ALSA: usx2y: Fix potential NULL pointer dereference"
  (bsc#1012628).
- Revert "isdn: mISDNinfineon: fix potential NULL pointer
  dereference" (bsc#1012628).
- isdn: mISDNinfineon: check/cleanup ioremap failure correctly
  in setup_io (bsc#1012628).
- Revert "ath6kl: return error code in
  ath6kl_wmi_set_roam_lrssi_cmd()" (bsc#1012628).
- ath6kl: return error code in ath6kl_wmi_set_roam_lrssi_cmd()
  (bsc#1012628).
- Revert "isdn: mISDN: Fix potential NULL pointer dereference
  of kzalloc" (bsc#1012628).
- isdn: mISDN: correctly handle ph_info allocation failure in
  hfcsusb_ph_info (bsc#1012628).
- Revert "dmaengine: qcom_hidma: Check for driver register
  failure" (bsc#1012628).
- dmaengine: qcom_hidma: comment platform_driver_register call
  (bsc#1012628).
- Revert "libertas: add checks for the return value of
  sysfs_create_group" (bsc#1012628).
- libertas: register sysfs groups properly (bsc#1012628).
- Revert "ASoC: cs43130: fix a NULL pointer dereference"
  (bsc#1012628).
- ASoC: cs43130: handle errors in cs43130_probe() properly
  (bsc#1012628).
- Revert "media: dvb: Add check on sp8870_readreg" (bsc#1012628).
- media: dvb: Add check on sp8870_readreg return (bsc#1012628).
- Revert "media: gspca: mt9m111: Check write_bridge for timeout"
  (bsc#1012628).
- media: gspca: mt9m111: Check write_bridge for timeout
  (bsc#1012628).
- Revert "media: gspca: Check the return value of write_bridge
  for timeout" (bsc#1012628).
- media: gspca: properly check for errors in po1030_probe()
  (bsc#1012628).
- Revert "net: liquidio: fix a NULL pointer dereference"
  (bsc#1012628).
- net: liquidio: Add missing null pointer checks (bsc#1012628).
- Revert "brcmfmac: add a check for the status of usb_register"
  (bsc#1012628).
- brcmfmac: properly check for bus register errors (bsc#1012628).
- btrfs: return whole extents in fiemap (bsc#1012628).
- scsi: ufs: ufs-mediatek: Fix power down spec violation
  (bsc#1012628).
- scsi: BusLogic: Fix 64-bit system enumeration error for Buslogic
  (bsc#1012628).
- openrisc: Define memory barrier mb (bsc#1012628).
- scsi: pm80xx: Fix drives missing during rmmod/insmod loop
  (bsc#1012628).
- btrfs: release path before starting transaction when cloning
  inline extent (bsc#1012628).
- btrfs: do not BUG_ON in link_to_fixup_dir (bsc#1012628).
- ALSA: dice: disable double_pcm_frames mode for M-Audio Profire
  610, 2626 and Avid M-Box 3 Pro (bsc#1012628).
- platform/x86: hp-wireless: add AMD's hardware id to the
  supported list (bsc#1012628).
- platform/x86: intel_punit_ipc: Append MODULE_DEVICE_TABLE for
  ACPI (bsc#1012628).
- platform/x86: touchscreen_dmi: Add info for the Mediacom Winpad
  7.0 W700 tablet (bsc#1012628).
- SMB3: incorrect file id in requests compounded with open
  (bsc#1012628).
- drm/amd/display: Disconnect non-DP with no EDID (bsc#1012628).
- drm/amd/amdgpu: fix refcount leak (bsc#1012628).
- drm/amdgpu: Fix a use-after-free (bsc#1012628).
- drm/amd/amdgpu: fix a potential deadlock in gpu reset
  (bsc#1012628).
- drm/amdgpu: stop touching sched.ready in the backend
  (bsc#1012628).
- platform/x86: touchscreen_dmi: Add info for the Chuwi Hi10 Pro
  (CWI529) tablet (bsc#1012628).
- block: fix a race between del_gendisk and BLKRRPART
  (bsc#1012628).
- linux/bits.h: fix compilation error with GENMASK (bsc#1012628).
- spi: take the SPI IO-mutex in the spi_set_cs_timing method
  (bsc#1012628).
- net: netcp: Fix an error message (bsc#1012628).
- net: dsa: fix error code getting shifted with 4 in
  dsa_slave_get_sset_count (bsc#1012628).
- interconnect: qcom: bcm-voter: add a missing of_node_put()
  (bsc#1012628).
- interconnect: qcom: Add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- usb: cdnsp: Fix lack of removing request from pending list
  (bsc#1012628).
- ASoC: cs42l42: Regmap must use_single_read/write (bsc#1012628).
- net: stmmac: Fix MAC WoL not working if PHY does not support
  WoL (bsc#1012628).
- net: ipa: memory region array is variable size (bsc#1012628).
- vfio-ccw: Check initialized flag in cp_init() (bsc#1012628).
- spi: Assume GPIO CS active high in ACPI case (bsc#1012628).
- net: really orphan skbs tied to closing sk (bsc#1012628).
- net: packetmmap: fix only tx timestamp on request (bsc#1012628).
- net: fec: fix the potential memory leak in fec_enet_init()
  (bsc#1012628).
- octeontx2-pf: fix a buffer overflow in otx2_set_rxfh_context()
  (bsc#1012628).
- ptp: ocp: Fix a resource leak in an error handling path
  (bsc#1012628).
- chelsio/chtls: unlock on error in chtls_pt_recvmsg()
  (bsc#1012628).
- net: mdio: thunder: Fix a double free issue in the .remove
  function (bsc#1012628).
- net: mdio: octeon: Fix some double free issues (bsc#1012628).
- cxgb4/ch_ktls: Clear resources when pf4 device is removed
  (bsc#1012628).
- openvswitch: meter: fix race when getting now_ms (bsc#1012628).
- tls splice: check SPLICE_F_NONBLOCK instead of MSG_DONTWAIT
  (bsc#1012628).
- net: sched: fix packet stuck problem for lockless qdisc
  (bsc#1012628).
- net: sched: fix tx action rescheduling issue during deactivation
  (bsc#1012628).
- net: sched: fix tx action reschedule issue with stopped queue
  (bsc#1012628).
- net: hso: check for allocation failure in
  hso_create_bulk_serial_device() (bsc#1012628).
- net: bnx2: Fix error return code in bnx2_init_board()
  (bsc#1012628).
- bnxt_en: Include new P5 HV definition in VF check (bsc#1012628).
- bnxt_en: Fix context memory setup for 64K page size
  (bsc#1012628).
- mld: fix panic in mld_newpack() (bsc#1012628).
- net/smc: remove device from smcd_dev_list after failed
  device_add() (bsc#1012628).
- gve: Check TX QPL was actually assigned (bsc#1012628).
- gve: Update mgmt_msix_idx if num_ntfy changes (bsc#1012628).
- gve: Add NULL pointer checks when freeing irqs (bsc#1012628).
- gve: Upgrade memory barrier in poll routine (bsc#1012628).
- gve: Correct SKB queue index validation (bsc#1012628).
- iommu/amd: Clear DMA ops when switching domain (bsc#1012628).
- iommu/virtio: Add missing MODULE_DEVICE_TABLE (bsc#1012628).
- net: hns3: fix incorrect resp_msg issue (bsc#1012628).
- net: hns3: put off calling register_netdev() until client
  initialize complete (bsc#1012628).
- net: hns3: fix user's coalesce configuration lost issue
  (bsc#1012628).
- net/mlx5: SF, Fix show state inactive when its inactivated
  (bsc#1012628).
- net/mlx5e: Make sure fib dev exists in fib event (bsc#1012628).
- net/mlx5e: Reject mirroring on source port change encap rules
  (bsc#1012628).
- iommu/vt-d: Check for allocation failure in aux_detach_device()
  (bsc#1012628).
- iommu/vt-d: Use user privilege for RID2PASID translation
  (bsc#1012628).
- cxgb4: avoid accessing registers when clearing filters
  (bsc#1012628).
- staging: emxx_udc: fix loop in _nbu2ss_nuke() (bsc#1012628).
- ASoC: cs35l33: fix an error code in probe() (bsc#1012628).
- bpf, offload: Reorder offload callback 'prepare' in verifier
  (bsc#1012628).
- bpf: Set mac_len in bpf_skb_change_head (bsc#1012628).
- ixgbe: fix large MTU request from VF (bsc#1012628).
- ASoC: qcom: lpass-cpu: Use optional clk APIs (bsc#1012628).
- scsi: libsas: Use _safe() loop in sas_resume_port()
  (bsc#1012628).
- net: lantiq: fix memory corruption in RX ring (bsc#1012628).
- ipv6: record frag_max_size in atomic fragments in input path
  (bsc#1012628).
- scsi: aic7xxx: Restore several defines for aic7xxx firmware
  build (bsc#1012628).
- ALSA: usb-audio: scarlett2: snd_scarlett_gen2_controls_create()
  can be static (bsc#1012628).
- net: ethernet: mtk_eth_soc: Fix packet statistics support for
  MT7628/88 (bsc#1012628).
- sch_dsmark: fix a NULL deref in qdisc_reset() (bsc#1012628).
- net: hsr: fix mac_len checks (bsc#1012628).
- MIPS: alchemy: xxs1500: add gpio-au1000.h header file
  (bsc#1012628).
- MIPS: ralink: export rt_sysc_membase for rt2880_wdt.c
  (bsc#1012628).
- net: zero-initialize tc skb extension on allocation
  (bsc#1012628).
- net: mvpp2: add buffer header handling in RX (bsc#1012628).
- SUNRPC: More fixes for backlog congestion (bsc#1012628).
- thermal/drivers/qcom: Fix error code in
  adc_tm5_get_dt_channel_data() (bsc#1012628).
- KVM: X86: hyper-v: Task srcu lock when accessing kvm_memslots()
  (bsc#1012628).
- xprtrdma: Revert 586a0787ce35 (bsc#1012628).
- samples/bpf: Consider frame size in tx_only of xdpsock sample
  (bsc#1012628).
- net: hns3: check the return of skb_checksum_help()
  (bsc#1012628).
- bpftool: Add sock_release help info for cgroup attach/prog
  load command (bsc#1012628).
- Revert "Revert "ALSA: usx2y: Fix potential NULL pointer
  dereference"" (bsc#1012628).
- net: hso: bail out on interrupt URB allocation failure
  (bsc#1012628).
- arm64: mm: don't use CON and BLK mapping if KFENCE is enabled
  (bsc#1012628).
- neighbour: Prevent Race condition in neighbour subsytem
  (bsc#1012628).
- usb: core: reduce power-on-good delay time of root hub
  (bsc#1012628).
- commit f17eb01
* Wed Jun  2 2021 msuchanek@suse.de
- kernel-binary.spec: Only use mkmakefile when it exists
  Linux 5.13 no longer has a mkmakefile script
- commit b453c7b
* Tue Jun  1 2021 msuchanek@suse.de
- kernel-doc: Use Sphinx3.
  Sphinx2 is about to be removed from Factory.
- commit fb6d3b6
* Mon May 31 2021 mkubecek@suse.cz
- Update to 5.13-rc4
- eliminate 3 patches
  - patches.suse/bpf-Fix-alu32-const-subreg-bound-tracking-on-bitwise.patch
  - patches.suse/bpf-Prevent-writable-memory-mapping-of-read-only-rin.patch
  - patches.suse/bpf-ringbuf-Deny-reserve-of-buffers-larger-than-ring.patch
- update configs
  - BPF_UNPRIV_DEFAULT_OFF=n (backward compatible)
  - MEMTEST=y (riscv64 only, enabled on most architectures)
- commit 25beba1
* Fri May 28 2021 tiwai@suse.de
- Input: elants_i2c - Fix NULL dereference at probing
  (bsc#1186454).
- commit bb5e8ab
* Fri May 28 2021 jslaby@suse.cz
- Linux 5.12.8 (bsc#1012628).
- NFC: nci: fix memory leak in nci_allocate_device (bsc#1012628).
- KVM: x86: Defer vtime accounting 'til after IRQ handling
  (bsc#1012628).
- context_tracking: Move guest exit vtime accounting to separate
  helpers (bsc#1012628).
- context_tracking: Move guest exit context tracking to separate
  helpers (bsc#1012628).
- bpf: No need to simulate speculative domain for immediates
  (bsc#1012628).
- bpf: Fix mask direction swap upon off reg sign change
  (bsc#1012628).
- bpf: Wrap aux data inside bpf_sanitize_info container
  (bsc#1012628).
- commit 7a4f594
* Fri May 28 2021 jslaby@suse.cz
- Refresh
  patches.suse/pinctrl-bcm2835-accept-fewer-than-expected-irqs.patch.
  Update upstream status.
- commit fc290e6
* Thu May 27 2021 jslaby@suse.cz
- Linux 5.12.7 (bsc#1012628).
- firmware: arm_scpi: Prevent the ternary sign expansion bug
  (bsc#1012628).
- openrisc: Fix a memory leak (bsc#1012628).
- tee: amdtee: unload TA only when its refcount becomes 0
  (bsc#1012628).
- habanalabs/gaudi: Fix a potential use after free in
  gaudi_memset_device_memory (bsc#1012628).
- RDMA/siw: Properly check send and receive CQ pointers
  (bsc#1012628).
- RDMA/siw: Release xarray entry (bsc#1012628).
- RDMA/core: Prevent divide-by-zero error triggered by the user
  (bsc#1012628).
- platform/x86: ideapad-laptop: fix a NULL pointer dereference
  (bsc#1012628).
- RDMA/rxe: Clear all QP fields if creation failed (bsc#1012628).
- scsi: ufs: core: Increase the usable queue depth (bsc#1012628).
- scsi: qedf: Add pointer checks in qedf_update_link_speed()
  (bsc#1012628).
- scsi: qla2xxx: Fix error return code in
  qla82xx_write_flash_dword() (bsc#1012628).
- RDMA/mlx5: Recover from fatal event in dual port mode
  (bsc#1012628).
- RDMA/rxe: Split MEM into MR and MW (bsc#1012628).
- RDMA/rxe: Return CQE error if invalid lkey was supplied
  (bsc#1012628).
- RDMA/core: Don't access cm_id after its destruction
  (bsc#1012628).
- nvmet: fix memory leak in nvmet_alloc_ctrl() (bsc#1012628).
- nvme-loop: fix memory leak in nvme_loop_create_ctrl()
  (bsc#1012628).
- nvme-tcp: rerun io_work if req_list is not empty (bsc#1012628).
- nvme-fc: clear q_live at beginning of association teardown
  (bsc#1012628).
- platform/mellanox: mlxbf-tmfifo: Fix a memory barrier issue
  (bsc#1012628).
- platform/x86: intel_int0002_vgpio: Only call enable_irq_wake()
  when using s2idle (bsc#1012628).
- platform/x86: dell-smbios-wmi: Fix oops on rmmod dell_smbios
  (bsc#1012628).
- RDMA/mlx5: Fix query DCT via DEVX (bsc#1012628).
- RDMA/uverbs: Fix a NULL vs IS_ERR() bug (bsc#1012628).
- tools/testing/selftests/exec: fix link error (bsc#1012628).
- drm/ttm: Do not add non-system domain BO into swap list
  (bsc#1012628).
- powerpc/pseries: Fix hcall tracing recursion in pv queued
  spinlocks (bsc#1012628).
- ptrace: make ptrace() fail if the tracee changed its pid
  unexpectedly (bsc#1012628).
- nvmet: seset ns->file when open fails (bsc#1012628).
- perf/x86: Avoid touching LBR_TOS MSR for Arch LBR (bsc#1012628).
- locking/lockdep: Correct calling tracepoints (bsc#1012628).
- locking/mutex: clear MUTEX_FLAGS if wait_list is empty due to
  signal (bsc#1012628).
- powerpc: Fix early setup to make early_ioremap() work
  (bsc#1012628).
- btrfs: avoid RCU stalls while running delayed iputs
  (bsc#1012628).
- btrfs: fix removed dentries still existing after log is synced
  (bsc#1012628).
- cifs: fix memory leak in smb2_copychunk_range (bsc#1012628).
- fs/mount_setattr: tighten permission checks (bsc#1012628).
- misc: eeprom: at24: check suspend status before disable
  regulator (bsc#1012628).
- ALSA: dice: fix stream format for TC Electronic Konnekt Live
  at high sampling transfer frequency (bsc#1012628).
- ALSA: intel8x0: Don't update period unless prepared
  (bsc#1012628).
- ALSA: firewire-lib: fix amdtp_packet tracepoints event for
  packet_index field (bsc#1012628).
- ALSA: line6: Fix racy initialization of LINE6 MIDI
  (bsc#1012628).
- ALSA: dice: fix stream format at middle sampling rate for
  Alesis iO 26 (bsc#1012628).
- ALSA: firewire-lib: fix calculation for size of IR context
  payload (bsc#1012628).
- ALSA: usb-audio: Validate MS endpoint descriptors (bsc#1012628).
- ALSA: bebob/oxfw: fix Kconfig entry for Mackie d.2 Pro
  (bsc#1012628).
- ALSA: hda: fixup headset for ASUS GU502 laptop (bsc#1012628).
- Revert "ALSA: sb8: add a check for request_region"
  (bsc#1012628).
- ALSA: firewire-lib: fix check for the size of isochronous
  packet payload (bsc#1012628).
- ALSA: hda/realtek: reset eapd coeff to default value for alc287
  (bsc#1012628).
- ALSA: hda/realtek: Add some CLOVE SSIDs of ALC293 (bsc#1012628).
- ALSA: hda/realtek: Fix silent headphone output on ASUS UX430UA
  (bsc#1012628).
- ALSA: hda/realtek: Add fixup for HP OMEN laptop (bsc#1012628).
- ALSA: hda/realtek: Add fixup for HP Spectre x360 15-df0xxx
  (bsc#1012628).
- ALSA: usb-audio: Configure Pioneer DJM-850 samplerate
  (bsc#1012628).
- ALSA: usb-audio: DJM-750: ensure format is set (bsc#1012628).
- uio/uio_pci_generic: fix return value changed in refactoring
  (bsc#1012628).
- uio_hv_generic: Fix a memory leak in error handling paths
  (bsc#1012628).
- uio_hv_generic: Fix another memory leak in error handling paths
  (bsc#1012628).
- platform/x86: ideapad-laptop: fix method name typo
  (bsc#1012628).
- Revert "rapidio: fix a NULL pointer dereference when
  create_workqueue() fails" (bsc#1012628).
- rapidio: handle create_workqueue() failure (bsc#1012628).
- Revert "serial: mvebu-uart: Fix to avoid a potential NULL
  pointer dereference" (bsc#1012628).
- nvme-tcp: fix possible use-after-completion (bsc#1012628).
- x86/build: Fix location of '-plugin-opt=' flags (bsc#1012628).
- x86/sev-es: Move sev_es_put_ghcb() in prep for follow on patch
  (bsc#1012628).
- x86/sev-es: Invalidate the GHCB after completing VMGEXIT
  (bsc#1012628).
- x86/sev-es: Don't return NULL from sev_es_get_ghcb()
  (bsc#1012628).
- x86/sev-es: Use __put_user()/__get_user() for data accesses
  (bsc#1012628).
- x86/sev-es: Forward page-faults which happen during emulation
  (bsc#1012628).
- drm/amd/display: Use the correct max downscaling value for
  DCN3.x family (bsc#1012628).
- drm/amdgpu: Fix GPU TLB update error when PAGE_SIZE >
  AMDGPU_PAGE_SIZE (bsc#1012628).
- drm/amdgpu: disable 3DCGCG on picasso/raven1 to avoid compute
  hang (bsc#1012628).
- drm/amdgpu: update gc golden setting for Navi12 (bsc#1012628).
- drm/amdgpu: update sdma golden setting for Navi12 (bsc#1012628).
- dma-buf: fix unintended pin/unpin warnings (bsc#1012628).
- powerpc/64s/syscall: Use pt_regs.trap to distinguish syscall
  ABI difference between sc and scv syscalls (bsc#1012628).
- powerpc/64s/syscall: Fix ptrace syscall info with scv syscalls
  (bsc#1012628).
- mmc: sdhci-pci-gli: increase 1.8V regulator wait (bsc#1012628).
- mmc: meson-gx: make replace WARN_ONCE with dev_warn_once about
  scatterlist offset alignment (bsc#1012628).
- mmc: meson-gx: also check SD_IO_RW_EXTENDED for scatterlist
  size alignment (bsc#1012628).
- gpio: tegra186: Don't set parent IRQ affinity (bsc#1012628).
- xen-pciback: redo VF placement in the virtual topology
  (bsc#1012628).
- xen-pciback: reconfigure also from backend watch handler
  (bsc#1012628).
- userfaultfd: hugetlbfs: fix new flag usage in error path
  (bsc#1012628).
- Revert "mm/gup: check page posion status for
  coredump." (bsc#1012628).
- dm snapshot: fix crash with transient storage and zero chunk
  size (bsc#1012628).
- kcsan: Fix debugfs initcall return type (bsc#1012628).
- Revert "video: hgafb: fix potential NULL pointer dereference"
  (bsc#1012628).
- Revert "net: stmicro: fix a missing check of clk_prepare"
  (bsc#1012628).
- Revert "leds: lp5523: fix a missing check of return value of
  lp55xx_read" (bsc#1012628).
- Revert "hwmon: (lm80) fix a missing check of bus read in lm80
  probe" (bsc#1012628).
- Revert "video: imsttfb: fix potential NULL pointer dereferences"
  (bsc#1012628).
- Revert "ecryptfs: replace BUG_ON with error handling code"
  (bsc#1012628).
- Revert "scsi: ufs: fix a missing check of
  devm_reset_control_get" (bsc#1012628).
- Revert "gdrom: fix a memory leak bug" (bsc#1012628).
- cdrom: gdrom: deallocate struct gdrom_unit fields in
  remove_gdrom (bsc#1012628).
- cdrom: gdrom: initialize global variable at init time
  (bsc#1012628).
- Revert "media: rcar_drif: fix a memory disclosure"
  (bsc#1012628).
- Revert "rtlwifi: fix a potential NULL pointer dereference"
  (bsc#1012628).
- Revert "qlcnic: Avoid potential NULL pointer dereference"
  (bsc#1012628).
- Revert "niu: fix missing checks of niu_pci_eeprom_read"
  (bsc#1012628).
- ethernet: sun: niu: fix missing checks of niu_pci_eeprom_read()
  (bsc#1012628).
- net: stmicro: handle clk_prepare() failure during init
  (bsc#1012628).
- scsi: ufs: handle cleanup correctly on devm_reset_control_get
  error (bsc#1012628).
- net: rtlwifi: properly check for alloc_workqueue() failure
  (bsc#1012628).
- ics932s401: fix broken handling of errors when word reading
  fails (bsc#1012628).
- leds: lp5523: check return value of lp5xx_read and jump to
  cleanup code (bsc#1012628).
- qlcnic: Add null check after calling netdev_alloc_skb
  (bsc#1012628).
- video: hgafb: fix potential NULL pointer dereference
  (bsc#1012628).
- vgacon: Record video mode changes with VT_RESIZEX (bsc#1012628).
- vt_ioctl: Revert VT_RESIZEX parameter handling removal
  (bsc#1012628).
- vt: Fix character height handling with VT_RESIZEX (bsc#1012628).
- tty: vt: always invoke vc->vc_sw->con_resize callback
  (bsc#1012628).
- drm/i915/gt: Disable HiZ Raw Stall Optimization on broken gen7
  (bsc#1012628).
- openrisc: mm/init.c: remove unused memblock_region variable
  in map_ram() (bsc#1012628).
- x86/Xen: swap NX determination and GDT setup on BSP
  (bsc#1012628).
- nvme-multipath: fix double initialization of ANA state
  (bsc#1012628).
- rtc: pcf85063: fallback to parent of_node (bsc#1012628).
- x86/boot/compressed/64: Check SEV encryption in the 32-bit
  boot-path (bsc#1012628).
- nvmet: use new ana_log_size instead the old one (bsc#1012628).
- video: hgafb: correctly handle card detect failure during probe
  (bsc#1012628).
- Bluetooth: SMP: Fail if remote and local public keys are
  identical (bsc#1012628).
- commit 06f922b
* Thu May 27 2021 jslaby@suse.cz
- Refresh
  patches.suse/ACPI-PM-s2idle-Add-missing-LPS0-functions-for-AMD.patch.
- Refresh
  patches.suse/ath10k-Fix-TKIP-Michael-MIC-verification-for-PCIe.patch.
- Refresh
  patches.suse/ath10k-Validate-first-subframe-of-A-MSDU-before-proc.patch.
- Refresh
  patches.suse/ath10k-add-CCMP-PN-replay-protection-for-fragmented-.patch.
- Refresh
  patches.suse/ath10k-drop-MPDU-which-has-discard-flag-set-by-firmw.patch.
- Refresh
  patches.suse/ath10k-drop-fragments-with-multicast-DA-for-PCIe.patch.
- Refresh
  patches.suse/ath10k-drop-fragments-with-multicast-DA-for-SDIO.patch.
- Refresh
  patches.suse/ath11k-Clear-the-fragment-cache-during-key-install.patch.
- Refresh
  patches.suse/can-isotp-prevent-race-between-isotp_bind-and-isotp_.patch.
- Refresh
  patches.suse/cfg80211-mitigate-A-MSDU-aggregation-attacks.patch.
- Refresh
  patches.suse/clk-bcm-rpi-release-firmware-handle-on-unbind.patch.
- Refresh
  patches.suse/drm-i915-gem-Pin-the-L-shape-quirked-object-as-unshrinkable.patch.
- Refresh
  patches.suse/drm-radeon-use-the-dummy-page-for-GART-if-needed.patch.
- Refresh
  patches.suse/dt-bindings-pwm-add-binding-for-rpi-firmware-pwm-bus.patch.
- Refresh
  patches.suse/firmware-raspberrypi-introduce-devm_rpi_firmware_get.patch.
- Refresh
  patches.suse/firmware-raspberrypi-keep-count-of-all-consumers.patch.
- Refresh
  patches.suse/gpio-raspberrypi-exp-release-firmware-handle-on-unbind.patch.
- Refresh
  patches.suse/mac80211-add-fragment-cache-to-sta_info.patch.
- Refresh
  patches.suse/mac80211-assure-all-fragments-are-encrypted.patch.
- Refresh
  patches.suse/mac80211-check-defrag-PN-against-current-frame.patch.
- Refresh patches.suse/mac80211-drop-A-MSDUs-on-old-ciphers.patch.
- Refresh
  patches.suse/mac80211-extend-protection-against-mixed-key-and-fra.patch.
- Refresh
  patches.suse/mac80211-prevent-attacks-on-TKIP-WEP-as-well.patch.
- Refresh
  patches.suse/mac80211-prevent-mixed-key-and-fragment-cache-attack.patch.
- Refresh
  patches.suse/mac80211-properly-handle-A-MSDUs-that-start-with-an-.patch.
- Refresh
  patches.suse/proc-Avoid-mixing-integer-types-in-mem_rw.patch.
- Refresh
  patches.suse/pwm-add-raspberry-pi-firmware-based-pwm-bus.patch.
- Refresh
  patches.suse/reset-raspberrypi-release-firmware-handle-on-unbind.patch.
- Refresh
  patches.suse/soc-bcm-raspberrypi-power-release-firmware-handle-on-unbind.patch.
- Refresh
  patches.suse/vchiq-release-firmware-handle-on-unbind.patch.
- Refresh
  patches.suse/ipc-mqueue-msg-sem-Avoid-relying-on-a-stack-reference.patch.
  Update upstream status.
- commit 9d851b0
* Mon May 24 2021 mkubecek@suse.cz
- Update to 5.13-rc3
- eliminated 3 patches
  patches.rpmify/kbuild-dummy-tools-adjust-to-stricter-stackprotector.patch
  patches.suse/ipc-mqueue-msg-sem-Avoid-relying-on-a-stack-reference.patch
- commit 2d296e7
* Sat May 22 2021 jslaby@suse.cz
- Linux 5.12.6 (bsc#1012628).
- x86/msr: Fix wr/rdmsr_safe_regs_on_cpu() prototypes
  (bsc#1012628).
- drm/i915/display: fix compiler warning about array overrun
  (bsc#1012628).
- airo: work around stack usage warning (bsc#1012628).
- kgdb: fix gcc-11 warning on indentation (bsc#1012628).
- usb: sl811-hcd: improve misleading indentation (bsc#1012628).
- PCI: thunder: Fix compile testing (bsc#1012628).
- dmaengine: dw-edma: Fix crash on loading/unloading driver
  (bsc#1012628).
- ARM: 9066/1: ftrace: pause/unpause function graph tracer in
  cpu_suspend() (bsc#1012628).
- NFS: Fix fscache invalidation in nfs_set_cache_invalid()
  (bsc#1012628).
- ACPI / hotplug / PCI: Fix reference count leak in enable_slot()
  (bsc#1012628).
- PCI: tegra: Fix runtime PM imbalance in
  pex_ep_event_pex_rst_deassert() (bsc#1012628).
- Input: elants_i2c - do not bind to i2c-hid compatible ACPI
  instantiated devices (bsc#1012628).
- Input: silead - add workaround for x86 BIOS-es which bring
  the chip up in a stuck state (bsc#1012628).
- NFS: NFS_INO_REVAL_PAGECACHE should mark the change attribute
  invalid (bsc#1012628).
- f2fs: fix to avoid NULL pointer dereference (bsc#1012628).
- svcrdma: Don't leak send_ctxt on Send errors (bsc#1012628).
- um: Mark all kernel symbols as local (bsc#1012628).
- um: Disable CONFIG_GCOV with MODULES (bsc#1012628).
- ARM: 9075/1: kernel: Fix interrupted SMC calls (bsc#1012628).
- platform/chrome: cros_ec_typec: Add DP mode check (bsc#1012628).
- riscv: Use $(LD) instead of $(CC) to link vDSO (bsc#1012628).
- scripts/recordmcount.pl: Fix RISC-V regex for clang
  (bsc#1012628).
- riscv: Workaround mcount name prior to clang-13 (bsc#1012628).
- scsi: lpfc: Fix illegal memory access on Abort IOCBs
  (bsc#1012628).
- ceph: fix fscache invalidation (bsc#1012628).
- ceph: don't clobber i_snap_caps on non-I_NEW inode
  (bsc#1012628).
- ceph: don't allow access to MDS-private inodes (bsc#1012628).
- scsi: target: tcmu: Return from tcmu_handle_completions()
  if cmd_id not found (bsc#1012628).
- amdgpu/pm: Prevent force of DCEFCLK on NAVI10 and SIENNA_CICHLID
  (bsc#1012628).
- bridge: Fix possible races between assigning rx_handler_data
  and setting IFF_BRIDGE_PORT bit (bsc#1012628).
- net: hsr: check skb can contain struct hsr_ethhdr in
  fill_frame_info (bsc#1012628).
- nvmet: remove unsupported command noise (bsc#1012628).
- drm/amd/display: Fix two cursor duplication when using overlay
  (bsc#1012628).
- gpiolib: acpi: Add quirk to ignore EC wakeups on Dell Venue
  10 Pro 5055 (bsc#1012628).
- net:CXGB4: fix leak if sk_buff is not used (bsc#1012628).
- ALSA: hda: generic: change the DAC ctl name for LO+SPK or LO+HP
  (bsc#1012628).
- block: reexpand iov_iter after read/write (bsc#1012628).
- lib: stackdepot: turn depot_lock spinlock to raw_spinlock
  (bsc#1012628).
- net: stmmac: Do not enable RX FIFO overflow interrupts
  (bsc#1012628).
- ip6_gre: proper dev_{hold|put} in ndo_[un]init methods
  (bsc#1012628).
- sit: proper dev_{hold|put} in ndo_[un]init methods
  (bsc#1012628).
- ip6_tunnel: sit: proper dev_{hold|put} in ndo_[un]init methods
  (bsc#1012628).
- bus: mhi: core: Download AMSS image from appropriate function
  (bsc#1012628).
- commit fe25271
* Wed May 19 2021 jslaby@suse.cz
- Refresh
  patches.suse/crypto-ccp-Annotate-SEV-Firmware-file-names.patch.
  Update upstream status.
- commit 37a9337
* Wed May 19 2021 jslaby@suse.cz
- ipv6: remove extra dev_hold() for fallback tunnels (git-fixes).
- x86/events/amd/iommu: Fix invalid Perf result due to IOMMU
  PMC power-gating (git-fixes).
- commit 5eb2110
* Wed May 19 2021 jslaby@suse.cz
- Linux 5.12.5 (bsc#1012628).
- KEYS: trusted: Fix memory leak on object td (bsc#1012628).
- tpm: fix error return code in tpm2_get_cc_attrs_tbl()
  (bsc#1012628).
- tpm, tpm_tis: Extend locality handling to TPM2 in
  tpm_tis_gen_interrupt() (bsc#1012628).
- tpm, tpm_tis: Reserve locality in tpm_tis_resume()
  (bsc#1012628).
- btrfs: fix unmountable seed device after fstrim (bsc#1012628).
- KVM: SVM: Make sure GHCB is mapped before updating
  (bsc#1012628).
- KVM/VMX: Invoke NMI non-IST entry instead of IST entry
  (bsc#1012628).
- ACPI: PM: Add ACPI ID of Alder Lake Fan (bsc#1012628).
- PM: runtime: Fix unpaired parent child_count for force_resume
  (bsc#1012628).
- cpufreq: intel_pstate: Use HWP if enabled by platform firmware
  (bsc#1012628).
- kvm: Cap halt polling at kvm->max_halt_poll_ns (bsc#1012628).
- ath11k: fix thermal temperature read (bsc#1012628).
- ALSA: usb-audio: Add Pioneer DJM-850 to quirks-table
  (bsc#1012628).
- fs: dlm: fix debugfs dump (bsc#1012628).
- fs: dlm: fix mark setting deadlock (bsc#1012628).
- fs: dlm: add errno handling to check callback (bsc#1012628).
- fs: dlm: add check if dlm is currently running (bsc#1012628).
- fs: dlm: change allocation limits (bsc#1012628).
- fs: dlm: check on minimum msglen size (bsc#1012628).
- fs: dlm: flush swork on shutdown (bsc#1012628).
- fs: dlm: add shutdown hook (bsc#1012628).
- tipc: convert dest node's address to network order
  (bsc#1012628).
- ASoC: Intel: bytcr_rt5640: Enable jack-detect support on Asus
  T100TAF (bsc#1012628).
- net/mlx5e: Use net_prefetchw instead of prefetchw in MPWQE TX
  datapath (bsc#1012628).
- net: stmmac: Set FIFO sizes for ipq806x (bsc#1012628).
- ASoC: rsnd: core: Check convert rate in rsnd_hw_params
  (bsc#1012628).
- Bluetooth: Fix incorrect status handling in LE PHY UPDATE event
  (bsc#1012628).
- i2c: bail out early when RDWR parameters are wrong
  (bsc#1012628).
- ALSA: hdsp: don't disable if not enabled (bsc#1012628).
- ALSA: hdspm: don't disable if not enabled (bsc#1012628).
- ALSA: rme9652: don't disable if not enabled (bsc#1012628).
- ALSA: bebob: enable to deliver MIDI messages for multiple ports
  (bsc#1012628).
- Bluetooth: Set CONF_NOT_COMPLETE as l2cap_chan default
  (bsc#1012628).
- Bluetooth: initialize skb_queue_head at l2cap_chan_create()
  (bsc#1012628).
- net/sched: cls_flower: use ntohs for struct
  flow_dissector_key_ports (bsc#1012628).
- net: bridge: when suppression is enabled exclude RARP packets
  (bsc#1012628).
- Bluetooth: check for zapped sk before connecting (bsc#1012628).
- selftests/powerpc: Fix L1D flushing tests for Power10
  (bsc#1012628).
- ALSA: hda/hdmi: fix max DP-MST dev_num for Intel TGL+ platforms
  (bsc#1012628).
- powerpc/32: Statically initialise first emergency context
  (bsc#1012628).
- net: hns3: remediate a potential overflow risk of bd_num_list
  (bsc#1012628).
- net: hns3: add handling for xmit skb with recursive fraglist
  (bsc#1012628).
- ip6_vti: proper dev_{hold|put} in ndo_[un]init methods
  (bsc#1012628).
- can: dev: can_free_echo_skb(): don't crash the kernel if
  can_priv::echo_skb is accessed out of bounds (bsc#1012628).
- iommu/arm-smmu-v3: Add a check to avoid invalid iotlb sync
  (bsc#1012628).
- ASoC: Intel: bytcr_rt5640: Add quirk for the Chuwi Hi8 tablet
  (bsc#1012628).
- ice: handle increasing Tx or Rx ring sizes (bsc#1012628).
- Bluetooth: btusb: Enable quirk boolean flag for Mediatek Chip
  (bsc#1012628).
- ASoC: rt5670: Add a quirk for the Dell Venue 10 Pro 5055
  (bsc#1012628).
- selftests: mptcp: launch mptcp_connect with timeout
  (bsc#1012628).
- i2c: Add I2C_AQ_NO_REP_START adapter quirk (bsc#1012628).
- Bluetooth: Do not set cur_adv_instance in adv param MGMT request
  (bsc#1012628).
- MIPS: Loongson64: Use _CACHE_UNCACHED instead of
  _CACHE_UNCACHED_ACCELERATED (bsc#1012628).
- coresight: Do not scan for graph if none is present
  (bsc#1012628).
- IB/hfi1: Correct oversized ring allocation (bsc#1012628).
- mac80211: Set priority and queue mapping for injected frames
  (bsc#1012628).
- mac80211: clear the beacon's CRC after channel switch
  (bsc#1012628).
- ASoC: soc-compress: lock pcm_mutex to resolve lockdep error
  (bsc#1012628).
- net: phy: make PHY PM ops a no-op if MAC driver manages PHY PM
  (bsc#1012628).
- net: fec: use mac-managed PHY PM (bsc#1012628).
- pinctrl: samsung: use 'int' for register masks in Exynos
  (bsc#1012628).
- rtw88: 8822c: add LC calibration for RTL8822C (bsc#1012628).
- mt76: mt7615: fix key set/delete issues (bsc#1012628).
- mt76: mt7615: support loading EEPROM for MT7613BE (bsc#1012628).
- mt76: mt76x0: disable GTK offloading (bsc#1012628).
- mt76: connac: always check return value from
  mt76_connac_mcu_alloc_wtbl_req (bsc#1012628).
- mt76: mt7915: always check return value from
  mt7915_mcu_alloc_wtbl_req (bsc#1012628).
- mt76: mt7915: fix key set/delete issue (bsc#1012628).
- mt76: mt7915: fix txpower init for TSSI off chips (bsc#1012628).
- mt76: mt7921: fix key set/delete issue (bsc#1012628).
- mt76: mt7915: add wifi subsystem reset (bsc#1012628).
- i2c: imx: Fix PM reference leak in i2c_imx_reg_slave()
  (bsc#1012628).
- fuse: invalidate attrs when page writeback completes
  (bsc#1012628).
- virtiofs: fix userns (bsc#1012628).
- cuse: prevent clone (bsc#1012628).
- iwlwifi: pcie: make cfg vs. trans_cfg more robust (bsc#1012628).
- iwlwifi: queue: avoid memory leak in reset flow (bsc#1012628).
- iwlwifi: trans/pcie: defer transport initialisation
  (bsc#1012628).
- powerpc/mm: Add cond_resched() while removing hpte mappings
  (bsc#1012628).
- ASoC: rsnd: call rsnd_ssi_master_clk_start() from
  rsnd_ssi_init() (bsc#1012628).
- net: bridge: propagate error code and extack from
  br_mc_disabled_update (bsc#1012628).
- Revert "iommu/amd: Fix performance counter initialization"
  (bsc#1012628).
- iommu/amd: Remove performance counter pre-initialization test
  (bsc#1012628).
- drm/amd/display: Force vsync flip when reconfiguring MPCC
  (bsc#1012628).
- selftests: Set CC to clang in lib.mk if LLVM is set
  (bsc#1012628).
- kconfig: nconf: stop endless search loops (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Lenovo Ideapad S740
  (bsc#1012628).
- ASoC: Intel: sof_sdw: add quirk for new ADL-P Rvp (bsc#1012628).
- ALSA: hda/hdmi: fix race in handling acomp ELD notification
  at resume (bsc#1012628).
- i2c: i801: Add support for Intel Alder Lake PCH-M (bsc#1012628).
- sctp: Fix out-of-bounds warning in sctp_process_asconf_param()
  (bsc#1012628).
- flow_dissector: Fix out-of-bounds warning in
  __skb_flow_bpf_to_target() (bsc#1012628).
- powerpc/xive: Use the "ibm, chip-id" property only under PowerNV
  (bsc#1012628).
- powerpc/smp: Set numa node before updating mask (bsc#1012628).
- wilc1000: Bring MAC address setting in line with typical Linux
  behavior (bsc#1012628).
- mac80211: properly drop the connection in case of invalid CSA IE
  (bsc#1012628).
- ASoC: rt286: Generalize support for ALC3263 codec (bsc#1012628).
- ethtool: ioctl: Fix out-of-bounds warning in
  store_link_ksettings_for_user() (bsc#1012628).
- net: sched: tapr: prevent cycle_time == 0 in
  parse_taprio_schedule (bsc#1012628).
- samples/bpf: Fix broken tracex1 due to kprobe argument change
  (bsc#1012628).
- powerpc/pseries: Stop calling printk in rtas_stop_self()
  (bsc#1012628).
- drm/amd/display: fixed divide by zero kernel crash during dsc
  enablement (bsc#1012628).
- drm/amd/display: add handling for hdcp2 rx id list validation
  (bsc#1012628).
- drm/amdgpu: Add mem sync flag for IB allocated by SA
  (bsc#1012628).
- mt76: mt7615: fix entering driver-own state on mt7663
  (bsc#1012628).
- crypto: ccp: Free SEV device if SEV init fails (bsc#1012628).
- wl3501_cs: Fix out-of-bounds warnings in wl3501_send_pkt
  (bsc#1012628).
- wl3501_cs: Fix out-of-bounds warnings in wl3501_mgmt_join
  (bsc#1012628).
- qtnfmac: Fix possible buffer overflow in
  qtnf_event_handle_external_auth (bsc#1012628).
- powerpc/iommu: Annotate nested lock for lockdep (bsc#1012628).
- iavf: remove duplicate free resources calls (bsc#1012628).
- net: ethernet: mtk_eth_soc: fix RX VLAN offload (bsc#1012628).
- selftests: mlxsw: Increase the tolerance of backlog buildup
  (bsc#1012628).
- selftests: mlxsw: Fix mausezahn invocation in ERSPAN scale test
  (bsc#1012628).
- kbuild: generate Module.symvers only when vmlinux exists
  (bsc#1012628).
- bnxt_en: Add PCI IDs for Hyper-V VF devices (bsc#1012628).
- ia64: module: fix symbolizer crash on fdescr (bsc#1012628).
- watchdog: rename __touch_watchdog() to a better descriptive name
  (bsc#1012628).
- watchdog: explicitly update timestamp when reporting softlockup
  (bsc#1012628).
- watchdog/softlockup: report the overall time of softlockups
  (bsc#1012628).
- watchdog/softlockup: remove logic that tried to prevent repeated
  reports (bsc#1012628).
- watchdog: fix barriers when printing backtraces from all CPUs
  (bsc#1012628).
- ASoC: rt286: Make RT286_SET_GPIO_* readable and writable
  (bsc#1012628).
- leds: lgm: fix gpiolib dependency (bsc#1012628).
- thermal: thermal_of: Fix error return code of
  thermal_of_populate_bind_params() (bsc#1012628).
- PCI/RCEC: Fix RCiEP device to RCEC association (bsc#1012628).
- f2fs: fix to allow migrating fully valid segment (bsc#1012628).
- f2fs: fix panic during f2fs_resize_fs() (bsc#1012628).
- f2fs: fix a redundant call to f2fs_balance_fs if an error occurs
  (bsc#1012628).
- rtc: tps65910: include linux/property.h (bsc#1012628).
- remoteproc: qcom_q6v5_mss: Validate p_filesz in ELF loader
  (bsc#1012628).
- PCI: iproc: Fix return value of iproc_msi_irq_domain_alloc()
  (bsc#1012628).
- PCI: brcmstb: Fix error return code in brcm_pcie_probe()
  (bsc#1012628).
- PCI: Release OF node in pci_scan_device()'s error path
  (bsc#1012628).
- ARM: 9064/1: hw_breakpoint: Do not directly check the event's
  overflow_handler hook (bsc#1012628).
- f2fs: fix to align to section for fallocate() on pinned file
  (bsc#1012628).
- f2fs: fix to update last i_size if fallocate partially succeeds
  (bsc#1012628).
- PCI: endpoint: Fix NULL pointer dereference for ->get_features()
  (bsc#1012628).
- f2fs: fix to avoid touching checkpointed data in get_victim()
  (bsc#1012628).
- f2fs: fix to cover __allocate_new_section() with curseg_lock
  (bsc#1012628).
- fs: 9p: fix v9fs_file_open writeback fid error check
  (bsc#1012628).
- f2fs: fix to restrict mount condition on readonly block device
  (bsc#1012628).
- f2fs: Fix a hungtask problem in atomic write (bsc#1012628).
- nfs: Subsequent READDIR calls should carry non-zero
  cookieverifier (bsc#1012628).
- NFS: Fix handling of cookie verifier in uncached_readdir()
  (bsc#1012628).
- NFS: Only change the cookie verifier if the directory page
  cache is empty (bsc#1012628).
- f2fs: fix to avoid accessing invalid fio in
  f2fs_allocate_data_block() (bsc#1012628).
- rpmsg: qcom_glink_native: fix error return code of
  qcom_glink_rx_data() (bsc#1012628).
- NFS: nfs4_bitmask_adjust() must not change the server global
  bitmasks (bsc#1012628).
- NFS: Fix attribute bitmask in _nfs42_proc_fallocate()
  (bsc#1012628).
- NFSv4.2: Always flush out writes in nfs42_proc_fallocate()
  (bsc#1012628).
- NFS: Deal correctly with attribute generation counter overflow
  (bsc#1012628).
- PCI: endpoint: Fix missing destroy_workqueue() (bsc#1012628).
- remoteproc: pru: Fixup interrupt-parent logic for fw events
  (bsc#1012628).
- remoteproc: pru: Fix wrong success return value for fw events
  (bsc#1012628).
- remoteproc: pru: Fix and cleanup firmware interrupt mapping
  logic (bsc#1012628).
- pNFS/flexfiles: fix incorrect size check in decode_nfs_fh()
  (bsc#1012628).
- NFSv4.2 fix handling of sr_eof in SEEK's reply (bsc#1012628).
- SUNRPC: Move fault injection call sites (bsc#1012628).
- SUNRPC: Remove trace_xprt_transmit_queued (bsc#1012628).
- SUNRPC: Handle major timeout in xprt_adjust_timeout()
  (bsc#1012628).
- NFSv42: Copy offload should update the file size when
  appropriate (bsc#1012628).
- thermal/drivers/tsens: Fix missing put_device error
  (bsc#1012628).
- NFSv4.x: Don't return NFS4ERR_NOMATCHING_LAYOUT if we're
  unmounting (bsc#1012628).
- nfsd: ensure new clients break delegations (bsc#1012628).
- rtc: fsl-ftm-alarm: add MODULE_TABLE() (bsc#1012628).
- dmaengine: idxd: Fix potential null dereference on pointer
  status (bsc#1012628).
- dmaengine: idxd: fix dma device lifetime (bsc#1012628).
- dmaengine: idxd: cleanup pci interrupt vector allocation
  management (bsc#1012628).
- dmaengine: idxd: removal of pcim managed mmio mapping
  (bsc#1012628).
- dmaengine: idxd: use ida for device instance enumeration
  (bsc#1012628).
- dmaengine: idxd: fix idxd conf_dev 'struct device' lifetime
  (bsc#1012628).
- dmaengine: idxd: fix wq conf_dev 'struct device' lifetime
  (bsc#1012628).
- dmaengine: idxd: fix engine conf_dev lifetime (bsc#1012628).
- dmaengine: idxd: fix group conf_dev lifetime (bsc#1012628).
- dmaengine: idxd: fix cdev setup and free device lifetime issues
  (bsc#1012628).
- SUNRPC: fix ternary sign expansion bug in tracing (bsc#1012628).
- SUNRPC: Fix null pointer dereference in svc_rqst_free()
  (bsc#1012628).
- pwm: atmel: Fix duty cycle calculation in .get_state()
  (bsc#1012628).
- xprtrdma: Avoid Receive Queue wrapping (bsc#1012628).
- xprtrdma: Fix cwnd update ordering (bsc#1012628).
- xprtrdma: rpcrdma_mr_pop() already does list_del_init()
  (bsc#1012628).
- riscv: Select HAVE_DYNAMIC_FTRACE when
  - fpatchable-function-entry is available (bsc#1012628).
- swiotlb: Fix the type of index (bsc#1012628).
- ceph: fix inode leak on getattr error in __fh_to_dentry
  (bsc#1012628).
- scsi: qla2xxx: Prevent PRLI in target mode (bsc#1012628).
- scsi: ufs: core: Do not put UFS power into LPM if link is broken
  (bsc#1012628).
- scsi: ufs: core: Cancel rpm_dev_flush_recheck_work during
  system suspend (bsc#1012628).
- scsi: ufs: core: Narrow down fast path in system suspend path
  (bsc#1012628).
- rtc: ds1307: Fix wday settings for rx8130 (bsc#1012628).
- net: hns3: fix incorrect configuration for igu_egu_hw_err
  (bsc#1012628).
- net: hns3: initialize the message content in
  hclge_get_link_mode() (bsc#1012628).
- net: hns3: add check for HNS3_NIC_STATE_INITED in
  hns3_reset_notify_up_enet() (bsc#1012628).
- arm64: stacktrace: restore terminal records (bsc#1012628).
- net: hns3: fix for vxlan gpe tx checksum bug (bsc#1012628).
- net: hns3: use netif_tx_disable to stop the transmit queue
  (bsc#1012628).
- net: hns3: disable phy loopback setting in hclge_mac_start_phy
  (bsc#1012628).
- sctp: do asoc update earlier in sctp_sf_do_dupcook_a
  (bsc#1012628).
- RISC-V: Fix error code returned by riscv_hartid_to_cpuid()
  (bsc#1012628).
- sunrpc: Fix misplaced barrier in call_decode (bsc#1012628).
- libbpf: Fix signed overflow in ringbuf_process_ring
  (bsc#1012628).
- block/rnbd-clt: Change queue_depth type in rnbd_clt_session
  to size_t (bsc#1012628).
- block/rnbd-clt: Check the return value of the function
  rtrs_clt_query (bsc#1012628).
- ata: ahci_brcm: Fix use of BCM7216 reset controller
  (bsc#1012628).
- PCI: brcmstb: Use reset/rearm instead of deassert/assert
  (bsc#1012628).
- ethernet:enic: Fix a use after free bug in enic_hard_start_xmit
  (bsc#1012628).
- sctp: fix a SCTP_MIB_CURRESTAB leak in sctp_sf_do_dupcook_b
  (bsc#1012628).
- netfilter: xt_SECMARK: add new revision to fix structure layout
  (bsc#1012628).
- xsk: Fix for xp_aligned_validate_desc() when len == chunk_size
  (bsc#1012628).
- powerpc/powernv/memtrace: Fix dcache flushing (bsc#1012628).
- net: stmmac: Clear receive all(RA) bit when promiscuous mode
  is off (bsc#1012628).
- drm/radeon: Fix off-by-one power_state index heap overwrite
  (bsc#1012628).
- drm/radeon: Avoid power table parsing memory leaks
  (bsc#1012628).
- arm64: entry: factor irq triage logic into macros (bsc#1012628).
- arm64: entry: always set GIC_PRIO_PSR_I_SET during entry
  (bsc#1012628).
- khugepaged: fix wrong result value for
  trace_mm_collapse_huge_page_isolate() (bsc#1012628).
- mm/hugeltb: handle the error case in
  hugetlb_fix_reserve_counts() (bsc#1012628).
- mm/migrate.c: fix potential indeterminate pte entry in
  migrate_vma_insert_page() (bsc#1012628).
- ksm: fix potential missing rmap_item for stable_node
  (bsc#1012628).
- mm/gup: check every subpage of a compound page during isolation
  (bsc#1012628).
- mm/gup: return an error on migration failure (bsc#1012628).
- mm/gup: check for isolation errors (bsc#1012628).
- kfence: await for allocation using wait_event (bsc#1012628).
- ethtool: fix missing NLM_F_MULTI flag when dumping
  (bsc#1012628).
- net: fix nla_strcmp to handle more then one trailing null
  character (bsc#1012628).
- smc: disallow TCP_ULP in smc_setsockopt() (bsc#1012628).
- netfilter: nfnetlink_osf: Fix a missing skb_header_pointer()
  NULL check (bsc#1012628).
- netfilter: nftables: Fix a memleak from userdata error path
  in new objects (bsc#1012628).
- can: mcp251xfd: mcp251xfd_probe(): fix an error pointer
  dereference in probe (bsc#1012628).
- can: mcp251xfd: mcp251xfd_probe(): add missing
  can_rx_offload_del() in error path (bsc#1012628).
- can: mcp251x: fix resume from sleep before interface was
  brought up (bsc#1012628).
- can: m_can: m_can_tx_work_queue(): fix tx_skb race condition
  (bsc#1012628).
- sched: Fix out-of-bound access in uclamp (bsc#1012628).
- sched/fair: Fix unfairness caused by missing load decay
  (bsc#1012628).
- net: ipa: fix inter-EE IRQ register definitions (bsc#1012628).
- fs/proc/generic.c: fix incorrect pde_is_permanent check
  (bsc#1012628).
- kernel: kexec_file: fix error return code of
  kexec_calculate_store_digests() (bsc#1012628).
- kernel/resource: make walk_system_ram_res() find all busy
  IORESOURCE_SYSTEM_RAM resources (bsc#1012628).
- kernel/resource: make walk_mem_res() find all busy
  IORESOURCE_MEM resources (bsc#1012628).
- netfilter: nftables: avoid overflows in nft_hash_buckets()
  (bsc#1012628).
- i40e: fix broken XDP support (bsc#1012628).
- i40e: Fix use-after-free in i40e_client_subtask() (bsc#1012628).
- i40e: fix the restart auto-negotiation after FEC modified
  (bsc#1012628).
- i40e: Fix PHY type identifiers for 2.5G and 5G adapters
  (bsc#1012628).
- i40e: Remove LLDP frame filters (bsc#1012628).
- mptcp: fix splat when closing unaccepted socket (bsc#1012628).
- ARC: entry: fix off-by-one error in syscall number validation
  (bsc#1012628).
- ARC: mm: PAE: use 40-bit physical page mask (bsc#1012628).
- ARC: mm: Use max_high_pfn as a HIGHMEM zone border
  (bsc#1012628).
- sh: Remove unused variable (bsc#1012628).
- powerpc/64s: Fix crashes when toggling stf barrier
  (bsc#1012628).
- powerpc/64s: Fix crashes when toggling entry flush barrier
  (bsc#1012628).
- hfsplus: prevent corruption in shrinking truncate (bsc#1012628).
- squashfs: fix divide error in calculate_skip() (bsc#1012628).
- userfaultfd: release page in error path to avoid BUG_ON
  (bsc#1012628).
- kasan: fix unit tests with CONFIG_UBSAN_LOCAL_BOUNDS enabled
  (bsc#1012628).
- mm/hugetlb: fix F_SEAL_FUTURE_WRITE (bsc#1012628).
- mm/hugetlb: fix cow where page writtable in child (bsc#1012628).
- blk-iocost: fix weight updates of inner active iocgs
  (bsc#1012628).
- x86, sched: Fix the AMD CPPC maximum performance value on
  certain AMD Ryzen generations (bsc#1012628).
- arm64: mte: initialize RGSR_EL1.SEED in __cpu_setup
  (bsc#1012628).
- arm64: Fix race condition on PG_dcache_clean in
  __sync_icache_dcache() (bsc#1012628).
- btrfs: fix deadlock when cloning inline extents and using
  qgroups (bsc#1012628).
- btrfs: zoned: fix silent data loss after failure splitting
  ordered extent (bsc#1012628).
- btrfs: fix race leading to unpersisted data and metadata on
  fsync (bsc#1012628).
- btrfs: initialize return variable in cleanup_free_space_cache_v1
  (bsc#1012628).
- btrfs: zoned: sanity check zone type (bsc#1012628).
- drm/radeon/dpm: Disable sclk switching on Oland when two 4K
  60Hz monitors are connected (bsc#1012628).
- drm/amd/display: Initialize attribute for hdcp_srm sysfs file
  (bsc#1012628).
- drm/i915: Avoid div-by-zero on gen2 (bsc#1012628).
- kvm: exit halt polling on need_resched() as well (bsc#1012628).
- drm/msm: fix LLC not being enabled for mmu500 targets
  (bsc#1012628).
- KVM: LAPIC: Accurately guarantee busy wait for timer to expire
  when using hv_timer (bsc#1012628).
- drm/msm/dp: initialize audio_comp when audio starts
  (bsc#1012628).
- KVM: x86: Cancel pvclock_gtod_work on module removal
  (bsc#1012628).
- KVM: x86: Prevent deadlock against tk_core.seq (bsc#1012628).
- KVM: SVM: Move GHCB unmapping to fix RCU warning (bsc#1012628).
- dax: Add an enum for specifying dax wakup mode (bsc#1012628).
- dax: Add a wakeup mode parameter to put_unlocked_entry()
  (bsc#1012628).
- dax: Wake up all waiters after invalidating dax entry
  (bsc#1012628).
- xen/unpopulated-alloc: fix error return code in fill_list()
  (bsc#1012628).
- perf tools: Fix dynamic libbpf link (bsc#1012628).
- usb: dwc3: gadget: Free gadget structure only after freeing
  endpoints (bsc#1012628).
- iio: light: gp2ap002: Fix rumtime PM imbalance on error
  (bsc#1012628).
- iio: proximity: pulsedlight: Fix rumtime PM imbalance on error
  (bsc#1012628).
- iio: hid-sensors: select IIO_TRIGGERED_BUFFER under
  HID_SENSOR_IIO_TRIGGER (bsc#1012628).
- iio: core: return ENODEV if ioctl is unknown (bsc#1012628).
- usb: fotg210-hcd: Fix an error message (bsc#1012628).
- hwmon: (occ) Fix poll rate limiting (bsc#1012628).
- usb: typec: tcpm: Fix wrong handling for Not_Supported in VDM
  AMS (bsc#1012628).
- usb: musb: Fix an error message (bsc#1012628).
- hwmon: (ltc2992) Put fwnode in error case during ->probe()
  (bsc#1012628).
- ACPI: scan: Fix a memory leak in an error handling path
  (bsc#1012628).
- kyber: fix out of bounds access when preempted (bsc#1012628).
- nvmet: fix inline bio check for bdev-ns (bsc#1012628).
- nvmet: fix inline bio check for passthru (bsc#1012628).
- nvmet-rdma: Fix NULL deref when SEND is completed with error
  (bsc#1012628).
- f2fs: compress: fix to free compress page correctly
  (bsc#1012628).
- f2fs: compress: fix race condition of overwrite vs truncate
  (bsc#1012628).
- f2fs: compress: fix to assign cc.cluster_idx correctly
  (bsc#1012628).
- sched/fair: Fix clearing of has_idle_cores flag in
  select_idle_cpu() (bsc#1012628).
- nbd: Fix NULL pointer in flush_workqueue (bsc#1012628).
- powerpc/64s: Make NMI record implicitly soft-masked code as
  irqs disabled (bsc#1012628).
- blk-mq: plug request for shared sbitmap (bsc#1012628).
- blk-mq: Swap two calls in blk_mq_exit_queue() (bsc#1012628).
- usb: dwc3: omap: improve extcon initialization (bsc#1012628).
- usb: dwc3: pci: Enable usb2-gadget-lpm-disable for Intel
  Merrifield (bsc#1012628).
- usb: xhci: Increase timeout for HC halt (bsc#1012628).
- usb: dwc2: Fix gadget DMA unmap direction (bsc#1012628).
- usb: core: hub: fix race condition about TRSMRCY of resume
  (bsc#1012628).
- usb: dwc3: imx8mp: fix error return code in dwc3_imx8mp_probe()
  (bsc#1012628).
- usb: dwc3: gadget: Enable suspend events (bsc#1012628).
- usb: dwc3: gadget: Return success always for kick transfer in
  ep queue (bsc#1012628).
- usb: typec: tcpm: Fix wrong handling in GET_SINK_CAP
  (bsc#1012628).
- usb: typec: ucsi: Retrieve all the PDOs instead of just the
  first 4 (bsc#1012628).
- usb: typec: ucsi: Put fwnode in any case during ->probe()
  (bsc#1012628).
- xhci-pci: Allow host runtime PM as default for Intel Alder
  Lake xHCI (bsc#1012628).
- xhci: Fix giving back cancelled URBs even if halted endpoint
  can't reset (bsc#1012628).
- xhci: Do not use GFP_KERNEL in (potentially) atomic context
  (bsc#1012628).
- xhci: Add reset resume quirk for AMD xhci controller
  (bsc#1012628).
- iio: core: fix ioctl handlers removal (bsc#1012628).
- iio: gyro: mpu3050: Fix reported temperature value
  (bsc#1012628).
- iio: tsl2583: Fix division by a zero lux_val (bsc#1012628).
- cdc-wdm: untangle a circular dependency between callback and
  softint (bsc#1012628).
- alarmtimer: Check RTC features instead of ops (bsc#1012628).
- xen/gntdev: fix gntdev_mmap() error exit path (bsc#1012628).
- KVM: x86: Emulate RDPID only if RDTSCP is supported
  (bsc#1012628).
- KVM: x86: Move RDPID emulation intercept to its own enum
  (bsc#1012628).
- KVM: x86: Add support for RDPID without RDTSCP (bsc#1012628).
- KVM: nVMX: Always make an attempt to map eVMCS after migration
  (bsc#1012628).
- KVM: VMX: Do not advertise RDPID if ENABLE_RDTSCP control is
  unsupported (bsc#1012628).
- KVM: VMX: Disable preemption when probing user return MSRs
  (bsc#1012628).
- mm: fix struct page layout on 32-bit systems (bsc#1012628).
- MIPS: Reinstate platform `__div64_32' handler (bsc#1012628).
- MIPS: Avoid DIVU in `__div64_32' is result would be zero
  (bsc#1012628).
- MIPS: Avoid handcoded DIVU in `__div64_32' altogether
  (bsc#1012628).
- clocksource/drivers/timer-ti-dm: Prepare to handle dra7 timer
  wrap issue (bsc#1012628).
- clocksource/drivers/timer-ti-dm: Handle dra7 timer wrap errata
  i940 (bsc#1012628).
- kobject_uevent: remove warning in init_uevent_argv()
  (bsc#1012628).
- drm/i915/gt: Fix a double free in gen8_preallocate_top_level_pdp
  (bsc#1012628).
- drm/msm/dp: check sink_count before update is_connected status
  (bsc#1012628).
- drm/i915: Read C0DRB3/C1DRB3 as 16 bits again (bsc#1012628).
- drm/i915/overlay: Fix active retire callback alignment
  (bsc#1012628).
- drm/i915: Fix crash in auto_retire (bsc#1012628).
- clk: exynos7: Mark aclk_fsys1_200 as critical (bsc#1012628).
- soc: mediatek: pm-domains: Add a meaningful power domain name
  (bsc#1012628).
- soc: mediatek: pm-domains: Add a power domain names for mt8183
  (bsc#1012628).
- soc: mediatek: pm-domains: Add a power domain names for mt8192
  (bsc#1012628).
- media: rkvdec: Remove of_match_ptr() (bsc#1012628).
- i2c: mediatek: Fix send master code at more than 1MHz
  (bsc#1012628).
- dt-bindings: media: renesas,vin: Make resets optional on R-Car
  Gen1 (bsc#1012628).
- dt-bindings: thermal: rcar-gen3-thermal: Support five TSC
  nodes on r8a779a0 (bsc#1012628).
- arm64: dts: renesas: falcon: Move console config to CPU board
  DTS (bsc#1012628).
- dt-bindings: phy: qcom,qmp-usb3-dp-phy: move usb3 compatibles
  back to qcom,qmp-phy.yaml (bsc#1012628).
- dt-bindings: serial: 8250: Remove duplicated compatible strings
  (bsc#1012628).
- dt-bindings: PCI: rcar-pci-host: Document missing R-Car H1
  support (bsc#1012628).
- debugfs: Make debugfs_allow RO after init (bsc#1012628).
- ext4: fix debug format string warning (bsc#1012628).
- nvme: do not try to reconfigure APST when the controller is
  not live (bsc#1012628).
- ASoC: rsnd: check all BUSIF status when error (bsc#1012628).
- net: bridge: fix error in br_multicast_add_port when
  CONFIG_NET_SWITCHDEV=n (bsc#1012628).
- Refresh
  patches.suse/usb-pci-quirks-disable-D3cold-on-xhci-suspend-for-s2.patch.
- commit 0ef707c
* Tue May 18 2021 tiwai@suse.de
- can: isotp: prevent race between isotp_bind() and
  isotp_setsockopt() (CVE-2021-32606 bsc#1185953 bsc#1185564).
- commit cf6ea2f
* Tue May 18 2021 tiwai@suse.de
- usb: pci-quirks: disable D3cold on xhci suspend for s2idle on
  AMD Renoire (bsc#1185840).
- ACPI / idle: override c-state latency when not in conformance
  with s0ix (bsc#1185840).
- ACPI: PM: s2idle: Add missing LPS0 functions for AMD
  (bsc#1185840).
- commit 152b604
* Mon May 17 2021 varad.gautam@suse.com
- ipc/mqueue, msg, sem: Avoid relying on a stack reference past
  its expiry (bsc#1185988).
- commit 2d71c6c
* Mon May 17 2021 varad.gautam@suse.com
- ipc/mqueue, msg, sem: Avoid relying on a stack reference past
  its expiry (bsc#1185988).
- commit 3e71e40
* Mon May 17 2021 mkubecek@suse.cz
- Update to 5.13-rc2
- commit 977da2f
* Sun May 16 2021 tiwai@suse.de
- drm/i915/gem: Pin the L-shape quirked object as unshrinkable
  (bsc#1185624 bsc#1186075).
- commit 6e53ea2
* Sat May 15 2021 mkubecek@suse.cz
- kbuild: dummy-tools: adjust to stricter stackprotector check.
  Fix i386 builds after recent changes of stackprotector feature check and
  restore stackprotector related config options.
- commit 9c7db9a
* Sat May 15 2021 jslaby@suse.cz
- serial: stm32: fix threaded interrupt handling (git-fixes).
- usb: typec: tcpm: Fix error while calculating PPS out values
  (git-fixes).
- RDMA/core: Unify RoCE check and re-factor code (git-fixes).
- commit a5aafd4
* Sat May 15 2021 jslaby@suse.cz
- Linux 5.12.4 (bsc#1012628).
- Bluetooth: verify AMP hci_chan before amp_destroy (bsc#1012628).
- bluetooth: eliminate the potential race condition when removing
  the HCI controller (bsc#1012628).
- net/nfc: fix use-after-free llcp_sock_bind/connect
  (bsc#1012628).
- io_uring: truncate lengths larger than MAX_RW_COUNT on provide
  buffers (bsc#1012628).
- coresight: etm-perf: Fix define build issue when built as module
  (bsc#1012628).
- software node: Allow node addition to already existing device
  (bsc#1012628).
- Revert "USB: cdc-acm: fix rounding error in TIOCSSERIAL"
  (bsc#1012628).
- usb: roles: Call try_module_get() from
  usb_role_switch_find_by_fwnode() (bsc#1012628).
- tty: moxa: fix TIOCSSERIAL jiffies conversions (bsc#1012628).
- tty: amiserial: fix TIOCSSERIAL permission check (bsc#1012628).
- USB: serial: usb_wwan: fix TIOCSSERIAL jiffies conversions
  (bsc#1012628).
- staging: greybus: uart: fix TIOCSSERIAL jiffies conversions
  (bsc#1012628).
- USB: serial: ti_usb_3410_5052: fix TIOCSSERIAL permission check
  (bsc#1012628).
- staging: fwserial: fix TIOCSSERIAL jiffies conversions
  (bsc#1012628).
- tty: moxa: fix TIOCSSERIAL permission check (bsc#1012628).
- tty: mxser: fix TIOCSSERIAL jiffies conversions (bsc#1012628).
- staging: fwserial: fix TIOCSSERIAL permission check
  (bsc#1012628).
- tty: mxser: fix TIOCSSERIAL permission check (bsc#1012628).
- drm: bridge: fix LONTIUM use of mipi_dsi_() functions
  (bsc#1012628).
- usb: typec: tcpm: Address incorrect values of tcpm psy for
  fixed supply (bsc#1012628).
- usb: typec: tcpm: Address incorrect values of tcpm psy for
  pps supply (bsc#1012628).
- usb: typec: tcpm: update power supply once partner accepts
  (bsc#1012628).
- USB: serial: xr: fix CSIZE handling (bsc#1012628).
- usb: xhci-mtk: remove or operator for setting schedule
  parameters (bsc#1012628).
- usb: xhci-mtk: improve bandwidth scheduling with TT
  (bsc#1012628).
- ASoC: samsung: tm2_wm5110: check of of_parse return value
  (bsc#1012628).
- ASoC: Intel: kbl_da7219_max98927: Fix kabylake_ssp_fixup
  function (bsc#1012628).
- ASoC: tlv320aic32x4: Register clocks before registering
  component (bsc#1012628).
- ASoC: tlv320aic32x4: Increase maximum register in regmap
  (bsc#1012628).
- MIPS: pci-mt7620: fix PLL lock check (bsc#1012628).
- MIPS: pci-rt2880: fix slot 0 configuration (bsc#1012628).
- FDDI: defxx: Bail out gracefully with unassigned PCI resource
  for CSR (bsc#1012628).
- PCI: Allow VPD access for QLogic ISP2722 (bsc#1012628).
- KVM: x86: Defer the MMU unload to the normal path on an global
  INVPCID (bsc#1012628).
- PCI: xgene: Fix cfg resource mapping (bsc#1012628).
- PCI: keystone: Let AM65 use the pci_ops defined in
  pcie-designware-host.c (bsc#1012628).
- PM / devfreq: Unlock mutex and free devfreq struct in error path
  (bsc#1012628).
- soc/tegra: regulators: Fix locking up when voltage-spread is
  out of range (bsc#1012628).
- iio: inv_mpu6050: Fully validate gyro and accel scale writes
  (bsc#1012628).
- iio: magnetometer: yas530: Include right header (bsc#1012628).
- iio: sx9310: Fix write_.._debounce() (bsc#1012628).
- iio:accel:adis16201: Fix wrong axis assignment that prevents
  loading (bsc#1012628).
- iio:adc:ad7476: Fix remove handling (bsc#1012628).
- iio: magnetometer: yas530: Fix return value on error path
  (bsc#1012628).
- iio: sx9310: Fix access to variable DT array (bsc#1012628).
- iio: hid-sensor-rotation: Fix quaternion data not correct
  (bsc#1012628).
- sc16is7xx: Defer probe if device read fails (bsc#1012628).
- phy: cadence: Sierra: Fix PHY power_on sequence (bsc#1012628).
- misc: lis3lv02d: Fix false-positive WARN on various HP models
  (bsc#1012628).
- phy: ti: j721e-wiz: Invoke wiz_init() before
  of_platform_device_create() (bsc#1012628).
- misc: vmw_vmci: explicitly initialize vmci_notify_bm_set_msg
  struct (bsc#1012628).
- misc: vmw_vmci: explicitly initialize vmci_datagram payload
  (bsc#1012628).
- selinux: add proper NULL termination to the secclass_map
  permissions (bsc#1012628).
- x86, sched: Treat Intel SNC topology as default, COD as
  exception (bsc#1012628).
- async_xor: increase src_offs when dropping destination page
  (bsc#1012628).
- md/bitmap: wait for external bitmap writes to complete during
  tear down (bsc#1012628).
- md-cluster: fix use-after-free issue when removing rdev
  (bsc#1012628).
- md: split mddev_find (bsc#1012628).
- md: factor out a mddev_find_locked helper from mddev_find
  (bsc#1012628).
- md: md_open returns -EBUSY when entering racing area
  (bsc#1012628).
- md: Fix missing unused status line of /proc/mdstat
  (bsc#1012628).
- MIPS: generic: Update node names to avoid unit addresses
  (bsc#1012628).
- mt76: mt7615: use ieee80211_free_txskb() in
  mt7615_tx_token_put() (bsc#1012628).
- ipw2x00: potential buffer overflow in libipw_wx_set_encodeext()
  (bsc#1012628).
- net: xilinx: drivers need/depend on HAS_IOMEM (bsc#1012628).
- cfg80211: scan: drop entry from hidden_list on overflow
  (bsc#1012628).
- rtw88: Fix array overrun in rtw_get_tx_power_params()
  (bsc#1012628).
- mt76: fix potential DMA mapping leak (bsc#1012628).
- FDDI: defxx: Make MMIO the configuration default except for EISA
  (bsc#1012628).
- drm/qxl: use ttm bo priorities (bsc#1012628).
- drm/ingenic: Fix non-OSD mode (bsc#1012628).
- drm/panfrost: Clear MMU irqs before handling the fault
  (bsc#1012628).
- drm/panfrost: Don't try to map pages that are already mapped
  (bsc#1012628).
- drm/radeon: fix copy of uninitialized variable back to userspace
  (bsc#1012628).
- drm/dp_mst: Revise broadcast msg lct & lcr (bsc#1012628).
- drm/dp_mst: Set CLEAR_PAYLOAD_ID_TABLE as broadcast
  (bsc#1012628).
- drm: bridge: fix ANX7625 use of mipi_dsi_() functions
  (bsc#1012628).
- drm: bridge/panel: Cleanup connector on bridge detach
  (bsc#1012628).
- drm/amd/display: Reject non-zero src_y and src_x for video
  planes (bsc#1012628).
- drm/amdgpu: fix concurrent VM flushes on Vega/Navi v2
  (bsc#1012628).
- drm/amdgpu: add new MC firmware for Polaris12 32bit ASIC
  (bsc#1012628).
- drm/amdgpu: fix r initial values (bsc#1012628).
- drm/amdgpu: Init GFX10_ADDR_CONFIG for VCN v3 in DPG mode
  (bsc#1012628).
- ALSA: hda/realtek: Re-order ALC882 Acer quirk table entries
  (bsc#1012628).
- ALSA: hda/realtek: Re-order ALC882 Sony quirk table entries
  (bsc#1012628).
- ALSA: hda/realtek: Re-order ALC882 Clevo quirk table entries
  (bsc#1012628).
- ALSA: hda/realtek: Re-order ALC269 HP quirk table entries
  (bsc#1012628).
- ALSA: hda/realtek: Re-order ALC269 Acer quirk table entries
  (bsc#1012628).
- ALSA: hda/realtek: Re-order ALC269 Dell quirk table entries
  (bsc#1012628).
- ALSA: hda/realtek: Re-order ALC269 ASUS quirk table entries
  (bsc#1012628).
- ALSA: hda/realtek: Re-order ALC269 Sony quirk table entries
  (bsc#1012628).
- ALSA: hda/realtek: Re-order ALC269 Lenovo quirk table entries
  (bsc#1012628).
- ALSA: hda/realtek: Re-order remaining ALC269 quirk table entries
  (bsc#1012628).
- ALSA: hda/realtek: Re-order ALC662 quirk table entries
  (bsc#1012628).
- ALSA: hda/realtek: Remove redundant entry for ALC861
  Haier/Uniwill devices (bsc#1012628).
- ALSA: hda/realtek: Fix speaker amp on HP Envy AiO 32
  (bsc#1012628).
- KVM: s390: VSIE: correctly handle MVPG when in VSIE
  (bsc#1012628).
- KVM: s390: split kvm_s390_logical_to_effective (bsc#1012628).
- KVM: s390: fix guarded storage control register handling
  (bsc#1012628).
- s390: fix detection of vector enhancements facility 1 vs. vector
  packed decimal facility (bsc#1012628).
- KVM: s390: VSIE: fix MVPG handling for prefixing and MSO
  (bsc#1012628).
- KVM: s390: split kvm_s390_real_to_abs (bsc#1012628).
- KVM: s390: extend kvm_s390_shadow_fault to return entry pointer
  (bsc#1012628).
- KVM: x86/mmu: Alloc page for PDPTEs when shadowing 32-bit NPT
  with 64-bit (bsc#1012628).
- KVM: x86/xen: Drop RAX[63:32] when processing hypercall
  (bsc#1012628).
- KVM: X86: Fix failure to boost kernel lock holder candidate
  in SEV-ES guests (bsc#1012628).
- KVM: x86: Properly handle APF vs disabled LAPIC situation
  (bsc#1012628).
- KVM: x86: Check CR3 GPA for validity regardless of vCPU mode
  (bsc#1012628).
- KVM: x86: Remove emulator's broken checks on CR0/CR3/CR4 loads
  (bsc#1012628).
- KVM: nSVM: Set the shadow root level to the TDP level for
  nested NPT (bsc#1012628).
- KVM: SVM: Don't strip the C-bit from CR2 on #PF interception
  (bsc#1012628).
- KVM: SVM: Use online_vcpus, not created_vcpus, to iterate over
  vCPUs (bsc#1012628).
- KVM: SVM: Do not set sev->es_active until KVM_SEV_ES_INIT
  completes (bsc#1012628).
- KVM: SVM: Do not allow SEV/SEV-ES initialization after vCPUs
  are created (bsc#1012628).
- KVM: SVM: Inject #GP on guest MSR_TSC_AUX accesses if RDTSCP
  unsupported (bsc#1012628).
- KVM: nVMX: Defer the MMU reload to the normal path on an EPTP
  switch (bsc#1012628).
- KVM: VMX: Truncate GPR value for DR and CR reads in !64-bit mode
  (bsc#1012628).
- KVM: nVMX: Truncate bits 63:32 of VMCS field on nested check
  in !64-bit (bsc#1012628).
- KVM: nVMX: Truncate base/index GPR value on address calc in
  !64-bit (bsc#1012628).
- KVM: arm/arm64: Fix KVM_VGIC_V3_ADDR_TYPE_REDIST read
  (bsc#1012628).
- KVM: Destroy I/O bus devices on unregister failure _after_
  sync'ing SRCU (bsc#1012628).
- KVM: Stop looking for coalesced MMIO zones if the bus is
  destroyed (bsc#1012628).
- KVM: arm64: Support PREL/PLT relocs in EL2 code (bsc#1012628).
- KVM: arm64: Fully zero the vcpu state on reset (bsc#1012628).
- KVM: arm64: Fix KVM_VGIC_V3_ADDR_TYPE_REDIST_REGION read
  (bsc#1012628).
- KVM: selftests: Sync data verify of dirty logging with guest
  sync (bsc#1012628).
- KVM: selftests: Always run vCPU thread with blocked SIG_IPI
  (bsc#1012628).
- Revert "drivers/net/wan/hdlc_fr: Fix a double free in pvc_xmit"
  (bsc#1012628).
- Revert "i3c master: fix missing destroy_workqueue() on error
  in i3c_master_register" (bsc#1012628).
- mfd: stmpe: Revert "Constify static struct resource"
  (bsc#1012628).
- ovl: fix missing revert_creds() on error path (bsc#1012628).
- usb: gadget: pch_udc: Revert d3cb25a12138 completely
  (bsc#1012628).
- Revert "tools/power turbostat: adjust for temperature offset"
  (bsc#1012628).
- firmware: xilinx: Fix dereferencing freed memory (bsc#1012628).
- firmware: xilinx: Remove zynqmp_pm_get_eemi_ops() in
  IS_REACHABLE(CONFIG_ZYNQMP_FIRMWARE) (bsc#1012628).
- x86/vdso: Use proper modifier for len's format specifier in
  extract() (bsc#1012628).
- fpga: fpga-mgr: xilinx-spi: fix error messages on -EPROBE_DEFER
  (bsc#1012628).
- crypto: keembay-ocs-hcu - Fix error return code in
  kmb_ocs_hcu_probe() (bsc#1012628).
- crypto: keembay-ocs-aes - Fix error return code in
  kmb_ocs_aes_probe() (bsc#1012628).
- crypto: sun8i-ss - fix result memory leak on error path
  (bsc#1012628).
- memory: gpmc: fix out of bounds read and dereference on
  gpmc_cs[] (bsc#1012628).
- ARM: dts: exynos: correct fuel gauge interrupt trigger level
  on GT-I9100 (bsc#1012628).
- ARM: dts: exynos: correct fuel gauge interrupt trigger level
  on P4 Note family (bsc#1012628).
- ARM: dts: exynos: correct fuel gauge interrupt trigger level
  on Midas family (bsc#1012628).
- ARM: dts: exynos: correct MUIC interrupt trigger level on
  Midas family (bsc#1012628).
- ARM: dts: exynos: correct PMIC interrupt trigger level on
  Midas family (bsc#1012628).
- ARM: dts: exynos: correct PMIC interrupt trigger level on
  Odroid X/U3 family (bsc#1012628).
- ARM: dts: exynos: correct PMIC interrupt trigger level on P4
  Note family (bsc#1012628).
- ARM: dts: exynos: correct PMIC interrupt trigger level on
  SMDK5250 (bsc#1012628).
- ARM: dts: exynos: correct PMIC interrupt trigger level on Snow
  (bsc#1012628).
- ARM: dts: s5pv210: correct fuel gauge interrupt trigger level
  on Fascinate family (bsc#1012628).
- ARM: dts: renesas: Add mmc aliases into R-Car Gen2 board dts
  files (bsc#1012628).
- arm64: dts: renesas: Add mmc aliases into board dts files
  (bsc#1012628).
- bus: ti-sysc: Fix initializing module_pa for modules without
  sysc register (bsc#1012628).
- x86/platform/uv: Set section block size for hubless
  architectures (bsc#1012628).
- serial: stm32: fix probe and remove order for dma (bsc#1012628).
- serial: stm32: fix startup by enabling usart for reception
  (bsc#1012628).
- serial: stm32: fix incorrect characters on console
  (bsc#1012628).
- serial: stm32: fix TX and RX FIFO thresholds (bsc#1012628).
- serial: stm32: fix a deadlock condition with wakeup event
  (bsc#1012628).
- serial: stm32: fix wake-up flag handling (bsc#1012628).
- serial: stm32: fix a deadlock in set_termios (bsc#1012628).
- serial: liteuart: fix return value check in liteuart_probe()
  (bsc#1012628).
- serial: stm32: fix tx dma completion, release channel
  (bsc#1012628).
- serial: stm32: call stm32_transmit_chars locked (bsc#1012628).
- serial: stm32: fix FIFO flush in startup and set_termios
  (bsc#1012628).
- serial: stm32: add FIFO flush when port is closed (bsc#1012628).
- serial: stm32: fix tx_empty condition (bsc#1012628).
- usb: typec: tcpm: Wait for vbus discharge to VSAFE0V before
  toggling (bsc#1012628).
- usb: typec: tcpci: Check ROLE_CONTROL while interpreting
  CC_STATUS (bsc#1012628).
- usb: typec: tps6598x: Fix return value check in tps6598x_probe()
  (bsc#1012628).
- usb: typec: stusb160x: fix return value check in
  stusb160x_probe() (bsc#1012628).
- mfd: intel_pmt: Fix nuisance messages and handling of disabled
  capabilities (bsc#1012628).
- regmap: set debugfs_name to NULL after it is freed
  (bsc#1012628).
- spi: rockchip: avoid objtool warning (bsc#1012628).
- arm64: dts: broadcom: bcm4908: fix switch parent node name
  (bsc#1012628).
- mtd: rawnand: fsmc: Fix error code in fsmc_nand_probe()
  (bsc#1012628).
- mtd: rawnand: brcmnand: fix OOB R/W with Hamming ECC
  (bsc#1012628).
- mtd: Handle possible -EPROBE_DEFER from parse_mtd_partitions()
  (bsc#1012628).
- mtd: rawnand: qcom: Return actual error code instead of -ENODEV
  (bsc#1012628).
- mtd: don't lock when recursively deleting partitions
  (bsc#1012628).
- mtd: parsers: qcom: Fix error condition (bsc#1012628).
- mtd: parsers: qcom: incompatible with spi-nor 4k sectors
  (bsc#1012628).
- mtd: maps: fix error return code of physmap_flash_remove()
  (bsc#1012628).
- ARM: dts: stm32: fix usart 2 & 3 pinconf to wake up with flow
  control (bsc#1012628).
- arm64: dts: ti: k3-j721e-main: Update the speed modes supported
  and their itap delay values for MMCSD subsystems (bsc#1012628).
- iio: adis16480: fix pps mode sampling frequency math
  (bsc#1012628).
- arm64: dts: qcom: sc7180: trogdor: Fix trip point config of
  charger thermal zone (bsc#1012628).
- arm64: dts: qcom: sm8250: Fix level triggered PMU interrupt
  polarity (bsc#1012628).
- arm64: dts: qcom: sm8350: Fix level triggered PMU interrupt
  polarity (bsc#1012628).
- arm64: dts: qcom: sm8250: Fix timer interrupt to specify EL2
  physical timer (bsc#1012628).
- arm64: dts: qcom: sc7180: Avoid glitching SPI CS at bootup on
  trogdor (bsc#1012628).
- arm64: dts: qcom: sdm845: fix number of pins in 'gpio-ranges'
  (bsc#1012628).
- arm64: dts: qcom: sm8150: fix number of pins in 'gpio-ranges'
  (bsc#1012628).
- arm64: dts: qcom: sm8250: fix number of pins in 'gpio-ranges'
  (bsc#1012628).
- arm64: dts: qcom: sm8350: fix number of pins in 'gpio-ranges'
  (bsc#1012628).
- arm64: dts: qcom: db845c: fix correct powerdown pin for WSA881x
  (bsc#1012628).
- crypto: sun8i-ss - Fix memory leak of object d when dma_iv
  fails to map (bsc#1012628).
- spi: stm32: drop devres version of spi_register_master
  (bsc#1012628).
- arm64: dts: broadcom: bcm4908: set Asus GT-AC5300 port 7 PHY
  mode (bsc#1012628).
- regulator: bd9576: Fix return from bd957x_probe() (bsc#1012628).
- arm64: dts: renesas: r8a77980: Fix vin4-7 endpoint binding
  (bsc#1012628).
- selftests/x86: Add a missing .note.GNU-stack section to
  thunks_32.S (bsc#1012628).
- crypto: arm/blake2s - fix for big endian (bsc#1012628).
- spi: stm32: Fix use-after-free on unbind (bsc#1012628).
- Drivers: hv: vmbus: Drop error message when 'No request id
  available' (bsc#1012628).
- staging: qlge: fix an error code in probe() (bsc#1012628).
- x86/microcode: Check for offline CPUs before requesting new
  microcode (bsc#1012628).
- usb: host: ehci-tegra: Select USB_GADGET Kconfig option
  (bsc#1012628).
- devtmpfs: fix placement of complete() call (bsc#1012628).
- usb: gadget: pch_udc: Replace cpu_to_le32() by lower_32_bits()
  (bsc#1012628).
- usb: gadget: pch_udc: Check if driver is present before calling
  - >setup() (bsc#1012628).
- usb: gadget: pch_udc: Check for DMA mapping error (bsc#1012628).
- usb: gadget: pch_udc: Initialize device pointer before use
  (bsc#1012628).
- usb: gadget: pch_udc: Provide a GPIO line used on Intel
  Minnowboard (v1) (bsc#1012628).
- crypto: ccp - fix command queuing to TEE ring buffer
  (bsc#1012628).
- crypto: qat - don't release uninitialized resources
  (bsc#1012628).
- crypto: qat - ADF_STATUS_PF_RUNNING should be set after
  adf_dev_init (bsc#1012628).
- fotg210-udc: Fix DMA on EP0 for length > max packet size
  (bsc#1012628).
- fotg210-udc: Fix EP0 IN requests bigger than two packets
  (bsc#1012628).
- fotg210-udc: Remove a dubious condition leading to fotg210_done
  (bsc#1012628).
- fotg210-udc: Mask GRP2 interrupts we don't handle (bsc#1012628).
- fotg210-udc: Don't DMA more than the buffer can take
  (bsc#1012628).
- fotg210-udc: Complete OUT requests on short packets
  (bsc#1012628).
- usb: gadget: s3c: Fix incorrect resources releasing
  (bsc#1012628).
- usb: gadget: s3c: Fix the error handling path in
  's3c2410_udc_probe()' (bsc#1012628).
- dt-bindings: serial: stm32: Use 'type: object' instead of
  false for 'additionalProperties' (bsc#1012628).
- mtd: require write permissions for locking and badblock ioctls
  (bsc#1012628).
- arm64: dts: renesas: r8a779a0: Fix PMU interrupt (bsc#1012628).
- arm64: dts: mt8183: Add gce client reg for display subcomponents
  (bsc#1012628).
- arm64: dts: mt8173: fix wrong power-domain phandle of pmic
  (bsc#1012628).
- bus: qcom: Put child node before return (bsc#1012628).
- arm64: dts: qcom: sm8250: fix display nodes (bsc#1012628).
- soundwire: bus: Fix device found flag correctly (bsc#1012628).
- soc: mediatek: pm-domains: Fix missing error code in
  scpsys_add_subdomain() (bsc#1012628).
- phy: ti: j721e-wiz: Delete "clk_div_sel" clk provider during
  cleanup (bsc#1012628).
- phy: ralink: phy-mt7621-pci: fix XTAL bitmask (bsc#1012628).
- phy: marvell: ARMADA375_USBCLUSTER_PHY should not default to y,
  unconditionally (bsc#1012628).
- phy: ralink: phy-mt7621-pci: fix return value check in
  mt7621_pci_phy_probe() (bsc#1012628).
- phy: ingenic: Fix a typo in ingenic_usb_phy_probe()
  (bsc#1012628).
- arm64: dts: mediatek: fix reset GPIO level on pumpkin
  (bsc#1012628).
- NFSv4.2: fix copy stateid copying for the async copy
  (bsc#1012628).
- crypto: poly1305 - fix poly1305_core_setkey() declaration
  (bsc#1012628).
- crypto: qat - fix error path in adf_isr_resource_alloc()
  (bsc#1012628).
- usb: gadget: aspeed: fix dma map failure (bsc#1012628).
- USB: gadget: udc: fix wrong pointer passed to IS_ERR() and
  PTR_ERR() (bsc#1012628).
- drivers: nvmem: Fix voltage settings for QTI qfprom-efuse
  (bsc#1012628).
- nvmem: rmem: fix undefined reference to memremap (bsc#1012628).
- driver core: platform: Declare early_platform_cleanup()
  prototype (bsc#1012628).
- ARM: dts: qcom: msm8974-lge-nexus5: correct fuel gauge interrupt
  trigger level (bsc#1012628).
- ARM: dts: qcom: msm8974-samsung-klte: correct fuel gauge
  interrupt trigger level (bsc#1012628).
- memory: pl353: fix mask of ECC page_size config register
  (bsc#1012628).
- soundwire: stream: fix memory leak in stream config error path
  (bsc#1012628).
- m68k: mvme147,mvme16x: Don't wipe PCC timer config bits
  (bsc#1012628).
- firmware: qcom_scm: Make __qcom_scm_is_call_available() return
  bool (bsc#1012628).
- firmware: qcom_scm: Reduce locking section for
  __get_convention() (bsc#1012628).
- firmware: qcom_scm: Workaround lack of "is available" call on
  SC7180 (bsc#1012628).
- iio: adc: Kconfig: make AD9467 depend on ADI_AXI_ADC symbol
  (bsc#1012628).
- mtd: rawnand: gpmi: Fix a double free in gpmi_nand_init
  (bsc#1012628).
- irqchip/gic-v3: Fix OF_BAD_ADDR error handling (bsc#1012628).
- staging: comedi: tests: ni_routes_test: Fix compilation error
  (bsc#1012628).
- staging: rtl8192u: Fix potential infinite loop (bsc#1012628).
- staging: fwserial: fix TIOCSSERIAL implementation (bsc#1012628).
- staging: fwserial: fix TIOCGSERIAL implementation (bsc#1012628).
- staging: greybus: uart: fix unprivileged TIOCCSERIAL
  (bsc#1012628).
- platform/x86: dell-wmi-sysman: Make init_bios_attributes()
  ACPI object parsing more robust (bsc#1012628).
- soc: qcom: pdr: Fix error return code in pdr_register_listener
  (bsc#1012628).
- PM / devfreq: Use more accurate returned new_freq as resume_freq
  (bsc#1012628).
- clocksource/drivers/timer-ti-dm: Fix posted mode status check
  order (bsc#1012628).
- clocksource/drivers/timer-ti-dm: Add missing
  set_state_oneshot_stopped (bsc#1012628).
- clocksource/drivers/ingenic_ost: Fix return value check in
  ingenic_ost_probe() (bsc#1012628).
- spi: Fix use-after-free with devm_spi_alloc_* (bsc#1012628).
- spi: fsl: add missing iounmap() on error in of_fsl_spi_probe()
  (bsc#1012628).
- soc: qcom: mdt_loader: Validate that p_filesz < p_memsz
  (bsc#1012628).
- soc: qcom: mdt_loader: Detect truncated read of segments
  (bsc#1012628).
- PM: runtime: Replace inline function
  pm_runtime_callbacks_present() (bsc#1012628).
- cpuidle: Fix ARM_QCOM_SPM_CPUIDLE configuration (bsc#1012628).
- ACPI: CPPC: Replace cppc_attr with kobj_attribute (bsc#1012628).
- crypto: allwinner - add missing CRYPTO_ prefix (bsc#1012628).
- crypto: sun8i-ss - Fix memory leak of pad (bsc#1012628).
- crypto: sa2ul - Fix memory leak of rxd (bsc#1012628).
- crypto: qat - Fix a double free in adf_create_ring
  (bsc#1012628).
- cpufreq: armada-37xx: Fix setting TBG parent for load levels
  (bsc#1012628).
- clk: mvebu: armada-37xx-periph: remove .set_parent method for
  CPU PM clock (bsc#1012628).
- cpufreq: armada-37xx: Fix the AVS value for load L1
  (bsc#1012628).
- clk: mvebu: armada-37xx-periph: Fix switching CPU freq from
  250 Mhz to 1 GHz (bsc#1012628).
- clk: mvebu: armada-37xx-periph: Fix workaround for switching
  from L1 to L0 (bsc#1012628).
- cpufreq: armada-37xx: Fix driver cleanup when registration
  failed (bsc#1012628).
- cpufreq: armada-37xx: Fix determining base CPU frequency
  (bsc#1012628).
- spi: spi-zynqmp-gqspi: use wait_for_completion_timeout to make
  zynqmp_qspi_exec_op not interruptible (bsc#1012628).
- spi: spi-zynqmp-gqspi: add mutex locking for exec_op
  (bsc#1012628).
- spi: spi-zynqmp-gqspi: transmit dummy circles by using the
  controller's internal functionality (bsc#1012628).
- spi: spi-zynqmp-gqspi: fix incorrect operating mode in
  zynqmp_qspi_read_op (bsc#1012628).
- spi: fsl-lpspi: Fix PM reference leak in
  lpspi_prepare_xfer_hardware() (bsc#1012628).
- usb: gadget: r8a66597: Add missing null check on return from
  platform_get_resource (bsc#1012628).
- USB: cdc-acm: fix unprivileged TIOCCSERIAL (bsc#1012628).
- USB: cdc-acm: fix TIOCGSERIAL implementation (bsc#1012628).
- tty: actually undefine superseded ASYNC flags (bsc#1012628).
- tty: fix return value for unsupported ioctls (bsc#1012628).
- tty: fix return value for unsupported termiox ioctls
  (bsc#1012628).
- serial: core: return early on unsupported ioctls (bsc#1012628).
- firmware: qcom-scm: Fix QCOM_SCM configuration (bsc#1012628).
- node: fix device cleanups in error handling code (bsc#1012628).
- crypto: chelsio - Read rxchannel-id from firmware (bsc#1012628).
- usbip: vudc: fix missing unlock on error in usbip_sockfd_store()
  (bsc#1012628).
- m68k: Add missing mmap_read_lock() to sys_cacheflush()
  (bsc#1012628).
- usb: cdnsp: Fixes issue with Configure Endpoint command
  (bsc#1012628).
- spi: spi-zynqmp-gqspi: Fix missing unlock on error in
  zynqmp_qspi_exec_op() (bsc#1012628).
- memory: renesas-rpc-if: fix possible NULL pointer dereference
  of resource (bsc#1012628).
- memory: samsung: exynos5422-dmc: handle clk_set_parent()
  failure (bsc#1012628).
- security: keys: trusted: fix TPM2 authorizations (bsc#1012628).
- char: tpm: fix error return code in tpm_cr50_i2c_tis_recv()
  (bsc#1012628).
- platform/x86: pmc_atom: Match all Beckhoff Automation baytrail
  boards with critclk_systems DMI table (bsc#1012628).
- usb: typec: tcpm: Honour pSnkStdby requirement during
  negotiation (bsc#1012628).
- spi: spi-zynqmp-gqspi: Fix runtime PM imbalance in
  zynqmp_qspi_probe (bsc#1012628).
- ARM: dts: aspeed: Rainier: Fix humidity sensor bus address
  (bsc#1012628).
- Drivers: hv: vmbus: Use after free in __vmbus_open()
  (bsc#1012628).
- crypto: arm64/aes-ce - deal with oversight in new CTR carry code
  (bsc#1012628).
- spi: spi-zynqmp-gqspi: fix clk_enable/disable imbalance issue
  (bsc#1012628).
- spi: spi-zynqmp-gqspi: fix hang issue when suspend/resume
  (bsc#1012628).
- spi: spi-zynqmp-gqspi: fix use-after-free in zynqmp_qspi_exec_op
  (bsc#1012628).
- spi: spi-zynqmp-gqspi: return -ENOMEM if dma_map_single fails
  (bsc#1012628).
- btrfs: zoned: move log tree node allocation out of
  log_root_tree->log_mutex (bsc#1012628).
- btrfs: zoned: bail out in btrfs_alloc_chunk for bad input
  (bsc#1012628).
- x86/platform/uv: Fix !KEXEC build failure (bsc#1012628).
- hwmon: (pmbus/pxe1610) don't bail out when not all pages are
  active (bsc#1012628).
- platform/surface: aggregator: fix a bit test (bsc#1012628).
- Drivers: hv: vmbus: Increase wait time for VMbus unload
  (bsc#1012628).
- PM: hibernate: x86: Use crc32 instead of md5 for hibernation
  e820 integrity check (bsc#1012628).
- usb: dwc2: Fix host mode hibernation exit with remote wakeup
  flow (bsc#1012628).
- usb: dwc2: Fix hibernation between host and device modes
  (bsc#1012628).
- ttyprintk: Add TTY hangup callback (bsc#1012628).
- serial: omap: don't disable rs485 if rts gpio is missing
  (bsc#1012628).
- serial: omap: fix rs485 half-duplex filtering (bsc#1012628).
- spi: tools: make a symbolic link to the header file spi.h
  (bsc#1012628).
- xen-blkback: fix compatibility bug with single page rings
  (bsc#1012628).
- soc: aspeed: fix a ternary sign expansion bug (bsc#1012628).
- drm/tilcdc: send vblank event when disabling crtc (bsc#1012628).
- drm/stm: Fix bus_flags handling (bsc#1012628).
- drm/amd/display: Fix off by one in hdmi_14_process_transaction()
  (bsc#1012628).
- drm/mcde/panel: Inverse misunderstood flag (bsc#1012628).
- scsi: lpfc: Fix null pointer dereference in lpfc_prep_els_iocb()
  (bsc#1012628).
- sched/fair: Fix shift-out-of-bounds in load_balance()
  (bsc#1012628).
- printk: limit second loop of syslog_print_all (bsc#1012628).
- afs: Fix updating of i_mode due to 3rd party change
  (bsc#1012628).
- rcu: Remove spurious instrumentation_end() in rcu_nmi_enter()
  (bsc#1012628).
- media: mtk: fix mtk-smi dependency (bsc#1012628).
- media: vivid: fix assignment of dev->fbuf_out_flags
  (bsc#1012628).
- media: saa7134: use sg_dma_len when building pgtable
  (bsc#1012628).
- media: saa7146: use sg_dma_len when building pgtable
  (bsc#1012628).
- media: omap4iss: return error code when omap4iss_get() failed
  (bsc#1012628).
- media: rkisp1: rsz: crash fix when setting src format
  (bsc#1012628).
- media: aspeed: fix clock handling logic (bsc#1012628).
- drm/panel-simple: Undo enable if HPD never asserts
  (bsc#1012628).
- power: supply: bq27xxx: fix sign of current_now for newer ICs
  (bsc#1012628).
- drm/probe-helper: Check epoch counter in output_poll_execute()
  (bsc#1012628).
- media: venus: core: Fix some resource leaks in the error path of
  'venus_probe()' (bsc#1012628).
- media: platform: sunxi: sun6i-csi: fix error return code of
  sun6i_video_start_streaming() (bsc#1012628).
- media: m88ds3103: fix return value check in m88ds3103_probe()
  (bsc#1012628).
- media: docs: Fix data organization of
  MEDIA_BUS_FMT_RGB101010_1X30 (bsc#1012628).
- media: [next] staging: media: atomisp: fix memory leak of
  object flash (bsc#1012628).
- media: atomisp: Fixed error handling path (bsc#1012628).
- media: m88rs6000t: avoid potential out-of-bounds reads on arrays
  (bsc#1012628).
- media: atomisp: Fix use after free in
  atomisp_alloc_css_stat_bufs() (bsc#1012628).
- x86/kprobes: Retrieve correct opcode for group instruction
  (bsc#1012628).
- drm/amdkfd: fix build error with AMD_IOMMU_V2=m (bsc#1012628).
- drm/amdkfd: Fix recursive lock warnings (bsc#1012628).
- drm/amd/display: Free local data after use (bsc#1012628).
- of: overlay: fix for_each_child.cocci warnings (bsc#1012628).
- scsi: qla2xxx: Check kzalloc() return value (bsc#1012628).
- x86/kprobes: Fix to check non boostable prefixes correctly
  (bsc#1012628).
- drm/omap: dsi: Add missing IRQF_ONESHOT (bsc#1012628).
- selftests: fix prepending $(OUTPUT) to $(TEST_PROGS)
  (bsc#1012628).
- pata_arasan_cf: fix IRQ check (bsc#1012628).
- pata_ipx4xx_cf: fix IRQ check (bsc#1012628).
- sata_mv: add IRQ checks (bsc#1012628).
- ata: libahci_platform: fix IRQ check (bsc#1012628).
- seccomp: Fix CONFIG tests for Seccomp_filters (bsc#1012628).
- drm/mediatek: Switch the hdmi bridge ops to the atomic versions
  (bsc#1012628).
- drm/mediatek: Don't support hdmi connector creation
  (bsc#1012628).
- nvme-tcp: block BH in sk state_change sk callback (bsc#1012628).
- nvmet-tcp: fix incorrect locking in state_change sk callback
  (bsc#1012628).
- clk: imx: Fix reparenting of UARTs not associated with stdout
  (bsc#1012628).
- power: supply: bq25980: Move props from battery node
  (bsc#1012628).
- nvme: retrigger ANA log update if group descriptor isn't found
  (bsc#1012628).
- media: ccs: Fix sub-device function (bsc#1012628).
- media: ipu3-cio2: Fix pixel-rate derived link frequency
  (bsc#1012628).
- media: i2c: imx219: Move out locking/unlocking of vflip and
  hflip controls from imx219_set_stream (bsc#1012628).
- media: i2c: imx219: Balance runtime PM use-count (bsc#1012628).
- media: v4l2-ctrls.c: fix race condition in hdl->requests list
  (bsc#1012628).
- media: rkvdec: Do not require all controls to be present in
  every request (bsc#1012628).
- vfio/fsl-mc: Re-order vfio_fsl_mc_probe() (bsc#1012628).
- vfio/pci: Move VGA and VF initialization to functions
  (bsc#1012628).
- vfio/pci: Re-order vfio_pci_probe() (bsc#1012628).
- drm/msm: Fix debugfs deadlock (bsc#1012628).
- drm/msm/dpu: enable DPU_SSPP_QOS_8LVL for SM8250 (bsc#1012628).
- vfio/mdev: Do not allow a mdev_type to have a NULL parent
  pointer (bsc#1012628).
- clk: zynqmp: move zynqmp_pll_set_mode out of round_rate callback
  (bsc#1012628).
- clk: zynqmp: pll: add set_pll_mode to check condition in
  zynqmp_pll_enable (bsc#1012628).
- drm: xlnx: zynqmp: fix a memset in zynqmp_dp_train()
  (bsc#1012628).
- media: i2c: rdamc21: Fix warning on u8 cast (bsc#1012628).
- clk: qcom: a7-pll: Add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- clk: qcom: a53-pll: Add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- clk: qcom: apss-ipq-pll: Add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- drm/amd/display: use GFP_ATOMIC in dcn20_resource_construct
  (bsc#1012628).
- drm/amd/display: check fb of primary plane (bsc#1012628).
- drm/radeon: Fix a missing check bug in radeon_dp_mst_detect()
  (bsc#1012628).
- bcache: Use 64-bit arithmetic instead of 32-bit (bsc#1012628).
- clk: uniphier: Fix potential infinite loop (bsc#1012628).
- scsi: pm80xx: Increase timeout for pm80xx mpi_uninit_check()
  (bsc#1012628).
- scsi: pm80xx: Fix potential infinite loop (bsc#1012628).
- scsi: ufs: ufshcd-pltfrm: Fix deferred probing (bsc#1012628).
- scsi: hisi_sas: Fix IRQ checks (bsc#1012628).
- scsi: jazz_esp: Add IRQ check (bsc#1012628).
- scsi: sun3x_esp: Add IRQ check (bsc#1012628).
- scsi: sni_53c710: Add IRQ check (bsc#1012628).
- scsi: ibmvfc: Fix invalid state machine BUG_ON() (bsc#1012628).
- mailbox: sprd: Introduce refcnt when clients requests/free
  channels (bsc#1012628).
- mfd: stm32-timers: Avoid clearing auto reload register
  (bsc#1012628).
- nvmet-tcp: fix a segmentation fault during io parsing error
  (bsc#1012628).
- nvme-pci: don't simple map sgl when sgls are disabled
  (bsc#1012628).
- media: meson-ge2d: fix rotation parameters (bsc#1012628).
- media: cedrus: Fix H265 status definitions (bsc#1012628).
- HSI: core: fix resource leaks in hsi_add_client_from_dt()
  (bsc#1012628).
- x86/events/amd/iommu: Fix sysfs type mismatch (bsc#1012628).
- perf/amd/uncore: Fix sysfs type mismatch (bsc#1012628).
- io_uring: fix overflows checks in provide buffers (bsc#1012628).
- block/rnbd-clt-sysfs: Remove copy buffer overlap in
  rnbd_clt_get_path_name (bsc#1012628).
- sched/debug: Fix cgroup_path[] serialization (bsc#1012628).
- kthread: Fix PF_KTHREAD vs to_kthread() race (bsc#1012628).
- ataflop: potential out of bounds in do_format() (bsc#1012628).
- ataflop: fix off by one in ataflop_probe() (bsc#1012628).
- drivers/block/null_blk/main: Fix a double free in null_init
  (bsc#1012628).
- xsk: Respect device's headroom and tailroom on generic xmit path
  (bsc#1012628).
- HID: plantronics: Workaround for double volume key presses
  (bsc#1012628).
- perf symbols: Fix dso__fprintf_symbols_by_name() to return
  the number of printed chars (bsc#1012628).
- ASoC: Intel: boards: sof-wm8804: add check for PLL setting
  (bsc#1012628).
- ASoC: Intel: Skylake: Compile when any configuration is selected
  (bsc#1012628).
- RDMA/mlx5: Zero out ODP related items in the mlx5_ib_mr
  (bsc#1012628).
- RDMA/mlx5: Fix query RoCE port (bsc#1012628).
- RDMA/mlx5: Fix mlx5 rates to IB rates map (bsc#1012628).
- net/mlx5: DR, Add missing vhca_id consume from STEv1
  (bsc#1012628).
- wilc1000: write value to WILC_INTR2_ENABLE register
  (bsc#1012628).
- KVM: x86/mmu: Retry page faults that hit an invalid memslot
  (bsc#1012628).
- Bluetooth: avoid deadlock between hci_dev->lock and socket lock
  (bsc#1012628).
- net: lapbether: Prevent racing when checking whether the netif
  is running (bsc#1012628).
- libbpf: Add explicit padding to bpf_xdp_set_link_opts
  (bsc#1012628).
- bpftool: Fix maybe-uninitialized warnings (bsc#1012628).
- iommu: Check dev->iommu in iommu_dev_xxx functions
  (bsc#1012628).
- iommu/dma: Resurrect the "forcedac" option (bsc#1012628).
- iommu/vt-d: Reject unsupported page request modes (bsc#1012628).
- ASoC: tegra30: i2s: Restore hardware state on runtime PM resume
  (bsc#1012628).
- net: dsa: bcm_sf2: add function finding RGMII register
  (bsc#1012628).
- net: dsa: bcm_sf2: fix BCM4908 RGMII reg(s) (bsc#1012628).
- selftests/bpf: Re-generate vmlinux.h and BPF skeletons if
  bpftool changed (bsc#1012628).
- libbpf: Add explicit padding to btf_dump_emit_type_decl_opts
  (bsc#1012628).
- powerpc/mm: Move the linear_mapping_mutex to the ifdef where
  it is used (bsc#1012628).
- powerpc/fadump: Mark fadump_calculate_reserve_size as __init
  (bsc#1012628).
- powerpc/prom: Mark identical_pvr_fixup as __init (bsc#1012628).
- MIPS: fix local_irq_{disable,enable} in asmmacro.h
  (bsc#1012628).
- ima: Fix the error code for restoring the PCR value
  (bsc#1012628).
- inet: use bigger hash table for IP ID generation (bsc#1012628).
- pinctrl: pinctrl-single: remove unused parameter (bsc#1012628).
- pinctrl: pinctrl-single: fix pcs_pin_dbg_show() when
  bits_per_mux is not zero (bsc#1012628).
- MIPS: loongson64: fix bug when PAGE_SIZE > 16KB (bsc#1012628).
- ASoC: wm8960: Remove bitclk relax condition in
  wm8960_configure_sysclk (bsc#1012628).
- iommu/arm-smmu-v3: add bit field SFM into GERROR_ERR_MASK
  (bsc#1012628).
- RDMA/mlx5: Fix drop packet rule in egress table (bsc#1012628).
- IB/isert: Fix a use after free in isert_connect_request
  (bsc#1012628).
- powerpc/64s: Fix hash fault to use TRAP accessor (bsc#1012628).
- powerpc: Fix HAVE_HARDLOCKUP_DETECTOR_ARCH build configuration
  (bsc#1012628).
- MIPS/bpf: Enable bpf_probe_read{, str}() on MIPS again
  (bsc#1012628).
- gpio: guard gpiochip_irqchip_add_domain() with GPIOLIB_IRQCHIP
  (bsc#1012628).
- fs: dlm: fix missing unlock on error in accept_from_sock()
  (bsc#1012628).
- ASoC: q6afe-clocks: fix reprobing of the driver (bsc#1012628).
- ALSA: core: remove redundant spin_lock pair in
  snd_card_disconnect (bsc#1012628).
- net: phy: lan87xx: fix access to wrong register of LAN87xx
  (bsc#1012628).
- udp: skip L4 aggregation for UDP tunnel packets (bsc#1012628).
- udp: never accept GSO_FRAGLIST packets (bsc#1012628).
- powerpc/pseries: Only register vio drivers if vio bus exists
  (bsc#1012628).
- net/tipc: fix missing destroy_workqueue() on error in
  tipc_crypto_start() (bsc#1012628).
- bug: Remove redundant condition check in report_bug
  (bsc#1012628).
- RDMA/core: Fix corrupted SL on passive side (bsc#1012628).
- nfc: pn533: prevent potential memory corruption (bsc#1012628).
- net: hns3: Limiting the scope of vector_ring_chain variable
  (bsc#1012628).
- mips: bmips: fix syscon-reboot nodes (bsc#1012628).
- KVM: arm64: Fix error return code in init_hyp_mode()
  (bsc#1012628).
- iommu/vt-d: Don't set then clear private data in
  prq_event_thread() (bsc#1012628).
- iommu: Fix a boundary issue to avoid performance drop
  (bsc#1012628).
- iommu/vt-d: Report right snoop capability when using FL for IOVA
  (bsc#1012628).
- iommu/vt-d: Report the right page fault address (bsc#1012628).
- iommu/vt-d: Remove WO permissions on second-level paging entries
  (bsc#1012628).
- iommu/vt-d: Invalidate PASID cache when root/context entry
  changed (bsc#1012628).
- ALSA: usb-audio: Add error checks for
  usb_driver_claim_interface() calls (bsc#1012628).
- HID: lenovo: Use brightness_set_blocking callback for setting
  LEDs brightness (bsc#1012628).
- HID: lenovo: Fix lenovo_led_set_tp10ubkbd() error handling
  (bsc#1012628).
- HID: lenovo: Check hid_get_drvdata() returns non NULL in
  lenovo_event() (bsc#1012628).
- HID: lenovo: Map mic-mute button to KEY_F20 instead of
  KEY_MICMUTE (bsc#1012628).
- KVM: arm64: Initialize VCPU mdcr_el2 before loading it
  (bsc#1012628).
- ASoC: simple-card: fix possible uninitialized single_cpu local
  variable (bsc#1012628).
- liquidio: Fix unintented sign extension of a left shift of a
  u16 (bsc#1012628).
- IB/hfi1: Use kzalloc() for mmu_rb_handler allocation
  (bsc#1012628).
- powerpc/64s: Fix pte update for kernel memory on radix
  (bsc#1012628).
- powerpc/pseries: Add key to flags in
  pSeries_lpar_hpte_updateboltedpp() (bsc#1012628).
- powerpc/64s: Use htab_convert_pte_flags() in
  hash__mark_rodata_ro() (bsc#1012628).
- powerpc/perf: Fix PMU constraint check for EBB events
  (bsc#1012628).
- powerpc: iommu: fix build when neither PCI or IBMVIO is set
  (bsc#1012628).
- mac80211: bail out if cipher schemes are invalid (bsc#1012628).
- perf vendor events amd: Fix broken L2 Cache Hits from L2 HWPF
  metric (bsc#1012628).
- RDMA/hns: Fix missing assignment of max_inline_data
  (bsc#1012628).
- xfs: fix return of uninitialized value in variable error
  (bsc#1012628).
- rtw88: Fix an error code in rtw_debugfs_set_rsvd_page()
  (bsc#1012628).
- mt7601u: fix always true expression (bsc#1012628).
- mt76: mt7615: fix tx skb dma unmap (bsc#1012628).
- mt76: mt7915: fix tx skb dma unmap (bsc#1012628).
- mt76: mt7921: fix suspend/resume sequence (bsc#1012628).
- mt76: mt7921: fix memory leak in mt7921_coredump_work
  (bsc#1012628).
- mt76: connac: fix up the setting for ht40 mode in
  mt76_connac_mcu_uni_add_bss (bsc#1012628).
- mt76: mt7921: fixup rx bitrate statistics (bsc#1012628).
- mt76: mt7615: fix memory leak in mt7615_coredump_work
  (bsc#1012628).
- mt76: mt7921: fix aggr length histogram (bsc#1012628).
- mt76: mt7915: fix aggr len debugfs node (bsc#1012628).
- mt76: mt7921: fix stats register definitions (bsc#1012628).
- mt76: mt7615: fix TSF configuration (bsc#1012628).
- mt76: mt7615: fix mib stats counter reporting to mac80211
  (bsc#1012628).
- mt76: mt7915: fix mib stats counter reporting to mac80211
  (bsc#1012628).
- mt76: connac: fix kernel warning adding monitor interface
  (bsc#1012628).
- mt76: check return value of mt76_txq_send_burst in
  mt76_txq_schedule_list (bsc#1012628).
- mt76: mt7921: fix the base of PCIe interrupt (bsc#1012628).
- mt76: mt7921: fix the base of the dynamic remap (bsc#1012628).
- mt76: mt7915: fix rxrate reporting (bsc#1012628).
- mt76: mt7915: fix txrate reporting (bsc#1012628).
- mt76: mt7663: fix when beacon filter is being applied
  (bsc#1012628).
- mt76: mt7663s: make all of packets 4-bytes aligned in sdio tx
  aggregation (bsc#1012628).
- mt76: mt7663s: fix the possible device hang in high traffic
  (bsc#1012628).
- mt76: mt7615: cleanup mcu tx queue in mt7615_dma_reset()
  (bsc#1012628).
- mt76: mt7915: cleanup mcu tx queue in mt7915_dma_reset()
  (bsc#1012628).
- mt76: mt7921: always wake the device in mt7921_remove_interface
  (bsc#1012628).
- mt76: mt7921: fix inappropriate WoW setup with the missing
  ARP informaiton (bsc#1012628).
- mt76: mt7921: fix the dwell time control (bsc#1012628).
- KVM: PPC: Book3S HV P9: Restore host CTRL SPR after guest exit
  (bsc#1012628).
- ovl: show "userxattr" in the mount data (bsc#1012628).
- ovl: invalidate readdir cache on changes to dir with origin
  (bsc#1012628).
- RDMA/qedr: Fix error return code in qedr_iw_connect()
  (bsc#1012628).
- IB/hfi1: Fix error return code in parse_platform_config()
  (bsc#1012628).
- RDMA/bnxt_re: Fix error return code in
  bnxt_qplib_cq_process_terminal() (bsc#1012628).
- cxgb4: Fix unintentional sign extension issues (bsc#1012628).
- net: thunderx: Fix unintentional sign extension issue
  (bsc#1012628).
- mt76: mt7921: fix kernel crash when the firmware fails to
  download (bsc#1012628).
- RDMA/srpt: Fix error return code in srpt_cm_req_recv()
  (bsc#1012628).
- RDMA/rtrs-clt: destroy sysfs after removing session from active
  list (bsc#1012628).
- pinctrl: at91-pio4: Fix slew rate disablement (bsc#1012628).
- i2c: cadence: fix reference leak when pm_runtime_get_sync fails
  (bsc#1012628).
- i2c: img-scb: fix reference leak when pm_runtime_get_sync fails
  (bsc#1012628).
- i2c: imx-lpi2c: fix reference leak when pm_runtime_get_sync
  fails (bsc#1012628).
- i2c: imx: fix reference leak when pm_runtime_get_sync fails
  (bsc#1012628).
- i2c: omap: fix reference leak when pm_runtime_get_sync fails
  (bsc#1012628).
- i2c: sprd: fix reference leak when pm_runtime_get_sync fails
  (bsc#1012628).
- i2c: stm32f7: fix reference leak when pm_runtime_get_sync fails
  (bsc#1012628).
- i2c: xiic: fix reference leak when pm_runtime_get_sync fails
  (bsc#1012628).
- i2c: cadence: add IRQ check (bsc#1012628).
- i2c: emev2: add IRQ check (bsc#1012628).
- i2c: jz4780: add IRQ check (bsc#1012628).
- i2c: mlxbf: add IRQ check (bsc#1012628).
- i2c: rcar: add IRQ check (bsc#1012628).
- i2c: sh7760: add IRQ check (bsc#1012628).
- fuse: fix matching of FUSE_DEV_IOC_CLONE command (bsc#1012628).
- iwlwifi: rs-fw: don't support stbc for HE 160 (bsc#1012628).
- iwlwifi: dbg: disable ini debug in 9000 family and below
  (bsc#1012628).
- powerpc/xive: Drop check on irq_data in xive_core_debug_show()
  (bsc#1012628).
- powerpc/xive: Fix xmon command "dxi" (bsc#1012628).
- powerpc/syscall: switch user_exit_irqoff and trace_hardirqs_off
  order (bsc#1012628).
- ASoC: ak5558: correct reset polarity (bsc#1012628).
- net/mlx5: Fix bit-wise and with zero (bsc#1012628).
- net/packet: remove data races in fanout operations
  (bsc#1012628).
- drm/i915/gvt: Fix error code in intel_gvt_init_device()
  (bsc#1012628).
- iommu/vt-d: Fix an error handling path in
  'intel_prepare_irq_remapping()' (bsc#1012628).
- iommu/amd: Put newline after closing bracket in warning
  (bsc#1012628).
- perf beauty: Fix fsconfig generator (bsc#1012628).
- drm/amdgpu: fix an error code in
  init_pmu_entry_by_type_and_add() (bsc#1012628).
- drm/amd/pm: fix error code in smu_set_power_limit()
  (bsc#1012628).
- MIPS: pci-legacy: stop using of_pci_range_to_resource
  (bsc#1012628).
- powerpc/pseries: extract host bridge from pci_bus prior to
  bus removal (bsc#1012628).
- iommu/mediatek: Always enable the clk on resume (bsc#1012628).
- mptcp: fix format specifiers for unsigned int (bsc#1012628).
- powerpc/smp: Reintroduce cpu_core_mask (bsc#1012628).
- KVM: x86: dump_vmcs should not assume GUEST_IA32_EFER is valid
  (bsc#1012628).
- rtlwifi: 8821ae: upgrade PHY and RF parameters (bsc#1012628).
- wlcore: fix overlapping snprintf arguments in debugfs
  (bsc#1012628).
- i2c: sh7760: fix IRQ error path (bsc#1012628).
- i2c: mediatek: Fix wrong dma sync flag (bsc#1012628).
- mwl8k: Fix a double Free in mwl8k_probe_hw (bsc#1012628).
- netfilter: nft_payload: fix C-VLAN offload support
  (bsc#1012628).
- netfilter: nftables_offload: VLAN id needs host byteorder in
  flow dissector (bsc#1012628).
- netfilter: nftables_offload: special ethertype handling for VLAN
  (bsc#1012628).
- vsock/vmci: log once the failed queue pair allocation
  (bsc#1012628).
- libbpf: Initialize the bpf_seq_printf parameters array field
  by field (bsc#1012628).
- net: ethernet: ixp4xx: Set the DMA masks explicitly
  (bsc#1012628).
- gro: fix napi_gro_frags() Fast GRO breakage due to IP alignment
  check (bsc#1012628).
- RDMA/cxgb4: add missing qpid increment (bsc#1012628).
- RDMA/i40iw: Fix error unwinding when i40iw_hmc_sd_one fails
  (bsc#1012628).
- ALSA: usb: midi: don't return -ENOMEM when usb_urb_ep_type_check
  fails (bsc#1012628).
- sfc: ef10: fix TX queue lookup in TX event handling
  (bsc#1012628).
- vsock/virtio: free queued packets when closing socket
  (bsc#1012628).
- net: marvell: prestera: fix port event handling on init
  (bsc#1012628).
- net: davinci_emac: Fix incorrect masking of tx and rx error
  channel (bsc#1012628).
- rtw88: refine napi deinit flow (bsc#1012628).
- mt76: mt7615: fix memleak when mt7615_unregister_device()
  (bsc#1012628).
- mt76: mt7915: fix memleak when mt7915_unregister_device()
  (bsc#1012628).
- mt76: mt7921: run mt7921_mcu_fw_log_2_host holding mt76 mutex
  (bsc#1012628).
- powerpc/pseries/iommu: Fix window size for direct mapping with
  pmem (bsc#1012628).
- crypto: ccp: Detect and reject "invalid" addresses destined
  for PSP (bsc#1012628).
- net: dsa: mv88e6xxx: Fix off-by-one in VTU devlink region size
  (bsc#1012628).
- nfp: devlink: initialize the devlink port attribute "lanes"
  (bsc#1012628).
- net: stmmac: fix TSO and TBS feature enabling during driver open
  (bsc#1012628).
- net: renesas: ravb: Fix a stuck issue when a lot of frames
  are received (bsc#1012628).
- net: phy: intel-xway: enable integrated led functions
  (bsc#1012628).
- mt76: mt7615: Fix a dereference of pointer sta before it is
  null checked (bsc#1012628).
- mt76: mt7921: fix possible invalid register access
  (bsc#1012628).
- RDMA/rxe: Fix a bug in rxe_fill_ip_info() (bsc#1012628).
- RDMA/core: Add CM to restrack after successful attachment to
  a device (bsc#1012628).
- powerpc/64: Fix the definition of the fixmap area (bsc#1012628).
- ath9k: Fix error check in ath9k_hw_read_revisions() for PCI
  devices (bsc#1012628).
- ath10k: Fix a use after free in ath10k_htc_send_bundle
  (bsc#1012628).
- ath10k: Fix ath10k_wmi_tlv_op_pull_peer_stats_info() unlock
  without lock (bsc#1012628).
- wlcore: Fix buffer overrun by snprintf due to incorrect buffer
  size (bsc#1012628).
- powerpc/perf: Fix the threshold event selection for memory
  events in power10 (bsc#1012628).
- powerpc/52xx: Fix an invalid ASM expression ('addi' used
  instead of 'add') (bsc#1012628).
- net: phy: marvell: fix m88e1011_set_downshift (bsc#1012628).
- net: phy: marvell: fix m88e1111_set_downshift (bsc#1012628).
- net: enetc: fix link error again (bsc#1012628).
- net, xdp: Update pkt_type if generic XDP changes unicast MAC
  (bsc#1012628).
- bnxt_en: fix ternary sign extension bug in bnxt_show_temp()
  (bsc#1012628).
- ARM: dts: uniphier: Change phy-mode to RGMII-ID to enable
  delay pins for RTL8211E (bsc#1012628).
- arm64: dts: uniphier: Change phy-mode to RGMII-ID to enable
  delay pins for RTL8211E (bsc#1012628).
- net: geneve: modify IP header check in geneve6_xmit_skb and
  geneve_xmit_skb (bsc#1012628).
- selftests: net: mirror_gre_vlan_bridge_1q: Make an FDB entry
  static (bsc#1012628).
- selftests: mlxsw: Remove a redundant if statement in port_scale
  test (bsc#1012628).
- selftests: mlxsw: Remove a redundant if statement in
  tc_flower_scale test (bsc#1012628).
- mptcp: Retransmit DATA_FIN (bsc#1012628).
- bnxt_en: Fix RX consumer index logic in the error path
  (bsc#1012628).
- KVM: VMX: Intercept FS/GS_BASE MSR accesses for 32-bit KVM
  (bsc#1012628).
- KVM: SVM: Zero out the VMCB array used to track SEV ASID
  association (bsc#1012628).
- KVM: SVM: Free sev_asid_bitmap during init if SEV setup fails
  (bsc#1012628).
- KVM: SVM: Disable SEV/SEV-ES if NPT is disabled (bsc#1012628).
- net/sched: act_ct: fix wild memory access when clearing
  fragments (bsc#1012628).
- net:emac/emac-mac: Fix a use after free in emac_mac_tx_buf_send
  (bsc#1012628).
- selftests/bpf: Fix BPF_CORE_READ_BITFIELD() macro (bsc#1012628).
- selftests/bpf: Fix field existence CO-RE reloc tests
  (bsc#1012628).
- selftests/bpf: Fix core_reloc test runner (bsc#1012628).
- bpf: Fix propagation of 32 bit unsigned bounds from 64 bit
  bounds (bsc#1012628).
- RDMA/siw: Fix a use after free in siw_alloc_mr (bsc#1012628).
- RDMA/bnxt_re: Fix a double free in bnxt_qplib_alloc_res
  (bsc#1012628).
- net: bridge: mcast: fix broken length + header check for MRDv6
  Adv (bsc#1012628).
- net: dsa: mv88e6xxx: Fix 6095/6097/6185 ports in non-SERDES
  CMODE (bsc#1012628).
- net:nfc:digital: Fix a double free in digital_tg_recv_dep_req
  (bsc#1012628).
- perf tools: Change fields type in perf_record_time_conv
  (bsc#1012628).
- perf jit: Let convert_timestamp() to be backwards-compatible
  (bsc#1012628).
- perf session: Add swap operation for event TIME_CONV
  (bsc#1012628).
- ia64: ensure proper NUMA distance and possible map
  initialization (bsc#1012628).
- ia64: fix EFI_DEBUG build (bsc#1012628).
- kfifo: fix ternary sign extension bugs (bsc#1012628).
- mm: memcontrol: slab: fix obtain a reference to a freeing memcg
  (bsc#1012628).
- mm/sparse: add the missing sparse_buffer_fini() in error branch
  (bsc#1012628).
- mm/memory-failure: unnecessary amount of unmapping
  (bsc#1012628).
- afs: Fix speculative status fetches (bsc#1012628).
- bpf: Fix alu32 const subreg bound tracking on bitwise operations
  (bsc#1012628).
- bpf, ringbuf: Deny reserve of buffers larger than ringbuf
  (bsc#1012628).
- bpf: Prevent writable memory-mapping of read-only ringbuf pages
  (bsc#1012628).
- net: Only allow init netns to set default tcp cong to a
  restricted algo (bsc#1012628).
- smp: Fix smp_call_function_single_async prototype (bsc#1012628).
- Refresh patches.suse/firmware-xilinx-Add-pinctrl-support.patch.
- Update config files.
- commit f003acc
* Fri May 14 2021 tiwai@suse.de
- drm/radeon: use the dummy page for GART if needed (bsc#1185516).
- commit 25fe027
* Fri May 14 2021 tiwai@suse.de
- ath11k: Clear the fragment cache during key install
  (CVE-2020-24586 CVE-2020-24587 CVE-2020-26145 CVE-2020-24588
  CVE-2020-24587 CVE-2020-26141 CVE-2020-26139 bsc#1185859
  bsc#1185860 bsc#1185861 bsc#1185862 bsc#1185863 bsc#1185987
  bsc#1186062).
- ath10k: Validate first subframe of A-MSDU before processing
  the list (CVE-2020-24586 CVE-2020-24587 CVE-2020-26145
  CVE-2020-24588 CVE-2020-24587 CVE-2020-26141 CVE-2020-26139
  bsc#1185859 bsc#1185860 bsc#1185861 bsc#1185862 bsc#1185863
  bsc#1185987 bsc#1186062).
- ath10k: Fix TKIP Michael MIC verification for PCIe
  (CVE-2020-24586 CVE-2020-24587 CVE-2020-26145 CVE-2020-24588
  CVE-2020-24587 CVE-2020-26141 CVE-2020-26139 bsc#1185859
  bsc#1185860 bsc#1185861 bsc#1185862 bsc#1185863 bsc#1185987
  bsc#1186062).
- ath10k: drop MPDU which has discard flag set by firmware
  for SDIO (CVE-2020-24586 CVE-2020-24587 CVE-2020-26145
  CVE-2020-24588 CVE-2020-24587 CVE-2020-26141 CVE-2020-26139
  bsc#1185859 bsc#1185860 bsc#1185861 bsc#1185862 bsc#1185863
  bsc#1185987 bsc#1186062).
- ath10k: drop fragments with multicast DA for SDIO
  (CVE-2020-24586 CVE-2020-24587 CVE-2020-26145 CVE-2020-24588
  CVE-2020-24587 CVE-2020-26141 CVE-2020-26139 bsc#1185859
  bsc#1185860 bsc#1185861 bsc#1185862 bsc#1185863 bsc#1185987
  bsc#1186062).
- ath10k: drop fragments with multicast DA for PCIe
  (CVE-2020-24586 CVE-2020-24587 CVE-2020-26145 CVE-2020-24588
  CVE-2020-24587 CVE-2020-26141 CVE-2020-26139 bsc#1185859
  bsc#1185860 bsc#1185861 bsc#1185862 bsc#1185863 bsc#1185987
  bsc#1186062).
- ath10k: add CCMP PN replay protection for fragmented frames
  for PCIe (CVE-2020-24586 CVE-2020-24587 CVE-2020-26145
  CVE-2020-24588 CVE-2020-24587 CVE-2020-26141 CVE-2020-26139
  bsc#1185859 bsc#1185860 bsc#1185861 bsc#1185862 bsc#1185863
  bsc#1185987 bsc#1186062).
- mac80211: extend protection against mixed key and fragment
  cache attacks (CVE-2020-24586 CVE-2020-24587 CVE-2020-26145
  CVE-2020-24588 CVE-2020-24587 CVE-2020-26141 CVE-2020-26139
  bsc#1185859 bsc#1185860 bsc#1185861 bsc#1185862 bsc#1185863
  bsc#1185987 bsc#1186062).
- mac80211: do not accept/forward invalid EAPOL frames
  (CVE-2020-24586 CVE-2020-24587 CVE-2020-26145 CVE-2020-24588
  CVE-2020-24587 CVE-2020-26141 CVE-2020-26139 bsc#1185859
  bsc#1185860 bsc#1185861 bsc#1185862 bsc#1185863 bsc#1185987
  bsc#1186062).
- mac80211: prevent attacks on TKIP/WEP as well (CVE-2020-24586
  CVE-2020-24587 CVE-2020-26145 CVE-2020-24588 CVE-2020-24587
  CVE-2020-26141 CVE-2020-26139 bsc#1185859 bsc#1185860
  bsc#1185861 bsc#1185862 bsc#1185863 bsc#1185987 bsc#1186062).
- mac80211: check defrag PN against current frame (CVE-2020-24586
  CVE-2020-24587 CVE-2020-26145 CVE-2020-24588 CVE-2020-24587
  CVE-2020-26141 CVE-2020-26139 bsc#1185859 bsc#1185860
  bsc#1185861 bsc#1185862 bsc#1185863 bsc#1185987 bsc#1186062).
- mac80211: add fragment cache to sta_info (CVE-2020-24586
  CVE-2020-24587 CVE-2020-26145 CVE-2020-24588 CVE-2020-24587
  CVE-2020-26141 CVE-2020-26139 bsc#1185859 bsc#1185860
  bsc#1185861 bsc#1185862 bsc#1185863 bsc#1185987 bsc#1186062).
- mac80211: drop A-MSDUs on old ciphers (CVE-2020-24586
  CVE-2020-24587 CVE-2020-26145 CVE-2020-24588 CVE-2020-24587
  CVE-2020-26141 CVE-2020-26139 bsc#1185859 bsc#1185860
  bsc#1185861 bsc#1185862 bsc#1185863 bsc#1185987 bsc#1186062).
- cfg80211: mitigate A-MSDU aggregation attacks (CVE-2020-24586
  CVE-2020-24587 CVE-2020-26145 CVE-2020-24588 CVE-2020-24587
  CVE-2020-26141 CVE-2020-26139 bsc#1185859 bsc#1185860
  bsc#1185861 bsc#1185862 bsc#1185863 bsc#1185987 bsc#1186062).
- mac80211: properly handle A-MSDUs that start with an RFC
  1042 header (CVE-2020-24586 CVE-2020-24587 CVE-2020-26145
  CVE-2020-24588 CVE-2020-24587 CVE-2020-26141 CVE-2020-26139
  bsc#1185859 bsc#1185860 bsc#1185861 bsc#1185862 bsc#1185863
  bsc#1185987 bsc#1186062).
- mac80211: prevent mixed key and fragment cache attacks
  (CVE-2020-24586 CVE-2020-24587 CVE-2020-26145 CVE-2020-24588
  CVE-2020-24587 CVE-2020-26141 CVE-2020-26139 bsc#1185859
  bsc#1185860 bsc#1185861 bsc#1185862 bsc#1185863 bsc#1185987
  bsc#1186062).
- mac80211: assure all fragments are encrypted (CVE-2020-24586
  CVE-2020-24587 CVE-2020-26145 CVE-2020-24588 CVE-2020-24587
  CVE-2020-26141 CVE-2020-26139 bsc#1185859 bsc#1185860
  bsc#1185861 bsc#1185862 bsc#1185863 bsc#1185987 bsc#1186062).
- commit 469e487
* Fri May 14 2021 iivanov@suse.de
- pinctrl: bcm2835: Accept fewer than expected IRQs (bsc#1181942)
- commit af44426
* Wed May 12 2021 tiwai@suse.de
- Delete patches.suse/radeon-workaround.patch.
  An upstream fix follows
- commit ff0b740
* Wed May 12 2021 glin@suse.com
- bpf: Prevent writable memory-mapping of read-only ringbuf pages
  (bsc#1185640 CVE-2021-3489).
- bpf, ringbuf: Deny reserve of buffers larger than ringbuf
  (bsc#1185640 CVE-2021-3489).
- bpf: Fix alu32 const subreg bound tracking on bitwise operations
  (bsc#1185641 CVE-2021-3490).
- commit 1f475c8
* Wed May 12 2021 jslaby@suse.cz
- Revert "drm/qxl: do not run release if qxl failed to init"
  (git-fixes).
- drm/amdgpu/display/dm: add missing parameter documentation
  (git-fixes).
- drm/amdgpu/display: remove redundant continue statement
  (git-fixes).
- ALSA: hda/realtek: ALC285 Thinkpad jack pin quirk is unreachable
  (git-fixes).
- io_uring: update sq_thread_idle after ctx deleted (git-fixes).
- commit 6e5c933
* Wed May 12 2021 jslaby@suse.cz
- Linux 5.12.3 (bsc#1012628).
- bus: mhi: core: Fix check for syserr at power_up (bsc#1012628).
- bus: mhi: core: Clear configuration from channel context during
  reset (bsc#1012628).
- bus: mhi: core: Sanity check values from remote device before
  use (bsc#1012628).
- bus: mhi: core: Add missing checks for MMIO register entries
  (bsc#1012628).
- bus: mhi: pci_generic: Remove WQ_MEM_RECLAIM flag from state
  workqueue (bsc#1012628).
- bus: mhi: core: Fix MHI runtime_pm behavior (bsc#1012628).
- bus: mhi: core: Fix invalid error returning in mhi_queue
  (bsc#1012628).
- nitro_enclaves: Fix stale file descriptors on failed usercopy
  (bsc#1012628).
- dyndbg: fix parsing file query without a line-range suffix
  (bsc#1012628).
- s390/disassembler: increase ebpf disasm buffer size
  (bsc#1012628).
- s390/zcrypt: fix zcard and zqueue hot-unplug memleak
  (bsc#1012628).
- s390/vfio-ap: fix circular lockdep when setting/clearing crypto
  masks (bsc#1012628).
- s390/cio: remove invalid condition on IO_SCH_UNREG
  (bsc#1012628).
- vhost-vdpa: fix vm_flags for virtqueue doorbell mapping
  (bsc#1012628).
- tpm: acpi: Check eventlog signature before using it
  (bsc#1012628).
- ACPI: custom_method: fix potential use-after-free issue
  (bsc#1012628).
- ACPI: custom_method: fix a possible memory leak (bsc#1012628).
- ftrace: Handle commands when closing set_ftrace_filter file
  (bsc#1012628).
- ARM: 9056/1: decompressor: fix BSS size calculation for LLVM
  ld.lld (bsc#1012628).
- arm64: dts: marvell: armada-37xx: add syscon compatible to NB
  clk node (bsc#1012628).
- arm64: dts: mt8173: fix property typo of 'phys' in dsi node
  (bsc#1012628).
- ecryptfs: fix kernel panic with null dev_name (bsc#1012628).
- fs/epoll: restore waking from ep_done_scan() (bsc#1012628).
- reset: add missing empty function reset_control_rearm()
  (bsc#1012628).
- mtd: spi-nor: core: Fix an issue of releasing resources during
  read/write (bsc#1012628).
- Revert "mtd: spi-nor: macronix: Add support for mx25l51245g"
  (bsc#1012628).
- mtd: spinand: core: add missing MODULE_DEVICE_TABLE()
  (bsc#1012628).
- mtd: rawnand: atmel: Update ecc_stats.corrected counter
  (bsc#1012628).
- mtd: physmap: physmap-bt1-rom: Fix unintentional stack access
  (bsc#1012628).
- erofs: add unsupported inode i_format check (bsc#1012628).
- spi: stm32-qspi: fix pm_runtime usage_count counter
  (bsc#1012628).
- spi: spi-ti-qspi: Free DMA resources (bsc#1012628).
- libceph: bump CephXAuthenticate encoding version (bsc#1012628).
- libceph: allow addrvecs with a single NONE/blank address
  (bsc#1012628).
- scsi: qla2xxx: Reserve extra IRQ vectors (bsc#1012628).
- scsi: lpfc: Fix rmmod crash due to bad ring pointers to
  abort_iotag (bsc#1012628).
- scsi: qla2xxx: Fix crash in qla2xxx_mqueuecommand()
  (bsc#1012628).
- scsi: mpt3sas: Only one vSES is present even when IOC has
  multi vSES (bsc#1012628).
- scsi: mpt3sas: Block PCI config access from userspace during
  reset (bsc#1012628).
- mmc: uniphier-sd: Fix an error handling path in
  uniphier_sd_probe() (bsc#1012628).
- mmc: uniphier-sd: Fix a resource leak in the remove function
  (bsc#1012628).
- mmc: sdhci: Check for reset prior to DMA address unmap
  (bsc#1012628).
- mmc: sdhci-pci: Fix initialization of some SD cards for Intel
  BYT-based controllers (bsc#1012628).
- mmc: sdhci-tegra: Add required callbacks to set/clear CQE_EN
  bit (bsc#1012628).
- mmc: block: Update ext_csd.cache_ctrl if it was written
  (bsc#1012628).
- mmc: block: Issue a cache flush only when it's enabled
  (bsc#1012628).
- mmc: core: Do a power cycle when the CMD11 fails (bsc#1012628).
- mmc: core: Set read only for SD cards with permanent write
  protect bit (bsc#1012628).
- mmc: core: Fix hanging on I/O during system suspend for
  removable cards (bsc#1012628).
- irqchip/gic-v3: Do not enable irqs when handling spurious
  interrups (bsc#1012628).
- cifs: Return correct error code from smb2_get_enc_key
  (bsc#1012628).
- cifs: fix out-of-bound memory access when calling smb3_notify()
  at mount point (bsc#1012628).
- cifs: fix leak in cifs_smb3_do_mount() ctx (bsc#1012628).
- cifs: detect dead connections only when echoes are enabled
  (bsc#1012628).
- cifs: fix regression when mounting shares with prefix paths
  (bsc#1012628).
- smb2: fix use-after-free in smb2_ioctl_query_info()
  (bsc#1012628).
- btrfs: handle remount to no compress during compression
  (bsc#1012628).
- x86/build: Disable HIGHMEM64G selection for M486SX
  (bsc#1012628).
- btrfs: fix metadata extent leak after failure to create
  subvolume (bsc#1012628).
- intel_th: pci: Add Rocket Lake CPU support (bsc#1012628).
- btrfs: fix race between transaction aborts and fsyncs leading
  to use-after-free (bsc#1012628).
- btrfs: zoned: fix unpaired block group unfreeze during device
  replace (bsc#1012628).
- btrfs: zoned: fail mount if the device does not support zone
  append (bsc#1012628).
- posix-timers: Preserve return value in clock_adjtime32()
  (bsc#1012628).
- fbdev: zero-fill colormap in fbcmap.c (bsc#1012628).
- cpuidle: tegra: Fix C7 idling state on Tegra114 (bsc#1012628).
- bus: ti-sysc: Probe for l4_wkup and l4_cfg interconnect devices
  first (bsc#1012628).
- staging: wimax/i2400m: fix byte-order issue (bsc#1012628).
- spi: ath79: always call chipselect function (bsc#1012628).
- spi: ath79: remove spi-master setup and cleanup assignment
  (bsc#1012628).
- bus: mhi: pci_generic: No-Op for device_wake operations
  (bsc#1012628).
- bus: mhi: core: Destroy SBL devices when moving to mission mode
  (bsc#1012628).
- bus: mhi: core: Process execution environment changes serially
  (bsc#1012628).
- crypto: api - check for ERR pointers in crypto_destroy_tfm()
  (bsc#1012628).
- crypto: qat - fix unmap invalid dma address (bsc#1012628).
- usb: gadget: uvc: add bInterval checking for HS mode
  (bsc#1012628).
- usb: webcam: Invalid size of Processing Unit Descriptor
  (bsc#1012628).
- x86/sev: Do not require Hypervisor CPUID bit for SEV guests
  (bsc#1012628).
- crypto: hisilicon/sec - fixes a printing error (bsc#1012628).
- genirq/matrix: Prevent allocation counter corruption
  (bsc#1012628).
- usb: gadget: f_uac2: validate input parameters (bsc#1012628).
- usb: gadget: f_uac1: validate input parameters (bsc#1012628).
- usb: dwc3: gadget: Ignore EP queue requests during bus reset
  (bsc#1012628).
- usb: xhci: Fix port minor revision (bsc#1012628).
- kselftest/arm64: mte: Fix compilation with native compiler
  (bsc#1012628).
- ARM: tegra: acer-a500: Rename avdd to vdda of touchscreen node
  (bsc#1012628).
- PCI: PM: Do not read power state in pci_enable_device_flags()
  (bsc#1012628).
- kselftest/arm64: mte: Fix MTE feature detection (bsc#1012628).
- ARM: dts: BCM5301X: fix "reg" formatting in /memory node
  (bsc#1012628).
- ARM: dts: ux500: Fix up TVK R3 sensors (bsc#1012628).
- x86/build: Propagate $(CLANG_FLAGS) to $(REALMODE_FLAGS)
  (bsc#1012628).
- x86/boot: Add $(CLANG_FLAGS) to compressed KBUILD_CFLAGS
  (bsc#1012628).
- efi/libstub: Add $(CLANG_FLAGS) to x86 flags (bsc#1012628).
- soc/tegra: pmc: Fix completion of power-gate toggling
  (bsc#1012628).
- arm64: dts: imx8mq-librem5-r3: Mark buck3 as always on
  (bsc#1012628).
- tee: optee: do not check memref size on return from Secure World
  (bsc#1012628).
- soundwire: cadence: only prepare attached devices on clock stop
  (bsc#1012628).
- perf/arm_pmu_platform: Use dev_err_probe() for IRQ errors
  (bsc#1012628).
- perf/arm_pmu_platform: Fix error handling (bsc#1012628).
- random: initialize ChaCha20 constants with correct endianness
  (bsc#1012628).
- usb: xhci-mtk: support quirk to disable usb2 lpm (bsc#1012628).
- fpga: dfl: pci: add DID for D5005 PAC cards (bsc#1012628).
- xhci: check port array allocation was successful before
  dereferencing it (bsc#1012628).
- xhci: check control context is valid before dereferencing it
  (bsc#1012628).
- xhci: fix potential array out of bounds with several
  interrupters (bsc#1012628).
- xhci: prevent double-fetch of transfer and transfer event TRBs
  (bsc#1012628).
- bus: mhi: core: Clear context for stopped channels from remove()
  (bsc#1012628).
- bus: mhi: pci_generic: Implement PCI shutdown callback
  (bsc#1012628).
- ARM: dts: at91: change the key code of the gpio key
  (bsc#1012628).
- tools/power/x86/intel-speed-select: Increase string size
  (bsc#1012628).
- platform/x86: ISST: Account for increased timeout in some cases
  (bsc#1012628).
- clocksource/drivers/dw_apb_timer_of: Add handling for potential
  memory leak (bsc#1012628).
- resource: Prevent irqresource_disabled() from erasing flags
  (bsc#1012628).
- spi: dln2: Fix reference leak to master (bsc#1012628).
- spi: omap-100k: Fix reference leak to master (bsc#1012628).
- spi: qup: fix PM reference leak in spi_qup_remove()
  (bsc#1012628).
- usb: dwc3: pci: add support for the Intel Alder Lake-M
  (bsc#1012628).
- usb: gadget: tegra-xudc: Fix possible use-after-free in
  tegra_xudc_remove() (bsc#1012628).
- usb: musb: fix PM reference leak in musb_irq_work()
  (bsc#1012628).
- usb: core: hub: Fix PM reference leak in usb_port_resume()
  (bsc#1012628).
- usb: dwc3: gadget: Check for disabled LPM quirk (bsc#1012628).
- tty: n_gsm: check error while registering tty devices
  (bsc#1012628).
- intel_th: Consistency and off-by-one fix (bsc#1012628).
- phy: phy-twl4030-usb: Fix possible use-after-free in
  twl4030_usb_remove() (bsc#1012628).
- crypto: sun4i-ss - Fix PM reference leak when
  pm_runtime_get_sync() fails (bsc#1012628).
- crypto: sun8i-ss - Fix PM reference leak when
  pm_runtime_get_sync() fails (bsc#1012628).
- crypto: sun8i-ce - Fix PM reference leak in sun8i_ce_probe()
  (bsc#1012628).
- crypto: stm32/hash - Fix PM reference leak on stm32-hash.c
  (bsc#1012628).
- crypto: stm32/cryp - Fix PM reference leak on stm32-cryp.c
  (bsc#1012628).
- crypto: sa2ul - Fix PM reference leak in sa_ul_probe()
  (bsc#1012628).
- crypto: omap-aes - Fix PM reference leak on omap-aes.c
  (bsc#1012628).
- platform/x86: intel_pmc_core: Don't use global pmcdev in quirks
  (bsc#1012628).
- spi: sync up initial chipselect state (bsc#1012628).
- btrfs: use btrfs_inode_lock/btrfs_inode_unlock inode lock
  helpers (bsc#1012628).
- btrfs: fix race between marking inode needs to be logged and
  log syncing (bsc#1012628).
- btrfs: fix exhaustion of the system chunk array due to
  concurrent allocations (bsc#1012628).
- btrfs: do proper error handling in create_reloc_root
  (bsc#1012628).
- btrfs: do proper error handling in btrfs_update_reloc_root
  (bsc#1012628).
- btrfs: convert logic BUG_ON()'s in replace_path to ASSERT()'s
  (bsc#1012628).
- regulator: da9121: automotive variants identity fix
  (bsc#1012628).
- drm: Added orientation quirk for OneGX1 Pro (bsc#1012628).
- drm/qxl: do not run release if qxl failed to init (bsc#1012628).
- drm/qxl: release shadow on shutdown (bsc#1012628).
- drm/ast: Fix invalid usage of AST_MAX_HWC_WIDTH in cursor
  atomic_check (bsc#1012628).
- drm/amd/display: changing sr exit latency (bsc#1012628).
- drm/amd/display: Fix MPC OGAM power on/off sequence
  (bsc#1012628).
- drm/amd/pm: do not issue message while write "r" into
  pp_od_clk_voltage (bsc#1012628).
- drm/ast: fix memory leak when unload the driver (bsc#1012628).
- drm/amd/display: Check for DSC support instead of ASIC revision
  (bsc#1012628).
- drm/amd/display: Don't optimize bandwidth before disabling
  planes (bsc#1012628).
- drm/amd/display: Return invalid state if GPINT times out
  (bsc#1012628).
- drm/amdgpu/display: buffer INTERRUPT_LOW_IRQ_CONTEXT interrupt
  work (bsc#1012628).
- drm/amd/display/dc/dce/dce_aux: Remove duplicate line causing
  'field overwritten' issue (bsc#1012628).
- scsi: lpfc: Fix incorrect dbde assignment when building target
  abts wqe (bsc#1012628).
- scsi: lpfc: Fix pt2pt connection does not recover after LOGO
  (bsc#1012628).
- scsi: lpfc: Fix status returned in lpfc_els_retry() error exit
  path (bsc#1012628).
- scsi: lpfc: Fix PLOGI ACC to be transmit after REG_LOGIN
  (bsc#1012628).
- scsi: lpfc: Fix ADISC handling that never frees nodes
  (bsc#1012628).
- drm/amd/pm/swsmu: clean up user profile function (bsc#1012628).
- drm/amdgpu: Fix some unload driver issues (bsc#1012628).
- sched/fair: Fix task utilization accountability in
  compute_energy() (bsc#1012628).
- sched/pelt: Fix task util_est update filtering (bsc#1012628).
- sched/topology: fix the issue groups don't span domain->span
  for NUMA diameter > 2 (bsc#1012628).
- kvfree_rcu: Use same set of GFP flags as does single-argument
  (bsc#1012628).
- drm/virtio: fix possible leak/unlock virtio_gpu_object_array
  (bsc#1012628).
- scsi: target: pscsi: Fix warning in pscsi_complete_cmd()
  (bsc#1012628).
- media: ite-cir: check for receive overflow (bsc#1012628).
- media: drivers: media: pci: sta2x11: fix Kconfig dependency
  on GPIOLIB (bsc#1012628).
- media: drivers/media/usb: fix memory leak in zr364xx_probe
  (bsc#1012628).
- media: cx23885: add more quirks for reset DMA on some AMD IOMMU
  (bsc#1012628).
- media: imx: capture: Return -EPIPE from
  __capture_legacy_try_fmt() (bsc#1012628).
- atomisp: don't let it go past pipes array (bsc#1012628).
- power: supply: bq27xxx: fix power_avg for newer ICs
  (bsc#1012628).
- extcon: arizona: Fix some issues when HPDET IRQ fires after
  the jack has been unplugged (bsc#1012628).
- extcon: arizona: Fix various races on driver unbind
  (bsc#1012628).
- media: venus: core, venc, vdec: Fix probe dependency error
  (bsc#1012628).
- s390/qdio: let driver manage the QAOB (bsc#1012628).
- media: media/saa7164: fix saa7164_encoder_register() memory
  leak bugs (bsc#1012628).
- media: gspca/sq905.c: fix uninitialized variable (bsc#1012628).
- media: v4l2-ctrls.c: initialize flags field of p_fwht_params
  (bsc#1012628).
- power: supply: Use IRQF_ONESHOT (bsc#1012628).
- backlight: qcom-wled: Use sink_addr for sync toggle
  (bsc#1012628).
- backlight: qcom-wled: Fix FSC update issue for WLED5
  (bsc#1012628).
- drm/amdgpu: enable retry fault wptr overflow (bsc#1012628).
- drm/amdgpu: enable 48-bit IH timestamp counter (bsc#1012628).
- drm/amdgpu: mask the xgmi number of hops reported from psp to
  kfd (bsc#1012628).
- drm/amdkfd: Fix UBSAN shift-out-of-bounds warning (bsc#1012628).
- drm/amd/display: Align cursor cache address to 2KB
  (bsc#1012628).
- drm/amdgpu : Fix asic reset regression issue introduce by
  8f211fe8ac7c4f (bsc#1012628).
- drm/amd/pm: fix workload mismatch on vega10 (bsc#1012628).
- drm/amd/display: Fix UBSAN warning for not a valid value for
  type '_Bool' (bsc#1012628).
- drm/amd/display: DCHUB underflow counter increasing in some
  scenarios (bsc#1012628).
- drm/amd/display: fix dml prefetch validation (bsc#1012628).
- drm/amd/display: Fix potential memory leak (bsc#1012628).
- scsi: qla2xxx: Always check the return value of
  qla24xx_get_isp_stats() (bsc#1012628).
- drm/vkms: fix misuse of WARN_ON (bsc#1012628).
- block, bfq: fix weight-raising resume with !low_latency
  (bsc#1012628).
- scsi: qla2xxx: Fix use after free in bsg (bsc#1012628).
- mmc: sdhci-esdhc-imx: validate pinctrl before use it
  (bsc#1012628).
- mmc: sdhci-pci: Add PCI IDs for Intel LKF (bsc#1012628).
- mmc: sdhci-brcmstb: Remove CQE quirk (bsc#1012628).
- ata: ahci: Disable SXS for Hisilicon Kunpeng920 (bsc#1012628).
- drm/komeda: Fix bit check to import to value of proper type
  (bsc#1012628).
- nvmet: return proper error code from discovery ctrl
  (bsc#1012628).
- selftests/resctrl: Enable gcc checks to detect buffer overflows
  (bsc#1012628).
- selftests/resctrl: Fix compilation issues for global variables
  (bsc#1012628).
- selftests/resctrl: Fix compilation issues for other global
  variables (bsc#1012628).
- selftests/resctrl: Clean up resctrl features check
  (bsc#1012628).
- selftests/resctrl: Fix missing options "-n" and "-p"
  (bsc#1012628).
- selftests/resctrl: Use resctrl/info for feature detection
  (bsc#1012628).
- selftests/resctrl: Fix incorrect parsing of iMC counters
  (bsc#1012628).
- selftests/resctrl: Fix checking for < 0 for unsigned values
  (bsc#1012628).
- power: supply: cpcap-charger: fix small mistake in current to
  register conversion (bsc#1012628).
- power: supply: cpcap-charger: Add usleep to cpcap charger to
  avoid usb plug bounce (bsc#1012628).
- scsi: smartpqi: Use host-wide tag space (bsc#1012628).
- scsi: smartpqi: Correct request leakage during reset operations
  (bsc#1012628).
- scsi: smartpqi: Add new PCI IDs (bsc#1012628).
- scsi: scsi_dh_alua: Remove check for ASC 24h in alua_rtpg()
  (bsc#1012628).
- media: em28xx: fix memory leak (bsc#1012628).
- media: vivid: update EDID (bsc#1012628).
- media: uvcvideo: Fix XU id print in forward scan (bsc#1012628).
- media: uvcvideo: Support devices that report an OT as an entity
  source (bsc#1012628).
- drm/msm/a6xx: Fix perfcounter oob timeout (bsc#1012628).
- drm/msm/dp: Fix incorrect NULL check kbot warnings in DP driver
  (bsc#1012628).
- clk: socfpga: arria10: Fix memory leak of socfpga_clk on error
  return (bsc#1012628).
- power: supply: generic-adc-battery: fix possible use-after-free
  in gab_remove() (bsc#1012628).
- power: supply: s3c_adc_battery: fix possible use-after-free
  in s3c_adc_bat_remove() (bsc#1012628).
- media: tc358743: fix possible use-after-free in
  tc358743_remove() (bsc#1012628).
- media: adv7604: fix possible use-after-free in adv76xx_remove()
  (bsc#1012628).
- media: i2c: adv7511-v4l2: fix possible use-after-free in
  adv7511_remove() (bsc#1012628).
- media: i2c: tda1997: Fix possible use-after-free in
  tda1997x_remove() (bsc#1012628).
- media: i2c: adv7842: fix possible use-after-free in
  adv7842_remove() (bsc#1012628).
- media: platform: sti: Fix runtime PM imbalance in regs_show
  (bsc#1012628).
- media: sun8i-di: Fix runtime PM imbalance in
  deinterlace_start_streaming (bsc#1012628).
- media: dvb-usb: fix memory leak in dvb_usb_adapter_init
  (bsc#1012628).
- media: gscpa/stv06xx: fix memory leak (bsc#1012628).
- sched/fair: Bring back select_idle_smt(), but differently
  (bsc#1012628).
- sched/fair: Ignore percpu threads for imbalance pulls
  (bsc#1012628).
- drm/msm/mdp5: Configure PP_SYNC_HEIGHT to double the vtotal
  (bsc#1012628).
- drm/msm/mdp5: Do not multiply vclk line count by 100
  (bsc#1012628).
- drm/amdgpu/ttm: Fix memory leak userptr pages (bsc#1012628).
- drm/radeon/ttm: Fix memory leak userptr pages (bsc#1012628).
- drm/amd/display: Fix debugfs link_settings entry (bsc#1012628).
- drm/amd/display: Fix UBSAN: shift-out-of-bounds warning
  (bsc#1012628).
- drm/radeon: don't evict if not initialized (bsc#1012628).
- drm/amdkfd: Fix cat debugfs hang_hws file causes system crash
  bug (bsc#1012628).
- amdgpu: avoid incorrect %%hu format string (bsc#1012628).
- drm/amdgpu/display: fix memory leak for dimgrey cavefish
  (bsc#1012628).
- drm/amd/display: Try YCbCr420 color when YCbCr444 fails
  (bsc#1012628).
- drm/amdgpu: fix NULL pointer dereference (bsc#1012628).
- drm/amd/display: Update DCN302 SR Exit Latency (bsc#1012628).
- scsi: mpt3sas: Fix out-of-bounds warnings in
  _ctl_addnl_diag_query (bsc#1012628).
- scsi: lpfc: Fix crash when a REG_RPI mailbox fails triggering
  a LOGO response (bsc#1012628).
- scsi: lpfc: Fix reference counting errors in lpfc_cmpl_els_rsp()
  (bsc#1012628).
- scsi: lpfc: Fix error handling for mailboxes completed in
  MBX_POLL mode (bsc#1012628).
- scsi: lpfc: Remove unsupported mbox PORT_CAPABILITIES logic
  (bsc#1012628).
- mfd: intel-m10-bmc: Fix the register access range (bsc#1012628).
- mfd: da9063: Support SMBus and I2C mode (bsc#1012628).
- mfd: arizona: Fix rumtime PM imbalance on error (bsc#1012628).
- scsi: libfc: Fix a format specifier (bsc#1012628).
- perf: Rework perf_event_exit_event() (bsc#1012628).
- sched,fair: Alternative sched_slice() (bsc#1012628).
- block/rnbd-srv: Prevent a deadlock generated by accessing
  sysfs in parallel (bsc#1012628).
- block/rnbd-clt: Fix missing a memory free when unloading the
  module (bsc#1012628).
- io_uring: safer sq_creds putting (bsc#1012628).
- s390/archrandom: add parameter check for
  s390_arch_random_generate (bsc#1012628).
- sched,psi: Handle potential task count underflow bugs more
  gracefully (bsc#1012628).
- nvmet: avoid queuing keep-alive timer if it is disabled
  (bsc#1012628).
- power: supply: cpcap-battery: fix invalid usage of list cursor
  (bsc#1012628).
- ALSA: emu8000: Fix a use after free in snd_emu8000_create_mixer
  (bsc#1012628).
- ALSA: hda/conexant: Re-order CX5066 quirk table entries
  (bsc#1012628).
- ALSA: sb: Fix two use after free in snd_sb_qsound_build
  (bsc#1012628).
- ALSA: usb-audio: Explicitly set up the clock selector
  (bsc#1012628).
- ALSA: usb-audio: Add dB range mapping for Sennheiser
  Communications Headset PC 8 (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP ProBook 445 G7
  (bsc#1012628).
- ALSA: hda/realtek: GA503 use same quirks as GA401 (bsc#1012628).
- ALSA: hda/realtek: fix mic boost on Intel NUC 8 (bsc#1012628).
- ALSA: hda/realtek - Headset Mic issue on HP platform
  (bsc#1012628).
- ALSA: hda/realtek: fix static noise on ALC285 Lenovo laptops
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Intel Clevo PCx0Dx
  (bsc#1012628).
- tools/power/turbostat: Fix turbostat for AMD Zen CPUs
  (bsc#1012628).
- btrfs: fix race when picking most recent mod log operation
  for an old root (bsc#1012628).
- btrfs: fix a potential hole punching failure (bsc#1012628).
- arm64/vdso: Discard .note.gnu.property sections in vDSO
  (bsc#1012628).
- Makefile: Move -Wno-unused-but-set-variable out of GCC only
  block (bsc#1012628).
- riscv/kprobe: fix kernel panic when invoking sys_read traced
  by kprobe (bsc#1012628).
- fs: fix reporting supported extra file attributes for statx()
  (bsc#1012628).
- virtiofs: fix memory leak in virtio_fs_probe() (bsc#1012628).
- kcsan, debugfs: Move debugfs file creation out of early init
  (bsc#1012628).
- ubifs: Only check replay with inode type to judge if inode
  linked (bsc#1012628).
- f2fs: fix error handling in f2fs_end_enable_verity()
  (bsc#1012628).
- f2fs: fix to avoid out-of-bounds memory access (bsc#1012628).
- mlxsw: spectrum_mr: Update egress RIF list before route's action
  (bsc#1012628).
- openvswitch: fix stack OOB read while fragmenting IPv4 packets
  (bsc#1012628).
- net/sched: sch_frag: fix stack OOB read while fragmenting IPv4
  packets (bsc#1012628).
- ACPI: GTDT: Don't corrupt interrupt mappings on watchdow probe
  failure (bsc#1012628).
- NFS: fs_context: validate UDP retrans to prevent shift
  out-of-bounds (bsc#1012628).
- NFS: Don't discard pNFS layout segments that are marked for
  return (bsc#1012628).
- NFSv4: Don't discard segments marked for return in
  _pnfs_return_layout() (bsc#1012628).
- Input: ili210x - add missing negation for touch indication on
  ili210x (bsc#1012628).
- jffs2: Fix kasan slab-out-of-bounds problem (bsc#1012628).
- jffs2: Hook up splice_write callback (bsc#1012628).
- iommu/vt-d: Force to flush iotlb before creating superpage
  (bsc#1012628).
- powerpc/vdso: Separate vvar vma from vdso (bsc#1012628).
- powerpc/powernv: Enable HAIL (HV AIL) for ISA v3.1 processors
  (bsc#1012628).
- powerpc/eeh: Fix EEH handling for hugepages in ioremap space
  (bsc#1012628).
- powerpc/kexec_file: Use current CPU info while setting up FDT
  (bsc#1012628).
- powerpc/32: Fix boot failure with CONFIG_STACKPROTECTOR
  (bsc#1012628).
- powerpc: fix EDEADLOCK redefinition error in uapi/asm/errno.h
  (bsc#1012628).
- powerpc/kvm: Fix PR KVM with KUAP/MEM_KEYS enabled
  (bsc#1012628).
- powerpc/kvm: Fix build error when PPC_MEM_KEYS/PPC_PSERIES=n
  (bsc#1012628).
- intel_th: pci: Add Alder Lake-M support (bsc#1012628).
- tpm: efi: Use local variable for calculating final log size
  (bsc#1012628).
- tpm: vtpm_proxy: Avoid reading host log when using a virtual
  device (bsc#1012628).
- crypto: arm/curve25519 - Move '.fpu' after '.arch'
  (bsc#1012628).
- crypto: rng - fix crypto_rng_reset() refcounting when
  !CRYPTO_STATS (bsc#1012628).
- md/raid1: properly indicate failure when ending a failed write
  request (bsc#1012628).
- dm raid: fix inconclusive reshape layout on fast raid4/5/6
  table reload sequences (bsc#1012628).
- fuse: fix write deadlock (bsc#1012628).
- mm: page_alloc: ignore init_on_free=1 for debug_pagealloc=1
  (bsc#1012628).
- exfat: fix erroneous discard when clear cluster bit
  (bsc#1012628).
- sfc: farch: fix TX queue lookup in TX flush done handling
  (bsc#1012628).
- sfc: farch: fix TX queue lookup in TX event handling
  (bsc#1012628).
- sfc: adjust efx->xdp_tx_queue_count with the real number of
  initialized queues (bsc#1012628).
- rcu/nocb: Fix missed nocb_timer requeue (bsc#1012628).
- security: commoncap: fix -Wstringop-overread warning
  (bsc#1012628).
- Fix misc new gcc warnings (bsc#1012628).
- smb3: when mounting with multichannel include it in requested
  capabilities (bsc#1012628).
- smb3: if max_channels set to more than one channel request
  multichannel (bsc#1012628).
- smb3: do not attempt multichannel to server which does not
  support it (bsc#1012628).
- Revert 337f13046ff0 ("futex: Allow FUTEX_CLOCK_REALTIME with
  FUTEX_WAIT op") (bsc#1012628).
- futex: Do not apply time namespace adjustment on FUTEX_LOCK_PI
  (bsc#1012628).
- x86/cpu: Initialize MSR_TSC_AUX if RDTSCP *or* RDPID is
  supported (bsc#1012628).
- kbuild: update config_data.gz only when the content of .config
  is changed (bsc#1012628).
- ext4: annotate data race in start_this_handle() (bsc#1012628).
- ext4: annotate data race in jbd2_journal_dirty_metadata()
  (bsc#1012628).
- ext4: fix check to prevent false positive report of incorrect
  used inodes (bsc#1012628).
- ext4: do not set SB_ACTIVE in ext4_orphan_cleanup()
  (bsc#1012628).
- ext4: always panic when errors=panic is specified (bsc#1012628).
- ext4: fix error code in ext4_commit_super (bsc#1012628).
- ext4: fix ext4_error_err save negative errno into superblock
  (bsc#1012628).
- ext4: fix error return code in ext4_fc_perform_commit()
  (bsc#1012628).
- ext4: allow the dax flag to be set and cleared on inline
  directories (bsc#1012628).
- ext4: Fix occasional generic/418 failure (bsc#1012628).
- media: dvbdev: Fix memory leak in dvb_media_device_free()
  (bsc#1012628).
- media: staging/intel-ipu3: Fix memory leak in imu_fmt
  (bsc#1012628).
- media: staging/intel-ipu3: Fix set_fmt error handling
  (bsc#1012628).
- media: staging/intel-ipu3: Fix race condition during set_fmt
  (bsc#1012628).
- media: v4l2-ctrls: fix reference to freed memory (bsc#1012628).
- media: coda: fix macroblocks count control usage (bsc#1012628).
- media: venus: pm_helpers: Set opp clock name for v1
  (bsc#1012628).
- media: venus: venc_ctrls: Change default header mode
  (bsc#1012628).
- media: venus: hfi_cmds: Support plane-actual-info property
  from v1 (bsc#1012628).
- media: venus: hfi_parser: Don't initialize parser on v1
  (bsc#1012628).
- media: venus: hfi_parser: Check for instance after hfi platform
  get (bsc#1012628).
- io_uring: remove extra sqpoll submission halting (bsc#1012628).
- io_uring: fix shared sqpoll cancellation hangs (bsc#1012628).
- io_uring: fix work_exit sqpoll cancellations (bsc#1012628).
- io_uring: Check current->io_uring in io_uring_cancel_sqpoll
  (bsc#1012628).
- usb: gadget: dummy_hcd: fix gpf in gadget_setup (bsc#1012628).
- usb: gadget: Fix double free of device descriptor pointers
  (bsc#1012628).
- usb: gadget/function/f_fs string table fix for multiple
  languages (bsc#1012628).
- usb: dwc3: gadget: Remove FS bInterval_m1 limitation
  (bsc#1012628).
- usb: dwc3: gadget: Fix START_TRANSFER link state check
  (bsc#1012628).
- usb: dwc3: core: Do core softreset when switch mode
  (bsc#1012628).
- usb: dwc2: Fix session request interrupt handler (bsc#1012628).
- PCI: dwc: Move iATU detection earlier (bsc#1012628).
- tty: fix memory leak in vc_deallocate (bsc#1012628).
- rsi: Use resume_noirq for SDIO (bsc#1012628).
- tools/power turbostat: Fix offset overflow issue in index
  converting (bsc#1012628).
- tracing: Map all PIDs to command lines (bsc#1012628).
- tracing: Restructure trace_clock_global() to never block
  (bsc#1012628).
- dm persistent data: packed struct should have an aligned()
  attribute too (bsc#1012628).
- dm space map common: fix division bug in sm_ll_find_free_block()
  (bsc#1012628).
- dm integrity: fix missing goto in bitmap_flush_interval error
  handling (bsc#1012628).
- dm rq: fix double free of blk_mq_tag_set in dev remove after
  table load fails (bsc#1012628).
- pinctrl: Ingenic: Add missing pins to the JZ4770 MAC MII group
  (bsc#1012628).
- pinctrl: Ingenic: Add support for read the pin configuration
  of X1830 (bsc#1012628).
- lib/vsprintf.c: remove leftover 'f' and 'F' cases from
  bstr_printf() (bsc#1012628).
- thermal/drivers/cpufreq_cooling: Fix slab OOB issue
  (bsc#1012628).
- thermal/core/fair share: Lock the thermal zone while looping
  over instances (bsc#1012628).
- commit e0bb900
* Wed May 12 2021 glin@suse.com
- scripts/git_sort/git_sort.py: add bpf git repo
- commit 65979e3
* Tue May 11 2021 mkubecek@suse.cz
- sctp: delay auto_asconf init until binding the first addr
  (CVE-2021-23133 bsc#1184675).
- Revert "net/sctp: fix race condition in sctp_destroy_sock"
  (CVE-2021-23133 bsc#1184675).
- commit 6758015
* Tue May 11 2021 ddiss@suse.de
- proc: Avoid mixing integer types in mem_rw() (CVE-2021-3491
  bsc#1185642).
- io_uring: truncate lengths larger than MAX_RW_COUNT on provide
  buffers (CVE-2021-3491 bsc#1185642).
- io_uring: fix overflows checks in provide buffers (CVE-2021-3491
  bsc#1185642).
- commit 079e747
* Tue May 11 2021 mbrugger@suse.com
- pinctrl: Add Xilinx ZynqMP pinctrl driver support (bsc#1185927).
- Update config files. (bsc#1185927)
- firmware: xilinx: Add pinctrl support (bsc#1185927).
- dt-bindings: pinctrl: Add binding for ZynqMP pinctrl driver
  (bsc#1185927).
- pinctrl: Introduce MODE group in enum pin_config_param
  (bsc#1185927).
- commit fce7e82
* Tue May 11 2021 tiwai@suse.de
- Workaround for a crash in radeon driver (bsc#1185516).
- commit 66123af
* Mon May 10 2021 tiwai@suse.de
- drm/i915/dp: Use slow and wide link training for everything
  (bsc#1185601).
- commit 3d40a8d
* Mon May 10 2021 tiwai@suse.de
- Delete patches.suse/Revert-drm-i915-Try-to-use-fast-narrow-link-on-eDP-a.patch
  An upstream fix will follow
- commit 3da1f57
* Mon May 10 2021 dmueller@suse.com
- Add dtb-apple (bsc#1185845)
- commit 405d0ae
* Mon May 10 2021 mkubecek@suse.cz
- Update to 5.13-rc1
- eliminated 34 patches (22 stable, 12 other)
  - patches.kernel.org/*
  - patches.suse/clk-bcm-rpi-release-firmware-handle-on-unbind.patch
  - patches.suse/dt-bindings-pwm-add-binding-for-rpi-firmware-pwm-bus.patch
  - patches.suse/firmware-raspberrypi-introduce-devm_rpi_firmware_get.patch
  - patches.suse/firmware-raspberrypi-keep-count-of-all-consumers.patch
  - patches.suse/gpio-raspberrypi-exp-release-firmware-handle-on-unbind.patch
  - patches.suse/input-raspberrypi-ts-release-firmware-handle-when-not-needed.patch
  - patches.suse/media-dvb-usb-Fix-memory-leak-at-error-in-dvb_usb_de.patch
  - patches.suse/media-dvb-usb-Fix-use-after-free-access.patch
  - patches.suse/pwm-add-raspberry-pi-firmware-based-pwm-bus.patch
  - patches.suse/reset-raspberrypi-release-firmware-handle-on-unbind.patch
  - patches.suse/soc-bcm-raspberrypi-power-release-firmware-handle-on-unbind.patch
  - patches.suse/vchiq-release-firmware-handle-on-unbind.patch
- disable ARM architectures (need config update)
- refresh
  - patches.rpmify/powerpc-64-BE-option-to-use-ELFv2-ABI-for-big-endian.patch
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/supported-flag
  - patches.suse/supported-flag-modverdir
  - patches.suse/vfs-add-super_operations-get_inode_dev
- config refresh (no longer available as module)
  - PVPANIC (m -> y)
  - NFS_V4_2_SSC_HELPER (m -> y)
- new config options
  - General setup
  - CGROUP_MISC=y
  - Virtualization
  - X86_SGX_KVM=y
  - General architecture-dependent options
  - RANDOMIZE_KSTACK_OFFSET_DEFAULT=y
  - Enable loadable module support
  - MODULE_COMPRESS_NONE=y
  - MODULE_COMPRESS_GZIP=n
  - MODULE_COMPRESS_XZ=n
  - MODULE_COMPRESS_ZSTD=n
  - MODPROBE_PATH="/sbin/modprobe"
  - Networking support
  - NF_LOG_SYSLOG=m
  - NETFILTER_XTABLES_COMPAT=y
  - PCPU_DEV_REFCNT=y
  - CAN_ETAS_ES58X=m
  - BT_AOSPEXT=y
  - BT_VIRTIO=m
  - File systems
  - NETFS_SUPPORT=m
  - NETFS_STATS=y
  - Security options
  - SECURITY_LANDLOCK=y
  - Cryptographic API
  - CRYPTO_ECDSA=y
  - SYSTEM_REVOCATION_LIST=y
  - SYSTEM_REVOCATION_KEYS=""
  - Kernel hacking
  - VMLINUX_MAP=y
  - TEST_DIV64=n
  - Virtualiation drivers
  - PVPANIC=y
  - PVPANIC_MMIO=m
  - PVPANIC_PCI=m
  - VDPA_SIM_BLOCK=m
  - VP_VDPA=m
  - Network device support
  - NET_DSA_MICROCHIP_KSZ8863_SMI=m
  - NET_VENDOR_MICROSOFT=y
  - MICROSOFT_MANA=m
  - MLX5_TC_SAMPLE=y
  - MARVELL_88X2222_PHY=m
  - NXP_C45_TJA11XX_PHY=m
  - WWAN=y
  - WWAN_CORE=m
  - MHI_WWAN_CTRL=m
  - Input device support
  - TOUCHSCREEN_HYCON_HY46XX=m
  - TOUCHSCREEN_ILITEK=m
  - TOUCHSCREEN_MSG2638=m
  - INPUT_IQS626A=m
  - Power supply class support
  - BATTERY_GOLDFISH=m
  - BATTERY_SURFACE=m
  - CHARGER_SURFACE=m
  - Hardware Monitoring support
  - SENSORS_NZXT_KRAKEN2=m
  - SENSORS_BPA_RS600=m
  - SENSORS_FSP_3Y=m
  - SENSORS_IR36021=m
  - SENSORS_MAX15301=m
  - SENSORS_STPDDC60=m
  - Graphics support
  - DRM_AMD_SECURE_DISPLAY=y
  - DRM_I915_REQUEST_TIMEOUT=20000
  - DRM_GUD=m
  - Sound card support
  - SND_SOC_FSL_RPMSG=n
  - SND_SOC_TLV320AIC3X_I2C=n
  - SND_SOC_TLV320AIC3X_SPI=n
  - SND_VIRTIO=m
  - HID support
  - HID_FT260=m
  - SURFACE_KBD=m
  - SURFACE_HID=m
  - X86 Platform Specific Device Drivers
  - GIGABYTE_WMI=m
  - ADV_SWBUTTON=m
  - Microsoft Surface Platform-Specific Device Drivers
  - SURFACE_AGGREGATOR_REGISTRY=m
  - SURFACE_DTX=m
  - SURFACE_PLATFORM_PROFILE=m
  - Industrial I/O support
  - BMI088_ACCEL=n
  - TI_ADS131E08=n
  - CROS_EC_MKBP_PROXIMITY=n
  - Misc devices
  - DW_XDATA_PCIE=m
  - I2C_CP2615=m
  - SPI_ALTERA_CORE=m
  - SPI_ALTERA_DFL=m
  - INTEL_TCC_COOLING=m
  - MFD_ATC260X_I2C=n
  - RTC_DRV_GOLDFISH=m
  - INTEL_IDXD_PERFMON=y
  - UIO_DFL=m
  - OF dependent (i386, ppc64 / ppc64le, riscv64)
  - MFD_NTXEC=n
  - MFD_ROHM_BD957XMUF=n
  - DRM_CHIPONE_ICN6211=n
  - DRM_LONTIUM_LT8912B=n
  - LEDS_RT4505=m
  - i386
  - MODULE_SIG_ALL=n
  - MODULE_SIG_SHA256=y
  - SND_SOC_RT1316_SDW=n
  - SND_SOC_RT711_SDCA_SDW=n
  - SND_SOC_RT715_SDCA_SDW=n
  - LEDS_LGM=m
  - MODULE_SIG_KEY="certs/signing_key.pem"
  - ppc64 / ppc64le
  - TIME_NS=y
  - STRICT_KERNEL_RWX=y
  - CMA_SYSFS=n
  - FSL_DPAA2_SWITCH=m
  - FSL_ENETC_IERB=m
  - DEBUG_RODATA_TEST=n
  - DEBUG_VM_PGTABLE=n
  - s390x
  - CMA_SYSFS=n
  - NET_DSA=n
  - CIO_INJECT=n
  - riscv64
  - SOC_MICROCHIP_POLARFIRE=y
  - RISCV_ERRATA_ALTERNATIVE=y
  - ERRATA_SIFIVE_CIP_453=y
  - ERRATA_SIFIVE_CIP_1200=y
  - KEXEC=y
  - CRASH_DUMP=y
  - PHYS_RAM_BASE_FIXED=n
  - XIP_KERNEL=n
  - STRICT_MODULE_RWX=y
  - PCIE_FU740
  - PROC_VMCORE=y
  - PROC_VMCORE_DEVICE_DUMP=y
  - FORTIFY_SOURCE=y
- commit 0ba08a9
* Mon May 10 2021 tiwai@suse.de
- Revert "drm/i915: Try to use fast+narrow link on eDP again
  and fall back to the old max strategy on failure" (bsc#1185601).
- commit 6c0f44c
* Fri May  7 2021 jslaby@suse.cz
- Linux 5.12.2 (bsc#1012628).
- perf/core: Fix unconditional security_locked_down() call
  (bsc#1012628).
- platform/x86: thinkpad_acpi: Correct thermal sensor allocation
  (bsc#1012628).
- USB: Add reset-resume quirk for WD19's Realtek Hub
  (bsc#1012628).
- USB: Add LPM quirk for Lenovo ThinkPad USB-C Dock Gen2 Ethernet
  (bsc#1012628).
- ALSA: usb-audio: Fix implicit sync clearance at stopping stream
  (bsc#1012628).
- ALSA: usb-audio: Add MIDI quirk for Vox ToneLab EX
  (bsc#1012628).
- ovl: allow upperdir inside lowerdir (bsc#1012628).
- ovl: fix leaked dentry (bsc#1012628).
- net: qrtr: Avoid potential use after free in MHI send
  (bsc#1012628).
- bpf: Fix leakage of uninitialized bpf stack under speculation
  (bsc#1012628).
- bpf: Fix masking negation logic upon negative dst register
  (bsc#1012628).
- drm/i915: Disable runtime power management during shutdown
  (bsc#1012628).
- net: usb: ax88179_178a: initialize local variables before use
  (bsc#1012628).
- netfilter: conntrack: Make global sysctls readonly in non-init
  netns (bsc#1012628).
- mips: Do not include hi and lo in clobber list for R6
  (bsc#1012628).
- commit 85a2a31
* Thu May  6 2021 msuchanek@suse.de
- kernel-docs.spec.in: Build using an utf-8 locale.
  Sphinx cannot handle UTF-8 input in non-UTF-8 locale.
- commit 0db6da1
* Thu May  6 2021 mkubecek@suse.cz
- config: disable kfence by default (bsc#1185565)
  Apperently the overhead of kfence is not as negligible as the help text
  seemed to promise so that it seems more appropriate to disable kfence by
  default by setting CONFIG_KFENCE_SAMPLE_INTERVAL to 0. Anyone who wants to
  enable it can still do so using the kfence.sample_interval command line
  parameter.
- commit 5d73dc7
* Wed May  5 2021 msuchanek@suse.de
- rpm/kernel-docs.spec.in: Add amscls as required for build.
  [  781s] ! LaTeX Error: File `amsthm.sty' not found.
- commit 1fd6a67
* Wed May  5 2021 msuchanek@suse.de
- Fix vanilla ppc64 build.
- commit f1085cb
* Wed May  5 2021 iivanov@suse.de
- mmc: sdhci-iproc: Set SDHCI_QUIRK_CAP_CLOCK_BASE_BROKEN on BCM2711 (bsc#1176576)
- commit 310b140
* Wed May  5 2021 iivanov@suse.de
- mmc: sdhci-iproc: Cap min clock frequency on BCM2711 (bsc#1176576)
- commit 3e41868
* Wed May  5 2021 mkubecek@suse.cz
- rpm: drop /usr/bin/env in interpreter specification
  OBS checks don't like /usr/bin/env in script interpreter lines but upstream
  developers tend to use it. A proper solution would be fixing the depedency
  extraction and drop the OBS check error but that's unlikely to happen so
  that we have to work around the problem on our side and rewrite the
  interpreter lines in scripts before collecting files for packages instead.
- commit 45c5c1a
* Tue May  4 2021 mbrugger@suse.com
- supported.conf: add USB Typec to installer (bsc#1184867)
- commit 17b53f0
* Tue May  4 2021 dwagner@suse.de
- scripts/git_sort/git_sort.py: Update nvme repositories
- commit e849c44
* Sun May  2 2021 jslaby@suse.cz
- Linux 5.12.1 (bsc#1012628).
- mei: me: add Alder Lake P device id (bsc#1012628).
- cfg80211: fix locking in netlink owner interface destruction
  (bsc#1012628).
- iwlwifi: Fix softirq/hardirq disabling in
  iwl_pcie_gen2_enqueue_hcmd() (bsc#1012628).
- USB: CDC-ACM: fix poison/unpoison imbalance (bsc#1012628).
- net: hso: fix NULL-deref on disconnect regression (bsc#1012628).
- commit 9f237a4
* Sat May  1 2021 msuchanek@suse.de
- powerpc/64: BE option to use ELFv2 ABI for big endian kernels
  (BTFIDS vmlinux FAILED unresolved symbol vfs_truncate).
  Update config files.
- commit 17ebdf1
* Fri Apr 30 2021 schwab@suse.de
- rpm/constraints.in: bump disk space to 45GB on riscv64
- commit f8b883f
* Thu Apr 29 2021 tiwai@suse.de
- Update config files: fix armv7hl/lpae config (bsc#1152773)
  CONFIG_OABI_COMPAT was left enabled mistakenly on lpae flavor, which
  resulted in the disablement of CONFIG_SECCOMP_FILTER.  Fix those.
  CONFIG_OABI_COMPAT -> disabled
  CONFIG_SECCOMP_FILTER=y
  CONFIG_HAVE_ARCH_SECCOMP_FILTER=y
  Also corrected the following with the update:
  CONFIG_HAVE_ARCH_AUDITSYSCALL=y
  CONFIG_AUDITSYSCALL=y
  CONFIG_FPE_NWFPE -> removed
  CONFIG_FPE_NWFPE_XP -> removed
  CONFIG_FPE_FASTFPE -> removed
- commit 644711e
* Wed Apr 28 2021 jslaby@suse.cz
- rpm/constraints.in: remove aarch64 disk size exception
  obs://Kernel:stable/kernel-default/ARM/aarch64 currrently fails:
  installing package kernel-default-livepatch-devel-5.12.0-3.1.g6208a83.aarch64 needs 3MB more space on the / filesystem
  The stats say:
  Maximal used disk space: 31799 Mbyte
  By default, we require 35G. For aarch64 we had an exception to lower
  this limit to 30G there. Drop this exception as it is obviously no
  longer valid.
- commit ee00b50
* Mon Apr 26 2021 mkubecek@suse.cz
- series.conf: cleanup
- fix Patch-mainline tag and move to "almost mainline" section:
  patches.suse/crypto-ccp-Annotate-SEV-Firmware-file-names.patch
- commit 3a48ed8
* Mon Apr 26 2021 jroedel@suse.de
- crypto: ccp: Annotate SEV Firmware file names (bsc#1185282).
- commit 66154b6
* Sun Apr 25 2021 mkubecek@suse.cz
- Update to 5.12 final
- refresh configs (headers only)
- commit 9683115
* Sun Apr 25 2021 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Require new enough pahole.
  pahole 1.21 is required for building line-next BTF
- commit 8df1aaa
* Fri Apr 23 2021 martin.wilck@suse.com
- rpm/macros.kernel-source: fix KMP failure in %%install (bsc#1185244)
- commit 52805ed
* Thu Apr 22 2021 msuchanek@suse.de
- rpm/kernel-obs-build.spec.in: Include essiv with dm-crypt (boo#1183063).
  Previously essiv was part of dm-crypt but now it is separate.
  Include the module in kernel-obs-build when available.
  Fixes: 7cf5b9e26d87 ("rpm/kernel-obs-build.spec.in: add dm-crypt for building with cryptsetup")
- commit fe15b78
* Thu Apr 22 2021 tiwai@suse.de
- Revert "rpm/kernel-binary.spec.in: Fix dependency of kernel-*-devel package (bsc#1184514)"
  This turned out to be a bad idea: the kernel-$flavor-devel package
  must be usable without kernel-$flavor, e.g. at the build of a KMP.
  And this change brought superfluous installation of kernel-preempt
  when a system had kernel-syms (bsc#1185113).
- commit d771304
* Wed Apr 21 2021 jslaby@suse.cz
- rpm/check-for-config-changes: add AS_HAS_* to ignores
  arch/arm64/Kconfig defines a lot of these. So far our current compilers
  seem to support them all. But it can quickly change with SLE later.
- commit a4d8194
* Wed Apr 21 2021 jslaby@suse.cz
- Linux 5.11.16 (bsc#1012628).
- bpf: Move sanitize_val_alu out of op switch (bsc#1012628).
- bpf: Improve verifier error messages for users (bsc#1012628).
- bpf: Rework ptr_limit into alu_limit and add common error path
  (bsc#1012628).
- ARM: 9071/1: uprobes: Don't hook on thumb instructions
  (bsc#1012628).
- bpf: Move off_reg into sanitize_ptr_alu (bsc#1012628).
- bpf: Ensure off_reg has no mixed signed bounds for all types
  (bsc#1012628).
- r8169: don't advertise pause in jumbo mode (bsc#1012628).
- r8169: tweak max read request size for newer chips also in
  jumbo mtu mode (bsc#1012628).
- kasan: remove redundant config option (bsc#1012628).
- kasan: fix hwasan build for gcc (bsc#1012628).
- KVM: VMX: Don't use vcpu->run->internal.ndata as an array index
  (bsc#1012628).
- KVM: VMX: Convert vcpu_vmx.exit_reason to a union (bsc#1012628).
- bpf: Use correct permission flag for mixed signed bounds
  arithmetic (bsc#1012628).
- arm64: dts: allwinner: h6: beelink-gs1: Remove ext. 32 kHz
  osc reference (bsc#1012628).
- arm64: dts: allwinner: Fix SD card CD GPIO for SOPine systems
  (bsc#1012628).
- ARM: OMAP2+: Fix uninitialized sr_inst (bsc#1012628).
- ARM: footbridge: fix PCI interrupt mapping (bsc#1012628).
- ARM: 9069/1: NOMMU: Fix conversion for_each_membock() to
  for_each_mem_range() (bsc#1012628).
- ARM: 9063/1: mm: reduce maximum number of CPUs if
  DEBUG_KMAP_LOCAL is enabled (bsc#1012628).
- ARM: OMAP2+: Fix warning for omap_init_time_of() (bsc#1012628).
- gro: ensure frag0 meets IP header alignment (bsc#1012628).
- ch_ktls: do not send snd_una update to TCB in middle
  (bsc#1012628).
- ch_ktls: tcb close causes tls connection failure (bsc#1012628).
- ch_ktls: fix device connection close (bsc#1012628).
- ch_ktls: Fix kernel panic (bsc#1012628).
- ibmvnic: remove duplicate napi_schedule call in open function
  (bsc#1012628).
- ibmvnic: remove duplicate napi_schedule call in do_reset
  function (bsc#1012628).
- ibmvnic: avoid calling napi_disable() twice (bsc#1012628).
- ia64: tools: remove inclusion of ia64-specific version of
  errno.h header (bsc#1012628).
- ia64: remove duplicate entries in generic_defconfig
  (bsc#1012628).
- ethtool: pause: make sure we init driver stats (bsc#1012628).
- i40e: fix the panic when running bpf in xdpdrv mode
  (bsc#1012628).
- ibmvnic: correctly use dev_consume/free_skb_irq (bsc#1012628).
- net: Make tcp_allowed_congestion_control readonly in non-init
  netns (bsc#1012628).
- mm: ptdump: fix build failure (bsc#1012628).
- net: ip6_tunnel: Unregister catch-all devices (bsc#1012628).
- net: sit: Unregister catch-all devices (bsc#1012628).
- net: phy: marvell: fix detection of PHY on Topaz switches
  (bsc#1012628).
- net: davicom: Fix regulator not turned off on failed probe
  (bsc#1012628).
- net/mlx5e: Fix setting of RS FEC mode (bsc#1012628).
- netfilter: nftables: clone set element expression template
  (bsc#1012628).
- netfilter: nft_limit: avoid possible divide error in
  nft_limit_init (bsc#1012628).
- net/mlx5e: fix ingress_ifindex check in mlx5e_flower_parse_meta
  (bsc#1012628).
- net: macb: fix the restore of cmp registers (bsc#1012628).
- drm/i915/display/vlv_dsi: Do not skip panel_pwr_cycle_delay
  when disabling the panel (bsc#1012628).
- libbpf: Fix potential NULL pointer dereference (bsc#1012628).
- netfilter: arp_tables: add pre_exit hook for table unregister
  (bsc#1012628).
- netfilter: bridge: add pre_exit hooks for ebtable unregistration
  (bsc#1012628).
- libnvdimm/region: Fix nvdimm_has_flush() to handle
  ND_REGION_ASYNC (bsc#1012628).
- ice: Fix potential infinite loop when using u8 loop counter
  (bsc#1012628).
- netfilter: conntrack: do not print icmpv6 as unknown via /proc
  (bsc#1012628).
- netfilter: flowtable: fix NAT IPv6 offload mangling
  (bsc#1012628).
- ixgbe: fix unbalanced device enable/disable in suspend/resume
  (bsc#1012628).
- ixgbe: Fix NULL pointer dereference in ethtool loopback test
  (bsc#1012628).
- drm/vmwgfx: Make sure we unpin no longer needed buffers
  (bsc#1012628).
- scsi: libsas: Reset num_scatter if libata marks qc as NODATA
  (bsc#1012628).
- riscv: Fix spelling mistake "SPARSEMEM" to "SPARSMEM"
  (bsc#1012628).
- vfio/pci: Add missing range check in vfio_pci_mmap
  (bsc#1012628).
- arm64: alternatives: Move length validation in
  alternative_{insn, endif} (bsc#1012628).
- arm64: mte: Ensure TIF_MTE_ASYNC_FAULT is set atomically
  (bsc#1012628).
- Update config files.
- arm64: fix inline asm in load_unaligned_zeropad() (bsc#1012628).
- drm/i915: Don't zero out the Y plane's watermarks (bsc#1012628).
- readdir: make sure to verify directory entry for legacy
  interfaces too (bsc#1012628).
- dm verity fec: fix misaligned RS roots IO (bsc#1012628).
- HID: wacom: set EV_KEY and EV_ABS only for non-HID_GENERIC
  type of devices (bsc#1012628).
- Input: i8042 - fix Pegatron C15B ID entry (bsc#1012628).
- Input: s6sy761 - fix coordinate read bit shift (bsc#1012628).
- net/sctp: fix race condition in sctp_destroy_sock (bsc#1012628).
- lib: fix kconfig dependency on ARCH_WANT_FRAME_POINTERS
  (bsc#1012628).
- virt_wifi: Return micros for BSS TSF values (bsc#1012628).
- mac80211: clear sta->fast_rx when STA removed from 4-addr VLAN
  (bsc#1012628).
- drm/amd/display: Add missing mask for DCN3 (bsc#1012628).
- pcnet32: Use pci_resource_len to validate PCI resource
  (bsc#1012628).
- net: ieee802154: forbid monitor for add llsec seclevel
  (bsc#1012628).
- net: ieee802154: stop dump llsec seclevels for monitors
  (bsc#1012628).
- net: ieee802154: forbid monitor for del llsec devkey
  (bsc#1012628).
- net: ieee802154: forbid monitor for add llsec devkey
  (bsc#1012628).
- net: ieee802154: stop dump llsec devkeys for monitors
  (bsc#1012628).
- net: ieee802154: forbid monitor for del llsec dev (bsc#1012628).
- net: ieee802154: forbid monitor for add llsec dev (bsc#1012628).
- net: ieee802154: stop dump llsec devs for monitors
  (bsc#1012628).
- net: ieee802154: forbid monitor for del llsec key (bsc#1012628).
- net: ieee802154: forbid monitor for add llsec key (bsc#1012628).
- net: ieee802154: stop dump llsec keys for monitors
  (bsc#1012628).
- iwlwifi: add support for Qu with AX201 device (bsc#1012628).
- scsi: scsi_transport_srp: Don't block target in SRP_PORT_LOST
  state (bsc#1012628).
- ASoC: fsl_esai: Fix TDM slot setup for I2S mode (bsc#1012628).
- drm/msm: Fix a5xx/a6xx timestamps (bsc#1012628).
- ARM: omap1: fix building with clang IAS (bsc#1012628).
- ARM: keystone: fix integer overflow warning (bsc#1012628).
- powerpc/signal32: Fix Oops on sigreturn with unmapped VDSO
  (bsc#1012628).
- neighbour: Disregard DEAD dst in neigh_update (bsc#1012628).
- bpf: Take module reference for trampoline in module
  (bsc#1012628).
- gpu/xen: Fix a use after free in xen_drm_drv_init (bsc#1012628).
- net: axienet: allow setups without MDIO (bsc#1012628).
- ASoC: max98373: Added 30ms turn on/off time delay (bsc#1012628).
- ASoC: max98373: Changed amp shutdown register as volatile
  (bsc#1012628).
- xfrm: BEET mode doesn't support fragments for inner packets
  (bsc#1012628).
- iwlwifi: Fix softirq/hardirq disabling in
  iwl_pcie_enqueue_hcmd() (bsc#1012628).
- arc: kernel: Return -EFAULT if copy_to_user() fails
  (bsc#1012628).
- lockdep: Add a missing initialization hint to the "INFO:
  Trying to register non-static key" message (bsc#1012628).
- remoteproc: pru: Fix loading of GNU Binutils ELF (bsc#1012628).
- ARM: dts: Fix moving mmc devices with aliases for omap4 & 5
  (bsc#1012628).
- ARM: dts: Drop duplicate sha2md5_fck to fix clk_disable race
  (bsc#1012628).
- ACPI: x86: Call acpi_boot_table_init() after
  acpi_table_upgrade() (bsc#1012628).
- dmaengine: idxd: fix wq cleanup of WQCFG registers
  (bsc#1012628).
- dmaengine: idxd: clear MSIX permission entry on shutdown
  (bsc#1012628).
- dmaengine: plx_dma: add a missing put_device() on error path
  (bsc#1012628).
- dmaengine: Fix a double free in dma_async_device_register
  (bsc#1012628).
- dmaengine: dw: Make it dependent to HAS_IOMEM (bsc#1012628).
- dmaengine: idxd: fix wq size store permission state
  (bsc#1012628).
- dmaengine: idxd: fix opcap sysfs attribute output (bsc#1012628).
- dmaengine: idxd: fix delta_rec and crc size field for completion
  record (bsc#1012628).
- dmaengine: idxd: Fix clobbering of SWERR overflow bit on
  writeback (bsc#1012628).
- gpio: sysfs: Obey valid_mask (bsc#1012628).
- Input: nspire-keypad - enable interrupts only when opened
  (bsc#1012628).
- mtd: rawnand: mtk: Fix WAITRDY break condition and timeout
  (bsc#1012628).
- AMD_SFH: Add DMI quirk table for BIOS-es which don't set the
  activestatus bits (bsc#1012628).
- AMD_SFH: Add sensor_mask module parameter (bsc#1012628).
- AMD_SFH: Removed unused activecontrolstatus member from the
  amd_mp2_dev struct (bsc#1012628).
- commit d57ad55
* Mon Apr 19 2021 mkubecek@suse.cz
- Update to 5.12-rc8
- refresh configs
- commit a71cb9a
* Fri Apr 16 2021 jslaby@suse.cz
- Linux 5.11.15 (bsc#1012628).
- net: sfp: cope with SFPs that set both LOS normal and LOS
  inverted (bsc#1012628).
- perf map: Tighten snprintf() string precision to pass gcc
  check on some 32-bit arches (bsc#1012628).
- netfilter: x_tables: fix compat match/target pad out-of-bound
  write (bsc#1012628).
- block: don't ignore REQ_NOWAIT for direct IO (bsc#1012628).
- riscv,entry: fix misaligned base for excp_vect_table
  (bsc#1012628).
- io_uring: don't mark S_ISBLK async work as unbounded
  (bsc#1012628).
- null_blk: fix command timeout completion handling (bsc#1012628).
- idr test suite: Create anchor before launching throbber
  (bsc#1012628).
- idr test suite: Take RCU read lock in idr_find_test_1
  (bsc#1012628).
- radix tree test suite: Register the main thread with the RCU
  library (bsc#1012628).
- block: only update parent bi_status when bio fail (bsc#1012628).
- radix tree test suite: Fix compilation (bsc#1012628).
- XArray: Fix splitting to non-zero orders (bsc#1012628).
- gpu: host1x: Use different lock classes for each client
  (bsc#1012628).
- drm/tegra: dc: Don't set PLL clock to 0Hz (bsc#1012628).
- tools/kvm_stat: Add restart delay (bsc#1012628).
- ftrace: Check if pages were allocated before calling
  free_pages() (bsc#1012628).
- gfs2: report "already frozen/thawed" errors (bsc#1012628).
- drm/imx: imx-ldb: fix out of bounds array access warning
  (bsc#1012628).
- KVM: arm64: Disable guest access to trace filter controls
  (bsc#1012628).
- KVM: arm64: Hide system instruction access to Trace registers
  (bsc#1012628).
- gfs2: Flag a withdraw if init_threads() fails (bsc#1012628).
- interconnect: core: fix error return code of icc_link_destroy()
  (bsc#1012628).
- commit 64fb5bf
* Wed Apr 14 2021 jslaby@suse.cz
- Linux 5.11.14 (bsc#1012628).
- xfrm/compat: Cleanup WARN()s that can be user-triggered
  (bsc#1012628).
- ALSA: aloop: Fix initialization of controls (bsc#1012628).
- ALSA: hda/realtek: Fix speaker amp setup on Acer Aspire E1
  (bsc#1012628).
- ALSA: hda/conexant: Apply quirk for another HP ZBook G5 model
  (bsc#1012628).
- file: fix close_range() for unshare+cloexec (bsc#1012628).
- ASoC: intel: atom: Stop advertising non working S24LE support
  (bsc#1012628).
- nfc: fix refcount leak in llcp_sock_bind() (bsc#1012628).
- nfc: fix refcount leak in llcp_sock_connect() (bsc#1012628).
- nfc: fix memory leak in llcp_sock_connect() (bsc#1012628).
- nfc: Avoid endless loops caused by repeated llcp_sock_connect()
  (bsc#1012628).
- selinux: make nslot handling in avtab more robust (bsc#1012628).
- selinux: fix cond_list corruption when changing booleans
  (bsc#1012628).
- selinux: fix race between old and new sidtab (bsc#1012628).
- xen/evtchn: Change irq_info lock to raw_spinlock_t
  (bsc#1012628).
- net: ipv6: check for validity before dereferencing
  cfg->fc_nlinfo.nlh (bsc#1012628).
- net: dsa: lantiq_gswip: Let GSWIP automatically set the xMII
  clock (bsc#1012628).
- net: dsa: lantiq_gswip: Don't use PHY auto polling
  (bsc#1012628).
- net: dsa: lantiq_gswip: Configure all remaining GSWIP_MII_CFG
  bits (bsc#1012628).
- ACPI: processor: Fix build when CONFIG_ACPI_PROCESSOR=m
  (bsc#1012628).
- drm/radeon: Fix size overflow (bsc#1012628).
- drm/amdgpu: Fix size overflow (bsc#1012628).
- drm/amdgpu/smu7: fix CAC setting on TOPAZ (bsc#1012628).
- rfkill: revert back to old userspace API by default
  (bsc#1012628).
- cifs: escape spaces in share names (bsc#1012628).
- cifs: On cifs_reconnect, resolve the hostname again
  (bsc#1012628).
- IB/hfi1: Fix probe time panic when AIP is enabled with a buggy
  BIOS (bsc#1012628).
- LOOKUP_MOUNTPOINT: we are cleaning "jumped" flag too late
  (bsc#1012628).
- gcov: re-fix clang-11+ support (bsc#1012628).
- ia64: fix user_stack_pointer() for ptrace() (bsc#1012628).
- nds32: flush_dcache_page: use page_mapping_file to avoid races
  with swapoff (bsc#1012628).
- ocfs2: fix deadlock between setattr and dio_end_io_write
  (bsc#1012628).
- fs: direct-io: fix missing sdio->boundary (bsc#1012628).
- ethtool: fix incorrect datatype in set_eee ops (bsc#1012628).
- of: property: fw_devlink: do not link ".*,nr-gpios"
  (bsc#1012628).
- parisc: parisc-agp requires SBA IOMMU driver (bsc#1012628).
- parisc: avoid a warning on u8 cast for cmpxchg on u8 pointers
  (bsc#1012628).
- ARM: dts: turris-omnia: configure LED[2]/INTn pin as interrupt
  pin (bsc#1012628).
- batman-adv: initialize "struct
  batadv_tvlv_tt_vlan_data"->reserved field (bsc#1012628).
- ice: Continue probe on link/PHY errors (bsc#1012628).
- ice: Increase control queue timeout (bsc#1012628).
- ice: prevent ice_open and ice_stop during reset (bsc#1012628).
- ice: fix memory allocation call (bsc#1012628).
- ice: remove DCBNL_DEVRESET bit from PF state (bsc#1012628).
- ice: Fix for dereference of NULL pointer (bsc#1012628).
- ice: Use port number instead of PF ID for WoL (bsc#1012628).
- ice: Cleanup fltr list in case of allocation issues
  (bsc#1012628).
- iwlwifi: pcie: properly set LTR workarounds on 22000 devices
  (bsc#1012628).
- ice: fix memory leak of aRFS after resuming from suspend
  (bsc#1012628).
- net: hso: fix null-ptr-deref during tty device unregistration
  (bsc#1012628).
- libbpf: Fix bail out from 'ringbuf_process_ring()' on error
  (bsc#1012628).
- bpf: Enforce that struct_ops programs be GPL-only (bsc#1012628).
- bpf: link: Refuse non-O_RDWR flags in BPF_OBJ_GET (bsc#1012628).
- ethernet/netronome/nfp: Fix a use after free in
  nfp_bpf_ctrl_msg_rx (bsc#1012628).
- libbpf: Ensure umem pointer is non-NULL before dereferencing
  (bsc#1012628).
- libbpf: Restore umem state after socket create failure
  (bsc#1012628).
- libbpf: Only create rx and tx XDP rings when necessary
  (bsc#1012628).
- bpf: Refcount task stack in bpf_get_task_stack (bsc#1012628).
- bpf, sockmap: Fix sk->prot unhash op reset (bsc#1012628).
- bpf, sockmap: Fix incorrect fwd_alloc accounting (bsc#1012628).
- net: ensure mac header is set in virtio_net_hdr_to_skb()
  (bsc#1012628).
- i40e: Fix sparse warning: missing error code 'err'
  (bsc#1012628).
- i40e: Fix sparse error: 'vsi->netdev' could be null
  (bsc#1012628).
- i40e: Fix sparse error: uninitialized symbol 'ring'
  (bsc#1012628).
- i40e: Fix sparse errors in i40e_txrx.c (bsc#1012628).
- vdpa/mlx5: Fix suspend/resume index restoration (bsc#1012628).
- net: sched: sch_teql: fix null-pointer dereference
  (bsc#1012628).
- net: sched: fix action overwrite reference counting
  (bsc#1012628).
- nl80211: fix beacon head validation (bsc#1012628).
- nl80211: fix potential leak of ACL params (bsc#1012628).
- cfg80211: check S1G beacon compat element length (bsc#1012628).
- mac80211: fix time-is-after bug in mlme (bsc#1012628).
- mac80211: fix TXQ AC confusion (bsc#1012628).
- net: hsr: Reset MAC header for Tx path (bsc#1012628).
- net-ipv6: bugfix - raw & sctp - switch to
  ipv6_can_nonlocal_bind() (bsc#1012628).
- net: let skb_orphan_partial wake-up waiters (bsc#1012628).
- thunderbolt: Fix a leak in tb_retimer_add() (bsc#1012628).
- thunderbolt: Fix off by one in tb_port_find_retimer()
  (bsc#1012628).
- usbip: add sysfs_lock to synchronize sysfs code paths
  (bsc#1012628).
- usbip: stub-dev synchronize sysfs code paths (bsc#1012628).
- usbip: vudc synchronize sysfs code paths (bsc#1012628).
- usbip: synchronize event handler with sysfs code paths
  (bsc#1012628).
- driver core: Fix locking bug in
  deferred_probe_timeout_work_func() (bsc#1012628).
- scsi: pm80xx: Fix chip initialization failure (bsc#1012628).
- scsi: target: iscsi: Fix zero tag inside a trace event
  (bsc#1012628).
- percpu: make pcpu_nr_empty_pop_pages per chunk type
  (bsc#1012628).
- i2c: turn recovery error on init to debug (bsc#1012628).
- powerpc/vdso: Make sure vdso_wrapper.o is rebuilt everytime
  vdso.so is rebuilt (bsc#1012628).
- powerpc/ptrace: Don't return error when getting/setting FP
  regs without CONFIG_PPC_FPU_REGS (bsc#1012628).
- KVM: x86/mmu: change TDP MMU yield function returns to match
  cond_resched (bsc#1012628).
- KVM: x86/mmu: Merge flush and non-flush
  tdp_mmu_iter_cond_resched (bsc#1012628).
- KVM: x86/mmu: Rename goal_gfn to next_last_level_gfn
  (bsc#1012628).
- KVM: x86/mmu: Ensure forward progress when yielding in TDP
  MMU iter (bsc#1012628).
- KVM: x86/mmu: Yield in TDU MMU iter even if no SPTES changed
  (bsc#1012628).
- KVM: x86/mmu: Ensure TLBs are flushed when yielding during
  GFN range zap (bsc#1012628).
- KVM: x86/mmu: Ensure TLBs are flushed for TDP MMU during NX
  zapping (bsc#1012628).
- KVM: x86/mmu: Don't allow TDP MMU to yield when recovering NX
  pages (bsc#1012628).
- KVM: x86/mmu: preserve pending TLB flush across calls to
  kvm_tdp_mmu_zap_sp (bsc#1012628).
- net: sched: fix err handler in tcf_action_init() (bsc#1012628).
- ice: Refactor DCB related variables out of the ice_port_info
  struct (bsc#1012628).
- ice: Recognize 860 as iSCSI port in CEE mode (bsc#1012628).
- xfrm: interface: fix ipv4 pmtu check to honor ip header df
  (bsc#1012628).
- xfrm: Use actual socket sk instead of skb socket for
  xfrm_output_resume (bsc#1012628).
- remoteproc: qcom: pil_info: avoid 64-bit division (bsc#1012628).
- regulator: bd9571mwv: Fix AVS and DVFS voltage range
  (bsc#1012628).
- ARM: OMAP4: Fix PMIC voltage domains for bionic (bsc#1012628).
- ARM: OMAP4: PM: update ROM return address for OSWR and OFF
  (bsc#1012628).
- remoteproc: pru: Fix firmware loading crashes on K3 SoCs
  (bsc#1012628).
- net: xfrm: Localize sequence counter per network namespace
  (bsc#1012628).
- esp: delete NETIF_F_SCTP_CRC bit from features for esp offload
  (bsc#1012628).
- ASoC: SOF: Intel: HDA: fix core status verification
  (bsc#1012628).
- ASoC: wm8960: Fix wrong bclk and lrclk with pll enabled for
  some chips (bsc#1012628).
- xfrm: Fix NULL pointer dereference on policy lookup
  (bsc#1012628).
- virtchnl: Fix layout of RSS structures (bsc#1012628).
- i40e: Added Asym_Pause to supported link modes (bsc#1012628).
- i40e: Fix kernel oops when i40e driver removes VF's
  (bsc#1012628).
- hostfs: fix memory handling in follow_link() (bsc#1012628).
- amd-xgbe: Update DMA coherency values (bsc#1012628).
- vxlan: do not modify the shared tunnel info when PMTU triggers
  an ICMP reply (bsc#1012628).
- geneve: do not modify the shared tunnel info when PMTU triggers
  an ICMP reply (bsc#1012628).
- sch_red: fix off-by-one checks in red_check_params()
  (bsc#1012628).
- drivers/net/wan/hdlc_fr: Fix a double free in pvc_xmit
  (bsc#1012628).
- arm64: dts: imx8mm/q: Fix pad control of SD1_DATA0
  (bsc#1012628).
- xfrm: Provide private skb extensions for segmented and hw
  offloaded ESP packets (bsc#1012628).
- can: bcm/raw: fix msg_namelen values depending on
  CAN_REQUIRED_SIZE (bsc#1012628).
- can: isotp: fix msg_namelen values depending on
  CAN_REQUIRED_SIZE (bsc#1012628).
- can: uapi: can.h: mark union inside struct can_frame packed
  (bsc#1012628).
- mlxsw: spectrum: Fix ECN marking in tunnel decapsulation
  (bsc#1012628).
- ethernet: myri10ge: Fix a use after free in myri10ge_sw_tso
  (bsc#1012628).
- gianfar: Handle error code at MAC address change (bsc#1012628).
- net: dsa: Fix type was not set for devlink port (bsc#1012628).
- clk: qcom: camcc: Update the clock ops for the SC7180
  (bsc#1012628).
- cxgb4: avoid collecting SGE_QBASE regs during traffic
  (bsc#1012628).
- net:tipc: Fix a double free in tipc_sk_mcast_rcv (bsc#1012628).
- ARM: dts: imx6: pbab01: Set vmmc supply for both SD interfaces
  (bsc#1012628).
- net/ncsi: Avoid channel_monitor hrtimer deadlock (bsc#1012628).
- net: qrtr: Fix memory leak on qrtr_tx_wait failure
  (bsc#1012628).
- nfp: flower: ignore duplicate merge hints from FW (bsc#1012628).
- net: phy: broadcom: Only advertise EEE for supported modes
  (bsc#1012628).
- I2C: JZ4780: Fix bug for Ingenic X1000 (bsc#1012628).
- ASoC: sunxi: sun4i-codec: fill ASoC card owner (bsc#1012628).
- net/mlx5e: Fix mapping of ct_label zero (bsc#1012628).
- net/mlx5: Delete auxiliary bus driver eth-rep first
  (bsc#1012628).
- net/mlx5e: Fix ethtool indication of connector type
  (bsc#1012628).
- net/mlx5: Don't request more than supported EQs (bsc#1012628).
- net/mlx5e: Guarantee room for XSK wakeup NOP on async ICOSQ
  (bsc#1012628).
- net/rds: Fix a use after free in rds_message_map_pages
  (bsc#1012628).
- xdp: fix xdp_return_frame() kernel BUG throw for page_pool
  memory model (bsc#1012628).
- soc/fsl: qbman: fix conflicting alignment attributes
  (bsc#1012628).
- i40e: fix receiving of single packets in xsk zero-copy mode
  (bsc#1012628).
- i40e: Fix display statistics for veb_tc (bsc#1012628).
- RDMA/rtrs-clt: Close rtrs client conn before destroying rtrs
  clt session files (bsc#1012628).
- drm/msm: Set drvdata to NULL when msm_drm_init() fails
  (bsc#1012628).
- net: udp: Add support for getsockopt(..., ..., UDP_GRO, ...,
  ...); (bsc#1012628).
- mptcp: forbit mcast-related sockopt on MPTCP sockets
  (bsc#1012628).
- mptcp: revert "mptcp: provide subflow aware release function"
  (bsc#1012628).
- scsi: ufs: core: Fix task management request completion timeout
  (bsc#1012628).
- scsi: ufs: core: Fix wrong Task Tag used in task management
  request UPIUs (bsc#1012628).
- drm/msm/disp/dpu1: program 3d_merge only if block is attached
  (bsc#1012628).
- Revert "arm64: dts: marvell: armada-cp110: Switch to per-port
  SATA interrupts" (bsc#1012628).
- ARM: dts: turris-omnia: fix hardware buffer management
  (bsc#1012628).
- net: cls_api: Fix uninitialised struct field
  bo->unlocked_driver_cb (bsc#1012628).
- net: macb: restore cmp registers on resume path (bsc#1012628).
- clk: fix invalid usage of list cursor in register (bsc#1012628).
- clk: fix invalid usage of list cursor in unregister
  (bsc#1012628).
- workqueue: Move the position of debug_work_activate() in
  __queue_work() (bsc#1012628).
- s390/cpcmd: fix inline assembly register clobbering
  (bsc#1012628).
- perf inject: Fix repipe usage (bsc#1012628).
- openvswitch: fix send of uninitialized stack memory in ct
  limit reply (bsc#1012628).
- i2c: designware: Adjust bus_freq_hz when refuse high speed
  mode set (bsc#1012628).
- iwlwifi: fix 11ax disabled bit in the regulatory capability
  flags (bsc#1012628).
- can: mcp251x: fix support for half duplex SPI host controllers
  (bsc#1012628).
- platform/x86: intel-hid: Fix spurious wakeups caused by
  tablet-mode events during suspend (bsc#1012628).
- tipc: increment the tmp aead refcnt before attaching it
  (bsc#1012628).
- net: hns3: clear VF down state bit before request link status
  (bsc#1012628).
- net/mlx5: Fix HW spec violation configuring uplink
  (bsc#1012628).
- net/mlx5: Fix placement of log_max_flow_counter (bsc#1012628).
- net/mlx5: Fix PPLM register mapping (bsc#1012628).
- net/mlx5: Fix PBMC register mapping (bsc#1012628).
- RDMA/cxgb4: check for ipv6 address properly while destroying
  listener (bsc#1012628).
- perf report: Fix wrong LBR block sorting (bsc#1012628).
- RDMA/qedr: Fix kernel panic when trying to access recv_cq
  (bsc#1012628).
- drm/vc4: crtc: Reduce PV fifo threshold on hvs4 (bsc#1012628).
- i40e: Fix parameters in aq_get_phy_register() (bsc#1012628).
- RDMA/addr: Be strict with gid size (bsc#1012628).
- vdpa/mlx5: should exclude header length and fcs from mtu
  (bsc#1012628).
- vdpa/mlx5: Fix wrong use of bit numbers (bsc#1012628).
- RAS/CEC: Correct ce_add_elem()'s returned values (bsc#1012628).
- clk: socfpga: fix iomem pointer cast on 64-bit (bsc#1012628).
- lockdep: Address clang -Wformat warning printing for %%hd
  (bsc#1012628).
- dt-bindings: net: ethernet-controller: fix typo in NVMEM
  (bsc#1012628).
- net: sched: bump refcount for new action in ACT replace mode
  (bsc#1012628).
- x86/traps: Correct exc_general_protection() and math_error()
  return paths (bsc#1012628).
- gpiolib: Read "gpio-line-names" from a firmware node
  (bsc#1012628).
- cfg80211: remove WARN_ON() in cfg80211_sme_connect
  (bsc#1012628).
- net: tun: set tun->dev->addr_len during TUNSETLINK processing
  (bsc#1012628).
- drivers: net: fix memory leak in atusb_probe (bsc#1012628).
- drivers: net: fix memory leak in peak_usb_create_dev
  (bsc#1012628).
- net: mac802154: Fix general protection fault (bsc#1012628).
- net: ieee802154: nl-mac: fix check on panid (bsc#1012628).
- net: ieee802154: fix nl802154 del llsec key (bsc#1012628).
- net: ieee802154: fix nl802154 del llsec dev (bsc#1012628).
- net: ieee802154: fix nl802154 add llsec key (bsc#1012628).
- net: ieee802154: fix nl802154 del llsec devkey (bsc#1012628).
- net: ieee802154: forbid monitor for set llsec params
  (bsc#1012628).
- net: ieee802154: forbid monitor for del llsec seclevel
  (bsc#1012628).
- net: ieee802154: stop dump llsec params for monitors
  (bsc#1012628).
- Revert "net: sched: bump refcount for new action in ACT replace
  mode" (bsc#1012628).
- commit f68b7e1
* Wed Apr 14 2021 jslaby@suse.cz
- rpm/check-for-config-changes: remove stale comment
  It is stale since 8ab393bf905a committed in 2005 :).
- commit c9f9f5a
* Tue Apr 13 2021 tiwai@suse.de
- rpm/mkspec: Use tilde instead of dot for version string with rc (bsc#1184650)
- commit f37613f
* Mon Apr 12 2021 tiwai@suse.de
- rpm/kernel-binary.spec.in: Fix dependency of kernel-*-devel package (bsc#1184514)
  The devel package requires the kernel binary package itself for building
  modules externally.
- commit 794be7b
* Mon Apr 12 2021 mkubecek@suse.cz
- Update to 5.12-rc7
- commit bd61ada
* Sun Apr 11 2021 jslaby@suse.cz
- drm/msm: a6xx: fix version check for the A650 SQE microcode
  (git-fixes).
- commit b15020c
* Sun Apr 11 2021 jslaby@suse.cz
- Linux 5.11.13 (bsc#1012628).
- init/Kconfig: make COMPILE_TEST depend on HAS_IOMEM
  (bsc#1012628).
- Update config files.
- bpf, x86: Validate computation of branch displacements for
  x86-32 (bsc#1012628).
- bpf, x86: Validate computation of branch displacements for
  x86-64 (bsc#1012628).
- tools/resolve_btfids: Add /libbpf to .gitignore (bsc#1012628).
- kbuild: Do not clean resolve_btfids if the output does not exist
  (bsc#1012628).
- kbuild: Add resolve_btfids clean to root clean target
  (bsc#1012628).
- tools/resolve_btfids: Set srctree variable unconditionally
  (bsc#1012628).
- tools/resolve_btfids: Check objects before removing
  (bsc#1012628).
- tools/resolve_btfids: Build libbpf and libsubcmd in separate
  directories (bsc#1012628).
- math: Export mul_u64_u64_div_u64 (bsc#1012628).
- io_uring: fix timeout cancel return code (bsc#1012628).
- cifs: Silently ignore unknown oplock break handle (bsc#1012628).
- cifs: revalidate mapping when we open files for SMB1 POSIX
  (bsc#1012628).
- ia64: fix format strings for err_inject (bsc#1012628).
- ia64: mca: allocate early mca with GFP_ATOMIC (bsc#1012628).
- selftests/vm: fix out-of-tree build (bsc#1012628).
- arm64: kernel: disable CNP on Carmel (bsc#1012628).
- Update config files.
- scsi: target: pscsi: Clean up after failure in pscsi_map_sg()
  (bsc#1012628).
- ptp_qoriq: fix overflow in ptp_qoriq_adjfine() u64 calcalation
  (bsc#1012628).
- platform/x86: intel_pmc_core: Ignore GBE LTR on Tiger Lake
  platforms (bsc#1012628).
- platform/x86: intel_pmt_class: Initial resource to 0
  (bsc#1012628).
- block: clear GD_NEED_PART_SCAN later in bdev_disk_changed
  (bsc#1012628).
- x86/build: Turn off -fcf-protection for realmode targets
  (bsc#1012628).
- drm/msm/disp/dpu1: icc path needs to be set before dpu runtime
  resume (bsc#1012628).
- kselftest/arm64: sve: Do not use non-canonical FFR register
  value (bsc#1012628).
- platform/x86: thinkpad_acpi: Allow the FnLock LED to change
  state (bsc#1012628).
- net: ipa: fix init header command validation (bsc#1012628).
- netfilter: nftables: skip hook overlap logic if flowtable is
  stale (bsc#1012628).
- netfilter: conntrack: Fix gre tunneling over ipv6 (bsc#1012628).
- drm/msm: Ratelimit invalid-fence message (bsc#1012628).
- drm/msm/adreno: a5xx_power: Don't apply A540 lm_setup to other
  GPUs (bsc#1012628).
- drm/msm/dsi_pll_7nm: Fix variable usage for pll_lockdet_rate
  (bsc#1012628).
- mac80211: choose first enabled channel for monitor
  (bsc#1012628).
- mac80211: Check crypto_aead_encrypt for errors (bsc#1012628).
- can: kvaser_usb: Add support for USBcan Pro 4xHS (bsc#1012628).
- net: arcnet: com20020 fix error handling (bsc#1012628).
- mISDN: fix crash in fritzpci (bsc#1012628).
- kunit: tool: Fix a python tuple typing error (bsc#1012628).
- net: pxa168_eth: Fix a potential data race in pxa168_eth_remove
  (bsc#1012628).
- net/mlx5e: Enforce minimum value check for ICOSQ size
  (bsc#1012628).
- bpf, x86: Use kvmalloc_array instead kmalloc_array in
  bpf_jit_comp (bsc#1012628).
- platform/x86: intel-hid: Support Lenovo ThinkPad X1 Tablet Gen 2
  (bsc#1012628).
- drm/msm: a6xx: Make sure the SQE microcode is safe
  (bsc#1012628).
- bus: ti-sysc: Fix warning on unbind if reset is not deasserted
  (bsc#1012628).
- ARM: dts: am33xx: add aliases for mmc interfaces (bsc#1012628).
- commit 0ea11a6
* Fri Apr  9 2021 msuchanek@suse.de
- Add obsolete_rebuilds_subpackage (boo#1172073 bsc#1191731).
- commit f037781
* Fri Apr  9 2021 msuchanek@suse.de
- rpm/check-for-config-changes: Also ignore AS_VERSION added in 5.12.
- commit bd64cb2
* Fri Apr  9 2021 msuchanek@suse.de
- post.sh: Return an error when module update fails (bsc#1047233 bsc#1184388).
- commit 18f65df
* Fri Apr  9 2021 jslaby@suse.cz
- Update
  patches.kernel.org/5.11.9-100-perf-x86-intel-Fix-a-crash-caused-by-zero-PEBS.patch
  (bsc#1012628 CVE-2021-28971 bsc#1184196).
  Add a CVE reference.
- commit 1b6b086
* Wed Apr  7 2021 jslaby@suse.cz
- Linux 5.11.12 (bsc#1012628).
- arm64: mm: correct the inside linear map range during hotplug
  check (bsc#1012628).
- virtiofs: Fail dax mount if device does not support it
  (bsc#1012628).
- ext4: shrink race window in ext4_should_retry_alloc()
  (bsc#1012628).
- ext4: fix bh ref count on error paths (bsc#1012628).
- fs: nfsd: fix kconfig dependency warning for NFSD_V4
  (bsc#1012628).
- rpc: fix NULL dereference on kmalloc failure (bsc#1012628).
- iomap: Fix negative assignment to unsigned sis->pages in
  iomap_swapfile_activate (bsc#1012628).
- ASoC: rt1015: fix i2c communication error (bsc#1012628).
- ASoC: rt5640: Fix dac- and adc- vol-tlv values being off by
  a factor of 10 (bsc#1012628).
- ASoC: rt5651: Fix dac- and adc- vol-tlv values being off by
  a factor of 10 (bsc#1012628).
- ASoC: sgtl5000: set DAP_AVC_CTRL register to correct default
  value on probe (bsc#1012628).
- ASoC: es8316: Simplify adc_pga_gain_tlv table (bsc#1012628).
- ASoC: soc-core: Prevent warning if no DMI table is present
  (bsc#1012628).
- ASoC: cs42l42: Fix Bitclock polarity inversion (bsc#1012628).
- ASoC: cs42l42: Fix channel width support (bsc#1012628).
- ASoC: cs42l42: Fix mixer volume control (bsc#1012628).
- ASoC: cs42l42: Always wait at least 3ms after reset
  (bsc#1012628).
- NFSD: fix error handling in NFSv4.0 callbacks (bsc#1012628).
- ASoC: mediatek: mt8192: fix tdm out data is valid on rising edge
  (bsc#1012628).
- kernel: freezer should treat PF_IO_WORKER like PF_KTHREAD for
  freezing (bsc#1012628).
- vhost: Fix vhost_vq_reset() (bsc#1012628).
- io_uring: fix ->flags races by linked timeouts (bsc#1012628).
- io_uring: halt SQO submission on ctx exit (bsc#1012628).
- scsi: st: Fix a use after free in st_open() (bsc#1012628).
- scsi: qla2xxx: Fix broken #endif placement (bsc#1012628).
- staging: comedi: cb_pcidas: fix request_irq() warn
  (bsc#1012628).
- staging: comedi: cb_pcidas64: fix request_irq() warn
  (bsc#1012628).
- ASoC: rt5659: Update MCLK rate in set_sysclk() (bsc#1012628).
- ASoC: rt711: add snd_soc_component remove callback
  (bsc#1012628).
- thermal/core: Add NULL pointer check before using cooling
  device stats (bsc#1012628).
- locking/ww_mutex: Simplify use_ww_ctx & ww_ctx handling
  (bsc#1012628).
- locking/ww_mutex: Fix acquire/release imbalance in
  ww_acquire_init()/ww_acquire_fini() (bsc#1012628).
- nvmet-tcp: fix kmap leak when data digest in use (bsc#1012628).
- io_uring: imply MSG_NOSIGNAL for send[msg]()/recv[msg]() calls
  (bsc#1012628).
- Revert "PM: ACPI: reboot: Use S5 for reboot" (bsc#1012628).
- nouveau: Skip unvailable ttm page entries (bsc#1012628).
- static_call: Align static_call_is_init() patching condition
  (bsc#1012628).
- ext4: do not iput inode under running transaction in
  ext4_rename() (bsc#1012628).
- io_uring: call req_set_fail_links() on short
  send[msg]()/recv[msg]() with MSG_WAITALL (bsc#1012628).
- net: mvpp2: fix interrupt mask/unmask skip condition
  (bsc#1012628).
- mptcp: deliver ssk errors to msk (bsc#1012628).
- mptcp: fix poll after shutdown (bsc#1012628).
- mptcp: init mptcp request socket earlier (bsc#1012628).
- mptcp: add a missing retransmission timer scheduling
  (bsc#1012628).
- flow_dissector: fix TTL and TOS dissection on IPv4 fragments
  (bsc#1012628).
- mptcp: fix DATA_FIN processing for orphaned sockets
  (bsc#1012628).
- mptcp: provide subflow aware release function (bsc#1012628).
- can: dev: move driver related infrastructure into separate
  subdir (bsc#1012628).
- net: introduce CAN specific pointer in the struct net_device
  (bsc#1012628).
- mptcp: fix race in release_cb (bsc#1012628).
- net: bonding: fix error return code of bond_neigh_init()
  (bsc#1012628).
- mptcp: fix bit MPTCP_PUSH_PENDING tests (bsc#1012628).
- can: tcan4x5x: fix max register value (bsc#1012628).
- brcmfmac: clear EAP/association status bits on linkdown events
  (bsc#1012628).
- ath11k: add ieee80211_unregister_hw to avoid kernel crash
  caused by NULL pointer (bsc#1012628).
- rtw88: coex: 8821c: correct antenna switch function
  (bsc#1012628).
- netdevsim: dev: Initialize FIB module after debugfs
  (bsc#1012628).
- iwlwifi: pcie: don't disable interrupts for reg_lock
  (bsc#1012628).
- ath10k: hold RCU lock when calling
  ieee80211_find_sta_by_ifaddr() (bsc#1012628).
- net: ethernet: aquantia: Handle error cleanup of start on open
  (bsc#1012628).
- appletalk: Fix skb allocation size in loopback case
  (bsc#1012628).
- net: ipa: remove two unused register definitions (bsc#1012628).
- net: ipa: use a separate pointer for adjusted GSI memory
  (bsc#1012628).
- net: ipa: fix register write command validation (bsc#1012628).
- net: wan/lmc: unregister device when no matching device is found
  (bsc#1012628).
- net: 9p: advance iov on empty read (bsc#1012628).
- bpf: Remove MTU check in __bpf_skb_max_len (bsc#1012628).
- ACPI: tables: x86: Reserve memory occupied by ACPI tables
  (bsc#1012628).
- ACPI: processor: Fix CPU0 wakeup in acpi_idle_play_dead()
  (bsc#1012628).
- ACPI: scan: Fix _STA getting called on devices with unmet
  dependencies (bsc#1012628).
- ALSA: usb-audio: Apply sample rate quirk to Logitech Connect
  (bsc#1012628).
- ALSA: hda: Re-add dropped snd_poewr_change_state() calls
  (bsc#1012628).
- ALSA: hda: Add missing sanity checks in PM prepare/complete
  callbacks (bsc#1012628).
- ALSA: hda/realtek: fix a determine_headset_type issue for a
  Dell AIO (bsc#1012628).
- ALSA: hda/realtek: call alc_update_headset_mode() in
  hp_automute_hook (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP 640 G8
  (bsc#1012628).
- xtensa: fix uaccess-related livelock in do_page_fault
  (bsc#1012628).
- xtensa: move coprocessor_flush to the .text section
  (bsc#1012628).
- KVM: SVM: load control fields from VMCB12 before checking them
  (bsc#1012628).
- KVM: SVM: ensure that EFER.SVME is set when running nested
  guest or on nested vmexit (bsc#1012628).
- PM: runtime: Fix race getting/putting suppliers at probe
  (bsc#1012628).
- PM: runtime: Fix ordering in pm_runtime_get_suppliers()
  (bsc#1012628).
- tracing: Fix stack trace event size (bsc#1012628).
- s390/vdso: copy tod_steering_delta value to vdso_data page
  (bsc#1012628).
- s390/vdso: fix tod_steering_delta type (bsc#1012628).
- drm/ttm: make ttm_bo_unpin more defensive (bsc#1012628).
- mm: fix race by making init_zero_pfn() early_initcall
  (bsc#1012628).
- drm/amdkfd: dqm fence memory corruption (bsc#1012628).
- drm/amd/pm: no need to force MCLK to highest when no display
  connected (bsc#1012628).
- drm/amdgpu/vangogh: don't check for dpm in is_dpm_running when
  in suspend (bsc#1012628).
- drm/amdgpu: fix offset calculation in
  amdgpu_vm_bo_clear_mappings() (bsc#1012628).
- drm/amdgpu: Set a suitable dev_info.gart_page_size
  (bsc#1012628).
- drm/amdgpu: check alignment on CPU page for bo map
  (bsc#1012628).
- reiserfs: update reiserfs_xattrs_initialized() condition
  (bsc#1012628).
- drm/imx: fix memory leak when fails to init (bsc#1012628).
- drm/tegra: dc: Restore coupling of display controllers
  (bsc#1012628).
- drm/tegra: sor: Grab runtime PM reference across reset
  (bsc#1012628).
- vfio/nvlink: Add missing SPAPR_TCE_IOMMU depends (bsc#1012628).
- pinctrl: microchip-sgpio: Fix wrong register offset for IRQ
  trigger (bsc#1012628).
- pinctrl: rockchip: fix restore error in resume (bsc#1012628).
- pinctrl: qcom: sc7280: Fix SDC_QDSD_PINGROUP and UFS_RESET
  offsets (bsc#1012628).
- pinctrl: qcom: sc7280: Fix SDC1_RCLK configurations
  (bsc#1012628).
- pinctrl: qcom: lpass lpi: use default pullup/strength values
  (bsc#1012628).
- pinctrl: qcom: fix unintentional string concatenation
  (bsc#1012628).
- extcon: Add stubs for extcon_register_notifier_all() functions
  (bsc#1012628).
- extcon: Fix error handling in extcon_dev_register (bsc#1012628).
- firmware: stratix10-svc: reset COMMAND_RECONFIG_FLAG_PARTIAL
  to 0 (bsc#1012628).
- powerpc/pseries/mobility: use struct for shared state
  (bsc#1012628).
- powerpc/pseries/mobility: handle premature return from H_JOIN
  (bsc#1012628).
- usb: dwc3: pci: Enable dis_uX_susphy_quirk for Intel Merrifield
  (bsc#1012628).
- video: hyperv_fb: Fix a double free in hvfb_probe (bsc#1012628).
- powerpc/mm/book3s64: Use the correct storage key value when
  calling H_PROTECT (bsc#1012628).
- usbip: vhci_hcd fix shift out-of-bounds in vhci_hub_control()
  (bsc#1012628).
- USB: quirks: ignore remote wake-up on Fibocom L850-GL LTE modem
  (bsc#1012628).
- usb: musb: Fix suspend with devices connected for a64
  (bsc#1012628).
- usb: xhci-mtk: fix broken streams issue on 0.96 xHCI
  (bsc#1012628).
- cdc-acm: fix BREAK rx code path adding necessary calls
  (bsc#1012628).
- USB: cdc-acm: untangle a circular dependency between callback
  and softint (bsc#1012628).
- USB: cdc-acm: downgrade message to debug (bsc#1012628).
- USB: cdc-acm: fix double free on probe failure (bsc#1012628).
- USB: cdc-acm: fix use-after-free after probe failure
  (bsc#1012628).
- usb: gadget: udc: amd5536udc_pci fix null-ptr-dereference
  (bsc#1012628).
- usb: dwc2: Fix HPRT0.PrtSusp bit setting for HiKey 960 board
  (bsc#1012628).
- usb: dwc2: Prevent core suspend when port connection flag is 0
  (bsc#1012628).
- usb: dwc3: qcom: skip interconnect init for ACPI probe
  (bsc#1012628).
- usb: dwc3: gadget: Clear DEP flags after stop transfers in ep
  disable (bsc#1012628).
- soc: qcom-geni-se: Cleanup the code to remove proxy votes
  (bsc#1012628).
- staging: rtl8192e: Fix incorrect source in memcpy()
  (bsc#1012628).
- staging: rtl8192e: Change state information from u16 to u8
  (bsc#1012628).
- driver core: clear deferred probe reason on probe retry
  (bsc#1012628).
- drivers: video: fbcon: fix NULL dereference in fbcon_cursor()
  (bsc#1012628).
- riscv: evaluate put_user() arg before enabling user access
  (bsc#1012628).
- io_uring: do ctx sqd ejection in a clear context (bsc#1012628).
- Revert "kernel: freezer should treat PF_IO_WORKER like
  PF_KTHREAD for freezing" (bsc#1012628).
- Revert "net: bonding: fix error return code of
  bond_neigh_init()" (bsc#1012628).
- commit 92a542e
* Wed Apr  7 2021 dmueller@suse.com
- config.conf: reenable armv6/armv7 configs
  (all modules, otherwise same settings like arm64)
- commit d115d63
* Wed Apr  7 2021 dmueller@suse.com
- arm64: add debug config with KASAN enabled (bsc#1183716)
- commit b68cba9
* Tue Apr  6 2021 tiwai@suse.de
- firewire: nosy: Fix a use-after-free bug in nosy_ioctl()
  (CVE-2021-3483 bsc#1184393).
- commit c90d8a9
* Tue Apr  6 2021 tiwai@suse.de
- drm/i915: Fix invalid access to ACPI _DSM objects (bsc#1184074).
- commit 6dbaa20
* Tue Apr  6 2021 dmueller@suse.com
- arm64: enable and update config for 5.12
- commit 0a5586c
* Mon Apr  5 2021 mkubecek@suse.cz
- Update to 5.12-rc6
- commit b5f88e6
* Tue Mar 30 2021 jslaby@suse.cz
- Linux 5.11.11 (bsc#1012628).
- mt76: fix tx skb error handling in mt76_dma_tx_queue_skb
  (bsc#1012628).
- mt76: mt7915: only modify tx buffer list after allocating tx
  token id (bsc#1012628).
- net: stmmac: fix dma physical address of descriptor when
  display ring (bsc#1012628).
- net: fec: ptp: avoid register access when ipg clock is disabled
  (bsc#1012628).
- powerpc/4xx: Fix build errors from mfdcr() (bsc#1012628).
- atm: eni: dont release is never initialized (bsc#1012628).
- atm: lanai: dont run lanai_dev_close if not open (bsc#1012628).
- Revert "r8152: adjust the settings about MAC clock speed down
  for RTL8153" (bsc#1012628).
- ALSA: hda: ignore invalid NHLT table (bsc#1012628).
- ixgbe: Fix memleak in ixgbe_configure_clsu32 (bsc#1012628).
- scsi: ufs: ufs-qcom: Disable interrupt in reset path
  (bsc#1012628).
- blk-cgroup: Fix the recursive blkg rwstat (bsc#1012628).
- net: tehuti: fix error return code in bdx_probe() (bsc#1012628).
- net: intel: iavf: fix error return code of
  iavf_init_get_resources() (bsc#1012628).
- sun/niu: fix wrong RXMAC_BC_FRM_CNT_COUNT count (bsc#1012628).
- gianfar: fix jumbo packets+napi+rx overrun crash (bsc#1012628).
- cifs: ask for more credit on async read/write code paths
  (bsc#1012628).
- gfs2: fix use-after-free in trans_drain (bsc#1012628).
- cpufreq: blacklist Arm Vexpress platforms in cpufreq-dt-platdev
  (bsc#1012628).
- gpiolib: acpi: Add missing IRQF_ONESHOT (bsc#1012628).
- nfs: fix PNFS_FLEXFILE_LAYOUT Kconfig default (bsc#1012628).
- NFS: Correct size calculation for create reply length
  (bsc#1012628).
- net: hisilicon: hns: fix error return code of
  hns_nic_clear_all_rx_fetch() (bsc#1012628).
- net: wan: fix error return code of uhdlc_init() (bsc#1012628).
- net: davicom: Use platform_get_irq_optional() (bsc#1012628).
- net: enetc: set MAC RX FIFO to recommended value (bsc#1012628).
- atm: uPD98402: fix incorrect allocation (bsc#1012628).
- atm: idt77252: fix null-ptr-dereference (bsc#1012628).
- cifs: change noisy error message to FYI (bsc#1012628).
- irqchip/ingenic: Add support for the JZ4760 (bsc#1012628).
- kbuild: add image_name to no-sync-config-targets (bsc#1012628).
- umem: fix error return code in mm_pci_probe() (bsc#1012628).
- sparc64: Fix opcode filtering in handling of no fault loads
  (bsc#1012628).
- habanalabs: Call put_pid() when releasing control device
  (bsc#1012628).
- habanalabs: Disable file operations after device is removed
  (bsc#1012628).
- staging: rtl8192e: fix kconfig dependency on CRYPTO
  (bsc#1012628).
- u64_stats,lockdep: Fix u64_stats_init() vs lockdep
  (bsc#1012628).
- kselftest: arm64: Fix exit code of sve-ptrace (bsc#1012628).
- regulator: qcom-rpmh: Correct the pmic5_hfsmps515 buck
  (bsc#1012628).
- regulator: qcom-rpmh: Use correct buck for S1C regulator
  (bsc#1012628).
- block: Fix REQ_OP_ZONE_RESET_ALL handling (bsc#1012628).
- drm/amd/display: Enable pflip interrupt upon pipe enable
  (bsc#1012628).
- drm/amd/display: Enabled pipe harvesting in dcn30 (bsc#1012628).
- drm/amdgpu/display: Use wm_table.entries for dcn301 calculate_wm
  (bsc#1012628).
- drm/amdgpu: fb BO should be ttm_bo_type_device (bsc#1012628).
- drm/radeon: fix AGP dependency (bsc#1012628).
- nvme: simplify error logic in nvme_validate_ns() (bsc#1012628).
- nvme: add NVME_REQ_CANCELLED flag in nvme_cancel_request()
  (bsc#1012628).
- nvme-fc: set NVME_REQ_CANCELLED in nvme_fc_terminate_exchange()
  (bsc#1012628).
- nvme-fc: return NVME_SC_HOST_ABORTED_CMD when a command has
  been aborted (bsc#1012628).
- nvme-core: check ctrl css before setting up zns (bsc#1012628).
- nvme-rdma: Fix a use after free in nvmet_rdma_write_data_done
  (bsc#1012628).
- nvme-pci: add the DISABLE_WRITE_ZEROES quirk for a Samsung
  PM1725a (bsc#1012628).
- nfs: we don't support removing system.nfs4_acl (bsc#1012628).
- block: Suppress uevent for hidden device when removed
  (bsc#1012628).
- io_uring: cancel deferred requests in try_cancel (bsc#1012628).
- mm/fork: clear PASID for new mm (bsc#1012628).
- ia64: fix ia64_syscall_get_set_arguments() for break-based
  syscalls (bsc#1012628).
- ia64: fix ptrace(PTRACE_SYSCALL_INFO_EXIT) sign (bsc#1012628).
- static_call: Pull some static_call declarations to the type
  headers (bsc#1012628).
- static_call: Allow module use without exposing static_call_key
  (bsc#1012628).
- static_call: Fix the module key fixup (bsc#1012628).
- static_call: Fix static_call_set_init() (bsc#1012628).
- KVM: x86: Protect userspace MSR filter with SRCU, and set
  atomically-ish (bsc#1012628).
- btrfs: do not initialize dev stats if we have no dev_root
  (bsc#1012628).
- btrfs: do not initialize dev replace for bad dev root
  (bsc#1012628).
- btrfs: fix check_data_csum() error message for direct I/O
  (bsc#1012628).
- btrfs: initialize device::fs_info always (bsc#1012628).
- btrfs: fix sleep while in non-sleep context during qgroup
  removal (bsc#1012628).
- btrfs: fix subvolume/snapshot deletion not triggered on mount
  (bsc#1012628).
- selinux: don't log MAC_POLICY_LOAD record on failed policy load
  (bsc#1012628).
- selinux: fix variable scope issue in live sidtab conversion
  (bsc#1012628).
- netsec: restore phy power state after controller reset
  (bsc#1012628).
- platform/x86: intel-vbtn: Stop reporting SW_DOCK events
  (bsc#1012628).
- psample: Fix user API breakage (bsc#1012628).
- z3fold: prevent reclaim/free race for headless pages
  (bsc#1012628).
- squashfs: fix inode lookup sanity checks (bsc#1012628).
- squashfs: fix xattr id and id lookup sanity checks
  (bsc#1012628).
- hugetlb_cgroup: fix imbalanced css_get and css_put pair for
  shared mappings (bsc#1012628).
- kasan: fix per-page tags for non-page_alloc pages (bsc#1012628).
- gcov: fix clang-11+ support (bsc#1012628).
- mm/highmem: fix CONFIG_DEBUG_KMAP_LOCAL_FORCE_MAP (bsc#1012628).
- ACPI: video: Add missing callback back for Sony VPCEH3U1E
  (bsc#1012628).
- ACPICA: Always create namespace nodes using
  acpi_ns_create_node() (bsc#1012628).
- arm64: stacktrace: don't trace arch_stack_walk() (bsc#1012628).
- arm64: dts: ls1046a: mark crypto engine dma coherent
  (bsc#1012628).
- arm64: dts: ls1012a: mark crypto engine dma coherent
  (bsc#1012628).
- arm64: dts: ls1043a: mark crypto engine dma coherent
  (bsc#1012628).
- ARM: dts: at91: sam9x60: fix mux-mask for PA7 so it can be
  set to A, B and C (bsc#1012628).
- ARM: dts: at91: sam9x60: fix mux-mask to match product's
  datasheet (bsc#1012628).
- ARM: dts: at91-sama5d27_som1: fix phy address to 7
  (bsc#1012628).
- integrity: double check iint_cache was initialized
  (bsc#1012628).
- drm/etnaviv: Use FOLL_FORCE for userptr (bsc#1012628).
- drm/amd/pm: workaround for audio noise issue (bsc#1012628).
- drm/amdgpu/display: restore AUX_DPHY_TX_CONTROL for DCN2.x
  (bsc#1012628).
- drm/amdgpu: fix the hibernation suspend with s0ix (bsc#1012628).
- drm/amdgpu: Add additional Sienna Cichlid PCI ID (bsc#1012628).
- drm/i915/dsc: fix DSS CTL register usage for ICL DSI transcoders
  (bsc#1012628).
- drm/i915: Fix the GT fence revocation runtime PM logic
  (bsc#1012628).
- dm verity: fix DM_VERITY_OPTS_MAX value (bsc#1012628).
- dm: don't report "detected capacity change" on device creation
  (bsc#1012628).
- dm ioctl: fix out of bounds array access when no devices
  (bsc#1012628).
- bus: omap_l3_noc: mark l3 irqs as IRQF_NO_THREAD (bsc#1012628).
- soc: ti: omap-prm: Fix reboot issue with invalid pcie reset
  map for dra7 (bsc#1012628).
- ARM: OMAP2+: Fix smartreflex init regression after dropping
  legacy data (bsc#1012628).
- soc: ti: omap-prm: Fix occasional abort on reset deassert for
  dra7 iva (bsc#1012628).
- veth: Store queue_mapping independently of XDP prog presence
  (bsc#1012628).
- bpf: Dont allow vmlinux BTF to be used in map_create and
  prog_load (bsc#1012628).
- bpf: Change inode_storage's lookup_elem return value from NULL
  to -EBADF (bsc#1012628).
- libbpf: Fix INSTALL flag order (bsc#1012628).
- net/mlx5e: RX, Mind the MPWQE gaps when calculating offsets
  (bsc#1012628).
- net/mlx5e: Set PTP channel pointer explicitly to NULL
  (bsc#1012628).
- net/mlx5e: When changing XDP program without reset, take refs
  for XSK RQs (bsc#1012628).
- net/mlx5e: Revert parameters on errors when changing PTP state
  without reset (bsc#1012628).
- net/mlx5e: Don't match on Geneve options in case option masks
  are all zero (bsc#1012628).
- net/mlx5e: E-switch, Fix rate calculation division
  (bsc#1012628).
- ipv6: fix suspecious RCU usage warning (bsc#1012628).
- drop_monitor: Perform cleanup upon probe registration failure
  (bsc#1012628).
- macvlan: macvlan_count_rx() needs to be aware of preemption
  (bsc#1012628).
- net: sched: validate stab values (bsc#1012628).
- net: dsa: bcm_sf2: Qualify phydev->dev_flags based on port
  (bsc#1012628).
- igc: reinit_locked() should be called with rtnl_lock
  (bsc#1012628).
- igc: Fix Pause Frame Advertising (bsc#1012628).
- igc: Fix Supported Pause Frame Link Setting (bsc#1012628).
- igc: Fix igc_ptp_rx_pktstamp() (bsc#1012628).
- e1000e: add rtnl_lock() to e1000_reset_task (bsc#1012628).
- e1000e: Fix error handling in e1000_set_d0_lplu_state_82571
  (bsc#1012628).
- kunit: tool: Disable PAGE_POISONING under --alltests
  (bsc#1012628).
- net/qlcnic: Fix a use after free in
  qlcnic_83xx_get_minidump_template (bsc#1012628).
- net: phy: broadcom: Add power down exit reset state delay
  (bsc#1012628).
- ice: fix napi work done reporting in xsk path (bsc#1012628).
- ftgmac100: Restart MAC HW once (bsc#1012628).
- clk: qcom: gcc-sc7180: Use floor ops for the correct sdcc1 clk
  (bsc#1012628).
- net: ipa: terminate message handler arrays (bsc#1012628).
- net: qrtr: fix a kernel-infoleak in qrtr_recvmsg()
  (bsc#1012628).
- flow_dissector: fix byteorder of dissected ICMP ID
  (bsc#1012628).
- selftests/bpf: Set gopt opt_class to 0 if get tunnel opt failed
  (bsc#1012628).
- netfilter: ctnetlink: fix dump of the expect mask attribute
  (bsc#1012628).
- net: hdlc_x25: Prevent racing between "x25_close" and
  "x25_xmit"/"x25_rx" (bsc#1012628).
- net: phylink: Fix phylink_err() function name error in
  phylink_major_config (bsc#1012628).
- tipc: better validate user input in tipc_nl_retrieve_key()
  (bsc#1012628).
- tcp: relookup sock for RST+ACK packets handled by obsolete
  req sock (bsc#1012628).
- mptcp: fix ADD_ADDR HMAC in case port is specified
  (bsc#1012628).
- can: isotp: isotp_setsockopt(): only allow to set low level
  TX flags for CAN-FD (bsc#1012628).
- can: isotp: TX-path: ensure that CAN frame flags are initialized
  (bsc#1012628).
- can: peak_usb: add forgotten supported devices (bsc#1012628).
- can: flexcan: flexcan_chip_freeze(): fix chip freeze for
  missing bitrate (bsc#1012628).
- can: kvaser_pciefd: Always disable bus load reporting
  (bsc#1012628).
- can: c_can_pci: c_can_pci_remove(): fix use-after-free
  (bsc#1012628).
- can: c_can: move runtime PM enable/disable to c_can_platform
  (bsc#1012628).
- can: m_can: m_can_do_rx_poll(): fix extraneous msg loss warning
  (bsc#1012628).
- can: m_can: m_can_rx_peripheral(): fix RX being blocked by
  errors (bsc#1012628).
- mac80211: fix rate mask reset (bsc#1012628).
- mac80211: Allow HE operation to be longer than expected
  (bsc#1012628).
- selftests/net: fix warnings on reuseaddr_ports_exhausted
  (bsc#1012628).
- nfp: flower: fix unsupported pre_tunnel flows (bsc#1012628).
- nfp: flower: add ipv6 bit to pre_tunnel control message
  (bsc#1012628).
- nfp: flower: fix pre_tun mask id allocation (bsc#1012628).
- ftrace: Fix modify_ftrace_direct (bsc#1012628).
- drm/msm/dsi: fix check-before-set in the 7nm dsi_pll code
  (bsc#1012628).
- ionic: linearize tso skb with too many frags (bsc#1012628).
- net/sched: cls_flower: fix only mask bit check in the
  validate_ct_state (bsc#1012628).
- netfilter: nftables: report EOPNOTSUPP on unsupported flowtable
  flags (bsc#1012628).
- netfilter: nftables: allow to update flowtable flags
  (bsc#1012628).
- netfilter: flowtable: Make sure GC works periodically in idle
  system (bsc#1012628).
- libbpf: Fix error path in bpf_object__elf_init() (bsc#1012628).
- libbpf: Use SOCK_CLOEXEC when opening the netlink socket
  (bsc#1012628).
- ARM: dts: imx6ull: fix ubi filesystem mount failed
  (bsc#1012628).
- ipv6: weaken the v4mapped source check (bsc#1012628).
- octeontx2-af: Formatting debugfs entry rsrc_alloc (bsc#1012628).
- octeontx2-af: Remove TOS field from MKEX TX (bsc#1012628).
- octeontx2-af: Fix irq free in rvu teardown (bsc#1012628).
- octeontx2-pf: Clear RSS enable flag on interace down
  (bsc#1012628).
- octeontx2-af: fix infinite loop in unmapping NPC counter
  (bsc#1012628).
- net: check all name nodes in __dev_alloc_name (bsc#1012628).
- net: cdc-phonet: fix data-interface release on probe failure
  (bsc#1012628).
- igb: check timestamp validity (bsc#1012628).
- sctp: move sk_route_caps check and set into
  sctp_outq_flush_transports (bsc#1012628).
- r8152: limit the RX buffer size of RTL8153A for USB 2.0
  (bsc#1012628).
- net: stmmac: dwmac-sun8i: Provide TX and RX fifo sizes
  (bsc#1012628).
- selinux: vsock: Set SID for socket returned by accept()
  (bsc#1012628).
- selftests: forwarding: vxlan_bridge_1d: Fix vxlan ecn
  decapsulate value (bsc#1012628).
- libbpf: Fix BTF dump of pointer-to-array-of-struct
  (bsc#1012628).
- bpf: Fix umd memory leak in copy_process() (bsc#1012628).
- can: isotp: tx-path: zero initialize outgoing CAN frames
  (bsc#1012628).
- platform/x86: dell-wmi-sysman: Fix crash caused by calling
  kset_unregister twice (bsc#1012628).
- platform/x86: dell-wmi-sysman: Fix possible NULL pointer deref
  on exit (bsc#1012628).
- platform/x86: dell-wmi-sysman: Make it safe to call
  exit_foo_attributes() multiple times (bsc#1012628).
- platform/x86: dell-wmi-sysman: Fix release_attributes_data()
  getting called twice on init_bios_attributes() failure
  (bsc#1012628).
- platform/x86: dell-wmi-sysman: Cleanup sysman_init() error-exit
  handling (bsc#1012628).
- platform/x86: dell-wmi-sysman: Make sysman_init() return
  - ENODEV of the interfaces are not found (bsc#1012628).
- drm/msm: fix shutdown hook in case GPU components failed to bind
  (bsc#1012628).
- drm/msm: Fix suspend/resume on i.MX5 (bsc#1012628).
- arm64: kdump: update ppos when reading elfcorehdr (bsc#1012628).
- PM: runtime: Defer suspending suppliers (bsc#1012628).
- net/mlx5: Add back multicast stats for uplink representor
  (bsc#1012628).
- net/mlx5e: Allow to match on MPLS parameters only for MPLS
  over UDP (bsc#1012628).
- net/mlx5e: Offload tuple rewrite for non-CT flows (bsc#1012628).
- net/mlx5e: Fix error path for ethtool set-priv-flag
  (bsc#1012628).
- mfd: intel_quark_i2c_gpio: Revert "Constify static struct
  resources" (bsc#1012628).
- PM: EM: postpone creating the debugfs dir till fs_initcall
  (bsc#1012628).
- platform/x86: intel_pmt_crashlog: Fix incorrect macros
  (bsc#1012628).
- net: bridge: don't notify switchdev for local FDB addresses
  (bsc#1012628).
- octeontx2-af: Fix memory leak of object buf (bsc#1012628).
- xen/x86: make XEN_BALLOON_MEMORY_HOTPLUG_LIMIT depend on
  MEMORY_HOTPLUG (bsc#1012628).
- RDMA/cxgb4: Fix adapter LE hash errors while destroying ipv6
  listening server (bsc#1012628).
- mm: memblock: fix section mismatch warning again (bsc#1012628).
- bpf: Don't do bpf_cgroup_storage_set() for kuprobe/tp programs
  (bsc#1012628).
- net: Consolidate common blackhole dst ops (bsc#1012628).
- net, bpf: Fix ip6ip6 crash with collect_md populated skbs
  (bsc#1012628).
- igb: avoid premature Rx buffer reuse (bsc#1012628).
- net: axienet: Fix probe error cleanup (bsc#1012628).
- net: phy: introduce phydev->port (bsc#1012628).
- net: phy: broadcom: Avoid forward for
  bcm54xx_config_clock_delay() (bsc#1012628).
- net: phy: broadcom: Set proper 1000BaseX/SGMII interface mode
  for BCM54616S (bsc#1012628).
- net: phy: broadcom: Fix RGMII delays for BCM50160 and BCM50610M
  (bsc#1012628).
- Revert "netfilter: x_tables: Switch synchronization to RCU"
  (bsc#1012628).
- netfilter: x_tables: Use correct memory barriers (bsc#1012628).
- bpf: Fix fexit trampoline (bsc#1012628).
- bpf: Use NOP_ATOMIC5 instead of emit_nops(&prog, 5) for
  BPF_TRAMP_F_CALL_ORIG (bsc#1012628).
- platform/x86: dell-wmi-sysman: Cleanup
  create_attributes_level_sysfs_files() (bsc#1012628).
- dm table: Fix zoned model check and zone sectors check
  (bsc#1012628).
- mm/mmu_notifiers: ensure range_end() is paired with
  range_start() (bsc#1012628).
- Revert "netfilter: x_tables: Update remaining dereference to
  RCU" (bsc#1012628).
- ACPI: scan: Rearrange memory allocation in acpi_device_add()
  (bsc#1012628).
- ACPI: scan: Use unique number for instance_no (bsc#1012628).
- perf auxtrace: Fix auxtrace queue conflict (bsc#1012628).
- perf synthetic events: Avoid write of uninitialized memory
  when generating PERF_RECORD_MMAP* records (bsc#1012628).
- io_uring: fix provide_buffers sign extension (bsc#1012628).
- block: recalculate segment count for multi-segment discards
  correctly (bsc#1012628).
- scsi: Revert "qla2xxx: Make sure that aborted commands are
  freed" (bsc#1012628).
- scsi: qedi: Fix error return code of qedi_alloc_global_queues()
  (bsc#1012628).
- scsi: mpt3sas: Fix error return code of mpt3sas_base_attach()
  (bsc#1012628).
- smb3: fix cached file size problems in duplicate extents
  (reflink) (bsc#1012628).
- cifs: Adjust key sizes and key generation routines for AES256
  encryption (bsc#1012628).
- locking/mutex: Fix non debug version of mutex_lock_io_nested()
  (bsc#1012628).
- x86/mem_encrypt: Correct physical address calculation in
  __set_clr_pte_enc() (bsc#1012628).
- fs/cachefiles: Remove wait_bit_key layout dependency
  (bsc#1012628).
- ch_ktls: fix enum-conversion warning (bsc#1012628).
- can: dev: Move device back to init netns on owning netns delete
  (bsc#1012628).
- r8169: fix DMA being used after buffer free if WoL is enabled
  (bsc#1012628).
- net: dsa: b53: VLAN filtering is global to all users
  (bsc#1012628).
- mac80211: fix double free in ibss_leave (bsc#1012628).
- ext4: add reclaim checks to xattr code (bsc#1012628).
- fs/ext4: fix integer overflow in s_log_groups_per_flex
  (bsc#1012628).
- Revert "xen: fix p2m size in dom0 for disabled memory hotplug
  case" (bsc#1012628).
- nvme: fix the nsid value to print in nvme_validate_or_alloc_ns
  (bsc#1012628).
- can: peak_usb: Revert "can: peak_usb: add forgotten supported
  devices" (bsc#1012628).
- selftest/bpf: Add a test to check trampoline freeing logic
  (bsc#1012628).
- xen-blkback: don't leak persistent grants from xen_blkbk_map()
  (bsc#1012628).
- Update config files.
- commit dbc4a02
* Mon Mar 29 2021 mkubecek@suse.cz
- Update to 5.12-rc5
- refresh configs
  - XEN_BALLOON_MEMORY_HOTPLUG_LIMIT renamed to XEN_MEMORY_HOTPLUG_LIMIT (x86_64)
- commit 5fe2d5c
* Fri Mar 26 2021 tiwai@suse.de
- drm/nouveau/kms/nve4-nv108: Limit cursors to 128x128
  (bsc#1183671).
- commit fa5dcf1
* Fri Mar 26 2021 tiwai@suse.de
- Update config files: disable CONFIG_SND_HDA_INTEL_HDMI_SILENT_STREAM (bsc#1184019)
- commit d848134
* Thu Mar 25 2021 jslaby@suse.cz
- Linux 5.11.10 (bsc#1012628).
- Revert "drm/ttm: Warn on pinning without holding a reference"
  (bsc#1012628).
- Revert "drm/ttm: make ttm_bo_unpin more defensive"
  (bsc#1012628).
- commit fccd69b
* Wed Mar 24 2021 jslaby@suse.cz
- drm/ttm: stop destroying pinned ghost object (git-fixes).
- commit 39815e4
* Wed Mar 24 2021 jslaby@suse.cz
- Linux 5.11.9 (bsc#1012628).
- ASoC: ak4458: Add MODULE_DEVICE_TABLE (bsc#1012628).
- ASoC: ak5558: Add MODULE_DEVICE_TABLE (bsc#1012628).
- spi: cadence: set cqspi to the driver_data field of struct
  device (bsc#1012628).
- ALSA: dice: fix null pointer dereference when node is
  disconnected (bsc#1012628).
- ALSA: hda/realtek: apply pin quirk for XiaomiNotebook Pro
  (bsc#1012628).
- ALSA: hda: generic: Fix the micmute led init state
  (bsc#1012628).
- ALSA: hda/realtek: Apply headset-mic quirks for Xiaomi Redmibook
  Air (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP 840 G8
  (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP 440 G8
  (bsc#1012628).
- ALSA: hda/realtek: fix mute/micmute LEDs for HP 850 G8
  (bsc#1012628).
- Revert "PM: runtime: Update device status before letting
  suppliers suspend" (bsc#1012628).
- s390/vtime: fix increased steal time accounting (bsc#1012628).
- s390/pci: refactor zpci_create_device() (bsc#1012628).
- s390/pci: remove superfluous zdev->zbus check (bsc#1012628).
- s390/pci: fix leak of PCI device structure (bsc#1012628).
- zonefs: Fix O_APPEND async write handling (bsc#1012628).
- zonefs: prevent use of seq files as swap file (bsc#1012628).
- zonefs: fix to update .i_wr_refcnt correctly in
  zonefs_open_zone() (bsc#1012628).
- btrfs: fix race when cloning extent buffer during rewind of
  an old root (bsc#1012628).
- btrfs: fix slab cache flags for free space tree bitmap
  (bsc#1012628).
- vhost-vdpa: fix use-after-free of v->config_ctx (bsc#1012628).
- vhost-vdpa: set v->config_ctx to NULL if eventfd_ctx_fdget()
  fails (bsc#1012628).
- drm/amd/display: Correct algorithm for reversed gamma
  (bsc#1012628).
- drm/amd/display: Remove MPC gamut remap logic for DCN30
  (bsc#1012628).
- iommu/amd: Don't call early_amd_iommu_init() when AMD IOMMU
  is disabled (bsc#1012628).
- iommu/amd: Keep track of amd_iommu_irq_remap state
  (bsc#1012628).
- iommu/amd: Move Stoney Ridge check to detect_ivrs()
  (bsc#1012628).
- ASoC: fsl_ssi: Fix TDM slot setup for I2S mode (bsc#1012628).
- ASoC: Intel: bytcr_rt5640: Fix HP Pavilion x2 10-p0XX OVCD
  current threshold (bsc#1012628).
- ASoC: SOF: Intel: unregister DMIC device on probe error
  (bsc#1012628).
- ASoC: SOF: intel: fix wrong poll bits in dsp power down
  (bsc#1012628).
- ASoC: qcom: sdm845: Fix array out of bounds access
  (bsc#1012628).
- ASoC: qcom: sdm845: Fix array out of range on rx slim channels
  (bsc#1012628).
- ASoC: codecs: wcd934x: add a sanity check in set channel map
  (bsc#1012628).
- ASoC: qcom: lpass-cpu: Fix lpass dai ids parse (bsc#1012628).
- ASoC: simple-card-utils: Do not handle device clock
  (bsc#1012628).
- afs: Fix accessing YFS xattrs on a non-YFS server (bsc#1012628).
- afs: Stop listxattr() from listing "afs.*" attributes
  (bsc#1012628).
- ALSA: usb-audio: Fix unintentional sign extension issue
  (bsc#1012628).
- nvme: fix Write Zeroes limitations (bsc#1012628).
- nvme-tcp: fix misuse of __smp_processor_id with preemption
  enabled (bsc#1012628).
- nvme-tcp: fix possible hang when failing to set io queues
  (bsc#1012628).
- nvme-tcp: fix a NULL deref when receiving a 0-length r2t PDU
  (bsc#1012628).
- nvmet: don't check iosqes,iocqes for discovery controllers
  (bsc#1012628).
- nfsd: Don't keep looking up unhashed files in the nfsd file
  cache (bsc#1012628).
- nfsd: don't abort copies early (bsc#1012628).
- NFSD: Repair misuse of sv_lock in 5.10.16-rt30 (bsc#1012628).
- NFSD: fix dest to src mount in inter-server COPY (bsc#1012628).
- svcrdma: disable timeouts on rdma backchannel (bsc#1012628).
- vfio: IOMMU_API should be selected (bsc#1012628).
- vhost_vdpa: fix the missing irq_bypass_unregister_producer()
  invocation (bsc#1012628).
- sunrpc: fix refcount leak for rpc auth modules (bsc#1012628).
- i915/perf: Start hrtimer only if sampling the OA buffer
  (bsc#1012628).
- iommu/tegra-smmu: Make tegra_smmu_probe_device() to handle
  all IOMMU phandles (bsc#1012628).
- pstore: Fix warning in pstore_kill_sb() (bsc#1012628).
- io_uring: ensure that SQPOLL thread is started for exit
  (bsc#1012628).
- net/qrtr: fix __netdev_alloc_skb call (bsc#1012628).
- cifs: warn and fail if trying to use rootfs without the config
  option (bsc#1012628).
- cifs: fix allocation size on newly created files (bsc#1012628).
- RISC-V: Fix out-of-bounds accesses in init_resources()
  (bsc#1012628).
- riscv: Correct SPARSEMEM configuration (bsc#1012628).
- scsi: lpfc: Fix some error codes in debugfs (bsc#1012628).
- scsi: myrs: Fix a double free in myrs_cleanup() (bsc#1012628).
- scsi: ufs: ufs-mediatek: Correct operator & -> && (bsc#1012628).
- scsi: mpt3sas: Do not use GFP_KERNEL in atomic context
  (bsc#1012628).
- RISC-V: correct enum sbi_ext_rfence_fid (bsc#1012628).
- counter: stm32-timer-cnt: Report count function when
  SLAVE_MODE_DISABLED (bsc#1012628).
- ASoC: codecs: lpass-va-macro: mute/unmute all active decimators
  (bsc#1012628).
- ASoC: codecs: lpass-wsa-macro: fix RX MIX input controls
  (bsc#1012628).
- powerpc/vdso32: Add missing _restgpr_31_x to fix build failure
  (bsc#1012628).
- drm/ttm: Warn on pinning without holding a reference
  (bsc#1012628).
- drm/ttm: make ttm_bo_unpin more defensive (bsc#1012628).
- gpiolib: Assign fwnode to parent's if no primary one provided
  (bsc#1012628).
- nvme-rdma: fix possible hang when failing to set io queues
  (bsc#1012628).
- powerpc: Force inlining of cpu_has_feature() to avoid build
  failure (bsc#1012628).
- usb-storage: Add quirk to defeat Kindle's automatic unload
  (bsc#1012628).
- usbip: Fix incorrect double assignment to udc->ud.tcp_rx
  (bsc#1012628).
- usb: gadget: configfs: Fix KASAN use-after-free (bsc#1012628).
- usb: typec: Remove vdo[3] part of tps6598x_rx_identity_reg
  struct (bsc#1012628).
- usb: typec: tcpm: Invoke power_supply_changed for
  tcpm-source-psy- (bsc#1012628).
- usb: dwc3: gadget: Allow runtime suspend if UDC unbinded
  (bsc#1012628).
- usb: dwc3: gadget: Prevent EP queuing while stopping transfers
  (bsc#1012628).
- thunderbolt: Initialize HopID IDAs in tb_switch_alloc()
  (bsc#1012628).
- thunderbolt: Increase runtime PM reference count on DP tunnel
  discovery (bsc#1012628).
- iio:adc:stm32-adc: Add HAS_IOMEM dependency (bsc#1012628).
- iio:adc:qcom-spmi-vadc: add default scale to LR_MUX2_BAT_ID
  channel (bsc#1012628).
- iio: adis16400: Fix an error code in adis16400_initial_setup()
  (bsc#1012628).
- iio: gyro: mpu3050: Fix error handling in
  mpu3050_trigger_handler (bsc#1012628).
- iio: adc: ab8500-gpadc: Fix off by 10 to 3 (bsc#1012628).
- iio: adc: ad7949: fix wrong ADC result due to incorrect bit mask
  (bsc#1012628).
- iio: adc: adi-axi-adc: add proper Kconfig dependencies
  (bsc#1012628).
- iio: hid-sensor-humidity: Fix alignment issue of timestamp
  channel (bsc#1012628).
- iio: hid-sensor-prox: Fix scale not correct issue (bsc#1012628).
- iio: hid-sensor-temperature: Fix issues of timestamp channel
  (bsc#1012628).
- counter: stm32-timer-cnt: fix ceiling write max value
  (bsc#1012628).
- counter: stm32-timer-cnt: fix ceiling miss-alignment with
  reload register (bsc#1012628).
- PCI: rpadlpar: Fix potential drc_name corruption in store
  functions (bsc#1012628).
- perf/x86/intel: Fix a crash caused by zero PEBS status
  (bsc#1012628).
- perf/x86/intel: Fix unchecked MSR access error caused by
  VLBR_EVENT (bsc#1012628).
- x86/ioapic: Ignore IRQ2 again (bsc#1012628).
- kernel, fs: Introduce and use set_restart_fn() and
  arch_set_restart_data() (bsc#1012628).
- x86: Move TS_COMPAT back to asm/thread_info.h (bsc#1012628).
- x86: Introduce TS_COMPAT_RESTART to fix get_nr_restart_syscall()
  (bsc#1012628).
- efivars: respect EFI_UNSUPPORTED return from firmware
  (bsc#1012628).
- ext4: fix error handling in ext4_end_enable_verity()
  (bsc#1012628).
- ext4: find old entry again if failed to rename whiteout
  (bsc#1012628).
- ext4: stop inode update before return (bsc#1012628).
- ext4: do not try to set xattr into ea_inode if value is empty
  (bsc#1012628).
- ext4: fix potential error in ext4_do_update_inode (bsc#1012628).
- ext4: fix timer use-after-free on failed mount (bsc#1012628).
- ext4: fix rename whiteout with fast commit (bsc#1012628).
- MAINTAINERS: move some real subsystems off of the staging
  mailing list (bsc#1012628).
- MAINTAINERS: move the staging subsystem to lists.linux.dev
  (bsc#1012628).
- static_call: Fix static_call_update() sanity check
  (bsc#1012628).
- efi: use 32-bit alignment for efi_guid_t literals (bsc#1012628).
- firmware/efi: Fix a use after bug in efi_mem_reserve_persistent
  (bsc#1012628).
- genirq: Disable interrupts for force threaded handlers
  (bsc#1012628).
- x86/apic/of: Fix CPU devicetree-node lookups (bsc#1012628).
- cifs: Fix preauth hash corruption (bsc#1012628).
- Update config files.
- commit 8be2d1c
* Mon Mar 22 2021 mkubecek@suse.cz
- Update to 5.12-rc4
- update configs
  - VFIO=n (s390x/zfcpdump only)
  - drop SND_SOC_SIRF_AUDIO_CODEC (removed)
  - drop ADI_AXI_ADC (x86_64, depends on OF now)
- commit 094141b
* Mon Mar 22 2021 mkubecek@suse.cz
- config: disable obsolete crypto algorithms (bsc#1180928)
- CONFIG_CRYPTO_USER_API_ENABLE_OBSOLETE y->n
  - drop CRYPTO_ANUBIS
  - drop CRYPTO_ARC4
  - drop CRYPTO_KHAZAD
  - drop CRYPTO_SEED
  - drop CRYPTO_TEA
- commit 1c5c406
* Sat Mar 20 2021 jslaby@suse.cz
- Linux 5.11.8 (bsc#1012628).
- io_uring: don't attempt IO reissue from the ring exit path
  (bsc#1012628).
- KVM: x86/mmu: Expand on the comment in
  kvm_vcpu_ad_need_write_protect() (bsc#1012628).
- KVM: x86/mmu: Set SPTE_AD_WRPROT_ONLY_MASK if and only if PML
  is enabled (bsc#1012628).
- mptcp: send ack for every add_addr (bsc#1012628).
- mptcp: pm: add lockdep assertions (bsc#1012628).
- io_uring: refactor scheduling in io_cqring_wait (bsc#1012628).
- io_uring: refactor io_cqring_wait (bsc#1012628).
- io_uring: don't keep looping for more events if we can't flush
  overflow (bsc#1012628).
- io_uring: simplify do_read return parsing (bsc#1012628).
- io_uring: clear IOCB_WAITQ for non -EIOCBQUEUED return
  (bsc#1012628).
- regulator: pca9450: Add SD_VSEL GPIO for LDO5 (bsc#1012628).
- regulator: pca9450: Enable system reset on WDOG_B assertion
  (bsc#1012628).
- regulator: pca9450: Clear PRESET_EN bit to fix BUCK1/2/3
  voltage setting (bsc#1012628).
- gfs2: Add common helper for holding and releasing the freeze
  glock (bsc#1012628).
- gfs2: move freeze glock outside the make_fs_rw and _ro functions
  (bsc#1012628).
- gfs2: bypass signal_our_withdraw if no journal (bsc#1012628).
- bpf: Prohibit alu ops for pointer types not defining ptr_limit
  (bsc#1012628).
- bpf: Fix off-by-one for area size in creating mask to left
  (bsc#1012628).
- bpf: Simplify alu_limit masking for pointer arithmetic
  (bsc#1012628).
- bpf: Add sanity check for upper ptr_limit (bsc#1012628).
- bpf, selftests: Fix up some test_verifier cases for unprivileged
  (bsc#1012628).
- arm64: Unconditionally set virtual cpu id registers
  (bsc#1012628).
- RDMA/srp: Fix support for unpopulated and unbalanced NUMA nodes
  (bsc#1012628).
- fuse: fix live lock in fuse_iget() (bsc#1012628).
- Revert "nfsd4: remove check_conflicting_opens warning"
  (bsc#1012628).
- Revert "nfsd4: a client's own opens needn't prevent delegations"
  (bsc#1012628).
- net: dsa: b53: Support setting learning on port (bsc#1012628).
- crypto: x86/aes-ni-xts - use direct calls to and 4-way stride
  (bsc#1012628).
- commit 995fe45
* Thu Mar 18 2021 dmueller@suse.com
- config.conf: add kernel-debug for arm64 (bsc#1183716)
- commit 68a1ba6
* Thu Mar 18 2021 jslaby@suse.cz
- kbuild: Fix <linux/version.h> for empty SUBLEVEL or PATCHLEVEL
  again (git-fixes).
- mptcp: dispose initial struct socket when its subflow is closed
  (git-fixes).
- kbuild: Fix <linux/version.h> for empty SUBLEVEL or PATCHLEVEL
  again (git-fixes).
- mptcp: dispose initial struct socket when its subflow is closed
  (git-fixes).
- commit a314558
* Wed Mar 17 2021 jslaby@suse.cz
- Linux 5.11.7 (bsc#1012628).
- uapi: nfnetlink_cthelper.h: fix userspace compilation error
  (bsc#1012628).
- powerpc/603: Fix protection of user pages mapped with PROT_NONE
  (bsc#1012628).
- powerpc/perf: Fix handling of privilege level checks in perf
  interrupt context (bsc#1012628).
- powerpc/pseries: Don't enforce MSI affinity with kdump
  (bsc#1012628).
- ethernet: alx: fix order of calls on resume (bsc#1012628).
- crypto: mips/poly1305 - enable for all MIPS processors
  (bsc#1012628).
- mptcp: fix length of ADD_ADDR with port sub-option
  (bsc#1012628).
- ath9k: fix transmitting to stations in dynamic SMPS mode
  (bsc#1012628).
- net: Fix gro aggregation for udp encaps with zero csum
  (bsc#1012628).
- net: check if protocol extracted by virtio_net_hdr_set_proto
  is correct (bsc#1012628).
- net: avoid infinite loop in mpls_gso_segment when mpls_hlen ==
  0 (bsc#1012628).
- ath11k: fix AP mode for QCA6390 (bsc#1012628).
- net: l2tp: reduce log level of messages in receive path,
  add counter instead (bsc#1012628).
- gpiolib: acpi: Add ACPI_GPIO_QUIRK_ABSOLUTE_NUMBER quirk
  (bsc#1012628).
- gpiolib: acpi: Allow to find GpioInt() resource by name and
  index (bsc#1012628).
- can: skb: can_skb_set_owner(): fix ref counting if socket was
  closed before setting skb ownership (bsc#1012628).
- gpio: pca953x: Set IRQ type when handle Intel Galileo Gen 2
  (bsc#1012628).
- can: flexcan: assert FRZ bit in flexcan_chip_freeze()
  (bsc#1012628).
- can: flexcan: enable RX FIFO after FRZ/HALT valid (bsc#1012628).
- can: flexcan: invoke flexcan_chip_freeze() to enter freeze mode
  (bsc#1012628).
- can: tcan4x5x: tcan4x5x_init(): fix initialization - clear
  MRAM before entering Normal Mode (bsc#1012628).
- tcp: Fix sign comparison bug in getsockopt(TCP_ZEROCOPY_RECEIVE)
  (bsc#1012628).
- tcp: add sanity tests to TCP_QUEUE_SEQ (bsc#1012628).
- netfilter: nf_nat: undo erroneous tcp edemux lookup
  (bsc#1012628).
- netfilter: x_tables: gpf inside xt_find_revision()
  (bsc#1012628).
- net: always use icmp{,v6}_ndo_send from ndo_start_xmit
  (bsc#1012628).
- net: phy: fix save wrong speed and duplex problem if autoneg
  is on (bsc#1012628).
- selftests/bpf: Use the last page in test_snprintf_btf on s390
  (bsc#1012628).
- selftests/bpf: No need to drop the packet when there is no
  geneve opt (bsc#1012628).
- selftests/bpf: Mask bpf_csum_diff() return value to 16 bits
  in test_verifier (bsc#1012628).
- samples, bpf: Add missing munmap in xdpsock (bsc#1012628).
- libbpf: Clear map_info before each bpf_obj_get_info_by_fd
  (bsc#1012628).
- ibmvnic: Fix possibly uninitialized old_num_tx_queues variable
  warning (bsc#1012628).
- ibmvnic: always store valid MAC address (bsc#1012628).
- ibmvnic: remove excessive irqsave (bsc#1012628).
- mt76: dma: do not report truncated frames to mac80211
  (bsc#1012628).
- gpio: fix gpio-device list corruption (bsc#1012628).
- mount: fix mounting of detached mounts onto targets that reside
  on shared mounts (bsc#1012628).
- cifs: fix credit accounting for extra channel (bsc#1012628).
- cifs: return proper error code in statfs(2) (bsc#1012628).
- Revert "mm, slub: consider rest of partial list if
  acquire_slab() fails" (bsc#1012628).
- docs: networking: drop special stable handling (bsc#1012628).
- net: dsa: tag_rtl4_a: fix egress tags (bsc#1012628).
- sh_eth: fix TRSCER mask for SH771x (bsc#1012628).
- net: enetc: don't overwrite the RSS indirection table when
  initializing (bsc#1012628).
- net: enetc: initialize RFS/RSS memories for unused ports too
  (bsc#1012628).
- net: enetc: take the MDIO lock only once per NAPI poll cycle
  (bsc#1012628).
- net: enetc: fix incorrect TPID when receiving 802.1ad tagged
  packets (bsc#1012628).
- net: enetc: don't disable VLAN filtering in IFF_PROMISC mode
  (bsc#1012628).
- net: enetc: force the RGMII speed and duplex instead of
  operating in inband mode (bsc#1012628).
- net: enetc: remove bogus write to SIRXIDR from enetc_setup_rxbdr
  (bsc#1012628).
- net: enetc: keep RX ring consumer index in sync with hardware
  (bsc#1012628).
- net: dsa: tag_mtk: fix 802.1ad VLAN egress (bsc#1012628).
- net: ethernet: mtk-star-emac: fix wrong unmap in RX handling
  (bsc#1012628).
- net/mlx4_en: update moderation when config reset (bsc#1012628).
- net: stmmac: fix incorrect DMA channel intr enable setting of
  EQoS v4.10 (bsc#1012628).
- nexthop: Do not flush blackhole nexthops when loopback goes down
  (bsc#1012628).
- net: sched: avoid duplicates in classes dump (bsc#1012628).
- net: mscc: ocelot: properly reject destination IP keys in VCAP
  IS1 (bsc#1012628).
- net: dsa: sja1105: fix SGMII PCS being forced to SPEED_UNKNOWN
  instead of SPEED_10 (bsc#1012628).
- net: usb: qmi_wwan: allow qmimux add/del with master up
  (bsc#1012628).
- netdevsim: init u64 stats for 32bit hardware (bsc#1012628).
- cipso,calipso: resolve a number of problems with the DOI
  refcounts (bsc#1012628).
- net: stmmac: Fix VLAN filter delete timeout issue in Intel
  mGBE SGMII (bsc#1012628).
- stmmac: intel: Fixes clock registration error seen for multiple
  interfaces (bsc#1012628).
- net: lapbether: Remove netif_start_queue / netif_stop_queue
  (bsc#1012628).
- net: davicom: Fix regulator not turned off on failed probe
  (bsc#1012628).
- net: davicom: Fix regulator not turned off on driver removal
  (bsc#1012628).
- net: enetc: allow hardware timestamping on TX queues with
  tc-etf enabled (bsc#1012628).
- net: qrtr: fix error return code of qrtr_sendmsg()
  (bsc#1012628).
- s390/qeth: fix memory leak after failed TX Buffer allocation
  (bsc#1012628).
- s390/qeth: improve completion of pending TX buffers
  (bsc#1012628).
- s390/qeth: schedule TX NAPI on QAOB completion (bsc#1012628).
- s390/qeth: fix notification for pending buffers during teardown
  (bsc#1012628).
- r8169: fix r8168fp_adjust_ocp_cmd function (bsc#1012628).
- ixgbe: fail to create xfrm offload of IPsec tunnel mode SA
  (bsc#1012628).
- tools/resolve_btfids: Fix build error with older host toolchains
  (bsc#1012628).
- perf build: Fix ccache usage in $(CC) when generating arch
  errno table (bsc#1012628).
- net: stmmac: stop each tx channel independently (bsc#1012628).
- net: stmmac: fix watchdog timeout during suspend/resume stress
  test (bsc#1012628).
- net: stmmac: fix wrongly set buffer2 valid when sph unsupport
  (bsc#1012628).
- ethtool: fix the check logic of at least one channel for RX/TX
  (bsc#1012628).
- net: phy: make mdio_bus_phy_suspend/resume as __maybe_unused
  (bsc#1012628).
- selftests: forwarding: Fix race condition in mirror installation
  (bsc#1012628).
- mlxsw: spectrum_ethtool: Add an external speed to PTYS register
  (bsc#1012628).
- perf traceevent: Ensure read cmdlines are null terminated
  (bsc#1012628).
- perf report: Fix -F for branch & mem modes (bsc#1012628).
- net: hns3: fix error mask definition of flow director
  (bsc#1012628).
- net: hns3: fix query vlan mask value error for flow director
  (bsc#1012628).
- net: hns3: fix bug when calculating the TCAM table info
  (bsc#1012628).
- s390/cio: return -EFAULT if copy_to_user() fails again
  (bsc#1012628).
- bnxt_en: reliably allocate IRQ table on reset to avoid crash
  (bsc#1012628).
- drm/fb-helper: only unmap if buffer not null (bsc#1012628).
- drm/compat: Clear bounce structures (bsc#1012628).
- drm/radeon: also init GEM funcs in
  radeon_gem_prime_import_sg_table (bsc#1012628).
- drm/amdgpu/display: use GFP_ATOMIC in
  dcn21_validate_bandwidth_fp() (bsc#1012628).
- drm/amd/display: Fix nested FPU context in
  dcn21_validate_bandwidth() (bsc#1012628).
- drm/amd/pm: correct the watermark settings for Polaris
  (bsc#1012628).
- drm/amd/pm: bug fix for pcie dpm (bsc#1012628).
- drm/amdgpu/display: don't assert in set backlight function
  (bsc#1012628 bsc#1180749).
- drm/shmem-helper: Check for purged buffers in fault handler
  (bsc#1012628).
- drm/shmem-helper: Don't remove the offset in vm_area_struct
  pgoff (bsc#1012628).
- drm: Use USB controller's DMA mask when importing dmabufs
  (bsc#1012628).
- drm/amdgpu: fix S0ix handling when the CONFIG_AMD_PMC=m
  (bsc#1012628).
- drm: meson_drv add shutdown function (bsc#1012628).
- drm/shmem-helpers: vunmap: Don't put pages for dma-buf
  (bsc#1012628).
- drm/i915: Wedge the GPU if command parser setup fails
  (bsc#1012628).
- s390/cio: return -EFAULT if copy_to_user() fails (bsc#1012628).
- s390/crypto: return -EFAULT if copy_to_user() fails
  (bsc#1012628).
- qxl: Fix uninitialised struct field head.surface_id
  (bsc#1012628).
- sh_eth: fix TRSCER mask for R7S9210 (bsc#1012628).
- media: usbtv: Fix deadlock on suspend (bsc#1012628).
- media: rkisp1: params: fix wrong bits settings (bsc#1012628).
- media: v4l: vsp1: Fix uif null pointer access (bsc#1012628).
- media: v4l: vsp1: Fix bru null pointer access (bsc#1012628).
- media: rc: compile rc-cec.c into rc-core (bsc#1012628).
- MIPS: kernel: Reserve exception base early to prevent corruption
  (bsc#1012628).
- mptcp: always graft subflow socket to parent (bsc#1012628).
- mptcp: reset last_snd on subflow close (bsc#1012628).
- i2c: rcar: faster irq code to minimize HW race condition
  (bsc#1012628).
- i2c: rcar: optimize cacheline to minimize HW race condition
  (bsc#1012628).
- scsi: pm80xx: Fix missing tag_free in NVMD DATA req
  (bsc#1012628).
- scsi: ufs: WB is only available on LUN #0 to #7 (bsc#1012628).
- scsi: ufs: Protect some contexts from unexpected clock scaling
  (bsc#1012628).
- udf: fix silent AED tagLocation corruption (bsc#1012628).
- iommu/vt-d: Clear PRQ overflow only when PRQ is empty
  (bsc#1012628).
- mmc: mxs-mmc: Fix a resource leak in an error handling path in
  'mxs_mmc_probe()' (bsc#1012628).
- mmc: mediatek: fix race condition between msdc_request_timeout
  and irq (bsc#1012628).
- mmc: sdhci-iproc: Add ACPI bindings for the RPi (bsc#1012628).
- platform/x86: amd-pmc: put device on error paths (bsc#1012628).
- Platform: OLPC: Fix probe error handling (bsc#1012628).
- powerpc/pci: Add ppc_md.discover_phbs() (bsc#1012628).
- spi: stm32: make spurious and overrun interrupts visible
  (bsc#1012628).
- powerpc: improve handling of unrecoverable system reset
  (bsc#1012628).
- powerpc/perf: Record counter overflow always if SAMPLE_IP is
  unset (bsc#1012628).
- HID: logitech-dj: add support for the new lightspeed connection
  iteration (bsc#1012628).
- powerpc/64: Fix stack trace not displaying final frame
  (bsc#1012628).
- iommu/amd: Fix performance counter initialization (bsc#1012628).
- clk: qcom: gdsc: Implement NO_RET_PERIPH flag (bsc#1012628).
- sparc32: Limit memblock allocation to low memory (bsc#1012628).
- sparc64: Use arch_validate_flags() to validate ADI flag
  (bsc#1012628).
- Input: applespi - don't wait for responses to commands
  indefinitely (bsc#1012628).
- PCI: xgene-msi: Fix race in installing chained irq handler
  (bsc#1012628).
- PCI: mediatek: Add missing of_node_put() to fix reference leak
  (bsc#1012628).
- drivers/base: build kunit tests without structleak plugin
  (bsc#1012628).
- PCI/LINK: Remove bandwidth notification (bsc#1012628).
- ext4: don't try to processed freed blocks until mballoc is
  initialized (bsc#1012628).
- kbuild: clamp SUBLEVEL to 255 (bsc#1012628).
- PCI: Fix pci_register_io_range() memory leak (bsc#1012628).
- i40e: Fix memory leak in i40e_probe (bsc#1012628).
- PCI/ERR: Retain status from error notification (bsc#1012628).
- kasan: fix memory corruption in kasan_bitops_tags test
  (bsc#1012628).
- s390/smp: __smp_rescan_cpus() - move cpumask away from stack
  (bsc#1012628).
- drivers/base/memory: don't store phys_device in memory blocks
  (bsc#1012628).
- sysctl.c: fix underflow value setting risk in vm_table
  (bsc#1012628).
- scsi: libiscsi: Fix iscsi_prep_scsi_cmd_pdu() error handling
  (bsc#1012628).
- scsi: target: core: Add cmd length set before cmd complete
  (bsc#1012628).
- scsi: target: core: Prevent underflow for service actions
  (bsc#1012628).
- clk: qcom: gpucc-msm8998: Add resets, cxc, fix flags on
  gpu_gx_gdsc (bsc#1012628).
- ALSA: hda/conexant: Add quirk for mute LED control on HP ZBook
  G5 (bsc#1012628).
- ALSA: hda/ca0132: Add Sound BlasterX AE-5 Plus support
  (bsc#1012628).
- ALSA: hda: Drop the BATCH workaround for AMD controllers
  (bsc#1012628).
- ALSA: usb-audio: Fix "cannot get freq eq" errors on Dell AE515
  sound bar (bsc#1012628).
- ALSA: usb-audio: Disable USB autosuspend properly in
  setup_disable_autosuspend() (bsc#1012628).
- ALSA: usb-audio: fix NULL ptr dereference in usb_audio_probe
  (bsc#1012628).
- ALSA: usb-audio: fix use after free in usb_audio_disconnect
  (bsc#1012628).
- opp: Don't drop extra references to OPPs accidentally
  (bsc#1012628).
- Revert 95ebabde382c ("capabilities: Don't allow writing
  ambiguous v3 file capabilities") (bsc#1012628).
- block: Discard page cache of zone reset target range
  (bsc#1012628).
- block: Try to handle busy underlying device on discard
  (bsc#1012628).
- arm64: kasan: fix page_alloc tagging with DEBUG_VIRTUAL
  (bsc#1012628).
- arm64: mte: Map hotplugged memory as Normal Tagged
  (bsc#1012628).
- arm64: perf: Fix 64-bit event counter read truncation
  (bsc#1012628).
- s390/dasd: fix hanging DASD driver unbind (bsc#1012628).
- s390/dasd: fix hanging IO request during DASD driver unbind
  (bsc#1012628).
- software node: Fix node registration (bsc#1012628).
- xen/events: reset affinity of 2-level event when tearing it down
  (bsc#1012628).
- xen/events: don't unmask an event channel when an eoi is pending
  (bsc#1012628).
- xen/events: avoid handling the same event on two cpus at the
  same time (bsc#1012628).
- mmc: mmci: Add MMC_CAP_NEED_RSP_BUSY for the stm32 variants
  (bsc#1012628).
- mmc: core: Fix partition switch time for eMMC (bsc#1012628).
- mmc: cqhci: Fix random crash when remove mmc module/card
  (bsc#1012628).
- cifs: do not send close in compound create+close requests
  (bsc#1012628).
- Goodix Fingerprint device is not a modem (bsc#1012628).
- USB: gadget: udc: s3c2410_udc: fix return value check in
  s3c2410_udc_probe() (bsc#1012628).
- USB: gadget: u_ether: Fix a configfs return code (bsc#1012628).
- usb: gadget: f_uac2: always increase endpoint max_packet_size
  by one audio slot (bsc#1012628).
- usb: gadget: f_uac1: stop playback on function disable
  (bsc#1012628).
- usb: dwc3: qcom: Add missing DWC3 OF node refcount decrement
  (bsc#1012628).
- usb: dwc3: qcom: add URS Host support for sdm845 ACPI boot
  (bsc#1012628).
- usb: dwc3: qcom: add ACPI device id for sc8180x (bsc#1012628).
- usb: dwc3: qcom: Honor wakeup enabled/disabled state
  (bsc#1012628).
- USB: usblp: fix a hang in poll() if disconnected (bsc#1012628).
- usb: renesas_usbhs: Clear PIPECFG for re-enabling pipe with
  other EPNUM (bsc#1012628).
- usb: xhci: do not perform Soft Retry for some xHCI hosts
  (bsc#1012628).
- xhci: Improve detection of device initiated wake signal
  (bsc#1012628).
- usb: xhci: Fix ASMedia ASM1042A and ASM3242 DMA addressing
  (bsc#1012628).
- xhci: Fix repeated xhci wake after suspend due to uncleared
  internal wake state (bsc#1012628).
- USB: serial: io_edgeport: fix memory leak in edge_startup
  (bsc#1012628).
- USB: serial: ch341: add new Product ID (bsc#1012628).
- USB: serial: cp210x: add ID for Acuity Brands nLight Air Adapter
  (bsc#1012628).
- USB: serial: cp210x: add some more GE USB IDs (bsc#1012628).
- usbip: fix stub_dev to check for stream socket (bsc#1012628).
- usbip: fix vhci_hcd to check for stream socket (bsc#1012628).
- usbip: fix vudc to check for stream socket (bsc#1012628).
- usbip: fix stub_dev usbip_sockfd_store() races leading to gpf
  (bsc#1012628).
- usbip: fix vhci_hcd attach_store() races leading to gpf
  (bsc#1012628).
- usbip: fix vudc usbip_sockfd_store races leading to gpf
  (bsc#1012628).
- Revert "serial: max310x: rework RX interrupt handling"
  (bsc#1012628).
- misc/pvpanic: Export module FDT device table (bsc#1012628).
- misc: fastrpc: restrict user apps from sending kernel RPC
  messages (bsc#1012628).
- staging: rtl8192u: fix ->ssid overflow in r8192_wx_set_scan()
  (bsc#1012628).
- staging: rtl8188eu: prevent ->ssid overflow in rtw_wx_set_scan()
  (bsc#1012628).
- staging: rtl8712: unterminated string leads to read overflow
  (bsc#1012628).
- staging: rtl8188eu: fix potential memory corruption in
  rtw_check_beacon_data() (bsc#1012628).
- staging: ks7010: prevent buffer overflow in ks_wlan_set_scan()
  (bsc#1012628).
- staging: rtl8712: Fix possible buffer overflow in
  r8712_sitesurvey_cmd (bsc#1012628).
- staging: rtl8192e: Fix possible buffer overflow in
  _rtl92e_wx_set_scan (bsc#1012628).
- staging: comedi: addi_apci_1032: Fix endian problem for COS
  sample (bsc#1012628).
- staging: comedi: addi_apci_1500: Fix endian problem for command
  sample (bsc#1012628).
- staging: comedi: adv_pci1710: Fix endian problem for AI command
  data (bsc#1012628).
- staging: comedi: das6402: Fix endian problem for AI command data
  (bsc#1012628).
- staging: comedi: das800: Fix endian problem for AI command data
  (bsc#1012628).
- staging: comedi: dmm32at: Fix endian problem for AI command data
  (bsc#1012628).
- staging: comedi: me4000: Fix endian problem for AI command data
  (bsc#1012628).
- staging: comedi: pcl711: Fix endian problem for AI command data
  (bsc#1012628).
- staging: comedi: pcl818: Fix endian problem for AI command data
  (bsc#1012628).
- mlxsw: spectrum_router: Ignore routes using a deleted nexthop
  object (bsc#1012628).
- net: phy: ti: take into account all possible interrupt sources
  (bsc#1012628).
- sh_eth: fix TRSCER mask for R7S72100 (bsc#1012628).
- powerpc/sstep: Fix VSX instruction emulation (bsc#1012628).
- net: macb: Add default usrio config to default gem config
  (bsc#1012628).
- cpufreq: qcom-hw: fix dereferencing freed memory 'data'
  (bsc#1012628).
- cpufreq: qcom-hw: Fix return value check in
  qcom_cpufreq_hw_cpu_init() (bsc#1012628).
- arm64/mm: Fix pfn_valid() for ZONE_DEVICE based memory
  (bsc#1012628).
- SUNRPC: Set memalloc_nofs_save() for sync tasks (bsc#1012628).
- NFS: Don't revalidate the directory permissions on a lookup
  failure (bsc#1012628).
- NFS: Don't gratuitously clear the inode cache when lookup failed
  (bsc#1012628).
- NFSv4.2: fix return value of _nfs4_get_security_label()
  (bsc#1012628).
- block: rsxx: fix error return code of rsxx_pci_probe()
  (bsc#1012628).
- drm/ttm: Fix TTM page pool accounting (bsc#1012628).
- nvme-fc: fix racing controller reset and create association
  (bsc#1012628).
- configfs: fix a use-after-free in __configfs_open_file
  (bsc#1012628).
- arm64: mm: use a 48-bit ID map when possible on 52-bit VA builds
  (bsc#1012628).
- io_uring: perform IOPOLL reaping if canceler is thread itself
  (bsc#1012628).
- drm/nouveau: fix dma syncing for loops (v2) (bsc#1012628).
- perf/arm_dmc620_pmu: Fix error return code in
  dmc620_pmu_device_probe() (bsc#1012628).
- net: expand textsearch ts_state to fit skb_seq_state
  (bsc#1012628).
- mptcp: put subflow sock on connect error (bsc#1012628).
- mptcp: fix memory accounting on allocation error (bsc#1012628).
- perf/core: Flush PMU internal buffers for per-CPU events
  (bsc#1012628).
- perf/x86/intel: Set PERF_ATTACH_SCHED_CB for large PEBS and LBR
  (bsc#1012628).
- hrtimer: Update softirq_expires_next correctly after
  __hrtimer_get_next_event() (bsc#1012628).
- powerpc/64s/exception: Clean up a missed SRR specifier
  (bsc#1012628).
- seqlock,lockdep: Fix seqcount_latch_init() (bsc#1012628).
- memblock: fix section mismatch warning (bsc#1012628).
- stop_machine: mark helpers __always_inline (bsc#1012628).
- include/linux/sched/mm.h: use rcu_dereference in in_vfork()
  (bsc#1012628).
- zram: fix return value on writeback_store (bsc#1012628).
- zram: fix broken page writeback (bsc#1012628).
- linux/compiler-clang.h: define HAVE_BUILTIN_BSWAP*
  (bsc#1012628).
- sched: Fix migration_cpu_stop() requeueing (bsc#1012628).
- sched/membarrier: fix missing local execution of
  ipi_sync_rq_state() (bsc#1012628).
- sched: Collate affine_move_task() stoppers (bsc#1012628).
- sched: Simplify migration_cpu_stop() (bsc#1012628).
- sched: Optimize migration_cpu_stop() (bsc#1012628).
- sched: Fix affine_move_task() self-concurrency (bsc#1012628).
- sched: Simplify set_affinity_pending refcounts (bsc#1012628).
- efi: stub: omit SetVirtualAddressMap() if marked unsupported
  in RT_PROP table (bsc#1012628).
- powerpc/64s: Fix instruction encoding for lis in
  ppc_function_entry() (bsc#1012628).
- powerpc: Fix inverted SET_FULL_REGS bitop (bsc#1012628).
- powerpc: Fix missing declaration of [en/dis]able_kernel_vsx()
  (bsc#1012628).
- binfmt_misc: fix possible deadlock in bm_register_write
  (bsc#1012628).
- kasan, mm: fix crash with HW_TAGS and DEBUG_PAGEALLOC
  (bsc#1012628).
- kasan: fix KASAN_STACK dependency for HW_TAGS (bsc#1012628).
- x86/unwind/orc: Disable KASAN checking in the ORC unwinder,
  part 2 (bsc#1012628).
- x86/sev-es: Introduce ip_within_syscall_gap() helper
  (bsc#1012628).
- x86/sev-es: Check regs->sp is trusted before adjusting #VC
  IST stack (bsc#1012628).
- x86/sev-es: Correctly track IRQ states in runtime #VC handler
  (bsc#1012628).
- x86/sev-es: Use __copy_from_user_inatomic() (bsc#1012628).
- x86/entry: Fix entry/exit mismatch on failed fast 32-bit
  syscalls (bsc#1012628).
- KVM: x86: Ensure deadline timer has truly expired before
  posting its IRQ (bsc#1012628).
- KVM: kvmclock: Fix vCPUs > 64 can't be online/hotpluged
  (bsc#1012628).
- KVM: arm64: Ensure I-cache isolation between vcpus of a same VM
  (bsc#1012628).
- KVM: arm64: Fix range alignment when walking page tables
  (bsc#1012628).
- KVM: arm64: Avoid corrupting vCPU context register in guest exit
  (bsc#1012628).
- KVM: arm64: nvhe: Save the SPE context early (bsc#1012628).
- KVM: arm64: Reject VM creation when the default IPA size is
  unsupported (bsc#1012628).
- KVM: arm64: Fix exclusive limit for IPA size (bsc#1012628).
- mm/highmem.c: fix zero_user_segments() with start > end
  (bsc#1012628).
- mm/userfaultfd: fix memory corruption due to writeprotect
  (bsc#1012628).
- mm/madvise: replace ptrace attach requirement for
  process_madvise (bsc#1012628).
- mm/memcg: set memcg when splitting page (bsc#1012628).
- mm/memcg: rename mem_cgroup_split_huge_fixup to split_page_memcg
  and add nr_pages argument (bsc#1012628).
- mm/page_alloc.c: refactor initialization of struct page for
  holes in memory layout (bsc#1012628).
- KVM: arm64: Fix nVHE hyp panic host context restore
  (bsc#1012628).
- Delete
  patches.suse/drm-amdgpu-display-don-t-assert-in-set-backlight-fun.patch.
- Update config files.
- Linux 5.11.7 (bsc#1012628).
- uapi: nfnetlink_cthelper.h: fix userspace compilation error
  (bsc#1012628).
- powerpc/603: Fix protection of user pages mapped with PROT_NONE
  (bsc#1012628).
- powerpc/perf: Fix handling of privilege level checks in perf
  interrupt context (bsc#1012628).
- powerpc/pseries: Don't enforce MSI affinity with kdump
  (bsc#1012628).
- ethernet: alx: fix order of calls on resume (bsc#1012628).
- crypto: mips/poly1305 - enable for all MIPS processors
  (bsc#1012628).
- mptcp: fix length of ADD_ADDR with port sub-option
  (bsc#1012628).
- ath9k: fix transmitting to stations in dynamic SMPS mode
  (bsc#1012628).
- net: Fix gro aggregation for udp encaps with zero csum
  (bsc#1012628).
- net: check if protocol extracted by virtio_net_hdr_set_proto
  is correct (bsc#1012628).
- net: avoid infinite loop in mpls_gso_segment when mpls_hlen ==
  0 (bsc#1012628).
- ath11k: fix AP mode for QCA6390 (bsc#1012628).
- net: l2tp: reduce log level of messages in receive path,
  add counter instead (bsc#1012628).
- gpiolib: acpi: Add ACPI_GPIO_QUIRK_ABSOLUTE_NUMBER quirk
  (bsc#1012628).
- gpiolib: acpi: Allow to find GpioInt() resource by name and
  index (bsc#1012628).
- can: skb: can_skb_set_owner(): fix ref counting if socket was
  closed before setting skb ownership (bsc#1012628).
- gpio: pca953x: Set IRQ type when handle Intel Galileo Gen 2
  (bsc#1012628).
- can: flexcan: assert FRZ bit in flexcan_chip_freeze()
  (bsc#1012628).
- can: flexcan: enable RX FIFO after FRZ/HALT valid (bsc#1012628).
- can: flexcan: invoke flexcan_chip_freeze() to enter freeze mode
  (bsc#1012628).
- can: tcan4x5x: tcan4x5x_init(): fix initialization - clear
  MRAM before entering Normal Mode (bsc#1012628).
- tcp: Fix sign comparison bug in getsockopt(TCP_ZEROCOPY_RECEIVE)
  (bsc#1012628).
- tcp: add sanity tests to TCP_QUEUE_SEQ (bsc#1012628).
- netfilter: nf_nat: undo erroneous tcp edemux lookup
  (bsc#1012628).
- netfilter: x_tables: gpf inside xt_find_revision()
  (bsc#1012628).
- net: always use icmp{,v6}_ndo_send from ndo_start_xmit
  (bsc#1012628).
- net: phy: fix save wrong speed and duplex problem if autoneg
  is on (bsc#1012628).
- selftests/bpf: Use the last page in test_snprintf_btf on s390
  (bsc#1012628).
- selftests/bpf: No need to drop the packet when there is no
  geneve opt (bsc#1012628).
- selftests/bpf: Mask bpf_csum_diff() return value to 16 bits
  in test_verifier (bsc#1012628).
- samples, bpf: Add missing munmap in xdpsock (bsc#1012628).
- libbpf: Clear map_info before each bpf_obj_get_info_by_fd
  (bsc#1012628).
- ibmvnic: Fix possibly uninitialized old_num_tx_queues variable
  warning (bsc#1012628).
- ibmvnic: always store valid MAC address (bsc#1012628).
- ibmvnic: remove excessive irqsave (bsc#1012628).
- mt76: dma: do not report truncated frames to mac80211
  (bsc#1012628).
- gpio: fix gpio-device list corruption (bsc#1012628).
- mount: fix mounting of detached mounts onto targets that reside
  on shared mounts (bsc#1012628).
- cifs: fix credit accounting for extra channel (bsc#1012628).
- cifs: return proper error code in statfs(2) (bsc#1012628).
- Revert "mm, slub: consider rest of partial list if
  acquire_slab() fails" (bsc#1012628).
- docs: networking: drop special stable handling (bsc#1012628).
- net: dsa: tag_rtl4_a: fix egress tags (bsc#1012628).
- sh_eth: fix TRSCER mask for SH771x (bsc#1012628).
- net: enetc: don't overwrite the RSS indirection table when
  initializing (bsc#1012628).
- net: enetc: initialize RFS/RSS memories for unused ports too
  (bsc#1012628).
- net: enetc: take the MDIO lock only once per NAPI poll cycle
  (bsc#1012628).
- net: enetc: fix incorrect TPID when receiving 802.1ad tagged
  packets (bsc#1012628).
- net: enetc: don't disable VLAN filtering in IFF_PROMISC mode
  (bsc#1012628).
- net: enetc: force the RGMII speed and duplex instead of
  operating in inband mode (bsc#1012628).
- net: enetc: remove bogus write to SIRXIDR from enetc_setup_rxbdr
  (bsc#1012628).
- net: enetc: keep RX ring consumer index in sync with hardware
  (bsc#1012628).
- net: dsa: tag_mtk: fix 802.1ad VLAN egress (bsc#1012628).
- net: ethernet: mtk-star-emac: fix wrong unmap in RX handling
  (bsc#1012628).
- net/mlx4_en: update moderation when config reset (bsc#1012628).
- net: stmmac: fix incorrect DMA channel intr enable setting of
  EQoS v4.10 (bsc#1012628).
- nexthop: Do not flush blackhole nexthops when loopback goes down
  (bsc#1012628).
- net: sched: avoid duplicates in classes dump (bsc#1012628).
- net: mscc: ocelot: properly reject destination IP keys in VCAP
  IS1 (bsc#1012628).
- net: dsa: sja1105: fix SGMII PCS being forced to SPEED_UNKNOWN
  instead of SPEED_10 (bsc#1012628).
- net: usb: qmi_wwan: allow qmimux add/del with master up
  (bsc#1012628).
- netdevsim: init u64 stats for 32bit hardware (bsc#1012628).
- cipso,calipso: resolve a number of problems with the DOI
  refcounts (bsc#1012628).
- net: stmmac: Fix VLAN filter delete timeout issue in Intel
  mGBE SGMII (bsc#1012628).
- stmmac: intel: Fixes clock registration error seen for multiple
  interfaces (bsc#1012628).
- net: lapbether: Remove netif_start_queue / netif_stop_queue
  (bsc#1012628).
- net: davicom: Fix regulator not turned off on failed probe
  (bsc#1012628).
- net: davicom: Fix regulator not turned off on driver removal
  (bsc#1012628).
- net: enetc: allow hardware timestamping on TX queues with
  tc-etf enabled (bsc#1012628).
- net: qrtr: fix error return code of qrtr_sendmsg()
  (bsc#1012628).
- s390/qeth: fix memory leak after failed TX Buffer allocation
  (bsc#1012628).
- s390/qeth: improve completion of pending TX buffers
  (bsc#1012628).
- s390/qeth: schedule TX NAPI on QAOB completion (bsc#1012628).
- s390/qeth: fix notification for pending buffers during teardown
  (bsc#1012628).
- r8169: fix r8168fp_adjust_ocp_cmd function (bsc#1012628).
- ixgbe: fail to create xfrm offload of IPsec tunnel mode SA
  (bsc#1012628).
- tools/resolve_btfids: Fix build error with older host toolchains
  (bsc#1012628).
- perf build: Fix ccache usage in $(CC) when generating arch
  errno table (bsc#1012628).
- net: stmmac: stop each tx channel independently (bsc#1012628).
- net: stmmac: fix watchdog timeout during suspend/resume stress
  test (bsc#1012628).
- net: stmmac: fix wrongly set buffer2 valid when sph unsupport
  (bsc#1012628).
- ethtool: fix the check logic of at least one channel for RX/TX
  (bsc#1012628).
- net: phy: make mdio_bus_phy_suspend/resume as __maybe_unused
  (bsc#1012628).
- selftests: forwarding: Fix race condition in mirror installation
  (bsc#1012628).
- mlxsw: spectrum_ethtool: Add an external speed to PTYS register
  (bsc#1012628).
- perf traceevent: Ensure read cmdlines are null terminated
  (bsc#1012628).
- perf report: Fix -F for branch & mem modes (bsc#1012628).
- net: hns3: fix error mask definition of flow director
  (bsc#1012628).
- net: hns3: fix query vlan mask value error for flow director
  (bsc#1012628).
- net: hns3: fix bug when calculating the TCAM table info
  (bsc#1012628).
- s390/cio: return -EFAULT if copy_to_user() fails again
  (bsc#1012628).
- bnxt_en: reliably allocate IRQ table on reset to avoid crash
  (bsc#1012628).
- drm/fb-helper: only unmap if buffer not null (bsc#1012628).
- drm/compat: Clear bounce structures (bsc#1012628).
- drm/radeon: also init GEM funcs in
  radeon_gem_prime_import_sg_table (bsc#1012628).
- drm/amdgpu/display: use GFP_ATOMIC in
  dcn21_validate_bandwidth_fp() (bsc#1012628).
- drm/amd/display: Fix nested FPU context in
  dcn21_validate_bandwidth() (bsc#1012628).
- drm/amd/pm: correct the watermark settings for Polaris
  (bsc#1012628).
- drm/amd/pm: bug fix for pcie dpm (bsc#1012628).
- drm/amdgpu/display: don't assert in set backlight function
  (bsc#1012628 bsc#1180749).
- drm/shmem-helper: Check for purged buffers in fault handler
  (bsc#1012628).
- drm/shmem-helper: Don't remove the offset in vm_area_struct
  pgoff (bsc#1012628).
- drm: Use USB controller's DMA mask when importing dmabufs
  (bsc#1012628).
- drm/amdgpu: fix S0ix handling when the CONFIG_AMD_PMC=m
  (bsc#1012628).
- drm: meson_drv add shutdown function (bsc#1012628).
- drm/shmem-helpers: vunmap: Don't put pages for dma-buf
  (bsc#1012628).
- drm/i915: Wedge the GPU if command parser setup fails
  (bsc#1012628).
- s390/cio: return -EFAULT if copy_to_user() fails (bsc#1012628).
- s390/crypto: return -EFAULT if copy_to_user() fails
  (bsc#1012628).
- qxl: Fix uninitialised struct field head.surface_id
  (bsc#1012628).
- sh_eth: fix TRSCER mask for R7S9210 (bsc#1012628).
- media: usbtv: Fix deadlock on suspend (bsc#1012628).
- media: rkisp1: params: fix wrong bits settings (bsc#1012628).
- media: v4l: vsp1: Fix uif null pointer access (bsc#1012628).
- media: v4l: vsp1: Fix bru null pointer access (bsc#1012628).
- media: rc: compile rc-cec.c into rc-core (bsc#1012628).
- MIPS: kernel: Reserve exception base early to prevent corruption
  (bsc#1012628).
- mptcp: always graft subflow socket to parent (bsc#1012628).
- mptcp: reset last_snd on subflow close (bsc#1012628).
- i2c: rcar: faster irq code to minimize HW race condition
  (bsc#1012628).
- i2c: rcar: optimize cacheline to minimize HW race condition
  (bsc#1012628).
- scsi: pm80xx: Fix missing tag_free in NVMD DATA req
  (bsc#1012628).
- scsi: ufs: WB is only available on LUN #0 to #7 (bsc#1012628).
- scsi: ufs: Protect some contexts from unexpected clock scaling
  (bsc#1012628).
- udf: fix silent AED tagLocation corruption (bsc#1012628).
- iommu/vt-d: Clear PRQ overflow only when PRQ is empty
  (bsc#1012628).
- mmc: mxs-mmc: Fix a resource leak in an error handling path in
  'mxs_mmc_probe()' (bsc#1012628).
- mmc: mediatek: fix race condition between msdc_request_timeout
  and irq (bsc#1012628).
- mmc: sdhci-iproc: Add ACPI bindings for the RPi (bsc#1012628).
- platform/x86: amd-pmc: put device on error paths (bsc#1012628).
- Platform: OLPC: Fix probe error handling (bsc#1012628).
- powerpc/pci: Add ppc_md.discover_phbs() (bsc#1012628).
- spi: stm32: make spurious and overrun interrupts visible
  (bsc#1012628).
- powerpc: improve handling of unrecoverable system reset
  (bsc#1012628).
- powerpc/perf: Record counter overflow always if SAMPLE_IP is
  unset (bsc#1012628).
- HID: logitech-dj: add support for the new lightspeed connection
  iteration (bsc#1012628).
- powerpc/64: Fix stack trace not displaying final frame
  (bsc#1012628).
- iommu/amd: Fix performance counter initialization (bsc#1012628).
- clk: qcom: gdsc: Implement NO_RET_PERIPH flag (bsc#1012628).
- sparc32: Limit memblock allocation to low memory (bsc#1012628).
- sparc64: Use arch_validate_flags() to validate ADI flag
  (bsc#1012628).
- Input: applespi - don't wait for responses to commands
  indefinitely (bsc#1012628).
- PCI: xgene-msi: Fix race in installing chained irq handler
  (bsc#1012628).
- PCI: mediatek: Add missing of_node_put() to fix reference leak
  (bsc#1012628).
- drivers/base: build kunit tests without structleak plugin
  (bsc#1012628).
- PCI/LINK: Remove bandwidth notification (bsc#1012628).
- ext4: don't try to processed freed blocks until mballoc is
  initialized (bsc#1012628).
- kbuild: clamp SUBLEVEL to 255 (bsc#1012628).
- PCI: Fix pci_register_io_range() memory leak (bsc#1012628).
- i40e: Fix memory leak in i40e_probe (bsc#1012628).
- PCI/ERR: Retain status from error notification (bsc#1012628).
- kasan: fix memory corruption in kasan_bitops_tags test
  (bsc#1012628).
- s390/smp: __smp_rescan_cpus() - move cpumask away from stack
  (bsc#1012628).
- drivers/base/memory: don't store phys_device in memory blocks
  (bsc#1012628).
- sysctl.c: fix underflow value setting risk in vm_table
  (bsc#1012628).
- scsi: libiscsi: Fix iscsi_prep_scsi_cmd_pdu() error handling
  (bsc#1012628).
- scsi: target: core: Add cmd length set before cmd complete
  (bsc#1012628).
- scsi: target: core: Prevent underflow for service actions
  (bsc#1012628).
- clk: qcom: gpucc-msm8998: Add resets, cxc, fix flags on
  gpu_gx_gdsc (bsc#1012628).
- ALSA: hda/conexant: Add quirk for mute LED control on HP ZBook
  G5 (bsc#1012628).
- ALSA: hda/ca0132: Add Sound BlasterX AE-5 Plus support
  (bsc#1012628).
- ALSA: hda: Drop the BATCH workaround for AMD controllers
  (bsc#1012628).
- ALSA: usb-audio: Fix "cannot get freq eq" errors on Dell AE515
  sound bar (bsc#1012628).
- ALSA: usb-audio: Disable USB autosuspend properly in
  setup_disable_autosuspend() (bsc#1012628).
- ALSA: usb-audio: fix NULL ptr dereference in usb_audio_probe
  (bsc#1012628).
- ALSA: usb-audio: fix use after free in usb_audio_disconnect
  (bsc#1012628).
- opp: Don't drop extra references to OPPs accidentally
  (bsc#1012628).
- Revert 95ebabde382c ("capabilities: Don't allow writing
  ambiguous v3 file capabilities") (bsc#1012628).
- block: Discard page cache of zone reset target range
  (bsc#1012628).
- block: Try to handle busy underlying device on discard
  (bsc#1012628).
- arm64: kasan: fix page_alloc tagging with DEBUG_VIRTUAL
  (bsc#1012628).
- arm64: mte: Map hotplugged memory as Normal Tagged
  (bsc#1012628).
- arm64: perf: Fix 64-bit event counter read truncation
  (bsc#1012628).
- s390/dasd: fix hanging DASD driver unbind (bsc#1012628).
- s390/dasd: fix hanging IO request during DASD driver unbind
  (bsc#1012628).
- software node: Fix node registration (bsc#1012628).
- xen/events: reset affinity of 2-level event when tearing it down
  (bsc#1012628).
- xen/events: don't unmask an event channel when an eoi is pending
  (bsc#1012628).
- xen/events: avoid handling the same event on two cpus at the
  same time (bsc#1012628).
- mmc: mmci: Add MMC_CAP_NEED_RSP_BUSY for the stm32 variants
  (bsc#1012628).
- mmc: core: Fix partition switch time for eMMC (bsc#1012628).
- mmc: cqhci: Fix random crash when remove mmc module/card
  (bsc#1012628).
- cifs: do not send close in compound create+close requests
  (bsc#1012628).
- Goodix Fingerprint device is not a modem (bsc#1012628).
- USB: gadget: udc: s3c2410_udc: fix return value check in
  s3c2410_udc_probe() (bsc#1012628).
- USB: gadget: u_ether: Fix a configfs return code (bsc#1012628).
- usb: gadget: f_uac2: always increase endpoint max_packet_size
  by one audio slot (bsc#1012628).
- usb: gadget: f_uac1: stop playback on function disable
  (bsc#1012628).
- usb: dwc3: qcom: Add missing DWC3 OF node refcount decrement
  (bsc#1012628).
- usb: dwc3: qcom: add URS Host support for sdm845 ACPI boot
  (bsc#1012628).
- usb: dwc3: qcom: add ACPI device id for sc8180x (bsc#1012628).
- usb: dwc3: qcom: Honor wakeup enabled/disabled state
  (bsc#1012628).
- USB: usblp: fix a hang in poll() if disconnected (bsc#1012628).
- usb: renesas_usbhs: Clear PIPECFG for re-enabling pipe with
  other EPNUM (bsc#1012628).
- usb: xhci: do not perform Soft Retry for some xHCI hosts
  (bsc#1012628).
- xhci: Improve detection of device initiated wake signal
  (bsc#1012628).
- usb: xhci: Fix ASMedia ASM1042A and ASM3242 DMA addressing
  (bsc#1012628).
- xhci: Fix repeated xhci wake after suspend due to uncleared
  internal wake state (bsc#1012628).
- USB: serial: io_edgeport: fix memory leak in edge_startup
  (bsc#1012628).
- USB: serial: ch341: add new Product ID (bsc#1012628).
- USB: serial: cp210x: add ID for Acuity Brands nLight Air Adapter
  (bsc#1012628).
- USB: serial: cp210x: add some more GE USB IDs (bsc#1012628).
- usbip: fix stub_dev to check for stream socket (bsc#1012628).
- usbip: fix vhci_hcd to check for stream socket (bsc#1012628).
- usbip: fix vudc to check for stream socket (bsc#1012628).
- usbip: fix stub_dev usbip_sockfd_store() races leading to gpf
  (bsc#1012628).
- usbip: fix vhci_hcd attach_store() races leading to gpf
  (bsc#1012628).
- usbip: fix vudc usbip_sockfd_store races leading to gpf
  (bsc#1012628).
- Revert "serial: max310x: rework RX interrupt handling"
  (bsc#1012628).
- misc/pvpanic: Export module FDT device table (bsc#1012628).
- misc: fastrpc: restrict user apps from sending kernel RPC
  messages (bsc#1012628).
- staging: rtl8192u: fix ->ssid overflow in r8192_wx_set_scan()
  (bsc#1012628).
- staging: rtl8188eu: prevent ->ssid overflow in rtw_wx_set_scan()
  (bsc#1012628).
- staging: rtl8712: unterminated string leads to read overflow
  (bsc#1012628).
- staging: rtl8188eu: fix potential memory corruption in
  rtw_check_beacon_data() (bsc#1012628).
- staging: ks7010: prevent buffer overflow in ks_wlan_set_scan()
  (bsc#1012628).
- staging: rtl8712: Fix possible buffer overflow in
  r8712_sitesurvey_cmd (bsc#1012628).
- staging: rtl8192e: Fix possible buffer overflow in
  _rtl92e_wx_set_scan (bsc#1012628).
- staging: comedi: addi_apci_1032: Fix endian problem for COS
  sample (bsc#1012628).
- staging: comedi: addi_apci_1500: Fix endian problem for command
  sample (bsc#1012628).
- staging: comedi: adv_pci1710: Fix endian problem for AI command
  data (bsc#1012628).
- staging: comedi: das6402: Fix endian problem for AI command data
  (bsc#1012628).
- staging: comedi: das800: Fix endian problem for AI command data
  (bsc#1012628).
- staging: comedi: dmm32at: Fix endian problem for AI command data
  (bsc#1012628).
- staging: comedi: me4000: Fix endian problem for AI command data
  (bsc#1012628).
- staging: comedi: pcl711: Fix endian problem for AI command data
  (bsc#1012628).
- staging: comedi: pcl818: Fix endian problem for AI command data
  (bsc#1012628).
- mlxsw: spectrum_router: Ignore routes using a deleted nexthop
  object (bsc#1012628).
- net: phy: ti: take into account all possible interrupt sources
  (bsc#1012628).
- sh_eth: fix TRSCER mask for R7S72100 (bsc#1012628).
- powerpc/sstep: Fix VSX instruction emulation (bsc#1012628).
- net: macb: Add default usrio config to default gem config
  (bsc#1012628).
- cpufreq: qcom-hw: fix dereferencing freed memory 'data'
  (bsc#1012628).
- cpufreq: qcom-hw: Fix return value check in
  qcom_cpufreq_hw_cpu_init() (bsc#1012628).
- arm64/mm: Fix pfn_valid() for ZONE_DEVICE based memory
  (bsc#1012628).
- SUNRPC: Set memalloc_nofs_save() for sync tasks (bsc#1012628).
- NFS: Don't revalidate the directory permissions on a lookup
  failure (bsc#1012628).
- NFS: Don't gratuitously clear the inode cache when lookup failed
  (bsc#1012628).
- NFSv4.2: fix return value of _nfs4_get_security_label()
  (bsc#1012628).
- block: rsxx: fix error return code of rsxx_pci_probe()
  (bsc#1012628).
- drm/ttm: Fix TTM page pool accounting (bsc#1012628).
- nvme-fc: fix racing controller reset and create association
  (bsc#1012628).
- configfs: fix a use-after-free in __configfs_open_file
  (bsc#1012628).
- arm64: mm: use a 48-bit ID map when possible on 52-bit VA builds
  (bsc#1012628).
- io_uring: perform IOPOLL reaping if canceler is thread itself
  (bsc#1012628).
- drm/nouveau: fix dma syncing for loops (v2) (bsc#1012628).
- perf/arm_dmc620_pmu: Fix error return code in
  dmc620_pmu_device_probe() (bsc#1012628).
- net: expand textsearch ts_state to fit skb_seq_state
  (bsc#1012628).
- mptcp: put subflow sock on connect error (bsc#1012628).
- mptcp: fix memory accounting on allocation error (bsc#1012628).
- perf/core: Flush PMU internal buffers for per-CPU events
  (bsc#1012628).
- perf/x86/intel: Set PERF_ATTACH_SCHED_CB for large PEBS and LBR
  (bsc#1012628).
- hrtimer: Update softirq_expires_next correctly after
  __hrtimer_get_next_event() (bsc#1012628).
- powerpc/64s/exception: Clean up a missed SRR specifier
  (bsc#1012628).
- seqlock,lockdep: Fix seqcount_latch_init() (bsc#1012628).
- memblock: fix section mismatch warning (bsc#1012628).
- stop_machine: mark helpers __always_inline (bsc#1012628).
- include/linux/sched/mm.h: use rcu_dereference in in_vfork()
  (bsc#1012628).
- zram: fix return value on writeback_store (bsc#1012628).
- zram: fix broken page writeback (bsc#1012628).
- linux/compiler-clang.h: define HAVE_BUILTIN_BSWAP*
  (bsc#1012628).
- sched: Fix migration_cpu_stop() requeueing (bsc#1012628).
- sched/membarrier: fix missing local execution of
  ipi_sync_rq_state() (bsc#1012628).
- sched: Collate affine_move_task() stoppers (bsc#1012628).
- sched: Simplify migration_cpu_stop() (bsc#1012628).
- sched: Optimize migration_cpu_stop() (bsc#1012628).
- sched: Fix affine_move_task() self-concurrency (bsc#1012628).
- sched: Simplify set_affinity_pending refcounts (bsc#1012628).
- efi: stub: omit SetVirtualAddressMap() if marked unsupported
  in RT_PROP table (bsc#1012628).
- powerpc/64s: Fix instruction encoding for lis in
  ppc_function_entry() (bsc#1012628).
- powerpc: Fix inverted SET_FULL_REGS bitop (bsc#1012628).
- powerpc: Fix missing declaration of [en/dis]able_kernel_vsx()
  (bsc#1012628).
- binfmt_misc: fix possible deadlock in bm_register_write
  (bsc#1012628).
- kasan, mm: fix crash with HW_TAGS and DEBUG_PAGEALLOC
  (bsc#1012628).
- kasan: fix KASAN_STACK dependency for HW_TAGS (bsc#1012628).
- x86/unwind/orc: Disable KASAN checking in the ORC unwinder,
  part 2 (bsc#1012628).
- x86/sev-es: Introduce ip_within_syscall_gap() helper
  (bsc#1012628).
- x86/sev-es: Check regs->sp is trusted before adjusting #VC
  IST stack (bsc#1012628).
- x86/sev-es: Correctly track IRQ states in runtime #VC handler
  (bsc#1012628).
- x86/sev-es: Use __copy_from_user_inatomic() (bsc#1012628).
- x86/entry: Fix entry/exit mismatch on failed fast 32-bit
  syscalls (bsc#1012628).
- KVM: x86: Ensure deadline timer has truly expired before
  posting its IRQ (bsc#1012628).
- KVM: kvmclock: Fix vCPUs > 64 can't be online/hotpluged
  (bsc#1012628).
- KVM: arm64: Ensure I-cache isolation between vcpus of a same VM
  (bsc#1012628).
- KVM: arm64: Fix range alignment when walking page tables
  (bsc#1012628).
- KVM: arm64: Avoid corrupting vCPU context register in guest exit
  (bsc#1012628).
- KVM: arm64: nvhe: Save the SPE context early (bsc#1012628).
- KVM: arm64: Reject VM creation when the default IPA size is
  unsupported (bsc#1012628).
- KVM: arm64: Fix exclusive limit for IPA size (bsc#1012628).
- mm/highmem.c: fix zero_user_segments() with start > end
  (bsc#1012628).
- mm/userfaultfd: fix memory corruption due to writeprotect
  (bsc#1012628).
- mm/madvise: replace ptrace attach requirement for
  process_madvise (bsc#1012628).
- mm/memcg: set memcg when splitting page (bsc#1012628).
- mm/memcg: rename mem_cgroup_split_huge_fixup to split_page_memcg
  and add nr_pages argument (bsc#1012628).
- mm/page_alloc.c: refactor initialization of struct page for
  holes in memory layout (bsc#1012628).
- KVM: arm64: Fix nVHE hyp panic host context restore
  (bsc#1012628).
- Delete
  patches.suse/drm-amdgpu-display-don-t-assert-in-set-backlight-fun.patch.
- commit 01db39a
* Tue Mar 16 2021 tiwai@suse.de
- drm/i915/ilk-glk: Fix link training on links with LTTPRs
  (bsc#1183294).
- commit 424e43f
* Tue Mar 16 2021 tiwai@suse.de
- Update config files: enable CONFIG_BMP280=m for x86 (bsc#1183198)
- commit e29c84f
* Mon Mar 15 2021 jslaby@suse.cz
- Refresh
  patches.rpmify/kbuild-dummy-tools-fix-inverted-tests-for-gcc.patch.
- Refresh
  patches.rpmify/kbuild-dummy-tools-support-MPROFILE_KERNEL-checks-fo.patch.
- Refresh
  patches.suse/ALSA-hda-Avoid-spurious-unsol-event-handling-during-.patch.
- Refresh
  patches.suse/ALSA-hda-Flush-pending-unsolicited-events-before-sus.patch.
- Refresh
  patches.suse/ALSA-hda-hdmi-Cancel-pending-works-before-suspend.patch.
- Refresh
  patches.suse/ALSA-usb-Add-Plantronics-C320-M-USB-ctrl-msg-delay-q.patch.
- Refresh
  patches.suse/ALSA-usb-audio-Apply-the-control-quirk-to-Plantronic.patch.
  Update upstream status.
- commit 3222af6
* Mon Mar 15 2021 mkubecek@suse.cz
- Update to 5.12-rc3
- eliminated 3 patches
  - patches.rpmify/kbuild-dummy-tools-adjust-to-scripts-cc-version.sh.patch
  - patches.rpmify/kbuild-dummy-tools-fix-inverted-tests-for-gcc.patch
  - patches.rpmify/kbuild-dummy-tools-support-MPROFILE_KERNEL-checks-fo.patch
- update configs
  - COMPILE_TEST=n (s390x)
  - TMPFS_INODE64=y (s390x)
- commit 89b1f10
* Sun Mar 14 2021 mkubecek@suse.cz
- config: update with dummy toolchain
- new config options:
  - GCC_PLUGINS=y
  - GCC_PLUGIN_CYC_COMPLEXITY is not set
  - GCC_PLUGIN_LATENT_ENTROPY is not set
  - GCC_PLUGIN_RANDSTRUCT is not set
  - GCC_PLUGIN_STRUCTLEAK_USER is not set
  - GCC_PLUGIN_STRUCTLEAK_BYREF is not set
  - GCC_PLUGIN_STRUCTLEAK_BYREF_ALL is not set
- commit 6e44961
* Sun Mar 14 2021 tiwai@suse.de
- drm/amd/display: Revert dram_clock_change_latency for DCN2.1
  (bsc#1183424).
- drm/amd/display: Copy over soc values before bounding box
  creation (bsc#1183424).
- commit bd60fa9
* Fri Mar 12 2021 tiwai@suse.de
- Refresh media fixes to the upstreamed version (bsc#1181104)
  Refreshed:
  patches.suse/media-dvb-usb-Fix-memory-leak-at-error-in-dvb_usb_de.patch
  patches.suse/media-dvb-usb-Fix-use-after-free-access.patch
- commit 101728a
* Thu Mar 11 2021 jslaby@suse.cz
- Linux 5.11.6 (bsc#1012628).
- nvme-pci: add quirks for Lexar 256GB SSD (bsc#1012628).
- nvme-pci: mark Seagate Nytro XM1440 as QUIRK_NO_NS_DESC_LIST
  (bsc#1012628).
- KVM: SVM: Clear the CR4 register on reset (bsc#1012628).
- scsi: ufs: Fix a duplicate dev quirk number (bsc#1012628).
- ASoC: Intel: sof_sdw: add quirk for HP Spectre x360 convertible
  (bsc#1012628).
- ASoC: Intel: sof_sdw: reorganize quirks by generation
  (bsc#1012628).
- PCI: cadence: Retrain Link to work around Gen2 training defect
  (bsc#1012628).
- HID: ite: Enable QUIRK_TOUCHPAD_ON_OFF_REPORT on Acer Aspire
  Switch 10E (bsc#1012628).
- ALSA: usb-audio: add mixer quirks for Pioneer DJM-900NXS2
  (bsc#1012628).
- ALSA: usb-audio: Add DJM750 to Pioneer mixer quirk
  (bsc#1012628).
- HID: i2c-hid: Add I2C_HID_QUIRK_NO_IRQ_AFTER_RESET for ITE8568
  EC on Voyo Winpad A15 (bsc#1012628).
- mmc: sdhci-of-dwcmshc: set SDHCI_QUIRK2_PRESET_VALUE_BROKEN
  (bsc#1012628).
- drm/msm/a5xx: Remove overwriting A5XX_PC_DBG_ECO_CNTL register
  (bsc#1012628).
- scsi: ufs: ufs-exynos: Use UFSHCD_QUIRK_ALIGN_SG_WITH_PAGE_SIZE
  (bsc#1012628).
- scsi: ufs: ufs-exynos: Apply vendor-specific values for three
  timeouts (bsc#1012628).
- scsi: ufs: Introduce a quirk to allow only page-aligned sg
  entries (bsc#1012628).
- misc: eeprom_93xx46: Add quirk to support Microchip 93LC46B
  eeprom (bsc#1012628).
- scsi: ufs: Add a quirk to permit overriding UniPro defaults
  (bsc#1012628).
- scsi: ufs-mediatek: Enable
  UFSHCI_QUIRK_SKIP_MANUAL_WB_FLUSH_CTRL (bsc#1012628).
- iommu/amd: Fix sleeping in atomic in increase_address_space()
  (bsc#1012628).
- btrfs: don't flush from btrfs_delayed_inode_reserve_metadata
  (bsc#1012628).
- btrfs: export and rename qgroup_reserve_meta (bsc#1012628).
- arm64: Make CPU_BIG_ENDIAN depend on ld.bfd or ld.lld 13.0.0+
  (bsc#1012628).
- parisc: Enable -mlong-calls gcc option with CONFIG_COMPILE_TEST
  (bsc#1012628).
- nvme-pci: mark Kingston SKC2000 as not supporting the deepest
  power state (bsc#1012628).
- media: cedrus: Remove checking for required controls
  (bsc#1012628).
- io_uring: don't take uring_lock during iowq cancel
  (bsc#1012628).
- io_uring/io-wq: return 2-step work swap scheme (bsc#1012628).
- io_uring/io-wq: kill off now unused IO_WQ_WORK_NO_CANCEL
  (bsc#1012628).
- io_uring: get rid of intermediate IORING_OP_CLOSE stage
  (bsc#1012628).
- fs: provide locked helper variant of close_fd_get_file()
  (bsc#1012628).
- io_uring: deduplicate failing task_work_add (bsc#1012628).
- io_uring: unpark SQPOLL thread for cancelation (bsc#1012628).
- io_uring: deduplicate core cancellations sequence (bsc#1012628).
- io_uring: fix inconsistent lock state (bsc#1012628).
- commit 7358b30
* Wed Mar 10 2021 tiwai@suse.de
- ALSA: hda/hdmi: Cancel pending works before suspend
  (bsc#1182377).
- ALSA: hda: Avoid spurious unsol event handling during S3/S4
  (bsc#1182377).
- ALSA: hda: Flush pending unsolicited events before suspend
  (bsc#1182377).
- commit 85f6d4b
* Wed Mar 10 2021 jslaby@suse.cz
- rpm/check-for-config-changes: comment on the list
  To explain what it actually is.
- commit e94bacf
* Wed Mar 10 2021 jslaby@suse.cz
- ACPICA: Fix race in generic_serial_bus (I2C) and GPIO op_region
  parameter handling (bsc#1012628).
- rpm/check-for-config-changes: define ignores more strictly
  * search for whole words, so make wildcards explicit
  * use ' for quoting
  * prepend CONFIG_ dynamically, so it need not be in the list
- commit 7b06a8c
* Wed Mar 10 2021 jslaby@suse.cz
- rpm/check-for-config-changes: sort the ignores
  They are growing so to make them searchable by humans.
- commit 67c6b55
* Wed Mar 10 2021 jslaby@suse.cz
- rpm/check-for-config-changes: add -mrecord-mcount ignore
  Added by 3b15cdc15956 (tracing: move function tracer options to Kconfig)
  upstream.
- commit 018b013
* Wed Mar 10 2021 jslaby@suse.cz
- Refresh
  patches.rpmify/kbuild-dummy-tools-fix-inverted-tests-for-gcc.patch.
- Refresh
  patches.rpmify/kbuild-dummy-tools-support-MPROFILE_KERNEL-checks-fo.patch.
  Update upstream status.
- commit c867c19
* Wed Mar 10 2021 jslaby@suse.cz
- kbuild: dummy-tools: adjust to scripts/cc-version.sh
  (bsc#1181862).
- commit cfbfafc
* Tue Mar  9 2021 msuchanek@suse.de
- Delete patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch.
  Should not be needed anymore with dummy-tools.
- commit 41fc82c
* Tue Mar  9 2021 jslaby@suse.cz
- Linux 5.11.5 (bsc#1012628).
- ALSA: hda/realtek: Enable headset mic of Acer SWIFT with ALC256
  (bsc#1012628).
- ALSA: usb-audio: use Corsair Virtuoso mapping for Corsair
  Virtuoso SE (bsc#1012628).
- ALSA: usb-audio: Don't abort even if the clock rate differs
  (bsc#1012628).
- ALSA: usb-audio: Drop bogus dB range in too low level
  (bsc#1012628).
- ALSA: usb-audio: Allow modifying parameters with succeeding
  hw_params calls (bsc#1012628).
- tpm, tpm_tis: Decorate tpm_tis_gen_interrupt() with
  request_locality() (bsc#1012628).
- tpm, tpm_tis: Decorate tpm_get_timeouts() with
  request_locality() (bsc#1012628).
- btrfs: avoid double put of block group when emptying cluster
  (bsc#1012628).
- btrfs: fix raid6 qstripe kmap (bsc#1012628).
- btrfs: fix race between writes to swap files and scrub
  (bsc#1012628).
- btrfs: fix race between swap file activation and snapshot
  creation (bsc#1012628).
- btrfs: fix stale data exposure after cloning a hole with
  NO_HOLES enabled (bsc#1012628).
- btrfs: tree-checker: do not error out if extent ref hash
  doesn't match (bsc#1012628).
- btrfs: fix race between extent freeing/allocation when using
  bitmaps (bsc#1012628).
- btrfs: validate qgroup inherit for SNAP_CREATE_V2 ioctl
  (bsc#1012628).
- btrfs: free correct amount of space in
  btrfs_delayed_inode_reserve_metadata (bsc#1012628).
- btrfs: fix spurious free_space_tree remount warning
  (bsc#1012628).
- btrfs: unlock extents in btrfs_zero_range in case of quota
  reservation errors (bsc#1012628).
- btrfs: fix warning when creating a directory with smack enabled
  (bsc#1012628).
- PM: runtime: Update device status before letting suppliers
  suspend (bsc#1012628).
- ring-buffer: Force before_stamp and write_stamp to be different
  on discard (bsc#1012628).
- io_uring: ignore double poll add on the same waitqueue head
  (bsc#1012628).
- dm bufio: subtract the number of initial sectors in
  dm_bufio_get_device_size (bsc#1012628).
- dm verity: fix FEC for RS roots unaligned to block size
  (bsc#1012628).
- drm/amd/pm: correct Arcturus mmTHM_BACO_CNTL register address
  (bsc#1012628).
- drm/amdgpu:disable VCN for Navi12 SKU (bsc#1012628).
- drm/amdgpu: Only check for S0ix if AMD_PMC is configured
  (bsc#1012628).
- drm/amdgpu: fix parameter error of RREG32_PCIE() in
  amdgpu_regs_pcie (bsc#1012628).
- crypto - shash: reduce minimum alignment of shash_desc structure
  (bsc#1012628).
- ALSA: ctxfi: cthw20k2: fix mask on conf to allow 4 bits
  (bsc#1012628).
- RDMA/cm: Fix IRQ restore in ib_send_cm_sidr_rep (bsc#1012628).
- RDMA/rxe: Fix missing kconfig dependency on CRYPTO
  (bsc#1012628).
- IB/mlx5: Add missing error code (bsc#1012628).
- ALSA: hda: intel-nhlt: verify config type (bsc#1012628).
- ftrace: Have recordmcount use w8 to read relp->r_info in
  arm64_is_fake_mcount (bsc#1012628).
- ia64: don't call handle_signal() unless there's actually a
  signal queued (bsc#1012628).
- rsxx: Return -EFAULT if copy_to_user() fails (bsc#1012628).
- iommu/tegra-smmu: Fix mc errors on tegra124-nyan (bsc#1012628).
- iommu: Don't use lazy flush for untrusted device (bsc#1012628).
- iommu/vt-d: Fix status code for Allocate/Free PASID command
  (bsc#1012628).
- btrfs: zoned: use sector_t for zone sectors (bsc#1012628).
- tomoyo: recognize kernel threads correctly (bsc#1012628).
- r8169: fix resuming from suspend on RTL8105e if machine runs
  on battery (bsc#1012628).
- commit d09469d
* Tue Mar  9 2021 tiwai@suse.de
- ALSA: usb-audio: Apply the control quirk to Plantronics headsets
  (bsc#1182552).
- ALSA: usb: Add Plantronics C320-M USB ctrl msg delay quirk
  (bsc#1182552).
- commit f99c94c
* Mon Mar  8 2021 jslaby@suse.cz
- kbuild: dummy-tools, support MPROFILE_KERNEL checks for ppc
  (bsc#1181862).
- commit c4424c2
* Mon Mar  8 2021 jslaby@suse.cz
- Delete
  patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch.
  With dummy-tools, this is no longer needed.
- commit 84a32d6
* Mon Mar  8 2021 jslaby@suse.cz
- Update config files.
  Just oldconfig.
- commit e687fe8
* Mon Mar  8 2021 jslaby@suse.cz
- ALSA: usb-audio: Fix Pioneer DJM devices URB_CONTROL request
  direction to set samplerate (git-fixes).
- commit be77cd2
* Sun Mar  7 2021 jslaby@suse.cz
- blacklist.conf: add a typo fix
- commit 2ae3683
* Sun Mar  7 2021 jslaby@suse.cz
- Linux 5.11.4 (bsc#1012628).
- ALSA: hda/realtek: Apply dual codec quirks for MSI Godlike
  X570 board (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Intel NUC 10 (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Clevo NH55RZQ (bsc#1012628).
- phy: mediatek: Add missing MODULE_DEVICE_TABLE() (bsc#1012628).
- tty: teach the n_tty ICANON case about the new "cookie
  continuations" too (bsc#1012628).
- tty: teach n_tty line discipline about the new "cookie
  continuations" (bsc#1012628).
- tty: clean up legacy leftovers from n_tty line discipline
  (bsc#1012628).
- tty: fix up hung_up_tty_read() conversion (bsc#1012628).
- tty: fix up iterate_tty_read() EOVERFLOW handling (bsc#1012628).
- swap: fix swapfile read/write offset (bsc#1012628).
- xen: fix p2m size in dom0 for disabled memory hotplug case
  (bsc#1012628).
- xen-netback: respect gnttab_map_refs()'s return value
  (bsc#1012628).
- Xen/gnttab: handle p2m update errors on a per-slot basis
  (bsc#1012628).
- scsi: iscsi: Verify lengths on passthrough PDUs (bsc#1012628).
- scsi: iscsi: Ensure sysfs attributes are limited to PAGE_SIZE
  (bsc#1012628).
- scsi: iscsi: Restrict sessions and handles to admin capabilities
  (bsc#1012628).
- ASoC: Intel: bytcr_rt5640: Add quirk for the Acer One S1002
  tablet (bsc#1012628).
- ASoC: Intel: bytcr_rt5651: Add quirk for the Jumper EZpad 7
  tablet (bsc#1012628).
- ASoC: Intel: bytcr_rt5640: Add quirk for the Voyo Winpad A15
  tablet (bsc#1012628).
- ASoC: Intel: bytcr_rt5640: Add quirk for the Estar Beauty HD
  MID 7316R tablet (bsc#1012628).
- sched/features: Fix hrtick reprogramming (bsc#1012628).
- parisc: Bump 64-bit IRQ stack size to 64 KB (bsc#1012628).
- ASoC: Intel: sof_sdw: detect DMIC number based on mach params
  (bsc#1012628).
- ASoC: Intel: sof-sdw: indent and add quirks consistently
  (bsc#1012628).
- perf/x86/kvm: Add Cascade Lake Xeon steppings to
  isolation_ucodes[] (bsc#1012628).
- btrfs: fix error handling in commit_fs_roots (bsc#1012628).
- ASoC: Intel: Add DMI quirk table to soc_intel_is_byt_cr()
  (bsc#1012628).
- ALSA: usb-audio: Add DJM-450 to the quirks table (bsc#1012628).
- ALSA: usb-audio: Add DJM450 to Pioneer format quirk
  (bsc#1012628).
- nvme-tcp: add clean action for failed reconnection
  (bsc#1012628).
- nvme-rdma: add clean action for failed reconnection
  (bsc#1012628).
- nvme-core: add cancel tagset helpers (bsc#1012628).
- f2fs: fix to set/clear I_LINKABLE under i_lock (bsc#1012628).
- f2fs: handle unallocated section and zone on pinned/atgc
  (bsc#1012628).
- media: uvcvideo: Allow entities with no pads (bsc#1012628).
- drm/amd/amdgpu: add error handling to
  amdgpu_virt_read_pf2vf_data (bsc#1012628).
- drm/amd/display: Guard against NULL pointer deref when
  get_i2c_info fails (bsc#1012628).
- ALSA: usb-audio: Add support for Pioneer DJM-750 (bsc#1012628).
- ASoC: Intel: bytcr_rt5640: Add new BYT_RT5640_NO_SPEAKERS
  quirk-flag (bsc#1012628).
- PCI: Add a REBAR size quirk for Sapphire RX 5600 XT Pulse
  (bsc#1012628).
- drm/amdgpu: Add check to prevent IH overflow (bsc#1012628).
- fs: make unlazy_walk() error handling consistent (bsc#1012628).
- crypto: tcrypt - avoid signed overflow in byte count
  (bsc#1012628).
- drm/hisilicon: Fix use-after-free (bsc#1012628).
- wilc1000: Fix use of void pointer as a wrong struct type
  (bsc#1012628).
- brcmfmac: Add DMI nvram filename quirk for Voyo winpad A15
  tablet (bsc#1012628).
- brcmfmac: Add DMI nvram filename quirk for Predia Basic tablet
  (bsc#1012628).
- net: ipa: avoid field overflow (bsc#1012628).
- staging: bcm2835-audio: Replace unsafe strcpy() with strscpy()
  (bsc#1012628).
- staging: most: sound: add sanity check for function argument
  (bsc#1012628).
- Bluetooth: Fix null pointer dereference in
  amp_read_loc_assoc_final_data (bsc#1012628).
- Bluetooth: Add new HCI_QUIRK_NO_SUSPEND_NOTIFIER quirk
  (bsc#1012628).
- net: sfp: add mode quirk for GPON module Ubiquiti U-Fiber
  Instant (bsc#1012628).
- ath10k: fix wmi mgmt tx queue full due to race condition
  (bsc#1012628).
- pktgen: fix misuse of BUG_ON() in pktgen_thread_worker()
  (bsc#1012628).
- mt76: mt7615: reset token when mac_reset happens (bsc#1012628).
- mt76: mt7915: reset token when mac_reset happens (bsc#1012628).
- selftests/bpf: Remove memory leak (bsc#1012628).
- Bluetooth: btusb: fix memory leak on suspend and resume
  (bsc#1012628).
- Bluetooth: hci_h5: Set HCI_QUIRK_SIMULTANEOUS_DISCOVERY for
  btrtl (bsc#1012628).
- wlcore: Fix command execute failure 19 for wl12xx (bsc#1012628).
- vt/consolemap: do font sum unsigned (bsc#1012628).
- can: flexcan: add CAN wakeup function for i.MX8QM (bsc#1012628).
- x86/reboot: Add Zotac ZBOX CI327 nano PCI reboot quirk
  (bsc#1012628).
- staging: fwserial: Fix error handling in fwserial_create
  (bsc#1012628).
- EDAC/amd64: Do not load on family 0x15, model 0x13
  (bsc#1012628).
- ath10k: prevent deinitializing NAPI twice (bsc#1012628).
- ASoC: qcom: Remove useless debug print (bsc#1012628).
- dt-bindings: net: btusb: DT fix
  s/interrupt-name/interrupt-names/ (bsc#1012628).
- dt-bindings: ethernet-controller: fix fixed-link specification
  (bsc#1012628).
- net: fix dev_ifsioc_locked() race condition (bsc#1012628).
- net: psample: Fix netlink skb length with tunnel info
  (bsc#1012628).
- net: hsr: add support for EntryForgetTime (bsc#1012628).
- net: ag71xx: remove unnecessary MTU reservation (bsc#1012628).
- net: dsa: tag_rtl4_a: Support also egress tags (bsc#1012628).
- net/sched: cls_flower: Reject invalid ct_state flags rules
  (bsc#1012628).
- net: bridge: use switchdev for port flags set through sysfs too
  (bsc#1012628).
- mptcp: fix DATA_FIN generation on early shutdown (bsc#1012628).
- mptcp: do not wakeup listener for MPJ subflows (bsc#1012628).
- tcp: fix tcp_rmem documentation (bsc#1012628).
- RDMA/rtrs-srv: Do not signal REG_MR (bsc#1012628).
- RDMA/rtrs-clt: Use bitmask to check sess->flags (bsc#1012628).
- RDMA/rtrs: Do not signal for heatbeat (bsc#1012628).
- vfio/type1: Use follow_pte() (bsc#1012628).
- mm/hugetlb.c: fix unnecessary address expansion of pmd sharing
  (bsc#1012628).
- nbd: handle device refs for DESTROY_ON_DISCONNECT properly
  (bsc#1012628).
- riscv: Get rid of MAX_EARLY_MAPPING_SIZE (bsc#1012628).
- mptcp: fix spurious retransmissions (bsc#1012628).
- net: fix up truesize of cloned skb in skb_prepare_for_shift()
  (bsc#1012628).
- tomoyo: ignore data race while checking quota (bsc#1012628).
- smackfs: restrict bytes count in smackfs write functions
  (bsc#1012628).
- net/af_iucv: remove WARN_ONCE on malformed RX packets
  (bsc#1012628).
- xfs: Fix assert failure in xfs_setattr_size() (bsc#1012628).
- media: zr364xx: fix memory leaks in probe() (bsc#1012628).
- media: v4l2-ctrls.c: fix shift-out-of-bounds in std_validate
  (bsc#1012628).
- erofs: fix shift-out-of-bounds of blkszbits (bsc#1012628).
- media: mceusb: sanity check for prescaler value (bsc#1012628).
- udlfb: Fix memory leak in dlfb_usb_probe (bsc#1012628).
- sched/core: Allow try_invoke_on_locked_down_task() with irqs
  disabled (bsc#1012628).
- JFS: more checks for invalid superblock (bsc#1012628).
- x86/build: Treat R_386_PLT32 relocation as R_386_PC32
  (bsc#1012628).
- iwlwifi: add new cards for So and Qu family (bsc#1012628).
- net: usb: qmi_wwan: support ZTE P685M modem (bsc#1012628).
- commit 43a5c33
* Sun Mar  7 2021 mkubecek@suse.cz
- Update to 5.12-rc2
- eliminated 1 patch
  - patches.suse/swap-fix-swapfile-read-write-offset.patch
- update configs
  - KVM_XEN=n (x86)
  - SND_SOC_SOF_MERRIFIELD=m (i386)
- commit d9388fc
* Sat Mar  6 2021 tiwai@suse.de
- drm/amd/display: Add a backlight module option (bsc#1180749).
- drm/amdgpu/display: handle aux backlight in
  backlight_get_brightness (bsc#1180749).
- drm/amdgpu/display: don't assert in set backlight function
  (bsc#1180749).
- drm/amdgpu/display: simplify backlight setting (bsc#1180749).
- commit 24ee23f
* Fri Mar  5 2021 dmueller@suse.com
- ARMv6/v7: Update config files. (bsc#1183009)
  enable CONFIG_ARM_MODULE_PLTS to fix module loading issues
- commit 501199e
* Fri Mar  5 2021 jslaby@suse.cz
- rpm/check-for-config-changes: declare sed args as an array
  So that we can reuse it in both seds.
  This also introduces IGNORED_CONFIGS_RE array which can be easily
  extended.
- commit a1976d2
* Thu Mar  4 2021 jslaby@suse.cz
- blacklist.conf: add a /proc revert
- commit 87aa54e
* Thu Mar  4 2021 jslaby@suse.cz
- Linux 5.11.3 (bsc#1012628).
- vmlinux.lds.h: add DWARF v5 sections (bsc#1012628).
- vdpa/mlx5: fix param validation in mlx5_vdpa_get_config()
  (bsc#1012628).
- debugfs: be more robust at handling improper input in
  debugfs_lookup() (bsc#1012628).
- debugfs: do not attempt to create a new file before the
  filesystem is initalized (bsc#1012628).
- driver core: auxiliary bus: Fix calling stage for auxiliary
  bus init (bsc#1012628).
- scsi: libsas: docs: Remove notify_ha_event() (bsc#1012628).
- scsi: qla2xxx: Fix mailbox Ch erroneous error (bsc#1012628).
- kdb: Make memory allocations more robust (bsc#1012628).
- w1: w1_therm: Fix conversion result for negative temperatures
  (bsc#1012628).
- PCI: qcom: Use PHY_REFCLK_USE_PAD only for ipq8064
  (bsc#1012628).
- PCI: Decline to resize resources if boot config must be
  preserved (bsc#1012628).
- virt: vbox: Do not use wait_event_interruptible when called
  from kernel context (bsc#1012628).
- bfq: Avoid false bfq queue merging (bsc#1012628).
- ALSA: usb-audio: Fix PCM buffer allocation in non-vmalloc mode
  (bsc#1012628).
- zsmalloc: account the number of compacted pages correctly
  (bsc#1012628).
- MIPS: vmlinux.lds.S: add missing PAGE_ALIGNED_DATA() section
  (bsc#1012628).
- vmlinux.lds.h: Define SANTIZER_DISCARDS with
  CONFIG_GCOV_KERNEL=y (bsc#1012628).
- random: fix the RNDRESEEDCRNG ioctl (bsc#1012628).
- ALSA: pcm: Call sync_stop at disconnection (bsc#1012628).
- ALSA: pcm: Assure sync with the pending stop operation at
  suspend (bsc#1012628).
- ALSA: pcm: Don't call sync_stop if it hasn't been stopped
  (bsc#1012628).
- drm/i915/gt: One more flush for Baytrail clear residuals
  (bsc#1012628).
- ath10k: Fix error handling in case of CE pipe init failure
  (bsc#1012628).
- Bluetooth: btqcomsmd: Fix a resource leak in error handling
  paths in the probe function (bsc#1012628).
- Bluetooth: hci_uart: Fix a race for write_work scheduling
  (bsc#1012628).
- Bluetooth: Fix initializing response id after clearing struct
  (bsc#1012628).
- arm64: dts: renesas: beacon kit: Fix choppy Bluetooth Audio
  (bsc#1012628).
- arm64: dts: renesas: beacon: Fix audio-1.8V pin enable
  (bsc#1012628).
- ARM: dts: exynos: correct PMIC interrupt trigger level on
  Artik 5 (bsc#1012628).
- ARM: dts: exynos: correct PMIC interrupt trigger level on Monk
  (bsc#1012628).
- ARM: dts: exynos: correct PMIC interrupt trigger level on Rinato
  (bsc#1012628).
- ARM: dts: exynos: correct PMIC interrupt trigger level on Spring
  (bsc#1012628).
- ARM: dts: exynos: correct PMIC interrupt trigger level on
  Arndale Octa (bsc#1012628).
- ARM: dts: exynos: correct PMIC interrupt trigger level on
  Odroid XU3 family (bsc#1012628).
- arm64: dts: exynos: correct PMIC interrupt trigger level on TM2
  (bsc#1012628).
- arm64: dts: exynos: correct PMIC interrupt trigger level on
  Espresso (bsc#1012628).
- memory: mtk-smi: Fix PM usage counter unbalance in mtk_smi ops
  (bsc#1012628).
- Bluetooth: hci_qca: Fix memleak in qca_controller_memdump
  (bsc#1012628).
- staging: vchiq: Fix bulk userdata handling (bsc#1012628).
- staging: vchiq: Fix bulk transfers on 64-bit builds
  (bsc#1012628).
- arm64: dts: qcom: msm8916-samsung-a5u: Fix iris compatible
  (bsc#1012628).
- net: stmmac: dwmac-meson8b: fix enabling the timing-adjustment
  clock (bsc#1012628).
- bpf: Add bpf_patch_call_args prototype to include/linux/bpf.h
  (bsc#1012628).
- bpf: Avoid warning when re-casting __bpf_call_base into
  __bpf_call_base_args (bsc#1012628).
- firmware: arm_scmi: Fix call site of scmi_notification_exit
  (bsc#1012628).
- arm64: dts: allwinner: A64: properly connect USB PHY to port 0
  (bsc#1012628).
- arm64: dts: allwinner: H6: properly connect USB PHY to port 0
  (bsc#1012628).
- arm64: dts: allwinner: Drop non-removable from SoPine/LTS SD
  card (bsc#1012628).
- arm64: dts: allwinner: H6: Allow up to 150 MHz MMC bus frequency
  (bsc#1012628).
- arm64: dts: allwinner: A64: Limit MMC2 bus frequency to 150 MHz
  (bsc#1012628).
- arm64: dts: qcom: msm8916-samsung-a2015: Fix sensors
  (bsc#1012628).
- cpufreq: brcmstb-avs-cpufreq: Free resources in error path
  (bsc#1012628).
- cpufreq: brcmstb-avs-cpufreq: Fix resource leaks in ->remove()
  (bsc#1012628).
- arm64: dts: rockchip: rk3328: Add clock_in_out property to
  gmac2phy node (bsc#1012628).
- ACPICA: Fix exception code class checks (bsc#1012628).
- usb: gadget: u_audio: Free requests only after callback
  (bsc#1012628).
- arm64: dts: qcom: sdm845-db845c: Fix reset-pin of ov8856 node
  (bsc#1012628).
- soc: qcom: socinfo: Fix an off by one in qcom_show_pmic_model()
  (bsc#1012628).
- soc: ti: pm33xx: Fix some resource leak in the error handling
  paths of the probe function (bsc#1012628).
- staging: media: atomisp: Fix size_t format specifier in
  hmm_alloc() debug statemenet (bsc#1012628).
- Bluetooth: drop HCI device reference before return
  (bsc#1012628).
- Bluetooth: Put HCI device if inquiry procedure interrupts
  (bsc#1012628).
- memory: ti-aemif: Drop child node when jumping out loop
  (bsc#1012628).
- ARM: dts: Configure missing thermal interrupt for 4430
  (bsc#1012628).
- usb: dwc2: Do not update data length if it is 0 on inbound
  transfers (bsc#1012628).
- usb: dwc2: Abort transaction after errors with unknown reason
  (bsc#1012628).
- usb: dwc2: Make "trimming xfer length" a debug message
  (bsc#1012628).
- staging: rtl8723bs: wifi_regd.c: Fix incorrect number of
  regulatory rules (bsc#1012628).
- x86/MSR: Filter MSR writes through X86_IOC_WRMSR_REGS ioctl too
  (bsc#1012628).
- arm64: dts: renesas: beacon: Fix EEPROM compatible value
  (bsc#1012628).
- can: mcp251xfd: mcp251xfd_probe(): fix errata reference
  (bsc#1012628).
- ARM: dts: armada388-helios4: assign pinctrl to LEDs
  (bsc#1012628).
- ARM: dts: armada388-helios4: assign pinctrl to each fan
  (bsc#1012628).
- arm64: dts: armada-3720-turris-mox: rename u-boot mtd partition
  to a53-firmware (bsc#1012628).
- opp: Correct debug message in _opp_add_static_v2()
  (bsc#1012628).
- Bluetooth: btusb: Fix memory leak in btusb_mtk_wmt_recv
  (bsc#1012628).
- soc: qcom: ocmem: don't return NULL in of_get_ocmem
  (bsc#1012628).
- arm64: dts: msm8916: Fix reserved and rfsa nodes unit address
  (bsc#1012628).
- arm64: dts: meson: fix broken wifi node for Khadas VIM3L
  (bsc#1012628).
- iwlwifi: mvm: set enabled in the PPAG command properly
  (bsc#1012628).
- ARM: s3c: fix fiq for clang IAS (bsc#1012628).
- optee: simplify i2c access (bsc#1012628).
- staging: wfx: fix possible panic with re-queued frames
  (bsc#1012628).
- ARM: at91: use proper asm syntax in pm_suspend (bsc#1012628).
- ath10k: Fix suspicious RCU usage warning in
  ath10k_wmi_tlv_parse_peer_stats_info() (bsc#1012628).
- ath10k: Fix lockdep assertion warning in ath10k_sta_statistics
  (bsc#1012628).
- ath11k: fix a locking bug in ath11k_mac_op_start()
  (bsc#1012628).
- soc: aspeed: snoop: Add clock control logic (bsc#1012628).
- iwlwifi: mvm: fix the type we use in the PPAG table validity
  checks (bsc#1012628).
- iwlwifi: mvm: store PPAG enabled/disabled flag properly
  (bsc#1012628).
- iwlwifi: mvm: send stored PPAG command instead of local
  (bsc#1012628).
- iwlwifi: mvm: assign SAR table revision to the command later
  (bsc#1012628).
- iwlwifi: mvm: don't check if CSA event is running before
  removing (bsc#1012628).
- bpf_lru_list: Read double-checked variable once without lock
  (bsc#1012628).
- iwlwifi: pnvm: set the PNVM again if it was already loaded
  (bsc#1012628).
- iwlwifi: pnvm: increment the pointer before checking the TLV
  (bsc#1012628).
- ath9k: fix data bus crash when setting nf_override via debugfs
  (bsc#1012628).
- selftests/bpf: Convert test_xdp_redirect.sh to bash
  (bsc#1012628).
- ibmvnic: Set to CLOSED state even on error (bsc#1012628).
- bnxt_en: reverse order of TX disable and carrier off
  (bsc#1012628).
- bnxt_en: Fix devlink info's stored fw.psid version format
  (bsc#1012628).
- xen/netback: fix spurious event detection for common event case
  (bsc#1012628).
- dpaa2-eth: fix memory leak in XDP_REDIRECT (bsc#1012628).
- net: phy: consider that suspend2ram may cut off PHY power
  (bsc#1012628).
- net/mlx5e: Enable XDP for Connect-X IPsec capable devices
  (bsc#1012628).
- net/mlx5e: Don't change interrupt moderation params when DIM
  is enabled (bsc#1012628).
- net/mlx5e: Change interrupt moderation channel params also
  when channels are closed (bsc#1012628).
- net/mlx5: Fix health error state handling (bsc#1012628).
- net/mlx5e: Replace synchronize_rcu with synchronize_net
  (bsc#1012628).
- net/mlx5e: kTLS, Use refcounts to free kTLS RX priv context
  (bsc#1012628).
- net/mlx5: Disable devlink reload for multi port slave device
  (bsc#1012628).
- net/mlx5: Disallow RoCE on multi port slave device
  (bsc#1012628).
- net/mlx5: Disallow RoCE on lag device (bsc#1012628).
- net/mlx5: Disable devlink reload for lag devices (bsc#1012628).
- net/mlx5e: CT: manage the lifetime of the ct entry object
  (bsc#1012628).
- net/mlx5e: Check tunnel offload is required before setting SWP
  (bsc#1012628).
- mac80211: fix potential overflow when multiplying to u32
  integers (bsc#1012628).
- libbpf: Ignore non function pointer member in struct_ops
  (bsc#1012628).
- bpf: Fix an unitialized value in bpf_iter (bsc#1012628).
- bpf, devmap: Use GFP_KERNEL for xdp bulk queue allocation
  (bsc#1012628).
- bpf: Fix bpf_fib_lookup helper MTU check for SKB ctx
  (bsc#1012628).
- selftests: mptcp: fix ACKRX debug message (bsc#1012628).
- tcp: fix SO_RCVLOWAT related hangs under mem pressure
  (bsc#1012628).
- net: axienet: Handle deferred probe on clock properly
  (bsc#1012628).
- cxgb4/chtls/cxgbit: Keeping the max ofld immediate data size
  same in cxgb4 and ulds (bsc#1012628).
- b43: N-PHY: Fix the update of coef for the PHY revision >=
  3case (bsc#1012628).
- bpf: Clear subreg_def for global function return values
  (bsc#1012628).
- ibmvnic: add memory barrier to protect long term buffer
  (bsc#1012628).
- ibmvnic: skip send_request_unmap for timeout reset
  (bsc#1012628).
- ibmvnic: serialize access to work queue on remove (bsc#1012628).
- net: dsa: felix: perform teardown in reverse order of setup
  (bsc#1012628).
- net: dsa: felix: don't deinitialize unused ports (bsc#1012628).
- net: phy: mscc: adding LCPLL reset to VSC8514 (bsc#1012628).
- net: amd-xgbe: Reset the PHY rx data path when mailbox command
  timeout (bsc#1012628).
- net: amd-xgbe: Fix NETDEV WATCHDOG transmit queue timeout
  warning (bsc#1012628).
- net: amd-xgbe: Reset link when the link never comes back
  (bsc#1012628).
- net: amd-xgbe: Fix network fluctuations when using 1G BELFUSE
  SFP (bsc#1012628).
- net: mvneta: Remove per-cpu queue mapping for Armada 3700
  (bsc#1012628).
- net: enetc: fix destroyed phylink dereference during unbind
  (bsc#1012628).
- Bluetooth: Remove hci_req_le_suspend_config (bsc#1012628).
- arm64: dts: broadcom: bcm4908: use proper NAND binding
  (bsc#1012628).
- Bluetooth: hci_qca: Wait for SSR completion during suspend
  (bsc#1012628).
- serial: stm32: fix DMA initialization error handling
  (bsc#1012628).
- bpf: Declare __bpf_free_used_maps() unconditionally
  (bsc#1012628).
- selftests/bpf: Sync RCU before unloading bpf_testmod
  (bsc#1012628).
- arm64: dts: qcom: sm8250: correct sdhc_2 xo clk (bsc#1012628).
- arm64: dts: qcom: qrb5165-rb5: fix uSD pins drive strength
  (bsc#1012628).
- tty: convert tty_ldisc_ops 'read()' function to take a kernel
  pointer (bsc#1012628).
- tty: implement read_iter (bsc#1012628).
- x86/sgx: Fix the return type of sgx_init() (bsc#1012628).
- selftests/bpf: Don't exit on failed bpf_testmod unload
  (bsc#1012628).
- arm64: dts: mt8183: rename rdma fifo size (bsc#1012628).
- arm64: dts: mt8183: refine gamma compatible name (bsc#1012628).
- arm64: dts: mt8183: Add missing power-domain for pwm0 node
  (bsc#1012628).
- net: sfp: add workaround for Realtek RTL8672 and RTL9601C chips
  (bsc#1012628).
- ARM: tegra: ouya: Fix eMMC on specific bootloaders
  (bsc#1012628).
- arm64: dts: mt8183: Fix GCE include path (bsc#1012628).
- Bluetooth: hci_qca: check for SSR triggered flag while suspend
  (bsc#1012628).
- Bluetooth: hci_qca: Fixed issue during suspend (bsc#1012628).
- soc: aspeed: socinfo: Add new systems (bsc#1012628).
- net/mlx5e: E-switch, Fix rate calculation for overflow
  (bsc#1012628).
- net/mlx5e: Enable striding RQ for Connect-X IPsec capable
  devices (bsc#1012628).
- net/mlx5e: Fix CQ params of ICOSQ and async ICOSQ (bsc#1012628).
- ibmvnic: change IBMVNIC_MAX_IND_DESCS to 16 (bsc#1012628).
- net: ipa: initialize all resources (bsc#1012628).
- net: phy: mscc: improved serdes calibration applied to VSC8514
  (bsc#1012628).
- net: phy: mscc: coma mode disabled for VSC8514 (bsc#1012628).
- fbdev: aty: SPARC64 requires FB_ATY_CT (bsc#1012628).
- drm/gma500: Fix error return code in psb_driver_load()
  (bsc#1012628).
- drm: document that user-space should force-probe connectors
  (bsc#1012628).
- gma500: clean up error handling in init (bsc#1012628).
- drm/fb-helper: Add missed unlocks in setcmap_legacy()
  (bsc#1012628).
- drm/panel: s6e63m0: Fix init sequence again (bsc#1012628).
- drm/panel: mantix: Tweak init sequence (bsc#1012628).
- drm/vc4: hdmi: Take into account the clock doubling flag in
  atomic_check (bsc#1012628).
- drm/panel: s6e63m0: Support max-brightness (bsc#1012628).
- crypto: sun4i-ss - linearize buffers content must be kept
  (bsc#1012628).
- crypto: sun4i-ss - fix kmap usage (bsc#1012628).
- crypto: arm64/aes-ce - really hide slower algos when faster
  ones are enabled (bsc#1012628).
- hwrng: ingenic - Fix a resource leak in an error handling path
  (bsc#1012628).
- media: allegro: Fix use after free on error (bsc#1012628).
- ASoC: fsl_aud2htx: select SND_SOC_IMX_PCM_DMA (bsc#1012628).
- kcsan: Rewrite kcsan_prandom_u32_max() without
  prandom_u32_state() (bsc#1012628).
- drm: rcar-du: Fix PM reference leak in rcar_cmm_enable()
  (bsc#1012628).
- drm: rcar-du: Fix crash when using LVDS1 clock for CRTC
  (bsc#1012628).
- drm: rcar-du: Fix the return check of of_parse_phandle and
  of_find_device_by_node (bsc#1012628).
- drm/amdgpu: Fix macro name _AMDGPU_TRACE_H_ in preprocessor
  if condition (bsc#1012628).
- MIPS: c-r4k: Fix section mismatch for loongson2_sc_init
  (bsc#1012628).
- MIPS: lantiq: Explicitly compare LTQ_EBU_PCC_ISTAT against 0
  (bsc#1012628).
- drm/virtio: make sure context is created in gem open
  (bsc#1012628).
- drm/fourcc: fix Amlogic format modifier masks (bsc#1012628).
- media: ipu3-cio2: Build only for x86 (bsc#1012628).
- media: i2c: ov5670: Fix PIXEL_RATE minimum value (bsc#1012628).
- media: imx: Unregister csc/scaler only if registered
  (bsc#1012628).
- media: imx: Fix csc/scaler unregister (bsc#1012628).
- media: mtk-vcodec: fix error return code in vdec_vp9_decode()
  (bsc#1012628).
- media: camss: Fix signedness bug in video_enum_fmt()
  (bsc#1012628).
- media: camss: missing error code in msm_video_register()
  (bsc#1012628).
- media: vsp1: Fix an error handling path in the probe function
  (bsc#1012628).
- media: em28xx: Fix use-after-free in em28xx_alloc_urbs
  (bsc#1012628).
- media: media/pci: Fix memleak in empress_init (bsc#1012628).
- media: tm6000: Fix memleak in tm6000_start_stream (bsc#1012628).
- media: aspeed: fix error return code in
  aspeed_video_setup_video() (bsc#1012628).
- ASoC: cs42l56: fix up error handling in probe (bsc#1012628).
- ASoC: qcom: qdsp6: Move frontend AIFs to q6asm-dai
  (bsc#1012628).
- evm: Fix memleak in init_desc (bsc#1012628).
- crypto: qat - replace CRYPTO_AES with CRYPTO_LIB_AES in Kconfig
  (bsc#1012628).
- crypto: bcm - Rename struct device_private to bcm_device_private
  (bsc#1012628).
- sched/fair: Avoid stale CPU util_est value for schedutil in
  task dequeue (bsc#1012628).
- drm/sun4i: tcon: fix inverted DCLK polarity (bsc#1012628).
- media: imx7: csi: Fix regression for parallel cameras on i.MX6UL
  (bsc#1012628).
- media: imx7: csi: Fix pad link validation (bsc#1012628).
- media: ti-vpe: cal: fix write to unallocated memory
  (bsc#1012628).
- MIPS: properly stop .eh_frame generation (bsc#1012628).
- MIPS: Compare __SYNC_loongson3_war against 0 (bsc#1012628).
- drm/tegra: Fix reference leak when pm_runtime_get_sync() fails
  (bsc#1012628).
- drm/amdgpu: toggle on DF Cstate after finishing xgmi injection
  (bsc#1012628).
- bsg: free the request before return error code (bsc#1012628).
- macintosh/adb-iop: Use big-endian autopoll mask (bsc#1012628).
- drm/amd/display: Fix 10/12 bpc setup in DCE output bit depth
  reduction (bsc#1012628).
- drm/amd/display: Fix HDMI deep color output for DCE 6-11
  (bsc#1012628).
- media: software_node: Fix refcounts in
  software_node_get_next_child() (bsc#1012628).
- media: lmedm04: Fix misuse of comma (bsc#1012628).
- media: vidtv: psi: fix missing crc for PMT (bsc#1012628).
- media: atomisp: Fix a buffer overflow in debug code
  (bsc#1012628).
- media: qm1d1c0042: fix error return code in qm1d1c0042_init()
  (bsc#1012628).
- media: cx25821: Fix a bug when reallocating some dma memory
  (bsc#1012628).
- media: mtk-vcodec: fix argument used when DEBUG is defined
  (bsc#1012628).
- mtd: phram: use div_u64_rem to stop overwrite len in phram_setup
  (bsc#1012628).
- media: pxa_camera: declare variable when DEBUG is defined
  (bsc#1012628).
- media: i2c/Kconfig: Select FWNODE for OV772x sensor
  (bsc#1012628).
- ASoC: max98373: Fixes a typo in max98373_feedback_get
  (bsc#1012628).
- sched/eas: Don't update misfit status if the task is pinned
  (bsc#1012628).
- f2fs: fix null page reference in redirty_blocks (bsc#1012628).
- f2fs: compress: fix potential deadlock (bsc#1012628).
- ASoC: qcom: lpass-cpu: Remove bit clock state check
  (bsc#1012628).
- ASoC: SOF: Intel: hda: cancel D0i3 work during runtime suspend
  (bsc#1012628).
- perf/arm-cmn: Fix PMU instance naming (bsc#1012628).
- perf/arm-cmn: Move IRQs when migrating context (bsc#1012628).
- mtd: parser: imagetag: fix error codes in
  bcm963xx_parse_imagetag_partitions() (bsc#1012628).
- crypto: talitos - Work around SEC6 ERRATA (AES-CTR mode data
  size error) (bsc#1012628).
- crypto: talitos - Fix ctr(aes) on SEC1 (bsc#1012628).
- irqchip/ls-extirq: add IRQCHIP_SKIP_SET_WAKE to the irqchip
  flags (bsc#1012628).
- mm: proc: Invalidate TLB after clearing soft-dirty page state
  (bsc#1012628).
- ata: ahci_brcm: Add back regulators management (bsc#1012628).
- ASoC: cpcap: fix microphone timeslot mask (bsc#1012628).
- ASoC: codecs: add missing max_register in regmap config
  (bsc#1012628).
- mtd: parsers: afs: Fix freeing the part name memory in failure
  (bsc#1012628).
- mtd: rawnand: intel: Fix an error handling path in
  'ebu_dma_start()' (bsc#1012628).
- f2fs: fix to avoid inconsistent quota data (bsc#1012628).
- drm/amdgpu: Prevent shift wrapping in amdgpu_read_mask()
  (bsc#1012628).
- f2fs: fix a wrong condition in __submit_bio (bsc#1012628).
- ASoC: qcom: Fix typo error in HDMI regmap config callbacks
  (bsc#1012628).
- KVM: nSVM: Don't strip host's C-bit from guest's CR3 when
  reading PDPTRs (bsc#1012628).
- drm/mediatek: Check if fb is null (bsc#1012628).
- Drivers: hv: vmbus: Avoid use-after-free in
  vmbus_onoffer_rescind() (bsc#1012628).
- ASoC: Intel: sof_sdw: add missing TGL_HDMI quirk for Dell SKU
  0A5E (bsc#1012628).
- ASoC: Intel: sof_sdw: add missing TGL_HDMI quirk for Dell SKU
  0A32 (bsc#1012628).
- ASoC: Intel: sof_sdw: add missing TGL_HDMI quirk for Dell SKU
  0A3E (bsc#1012628).
- locking/lockdep: Avoid unmatched unlock (bsc#1012628).
- ASoC: qcom: lpass: Fix i2s ctl register bit map (bsc#1012628).
- ASoC: rt5682: Fix panic in rt5682_jack_detect_handler happening
  during system shutdown (bsc#1012628).
- ASoC: SOF: debug: Fix a potential issue on string buffer
  termination (bsc#1012628).
- btrfs: clarify error returns values in __load_free_space_cache
  (bsc#1012628).
- btrfs: fix double accounting of ordered extent for subpage
  case in btrfs_invalidapge (bsc#1012628).
- MIPS: relocatable: Provide kaslr_offset() to get the kernel
  offset (bsc#1012628).
- KVM: x86: Restore all 64 bits of DR6 and DR7 during RSM on
  x86-64 (bsc#1012628).
- s390/zcrypt: return EIO when msg retry limit reached
  (bsc#1012628).
- drm/vc4: hdmi: Move hdmi reset to bind (bsc#1012628).
- drm/vc4: hdmi: Fix register offset with longer CEC messages
  (bsc#1012628).
- drm/vc4: hdmi: Fix up CEC registers (bsc#1012628).
- drm/vc4: hdmi: Restore cec physical address on reconnect
  (bsc#1012628).
- drm/vc4: hdmi: Compute the CEC clock divider from the clock rate
  (bsc#1012628).
- drm/vc4: hdmi: Update the CEC clock divider on HSM rate change
  (bsc#1012628).
- drm/lima: fix reference leak in lima_pm_busy (bsc#1012628).
- drm/virtio: fix an error code in virtio_gpu_init()
  (bsc#1012628).
- drm/dp_mst: Don't cache EDIDs for physical ports (bsc#1012628).
- hwrng: timeriomem - Fix cooldown period calculation
  (bsc#1012628).
- crypto: ecdh_helper - Ensure 'len >= secret.len' in decode_key()
  (bsc#1012628).
- io_uring: fix possible deadlock in io_uring_poll (bsc#1012628).
- nvmet-tcp: fix receive data digest calculation for multiple
  h2cdata PDUs (bsc#1012628).
- nvmet-tcp: fix potential race of tcp socket closing accept_work
  (bsc#1012628).
- nvme-multipath: set nr_zones for zoned namespaces (bsc#1012628).
- nvmet: remove extra variable in identify ns (bsc#1012628).
- nvmet: set status to 0 in case for invalid nsid (bsc#1012628).
- ASoC: SOF: sof-pci-dev: add missing Up-Extreme quirk
  (bsc#1012628).
- ima: Free IMA measurement buffer on error (bsc#1012628).
- ima: Free IMA measurement buffer after kexec syscall
  (bsc#1012628).
- ASoC: simple-card-utils: Fix device module clock (bsc#1012628).
- fs/jfs: fix potential integer overflow on shift of a int
  (bsc#1012628).
- jffs2: fix use after free in jffs2_sum_write_data()
  (bsc#1012628).
- ubifs: Fix memleak in ubifs_init_authentication (bsc#1012628).
- ubifs: replay: Fix high stack usage, again (bsc#1012628).
- ubifs: Fix error return code in alloc_wbufs() (bsc#1012628).
- irqchip/imx: IMX_INTMUX should not default to y, unconditionally
  (bsc#1012628).
- smp: Process pending softirqs in
  flush_smp_call_function_from_idle() (bsc#1012628).
- drm/amdgpu/display: remove hdcp_srm sysfs on device removal
  (bsc#1012628).
- Input: da7280 - fix missing error test (bsc#1012628).
- Input: da7280 - protect OF match table with CONFIG_OF
  (bsc#1012628).
- Input: imx_keypad - add dependency on HAS_IOMEM (bsc#1012628).
- capabilities: Don't allow writing ambiguous v3 file capabilities
  (bsc#1012628).
- HSI: Fix PM usage counter unbalance in ssi_hw_init
  (bsc#1012628).
- power: supply: cpcap: Add missing IRQF_ONESHOT to fix regression
  (bsc#1012628).
- clk: meson: clk-pll: fix initializing the old rate (fallback)
  for a PLL (bsc#1012628).
- clk: meson: clk-pll: make "ret" a signed integer (bsc#1012628).
- clk: meson: clk-pll: propagate the error from
  meson_clk_pll_set_rate() (bsc#1012628).
- selftests/powerpc: Make the test check in eeh-basic.sh posix
  compliant (bsc#1012628).
- regulator: qcom-rpmh-regulator: add pm8009-1 chip revision
  (bsc#1012628).
- arm64: dts: qcom: qrb5165-rb5: fix pm8009 regulators
  (bsc#1012628).
- quota: Fix memory leak when handling corrupted quota file
  (bsc#1012628).
- i2c: iproc: handle only slave interrupts which are enabled
  (bsc#1012628).
- i2c: iproc: update slave isr mask (ISR_MASK_SLAVE)
  (bsc#1012628).
- i2c: iproc: handle master read request (bsc#1012628).
- spi: cadence-quadspi: Abort read if dummy cycles required are
  too many (bsc#1012628).
- clk: sunxi-ng: h6: Fix CEC clock (bsc#1012628).
- clk: renesas: r8a779a0: Remove non-existent S2 clock
  (bsc#1012628).
- clk: renesas: r8a779a0: Fix parent of CBFUSA clock
  (bsc#1012628).
- HID: core: detect and skip invalid inputs to snto32()
  (bsc#1012628).
- RDMA/siw: Fix handling of zero-sized Read and Receive Queues
  (bsc#1012628).
- dmaengine: fsldma: Fix a resource leak in the remove function
  (bsc#1012628).
- dmaengine: fsldma: Fix a resource leak in an error handling
  path of the probe function (bsc#1012628).
- dmaengine: owl-dma: Fix a resource leak in the remove function
  (bsc#1012628).
- rtc: rx6110: fix build against modular I2C (bsc#1012628).
- dmaengine: qcom: Always inline gpi_update_reg (bsc#1012628).
- dmaengine: ti: k3-udma: Set rflow count for BCDMA split channels
  (bsc#1012628).
- dmaengine: hsu: disable spurious interrupt (bsc#1012628).
- mfd: bd9571mwv: Use devm_mfd_add_devices() (bsc#1012628).
- power: supply: cpcap-charger: Fix missing power_supply_put()
  (bsc#1012628).
- power: supply: cpcap-battery: Fix missing power_supply_put()
  (bsc#1012628).
- scsi: ufs: Fix a possible NULL pointer issue (bsc#1012628).
- power: supply: cpcap-charger: Fix power_supply_put on null
  battery pointer (bsc#1012628).
- fdt: Properly handle "no-map" field in the memory region
  (bsc#1012628).
- of/fdt: Make sure no-map does not remove already reserved
  regions (bsc#1012628).
- RDMA/rtrs: Extend ibtrs_cq_qp_create (bsc#1012628).
- RDMA/rtrs-srv: Release lock before call into close_sess
  (bsc#1012628).
- RDMA/rtrs-srv: Use sysfs_remove_file_self for disconnect
  (bsc#1012628).
- RDMA/rtrs-clt: Set mininum limit when create QP (bsc#1012628).
- RDMA/rtrs-srv: Jump to dereg_mr label if allocate iu fails
  (bsc#1012628).
- RDMA/rtrs: Call kobject_put in the failure path (bsc#1012628).
- RDMA/rtrs-srv: Fix missing wr_cqe (bsc#1012628).
- RDMA/rtrs-clt: Refactor the failure cases in alloc_clt
  (bsc#1012628).
- RDMA/rtrs-srv: Init wr_cnt as 1 (bsc#1012628).
- RDMA/rtrs: Fix KASAN: stack-out-of-bounds bug (bsc#1012628).
- power: reset: at91-sama5d2_shdwc: fix wkupdbc mask
  (bsc#1012628).
- rtc: s5m: select REGMAP_I2C (bsc#1012628).
- dmaengine: idxd: set DMA channel to be private (bsc#1012628).
- power: supply: fix sbs-charger build, needs REGMAP_I2C
  (bsc#1012628).
- clocksource/drivers/ixp4xx: Select TIMER_OF when needed
  (bsc#1012628).
- clocksource/drivers/mxs_timer: Add missing semicolon when
  DEBUG is defined (bsc#1012628).
- module: harden ELF info handling (bsc#1012628).
- spi: imx: Don't print error on -EPROBEDEFER (bsc#1012628).
- RDMA/mlx5: Use the correct obj_id upon DEVX TIR creation
  (bsc#1012628).
- IB/mlx5: Add mutex destroy call to cap_mask_mutex mutex
  (bsc#1012628).
- clk: sunxi-ng: h6: Fix clock divider range on some clocks
  (bsc#1012628).
- platform/chrome: cros_ec_proto: Use EC_HOST_EVENT_MASK not BIT
  (bsc#1012628).
- platform/chrome: cros_ec_proto: Add LID and BATTERY to default
  mask (bsc#1012628).
- regulator: axp20x: Fix reference cout leak (bsc#1012628).
- watch_queue: Drop references to /dev/watch_queue (bsc#1012628).
- certs: Fix blacklist flag type confusion (bsc#1012628).
- regulator: s5m8767: Fix reference count leak (bsc#1012628).
- spi: atmel: Put allocated master before return (bsc#1012628).
- regulator: s5m8767: Drop regulators OF node reference
  (bsc#1012628).
- scsi: libsas: Remove notifier indirection (bsc#1012628).
- scsi: libsas: Introduce a _gfp() variant of event notifiers
  (bsc#1012628).
- scsi: mvsas: Pass gfp_t flags to libsas event notifiers
  (bsc#1012628).
- scsi: isci: Pass gfp_t flags in isci_port_link_down()
  (bsc#1012628).
- scsi: isci: Pass gfp_t flags in isci_port_link_up()
  (bsc#1012628).
- scsi: isci: Pass gfp_t flags in isci_port_bc_change_received()
  (bsc#1012628).
- power: supply: axp20x_usb_power: Init work before enabling IRQs
  (bsc#1012628).
- power: supply: smb347-charger: Fix interrupt usage if interrupt
  is unavailable (bsc#1012628).
- regulator: core: Avoid debugfs: Directory ... already
  present! error (bsc#1012628).
- isofs: release buffer head before return (bsc#1012628).
- watchdog: intel-mid_wdt: Postpone IRQ handler registration
  till SCU is ready (bsc#1012628).
- auxdisplay: ht16k33: Fix refresh rate handling (bsc#1012628).
- auxdisplay: Fix duplicate CHARLCD config symbol (bsc#1012628).
- objtool: Fix error handling for STD/CLD warnings (bsc#1012628).
- objtool: Fix retpoline detection in asm code (bsc#1012628).
- objtool: Fix ".cold" section suffix check for newer versions
  of GCC (bsc#1012628).
- scsi: lpfc: Fix ancient double free (bsc#1012628).
- iommu: Switch gather->end to the inclusive end (bsc#1012628).
- tools/testing/scatterlist: Fix overflow of max segment size
  (bsc#1012628).
- RDMA/mlx5: Allow creating all QPs even when non RDMA profile
  is used (bsc#1012628).
- IB/umad: Return EIO in case of when device disassociated
  (bsc#1012628).
- IB/umad: Return EPOLLERR in case of when device disassociated
  (bsc#1012628).
- KVM: PPC: Make the VMX instruction emulation routines static
  (bsc#1012628).
- powerpc/kvm: Force selection of CONFIG_PPC_FPU (bsc#1012628).
- powerpc/47x: Disable 256k page size (bsc#1012628).
- powerpc/sstep: Check instruction validity against ISA version
  before emulation (bsc#1012628).
- powerpc/sstep: Fix incorrect return from analyze_instr()
  (bsc#1012628).
- powerpc/time: Enable sched clock for irqtime (bsc#1012628).
- powerpc: Fix build error in paravirt.h (bsc#1012628).
- mmc: owl-mmc: Fix a resource leak in an error handling path
  and in the remove function (bsc#1012628).
- mmc: sdhci-sprd: Fix some resource leaks in the remove function
  (bsc#1012628).
- mmc: usdhi6rol0: Fix a resource leak in the error handling
  path of the probe (bsc#1012628).
- mmc: renesas_sdhi_internal_dmac: Fix DMA buffer alignment from
  8 to 128-bytes (bsc#1012628).
- ARM: 9046/1: decompressor: Do not clear SCTLR.nTLSMD for ARMv7+
  cores (bsc#1012628).
- i2c: qcom-geni: Store DMA mapping data in geni_i2c_dev struct
  (bsc#1012628).
- i3c/master/mipi-i3c-hci: Specify HAS_IOMEM dependency
  (bsc#1012628).
- amba: Fix resource leak for drivers without .remove
  (bsc#1012628).
- iommu: Move iotlb_sync_map out from __iommu_map (bsc#1012628).
- iommu: Properly pass gfp_t in _iommu_map() to avoid atomic
  sleeping (bsc#1012628).
- IB/mlx5: Return appropriate error code instead of ENOMEM
  (bsc#1012628).
- IB/cm: Avoid a loop when device has 255 ports (bsc#1012628).
- tracepoint: Do not fail unregistering a probe due to memory
  failure (bsc#1012628).
- rtc: zynqmp: depend on HAS_IOMEM (bsc#1012628).
- platform/x86: intel_pmt: Make INTEL_PMT_CLASS
  non-user-selectable (bsc#1012628).
- platform/x86: intel_pmt_telemetry: Add dependency on
  MFD_INTEL_PMT (bsc#1012628).
- platform/x86: intel_pmt_crashlog: Add dependency on
  MFD_INTEL_PMT (bsc#1012628).
- perf tools: Fix DSO filtering when not finding a map for a
  sampled address (bsc#1012628).
- perf vendor events arm64: Fix Ampere eMag event typo
  (bsc#1012628).
- RDMA/rxe: Fix coding error in rxe_recv.c (bsc#1012628).
- RDMA/rxe: Fix coding error in rxe_rcv_mcast_pkt (bsc#1012628).
- RDMA/rxe: Correct skb on loopback path (bsc#1012628).
- spi: stm32: properly handle 0 byte transfer (bsc#1012628).
- mfd: altera-sysmgr: Fix physical address storing more
  (bsc#1012628).
- mfd: wm831x-auxadc: Prevent use after free in
  wm831x_auxadc_read_irq() (bsc#1012628).
- powerpc/pseries/dlpar: handle ibm, configure-connector delay
  status (bsc#1012628).
- powerpc/8xx: Fix software emulation interrupt (bsc#1012628).
- powerpc/sstep: Fix load-store and update emulation
  (bsc#1012628).
- powerpc/sstep: Fix darn emulation (bsc#1012628).
- clk: qcom: gfm-mux: fix clk mask (bsc#1012628).
- clk: qcom: gcc-sc7180: Mark the MM XO clocks to be always ON
  (bsc#1012628).
- clk: qcom: gcc-msm8998: Fix Alpha PLL type for all GPLLs
  (bsc#1012628).
- kunit: tool: fix unit test cleanup handling (bsc#1012628).
- kselftests: dmabuf-heaps: Fix Makefile's inclusion of the
  kernel's usr/include dir (bsc#1012628).
- RDMA/hns: Allocate one more recv SGE for HIP08 (bsc#1012628).
- RDMA/hns: Bugfix for checking whether the srq is full when
  post wr (bsc#1012628).
- RDMA/hns: Force srq_limit to 0 when creating SRQ (bsc#1012628).
- RDMA/hns: Fixed wrong judgments in the goto branch
  (bsc#1012628).
- RDMA/hns: Remove the reserved WQE of SRQ (bsc#1012628).
- RDMA/siw: Fix calculation of tx_valid_cpus size (bsc#1012628).
- RDMA/hns: Avoid filling sgid index when modifying QP to RTR
  (bsc#1012628).
- RDMA/hns: Fix type of sq_signal_bits (bsc#1012628).
- RDMA/hns: Add mapped page count checking for MTR (bsc#1012628).
- RDMA/hns: Disable RQ inline by default (bsc#1012628).
- clk: divider: fix initialization with parent_hw (bsc#1012628).
- spi: pxa2xx: Fix the controller numbering for Wildcat Point
  (bsc#1012628).
- powerpc/uaccess: Avoid might_fault() when user access is enabled
  (bsc#1012628).
- powerpc/kuap: Restore AMR after replaying soft interrupts
  (bsc#1012628).
- regulator: qcom-rpmh: fix pm8009 ldo7 (bsc#1012628).
- clk: aspeed: Fix APLL calculate formula from ast2600-A2
  (bsc#1012628).
- selftests/ftrace: Update synthetic event syntax errors
  (bsc#1012628).
- perf symbols: Use (long) for iterator for bfd symbols
  (bsc#1012628).
- regulator: bd718x7, bd71828, Fix dvs voltage levels
  (bsc#1012628).
- spi: dw: Avoid stack content exposure (bsc#1012628).
- spi: Skip zero-length transfers in spi_transfer_one_message()
  (bsc#1012628).
- printk: avoid prb_first_valid_seq() where possible
  (bsc#1012628).
- perf symbols: Fix return value when loading PE DSO
  (bsc#1012628).
- nfsd: register pernet ops last, unregister first (bsc#1012628).
- svcrdma: Hold private mutex while invoking rdma_accept()
  (bsc#1012628).
- ceph: fix flush_snap logic after putting caps (bsc#1012628).
- RDMA/hns: Fixes missing error code of CMDQ (bsc#1012628).
- RDMA/ucma: Fix use-after-free bug in ucma_create_uevent
  (bsc#1012628).
- RDMA/rtrs-srv: Fix stack-out-of-bounds (bsc#1012628).
- RDMA/rtrs: Only allow addition of path to an already established
  session (bsc#1012628).
- RDMA/rtrs-srv: fix memory leak by missing kobject free
  (bsc#1012628).
- RDMA/rtrs-srv-sysfs: fix missing put_device (bsc#1012628).
- RDMA/rtrs-srv: Do not pass a valid pointer to PTR_ERR()
  (bsc#1012628).
- Input: sur40 - fix an error code in sur40_probe() (bsc#1012628).
- perf record: Fix continue profiling after draining the buffer
  (bsc#1012628).
- perf unwind: Set userdata for all __report_module() paths
  (bsc#1012628).
- perf intel-pt: Fix missing CYC processing in PSB (bsc#1012628).
- perf intel-pt: Fix premature IPC (bsc#1012628).
- perf intel-pt: Fix IPC with CYC threshold (bsc#1012628).
- perf test: Fix unaligned access in sample parsing test
  (bsc#1012628).
- Input: elo - fix an error code in elo_connect() (bsc#1012628).
- sparc64: only select COMPAT_BINFMT_ELF if BINFMT_ELF is set
  (bsc#1012628).
- sparc: fix led.c driver when PROC_FS is not enabled
  (bsc#1012628).
- Input: zinitix - fix return type of zinitix_init_touch()
  (bsc#1012628).
- Input: st1232 - add IDLE state as ready condition (bsc#1012628).
- ARM: 9065/1: OABI compat: fix build when EPOLL is not enabled
  (bsc#1012628).
- Input: st1232 - fix NORMAL vs. IDLE state handling
  (bsc#1012628).
- misc: eeprom_93xx46: Fix module alias to enable module autoprobe
  (bsc#1012628).
- phy: rockchip-emmc: emmc_phy_init() always return 0
  (bsc#1012628).
- phy: cadence-torrent: Fix error code in cdns_torrent_phy_probe()
  (bsc#1012628).
- misc: eeprom_93xx46: Add module alias to avoid breaking support
  for non device tree users (bsc#1012628).
- PCI: rcar: Always allocate MSI addresses in 32bit space
  (bsc#1012628).
- soundwire: cadence: fix ACK/NAK handling (bsc#1012628).
- pwm: rockchip: Enable APB clock during register access while
  probing (bsc#1012628).
- pwm: rockchip: rockchip_pwm_probe(): Remove superfluous
  clk_unprepare() (bsc#1012628).
- pwm: rockchip: Eliminate potential race condition when probing
  (bsc#1012628).
- PCI: xilinx-cpm: Fix reference count leak on error path
  (bsc#1012628).
- VMCI: Use set_page_dirty_lock() when unregistering guest memory
  (bsc#1012628).
- PCI: Align checking of syscall user config accessors
  (bsc#1012628).
- mei: hbm: call mei_set_devstate() on hbm stop response
  (bsc#1012628).
- drm/msm: Fix MSM_INFO_GET_IOVA with carveout (bsc#1012628).
- drm/msm: Add proper checks for GPU LLCC support (bsc#1012628).
- drm/msm/dsi: Correct io_start for MSM8994 (20nm PHY)
  (bsc#1012628).
- drm/msm/mdp5: Fix wait-for-commit for cmd panels (bsc#1012628).
- drm/msm: Fix race of GPU init vs timestamp power management
  (bsc#1012628).
- drm/msm: Fix races managing the OOB state for timestamp vs
  timestamps (bsc#1012628).
- drm/msm/kms: Make a lock_class_key for each crtc mutex
  (bsc#1012628).
- drm/msm/dp: trigger unplug event in msm_dp_display_disable
  (bsc#1012628).
- vfio/iommu_type1: Populate full dirty when detach non-pinned
  group (bsc#1012628).
- vfio/iommu_type1: Fix some sanity checks in detach group
  (bsc#1012628).
- vfio-pci/zdev: fix possible segmentation fault issue
  (bsc#1012628).
- ext4: fix potential htree index checksum corruption
  (bsc#1012628).
- phy: USB_LGM_PHY should depend on X86 (bsc#1012628).
- coresight: etm4x: Skip accessing TRCPDCR in save/restore
  (bsc#1012628).
- nvmem: core: Fix a resource leak on error in
  nvmem_add_cells_from_of() (bsc#1012628).
- nvmem: core: skip child nodes not matching binding
  (bsc#1012628).
- drm/msm: Fix legacy relocs path (bsc#1012628).
- soundwire: bus: use sdw_update_no_pm when initializing a device
  (bsc#1012628).
- soundwire: bus: use sdw_write_no_pm when setting the bus scale
  registers (bsc#1012628).
- soundwire: export sdw_write/read_no_pm functions (bsc#1012628).
- soundwire: bus: fix confusion on device used by pm_runtime
  (bsc#1012628).
- drm/msm/dp: Add a missing semi-colon (bsc#1012628).
- misc: fastrpc: fix incorrect usage of dma_map_sgtable
  (bsc#1012628).
- remoteproc/mediatek: acknowledge watchdog IRQ after handled
  (bsc#1012628).
- mhi: Fix double dma free (bsc#1012628).
- regmap: sdw: use _no_pm functions in regmap_read/write
  (bsc#1012628).
- ext: EXT4_KUNIT_TESTS should depend on EXT4_FS instead of
  selecting it (bsc#1012628).
- mailbox: sprd: correct definition of SPRD_OUTBOX_FIFO_FULL
  (bsc#1012628).
- device-dax: Fix default return code of range_parse()
  (bsc#1012628).
- PCI: pci-bridge-emul: Fix array overruns, improve safety
  (bsc#1012628).
- PCI: cadence: Fix DMA range mapping early return error
  (bsc#1012628).
- i40e: Fix flow for IPv6 next header (extension header)
  (bsc#1012628).
- i40e: Add zero-initialization of AQ command structures
  (bsc#1012628).
- i40e: Fix overwriting flow control settings during driver
  loading (bsc#1012628).
- i40e: Fix addition of RX filters after enabling FW LLDP agent
  (bsc#1012628).
- i40e: Fix VFs not created (bsc#1012628).
- Take mmap lock in cacheflush syscall (bsc#1012628).
- nios2: fixed broken sys_clone syscall (bsc#1012628).
- i40e: Fix add TC filter for IPv6 (bsc#1012628).
- i40e: Fix endianness conversions (bsc#1012628).
- octeontx2-af: Fix an off by one in rvu_dbg_qsize_write()
  (bsc#1012628).
- pwm: iqs620a: Fix overflow and optimize calculations
  (bsc#1012628).
- ice: report correct max number of TCs (bsc#1012628).
- ice: Account for port VLAN in VF max packet size calculation
  (bsc#1012628).
- ice: Fix state bits on LLDP mode switch (bsc#1012628).
- ice: update the number of available RSS queues (bsc#1012628).
- dpaa_eth: fix the access method for the dpaa_napi_portal
  (bsc#1012628).
- net: stmmac: fix CBS idleslope and sendslope calculation
  (bsc#1012628).
- net/mlx4_core: Add missed mlx4_free_cmd_mailbox() (bsc#1012628).
- PCI: rockchip: Make 'ep-gpios' DT property optional
  (bsc#1012628).
- vxlan: move debug check after netdev unregister (bsc#1012628).
- wireguard: device: do not generate ICMP for non-IP packets
  (bsc#1012628).
- wireguard: kconfig: use arm chacha even with no neon
  (bsc#1012628).
- ocfs2: fix a use after free on error (bsc#1012628).
- mm: memcontrol: fix NR_ANON_THPS accounting in charge moving
  (bsc#1012628).
- mm: memcontrol: fix slub memory accounting (bsc#1012628).
- mm/memory.c: fix potential pte_unmap_unlock pte error
  (bsc#1012628).
- mm/hugetlb: fix potential double free in hugetlb_register_node()
  error path (bsc#1012628).
- mm/hugetlb: suppress wrong warning info when alloc gigantic page
  (bsc#1012628).
- mm/compaction: fix misbehaviors of fast_find_migrateblock()
  (bsc#1012628).
- net: phy: micrel: set soft_reset callback to genphy_soft_reset
  for KSZ8081 (bsc#1012628).
- r8169: fix jumbo packet handling on RTL8168e (bsc#1012628).
- NFSv4: Fixes for nfs4_bitmask_adjust() (bsc#1012628).
- KVM: SVM: Intercept INVPCID when it's disabled to inject #UD
  (bsc#1012628).
- KVM: x86/mmu: Expand collapsible SPTE zap for TDP MMU to
  ZONE_DEVICE and HugeTLB pages (bsc#1012628).
- cifs: Fix inconsistent IS_ERR and PTR_ERR (bsc#1012628).
- arm64: Add missing ISB after invalidating TLB in
  __primary_switch (bsc#1012628).
- i2c: brcmstb: Fix brcmstd_send_i2c_cmd condition (bsc#1012628).
- i2c: exynos5: Preserve high speed master code (bsc#1012628).
- mm,thp,shmem: make khugepaged obey tmpfs mount flags
  (bsc#1012628).
- mm: fix memory_failure() handling of dax-namespace metadata
  (bsc#1012628).
- mm/rmap: fix potential pte_unmap on an not mapped pte
  (bsc#1012628).
- proc: use kvzalloc for our kernel buffer (bsc#1012628).
- csky: Fix a size determination in gpr_get() (bsc#1012628).
- scsi: bnx2fc: Fix Kconfig warning & CNIC build errors
  (bsc#1012628).
- scsi: sd: sd_zbc: Don't pass GFP_NOIO to kvcalloc (bsc#1012628).
- block: reopen the device in blkdev_reread_part (bsc#1012628).
- block: fix logging on capacity change (bsc#1012628).
- ide/falconide: Fix module unload (bsc#1012628).
- scsi: sd: Fix Opal support (bsc#1012628).
- blk-settings: align max_sectors on "logical_block_size" boundary
  (bsc#1012628).
- soundwire: intel: fix possible crash when no device is detected
  (bsc#1012628).
- ACPI: property: Fix fwnode string properties matching
  (bsc#1012628).
- ACPI: configfs: add missing check after
  configfs_register_default_group() (bsc#1012628).
- cpufreq: ACPI: Set cpuinfo.max_freq directly if max boost is
  known (bsc#1012628).
- HID: logitech-dj: add support for keyboard events in eQUAD
  step 4 Gaming (bsc#1012628).
- HID: wacom: Ignore attempts to overwrite the touch_max value
  from HID (bsc#1012628).
- Input: raydium_ts_i2c - do not send zero length (bsc#1012628).
- Input: xpad - add support for PowerA Enhanced Wired Controller
  for Xbox Series X|S (bsc#1012628).
- Input: joydev - prevent potential read overflow in ioctl
  (bsc#1012628).
- Input: i8042 - add ASUS Zenbook Flip to noselftest list
  (bsc#1012628).
- media: mceusb: Fix potential out-of-bounds shift (bsc#1012628).
- USB: serial: option: update interface mapping for ZTE P685M
  (bsc#1012628).
- usb: musb: Fix runtime PM race in musb_queue_resume_work
  (bsc#1012628).
- usb: dwc3: gadget: Fix setting of DEPCFG.bInterval_m1
  (bsc#1012628).
- usb: dwc3: gadget: Fix dep->interval for fullspeed interrupt
  (bsc#1012628).
- USB: serial: ftdi_sio: fix FTX sub-integer prescaler
  (bsc#1012628).
- USB: serial: pl2303: fix line-speed handling on newer chips
  (bsc#1012628).
- USB: serial: mos7840: fix error code in mos7840_write()
  (bsc#1012628).
- USB: serial: mos7720: fix error code in mos7720_write()
  (bsc#1012628).
- phy: lantiq: rcu-usb2: wait after clock enable (bsc#1012628).
- ALSA: usb-audio: Correct document for
  snd_usb_endpoint_free_all() (bsc#1012628).
- ALSA: usb-audio: Handle invalid running state at releasing EP
  (bsc#1012628).
- ALSA: usb-audio: More strict state change in EP (bsc#1012628).
- ALSA: usb-audio: Don't avoid stopping the stream at
  disconnection (bsc#1012628).
- ALSA: usb-audio: Add implicit fb quirk for BOSS GP-10
  (bsc#1012628).
- ALSA: fireface: fix to parse sync status register of latter
  protocol (bsc#1012628).
- ALSA: hda: Add another CometLake-H PCI ID (bsc#1012628).
- ALSA: hda/hdmi: Drop bogus check at closing a stream
  (bsc#1012628).
- ALSA: hda/realtek: modify EAPD in the ALC886 (bsc#1012628).
- ALSA: hda/realtek: Quirk for HP Spectre x360 14 amp setup
  (bsc#1012628).
- MIPS: Ingenic: Disable HPTLB for D0 XBurst CPUs too
  (bsc#1012628).
- MIPS: Support binutils configured with
  - -enable-mips-fix-loongson3-llsc=yes (bsc#1012628).
- MIPS: VDSO: Use CLANG_FLAGS instead of filtering out '--target='
  (bsc#1012628).
- Revert "MIPS: Octeon: Remove special handling of
  CONFIG_MIPS_ELF_APPENDED_DTB=y" (bsc#1012628).
- MIPS: compressed: fix build with enabled UBSAN (bsc#1012628).
- Revert "bcache: Kill btree_io_wq" (bsc#1012628).
- bcache: Give btree_io_wq correct semantics again (bsc#1012628).
- bcache: Move journal work to new flush wq (bsc#1012628).
- Revert "drm/amd/display: Update NV1x SR latency values"
  (bsc#1012628).
- drm/amd/display: Add FPU wrappers to dcn21_validate_bandwidth()
  (bsc#1012628).
- drm/amd/display: Remove Assert from dcn10_get_dig_frontend
  (bsc#1012628).
- drm/amd/display: Add vupdate_no_lock interrupts for DCN2.1
  (bsc#1012628).
- Revert "drm/amd/display: reuse current context instead of
  recreating one" (bsc#1012628).
- drm/amdkfd: Fix recursive lock warnings (bsc#1012628).
- drm/amdgpu: fix CGTS_TCC_DISABLE register offset on gfx10.3
  (bsc#1012628).
- drm/amdgpu: Set reference clock to 100Mhz on Renoir (v2)
  (bsc#1012628).
- drm/amdgpu: fix shutdown and poweroff process failed with s0ix
  (bsc#1012628).
- drm/ttm: Fix a memory leak (bsc#1012628).
- drm/nouveau/kms: handle mDP connectors (bsc#1012628).
- drm/modes: Switch to 64bit maths to avoid integer overflow
  (bsc#1012628).
- drm/sched: Cancel and flush all outstanding jobs before finish
  (bsc#1012628).
- drm/panel: kd35t133: allow using non-continuous dsi clock
  (bsc#1012628).
- drm/rockchip: Require the YTR modifier for AFBC (bsc#1012628).
- ASoC: siu: Fix build error by a wrong const prefix
  (bsc#1012628).
- selinux: fix inconsistency between inode_getxattr and
  inode_listsecurity (bsc#1012628).
- erofs: initialized fields can only be observed after bit is set
  (bsc#1012628).
- tpm_tis: Fix check_locality for correct locality acquisition
  (bsc#1012628).
- tpm_tis: Clean up locality release (bsc#1012628).
- KEYS: trusted: Fix incorrect handling of tpm_get_random()
  (bsc#1012628).
- KEYS: trusted: Fix migratable=1 failing (bsc#1012628).
- KEYS: trusted: Reserve TPM for seal and unseal operations
  (bsc#1012628).
- btrfs: do not cleanup upper nodes in btrfs_backref_cleanup_node
  (bsc#1012628).
- btrfs: do not warn if we can't find the reloc root when looking
  up backref (bsc#1012628).
- btrfs: add asserts for deleting backref cache nodes
  (bsc#1012628).
- btrfs: abort the transaction if we fail to inc ref in
  btrfs_copy_root (bsc#1012628).
- btrfs: fix reloc root leak with 0 ref reloc roots on recovery
  (bsc#1012628).
- btrfs: splice remaining dirty_bg's onto the transaction dirty
  bg list (bsc#1012628).
- btrfs: handle space_info::total_bytes_pinned inside the delayed
  ref itself (bsc#1012628).
- btrfs: account for new extents being deleted in
  total_bytes_pinned (bsc#1012628).
- btrfs: fix extent buffer leak on failure to copy root
  (bsc#1012628).
- drm/i915/gt: Flush before changing register state (bsc#1012628).
- drm/i915/gt: Correct surface base address for renderclear
  (bsc#1012628).
- crypto: arm64/sha - add missing module aliases (bsc#1012628).
- crypto: aesni - prevent misaligned buffers on the stack
  (bsc#1012628).
- crypto: michael_mic - fix broken misalignment handling
  (bsc#1012628).
- crypto: sun4i-ss - checking sg length is not sufficient
  (bsc#1012628).
- crypto: sun4i-ss - IV register does not work on A10 and A13
  (bsc#1012628).
- crypto: sun4i-ss - handle BigEndian for cipher (bsc#1012628).
- crypto: sun4i-ss - initialize need_fallback (bsc#1012628).
- soc: samsung: exynos-asv: don't defer early on not-supported
  SoCs (bsc#1012628).
- soc: samsung: exynos-asv: handle reading revision register error
  (bsc#1012628).
- seccomp: Add missing return in non-void function (bsc#1012628).
- arm64: ptrace: Fix seccomp of traced syscall -1 (NO_SYSCALL)
  (bsc#1012628).
- misc: rtsx: init of rts522a add OCP power off when no card is
  present (bsc#1012628).
- drivers/misc/vmw_vmci: restrict too big queue size in
  qp_host_alloc_queue (bsc#1012628).
- pstore: Fix typo in compression option name (bsc#1012628).
- dts64: mt7622: fix slow sd card access (bsc#1012628).
- arm64: dts: agilex: fix phy interface bit shift for gmac1 and
  gmac2 (bsc#1012628).
- staging/mt7621-dma: mtk-hsdma.c->hsdma-mt7621.c (bsc#1012628).
- staging: gdm724x: Fix DMA from stack (bsc#1012628).
- staging: rtl8188eu: Add Edimax EW-7811UN V2 to device table
  (bsc#1012628).
- media: i2c: max9286: fix access to unallocated memory
  (bsc#1012628).
- media: v4l: ioctl: Fix memory leak in video_usercopy
  (bsc#1012628).
- media: ir_toy: add another IR Droid device (bsc#1012628).
- media: ipu3-cio2: Fix mbus_code processing in
  cio2_subdev_set_fmt() (bsc#1012628).
- media: marvell-ccic: power up the device on mclk enable
  (bsc#1012628).
- media: smipcie: fix interrupt handling and IR timeout
  (bsc#1012628).
- x86/virt: Eat faults on VMXOFF in reboot flows (bsc#1012628).
- x86/reboot: Force all cpus to exit VMX root if VMX is supported
  (bsc#1012628).
- x86/fault: Fix AMD erratum #91 errata fixup for user code
  (bsc#1012628).
- x86/entry: Fix instrumentation annotation (bsc#1012628).
- powerpc/prom: Fix "ibm,arch-vec-5-platform-support" scan
  (bsc#1012628).
- rcu: Pull deferred rcuog wake up to rcu_eqs_enter() callers
  (bsc#1012628).
- rcu/nocb: Perform deferred wake up before last idle's
  need_resched() check (bsc#1012628).
- rcu/nocb: Trigger self-IPI on late deferred wake up before
  user resume (bsc#1012628).
- entry: Explicitly flush pending rcuog wakeup before last
  rescheduling point (bsc#1012628).
- entry/kvm: Explicitly flush pending rcuog wakeup before last
  rescheduling point (bsc#1012628).
- kprobes: Fix to delay the kprobes jump optimization
  (bsc#1012628).
- arm64: Extend workaround for erratum 1024718 to all versions
  of Cortex-A55 (bsc#1012628).
- iommu/arm-smmu-qcom: Fix mask extraction for bootloader
  programmed SMRs (bsc#1012628).
- mailbox: arm_mhuv2: Skip calling kfree() with invalid pointer
  (bsc#1012628).
- arm64: kexec_file: fix memory leakage in create_dtb() when
  fdt_open_into() fails (bsc#1012628).
- arm64: uprobe: Return EOPNOTSUPP for AARCH32 instruction probing
  (bsc#1012628).
- arm64 module: set plt* section addresses to 0x0 (bsc#1012628).
- arm64: spectre: Prevent lockdep splat on v4 mitigation enable
  path (bsc#1012628).
- riscv: Disable KSAN_SANITIZE for vDSO (bsc#1012628).
- watchdog: qcom: Remove incorrect usage of QCOM_WDT_ENABLE_IRQ
  (bsc#1012628).
- watchdog: mei_wdt: request stop on unregister (bsc#1012628).
- coresight: etm4x: Handle accesses to TRCSTALLCTLR (bsc#1012628).
- mtd: spi-nor: sfdp: Fix last erase region marking (bsc#1012628).
- mtd: spi-nor: sfdp: Fix wrong erase type bitmask for overlaid
  region (bsc#1012628).
- mtd: spi-nor: core: Fix erase type discovery for overlaid region
  (bsc#1012628).
- mtd: spi-nor: core: Add erase size check for erase command
  initialization (bsc#1012628).
- mtd: spi-nor: hisi-sfc: Put child node np on error path
  (bsc#1012628).
- fs/affs: release old buffer head on error path (bsc#1012628).
- seq_file: document how per-entry resources are managed
  (bsc#1012628).
- x86: fix seq_file iteration for pat/memtype.c (bsc#1012628).
- mm: memcontrol: fix swap undercounting in cgroup2 (bsc#1012628).
- mm: memcontrol: fix get_active_memcg return value (bsc#1012628).
- hugetlb: fix update_and_free_page contig page struct assumption
  (bsc#1012628).
- hugetlb: fix copy_huge_page_from_user contig page struct
  assumption (bsc#1012628).
- mm/vmscan: restore zone_reclaim_mode ABI (bsc#1012628).
- mm, compaction: make fast_isolate_freepages() stay within zone
  (bsc#1012628).
- KVM: nSVM: fix running nested guests when npt=0 (bsc#1012628).
- nvmem: qcom-spmi-sdam: Fix uninitialized pdev pointer
  (bsc#1012628).
- module: Ignore _GLOBAL_OFFSET_TABLE_ when warning for undefined
  symbols (bsc#1012628).
- mmc: sdhci-esdhc-imx: fix kernel panic when remove module
  (bsc#1012628).
- mmc: sdhci-pci-o2micro: Bug fix for SDR104 HW tuning failure
  (bsc#1012628).
- powerpc/32: Preserve cr1 in exception prolog stack check to
  fix build error (bsc#1012628).
- powerpc/kexec_file: fix FDT size estimation for kdump kernel
  (bsc#1012628).
- powerpc/32s: Add missing call to kuep_lock on syscall entry
  (bsc#1012628).
- spmi: spmi-pmic-arb: Fix hw_irq overflow (bsc#1012628).
- mei: bus: block send with vtag on non-conformat FW
  (bsc#1012628).
- mei: fix transfer over dma with extended header (bsc#1012628).
- mei: me: emmitsburg workstation DID (bsc#1012628).
- mei: me: add adler lake point S DID (bsc#1012628).
- mei: me: add adler lake point LP DID (bsc#1012628).
- gpio: pcf857x: Fix missing first interrupt (bsc#1012628).
- mfd: gateworks-gsc: Fix interrupt type (bsc#1012628).
- printk: fix deadlock when kernel panic (bsc#1012628).
- exfat: fix shift-out-of-bounds in exfat_fill_super()
  (bsc#1012628).
- zonefs: Fix file size of zones in full condition (bsc#1012628).
- kcmp: Support selection of SYS_kcmp without CHECKPOINT_RESTORE
  (bsc#1012628).
- thermal: cpufreq_cooling: freq_qos_update_request() returns <
  0 on error (bsc#1012628).
- cpufreq: qcom-hw: drop devm_xxx() calls from init/exit hooks
  (bsc#1012628).
- cpufreq: intel_pstate: Change intel_pstate_get_hwp_max()
  argument (bsc#1012628).
- cpufreq: intel_pstate: Get per-CPU max freq via
  MSR_HWP_CAPABILITIES if available (bsc#1012628).
- proc: don't allow async path resolution of /proc/thread-self
  components (bsc#1012628).
- s390/vtime: fix inline assembly clobber list (bsc#1012628).
- virtio/s390: implement virtio-ccw revision 2 correctly
  (bsc#1012628).
- um: mm: check more comprehensively for stub changes
  (bsc#1012628).
- um: defer killing userspace on page table update failures
  (bsc#1012628).
- irqchip/loongson-pch-msi: Use bitmap_zalloc() to allocate bitmap
  (bsc#1012628).
- f2fs: fix out-of-repair __setattr_copy() (bsc#1012628).
- f2fs: enforce the immutable flag on open files (bsc#1012628).
- f2fs: flush data when enabling checkpoint back (bsc#1012628).
- cifs: fix DFS failover (bsc#1012628).
- cifs: check all path components in resolved dfs target
  (bsc#1012628).
- cifs: introduce helper for finding referral server to improve
  DFS target resolution (bsc#1012628).
- cifs: fix nodfs mount option (bsc#1012628).
- cifs: fix handling of escaped ',' in the password mount argument
  (bsc#1012628).
- sparc32: fix a user-triggerable oops in clear_user()
  (bsc#1012628).
- perf stat: Use nftw() instead of ftw() (bsc#1012628).
- spi: fsl: invert spisel_boot signal on MPC8309 (bsc#1012628).
- spi: spi-synquacer: fix set_cs handling (bsc#1012628).
- gfs2: fix glock confusion in function signal_our_withdraw
  (bsc#1012628).
- gfs2: Don't skip dlm unlock if glock has an lvb (bsc#1012628).
- gfs2: Lock imbalance on error path in gfs2_recover_one
  (bsc#1012628).
- gfs2: Recursive gfs2_quota_hold in gfs2_iomap_end (bsc#1012628).
- dm: fix deadlock when swapping to encrypted device
  (bsc#1012628).
- dm table: fix iterate_devices based device capability checks
  (bsc#1012628).
- dm table: fix DAX iterate_devices based device capability checks
  (bsc#1012628).
- dm table: fix zoned iterate_devices based device capability
  checks (bsc#1012628).
- dm writecache: fix performance degradation in ssd mode
  (bsc#1012628).
- dm writecache: return the exact table values that were set
  (bsc#1012628).
- dm writecache: fix writing beyond end of underlying device
  when shrinking (bsc#1012628).
- dm era: Recover committed writeset after crash (bsc#1012628).
- dm era: Update in-core bitset after committing the metadata
  (bsc#1012628).
- dm era: Verify the data block size hasn't changed (bsc#1012628).
- dm era: Fix bitset memory leaks (bsc#1012628).
- dm era: Use correct value size in equality function of writeset
  tree (bsc#1012628).
- dm era: Reinitialize bitset cache before digesting a new
  writeset (bsc#1012628).
- dm era: only resize metadata in preresume (bsc#1012628).
- drm/i915: Reject 446-480MHz HDMI clock on GLK (bsc#1012628).
- kgdb: fix to kill breakpoints on initmem after boot
  (bsc#1012628).
- ipv6: silence compilation warning for non-IPV6 builds
  (bsc#1012628).
- net: icmp: pass zeroed opts from icmp{,v6}_ndo_send before
  sending (bsc#1012628).
- wireguard: selftests: test multiple parallel streams
  (bsc#1012628).
- wireguard: queueing: get rid of per-peer ring buffers
  (bsc#1012628).
- net: sched: fix police ext initialization (bsc#1012628).
- net: qrtr: Fix memory leak in qrtr_tun_open (bsc#1012628).
- net_sched: fix RTNL deadlock again caused by request_module()
  (bsc#1012628).
- ARM: dts: aspeed: Add LCLK to lpc-snoop (bsc#1012628).
- Update config files.
- commit 39714eb
* Thu Mar  4 2021 jslaby@suse.cz
- rpm/check-for-config-changes: ignore more configs
  Specifially, these:
  * CONFIG_CC_HAS_*
  * CONFIG_CC_HAVE_*
  * CONFIG_CC_CAN_*
  * CONFIG_HAVE_[A-Z]*_COMPILER
  * CONFIG_TOOLS_SUPPORT_*
  are compiler specific too. This will allow us to use super configs
  using kernel's dummy-tools.
- commit d12dcbd
* Thu Mar  4 2021 mkubecek@suse.cz
- swap: fix swapfile read/write offset.
- commit bdb065a
* Wed Mar  3 2021 yousaf.kaukab@suse.com
- config: arm64: sync xgmac-mdio config with SLE
- commit 277fee9
* Wed Mar  3 2021 yousaf.kaukab@suse.com
- config: arm64: sync coresight configs with SLE
- commit b4d272d
* Wed Mar  3 2021 jslaby@suse.cz
- Update config files.
  Refresh with dummy-tools.
- commit 433c0e0
* Wed Mar  3 2021 jslaby@suse.cz
- kbuild: dummy-tools, fix inverted tests for gcc (bsc#1181862).
- commit ddbefa3
* Tue Mar  2 2021 dmueller@suse.com
- Remove zte device tree builds
  The zte vendor directory has been dropped in 5.12.rc1 via this change:
  commit 89d4f98ae90d95716009bb89823118a8cfbb94dd
  Author: Arnd Bergmann <arnd@arndb.de>
  Date:   Mon Jan 18 14:06:09 2021 +0100
- commit 6811d6c
* Mon Mar  1 2021 mkubecek@suse.cz
- Update to 5.12-rc1
- eliminated 30 patches (26 stable, 4 other)
  - patches.kernel.org/*
  - patches.suse/drm-bail-out-of-nouveau_channel_new-if-channel-init-.patch
  - patches.suse/floppy-reintroduce-O_NDELAY-fix.patch
  - patches.suse/media-uvcvideo-Accept-invalid-bFormatIndex-and-bFram.patch
  - patches.suse/nvmem-add-driver-to-expose-reserved-memory-as-nvmem.patch
- disable ARM architectures (need config update)
- refresh
  - patches.rpmify/Add-ksym-provides-tool.patch
  - patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch
  - patches.suse/acpi_thermal_passive_blacklist.patch
  - patches.suse/btrfs-use-the-new-VFS-super_block_dev.patch
  - patches.suse/supported-flag
  - patches.suse/supported-flag-modverdir
  - patches.suse/supported-flag-wildcards
  - patches.suse/vfs-add-super_operations-get_inode_dev
- new config options
  - Power management and ACPI options
  - CONFIG_ACPI_FPDT=y
  - General architecture-dependent options
  - CONFIG_LTO_NONE=y
  - Enable loadable module support
  - CONFIG_TRIM_UNUSED_KSYMS=n
  - Networking support
  - CONFIG_IP_VS_TWOS=m
  - CONFIG_NET_DSA_TAG_XRS700X=m
  - CONFIG_NFC_VIRTUAL_NCI=m
  - Library routines
  - CONFIG_STACK_HASH_ORDER=20
  - Kernel hacking
  - CONFIG_DEBUG_INFO_DWARF_TOOLCHAIN_DEFAULT=n
  - CONFIG_KFENCE=y
  - CONFIG_KFENCE_STATIC_KEYS=y
  - CONFIG_KFENCE_SAMPLE_INTERVAL=100
  - CONFIG_KFENCE_NUM_OBJECTS=255
  - CONFIG_KFENCE_STRESS_TEST_FAULTS=0
  - CONFIG_DEBUG_IRQFLAGS=n
  - PCI support
  - CONFIG_PCI_EPF_NTB=m
  - CONFIG_CXL_BUS=m
  - CONFIG_CXL_MEM=m
  - CONFIG_CXL_MEM_RAW_COMMANDS=n
  - Network device support
  - CONFIG_NET_DSA_XRS700X_I2C=m
  - CONFIG_NET_DSA_XRS700X_MDIO=m
  - CONFIG_MLX5_SF=y
  - CONFIG_XILINX_EMACLITE=n
  - CONFIG_MT7921E=m
  - Power management
  - CONFIG_CHARGER_LTC4162L=m
  - CONFIG_CHARGER_BQ256XX=m
  - CONFIG_SENSORS_AHT10=m
  - CONFIG_SENSORS_TPS23861=m
  - CONFIG_REGULATOR_MT6315=m
  - Multimedia support
  - CONFIG_CIO2_BRIDGE=y
  - CONFIG_VIDEO_OV5648=m
  - CONFIG_VIDEO_OV8865=m
  - CONFIG_VIDEO_RDACM21=m
  - Sound card support
  - CONFIG_SND_JACK_INJECTION_DEBUG=n
  - CONFIG_SND_INTEL_BYT_PREFER_SOF=y
  - CONFIG_SND_SOC_RT5659=m
  - CONFIG_SND_SOC_LPASS_RX_MACRO=n
  - CONFIG_SND_SOC_LPASS_TX_MACRO=n
  - HID support
  - CONFIG_HID_PLAYSTATION=m
  - CONFIG_PLAYSTATION_FF=y
  - CONFIG_I2C_HID_ACPI=m
  - USB support
  - CONFIG_USB_CDNS_SUPPORT=m
  - CONFIG_USB_CDNSP_PCI=m
  - CONFIG_USB_CDNSP_GADGET=y
  - CONFIG_USB_CDNSP_HOST=y
  - CONFIG_USB_SERIAL_XR=m
  - LED Support
  - CONFIG_LEDS_TRIGGER_TTY=m
  - CONFIG_LEDS_BLINK=y
  - Microsoft Surface Platform-Specific Device Drivers
  - CONFIG_SURFACE_HOTPLUG=m
  - CONFIG_SURFACE_ACPI_NOTIFY=m
  - CONFIG_SURFACE_AGGREGATOR=m
  - CONFIG_SURFACE_AGGREGATOR_CDEV=m
  - CONFIG_SURFACE_AGGREGATOR_BUS=y
  - CONFIG_SURFACE_AGGREGATOR_ERROR_INJECTION=n
  - Industrial I/O support
  - CONFIG_AD5766=n
  - CONFIG_YAMAHA_YAS530=n
  - CONFIG_HID_SENSOR_CUSTOM_INTEL_HINGE=n
  - Generic powercap sysfs driver
  - CONFIG_DTPM=y
  - CONFIG_DTPM_CPU=y
  - Misc devices
  - CONFIG_BCM_VK=m
  - CONFIG_BCM_VK_TTY=y
  - CONFIG_TCG_TIS_I2C_CR50=m
  - CONFIG_SVC_I3C_MASTER=m
  - CONFIG_MMC_CRYPTO=y
  - CONFIG_INTEL_LDMA=y
  - CONFIG_DMABUF_DEBUG=n
  - CONFIG_ACRN_HSM=m
  - CONFIG_FPGA_DFL_EMIF=m
  - CONFIG_NTB_EPF=m
  - CONFIG_FPGA_DFL_NIOS_INTEL_PAC_N3000=m
  - x86
  - CONFIG_X86_PLATFORM_DRIVERS_DELL=y
  - OF dependent drivers (i386, ppc64/ppc64le, riscv64)
  - PCIE_MICROCHIP_HOST=y
  - VIDEO_IMX334=m
  - DRM_PANEL_DSI_CM=n
  - DRM_PANEL_KHADAS_TS050=n
  - I2C_HID_OF=m
  - I2C_HID_OF_GOODIX=m
  - COMMON_CLK_AXI_CLKGEN=m
  - i386
  - NET_DSA_MV88E6XXX_PTP=y
  - SPI_CADENCE_QUADSPI=m
  - LEDS_BLINK_LGM=m
  - s390x
  - TIME_NS=y
  - DEBUG_ENTRY=n
  - riscv64
  - NUMA=y
  - NODES_SHIFT=2
  - SPARSEMEM_VMEMMAP=y
  - DEFERRED_STRUCT_PAGE_INIT=y
  - LEDS_BLINK_LGM=m
  - KGDB_HONOUR_BLOCKLIST=y
  - FAIL_FUNCTION=n
  - KPROBES_SANITY_TEST=n
  - NUMA_BALANCING=y
  - NUMA_BALANCING_DEFAULT_ENABLED=y
- commit 42fc050
* Mon Mar  1 2021 mkubecek@suse.cz
- rpm/kernel-source.spec.in: temporary workaround for a build failure
  Upstream c6x architecture removal left a dangling link behind which
  triggers openSUSE post-build check in kernel-source, failing
  kernel-source build.
  A fix deleting the danglink link has been submitted but it did not make
  it into 5.12-rc1. Unfortunately we cannot add it as a patch as patch
  utility does not handle symlink removal. Add a temporary band-aid which
  deletes all dangling symlinks after unpacking the kernel source tarball.
  [jslaby] It's not that temporary as we are dragging this for quite some
  time in master. The reason is that this can happen any time again, so
  let's have this in packaging instead.
- rpm/kernel-source.spec.in: temporary workaround for a build failure
  Upstream c6x architecture removal left a dangling link behind which
  triggers openSUSE post-build check in kernel-source, failing
  kernel-source build.
  A fix deleting the danglink link has been submitted but it did not make
  it into 5.12-rc1. Unfortunately we cannot add it as a patch as patch
  utility does not handle symlink removal. Add a temporary band-aid which
  deletes all dangling symlinks after unpacking the kernel source tarball.
- commit 52a1ad7
* Sun Feb 28 2021 schwab@suse.de
- config: riscv64: enable EFI_STUB for vanilla
- commit bcd346c
* Fri Feb 26 2021 jslaby@suse.cz
- Linux 5.11.2 (bsc#1012628).
- KVM: Use kvm_pfn_t for local PFN variable in
  hva_to_pfn_remapped() (bsc#1012628).
- mm: provide a saner PTE walking API for modules (bsc#1012628).
- KVM: do not assume PTE is writable after follow_pfn
  (bsc#1012628).
- KVM: x86: Zap the oldest MMU pages, not the newest
  (bsc#1012628).
- hwmon: (dell-smm) Add XPS 15 L502X to fan control blacklist
  (bsc#1012628).
- arm64: tegra: Add power-domain for Tegra210 HDA (bsc#1012628).
- Bluetooth: btusb: Some Qualcomm Bluetooth adapters stop working
  (bsc#1012628).
- ntfs: check for valid standard information attribute
  (bsc#1012628).
- usb: quirks: add quirk to start video capture on ELMO L-12F
  document camera reliable (bsc#1012628).
- USB: quirks: sort quirk entries (bsc#1012628).
- HID: make arrays usage and value to be the same (bsc#1012628).
- bpf: Fix truncation handling for mod32 dst reg wrt zero
  (bsc#1012628).
- commit 6fd6105
* Fri Feb 26 2021 mkubecek@suse.cz
- config: refresh
- fix misspelled USB gadget debugging options
- commit 20be8e3
* Wed Feb 24 2021 oneukum@suse.com
- Update config files. Update config files. Enable USB_GADGET(jsc#SLE-14042)
- supported.conf:
  After discussion what the feature request implied, it was
  decided that gadget mode is also needed on x86_64
- commit 4adcbc0
* Wed Feb 24 2021 msuchanek@suse.de
- macros.kernel-source: Use spec_install_pre for certificate installation (boo#1182672).
  Since rpm 4.16 files installed during build phase are lost.
- commit d0b887e
* Wed Feb 24 2021 mkubecek@suse.cz
- update mainline references
- update mainline references:
  patches.suse/drm-bail-out-of-nouveau_channel_new-if-channel-init-.patch
  patches.suse/floppy-reintroduce-O_NDELAY-fix.patch
  patches.suse/media-uvcvideo-Accept-invalid-bFormatIndex-and-bFram.patch
- commit 4eacbc9
* Tue Feb 23 2021 jslaby@suse.cz
- Linux 5.11.1 (bsc#1012628).
- Xen/x86: don't bail early from clear_foreign_p2m_mapping()
  (bsc#1012628).
- Xen/x86: also check kernel mapping in set_foreign_p2m_mapping()
  (bsc#1012628).
- Xen/gntdev: correct dev_bus_addr handling in
  gntdev_map_grant_pages() (bsc#1012628).
- Xen/gntdev: correct error checking in gntdev_map_grant_pages()
  (bsc#1012628).
- xen/arm: don't ignore return errors from set_phys_to_machine
  (bsc#1012628).
- xen-blkback: don't "handle" error by BUG() (bsc#1012628).
- xen-netback: don't "handle" error by BUG() (bsc#1012628).
- xen-scsiback: don't "handle" error by BUG() (bsc#1012628).
- xen-blkback: fix error handling in xen_blkbk_map()
  (bsc#1012628).
- tty: protect tty_write from odd low-level tty disciplines
  (bsc#1012628).
- Bluetooth: btusb: Always fallback to alt 1 for WBS
  (bsc#1012628).
- commit 3652ea1
* Mon Feb 22 2021 mbrugger@suse.com
- arm: Update config files.
  Set CONFIG_WATCHDOG_SYSFS to true (bsc#1182560)
- commit 702d1a3
* Mon Feb 22 2021 msuchanek@suse.de
- rpm/kernel-subpackage-build: Workaround broken bot
  (https://github.com/openSUSE/openSUSE-release-tools/issues/2439)
- commit b74d860
* Wed Feb 17 2021 nsaenzjulienne@suse.de
- Update config files: Set reset-raspberrypi as builtin (bsc#1180336)
  This driver is needed in order to boot through USB. Ideally the kernel
  module should be selected by dracut, but it's not. So make it builtin
  until the relevant dracut fixes are available.
- commit 8186eab
* Tue Feb 16 2021 mkubecek@suse.cz
- series.conf: cleanup
- move patches on the way to mainline into respective section
  patches.suse/drm-bail-out-of-nouveau_channel_new-if-channel-init-.patch
  patches.suse/media-uvcvideo-Accept-invalid-bFormatIndex-and-bFram.patch
  patches.suse/media-dvb-usb-Fix-memory-leak-at-error-in-dvb_usb_de.patch
  patches.suse/media-dvb-usb-Fix-use-after-free-access.patch
  patches.suse/media-pwc-Use-correct-device-for-DMA.patch
- commit 8309a4e
* Mon Feb 15 2021 msuchanek@suse.de
- kernel-binary.spec: Add back initrd and image symlink ghosts to
  filelist (bsc#1182140).
  Fixes: 76a9256314c3 ("rpm/kernel-{source,binary}.spec: do not include ghost symlinks (boo#1179082).")
- commit 606c9d1
* Mon Feb 15 2021 tiwai@suse.de
- rpm/post.sh: Avoid purge-kernel for the first installed kernel (bsc#1180058)
- commit c29e77d
* Mon Feb 15 2021 jslaby@suse.cz
- Refresh
  patches.suse/drm-bail-out-of-nouveau_channel_new-if-channel-init-.patch.
- Refresh
  patches.suse/media-uvcvideo-Accept-invalid-bFormatIndex-and-bFram.patch.
  Update upstream status.
- commit 1916d9d
* Mon Feb 15 2021 mkubecek@suse.cz
- Update to 5.11 final
- refresh configs
- commit 253d8c6
* Sat Feb 13 2021 jslaby@suse.cz
- Linux 5.10.16 (bsc#1012628).
- squashfs: add more sanity checks in xattr id lookup
  (bsc#1012628).
- squashfs: add more sanity checks in inode lookup (bsc#1012628).
- squashfs: add more sanity checks in id lookup (bsc#1012628).
- squashfs: avoid out of bounds writes in decompressors
  (bsc#1012628).
- Revert "mm: memcontrol: avoid workload stalls when lowering
  memory.high" (bsc#1012628).
- nilfs2: make splice write available again (bsc#1012628).
- drm/i915: Skip vswing programming for TBT (bsc#1012628).
- drm/i915: Fix ICL MG PHY vswing handling (bsc#1012628).
- bpf: Fix verifier jsgt branch analysis on max bound
  (bsc#1012628).
- bpf: Fix 32 bit src register truncation on div/mod
  (bsc#1012628).
- bpf: Fix verifier jmp32 pruning decision logic (bsc#1012628).
- regulator: Fix lockdep warning resolving supplies (bsc#1012628).
- blk-cgroup: Use cond_resched() when destroy blkgs (bsc#1012628).
- i2c: mediatek: Move suspend and resume handling to NOIRQ phase
  (bsc#1012628).
- SUNRPC: Handle 0 length opaque XDR object data properly
  (bsc#1012628).
- SUNRPC: Move simple_get_bytes and simple_get_netobj into
  private header (bsc#1012628).
- iwlwifi: queue: bail out on invalid freeing (bsc#1012628).
- iwlwifi: mvm: guard against device removal in reprobe
  (bsc#1012628).
- iwlwifi: pcie: add rules to match Qu with Hr2 (bsc#1012628).
- iwlwifi: mvm: invalidate IDs of internal stations at mvm start
  (bsc#1012628).
- iwlwifi: pcie: fix context info memory leak (bsc#1012628).
- iwlwifi: pcie: add a NULL check in iwl_pcie_txq_unmap
  (bsc#1012628).
- iwlwifi: mvm: take mutex for calling iwl_mvm_get_sync_time()
  (bsc#1012628).
- iwlwifi: mvm: skip power command when unbinding vif during CSA
  (bsc#1012628).
- ASoC: Intel: sof_sdw: set proper flags for Dell TGL-H SKU 0A5E
  (bsc#1012628).
- ASoC: ak4458: correct reset polarity (bsc#1012628).
- ALSA: hda: intel-dsp-config: add PCI id for TGL-H (bsc#1012628).
- pNFS/NFSv4: Improve rejection of out-of-order layouts
  (bsc#1012628).
- pNFS/NFSv4: Try to return invalid layout in
  pnfs_layout_process() (bsc#1012628).
- chtls: Fix potential resource leak (bsc#1012628).
- ASoC: Intel: Skylake: Zero snd_ctl_elem_value (bsc#1012628).
- mac80211: 160MHz with extended NSS BW in CSA (bsc#1012628).
- drm/nouveau/nvif: fix method count when pushing an array
  (bsc#1012628).
- ASoC: wm_adsp: Fix control name parsing for multi-fw
  (bsc#1012628).
- regulator: core: avoid regulator_resolve_supply() race condition
  (bsc#1012628).
- af_key: relax availability checks for skb size calculation
  (bsc#1012628).
- powerpc/64/signal: Fix regression in __kernel_sigtramp_rt64()
  semantics (bsc#1012628).
- gpiolib: cdev: clear debounce period if line set to output
  (bsc#1012628).
- io_uring: drop mm/files between task_work_submit (bsc#1012628).
- io_uring: reinforce cancel on flush during exit (bsc#1012628).
- io_uring: fix sqo ownership false positive warning
  (bsc#1012628).
- io_uring: fix list corruption for splice file_get (bsc#1012628).
- io_uring: fix flush cqring overflow list while
  TASK_INTERRUPTIBLE (bsc#1012628).
- io_uring: fix cancellation taking mutex while
  TASK_UNINTERRUPTIBLE (bsc#1012628).
- io_uring: replace inflight_wait with tctx->wait (bsc#1012628).
- io_uring: fix __io_uring_files_cancel() with
  TASK_UNINTERRUPTIBLE (bsc#1012628).
- io_uring: if we see flush on exit, cancel related tasks
  (bsc#1012628).
- io_uring: account io_uring internal files as REQ_F_INFLIGHT
  (bsc#1012628).
- io_uring: fix files cancellation (bsc#1012628).
- io_uring: always batch cancel in *cancel_files() (bsc#1012628).
- io_uring: pass files into kill timeouts/poll (bsc#1012628).
- io_uring: don't iterate io_uring_cancel_files() (bsc#1012628).
- io_uring: add a {task,files} pair matching helper (bsc#1012628).
- io_uring: simplify io_task_match() (bsc#1012628).
- commit 11381f3
* Fri Feb 12 2021 tiwai@suse.de
- Update config files: enable CONFIG_SERIAL_DEV_CTRL_TTYPORT on x86 (bsc#1182035)
  For supporting MS Surface devices. This required CONFIG_SERIAL_DEV_BUS
  to be built-in. Also this allowed CONFIG_BT_HCIUART_BCM=y as well.
- commit 52688e6
* Fri Feb 12 2021 tiwai@suse.de
- media: pwc: Use correct device for DMA (bsc#1181133).
- commit 721eebd
* Fri Feb 12 2021 tiwai@suse.de
- Drop pwc fix patch; it'll be replaced with the upstream fix (bsc#1181133)
- commit 2202405
* Fri Feb 12 2021 nsaenzjulienne@suse.de
- Update config files: armv7hl: Set ledtrig-default-on as builtin (bsc#1182128)
- commit fa9dd94
* Thu Feb 11 2021 fdmanana@suse.com
- btrfs: fix crash after non-aligned direct IO write with O_DSYNC
  (bsc#1181605).
- commit 9e44573
* Thu Feb 11 2021 nsaenzjulienne@suse.de
- Update config files: Set ledtrig-default-on as builtin (bsc#1182128)
- commit 7800832
* Thu Feb 11 2021 oneukum@suse.com
- Update config files. Enable DWC3 on x86_64
  DWC3 is now needed on x86_64, too, with the added benefit
  of making x86_64 and ARM64 closer (jsc#SLE-14042)
- commit ad4ea5b
* Wed Feb 10 2021 jslaby@suse.cz
- Linux 5.10.15 (bsc#1012628).
- USB: serial: cp210x: add pid/vid for WSDA-200-USB (bsc#1012628).
- USB: serial: cp210x: add new VID/PID for supporting Teraoka
  AD2000 (bsc#1012628).
- USB: serial: option: Adding support for Cinterion MV31
  (bsc#1012628).
- usb: host: xhci: mvebu: make USB 3.0 PHY optional for Armada
  3720 (bsc#1012628).
- USB: gadget: legacy: fix an error code in eth_bind()
  (bsc#1012628).
- usb: gadget: aspeed: add missing of_node_put (bsc#1012628).
- USB: usblp: don't call usb_set_interface if there's a single
  alt (bsc#1012628).
- usb: renesas_usbhs: Clear pipe running flag in usbhs_pkt_pop()
  (bsc#1012628).
- usb: dwc2: Fix endpoint direction check in ep_from_windex
  (bsc#1012628).
- usb: dwc3: fix clock issue during resume in OTG mode
  (bsc#1012628).
- usb: xhci-mtk: fix unreleased bandwidth data (bsc#1012628).
- usb: xhci-mtk: skip dropping bandwidth of unchecked endpoints
  (bsc#1012628).
- usb: xhci-mtk: break loop when find the endpoint to drop
  (bsc#1012628).
- ARM: OMAP1: OSK: fix ohci-omap breakage (bsc#1012628).
- arm64: dts: qcom: c630: keep both touchpad devices enabled
  (bsc#1012628).
- Input: i8042 - unbreak Pegatron C15B (bsc#1012628).
- arm64: dts: amlogic: meson-g12: Set FL-adj property value
  (bsc#1012628).
- arm64: dts: rockchip: fix vopl iommu irq on px30 (bsc#1012628).
- arm64: dts: rockchip: Use only supported PCIe link speed on
  Pinebook Pro (bsc#1012628).
- ARM: dts: stm32: Fix polarity of the DH DRC02 uSD card detect
  (bsc#1012628).
- ARM: dts: stm32: Connect card-detect signal on DHCOM
  (bsc#1012628).
- ARM: dts: stm32: Disable WP on DHCOM uSD slot (bsc#1012628).
- ARM: dts: stm32: Disable optional TSC2004 on DRC02 board
  (bsc#1012628).
- ARM: dts: stm32: Fix GPIO hog flags on DHCOM DRC02
  (bsc#1012628).
- vdpa/mlx5: Fix memory key MTT population (bsc#1012628).
- bpf, cgroup: Fix optlen WARN_ON_ONCE toctou (bsc#1012628).
- bpf, cgroup: Fix problematic bounds check (bsc#1012628).
- bpf, inode_storage: Put file handler if no storage was found
  (bsc#1012628).
- um: virtio: free vu_dev only with the contained struct device
  (bsc#1012628).
- bpf, preload: Fix build when $(O) points to a relative path
  (bsc#1012628).
- arm64: dts: meson: switch TFLASH_VDD_EN pin to open drain on
  Odroid-C4 (bsc#1012628).
- r8169: work around RTL8125 UDP hw bug (bsc#1012628).
- rxrpc: Fix deadlock around release of dst cached on udp tunnel
  (bsc#1012628).
- arm64: dts: ls1046a: fix dcfg address range (bsc#1012628).
- SUNRPC: Fix NFS READs that start at non-page-aligned offsets
  (bsc#1012628).
- igc: set the default return value to -IGC_ERR_NVM in
  igc_write_nvm_srwr (bsc#1012628).
- igc: check return value of ret_val in
  igc_config_fc_after_link_up (bsc#1012628).
- i40e: Revert "i40e: don't report link up for a VF who hasn't
  enabled queues" (bsc#1012628).
- ibmvnic: device remove has higher precedence over reset
  (bsc#1012628).
- net/mlx5: Fix leak upon failure of rule creation (bsc#1012628).
- net/mlx5e: Update max_opened_tc also when channels are closed
  (bsc#1012628).
- net/mlx5e: Release skb in case of failure in tc update skb
  (bsc#1012628).
- net: lapb: Copy the skb before sending a packet (bsc#1012628).
- net: mvpp2: TCAM entry enable should be written after SRAM data
  (bsc#1012628).
- r8169: fix WoL on shutdown if CONFIG_DEBUG_SHIRQ is set
  (bsc#1012628).
- net: ipa: pass correct dma_handle to dma_free_coherent()
  (bsc#1012628).
- ARM: dts: sun7i: a20: bananapro: Fix ethernet phy-mode
  (bsc#1012628).
- nvmet-tcp: fix out-of-bounds access when receiving multiple
  h2cdata PDUs (bsc#1012628).
- vdpa/mlx5: Restore the hardware used index after change map
  (bsc#1012628).
- memblock: do not start bottom-up allocations with kernel_end
  (bsc#1012628).
- kbuild: fix duplicated flags in DEBUG_CFLAGS (bsc#1012628).
- thunderbolt: Fix possible NULL pointer dereference in
  tb_acpi_add_link() (bsc#1012628).
- ovl: fix dentry leak in ovl_get_redirect (bsc#1012628).
- ovl: avoid deadlock on directory ioctl (bsc#1012628).
- ovl: implement volatile-specific fsync error behaviour
  (bsc#1012628).
- mac80211: fix station rate table updates on assoc (bsc#1012628).
- gpiolib: free device name on error path to fix kmemleak
  (bsc#1012628).
- fgraph: Initialize tracing_graph_pause at task creation
  (bsc#1012628).
- tracing/kprobe: Fix to support kretprobe events on unloaded
  modules (bsc#1012628).
- kretprobe: Avoid re-registration of the same kretprobe earlier
  (bsc#1012628).
- tracing: Use pause-on-trace with the latency tracers
  (bsc#1012628).
- tracepoint: Fix race between tracing and removing tracepoint
  (bsc#1012628).
- libnvdimm/namespace: Fix visibility of namespace resource
  attribute (bsc#1012628).
- libnvdimm/dimm: Avoid race between probe and
  available_slots_show() (bsc#1012628).
- genirq: Prevent [devm_]irq_alloc_desc from returning irq 0
  (bsc#1012628).
- genirq/msi: Activate Multi-MSI early when
  MSI_FLAG_ACTIVATE_EARLY is set (bsc#1012628).
- scripts: use pkg-config to locate libcrypto (bsc#1012628).
- xhci: fix bounce buffer usage for non-sg list case
  (bsc#1012628).
- RISC-V: Define MAXPHYSMEM_1GB only for RV32 (bsc#1012628).
- cifs: report error instead of invalid when revalidating a
  dentry fails (bsc#1012628).
- iommu: Check dev->iommu in dev_iommu_priv_get() before
  dereferencing it (bsc#1012628).
- smb3: Fix out-of-bounds bug in SMB2_negotiate() (bsc#1012628).
- smb3: fix crediting for compounding when only one request in
  flight (bsc#1012628).
- mmc: sdhci-pltfm: Fix linking err for sdhci-brcmstb
  (bsc#1012628).
- mmc: core: Limit retries when analyse of SDIO tuples fails
  (bsc#1012628).
- Fix unsynchronized access to sev members through
  svm_register_enc_region (bsc#1012628).
- drm/dp/mst: Export drm_dp_get_vc_payload_bw() (bsc#1012628).
- drm/i915: Fix the MST PBN divider calculation (bsc#1012628).
- drm/i915/gem: Drop lru bumping on display unpinning
  (bsc#1012628).
- drm/i915/gt: Close race between enable_breadcrumbs and
  cancel_breadcrumbs (bsc#1012628).
- drm/i915/display: Prevent double YUV range correction on HDR
  planes (bsc#1012628).
- drm/i915: Extract intel_ddi_power_up_lanes() (bsc#1012628).
- drm/i915: Power up combo PHY lanes for for HDMI as well
  (bsc#1012628).
- drm/amd/display: Revert "Fix EDID parsing after resume from
  suspend" (bsc#1012628).
- io_uring: don't modify identity's files uncess identity is cowed
  (bsc#1012628).
- nvme-pci: avoid the deepest sleep state on Kingston A2000 SSDs
  (bsc#1012628).
- KVM: SVM: Treat SVM as unsupported when running as an SEV guest
  (bsc#1012628).
- KVM: x86/mmu: Fix TDP MMU zap collapsible SPTEs (bsc#1012628).
- KVM: x86: Allow guests to see MSR_IA32_TSX_CTRL even if tsx=off
  (bsc#1012628).
- KVM: x86: fix CPUID entries returned by KVM_GET_CPUID2 ioctl
  (bsc#1012628).
- KVM: x86: Update emulator context mode if SYSENTER xfers to
  64-bit mode (bsc#1012628).
- KVM: x86: Set so called 'reserved CR3 bits in LM mask' at vCPU
  reset (bsc#1012628).
- DTS: ARM: gta04: remove legacy spi-cs-high to make display
  work again (bsc#1012628).
- ARM: dts; gta04: SPI panel chip select is active low
  (bsc#1012628).
- ARM: footbridge: fix dc21285 PCI configuration accessors
  (bsc#1012628).
- ARM: 9043/1: tegra: Fix misplaced tegra_uart_config in
  decompressor (bsc#1012628).
- mm: hugetlbfs: fix cannot migrate the fallocated HugeTLB page
  (bsc#1012628).
- mm: hugetlb: fix a race between freeing and dissolving the page
  (bsc#1012628).
- mm: hugetlb: fix a race between isolating and freeing page
  (bsc#1012628).
- mm: hugetlb: remove VM_BUG_ON_PAGE from page_huge_active
  (bsc#1012628).
- mm, compaction: move high_pfn to the for loop scope
  (bsc#1012628).
- mm/vmalloc: separate put pages and flush VM flags (bsc#1012628).
- mm: thp: fix MADV_REMOVE deadlock on shmem THP (bsc#1012628).
- mm/filemap: add missing mem_cgroup_uncharge() to
  __add_to_page_cache_locked() (bsc#1012628).
- x86/build: Disable CET instrumentation in the kernel
  (bsc#1012628).
- x86/debug: Fix DR6 handling (bsc#1012628).
- x86/debug: Prevent data breakpoints on __per_cpu_offset
  (bsc#1012628).
- x86/debug: Prevent data breakpoints on cpu_dr7 (bsc#1012628).
- x86/apic: Add extra serialization for non-serializing MSRs
  (bsc#1012628).
- Input: goodix - add support for Goodix GT9286 chip
  (bsc#1012628).
- Input: xpad - sync supported devices with fork on GitHub
  (bsc#1012628).
- Input: ili210x - implement pressure reporting for ILI251x
  (bsc#1012628).
- md: Set prev_flush_start and flush_bio in an atomic way
  (bsc#1012628).
- igc: Report speed and duplex as unknown when device is runtime
  suspended (bsc#1012628).
- neighbour: Prevent a dead entry from updating gc_list
  (bsc#1012628).
- net: ip_tunnel: fix mtu calculation (bsc#1012628).
- udp: ipv4: manipulate network header of NATed UDP GRO fraglist
  (bsc#1012628).
- net: dsa: mv88e6xxx: override existent unicast portvec in
  port_fdb_add (bsc#1012628).
- net: sched: replaced invalid qdisc tree flush helper in
  qdisc_replace (bsc#1012628).
- commit 24c2efe
* Tue Feb  9 2021 jslaby@suse.cz
- Update
  patches.kernel.org/5.10.13-143-vsock-fix-the-race-conditions-in-multi-transp.patch
  (bsc#1012628 bsc#1181806 CVE-2021-26708).
  Add CVE number.
- commit bf327d1
* Mon Feb  8 2021 matwey.kornilov@gmail.com
- config: arm64: Use y for CLK_RK3399
  This is to fix booting on RK3399 systems (JeOS-rockpi4)
  When compiled as 'm' there are lots of errors related to clk and no host mmc
  controler initialized.
- commit 52fdc54
* Mon Feb  8 2021 mkubecek@suse.cz
- Update to 5.11-rc7
- refresh configs
- commit 68cabb0
* Sun Feb  7 2021 jslaby@suse.cz
- Linux 5.10.14 (bsc#1012628).
- workqueue: Restrict affinity change to rescuer (bsc#1012628).
- kthread: Extract KTHREAD_IS_PER_CPU (bsc#1012628).
- x86/cpu: Add another Alder Lake CPU to the Intel family
  (bsc#1012628).
- objtool: Don't fail the kernel build on fatal errors
  (bsc#1012628).
- habanalabs: disable FW events on device removal (bsc#1012628).
- habanalabs: fix backward compatibility of idle check
  (bsc#1012628).
- habanalabs: zero pci counters packet before submit to FW
  (bsc#1012628).
- drm/amd/display: Fixed corruptions on HPDRX link loss restore
  (bsc#1012628).
- drm/amd/display: Use hardware sequencer functions for PG control
  (bsc#1012628).
- drm/amd/display: Change function decide_dp_link_settings to
  avoid infinite looping (bsc#1012628).
- drm/amd/display: Allow PSTATE chnage when no displays are
  enabled (bsc#1012628).
- drm/amd/display: Update dram_clock_change_latency for DCN2.1
  (bsc#1012628).
- selftests/powerpc: Only test lwm/stmw on big endian
  (bsc#1012628).
- platform/x86: thinkpad_acpi: Add P53/73 firmware to
  fan_quirk_table for dual fan control (bsc#1012628).
- nvmet: set right status on error in id-ns handler (bsc#1012628).
- nvme-pci: allow use of cmb on v1.4 controllers (bsc#1012628).
- nvme-tcp: avoid request double completion for concurrent
  nvme_tcp_timeout (bsc#1012628).
- nvme-rdma: avoid request double completion for concurrent
  nvme_rdma_timeout (bsc#1012628).
- nvme: check the PRINFO bit before deciding the host buffer
  length (bsc#1012628).
- udf: fix the problem that the disc content is not displayed
  (bsc#1012628).
- i2c: tegra: Create i2c_writesl_vi() to use with VI I2C for
  filling TX FIFO (bsc#1012628).
- ALSA: hda: Add Cometlake-R PCI ID (bsc#1012628).
- scsi: ibmvfc: Set default timeout to avoid crash during
  migration (bsc#1012628).
- mac80211: fix encryption key selection for 802.3 xmit
  (bsc#1012628).
- mac80211: fix fast-rx encryption check (bsc#1012628).
- mac80211: fix incorrect strlen of .write in debugfs
  (bsc#1012628).
- objtool: Don't add empty symbols to the rbtree (bsc#1012628).
- ALSA: hda: Add AlderLake-P PCI ID and HDMI codec vid
  (bsc#1012628).
- ASoC: SOF: Intel: hda: Resume codec to do jack detection
  (bsc#1012628).
- scsi: fnic: Fix memleak in vnic_dev_init_devcmd2 (bsc#1012628).
- scsi: libfc: Avoid invoking response handler twice if ep is
  already completed (bsc#1012628).
- scsi: scsi_transport_srp: Don't block target in failfast state
  (bsc#1012628).
- x86: __always_inline __{rd,wr}msr() (bsc#1012628).
- locking/lockdep: Avoid noinstr warning for DEBUG_LOCKDEP
  (bsc#1012628).
- habanalabs: fix dma_addr passed to dma_mmap_coherent
  (bsc#1012628).
- platform/x86: intel-vbtn: Support for tablet mode on Dell
  Inspiron 7352 (bsc#1012628).
- platform/x86: touchscreen_dmi: Add swap-x-y quirk for Goodix
  touchscreen on Estar Beauty HD tablet (bsc#1012628).
- tools/power/x86/intel-speed-select: Set higher of
  cpuinfo_max_freq or base_frequency (bsc#1012628).
- tools/power/x86/intel-speed-select: Set scaling_max_freq to
  base_frequency (bsc#1012628).
- phy: cpcap-usb: Fix warning for missing regulator_disable
  (bsc#1012628).
- iommu/vt-d: Do not use flush-queue when caching-mode is on
  (bsc#1012628).
- ARM: 9025/1: Kconfig: CPU_BIG_ENDIAN depends on !LD_IS_LLD
  (bsc#1012628).
- Revert "x86/setup: don't remove E820_TYPE_RAM for pfn 0"
  (bsc#1012628).
- arm64: Do not pass tagged addresses to __is_lm_address()
  (bsc#1012628).
- arm64: Fix kernel address detection of __is_lm_address()
  (bsc#1012628).
- arm64: dts: meson: Describe G12b GPU as coherent (bsc#1012628).
- drm/panfrost: Support cache-coherent integrations (bsc#1012628).
- iommu/io-pgtable-arm: Support coherency for Mali LPAE
  (bsc#1012628).
- ibmvnic: Ensure that CRQ entry read are correctly ordered
  (bsc#1012628).
- net: switchdev: don't set port_obj_info->handled true when
  - EOPNOTSUPP (bsc#1012628).
- net: dsa: bcm_sf2: put device node before return (bsc#1012628).
- mlxsw: spectrum_span: Do not overwrite policer configuration
  (bsc#1012628).
- stmmac: intel: Configure EHL PSE0 GbE and PSE1 GbE to 32 bits
  DMA addressing (bsc#1012628).
- net: octeontx2: Make sure the buffer is 128 byte aligned
  (bsc#1012628).
- net: fec: put child node on error path (bsc#1012628).
- net: stmmac: dwmac-intel-plat: remove config data on error
  (bsc#1012628).
- net: dsa: microchip: Adjust reset release timing to match
  reference reset circuit (bsc#1012628).
- commit 0a69f62
* Fri Feb  5 2021 jslaby@suse.cz
- Update
  patches.kernel.org/5.10.13-143-vsock-fix-the-race-conditions-in-multi-transp.patch
  (bsc#1012628 bsc#1181806).
  Add bsc reference.
- commit 64ec974
* Thu Feb  4 2021 jslaby@suse.cz
- net/mlx5: Fix function calculation for page trees (git-fixes).
- commit e976b88
* Thu Feb  4 2021 jslaby@suse.cz
- Linux 5.10.13 (bsc#1012628).
- iwlwifi: provide gso_type to GSO packets (bsc#1012628).
- nbd: freeze the queue while we're adding connections
  (bsc#1012628).
- tty: avoid using vfs_iocb_iter_write() for redirected console
  writes (bsc#1012628).
- ACPI: sysfs: Prefer "compatible" modalias (bsc#1012628).
- ACPI: thermal: Do not call acpi_thermal_check() directly
  (bsc#1012628).
- kernel: kexec: remove the lock operation of
  system_transition_mutex (bsc#1012628).
- ALSA: hda/realtek: Enable headset of ASUS B1400CEPE with ALC256
  (bsc#1012628).
- parisc: Enable -mlong-calls gcc option by default when
  !CONFIG_MODULES (bsc#1012628).
- media: cec: add stm32 driver (bsc#1012628).
- media: cedrus: Fix H264 decoding (bsc#1012628).
- media: hantro: Fix reset_raw_fmt initialization (bsc#1012628).
- media: rc: fix timeout handling after switch to microsecond
  durations (bsc#1012628).
- media: rc: ite-cir: fix min_timeout calculation (bsc#1012628).
- media: rc: ensure that uevent can be read directly after rc
  device register (bsc#1012628).
- ARM: dts: tbs2910: rename MMC node aliases (bsc#1012628).
- ARM: dts: ux500: Reserve memory carveouts (bsc#1012628).
- ARM: dts: imx6qdl-gw52xx: fix duplicate regulator naming
  (bsc#1012628).
- wext: fix NULL-ptr-dereference with cfg80211's lack of commit()
  (bsc#1012628).
- x86/xen: avoid warning in Xen pv guest with
  CONFIG_AMD_MEM_ENCRYPT enabled (bsc#1012628).
- ASoC: AMD Renoir - refine DMI entries for some Lenovo products
  (bsc#1012628).
- Revert "drm/amdgpu/swsmu: drop set_fan_speed_percent (v2)"
  (bsc#1012628).
- drm/nouveau/kms/gk104-gp1xx: Fix > 64x64 cursors (bsc#1012628).
- drm/i915: Always flush the active worker before returning from
  the wait (bsc#1012628).
- drm/i915/gt: Always try to reserve GGTT address 0x0
  (bsc#1012628).
- drivers/nouveau/kms/nv50-: Reject format modifiers for cursor
  planes (bsc#1012628).
- bcache: only check feature sets when sb->version >=
  BCACHE_SB_VERSION_CDEV_WITH_FEATURES (bsc#1012628).
- net: usb: qmi_wwan: added support for Thales Cinterion PLSx3
  modem family (bsc#1012628).
- s390: uv: Fix sysfs max number of VCPUs reporting (bsc#1012628).
- s390/vfio-ap: No need to disable IRQ after queue reset
  (bsc#1012628).
- PM: hibernate: flush swap writer after marking (bsc#1012628).
- x86/entry: Emit a symbol for register restoring thunk
  (bsc#1012628).
- efi/apple-properties: Reinstate support for boolean properties
  (bsc#1012628).
- crypto: marvel/cesa - Fix tdma descriptor on 64-bit
  (bsc#1012628).
- drivers: soc: atmel: Avoid calling at91_soc_init on non AT91
  SoCs (bsc#1012628).
- drivers: soc: atmel: add null entry at the end of
  at91_soc_allowed_list[] (bsc#1012628).
- btrfs: fix lockdep warning due to seqcount_mutex on 32bit arch
  (bsc#1012628).
- btrfs: fix possible free space tree corruption with online
  conversion (bsc#1012628).
- KVM: x86/pmu: Fix HW_REF_CPU_CYCLES event pseudo-encoding in
  intel_arch_events[] (bsc#1012628).
- KVM: x86/pmu: Fix UBSAN shift-out-of-bounds warning in
  intel_pmu_refresh() (bsc#1012628).
- KVM: arm64: Filter out v8.1+ events on v8.0 HW (bsc#1012628).
- KVM: nSVM: cancel KVM_REQ_GET_NESTED_STATE_PAGES on nested
  vmexit (bsc#1012628).
- KVM: x86: allow KVM_REQ_GET_NESTED_STATE_PAGES outside guest
  mode for VMX (bsc#1012628).
- KVM: nVMX: Sync unsync'd vmcs02 state to vmcs12 on migration
  (bsc#1012628).
- KVM: x86: get smi pending status correctly (bsc#1012628).
- KVM: Forbid the use of tagged userspace addresses for memslots
  (bsc#1012628).
- io_uring: fix wqe->lock/completion_lock deadlock (bsc#1012628).
- xen: Fix XenStore initialisation for XS_LOCAL (bsc#1012628).
- leds: trigger: fix potential deadlock with libata (bsc#1012628).
- arm64: dts: broadcom: Fix USB DMA address translation for
  Stingray (bsc#1012628).
- mt7601u: fix kernel crash unplugging the device (bsc#1012628).
- mt76: mt7663s: fix rx buffer refcounting (bsc#1012628).
- mt7601u: fix rx buffer refcounting (bsc#1012628).
- iwlwifi: Fix IWL_SUBDEVICE_NO_160 macro to use the correct bit
  (bsc#1012628).
- drm/i915/gt: Clear CACHE_MODE prior to clearing residuals
  (bsc#1012628).
- drm/i915/pmu: Don't grab wakeref when enabling events
  (bsc#1012628).
- net/mlx5e: Fix IPSEC stats (bsc#1012628).
- ARM: dts: imx6qdl-kontron-samx6i: fix pwms for lcd-backlight
  (bsc#1012628).
- drm/nouveau/svm: fail NOUVEAU_SVM_INIT ioctl on unsupported
  devices (bsc#1012628).
- drm/vc4: Correct lbm size and calculation (bsc#1012628).
- drm/vc4: Correct POS1_SCL for hvs5 (bsc#1012628).
- drm/i915: Check for all subplatform bits (bsc#1012628).
- drm/i915/selftest: Fix potential memory leak (bsc#1012628).
- uapi: fix big endian definition of ipv6_rpl_sr_hdr
  (bsc#1012628).
- KVM: Documentation: Fix spec for KVM_CAP_ENABLE_CAP_VM
  (bsc#1012628).
- tee: optee: replace might_sleep with cond_resched (bsc#1012628).
- xen-blkfront: allow discard-* nodes to be optional
  (bsc#1012628).
- blk-mq: test QUEUE_FLAG_HCTX_ACTIVE for sbitmap_shared in
  hctx_may_queue (bsc#1012628).
- clk: imx: fix Kconfig warning for i.MX SCU clk (bsc#1012628).
- clk: mmp2: fix build without CONFIG_PM (bsc#1012628).
- clk: qcom: gcc-sm250: Use floor ops for sdcc clks (bsc#1012628).
- ARM: imx: build suspend-imx6.S with arm instruction set
  (bsc#1012628).
- ARM: zImage: atags_to_fdt: Fix node names on added root nodes
  (bsc#1012628).
- netfilter: nft_dynset: add timeout extension to template
  (bsc#1012628).
- Revert "RDMA/mlx5: Fix devlink deadlock on net namespace
  deletion" (bsc#1012628).
- Revert "block: simplify set_init_blocksize" to regain lost
  performance (bsc#1012628).
- xfrm: Fix oops in xfrm_replay_advance_bmp (bsc#1012628).
- xfrm: fix disable_xfrm sysctl when used on xfrm interfaces
  (bsc#1012628).
- selftests: xfrm: fix test return value override issue in
  xfrm_policy.sh (bsc#1012628).
- xfrm: Fix wraparound in xfrm_policy_addr_delta() (bsc#1012628).
- arm64: dts: ls1028a: fix the offset of the reset register
  (bsc#1012628).
- ARM: imx: fix imx8m dependencies (bsc#1012628).
- ARM: dts: imx6qdl-kontron-samx6i: fix i2c_lcd/cam default status
  (bsc#1012628).
- ARM: dts: imx6qdl-sr-som: fix some cubox-i platforms
  (bsc#1012628).
- arm64: dts: imx8mp: Correct the gpio ranges of gpio3
  (bsc#1012628).
- firmware: imx: select SOC_BUS to fix firmware build
  (bsc#1012628).
- RDMA/cxgb4: Fix the reported max_recv_sge value (bsc#1012628).
- ASoC: dt-bindings: lpass: Fix and common up lpass dai ids
  (bsc#1012628).
- ASoC: qcom: Fix incorrect volatile registers (bsc#1012628).
- ASoC: qcom: Fix broken support to MI2S TERTIARY and QUATERNARY
  (bsc#1012628).
- ASoC: qcom: lpass-ipq806x: fix bitwidth regmap field
  (bsc#1012628).
- spi: altera: Fix memory leak on error path (bsc#1012628).
- ASoC: Intel: Skylake: skl-topology: Fix OOPs ib
  skl_tplg_complete (bsc#1012628).
- powerpc/64s: prevent recursive replay_soft_interrupts causing
  superfluous interrupt (bsc#1012628).
- pNFS/NFSv4: Fix a layout segment leak in pnfs_layout_process()
  (bsc#1012628).
- pNFS/NFSv4: Update the layout barrier when we schedule a
  layoutreturn (bsc#1012628).
- ASoC: SOF: Intel: soundwire: fix select/depend unmet
  dependencies (bsc#1012628).
- ASoC: qcom: lpass: Fix out-of-bounds DAI ID lookup
  (bsc#1012628).
- iwlwifi: pcie: avoid potential PNVM leaks (bsc#1012628).
- iwlwifi: pnvm: don't skip everything when not reloading
  (bsc#1012628).
- iwlwifi: pnvm: don't try to load after failures (bsc#1012628).
- iwlwifi: pcie: set LTR on more devices (bsc#1012628).
- iwlwifi: pcie: use jiffies for memory read spin time limit
  (bsc#1012628).
- iwlwifi: pcie: reschedule in long-running memory reads
  (bsc#1012628).
- mac80211: pause TX while changing interface type (bsc#1012628).
- ice: fix FDir IPv6 flexbyte (bsc#1012628).
- ice: Implement flow for IPv6 next header (extension header)
  (bsc#1012628).
- ice: update dev_addr in ice_set_mac_address even if HW filter
  exists (bsc#1012628).
- ice: Don't allow more channels than LAN MSI-X available
  (bsc#1012628).
- ice: Fix MSI-X vector fallback logic (bsc#1012628).
- i40e: acquire VSI pointer only after VF is initialized
  (bsc#1012628).
- igc: fix link speed advertising (bsc#1012628).
- net/mlx5: Fix memory leak on flow table creation error flow
  (bsc#1012628).
- net/mlx5e: E-switch, Fix rate calculation for overflow
  (bsc#1012628).
- net/mlx5e: free page before return (bsc#1012628).
- net/mlx5e: Reduce tc unsupported key print level (bsc#1012628).
- net/mlx5: Maintain separate page trees for ECPF and PF functions
  (bsc#1012628).
- net/mlx5e: Disable hw-tc-offload when MLX5_CLS_ACT config is
  disabled (bsc#1012628).
- net/mlx5e: Fix CT rule + encap slow path offload and deletion
  (bsc#1012628).
- net/mlx5e: Correctly handle changing the number of queues when
  the interface is down (bsc#1012628).
- net/mlx5e: Revert parameters on errors when changing trust
  state without reset (bsc#1012628).
- net/mlx5e: Revert parameters on errors when changing MTU and
  LRO state without reset (bsc#1012628).
- net/mlx5: CT: Fix incorrect removal of tuple_nat_node from
  nat rhashtable (bsc#1012628).
- can: dev: prevent potential information leak in can_fill_info()
  (bsc#1012628).
- ACPI/IORT: Do not blindly trust DMA masks from firmware
  (bsc#1012628).
- of/device: Update dma_range_map only when dev has valid
  dma-ranges (bsc#1012628).
- iommu/amd: Use IVHD EFR for early initialization of IOMMU
  features (bsc#1012628).
- iommu/vt-d: Correctly check addr alignment in
  qi_flush_dev_iotlb_pasid() (bsc#1012628).
- nvme-multipath: Early exit if no path is available
  (bsc#1012628).
- selftests: forwarding: Specify interface when invoking mausezahn
  (bsc#1012628).
- rxrpc: Fix memory leak in rxrpc_lookup_local (bsc#1012628).
- NFC: fix resource leak when target index is invalid
  (bsc#1012628).
- NFC: fix possible resource leak (bsc#1012628).
- ASoC: mediatek: mt8183-da7219: ignore TDM DAI link by default
  (bsc#1012628).
- ASoC: mediatek: mt8183-mt6358: ignore TDM DAI link by default
  (bsc#1012628).
- ASoC: topology: Properly unregister DAI on removal
  (bsc#1012628).
- ASoC: topology: Fix memory corruption in
  soc_tplg_denum_create_values() (bsc#1012628).
- scsi: qla2xxx: Fix description for parameter
  ql2xenforce_iocb_limit (bsc#1012628).
- team: protect features update by RCU to avoid deadlock
  (bsc#1012628).
- tcp: make TCP_USER_TIMEOUT accurate for zero window probes
  (bsc#1012628).
- tcp: fix TLP timer not set when CA_STATE changes from DISORDER
  to OPEN (bsc#1012628).
- vsock: fix the race conditions in multi-transport support
  (bsc#1012628).
- Update patches.suse/acpi_thermal_passive_blacklist.patch
  (bsc#333043).
- commit 3527948
* Wed Feb  3 2021 tiwai@suse.de
- rpm/kernel-binary.spec.in: Correct Supplements in optional subpkg (jsc#SLE-11796)
  The product string was changed from openSUSE to Leap.
- commit 3cb7943
* Mon Feb  1 2021 mkubecek@suse.cz
- Update to 5.11-rc6
- eliminated 1 patch
  - patches.suse/iwlwifi-dbg-Don-t-touch-the-tlv-data.patch
- refresh
  - patches.suse/acpi_thermal_passive_blacklist.patch
- update configs
  - LEDS_RT8515=m
- commit 8d79a70
* Sat Jan 30 2021 jslaby@suse.cz
- Linux 5.10.12 (bsc#1012628).
- gpio: mvebu: fix pwm .get_state period calculation
  (bsc#1012628).
- Revert "mm/slub: fix a memory leak in sysfs_slab_add()"
  (bsc#1012628).
- futex: Ensure the correct return value from futex_lock_pi()
  (bsc#1012628).
- futex: Replace pointless printk in fixup_owner() (bsc#1012628).
- futex: Provide and use pi_state_update_owner() (bsc#1012628).
- rtmutex: Remove unused argument from rt_mutex_proxy_unlock()
  (bsc#1012628).
- futex: Use pi_state_update_owner() in put_pi_state()
  (bsc#1012628).
- futex: Simplify fixup_pi_state_owner() (bsc#1012628).
- futex: Handle faults correctly for PI futexes (bsc#1012628).
- HID: wacom: Correct NULL dereference on AES pen proximity
  (bsc#1012628).
- HID: multitouch: Apply MT_QUIRK_CONFIDENCE quirk for multi-input
  devices (bsc#1012628).
- media: Revert "media: videobuf2: Fix length check for single
  plane dmabuf queueing" (bsc#1012628).
- media: v4l2-subdev.h: BIT() is not available in userspace
  (bsc#1012628).
- RDMA/vmw_pvrdma: Fix network_hdr_type reported in WC
  (bsc#1012628).
- kernel/io_uring: cancel io_uring before task works
  (bsc#1012628).
- io_uring: inline io_uring_attempt_task_drop() (bsc#1012628).
- io_uring: add warn_once for io_uring_flush() (bsc#1012628).
- io_uring: stop SQPOLL submit on creator's death (bsc#1012628).
- io_uring: fix null-deref in io_disable_sqo_submit (bsc#1012628).
- io_uring: do sqo disable on install_fd error (bsc#1012628).
- io_uring: fix false positive sqo warning on flush (bsc#1012628).
- io_uring: fix uring_flush in exit_files() warning (bsc#1012628).
- io_uring: fix skipping disabling sqo on exec (bsc#1012628).
- io_uring: dont kill fasync under completion_lock (bsc#1012628).
- io_uring: fix sleeping under spin in __io_clean_op
  (bsc#1012628).
- objtool: Don't fail on missing symbol table (bsc#1012628).
- mm/page_alloc: add a missing mm_page_alloc_zone_locked()
  tracepoint (bsc#1012628).
- mm: fix a race on nr_swap_pages (bsc#1012628).
- tools: Factor HOSTCC, HOSTLD, HOSTAR definitions (bsc#1012628).
- printk: fix buffer overflow potential for print_text()
  (bsc#1012628).
- printk: fix string termination for record_print_text()
  (bsc#1012628).
- commit a3c8888
* Sat Jan 30 2021 afaerber@suse.com
- config: arm64: Enable Arm SP805 hardware watchdog (boo#1181607)
  The Ten64 board with NXP LS1088A SoC is documented to have Arm SP805 based
  watchdogs, so let's enable the driver for it.
- commit a0c37a5
* Fri Jan 29 2021 mkubecek@suse.cz
- series.conf: cleanup
- move to "almost mainline" section:
  patches.suse/floppy-reintroduce-O_NDELAY-fix.patch
- commit 26dd464
* Thu Jan 28 2021 mgorman@suse.de
- series.conf: Move performance-related tuning parameters to separate section
  This is in preparation for syncing between SLE-specific tunable changes and
  the master tunings.
- commit 1019feb
* Thu Jan 28 2021 msuchanek@suse.de
- floppy: reintroduce O_NDELAY fix (boo#1181018).
- commit fcfe481
* Wed Jan 27 2021 jslaby@suse.cz
- Update config files.
  Only refresh after 5.10.11.
- commit 90db4e6
* Wed Jan 27 2021 jslaby@suse.cz
- Linux 5.10.11 (bsc#1012628).
- scsi: target: tcmu: Fix use-after-free of se_cmd->priv
  (bsc#1012628).
- mtd: rawnand: gpmi: fix dst bit offset when extracting raw
  payload (bsc#1012628).
- mtd: rawnand: nandsim: Fix the logic when selecting Hamming
  soft ECC engine (bsc#1012628).
- i2c: tegra: Wait for config load atomically while in ISR
  (bsc#1012628).
- i2c: bpmp-tegra: Ignore unknown I2C_M flags (bsc#1012628).
- platform/x86: i2c-multi-instantiate: Don't create platform
  device for INT3515 ACPI nodes (bsc#1012628).
- platform/x86: ideapad-laptop: Disable touchpad_switch for
  ELAN0634 (bsc#1012628).
- ALSA: seq: oss: Fix missing error check in
  snd_seq_oss_synth_make_info() (bsc#1012628).
- ALSA: hda/realtek - Limit int mic boost on Acer Aspire E5-575T
  (bsc#1012628).
- ALSA: hda/via: Add minimum mute flag (bsc#1012628).
- crypto: xor - Fix divide error in do_xor_speed() (bsc#1012628).
- dm crypt: fix copy and paste bug in crypt_alloc_req_aead
  (bsc#1012628).
- ACPI: scan: Make acpi_bus_get_device() clear return pointer
  on error (bsc#1012628).
- btrfs: don't get an EINTR during drop_snapshot for reloc
  (bsc#1012628).
- btrfs: do not double free backref nodes on error (bsc#1012628).
- btrfs: fix lockdep splat in btrfs_recover_relocation
  (bsc#1012628).
- btrfs: don't clear ret in btrfs_start_dirty_block_groups
  (bsc#1012628).
- btrfs: send: fix invalid clone operations when cloning from
  the same file and root (bsc#1012628).
- fs: fix lazytime expiration handling in
  __writeback_single_inode() (bsc#1012628).
- pinctrl: ingenic: Fix JZ4760 support (bsc#1012628).
- mmc: core: don't initialize block size from ext_csd if not
  present (bsc#1012628).
- mmc: sdhci-of-dwcmshc: fix rpmb access (bsc#1012628).
- mmc: sdhci-xenon: fix 1.8v regulator stabilization
  (bsc#1012628).
- mmc: sdhci-brcmstb: Fix mmc timeout errors on S5 suspend
  (bsc#1012628).
- dm: avoid filesystem lookup in dm_get_dev_t() (bsc#1012628).
- dm integrity: fix a crash if "recalculate" used without
  "internal_hash" (bsc#1012628).
- dm integrity: conditionally disable "recalculate" feature
  (bsc#1012628).
- drm/atomic: put state on error path (bsc#1012628).
- drm/syncobj: Fix use-after-free (bsc#1012628).
- drm/amdgpu: remove gpu info firmware of green sardine
  (bsc#1012628).
- drm/amd/display: DCN2X Find Secondary Pipe properly in MPO +
  ODM Case (bsc#1012628).
- drm/i915/gt: Prevent use of engine->wa_ctx after error
  (bsc#1012628).
- drm/i915: Check for rq->hwsp validity after acquiring RCU lock
  (bsc#1012628).
- ASoC: Intel: haswell: Add missing pm_ops (bsc#1012628).
- ASoC: rt711: mutex between calibration and power state changes
  (bsc#1012628).
- SUNRPC: Handle TCP socket sends with kernel_sendpage() again
  (bsc#1012628).
- HID: multitouch: Enable multi-input for Synaptics
  pointstick/touchpad device (bsc#1012628).
- HID: sony: select CONFIG_CRC32 (bsc#1012628).
- dm integrity: select CRYPTO_SKCIPHER (bsc#1012628).
- x86/hyperv: Fix kexec panic/hang issues (bsc#1012628).
- scsi: ufs: Relax the condition of
  UFSHCI_QUIRK_SKIP_MANUAL_WB_FLUSH_CTRL (bsc#1012628).
- scsi: ufs: Correct the LUN used in eh_device_reset_handler()
  callback (bsc#1012628).
- scsi: qedi: Correct max length of CHAP secret (bsc#1012628).
- scsi: scsi_debug: Fix memleak in scsi_debug_init()
  (bsc#1012628).
- scsi: sd: Suppress spurious errors when WRITE SAME is being
  disabled (bsc#1012628).
- riscv: Fix kernel time_init() (bsc#1012628).
- riscv: Fix sifive serial driver (bsc#1012628).
- riscv: Enable interrupts during syscalls with M-Mode
  (bsc#1012628).
- HID: logitech-dj: add the G602 receiver (bsc#1012628).
- HID: Ignore battery for Elan touchscreen on ASUS UX550
  (bsc#1012628).
- clk: tegra30: Add hda clock default rates to clock driver
  (bsc#1012628).
- ALSA: hda/tegra: fix tegra-hda on tegra30 soc (bsc#1012628).
- riscv: cacheinfo: Fix using smp_processor_id() in preemptible
  (bsc#1012628).
- arm64: make atomic helpers __always_inline (bsc#1012628).
- xen: Fix event channel callback via INTX/GSI (bsc#1012628).
- x86/xen: Add xen_no_vector_callback option to test PCI INTX
  delivery (bsc#1012628).
- x86/xen: Fix xen_hvm_smp_init() when vector callback not
  available (bsc#1012628).
- dts: phy: fix missing mdio device and probe failure of
  vsc8541-01 device (bsc#1012628).
- dts: phy: add GPIO number and active state used for phy reset
  (bsc#1012628).
- riscv: defconfig: enable gpio support for HiFive Unleashed
  (bsc#1012628).
- drm/amdgpu/psp: fix psp gfx ctrl cmds (bsc#1012628).
- drm/amd/display: disable dcn10 pipe split by default
  (bsc#1012628).
- HID: logitech-hidpp: Add product ID for MX Ergo in Bluetooth
  mode (bsc#1012628).
- drm/amd/display: Fix to be able to stop crc calculation
  (bsc#1012628).
- drm/nouveau/bios: fix issue shadowing expansion ROMs
  (bsc#1012628).
- drm/nouveau/privring: ack interrupts the same way as RM
  (bsc#1012628).
- drm/nouveau/i2c/gm200: increase width of aux semaphore owner
  fields (bsc#1012628).
- drm/nouveau/mmu: fix vram heap sizing (bsc#1012628).
- drm/nouveau/kms/nv50-: fix case where notifier buffer is at
  offset 0 (bsc#1012628).
- io_uring: flush timeouts that should already have expired
  (bsc#1012628).
- libperf tests: If a test fails return non-zero (bsc#1012628).
- libperf tests: Fail when failing to get a tracepoint id
  (bsc#1012628).
- RISC-V: Set current memblock limit (bsc#1012628).
- RISC-V: Fix maximum allowed phsyical memory for RV32
  (bsc#1012628).
- x86/xen: fix 'nopvspin' build error (bsc#1012628).
- nfsd: Fixes for nfsd4_encode_read_plus_data() (bsc#1012628).
- nfsd: Don't set eof on a truncated READ_PLUS (bsc#1012628).
- gpiolib: cdev: fix frame size warning in gpio_ioctl()
  (bsc#1012628).
- pinctrl: aspeed: g6: Fix PWMG0 pinctrl setting (bsc#1012628).
- pinctrl: mediatek: Fix fallback call path (bsc#1012628).
- RDMA/ucma: Do not miss ctx destruction steps in some cases
  (bsc#1012628).
- btrfs: print the actual offset in btrfs_root_name (bsc#1012628).
- scsi: megaraid_sas: Fix MEGASAS_IOC_FIRMWARE regression
  (bsc#1012628).
- scsi: ufs: ufshcd-pltfrm depends on HAS_IOMEM (bsc#1012628).
- scsi: ufs: Fix tm request when non-fatal error happens
  (bsc#1012628).
- crypto: omap-sham - Fix link error without crypto-engine
  (bsc#1012628).
- bpf: Prevent double bpf_prog_put call from
  bpf_tracing_prog_attach (bsc#1012628).
- powerpc: Use the common INIT_DATA_SECTION macro in vmlinux.lds.S
  (bsc#1012628).
- powerpc: Fix alignment bug within the init sections
  (bsc#1012628).
- arm64: entry: remove redundant IRQ flag tracing (bsc#1012628).
- bpf: Reject too big ctx_size_in for raw_tp test run
  (bsc#1012628).
- drm/amdkfd: Fix out-of-bounds read in
  kdf_create_vcrat_image_cpu() (bsc#1012628).
- RDMA/umem: Avoid undefined behavior of rounddown_pow_of_two()
  (bsc#1012628).
- RDMA/cma: Fix error flow in default_roce_mode_store
  (bsc#1012628).
- printk: ringbuffer: fix line counting (bsc#1012628).
- printk: fix kmsg_dump_get_buffer length calulations
  (bsc#1012628).
- iov_iter: fix the uaccess area in copy_compat_iovec_from_user
  (bsc#1012628).
- i2c: octeon: check correct size of maximum RECV_LEN packet
  (bsc#1012628).
- drm/vc4: Unify PCM card's driver_name (bsc#1012628).
- platform/x86: intel-vbtn: Drop HP Stream x360 Convertible PC
  11 from allow-list (bsc#1012628).
- platform/x86: hp-wmi: Don't log a warning on
  HPWMI_RET_UNKNOWN_COMMAND errors (bsc#1012628).
- gpio: sifive: select IRQ_DOMAIN_HIERARCHY rather than depend
  on it (bsc#1012628).
- ALSA: hda: Balance runtime/system PM if direct-complete is
  disabled (bsc#1012628).
- xsk: Clear pool even for inactive queues (bsc#1012628).
- selftests: net: fib_tests: remove duplicate log test
  (bsc#1012628).
- can: dev: can_restart: fix use after free bug (bsc#1012628).
- can: vxcan: vxcan_xmit: fix use after free bug (bsc#1012628).
- can: peak_usb: fix use after free bugs (bsc#1012628).
- perf evlist: Fix id index for heterogeneous systems
  (bsc#1012628).
- i2c: sprd: depend on COMMON_CLK to fix compile tests
  (bsc#1012628).
- iio: common: st_sensors: fix possible infinite loop in
  st_sensors_irq_thread (bsc#1012628).
- iio: ad5504: Fix setting power-down state (bsc#1012628).
- drivers: iio: temperature: Add delay after the addressed reset
  command in mlx90632.c (bsc#1012628).
- iio: adc: ti_am335x_adc: remove omitted iio_kfifo_free()
  (bsc#1012628).
- counter:ti-eqep: remove floor (bsc#1012628).
- powerpc/64s: fix scv entry fallback flush vs interrupt
  (bsc#1012628).
- cifs: do not fail __smb_send_rqst if non-fatal signals are
  pending (bsc#1012628).
- irqchip/mips-cpu: Set IPI domain parent chip (bsc#1012628).
- x86/fpu: Add kernel_fpu_begin_mask() to selectively initialize
  state (bsc#1012628).
- x86/topology: Make __max_die_per_package available
  unconditionally (bsc#1012628).
- x86/mmx: Use KFPU_387 for MMX string operations (bsc#1012628).
- x86/setup: don't remove E820_TYPE_RAM for pfn 0 (bsc#1012628).
- proc_sysctl: fix oops caused by incorrect command parameters
  (bsc#1012628).
- mm: memcg/slab: optimize objcg stock draining (bsc#1012628).
- mm: memcg: fix memcg file_dirty numa stat (bsc#1012628).
- mm: fix numa stats for thp migration (bsc#1012628).
- io_uring: iopoll requests should also wake task ->in_idle state
  (bsc#1012628).
- io_uring: fix SQPOLL IORING_OP_CLOSE cancelation state
  (bsc#1012628).
- io_uring: fix short read retries for non-reg files
  (bsc#1012628).
- intel_th: pci: Add Alder Lake-P support (bsc#1012628).
- stm class: Fix module init return on allocation failure
  (bsc#1012628).
- serial: mvebu-uart: fix tx lost characters at power off
  (bsc#1012628).
- ehci: fix EHCI host controller initialization sequence
  (bsc#1012628).
- USB: ehci: fix an interrupt calltrace error (bsc#1012628).
- usb: gadget: aspeed: fix stop dma register setting
  (bsc#1012628).
- USB: gadget: dummy-hcd: Fix errors in port-reset handling
  (bsc#1012628).
- usb: udc: core: Use lock when write to soft_connect
  (bsc#1012628).
- usb: bdc: Make bdc pci driver depend on BROKEN (bsc#1012628).
- usb: cdns3: imx: fix writing read-only memory issue
  (bsc#1012628).
- usb: cdns3: imx: fix can't create core device the second time
  issue (bsc#1012628).
- xhci: make sure TRB is fully written before giving it to the
  controller (bsc#1012628).
- xhci: tegra: Delay for disabling LFPS detector (bsc#1012628).
- drivers core: Free dma_range_map when driver probe failed
  (bsc#1012628).
- driver core: Fix device link device name collision
  (bsc#1012628).
- driver core: Extend device_is_dependent() (bsc#1012628).
- drm/i915: s/intel_dp_sink_dpms/intel_dp_set_power/
  (bsc#1012628).
- drm/i915: Only enable DFP 4:4:4->4:2:0 conversion when
  outputting YCbCr 4:4:4 (bsc#1012628).
- x86/entry: Fix noinstr fail (bsc#1012628).
- x86/cpu/amd: Set __max_die_per_package on AMD (bsc#1012628).
- cls_flower: call nla_ok() before nla_next() (bsc#1012628).
- netfilter: rpfilter: mask ecn bits before fib lookup
  (bsc#1012628).
- tools: gpio: fix %%llu warning in gpio-event-mon.c (bsc#1012628).
- tools: gpio: fix %%llu warning in gpio-watch.c (bsc#1012628).
- drm/i915/hdcp: Update CP property in update_pipe (bsc#1012628).
- sh: dma: fix kconfig dependency for G2_DMA (bsc#1012628).
- sh: Remove unused HAVE_COPY_THREAD_TLS macro (bsc#1012628).
- locking/lockdep: Cure noinstr fail (bsc#1012628).
- ASoC: SOF: Intel: fix page fault at probe if i915 init fails
  (bsc#1012628).
- octeontx2-af: Fix missing check bugs in rvu_cgx.c (bsc#1012628).
- net: dsa: mv88e6xxx: also read STU state in
  mv88e6250_g1_vtu_getnext (bsc#1012628).
- selftests/powerpc: Fix exit status of pkey tests (bsc#1012628).
- sh_eth: Fix power down vs. is_opened flag ordering
  (bsc#1012628).
- nvme-pci: refactor nvme_unmap_data (bsc#1012628).
- nvme-pci: fix error unwind in nvme_map_data (bsc#1012628).
- cachefiles: Drop superfluous readpages aops NULL check
  (bsc#1012628 bsc#1175245).
- lightnvm: fix memory leak when submit fails (bsc#1012628).
- skbuff: back tiny skbs with kmalloc() in __netdev_alloc_skb()
  too (bsc#1012628).
- kasan: fix unaligned address is unhandled in
  kasan_remove_zero_shadow (bsc#1012628).
- kasan: fix incorrect arguments passing in kasan_add_zero_shadow
  (bsc#1012628).
- tcp: fix TCP socket rehash stats mis-accounting (bsc#1012628).
- net_sched: gen_estimator: support large ewma log (bsc#1012628).
- udp: mask TOS bits in udp_v4_early_demux() (bsc#1012628).
- ipv6: create multicast route with RTPROT_KERNEL (bsc#1012628).
- net_sched: avoid shift-out-of-bounds in tcindex_set_parms()
  (bsc#1012628).
- net_sched: reject silly cell_log in qdisc_get_rtab()
  (bsc#1012628).
- ipv6: set multicast flag on the multicast route (bsc#1012628).
- net: mscc: ocelot: allow offloading of bridge on top of LAG
  (bsc#1012628).
- net: Disable NETIF_F_HW_TLS_RX when RXCSUM is disabled
  (bsc#1012628).
- net: dsa: b53: fix an off by one in checking "vlan->vid"
  (bsc#1012628).
- tcp: do not mess with cloned skbs in tcp_add_backlog()
  (bsc#1012628).
- tcp: fix TCP_USER_TIMEOUT with zero window (bsc#1012628).
- net: mscc: ocelot: Fix multicast to the CPU port (bsc#1012628).
- net: core: devlink: use right genl user_ptr when handling port
  param get/set (bsc#1012628).
- pinctrl: qcom: Allow SoCs to specify a GPIO function that's
  not 0 (bsc#1012628).
- pinctrl: qcom: No need to read-modify-write the interrupt status
  (bsc#1012628).
- pinctrl: qcom: Properly clear "intr_ack_high" interrupts when
  unmasking (bsc#1012628).
- pinctrl: qcom: Don't clear pending interrupts when enabling
  (bsc#1012628).
- x86/sev: Fix nonistr violation (bsc#1012628).
- tty: implement write_iter (bsc#1012628).
- tty: fix up hung_up_tty_write() conversion (bsc#1012628).
- net: systemport: free dev before on error path (bsc#1012628).
- x86/sev-es: Handle string port IO to kernel memory properly
  (bsc#1012628).
- tcp: Fix potential use-after-free due to double kfree()
  (bsc#1012628).
- ASoC: SOF: Intel: hda: Avoid checking jack on system suspend
  (bsc#1012628).
- drm/i915/hdcp: Get conn while content_type changed
  (bsc#1012628).
- bpf: Local storage helpers should check nullness of owner ptr
  passed (bsc#1012628).
- kernfs: implement ->read_iter (bsc#1012628).
- kernfs: implement ->write_iter (bsc#1012628).
- kernfs: wire up ->splice_read and ->splice_write (bsc#1012628).
- interconnect: imx8mq: Use icc_sync_state (bsc#1012628).
- fs/pipe: allow sendfile() to pipe again (bsc#1012628).
- Commit 9bb48c82aced ("tty: implement write_iter") converted
  the tty layer to use write_iter. Fix the redirected_tty_write
  declaration also in n_tty and change the comparisons to use
  write_iter instead of write. also in n_tty and change the
  comparisons to use write_iter instead of write (bsc#1012628).
- mm: fix initialization of struct page for holes in memory layout
  (bsc#1012628).
- Revert "mm: fix initialization of struct page for holes in
  memory layout" (bsc#1012628).
- Delete
  patches.suse/fs-cachefs-Drop-superfluous-readpages-aops-NULL-chec.patch.
- commit 7d05541
* Tue Jan 26 2021 tiwai@suse.de
- ALSA: hda/via: Apply the workaround generically for Clevo
  machines (bsc#1181330).
- commit 87d962b
* Mon Jan 25 2021 mkubecek@suse.cz
- Update to 5.11-rc5
- eliminated 3 patches
  - patches.suse/fs-cachefs-Drop-superfluous-readpages-aops-NULL-chec.patch
  - patches.suse/irq-export-irq_check_status_bit-symbol.patch
  - patches.suse/x86-xen-fix-nopvspin-build-error.patch
- refresh configs
- commit 1a51baa
* Sat Jan 23 2021 jslaby@suse.cz
- Linux 5.10.10 (bsc#1012628).
- spi: cadence: cache reference clock rate during probe
  (bsc#1012628).
- spi: fsl: Fix driver breakage when SPI_CS_HIGH is not set in
  spi->mode (bsc#1012628).
- cxgb4/chtls: Fix tid stuck due to wrong update of qid
  (bsc#1012628).
- net: dsa: unbind all switches from tree when DSA master unbinds
  (bsc#1012628).
- mac80211: check if atf has been disabled in
  __ieee80211_schedule_txq (bsc#1012628).
- mac80211: do not drop tx nulldata packets on encrypted links
  (bsc#1012628).
- drm/panel: otm8009a: allow using non-continuous dsi clock
  (bsc#1012628).
- can: mcp251xfd: mcp251xfd_handle_rxif_one(): fix wrong NULL
  pointer check (bsc#1012628).
- net: stmmac: use __napi_schedule() for PREEMPT_RT (bsc#1012628).
- rxrpc: Fix handling of an unsupported token type in rxrpc_read()
  (bsc#1012628).
- net: dsa: clear devlink port type before unregistering slave
  netdevs (bsc#1012628).
- net: phy: smsc: fix clk error handling (bsc#1012628).
- dt-bindings: net: renesas,etheravb: RZ/G2H needs
  tx-internal-delay-ps (bsc#1012628).
- net: avoid 32 x truesize under-estimation for tiny skbs
  (bsc#1012628).
- net: stmmac: fix taprio configuration when base_time is in
  the past (bsc#1012628).
- net: stmmac: fix taprio schedule configuration (bsc#1012628).
- net: sit: unregister_netdevice on newlink's error path
  (bsc#1012628).
- net: stmmac: Fixed mtu channged by cache aligned (bsc#1012628).
- i40e: fix potential NULL pointer dereferencing (bsc#1012628).
- rxrpc: Call state should be read with READ_ONCE() under some
  circumstances (bsc#1012628).
- net: dcb: Accept RTM_GETDCB messages carrying set-like DCB
  commands (bsc#1012628).
- net: dcb: Validate netlink message in DCB handler (bsc#1012628).
- esp: avoid unneeded kmap_atomic call (bsc#1012628).
- rndis_host: set proper input size for OID_GEN_PHYSICAL_MEDIUM
  request (bsc#1012628).
- net: mvpp2: Remove Pause and Asym_Pause support (bsc#1012628).
- mlxsw: core: Increase critical threshold for ASIC thermal zone
  (bsc#1012628).
- mlxsw: core: Add validation of transceiver temperature
  thresholds (bsc#1012628).
- tipc: fix NULL deref in tipc_link_xmit() (bsc#1012628).
- net: ipv6: Validate GSO SKB before finish IPv6 processing
  (bsc#1012628).
- netxen_nic: fix MSI/MSI-x interrupts (bsc#1012628).
- udp: Prevent reuseport_select_sock from reading uninitialized
  socks (bsc#1012628).
- net: fix use-after-free when UDP GRO with shared fraglist
  (bsc#1012628).
- net: ipa: modem: add missing SET_NETDEV_DEV() for proper sysfs
  links (bsc#1012628).
- bpf: Fix helper bpf_map_peek_elem_proto pointing to wrong
  callback (bsc#1012628).
- bpf: Support PTR_TO_MEM{,_OR_NULL} register spilling
  (bsc#1012628).
- bpf: Don't leak memory in bpf getsockopt when optlen == 0
  (bsc#1012628).
- nfsd4: readdirplus shouldn't return parent of export
  (bsc#1012628).
- X.509: Fix crash caused by NULL pointer (bsc#1012628).
- bpf: Fix signed_{sub,add32}_overflows type handling
  (bsc#1012628).
- drm/amdgpu/display: drop DCN support for aarch64 (bsc#1012628).
- Update config files.
- x86/hyperv: Initialize clockevents after LAPIC is initialized
  (bsc#1012628).
- bpf: Fix selftest compilation on clang 11 (bsc#1012628).
- Revert "kconfig: remove 'kvmconfig' and 'xenconfig' shorthands"
  (bsc#1012628).
- commit 167b75d
* Fri Jan 22 2021 tiwai@suse.de
- drm/gpu/nouveau/dispnv50: Restore pushing of all data
  (boo#1181271).
- commit c3f7185
* Thu Jan 21 2021 tiwai@suse.de
- media: pwc: Fix the URB buffer allocation (bsc#1181133).
- commit a9c85b1
* Thu Jan 21 2021 tiwai@suse.de
- media: dvb-usb: Fix use-after-free access (bsc#1181104).
- media: dvb-usb: Fix memory leak at error in
  dvb_usb_device_init() (bsc#1181104).
- media: dvb-usb: Fix use-after-free access (bsc#1181104).
- media: dvb-usb: Fix memory leak at error in
  dvb_usb_device_init() (bsc#1181104).
- commit 8c718c9
* Wed Jan 20 2021 msuchanek@suse.de
- Exclude Symbols.list again.
  Removing the exclude builds vanilla/linux-next builds.
  Fixes: 55877625c800 ("kernel-binary.spec.in: Package the obj_install_dir as explicit filelist.")
- commit a1728f2
* Wed Jan 20 2021 jslaby@suse.cz
- Linux 5.10.9 (bsc#1012628).
- btrfs: reloc: fix wrong file extent type check to avoid false
  ENOENT (bsc#1012628).
- btrfs: prevent NULL pointer dereference in extent_io_tree_panic
  (bsc#1012628).
- ALSA: hda/realtek: fix right sounds and mute/micmute LEDs for
  HP machines (bsc#1012628).
- ALSA: doc: Fix reference to mixart.rst (bsc#1012628).
- ASoC: AMD Renoir - add DMI entry for Lenovo ThinkPad X395
  (bsc#1012628).
- ASoC: dapm: remove widget from dirty list on free (bsc#1012628).
- x86/hyperv: check cpu mask after interrupt has been disabled
  (bsc#1012628).
- drm/amdgpu: add green_sardine device id (v2) (bsc#1012628).
- drm/amdgpu: fix DRM_INFO flood if display core is not supported
  (bug 210921) (bsc#1012628).
- drm/amdgpu: add new device id for Renior (bsc#1012628).
- drm/i915: Allow the sysadmin to override security mitigations
  (bsc#1012628).
- drm/i915/gt: Limit VFE threads based on GT (bsc#1012628).
- drm/i915/backlight: fix CPU mode backlight takeover on LPT
  (bsc#1012628).
- drm/bridge: sii902x: Refactor init code into separate function
  (bsc#1012628).
- dt-bindings: display: sii902x: Add supply bindings
  (bsc#1012628).
- drm/bridge: sii902x: Enable I/O and core VCC supplies if present
  (bsc#1012628).
- tracing/kprobes: Do the notrace functions check without kprobes
  on ftrace (bsc#1012628).
- tools/bootconfig: Add tracing_on support to helper scripts
  (bsc#1012628).
- ext4: use IS_ERR instead of IS_ERR_OR_NULL and set inode null
  when IS_ERR (bsc#1012628).
- ext4: fix wrong list_splice in ext4_fc_cleanup (bsc#1012628).
- ext4: fix bug for rename with RENAME_WHITEOUT (bsc#1012628).
- cifs: check pointer before freeing (bsc#1012628).
- cifs: fix interrupted close commands (bsc#1012628).
- riscv: Drop a duplicated PAGE_KERNEL_EXEC (bsc#1012628).
- riscv: return -ENOSYS for syscall -1 (bsc#1012628).
- riscv: Fixup CONFIG_GENERIC_TIME_VSYSCALL (bsc#1012628).
- riscv: Fix KASAN memory mapping (bsc#1012628).
- mips: fix Section mismatch in reference (bsc#1012628).
- mips: lib: uncached: fix non-standard usage of variable 'sp'
  (bsc#1012628).
- MIPS: boot: Fix unaligned access with
  CONFIG_MIPS_RAW_APPENDED_DTB (bsc#1012628).
- MIPS: Fix malformed NT_FILE and NT_SIGINFO in 32bit coredumps
  (bsc#1012628).
- MIPS: relocatable: fix possible boot hangup with KASLR enabled
  (bsc#1012628).
- RDMA/ocrdma: Fix use after free in ocrdma_dealloc_ucontext_pd()
  (bsc#1012628).
- ACPI: scan: Harden acpi_device_add() against device ID overflows
  (bsc#1012628).
- xen/privcmd: allow fetching resource sizes (bsc#1012628).
- compiler.h: Raise minimum version of GCC to 5.1 for arm64
  (bsc#1012628).
- mm/vmalloc.c: fix potential memory leak (bsc#1012628).
- mm/hugetlb: fix potential missing huge page size info
  (bsc#1012628).
- mm/process_vm_access.c: include compat.h (bsc#1012628).
- dm raid: fix discard limits for raid1 (bsc#1012628).
- dm snapshot: flush merged data before committing metadata
  (bsc#1012628).
- dm integrity: fix flush with external metadata device
  (bsc#1012628).
- dm integrity: fix the maximum number of arguments (bsc#1012628).
- dm crypt: use GFP_ATOMIC when allocating crypto requests from
  softirq (bsc#1012628).
- dm crypt: do not wait for backlogged crypto request completion
  in softirq (bsc#1012628).
- dm crypt: do not call bio_endio() from the dm-crypt tasklet
  (bsc#1012628).
- dm crypt: defer decryption to a tasklet if interrupts disabled
  (bsc#1012628).
- stmmac: intel: change all EHL/TGL to auto detect phy addr
  (bsc#1012628).
- r8152: Add Lenovo Powered USB-C Travel Hub (bsc#1012628).
- btrfs: tree-checker: check if chunk item end overflows
  (bsc#1012628).
- ext4: don't leak old mountpoint samples (bsc#1012628).
- io_uring: don't take files/mm for a dead task (bsc#1012628).
- io_uring: drop mm and files after task_work_run (bsc#1012628).
- ARC: build: remove non-existing bootpImage from KBUILD_IMAGE
  (bsc#1012628).
- ARC: build: add uImage.lzma to the top-level target
  (bsc#1012628).
- ARC: build: add boot_targets to PHONY (bsc#1012628).
- ARC: build: move symlink creation to arch/arc/Makefile to
  avoid race (bsc#1012628).
- ARM: omap2: pmic-cpcap: fix maximum voltage to be consistent
  with defaults on xt875 (bsc#1012628).
- ath11k: fix crash caused by NULL rx_channel (bsc#1012628).
- netfilter: ipset: fixes possible oops in mtype_resize
  (bsc#1012628).
- ath11k: qmi: try to allocate a big block of DMA memory first
  (bsc#1012628).
- btrfs: fix async discard stall (bsc#1012628).
- btrfs: merge critical sections of discard lock in workfn
  (bsc#1012628).
- btrfs: fix transaction leak and crash after RO remount caused
  by qgroup rescan (bsc#1012628).
- regulator: bd718x7: Add enable times (bsc#1012628).
- ethernet: ucc_geth: fix definition and size of
  ucc_geth_tx_global_pram (bsc#1012628).
- ARM: dts: ux500/golden: Set display max brightness
  (bsc#1012628).
- habanalabs: adjust pci controller init to new firmware
  (bsc#1012628).
- habanalabs/gaudi: retry loading TPC f/w on -EINTR (bsc#1012628).
- habanalabs: register to pci shutdown callback (bsc#1012628).
- staging: spmi: hisi-spmi-controller: Fix some error handling
  paths (bsc#1012628).
- spi: altera: fix return value for altera_spi_txrx()
  (bsc#1012628).
- habanalabs: Fix memleak in hl_device_reset (bsc#1012628).
- hwmon: (pwm-fan) Ensure that calculation doesn't discard big
  period values (bsc#1012628).
- lib/raid6: Let $(UNROLL) rules work with macOS userland
  (bsc#1012628).
- kconfig: remove 'kvmconfig' and 'xenconfig' shorthands
  (bsc#1012628).
- spi: fix the divide by 0 error when calculating xfer waiting
  time (bsc#1012628).
- io_uring: drop file refs after task cancel (bsc#1012628).
- bfq: Fix computation of shallow depth (bsc#1012628).
- arch/arc: add copy_user_page() to <asm/page.h> to fix build
  error on ARC (bsc#1012628).
- misdn: dsp: select CONFIG_BITREVERSE (bsc#1012628).
- net: ethernet: fs_enet: Add missing MODULE_LICENSE
  (bsc#1012628).
- selftests: fix the return value for UDP GRO test (bsc#1012628).
- nvme-pci: mark Samsung PM1725a as IGNORE_DEV_SUBNQN
  (bsc#1012628).
- nvme: avoid possible double fetch in handling CQE (bsc#1012628).
- nvmet-rdma: Fix list_del corruption on queue establishment
  failure (bsc#1012628).
- drm/amd/display: fix sysfs amdgpu_current_backlight_pwm NULL
  pointer issue (bsc#1012628).
- drm/amdgpu: fix a GPU hang issue when remove device
  (bsc#1012628).
- drm/amd/pm: fix the failure when change power profile for renoir
  (bsc#1012628).
- drm/amdgpu: fix potential memory leak during navi12
  deinitialization (bsc#1012628).
- usb: typec: Fix copy paste error for NVIDIA alt-mode description
  (bsc#1012628).
- iommu/vt-d: Fix lockdep splat in sva bind()/unbind()
  (bsc#1012628).
- ACPI: scan: add stub acpi_create_platform_device() for
  !CONFIG_ACPI (bsc#1012628).
- drm/msm: Call msm_init_vram before binding the gpu
  (bsc#1012628).
- ARM: picoxcell: fix missing interrupt-parent properties
  (bsc#1012628).
- poll: fix performance regression due to out-of-line __put_user()
  (bsc#1012628).
- rcu-tasks: Move RCU-tasks initialization to before
  early_initcall() (bsc#1012628).
- bpf: Simplify task_file_seq_get_next() (bsc#1012628).
- bpf: Save correct stopping point in file seq iteration
  (bsc#1012628).
- x86/sev-es: Fix SEV-ES OUT/IN immediate opcode vc handling
  (bsc#1012628).
- cfg80211: select CONFIG_CRC32 (bsc#1012628).
- nvme-fc: avoid calling _nvme_fc_abort_outstanding_ios from
  interrupt context (bsc#1012628).
- iommu/vt-d: Update domain geometry in iommu_ops.at(de)tach_dev
  (bsc#1012628).
- net/mlx5e: CT: Use per flow counter when CT flow accounting
  is enabled (bsc#1012628).
- net/mlx5: Fix passing zero to 'PTR_ERR' (bsc#1012628).
- net/mlx5: E-Switch, fix changing vf VLANID (bsc#1012628).
- blk-mq-debugfs: Add decode for BLK_MQ_F_TAG_HCTX_SHARED
  (bsc#1012628).
- mm: fix clear_refs_write locking (bsc#1012628).
- mm: don't play games with pinned pages in clear_page_refs
  (bsc#1012628).
- mm: don't put pinned pages into the swap cache (bsc#1012628).
- perf intel-pt: Fix 'CPU too large' error (bsc#1012628).
- dump_common_audit_data(): fix racy accesses to ->d_name
  (bsc#1012628).
- ASoC: meson: axg-tdm-interface: fix loopback (bsc#1012628).
- ASoC: meson: axg-tdmin: fix axg skew offset (bsc#1012628).
- ASoC: Intel: fix error code cnl_set_dsp_D0() (bsc#1012628).
- nvmet-rdma: Fix NULL deref when setting pi_enable and traddr
  INADDR_ANY (bsc#1012628).
- nvme: don't intialize hwmon for discovery controllers
  (bsc#1012628).
- nvme-tcp: fix possible data corruption with bio merges
  (bsc#1012628).
- nvme-tcp: Fix warning with CONFIG_DEBUG_PREEMPT (bsc#1012628).
- NFS4: Fix use-after-free in trace_event_raw_event_nfs4_set_lock
  (bsc#1012628).
- pNFS: We want return-on-close to complete when evicting the
  inode (bsc#1012628).
- pNFS: Mark layout for return if return-on-close was not sent
  (bsc#1012628).
- pNFS: Stricter ordering of layoutget and layoutreturn
  (bsc#1012628).
- NFS: Adjust fs_context error logging (bsc#1012628).
- NFS/pNFS: Don't call pnfs_free_bucket_lseg() before removing
  the request (bsc#1012628).
- NFS/pNFS: Don't leak DS commits in pnfs_generic_retry_commit()
  (bsc#1012628).
- NFS/pNFS: Fix a leak of the layout 'plh_outstanding' counter
  (bsc#1012628).
- NFS: nfs_delegation_find_inode_server must first reference
  the superblock (bsc#1012628).
- NFS: nfs_igrab_and_active must first reference the superblock
  (bsc#1012628).
- scsi: ufs: Fix possible power drain during system suspend
  (bsc#1012628).
- ext4: fix superblock checksum failure when setting password salt
  (bsc#1012628).
- RDMA/restrack: Don't treat as an error allocation ID wrapping
  (bsc#1012628).
- RDMA/usnic: Fix memleak in find_free_vf_and_create_qp_grp
  (bsc#1012628).
- bnxt_en: Improve stats context resource accounting with RDMA
  driver loaded (bsc#1012628).
- RDMA/mlx5: Fix wrong free of blue flame register on error
  (bsc#1012628).
- IB/mlx5: Fix error unwinding when set_has_smi_cap fails
  (bsc#1012628).
- umount(2): move the flag validity checks first (bsc#1012628).
- dm zoned: select CONFIG_CRC32 (bsc#1012628).
- drm/i915/dsi: Use unconditional msleep for the panel_on_delay
  when there is no reset-deassert MIPI-sequence (bsc#1012628).
- drm/i915/icl: Fix initing the DSI DSC power refcount during
  HW readout (bsc#1012628).
- drm/i915/gt: Restore clear-residual mitigations for Ivybridge,
  Baytrail (bsc#1012628).
- mm, slub: consider rest of partial list if acquire_slab()
  fails (bsc#1012628).
- riscv: Trace irq on only interrupt is enabled (bsc#1012628).
- iommu/vt-d: Fix unaligned addresses for
  intel_flush_svm_range_dev() (bsc#1012628).
- net: sunrpc: interpret the return value of kstrtou32 correctly
  (bsc#1012628).
- selftests: netfilter: Pass family parameter "-f" to conntrack
  tool (bsc#1012628).
- dm: eliminate potential source of excessive kernel log noise
  (bsc#1012628).
- ALSA: fireface: Fix integer overflow in transmit_midi_msg()
  (bsc#1012628).
- ALSA: firewire-tascam: Fix integer overflow in midi_port_work()
  (bsc#1012628).
- netfilter: conntrack: fix reading nf_conntrack_buckets
  (bsc#1012628).
- netfilter: nf_nat: Fix memleak in nf_nat_init (bsc#1012628).
- Update config files.
- commit b7732a5
* Mon Jan 18 2021 mkubecek@suse.cz
- update patch metadata
- update upstream reference:
  patches.suse/iwlwifi-dbg-Don-t-touch-the-tlv-data.patch
- commit e7f6170
* Mon Jan 18 2021 mkubecek@suse.cz
- x86/xen: fix 'nopvspin' build error.
  (fix x86_64/debug and i586/debug builds)
- commit 813e08e
* Mon Jan 18 2021 mkubecek@suse.cz
- Update to 5.11-rc4
- update configs
  - KPROBE_EVENTS_ON_NOTRACE=n (new on arm*, ppc64)
- commit 41414a9
* Sun Jan 17 2021 jslaby@suse.cz
- Linux 5.10.8 (bsc#1012628).
- powerpc/32s: Fix RTAS machine check with VMAP stack
  (bsc#1012628).
- io_uring: synchronise IOPOLL on task_submit fail (bsc#1012628).
- io_uring: limit {io|sq}poll submit locking scope (bsc#1012628).
- io_uring: patch up IOPOLL overflow_flush sync (bsc#1012628).
- iommu/arm-smmu-qcom: Initialize SCTLR of the bypass context
  (bsc#1012628).
- io_uring: Fix return value from alloc_fixed_file_ref_node
  (bsc#1012628).
- btrfs: skip unnecessary searches for xattrs when logging an
  inode (bsc#1012628).
- btrfs: fix deadlock when cloning inline extent and low on free
  metadata space (bsc#1012628).
- btrfs: shrink delalloc pages instead of full inodes
  (bsc#1012628).
- net: cdc_ncm: correct overhead in delayed_ndp_size
  (bsc#1012628).
- net: hns3: fix incorrect handling of sctp6 rss tuple
  (bsc#1012628).
- net: hns3: fix the number of queues actually used by ARQ
  (bsc#1012628).
- net: hns3: fix a phy loopback fail issue (bsc#1012628).
- net: stmmac: dwmac-sun8i: Fix probe error handling
  (bsc#1012628).
- net: stmmac: dwmac-sun8i: Balance internal PHY resource
  references (bsc#1012628).
- net: stmmac: dwmac-sun8i: Balance internal PHY power
  (bsc#1012628).
- net: stmmac: dwmac-sun8i: Balance syscon (de)initialization
  (bsc#1012628).
- net: vlan: avoid leaks on register_vlan_dev() failures
  (bsc#1012628).
- net/sonic: Fix some resource leaks in error handling paths
  (bsc#1012628).
- net: bareudp: add missing error handling for
  bareudp_link_config() (bsc#1012628).
- ptp: ptp_ines: prevent build when HAS_IOMEM is not set
  (bsc#1012628).
- net: ipv6: fib: flush exceptions when purging route
  (bsc#1012628).
- tools: selftests: add test for changing routes with PTMU
  exceptions (bsc#1012628).
- net: fix pmtu check in nopmtudisc mode (bsc#1012628).
- net: ip: always refragment ip defragmented packets
  (bsc#1012628).
- chtls: Fix hardware tid leak (bsc#1012628).
- chtls: Remove invalid set_tcb call (bsc#1012628).
- chtls: Fix panic when route to peer not configured
  (bsc#1012628).
- chtls: Avoid unnecessary freeing of oreq pointer (bsc#1012628).
- chtls: Replace skb_dequeue with skb_peek (bsc#1012628).
- chtls: Added a check to avoid NULL pointer dereference
  (bsc#1012628).
- chtls: Fix chtls resources release sequence (bsc#1012628).
- octeontx2-af: fix memory leak of lmac and lmac->name
  (bsc#1012628).
- nexthop: Fix off-by-one error in error path (bsc#1012628).
- nexthop: Unlink nexthop group entry in error path (bsc#1012628).
- nexthop: Bounce NHA_GATEWAY in FDB nexthop groups (bsc#1012628).
- s390/qeth: fix deadlock during recovery (bsc#1012628).
- s390/qeth: fix locking for discipline setup / removal
  (bsc#1012628).
- s390/qeth: fix L2 header access in qeth_l3_osa_features_check()
  (bsc#1012628).
- net: dsa: lantiq_gswip: Exclude RMII from modes that report
  1 GbE (bsc#1012628).
- net/mlx5: Use port_num 1 instead of 0 when delete a RoCE address
  (bsc#1012628).
- net/mlx5e: ethtool, Fix restriction of autoneg with 56G
  (bsc#1012628).
- net/mlx5e: In skb build skip setting mark in switchdev mode
  (bsc#1012628).
- net/mlx5: Check if lag is supported before creating one
  (bsc#1012628).
- ionic: start queues before announcing link up (bsc#1012628).
- HID: wacom: Fix memory leakage caused by kfifo_alloc
  (bsc#1012628).
- fanotify: Fix sys_fanotify_mark() on native x86-32
  (bsc#1012628).
- ARM: OMAP2+: omap_device: fix idling of devices during probe
  (bsc#1012628).
- i2c: sprd: use a specific timeout to avoid system hang up issue
  (bsc#1012628).
- dmaengine: dw-edma: Fix use after free in dw_edma_alloc_chunk()
  (bsc#1012628).
- selftests/bpf: Clarify build error if no vmlinux (bsc#1012628).
- can: tcan4x5x: fix bittiming const, use common bittiming from
  m_can driver (bsc#1012628).
- can: m_can: m_can_class_unregister(): remove erroneous
  m_can_clk_stop() (bsc#1012628).
- can: kvaser_pciefd: select CONFIG_CRC32 (bsc#1012628).
- spi: spi-geni-qcom: Fail new xfers if xfer/cancel/abort pending
  (bsc#1012628).
- cpufreq: powernow-k8: pass policy rather than use
  cpufreq_cpu_get() (bsc#1012628).
- spi: spi-geni-qcom: Fix geni_spi_isr() NULL dereference in
  timeout case (bsc#1012628).
- spi: stm32: FIFO threshold level - fix align packet size
  (bsc#1012628).
- i2c: i801: Fix the i2c-mux gpiod_lookup_table not being properly
  terminated (bsc#1012628).
- i2c: mediatek: Fix apdma and i2c hand-shake timeout
  (bsc#1012628).
- bcache: set bcache device into read-only mode for
  BCH_FEATURE_INCOMPAT_OBSO_LARGE_BUCKET (bsc#1012628).
- interconnect: imx: Add a missing of_node_put after
  of_device_is_available (bsc#1012628).
- interconnect: qcom: fix rpmh link failures (bsc#1012628).
- dmaengine: mediatek: mtk-hsdma: Fix a resource leak in the
  error handling path of the probe function (bsc#1012628).
- dmaengine: milbeaut-xdmac: Fix a resource leak in the error
  handling path of the probe function (bsc#1012628).
- dmaengine: xilinx_dma: check dma_async_device_register return
  value (bsc#1012628).
- dmaengine: xilinx_dma: fix incompatible param warning in
  _child_probe() (bsc#1012628).
- dmaengine: xilinx_dma: fix mixed_enum_type coverity warning
  (bsc#1012628).
- arm64: mm: Fix ARCH_LOW_ADDRESS_LIMIT when !CONFIG_ZONE_DMA
  (bsc#1012628).
- qed: select CONFIG_CRC32 (bsc#1012628).
- phy: dp83640: select CONFIG_CRC32 (bsc#1012628).
- wil6210: select CONFIG_CRC32 (bsc#1012628).
- block: rsxx: select CONFIG_CRC32 (bsc#1012628).
- lightnvm: select CONFIG_CRC32 (bsc#1012628).
- zonefs: select CONFIG_CRC32 (bsc#1012628).
- iommu/vt-d: Fix misuse of ALIGN in qi_flush_piotlb()
  (bsc#1012628).
- iommu/intel: Fix memleak in intel_irq_remapping_alloc
  (bsc#1012628).
- bpftool: Fix compilation failure for net.o with older glibc
  (bsc#1012628).
- nvme-tcp: Fix possible race of io_work and direct send
  (bsc#1012628).
- net/mlx5e: Fix memleak in mlx5e_create_l2_table_groups
  (bsc#1012628).
- net/mlx5e: Fix two double free cases (bsc#1012628).
- regmap: debugfs: Fix a memory leak when calling
  regmap_attach_dev (bsc#1012628).
- wan: ds26522: select CONFIG_BITREVERSE (bsc#1012628).
- arm64: cpufeature: remove non-exist CONFIG_KVM_ARM_HOST
  (bsc#1012628).
- regulator: qcom-rpmh-regulator: correct hfsmps515 definition
  (bsc#1012628).
- net: mvpp2: disable force link UP during port init procedure
  (bsc#1012628).
- drm/i915/dp: Track pm_qos per connector (bsc#1012628).
- net: mvneta: fix error message when MTU too large for XDP
  (bsc#1012628).
- selftests: fib_nexthops: Fix wrong mausezahn invocation
  (bsc#1012628).
- KVM: arm64: Don't access PMCR_EL0 when no PMU is available
  (bsc#1012628).
- xsk: Fix race in SKB mode transmit with shared cq (bsc#1012628).
- xsk: Rollback reservation at NETDEV_TX_BUSY (bsc#1012628).
- block/rnbd-clt: avoid module unload race with close confirmation
  (bsc#1012628).
- can: isotp: isotp_getname(): fix kernel information leak
  (bsc#1012628).
- block: fix use-after-free in disk_part_iter_next (bsc#1012628).
- net: drop bogus skb with CHECKSUM_PARTIAL and offset beyond
  end of trimmed packet (bsc#1012628).
- regmap: debugfs: Fix a reversed if statement in
  regmap_debugfs_init() (bsc#1012628).
- tools headers UAPI: Sync linux/fscrypt.h with the kernel sources
  (bsc#1012628).
- Update config files.
- commit 8611168
* Thu Jan 14 2021 dmueller@suse.com
- arm*: config: Disable CONFIG_CRYPTO_USER_API_ENABLE_OBSOLETE (bsc#1180928)
  We don't need those deprecated ciphers to be enabled, as nothing
  should be using them
- commit 936fdc1
* Wed Jan 13 2021 nsaenzjulienne@suse.de
- nvmem: Add driver to expose reserved memory as nvmem (jsc#SLE-SLE-16616).
- Update config files: Enable nvmem-rmem as module on arm64 & armv7+lpae, disable it otherwise
  This is needed early to get boot-loader configuration working on RPi4;
  an essential feature.
- commit c9a364d
* Wed Jan 13 2021 nsaenzjulienne@suse.de
- Update config files: Enable i2c_mux_pinctrl (jsc#SLE-15318)
- commit 709516b
* Wed Jan 13 2021 jslaby@suse.cz
- scsi: ufs: Fix -Wsometimes-uninitialized warning (git-fixes).
- commit 1c33a89
* Wed Jan 13 2021 jslaby@suse.cz
- Linux 5.10.7 (bsc#1012628).
- i40e: Fix Error I40E_AQ_RC_EINVAL when removing VFs
  (bsc#1012628).
- iavf: fix double-release of rtnl_lock (bsc#1012628).
- net: mvpp2: Add TCAM entry to drop flow control pause frames
  (bsc#1012628).
- net: mvpp2: prs: fix PPPoE with ipv6 packet parse (bsc#1012628).
- net: systemport: set dev->max_mtu to UMAC_MAX_MTU_SIZE
  (bsc#1012628).
- ethernet: ucc_geth: fix use-after-free in ucc_geth_remove()
  (bsc#1012628).
- ethernet: ucc_geth: set dev->max_mtu to 1518 (bsc#1012628).
- ionic: account for vlan tag len in rx buffer len (bsc#1012628).
- atm: idt77252: call pci_disable_device() on error path
  (bsc#1012628).
- net: mvpp2: Fix GoP port 3 Networking Complex Control
  configurations (bsc#1012628).
- net: stmmac: dwmac-meson8b: ignore the second clock input
  (bsc#1012628).
- ibmvnic: fix login buffer memory leak (bsc#1012628).
- ibmvnic: continue fatal error reset after passive init
  (bsc#1012628).
- net: ethernet: mvneta: Fix error handling in mvneta_probe
  (bsc#1012628).
- qede: fix offload for IPIP tunnel packets (bsc#1012628).
- virtio_net: Fix recursive call to cpus_read_lock()
  (bsc#1012628).
- net/ncsi: Use real net-device for response handler
  (bsc#1012628).
- net: ethernet: Fix memleak in ethoc_probe (bsc#1012628).
- net-sysfs: take the rtnl lock when storing xps_cpus
  (bsc#1012628).
- net-sysfs: take the rtnl lock when accessing xps_cpus_map and
  num_tc (bsc#1012628).
- net-sysfs: take the rtnl lock when storing xps_rxqs
  (bsc#1012628).
- net-sysfs: take the rtnl lock when accessing xps_rxqs_map and
  num_tc (bsc#1012628).
- net: ethernet: ti: cpts: fix ethtool output when no ptp_clock
  registered (bsc#1012628).
- tun: fix return value when the number of iovs exceeds
  MAX_SKB_FRAGS (bsc#1012628).
- e1000e: Only run S0ix flows if shutdown succeeded (bsc#1012628).
- e1000e: bump up timeout to wait when ME un-configures ULP mode
  (bsc#1012628).
- Revert "e1000e: disable s0ix entry and exit flows for ME
  systems" (bsc#1012628).
- e1000e: Export S0ix flags to ethtool (bsc#1012628).
- bnxt_en: Check TQM rings for maximum supported value
  (bsc#1012628).
- net: mvpp2: fix pkt coalescing int-threshold configuration
  (bsc#1012628).
- bnxt_en: Fix AER recovery (bsc#1012628).
- ipv4: Ignore ECN bits for fib lookups in fib_compute_spec_dst()
  (bsc#1012628).
- net: sched: prevent invalid Scell_log shift count (bsc#1012628).
- net: hns: fix return value check in __lb_other_process()
  (bsc#1012628).
- erspan: fix version 1 check in gre_parse_header() (bsc#1012628).
- net: hdlc_ppp: Fix issues when mod_timer is called while timer
  is running (bsc#1012628).
- bareudp: set NETIF_F_LLTX flag (bsc#1012628).
- bareudp: Fix use of incorrect min_headroom size (bsc#1012628).
- vhost_net: fix ubuf refcount incorrectly when sendmsg fails
  (bsc#1012628).
- r8169: work around power-saving bug on some chip versions
  (bsc#1012628).
- net: dsa: lantiq_gswip: Enable GSWIP_MII_CFG_EN also for
  internal PHYs (bsc#1012628).
- net: dsa: lantiq_gswip: Fix GSWIP_MII_CFG(p) register access
  (bsc#1012628).
- CDC-NCM: remove "connected" log message (bsc#1012628).
- ibmvnic: fix: NULL pointer dereference (bsc#1012628).
- net: usb: qmi_wwan: add Quectel EM160R-GL (bsc#1012628).
- selftests: mlxsw: Set headroom size of correct port
  (bsc#1012628).
- stmmac: intel: Add PCI IDs for TGL-H platform (bsc#1012628).
- selftests/vm: fix building protection keys test (bsc#1012628).
- block: add debugfs stanza for QUEUE_FLAG_NOWAIT (bsc#1012628).
- workqueue: Kick a worker based on the actual activation of
  delayed works (bsc#1012628).
- scsi: ufs: Fix wrong print message in dev_err() (bsc#1012628).
- scsi: ufs-pci: Fix restore from S4 for Intel controllers
  (bsc#1012628).
- scsi: ufs-pci: Ensure UFS device is in PowerDown mode for
  suspend-to-disk ->poweroff() (bsc#1012628).
- scsi: ufs-pci: Fix recovery from hibernate exit errors for
  Intel controllers (bsc#1012628).
- scsi: ufs-pci: Enable UFSHCD_CAP_RPM_AUTOSUSPEND for Intel
  controllers (bsc#1012628).
- scsi: block: Introduce BLK_MQ_REQ_PM (bsc#1012628).
- scsi: ide: Do not set the RQF_PREEMPT flag for sense requests
  (bsc#1012628).
- scsi: ide: Mark power management requests with RQF_PM instead
  of RQF_PREEMPT (bsc#1012628).
- scsi: scsi_transport_spi: Set RQF_PM for domain validation
  commands (bsc#1012628).
- scsi: core: Only process PM requests if rpm_status != RPM_ACTIVE
  (bsc#1012628).
- local64.h: make <asm/local64.h> mandatory (bsc#1012628).
- lib/genalloc: fix the overflow when size is too big
  (bsc#1012628).
- depmod: handle the case of /sbin/depmod without /sbin in PATH
  (bsc#1012628).
- scsi: ufs: Clear UAC for FFU and RPMB LUNs (bsc#1012628).
- kbuild: don't hardcode depmod path (bsc#1012628).
- Bluetooth: revert: hci_h5: close serdev device and free hu in
  h5_close (bsc#1012628).
- scsi: block: Remove RQF_PREEMPT and BLK_MQ_REQ_PREEMPT
  (bsc#1012628).
- scsi: block: Do not accept any requests while suspended
  (bsc#1012628).
- crypto: ecdh - avoid buffer overflow in ecdh_set_secret()
  (bsc#1012628).
- crypto: asym_tpm: correct zero out potential secrets
  (bsc#1012628).
- powerpc: Handle .text.{hot,unlikely}.* in linker script
  (bsc#1012628).
- Staging: comedi: Return -EFAULT if copy_to_user() fails
  (bsc#1012628).
- staging: mt7621-dma: Fix a resource leak in an error handling
  path (bsc#1012628).
- usb: gadget: enable super speed plus (bsc#1012628).
- USB: cdc-acm: blacklist another IR Droid device (bsc#1012628).
- USB: cdc-wdm: Fix use after free in
  service_outstanding_interrupt() (bsc#1012628).
- usb: typec: intel_pmc_mux: Configure HPD first for HPD+IRQ
  request (bsc#1012628).
- usb: dwc3: meson-g12a: disable clk on error handling path in
  probe (bsc#1012628).
- usb: dwc3: gadget: Restart DWC3 gadget when enabling pullup
  (bsc#1012628).
- usb: dwc3: gadget: Clear wait flag on dequeue (bsc#1012628).
- usb: dwc3: ulpi: Use VStsDone to detect PHY regs access
  completion (bsc#1012628).
- usb: dwc3: ulpi: Replace CPU-based busyloop with Protocol-based
  one (bsc#1012628).
- usb: dwc3: ulpi: Fix USB2.0 HS/FS/LS PHY suspend regression
  (bsc#1012628).
- usb: chipidea: ci_hdrc_imx: add missing put_device() call in
  usbmisc_get_init_data() (bsc#1012628).
- USB: xhci: fix U1/U2 handling for hardware with XHCI_INTEL_HOST
  quirk set (bsc#1012628).
- usb: usbip: vhci_hcd: protect shift size (bsc#1012628).
- usb: uas: Add PNY USB Portable SSD to unusual_uas (bsc#1012628).
- USB: serial: iuu_phoenix: fix DMA from stack (bsc#1012628).
- USB: serial: option: add LongSung M5710 module support
  (bsc#1012628).
- USB: serial: option: add Quectel EM160R-GL (bsc#1012628).
- USB: yurex: fix control-URB timeout handling (bsc#1012628).
- USB: usblp: fix DMA to stack (bsc#1012628).
- ALSA: usb-audio: Fix UBSAN warnings for MIDI jacks
  (bsc#1012628).
- usb: gadget: select CONFIG_CRC32 (bsc#1012628).
- USB: Gadget: dummy-hcd: Fix shift-out-of-bounds bug
  (bsc#1012628).
- usb: gadget: f_uac2: reset wMaxPacketSize (bsc#1012628).
- usb: gadget: function: printer: Fix a memory leak for interface
  descriptor (bsc#1012628).
- usb: gadget: u_ether: Fix MTU size mismatch with RX packet size
  (bsc#1012628).
- USB: gadget: legacy: fix return error code in acm_ms_bind()
  (bsc#1012628).
- usb: gadget: Fix spinlock lockup on usb_function_deactivate
  (bsc#1012628).
- usb: gadget: configfs: Preserve function ordering after bind
  failure (bsc#1012628).
- usb: gadget: configfs: Fix use-after-free issue with udc_name
  (bsc#1012628).
- USB: serial: keyspan_pda: remove unused variable (bsc#1012628).
- hwmon: (amd_energy) fix allocation of hwmon_channel_info config
  (bsc#1012628).
- mm: make wait_on_page_writeback() wait for multiple pending
  writebacks (bsc#1012628).
- x86/mm: Fix leak of pmd ptlock (bsc#1012628).
- KVM: x86/mmu: Use -1 to flag an undefined spte in
  get_mmio_spte() (bsc#1012628).
- KVM: x86/mmu: Get root level from walkers when retrieving MMIO
  SPTE (bsc#1012628).
- kvm: check tlbs_dirty directly (bsc#1012628).
- KVM: x86/mmu: Ensure TDP MMU roots are freed after yield
  (bsc#1012628).
- x86/resctrl: Use an IPI instead of task_work_add() to update
  PQR_ASSOC MSR (bsc#1012628).
- x86/resctrl: Don't move a task to the same resource group
  (bsc#1012628).
- blk-iocost: fix NULL iocg deref from racing against
  initialization (bsc#1012628).
- ALSA: hda/via: Fix runtime PM for Clevo W35xSS (bsc#1012628).
- ALSA: hda/conexant: add a new hda codec CX11970 (bsc#1012628).
- ALSA: hda/realtek - Fix speaker volume control on Lenovo C940
  (bsc#1012628).
- ALSA: hda/realtek: Add mute LED quirk for more HP laptops
  (bsc#1012628).
- ALSA: hda/realtek: Enable mute and micmute LED on HP EliteBook
  850 G7 (bsc#1012628).
- ALSA: hda/realtek: Add two "Intel Reference board" SSID in
  the ALC256 (bsc#1012628).
- iommu/vt-d: Move intel_iommu info from struct intel_svm to
  struct intel_svm_dev (bsc#1012628).
- btrfs: qgroup: don't try to wait flushing if we're already
  holding a transaction (bsc#1012628).
- btrfs: send: fix wrong file path when there is an inode with
  a pending rmdir (bsc#1012628).
- Revert "device property: Keep secondary firmware node secondary
  by type" (bsc#1012628).
- dmabuf: fix use-after-free of dmabuf's file->f_inode
  (bsc#1012628).
- arm64: link with -z norelro for LLD or aarch64-elf
  (bsc#1012628).
- drm/i915: clear the shadow batch (bsc#1012628).
- drm/i915: clear the gpu reloc batch (bsc#1012628).
- bcache: fix typo from SUUP to SUPP in features.h (bsc#1012628).
- bcache: check unsupported feature sets for bcache register
  (bsc#1012628).
- bcache: introduce BCH_FEATURE_INCOMPAT_LOG_LARGE_BUCKET_SIZE
  for large bucket (bsc#1012628).
- net/mlx5e: Fix SWP offsets when vlan inserted by driver
  (bsc#1012628).
- ARM: dts: OMAP3: disable AES on N950/N9 (bsc#1012628).
- netfilter: x_tables: Update remaining dereference to RCU
  (bsc#1012628).
- netfilter: ipset: fix shift-out-of-bounds in htable_bits()
  (bsc#1012628).
- netfilter: xt_RATEEST: reject non-null terminated string from
  userspace (bsc#1012628).
- netfilter: nft_dynset: report EOPNOTSUPP on missing set feature
  (bsc#1012628).
- dmaengine: idxd: off by one in cleanup code (bsc#1012628).
- x86/mtrr: Correct the range check before performing MTRR type
  lookups (bsc#1012628).
- KVM: x86: fix shift out of bounds reported by UBSAN
  (bsc#1012628).
- xsk: Fix memory leak for failed bind (bsc#1012628).
- rtlwifi: rise completion at the last step of firmware callback
  (bsc#1012628).
- scsi: target: Fix XCOPY NAA identifier lookup (bsc#1012628).
- commit 1ca962e
* Mon Jan 11 2021 mkubecek@suse.cz
- Update to 5.11-rc3
- update configs
  - NULL_TTY=m
  - AQTION=m (also on other architectures than x86_64 and arm64)
- commit 840b25f
* Sun Jan 10 2021 jslaby@suse.cz
- Linux 5.10.6 (bsc#1012628).
- Revert "drm/amd/display: Fix memory leaks in S3 resume"
  (bsc#1012628).
- Revert "mtd: spinand: Fix OOB read" (bsc#1012628).
- rtc: pcf2127: move watchdog initialisation to a separate
  function (bsc#1012628).
- rtc: pcf2127: only use watchdog when explicitly available
  (bsc#1012628).
- dt-bindings: rtc: add reset-source property (bsc#1012628).
- kdev_t: always inline major/minor helper functions
  (bsc#1012628).
- Bluetooth: Fix attempting to set RPA timeout when unsupported
  (bsc#1012628).
- ALSA: hda/realtek - Modify Dell platform name (bsc#1012628).
- drm/i915/tgl: Fix Combo PHY DPLL fractional divider for 38.4MHz
  ref clock (bsc#1012628).
- scsi: ufs: Allow an error return value from ->device_reset()
  (bsc#1012628).
- scsi: ufs: Re-enable WriteBooster after device reset
  (bsc#1012628).
- RDMA/core: remove use of dma_virt_ops (bsc#1012628).
- RDMA/siw,rxe: Make emulated devices virtual in the device tree
  (bsc#1012628).
- fuse: fix bad inode (bsc#1012628).
- perf: Break deadlock involving exec_update_mutex (bsc#1012628).
- rwsem: Implement down_read_killable_nested (bsc#1012628).
- rwsem: Implement down_read_interruptible (bsc#1012628).
- exec: Transform exec_update_mutex into a rw_semaphore
  (bsc#1012628).
- mwifiex: Fix possible buffer overflows in
  mwifiex_cmd_802_11_ad_hoc_start (bsc#1012628).
- commit 5bdc505
* Sat Jan  9 2021 mbrugger@suse.com
- regulator: mt6323: Add OF match table (bsc#1180731).
- regulator: mt6358: Add OF match table (bsc#1180731).
- regulator: mt6360: Add OF match table (bsc#1180731).
- commit a930122
* Sat Jan  9 2021 mbrugger@suse.com
- regulator: mt6323: Add OF match table (bsc#1180731).
- regulator: mt6358: Add OF match table (bsc#1180731).
- regulator: mt6360: Add OF match table (bsc#1180731).
- commit b8fd94e
* Fri Jan  8 2021 tiwai@suse.de
- drm: bail out of nouveau_channel_new if channel init fails
  (CVE-2020-25639 bsc#1176846).
- commit c1cbbd6
* Thu Jan  7 2021 mkubecek@suse.cz
- irq: export irq_check_status_bit symbol.
  Fix aarch64 builds.
- commit 74f9771
* Thu Jan  7 2021 mkubecek@suse.cz
- config: refresh arm configs
- now available: DEBUG_INFO_BTF_MODULES=y
- commit e9c4359
* Thu Jan  7 2021 mkubecek@suse.cz
- iwlwifi: dbg: Don't touch the tlv data (bsc#1180344).
- commit cba8ab9
* Wed Jan  6 2021 jslaby@suse.cz
- drm/docs: Fix todo.rst (git-fixes).
- net/sched: sch_taprio: ensure to reset/destroy all child qdiscs
  (git-fixes).
- commit 19815f3
* Wed Jan  6 2021 jslaby@suse.cz
- Linux 5.10.5 (bsc#1012628).
- net/sched: sch_taprio: reset child qdiscs before freeing them
  (bsc#1012628).
- mptcp: fix security context on server socket (bsc#1012628).
- ethtool: fix error paths in ethnl_set_channels() (bsc#1012628).
- ethtool: fix string set id check (bsc#1012628).
- md/raid10: initialize r10_bio->read_slot before use
  (bsc#1012628).
- drm/amd/display: Add get_dig_frontend implementation for DCEx
  (bsc#1012628).
- io_uring: close a small race gap for files cancel (bsc#1012628).
- jffs2: Allow setting rp_size to zero during remounting
  (bsc#1012628).
- jffs2: Fix NULL pointer dereference in rp_size fs option parsing
  (bsc#1012628).
- spi: dw-bt1: Fix undefined devm_mux_control_get symbol
  (bsc#1012628).
- opp: fix memory leak in _allocate_opp_table (bsc#1012628).
- opp: Call the missing clk_put() on error (bsc#1012628).
- scsi: block: Fix a race in the runtime power management code
  (bsc#1012628).
- mm/hugetlb: fix deadlock in hugetlb_cow error path
  (bsc#1012628).
- mm: memmap defer init doesn't work as expected (bsc#1012628).
- lib/zlib: fix inflating zlib streams on s390 (bsc#1012628).
- io_uring: don't assume mm is constant across submits
  (bsc#1012628).
- io_uring: use bottom half safe lock for fixed file data
  (bsc#1012628).
- io_uring: add a helper for setting a ref node (bsc#1012628).
- io_uring: fix io_sqe_files_unregister() hangs (bsc#1012628).
- uapi: move constants from <linux/kernel.h> to <linux/const.h>
  (bsc#1012628).
- tools headers UAPI: Sync linux/const.h with the kernel headers
  (bsc#1012628).
- cgroup: Fix memory leak when parsing multiple source parameters
  (bsc#1012628).
- zlib: move EXPORT_SYMBOL() and MODULE_LICENSE() out of
  dfltcc_syms.c (bsc#1012628).
- scsi: cxgb4i: Fix TLS dependency (bsc#1012628).
- Bluetooth: hci_h5: close serdev device and free hu in h5_close
  (bsc#1012628).
- fbcon: Disable accelerated scrolling (bsc#1012628).
- reiserfs: add check for an invalid ih_entry_count (bsc#1012628).
- misc: vmw_vmci: fix kernel info-leak by initializing dbells
  in vmci_ctx_get_chkpt_doorbells() (bsc#1012628).
- media: gp8psk: initialize stats at power control logic
  (bsc#1012628).
- f2fs: fix shift-out-of-bounds in sanity_check_raw_super()
  (bsc#1012628).
- ALSA: seq: Use bool for snd_seq_queue internal flags
  (bsc#1012628).
- ALSA: rawmidi: Access runtime->avail always in spinlock
  (bsc#1012628).
- bfs: don't use WARNING: string when it's just info
  (bsc#1012628).
- ext4: check for invalid block size early when mounting a file
  system (bsc#1012628).
- fcntl: Fix potential deadlock in send_sig{io, urg}()
  (bsc#1012628).
- io_uring: check kthread stopped flag when sq thread is unparked
  (bsc#1012628).
- rtc: sun6i: Fix memleak in sun6i_rtc_clk_init (bsc#1012628).
- module: set MODULE_STATE_GOING state when a module fails to load
  (bsc#1012628).
- quota: Don't overflow quota file offsets (bsc#1012628).
- rtc: pl031: fix resource leak in pl031_probe (bsc#1012628).
- powerpc: sysdev: add missing iounmap() on error in
  mpic_msgr_probe() (bsc#1012628).
- i3c master: fix missing destroy_workqueue() on error in
  i3c_master_register (bsc#1012628).
- NFSv4: Fix a pNFS layout related use-after-free race when
  freeing the inode (bsc#1012628).
- f2fs: avoid race condition for shrinker count (bsc#1012628).
- f2fs: fix race of pending_pages in decompression (bsc#1012628).
- module: delay kobject uevent until after module init call
  (bsc#1012628).
- powerpc/64: irq replay remove decrementer overflow check
  (bsc#1012628).
- fs/namespace.c: WARN if mnt_count has become negative
  (bsc#1012628).
- watchdog: rti-wdt: fix reference leak in rti_wdt_probe
  (bsc#1012628).
- um: random: Register random as hwrng-core device (bsc#1012628).
- um: ubd: Submit all data segments atomically (bsc#1012628).
- NFSv4.2: Don't error when exiting early on a READ_PLUS buffer
  overflow (bsc#1012628).
- ceph: fix inode refcount leak when ceph_fill_inode on non-I_NEW
  inode fails (bsc#1012628).
- drm/amd/display: updated wm table for Renoir (bsc#1012628).
- tick/sched: Remove bogus boot "safety" check (bsc#1012628).
- s390: always clear kernel stack backchain before calling
  functions (bsc#1012628).
- io_uring: remove racy overflow list fast checks (bsc#1012628).
- ALSA: pcm: Clear the full allocated memory at hw_params
  (bsc#1012628).
- dm verity: skip verity work if I/O error when system is shutting
  down (bsc#1012628).
- ext4: avoid s_mb_prefetch to be zero in individual scenarios
  (bsc#1012628).
- device-dax: Fix range release (bsc#1012628).
- Refresh patches.suse/supported-flag.
- commit 3bb334e
* Wed Jan  6 2021 dmueller@suse.com
- config.conf: Reenable armv6hl/armv7hl/arm64
- Update config files:
  * Settings copied from x86_64 update
  * arm specific options are =m except if debug or test, =y otherwise
- commit 1fc3034
* Tue Jan  5 2021 tiwai@suse.de
- Revert "drm/amd/display: Fixed Intermittent blue screen on
  OLED panel" (bsc#1180404).
- commit 086fc4c
* Tue Jan  5 2021 tiwai@suse.de
- ALSA: hda/hdmi: Fix incorrect mutex unlock in
  silent_stream_disable() (bsc#1180543).
- commit 010df91
* Mon Jan  4 2021 mkubecek@suse.cz
- Update to 5.11-rc2
- commit b4a462c
* Wed Dec 30 2020 jslaby@suse.cz
- drm/panfrost: Remove unused variables in panfrost_job_close()
  (git-fixes).
- commit 4169c1f
* Wed Dec 30 2020 jslaby@suse.cz
- drm/panfrost: Don't corrupt the queue mutex on open/close
  (git-fixes).
- RDMA/hns: Avoid filling sl in high 3 bits of vlan_id
  (git-fixes).
- scsi: lpfc: Fix variable 'vport' set but not used in
  lpfc_sli4_abts_err_handler() (git-fixes).
- commit 77d98b1
* Wed Dec 30 2020 jslaby@suse.cz
- Linux 5.10.4 (bsc#1012628).
- hwmon: (k10temp) Remove support for displaying voltage and
  current on Zen CPUs (bsc#1012628).
- drm/gma500: fix double free of gma_connector (bsc#1012628).
- iio: adc: at91_adc: add Kconfig dep on the OF symbol and remove
  of_match_ptr() (bsc#1012628).
- drm/aspeed: Fix Kconfig warning & subsequent build errors
  (bsc#1012628).
- drm/mcde: Fix handling of platform_get_irq() error
  (bsc#1012628).
- drm/tve200: Fix handling of platform_get_irq() error
  (bsc#1012628).
- arm64: dts: renesas: hihope-rzg2-ex: Drop rxc-skew-ps from
  ethernet-phy node (bsc#1012628).
- arm64: dts: renesas: cat875: Remove rxc-skew-ps from
  ethernet-phy node (bsc#1012628).
- soc: renesas: rmobile-sysc: Fix some leaks in
  rmobile_init_pm_domains() (bsc#1012628).
- soc: mediatek: Check if power domains can be powered on at
  boot time (bsc#1012628).
- arm64: dts: mediatek: mt8183: fix gce incorrect mbox-cells value
  (bsc#1012628).
- arm64: dts: ipq6018: update the reserved-memory node
  (bsc#1012628).
- arm64: dts: qcom: sc7180: Fix one forgotten interconnect
  reference (bsc#1012628).
- soc: qcom: geni: More properly switch to DMA mode (bsc#1012628).
- Revert "i2c: i2c-qcom-geni: Fix DMA transfer race"
  (bsc#1012628).
- RDMA/bnxt_re: Set queue pair state when being queried
  (bsc#1012628).
- rtc: pcf2127: fix pcf2127_nvmem_read/write() returns
  (bsc#1012628).
- RDMA/bnxt_re: Fix entry size during SRQ create (bsc#1012628).
- selinux: fix error initialization in inode_doinit_with_dentry()
  (bsc#1012628).
- ARM: dts: aspeed-g6: Fix the GPIO memory size (bsc#1012628).
- ARM: dts: aspeed: s2600wf: Fix VGA memory region location
  (bsc#1012628).
- RDMA/core: Fix error return in _ib_modify_qp() (bsc#1012628).
- RDMA/rxe: Compute PSN windows correctly (bsc#1012628).
- x86/mm/ident_map: Check for errors from ident_pud_init()
  (bsc#1012628).
- ARM: p2v: fix handling of LPAE translation in BE mode
  (bsc#1012628).
- RDMA/rtrs-clt: Remove destroy_con_cq_qp in case route resolving
  failed (bsc#1012628).
- RDMA/rtrs-clt: Missing error from rtrs_rdma_conn_established
  (bsc#1012628).
- RDMA/rtrs-srv: Don't guard the whole __alloc_srv with srv_mutex
  (bsc#1012628).
- x86/apic: Fix x2apic enablement without interrupt remapping
  (bsc#1012628).
- ASoC: qcom: fix unsigned int bitwidth compared to less than zero
  (bsc#1012628).
- sched/deadline: Fix sched_dl_global_validate() (bsc#1012628).
- sched: Reenable interrupts in do_sched_yield() (bsc#1012628).
- drm/amdgpu: fix incorrect enum type (bsc#1012628).
- crypto: talitos - Endianess in current_desc_hdr() (bsc#1012628).
- crypto: talitos - Fix return type of current_desc_hdr()
  (bsc#1012628).
- crypto: inside-secure - Fix sizeof() mismatch (bsc#1012628).
- ASoC: sun4i-i2s: Fix lrck_period computation for I2S justified
  mode (bsc#1012628).
- drm/msm: Add missing stub definition (bsc#1012628).
- ARM: dts: aspeed: tiogapass: Remove vuart (bsc#1012628).
- drm/amdgpu: fix build_coefficients() argument (bsc#1012628).
- powerpc/64: Set up a kernel stack for secondaries before
  cpu_restore() (bsc#1012628).
- spi: img-spfi: fix reference leak in img_spfi_resume
  (bsc#1012628).
- f2fs: call f2fs_get_meta_page_retry for nat page (bsc#1012628).
- RDMA/mlx5: Fix corruption of reg_pages in
  mlx5_ib_rereg_user_mr() (bsc#1012628).
- perf test: Use generic event for expand_libpfm_events()
  (bsc#1012628).
- drm/msm/dp: DisplayPort PHY compliance tests fixup
  (bsc#1012628).
- drm/msm/dsi_pll_7nm: restore VCO rate during restore_state
  (bsc#1012628).
- drm/msm/dsi_pll_10nm: restore VCO rate during restore_state
  (bsc#1012628).
- drm/msm/dpu: fix clock scaling on non-sc7180 board
  (bsc#1012628).
- spi: spi-mem: fix reference leak in spi_mem_access_start
  (bsc#1012628).
- scsi: aacraid: Improve compat_ioctl handlers (bsc#1012628).
- pinctrl: core: Add missing #ifdef CONFIG_GPIOLIB (bsc#1012628).
- ASoC: pcm: DRAIN support reactivation (bsc#1012628).
- drm/bridge: tpd12s015: Fix irq registering in tpd12s015_probe
  (bsc#1012628).
- crypto: arm64/poly1305-neon - reorder PAC authentication with
  SP update (bsc#1012628).
- crypto: arm/aes-neonbs - fix usage of cbc(aes) fallback
  (bsc#1012628).
- crypto: caam - fix printing on xts fallback allocation error
  path (bsc#1012628).
- selinux: fix inode_doinit_with_dentry() LABEL_INVALID error
  handling (bsc#1012628).
- nl80211/cfg80211: fix potential infinite loop (bsc#1012628).
- spi: stm32: fix reference leak in stm32_spi_resume
  (bsc#1012628).
- bpf: Fix tests for local_storage (bsc#1012628).
- x86/mce: Correct the detection of invalid notifier priorities
  (bsc#1012628).
- drm/edid: Fix uninitialized variable in drm_cvt_modes()
  (bsc#1012628).
- ath11k: Initialize complete alpha2 for regulatory change
  (bsc#1012628).
- ath11k: Fix number of rules in filtered ETSI regdomain
  (bsc#1012628).
- ath11k: fix wmi init configuration (bsc#1012628).
- brcmfmac: Fix memory leak for unpaired brcmf_{alloc/free}
  (bsc#1012628).
- arm64: dts: exynos: Include common syscon restart/poweroff
  for Exynos7 (bsc#1012628).
- arm64: dts: exynos: Correct psci compatible used on Exynos7
  (bsc#1012628).
- drm/panel: simple: Add flags to boe_nv133fhm_n61 (bsc#1012628).
- Bluetooth: Fix null pointer dereference in hci_event_packet()
  (bsc#1012628).
- Bluetooth: Fix: LL PRivacy BLE device fails to connect
  (bsc#1012628).
- Bluetooth: hci_h5: fix memory leak in h5_close (bsc#1012628).
- spi: stm32-qspi: fix reference leak in stm32 qspi operations
  (bsc#1012628).
- spi: spi-ti-qspi: fix reference leak in ti_qspi_setup
  (bsc#1012628).
- spi: mt7621: fix missing clk_disable_unprepare() on error in
  mt7621_spi_probe (bsc#1012628).
- spi: tegra20-slink: fix reference leak in slink ops of tegra20
  (bsc#1012628).
- spi: tegra20-sflash: fix reference leak in tegra_sflash_resume
  (bsc#1012628).
- spi: tegra114: fix reference leak in tegra spi ops
  (bsc#1012628).
- spi: bcm63xx-hsspi: fix missing clk_disable_unprepare() on
  error in bcm63xx_hsspi_resume (bsc#1012628).
- spi: imx: fix reference leak in two imx operations
  (bsc#1012628).
- ASoC: qcom: common: Fix refcounting in qcom_snd_parse_of()
  (bsc#1012628).
- ath11k: Handle errors if peer creation fails (bsc#1012628).
- mwifiex: fix mwifiex_shutdown_sw() causing sw reset failure
  (bsc#1012628).
- drm/msm/a6xx: Clear shadow on suspend (bsc#1012628).
- drm/msm/a5xx: Clear shadow on suspend (bsc#1012628).
- firmware: tegra: fix strncpy()/strncat() confusion
  (bsc#1012628).
- drm/msm/dp: return correct connection status after suspend
  (bsc#1012628).
- drm/msm/dp: skip checking LINK_STATUS_UPDATED bit (bsc#1012628).
- drm/msm/dp: do not notify audio subsystem if sink doesn't
  support audio (bsc#1012628).
- selftests/run_kselftest.sh: fix dry-run typo (bsc#1012628).
- selftest/bpf: Add missed ip6ip6 test back (bsc#1012628).
- ASoC: wm8994: Fix PM disable depth imbalance on error
  (bsc#1012628).
- ASoC: wm8998: Fix PM disable depth imbalance on error
  (bsc#1012628).
- spi: sprd: fix reference leak in sprd_spi_remove (bsc#1012628).
- virtiofs fix leak in setup (bsc#1012628).
- ASoC: arizona: Fix a wrong free in wm8997_probe (bsc#1012628).
- RDMa/mthca: Work around -Wenum-conversion warning (bsc#1012628).
- ASoC: SOF: Intel: fix Kconfig dependency for
  SND_INTEL_DSP_CONFIG (bsc#1012628).
- arm64: dts: ti: k3-am65*/j721e*: Fix unit address format error
  for dss node (bsc#1012628).
- MIPS: BCM47XX: fix kconfig dependency bug for BCM47XX_BCMA
  (bsc#1012628).
- drm/amdgpu: fix compute queue priority if num_kcq is less than 4
  (bsc#1012628).
- soc: ti: omap-prm: Do not check rstst bit on deassert if
  already deasserted (bsc#1012628).
- crypto: Kconfig - CRYPTO_MANAGER_EXTRA_TESTS requires the
  manager (bsc#1012628).
- crypto: qat - fix status check in qat_hal_put_rel_rd_xfer()
  (bsc#1012628).
- firmware: arm_scmi: Fix missing destroy_workqueue()
  (bsc#1012628).
- drm/udl: Fix missing error code in udl_handle_damage()
  (bsc#1012628).
- staging: greybus: codecs: Fix reference counter leak in error
  handling (bsc#1012628).
- staging: gasket: interrupt: fix the missed eventfd_ctx_put()
  in gasket_interrupt.c (bsc#1012628).
- scripts: kernel-doc: Restore anonymous enum parsing
  (bsc#1012628).
- drm/amdkfd: Put ACPI table after using it (bsc#1012628).
- ionic: use mc sync for multicast filters (bsc#1012628).
- ionic: flatten calls to ionic_lif_rx_mode (bsc#1012628).
- ionic: change set_rx_mode from_ndo to can_sleep (bsc#1012628).
- media: tm6000: Fix sizeof() mismatches (bsc#1012628).
- media: platform: add missing put_device() call in
  mtk_jpeg_clk_init() (bsc#1012628).
- media: mtk-vcodec: add missing put_device() call in
  mtk_vcodec_init_dec_pm() (bsc#1012628).
- media: mtk-vcodec: add missing put_device() call in
  mtk_vcodec_release_dec_pm() (bsc#1012628).
- media: mtk-vcodec: add missing put_device() call in
  mtk_vcodec_init_enc_pm() (bsc#1012628).
- media: v4l2-fwnode: Return -EINVAL for invalid bus-type
  (bsc#1012628).
- media: v4l2-fwnode: v4l2_fwnode_endpoint_parse caller must
  init vep argument (bsc#1012628).
- media: ov5640: fix support of BT656 bus mode (bsc#1012628).
- media: staging: rkisp1: cap: fix runtime PM imbalance on error
  (bsc#1012628).
- media: cedrus: fix reference leak in cedrus_start_streaming
  (bsc#1012628).
- media: platform: add missing put_device() call in
  mtk_jpeg_probe() and mtk_jpeg_remove() (bsc#1012628).
- media: venus: core: change clk enable and disable order in
  resume and suspend (bsc#1012628).
- media: venus: core: vote for video-mem path (bsc#1012628).
- media: venus: core: vote with average bandwidth and peak
  bandwidth as zero (bsc#1012628).
- RDMA/cma: Add missing error handling of listen_id (bsc#1012628).
- ASoC: meson: fix COMPILE_TEST error (bsc#1012628).
- spi: dw: fix build error by selecting MULTIPLEXER (bsc#1012628).
- scsi: core: Fix VPD LUN ID designator priorities (bsc#1012628).
- media: venus: put dummy vote on video-mem path after last
  session release (bsc#1012628).
- media: solo6x10: fix missing snd_card_free in error handling
  case (bsc#1012628).
- video: fbdev: atmel_lcdfb: fix return error code in
  atmel_lcdfb_of_init() (bsc#1012628).
- mmc: sdhci: tegra: fix wrong unit with busy_timeout
  (bsc#1012628).
- drm/omap: dmm_tiler: fix return error code in omap_dmm_probe()
  (bsc#1012628).
- drm/meson: Free RDMA resources after tearing down DRM
  (bsc#1012628).
- drm/meson: Unbind all connectors on module removal
  (bsc#1012628).
- drm/meson: dw-hdmi: Register a callback to disable the regulator
  (bsc#1012628).
- drm/meson: dw-hdmi: Ensure that clocks are enabled before
  touching the TOP registers (bsc#1012628).
- ASoC: intel: SND_SOC_INTEL_KEEMBAY should depend on ARCH_KEEMBAY
  (bsc#1012628).
- iommu/vt-d: include conditionally on CONFIG_INTEL_IOMMU_SVM
  (bsc#1012628).
- Input: ads7846 - fix race that causes missing releases
  (bsc#1012628).
- Input: ads7846 - fix integer overflow on Rt calculation
  (bsc#1012628).
- Input: ads7846 - fix unaligned access on 7845 (bsc#1012628).
- bus: mhi: core: Remove double locking from mhi_driver_remove()
  (bsc#1012628).
- bus: mhi: core: Fix null pointer access when parsing MHI
  configuration (bsc#1012628).
- usb/max3421: fix return error code in max3421_probe()
  (bsc#1012628).
- spi: mxs: fix reference leak in mxs_spi_probe (bsc#1012628).
- selftests/bpf: Fix broken riscv build (bsc#1012628).
- powerpc: Avoid broken GCC __attribute__((optimize))
  (bsc#1012628).
- powerpc/feature: Fix CPU_FTRS_ALWAYS by removing
  CPU_FTRS_GENERIC_32 (bsc#1012628).
- ARM: dts: tacoma: Fix node vs reg mismatch for flash memory
  (bsc#1012628).
- Revert "powerpc/pseries/hotplug-cpu: Remove double free in
  error path" (bsc#1012628).
- powerpc/powernv/sriov: fix unsigned int win compared to less
  than zero (bsc#1012628).
- mfd: htc-i2cpld: Add the missed i2c_put_adapter() in
  htcpld_register_chip_i2c() (bsc#1012628).
- mfd: MFD_SL28CPLD should depend on ARCH_LAYERSCAPE
  (bsc#1012628).
- mfd: stmfx: Fix dev_err_probe() call in stmfx_chip_init()
  (bsc#1012628).
- mfd: cpcap: Fix interrupt regression with regmap clear_ack
  (bsc#1012628).
- EDAC/mce_amd: Use struct cpuinfo_x86.cpu_die_id for AMD NodeId
  (bsc#1012628).
- scsi: ufs: Avoid to call REQ_CLKS_OFF to CLKS_OFF (bsc#1012628).
- scsi: ufs: Fix clkgating on/off (bsc#1012628).
- rcu: Allow rcu_irq_enter_check_tick() from NMI (bsc#1012628).
- rcu,ftrace: Fix ftrace recursion (bsc#1012628).
- rcu/tree: Defer kvfree_rcu() allocation to a clean context
  (bsc#1012628).
- crypto: crypto4xx - Replace bitwise OR with logical OR in
  crypto4xx_build_pd (bsc#1012628).
- crypto: omap-aes - Fix PM disable depth imbalance in
  omap_aes_probe (bsc#1012628).
- crypto: sun8i-ce - fix two error path's memory leak
  (bsc#1012628).
- spi: fix resource leak for drivers without .remove callback
  (bsc#1012628).
- drm/meson: dw-hdmi: Disable clocks on driver teardown
  (bsc#1012628).
- drm/meson: dw-hdmi: Enable the iahb clock early enough
  (bsc#1012628).
- PCI: Disable MSI for Pericom PCIe-USB adapter (bsc#1012628).
- PCI: brcmstb: Initialize "tmp" before use (bsc#1012628).
- soc: ti: knav_qmss: fix reference leak in knav_queue_probe
  (bsc#1012628).
- soc: ti: Fix reference imbalance in knav_dma_probe
  (bsc#1012628).
- drivers: soc: ti: knav_qmss_queue: Fix error return code in
  knav_queue_probe (bsc#1012628).
- soc: qcom: initialize local variable (bsc#1012628).
- arm64: dts: qcom: sm8250: correct compatible for sm8250-mtp
  (bsc#1012628).
- arm64: dts: qcom: msm8916-samsung-a2015: Disable muic i2c pin
  bias (bsc#1012628).
- Input: omap4-keypad - fix runtime PM error handling
  (bsc#1012628).
- clk: meson: Kconfig: fix dependency for G12A (bsc#1012628).
- staging: mfd: hi6421-spmi-pmic: fix error return code in
  hi6421_spmi_pmic_probe() (bsc#1012628).
- ath11k: Fix the rx_filter flag setting for peer rssi stats
  (bsc#1012628).
- RDMA/cxgb4: Validate the number of CQEs (bsc#1012628).
- soundwire: Fix DEBUG_LOCKS_WARN_ON for uninitialized attribute
  (bsc#1012628).
- pinctrl: sunxi: fix irq bank map for the Allwinner A100 pin
  controller (bsc#1012628).
- memstick: fix a double-free bug in memstick_check (bsc#1012628).
- ARM: dts: at91: sam9x60: add pincontrol for USB Host
  (bsc#1012628).
- ARM: dts: at91: sama5d4_xplained: add pincontrol for USB Host
  (bsc#1012628).
- ARM: dts: at91: sama5d3_xplained: add pincontrol for USB Host
  (bsc#1012628).
- mmc: pxamci: Fix error return code in pxamci_probe
  (bsc#1012628).
- brcmfmac: fix error return code in brcmf_cfg80211_connect()
  (bsc#1012628).
- orinoco: Move context allocation after processing the skb
  (bsc#1012628).
- qtnfmac: fix error return code in qtnf_pcie_probe()
  (bsc#1012628).
- rsi: fix error return code in rsi_reset_card() (bsc#1012628).
- cw1200: fix missing destroy_workqueue() on error in
  cw1200_init_common (bsc#1012628).
- dmaengine: mv_xor_v2: Fix error return code in mv_xor_v2_probe()
  (bsc#1012628).
- arm64: dts: qcom: sdm845: Limit ipa iommu streams (bsc#1012628).
- leds: netxbig: add missing put_device() call in
  netxbig_leds_get_of_pdata() (bsc#1012628).
- leds: lp50xx: Fix an error handling path in 'lp50xx_probe_dt()'
  (bsc#1012628).
- leds: turris-omnia: check for LED_COLOR_ID_RGB instead
  LED_COLOR_ID_MULTI (bsc#1012628).
- arm64: tegra: Fix DT binding for IO High Voltage entry
  (bsc#1012628).
- RDMA/cma: Fix deadlock on &lock in rdma_cma_listen_on_all()
  error unwind (bsc#1012628).
- soundwire: qcom: Fix build failure when slimbus is module
  (bsc#1012628).
- drm/imx/dcss: fix rotations for Vivante tiled formats
  (bsc#1012628).
- media: siano: fix memory leak of debugfs members in
  smsdvb_hotplug (bsc#1012628).
- platform/x86: mlx-platform: Remove PSU EEPROM from default
  platform configuration (bsc#1012628).
- platform/x86: mlx-platform: Remove PSU EEPROM from MSN274x
  platform configuration (bsc#1012628).
- arm64: dts: qcom: sc7180: limit IPA iommu streams (bsc#1012628).
- RDMA/hns: Only record vlan info for HIP08 (bsc#1012628).
- RDMA/hns: Fix missing fields in address vector (bsc#1012628).
- RDMA/hns: Avoid setting loopback indicator when smac is same
  as dmac (bsc#1012628).
- serial: 8250-mtk: Fix reference leak in mtk8250_probe
  (bsc#1012628).
- samples: bpf: Fix lwt_len_hist reusing previous BPF map
  (bsc#1012628).
- media: imx214: Fix stop streaming (bsc#1012628).
- mips: cdmm: fix use-after-free in mips_cdmm_bus_discover
  (bsc#1012628).
- media: max2175: fix max2175_set_csm_mode() error code
  (bsc#1012628).
- slimbus: qcom-ngd-ctrl: Avoid sending power requests without
  QMI (bsc#1012628).
- RDMA/core: Track device memory MRs (bsc#1012628).
- drm/mediatek: Use correct aliases name for ovl (bsc#1012628).
- HSI: omap_ssi: Don't jump to free ID in ssi_add_controller()
  (bsc#1012628).
- ARM: dts: Remove non-existent i2c1 from 98dx3236 (bsc#1012628).
- arm64: dts: armada-3720-turris-mox: update ethernet-phy handle
  name (bsc#1012628).
- power: supply: bq25890: Use the correct range for IILIM register
  (bsc#1012628).
- arm64: dts: rockchip: Set dr_mode to "host" for OTG on
  rk3328-roc-cc (bsc#1012628).
- power: supply: max17042_battery: Fix current_{avg,now} hiding
  with no current sense (bsc#1012628).
- power: supply: axp288_charger: Fix HP Pavilion x2 10 DMI
  matching (bsc#1012628).
- power: supply: bq24190_charger: fix reference leak
  (bsc#1012628).
- genirq/irqdomain: Don't try to free an interrupt that has no
  mapping (bsc#1012628).
- arm64: dts: ls1028a: fix ENETC PTP clock input (bsc#1012628).
- arm64: dts: ls1028a: fix FlexSPI clock input (bsc#1012628).
- arm64: dts: freescale: sl28: combine SPI MTD partitions
  (bsc#1012628).
- phy: tegra: xusb: Fix usb_phy device driver field (bsc#1012628).
- arm64: dts: qcom: c630: Polish i2c-hid devices (bsc#1012628).
- arm64: dts: qcom: c630: Fix pinctrl pins properties
  (bsc#1012628).
- PCI: Bounds-check command-line resource alignment requests
  (bsc#1012628).
- PCI: Fix overflow in command-line resource alignment requests
  (bsc#1012628).
- PCI: iproc: Fix out-of-bound array accesses (bsc#1012628).
- PCI: iproc: Invalidate correct PAXB inbound windows
  (bsc#1012628).
- arm64: dts: meson: fix spi-max-frequency on Khadas VIM2
  (bsc#1012628).
- arm64: dts: meson-sm1: fix typo in opp table (bsc#1012628).
- soc: amlogic: canvas: add missing put_device() call in
  meson_canvas_get() (bsc#1012628).
- scsi: hisi_sas: Fix up probe error handling for v3 hw
  (bsc#1012628).
- scsi: pm80xx: Do not sleep in atomic context (bsc#1012628).
- spi: spi-fsl-dspi: Use max_native_cs instead of num_chipselect
  to set SPI_MCR (bsc#1012628).
- ARM: dts: at91: at91sam9rl: fix ADC triggers (bsc#1012628).
- RDMA/hns: Fix 0-length sge calculation error (bsc#1012628).
- RDMA/hns: Bugfix for calculation of extended sge (bsc#1012628).
- mailbox: arm_mhu_db: Fix mhu_db_shutdown by replacing kfree
  with devm_kfree (bsc#1012628).
- soundwire: master: use pm_runtime_set_active() on add
  (bsc#1012628).
- platform/x86: dell-smbios-base: Fix error return code in
  dell_smbios_init (bsc#1012628).
- ASoC: Intel: Boards: tgl_max98373: update TDM slot_width
  (bsc#1012628).
- media: max9271: Fix GPIO enable/disable (bsc#1012628).
- media: rdacm20: Enable GPIO1 explicitly (bsc#1012628).
- media: i2c: imx219: Selection compliance fixes (bsc#1012628).
- ath11k: Don't cast ath11k_skb_cb to ieee80211_tx_info.control
  (bsc#1012628).
- ath11k: Reset ath11k_skb_cb before setting new flags
  (bsc#1012628).
- ath11k: Fix an error handling path (bsc#1012628).
- ath10k: Fix the parsing error in service available event
  (bsc#1012628).
- ath10k: Fix an error handling path (bsc#1012628).
- ath10k: Release some resources in an error handling path
  (bsc#1012628).
- SUNRPC: rpc_wake_up() should wake up tasks in the correct order
  (bsc#1012628).
- NFSv4.2: condition READDIR's mask for security label based on
  LSM state (bsc#1012628).
- SUNRPC: xprt_load_transport() needs to support the netid "rdma6"
  (bsc#1012628).
- NFSv4: Fix the alignment of page data in the getdeviceinfo reply
  (bsc#1012628).
- net: sunrpc: Fix 'snprintf' return value check in
  'do_xprt_debugfs' (bsc#1012628).
- lockd: don't use interval-based rebinding over TCP
  (bsc#1012628).
- NFS: switch nfsiod to be an UNBOUND workqueue (bsc#1012628).
- selftests/seccomp: Update kernel config (bsc#1012628).
- vfio-pci: Use io_remap_pfn_range() for PCI IO memory
  (bsc#1012628).
- hwmon: (ina3221) Fix PM usage counter unbalance in
  ina3221_write_enable (bsc#1012628).
- f2fs: fix double free of unicode map (bsc#1012628).
- media: tvp5150: Fix wrong return value of tvp5150_parse_dt()
  (bsc#1012628).
- media: saa7146: fix array overflow in vidioc_s_audio()
  (bsc#1012628).
- powerpc/perf: Fix crash with is_sier_available when pmu is
  not set (bsc#1012628).
- powerpc/64: Fix an EMIT_BUG_ENTRY in head_64.S (bsc#1012628).
- powerpc/xmon: Fix build failure for 8xx (bsc#1012628).
- powerpc/perf: Fix to update radix_scope_qual in power10
  (bsc#1012628).
- powerpc/perf: Update the PMU group constraints for l2l3 events
  in power10 (bsc#1012628).
- powerpc/perf: Fix the PMU group constraints for threshold
  events in power10 (bsc#1012628).
- clocksource/drivers/orion: Add missing clk_disable_unprepare()
  on error path (bsc#1012628).
- clocksource/drivers/cadence_ttc: Fix memory leak in
  ttc_setup_clockevent() (bsc#1012628).
- clocksource/drivers/ingenic: Fix section mismatch (bsc#1012628).
- clocksource/drivers/riscv: Make RISCV_TIMER depends on RISCV_SBI
  (bsc#1012628).
- arm64: mte: fix prctl(PR_GET_TAGGED_ADDR_CTRL) if TCF0=NONE
  (bsc#1012628).
- iio: hrtimer-trigger: Mark hrtimer to expire in hard interrupt
  context (bsc#1012628).
- libbpf: Sanitise map names before pinning (bsc#1012628).
- ARM: dts: at91: sam9x60ek: remove bypass property (bsc#1012628).
- ARM: dts: at91: sama5d2: map securam as device (bsc#1012628).
- scripts: kernel-doc: fix parsing function-like typedefs
  (bsc#1012628).
- bpf: Fix bpf_put_raw_tracepoint()'s use of __module_address()
  (bsc#1012628).
- selftests/bpf: Fix invalid use of strncat in test_sockmap
  (bsc#1012628).
- pinctrl: falcon: add missing put_device() call in
  pinctrl_falcon_probe() (bsc#1012628).
- soc: rockchip: io-domain: Fix error return code in
  rockchip_iodomain_probe() (bsc#1012628).
- arm64: dts: rockchip: Fix UART pull-ups on rk3328 (bsc#1012628).
- memstick: r592: Fix error return in r592_probe() (bsc#1012628).
- MIPS: Don't round up kernel sections size for memblock_add()
  (bsc#1012628).
- mt76: mt7663s: fix a possible ple quota underflow (bsc#1012628).
- mt76: mt7915: set fops_sta_stats.owner to THIS_MODULE
  (bsc#1012628).
- mt76: set fops_tx_stats.owner to THIS_MODULE (bsc#1012628).
- mt76: dma: fix possible deadlock running mt76_dma_cleanup
  (bsc#1012628).
- net/mlx5: Properly convey driver version to firmware
  (bsc#1012628).
- mt76: fix memory leak if device probing fails (bsc#1012628).
- mt76: fix tkip configuration for mt7615/7663 devices
  (bsc#1012628).
- ASoC: jz4740-i2s: add missed checks for clk_get() (bsc#1012628).
- ASoC: q6afe-clocks: Add missing parent clock rate (bsc#1012628).
- dm ioctl: fix error return code in target_message (bsc#1012628).
- ASoC: cros_ec_codec: fix uninitialized memory read
  (bsc#1012628).
- ASoC: atmel: mchp-spdifrx needs COMMON_CLK (bsc#1012628).
- ASoC: qcom: fix QDSP6 dependencies, attempt #3 (bsc#1012628).
- phy: mediatek: allow compile-testing the hdmi phy (bsc#1012628).
- phy: renesas: rcar-gen3-usb2: disable runtime pm in case of
  failure (bsc#1012628).
- memory: ti-emif-sram: only build for ARMv7 (bsc#1012628).
- memory: jz4780_nemc: Fix potential NULL dereference in
  jz4780_nemc_probe() (bsc#1012628).
- drm/msm: a5xx: Make preemption reset case reentrant
  (bsc#1012628).
- drm/msm: add IOMMU_SUPPORT dependency (bsc#1012628).
- clocksource/drivers/arm_arch_timer: Use stable count reader
  in erratum sne (bsc#1012628).
- clocksource/drivers/arm_arch_timer: Correct fault programming
  of CNTKCTL_EL1.EVNTI (bsc#1012628).
- cpufreq: ap806: Add missing MODULE_DEVICE_TABLE (bsc#1012628).
- cpufreq: highbank: Add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- cpufreq: mediatek: Add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- cpufreq: qcom: Add missing MODULE_DEVICE_TABLE (bsc#1012628).
- cpufreq: st: Add missing MODULE_DEVICE_TABLE (bsc#1012628).
- cpufreq: sun50i: Add missing MODULE_DEVICE_TABLE (bsc#1012628).
- cpufreq: loongson1: Add missing MODULE_ALIAS (bsc#1012628).
- cpufreq: scpi: Add missing MODULE_ALIAS (bsc#1012628).
- cpufreq: vexpress-spc: Add missing MODULE_ALIAS (bsc#1012628).
- cpufreq: imx: fix NVMEM_IMX_OCOTP dependency (bsc#1012628).
- macintosh/adb-iop: Always wait for reply message from IOP
  (bsc#1012628).
- macintosh/adb-iop: Send correct poll command (bsc#1012628).
- staging: bcm2835: fix vchiq_mmal dependencies (bsc#1012628).
- staging: greybus: audio: Fix possible leak free widgets in
  gbaudio_dapm_free_controls (bsc#1012628).
- spi: dw: Fix error return code in dw_spi_bt1_probe()
  (bsc#1012628).
- Bluetooth: btusb: Add the missed release_firmware() in
  btusb_mtk_setup_firmware() (bsc#1012628).
- Bluetooth: btmtksdio: Add the missed release_firmware() in
  mtk_setup_firmware() (bsc#1012628).
- Bluetooth: sco: Fix crash when using BT_SNDMTU/BT_RCVMTU option
  (bsc#1012628).
- block/rnbd-clt: Dynamically alloc buffer for pathname &
  blk_symlink_name (bsc#1012628).
- block/rnbd: fix a null pointer dereference on
  dev->blk_symlink_name (bsc#1012628).
- Bluetooth: btusb: Fix detection of some fake CSR controllers
  with a bcdDevice val of 0x0134 (bsc#1012628).
- platform/x86: intel-vbtn: Fix SW_TABLET_MODE always reporting
  1 on some HP x360 models (bsc#1012628).
- adm8211: fix error return code in adm8211_probe() (bsc#1012628).
- mtd: spi-nor: sst: fix BPn bits for the SST25VF064C
  (bsc#1012628).
- mtd: spi-nor: ignore errors in spi_nor_unlock_all()
  (bsc#1012628).
- mtd: spi-nor: atmel: remove global protection flag
  (bsc#1012628).
- mtd: spi-nor: atmel: fix unlock_all() for AT25FS010/040
  (bsc#1012628).
- arm64: dts: meson: g12b: odroid-n2: fix PHY deassert timing
  requirements (bsc#1012628).
- arm64: dts: meson: fix PHY deassert timing requirements
  (bsc#1012628).
- ARM: dts: meson: fix PHY deassert timing requirements
  (bsc#1012628).
- arm64: dts: meson: g12a: x96-max: fix PHY deassert timing
  requirements (bsc#1012628).
- arm64: dts: meson: g12b: w400: fix PHY deassert timing
  requirements (bsc#1012628).
- clk: fsl-sai: fix memory leak (bsc#1012628).
- scsi: qedi: Fix missing destroy_workqueue() on error in
  __qedi_probe (bsc#1012628).
- scsi: pm80xx: Fix error return in pm8001_pci_probe()
  (bsc#1012628).
- scsi: iscsi: Fix inappropriate use of put_device()
  (bsc#1012628).
- seq_buf: Avoid type mismatch for seq_buf_init (bsc#1012628).
- scsi: fnic: Fix error return code in fnic_probe() (bsc#1012628).
- platform/x86: mlx-platform: Fix item counter assignment for
  MSN2700, MSN24xx systems (bsc#1012628).
- platform/x86: mlx-platform: Fix item counter assignment for
  MSN2700/ComEx system (bsc#1012628).
- ARM: 9030/1: entry: omit FP emulation for UND exceptions taken
  in kernel mode (bsc#1012628).
- powerpc/pseries/hibernation: drop pseries_suspend_begin()
  from suspend ops (bsc#1012628).
- powerpc/pseries/hibernation: remove redundant cacheinfo update
  (bsc#1012628).
- powerpc/powermac: Fix low_sleep_handler with CONFIG_VMAP_STACK
  (bsc#1012628).
- drm/mediatek: avoid dereferencing a null hdmi_phy on an error
  message (bsc#1012628).
- ASoC: amd: change clk_get() to devm_clk_get() and add missed
  checks (bsc#1012628).
- coresight: remove broken __exit annotations (bsc#1012628).
- ASoC: max98390: Fix error codes in max98390_dsm_init()
  (bsc#1012628).
- powerpc/mm: sanity_check_fault() should work for all, not only
  BOOK3S (bsc#1012628).
- usb: ehci-omap: Fix PM disable depth umbalance in
  ehci_hcd_omap_probe (bsc#1012628).
- usb: oxu210hp-hcd: Fix memory leak in oxu_create (bsc#1012628).
- speakup: fix uninitialized flush_lock (bsc#1012628).
- nfsd: Fix message level for normal termination (bsc#1012628).
- NFSD: Fix 5 seconds delay when doing inter server copy
  (bsc#1012628).
- nfs_common: need lock during iterate through the list
  (bsc#1012628).
- x86/kprobes: Restore BTF if the single-stepping is cancelled
  (bsc#1012628).
- scsi: qla2xxx: Fix FW initialization error on big endian
  machines (bsc#1012628).
- scsi: qla2xxx: Fix N2N and NVMe connect retry failure
  (bsc#1012628).
- platform/chrome: cros_ec_spi: Don't overwrite spi::mode
  (bsc#1012628).
- misc: pci_endpoint_test: fix return value of error branch
  (bsc#1012628).
- bus: fsl-mc: add back accidentally dropped error check
  (bsc#1012628).
- bus: fsl-mc: fix error return code in fsl_mc_object_allocate()
  (bsc#1012628).
- fsi: Aspeed: Add mutex to protect HW access (bsc#1012628).
- s390/cio: fix use-after-free in ccw_device_destroy_console
  (bsc#1012628).
- iwlwifi: dbg-tlv: fix old length in is_trig_data_contained()
  (bsc#1012628).
- iwlwifi: mvm: hook up missing RX handlers (bsc#1012628).
- erofs: avoid using generic_block_bmap (bsc#1012628).
- clk: renesas: r8a779a0: Fix R and OSC clocks (bsc#1012628).
- can: m_can: m_can_config_endisable(): remove double clearing
  of clock stop request bit (bsc#1012628).
- powerpc/sstep: Emulate prefixed instructions only when
  CPU_FTR_ARCH_31 is set (bsc#1012628).
- powerpc/sstep: Cover new VSX instructions under CONFIG_VSX
  (bsc#1012628).
- slimbus: qcom: fix potential NULL dereference in
  qcom_slim_prg_slew() (bsc#1012628).
- ALSA: hda/hdmi: fix silent stream for first playback to DP
  (bsc#1012628).
- RDMA/core: Do not indicate device ready when device enablement
  fails (bsc#1012628).
- RDMA/uverbs: Fix incorrect variable type (bsc#1012628).
- remoteproc/mediatek: change MT8192 CFG register base
  (bsc#1012628).
- remoteproc/mtk_scp: surround DT device IDs with CONFIG_OF
  (bsc#1012628).
- remoteproc: q6v5-mss: fix error handling in q6v5_pds_enable
  (bsc#1012628).
- remoteproc: qcom: fix reference leak in adsp_start
  (bsc#1012628).
- remoteproc: qcom: pas: fix error handling in adsp_pds_enable
  (bsc#1012628).
- remoteproc: k3-dsp: Fix return value check in
  k3_dsp_rproc_of_get_memories() (bsc#1012628).
- remoteproc: qcom: Fix potential NULL dereference in
  adsp_init_mmio() (bsc#1012628).
- remoteproc/mediatek: unprepare clk if scp_before_load fails
  (bsc#1012628).
- clk: qcom: gcc-sc7180: Use floor ops for sdcc clks
  (bsc#1012628).
- clk: tegra: Fix duplicated SE clock entry (bsc#1012628).
- mtd: rawnand: gpmi: fix reference count leak in gpmi ops
  (bsc#1012628).
- mtd: rawnand: meson: Fix a resource leak in init (bsc#1012628).
- mtd: rawnand: gpmi: Fix the random DMA timeout issue
  (bsc#1012628).
- samples/bpf: Fix possible hang in xdpsock with multiple threads
  (bsc#1012628).
- fs: Handle I_DONTCACHE in iput_final() instead of
  generic_drop_inode() (bsc#1012628).
- extcon: max77693: Fix modalias string (bsc#1012628).
- crypto: atmel-i2c - select CONFIG_BITREVERSE (bsc#1012628).
- mac80211: don't set set TDLS STA bandwidth wider than possible
  (bsc#1012628).
- mac80211: fix a mistake check for rx_stats update (bsc#1012628).
- ASoC: wm_adsp: remove "ctl" from list on error in
  wm_adsp_create_control() (bsc#1012628).
- irqchip/alpine-msi: Fix freeing of interrupts on allocation
  error path (bsc#1012628).
- irqchip/ti-sci-inta: Fix printing of inta id on probe success
  (bsc#1012628).
- irqchip/ti-sci-intr: Fix freeing of irqs (bsc#1012628).
- dmaengine: ti: k3-udma: Correct normal channel offset when
  uchan_cnt is not 0 (bsc#1012628).
- RDMA/hns: Limit the length of data copied between kernel and
  userspace (bsc#1012628).
- RDMA/hns: Normalization the judgment of some features
  (bsc#1012628).
- RDMA/hns: Do shift on traffic class when using RoCEv2
  (bsc#1012628).
- gpiolib: irq hooks: fix recursion in gpiochip_irq_unmask
  (bsc#1012628).
- ath11k: Fix incorrect tlvs in scan start command (bsc#1012628).
- irqchip/qcom-pdc: Fix phantom irq when changing between
  rising/falling (bsc#1012628).
- watchdog: armada_37xx: Add missing dependency on HAS_IOMEM
  (bsc#1012628).
- watchdog: sirfsoc: Add missing dependency on HAS_IOMEM
  (bsc#1012628).
- watchdog: sprd: remove watchdog disable from resume fail path
  (bsc#1012628).
- watchdog: sprd: check busy bit before new loading rather than
  after that (bsc#1012628).
- watchdog: Fix potential dereferencing of null pointer
  (bsc#1012628).
- ubifs: Fix error return code in ubifs_init_authentication()
  (bsc#1012628).
- um: Monitor error events in IRQ controller (bsc#1012628).
- um: tty: Fix handling of close in tty lines (bsc#1012628).
- um: chan_xterm: Fix fd leak (bsc#1012628).
- sunrpc: fix xs_read_xdr_buf for partial pages receive
  (bsc#1012628).
- RDMA/mlx5: Fix MR cache memory leak (bsc#1012628).
- RDMA/cma: Don't overwrite sgid_attr after device is released
  (bsc#1012628).
- nfc: s3fwrn5: Release the nfc firmware (bsc#1012628).
- drm: mxsfb: Silence -EPROBE_DEFER while waiting for bridge
  (bsc#1012628).
- powerpc/perf: Fix Threshold Event Counter Multiplier width
  for P10 (bsc#1012628).
- powerpc/ps3: use dma_mapping_error() (bsc#1012628).
- perf test: Fix metric parsing test (bsc#1012628).
- drm/amdgpu: fix regression in vbios reservation handling on
  headless (bsc#1012628).
- mm/gup: reorganize internal_get_user_pages_fast() (bsc#1012628).
- mm/gup: prevent gup_fast from racing with COW during fork
  (bsc#1012628).
- mm/gup: combine put_compound_head() and unpin_user_page()
  (bsc#1012628).
- mm: memcg/slab: fix return of child memcg objcg for root memcg
  (bsc#1012628).
- mm: memcg/slab: fix use after free in obj_cgroup_charge
  (bsc#1012628).
- mm/rmap: always do TTU_IGNORE_ACCESS (bsc#1012628).
- sparc: fix handling of page table constructor failure
  (bsc#1012628).
- mm/vmalloc: Fix unlock order in s_stop() (bsc#1012628).
- mm/vmalloc.c: fix kasan shadow poisoning size (bsc#1012628).
- mm,memory_failure: always pin the page in madvise_inject_error
  (bsc#1012628).
- hugetlb: fix an error code in hugetlb_reserve_pages()
  (bsc#1012628).
- mm: don't wake kswapd prematurely when watermark boosting is
  disabled (bsc#1012628).
- proc: fix lookup in /proc/net subdirectories after setns(2)
  (bsc#1012628).
- checkpatch: fix unescaped left brace (bsc#1012628).
- s390/test_unwind: fix CALL_ON_STACK tests (bsc#1012628).
- lan743x: fix rx_napi_poll/interrupt ping-pong (bsc#1012628).
- ice, xsk: clear the status bits for the next_to_use descriptor
  (bsc#1012628).
- i40e, xsk: clear the status bits for the next_to_use descriptor
  (bsc#1012628).
- net: dsa: qca: ar9331: fix sleeping function called from
  invalid context bug (bsc#1012628).
- dpaa2-eth: fix the size of the mapped SGT buffer (bsc#1012628).
- net: bcmgenet: Fix a resource leak in an error handling path
  in the probe functin (bsc#1012628).
- net: mscc: ocelot: Fix a resource leak in the error handling
  path of the probe function (bsc#1012628).
- net: allwinner: Fix some resources leak in the error handling
  path of the probe and in the remove function (bsc#1012628).
- block/rnbd-clt: Get rid of warning regarding size argument in
  strlcpy (bsc#1012628).
- block/rnbd-clt: Fix possible memleak (bsc#1012628).
- NFS/pNFS: Fix a typo in ff_layout_resend_pnfs_read()
  (bsc#1012628).
- net: korina: fix return value (bsc#1012628).
- devlink: use _BITUL() macro instead of BIT() in the UAPI header
  (bsc#1012628).
- libnvdimm/label: Return -ENXIO for no slot in __blk_label_update
  (bsc#1012628).
- powerpc/32s: Fix cleanup_cpu_mmu_context() compile bug
  (bsc#1012628).
- watchdog: qcom: Avoid context switch in restart handler
  (bsc#1012628).
- watchdog: coh901327: add COMMON_CLK dependency (bsc#1012628).
- clk: ti: Fix memleak in ti_fapll_synth_setup (bsc#1012628).
- pwm: zx: Add missing cleanup in error path (bsc#1012628).
- pwm: lp3943: Dynamically allocate PWM chip base (bsc#1012628).
- pwm: imx27: Fix overflow for bigger periods (bsc#1012628).
- pwm: sun4i: Remove erroneous else branch (bsc#1012628).
- io_uring: cancel only requests of current task (bsc#1012628).
- tools build: Add missing libcap to test-all.bin target
  (bsc#1012628).
- =?UTF-8?q?perf=20record:=20Fix=20memory=20leak=20when=20u?=
  =?UTF-8?q?sing=20'--user-regs=3D=3F'=20to=20list=20registers?=
  (bsc#1012628).
- qlcnic: Fix error code in probe (bsc#1012628).
- nfp: move indirect block cleanup to flower app stop callback
  (bsc#1012628).
- vdpa/mlx5: Use write memory barrier after updating CQ index
  (bsc#1012628).
- virtio_ring: Cut and paste bugs in
  vring_create_virtqueue_packed() (bsc#1012628).
- virtio_net: Fix error code in probe() (bsc#1012628).
- virtio_ring: Fix two use after free bugs (bsc#1012628).
- vhost scsi: fix error return code in vhost_scsi_set_endpoint()
  (bsc#1012628).
- epoll: check for events when removing a timed out thread from
  the wait queue (bsc#1012628).
- clk: at91: sama7g5: fix compilation error (bsc#1012628).
- clk: at91: sam9x60: remove atmel,osc-bypass support
  (bsc#1012628).
- clk: s2mps11: Fix a resource leak in error handling paths in
  the probe function (bsc#1012628).
- clk: sunxi-ng: Make sure divider tables have sentinel
  (bsc#1012628).
- clk: vc5: Use "idt,voltage-microvolt" instead of
  "idt,voltage-microvolts" (bsc#1012628).
- kconfig: fix return value of do_error_if() (bsc#1012628).
- powerpc/boot: Fix build of dts/fsl (bsc#1012628).
- powerpc/smp: Add __init to init_big_cores() (bsc#1012628).
- ARM: 9044/1: vfp: use undef hook for VFP support detection
  (bsc#1012628).
- ARM: 9036/1: uncompress: Fix dbgadtb size parameter name
  (bsc#1012628).
- perf probe: Fix memory leak when synthesizing SDT probes
  (bsc#1012628).
- io_uring: fix racy IOPOLL flush overflow (bsc#1012628).
- io_uring: cancel reqs shouldn't kill overflow list
  (bsc#1012628).
- Smack: Handle io_uring kernel thread privileges (bsc#1012628).
- proc mountinfo: make splice available again (bsc#1012628).
- io_uring: fix io_cqring_events()'s noflush (bsc#1012628).
- io_uring: fix racy IOPOLL completions (bsc#1012628).
- io_uring: always let io_iopoll_complete() complete polled io
  (bsc#1012628).
- vfio/pci: Move dummy_resources_list init in vfio_pci_probe()
  (bsc#1012628).
- vfio/pci/nvlink2: Do not attempt NPU2 setup on POWER8NVL NPU
  (bsc#1012628).
- media: gspca: Fix memory leak in probe (bsc#1012628).
- io_uring: fix io_wqe->work_list corruption (bsc#1012628).
- io_uring: fix 0-iov read buffer select (bsc#1012628).
- io_uring: hold uring_lock while completing failed polled io
  in io_wq_submit_work() (bsc#1012628).
- io_uring: fix ignoring xa_store errors (bsc#1012628).
- io_uring: fix double io_uring free (bsc#1012628).
- io_uring: make ctx cancel on exit targeted to actual ctx
  (bsc#1012628).
- media: sunxi-cir: ensure IR is handled when it is continuous
  (bsc#1012628).
- media: netup_unidvb: Don't leak SPI master in probe error path
  (bsc#1012628).
- media: ipu3-cio2: Remove traces of returned buffers
  (bsc#1012628).
- media: ipu3-cio2: Return actual subdev format (bsc#1012628).
- media: ipu3-cio2: Serialise access to pad format (bsc#1012628).
- media: ipu3-cio2: Validate mbus format in setting subdev format
  (bsc#1012628).
- media: ipu3-cio2: Make the field on subdev format
  V4L2_FIELD_NONE (bsc#1012628).
- Input: cyapa_gen6 - fix out-of-bounds stack access
  (bsc#1012628).
- ALSA: hda/ca0132 - Change Input Source enum strings
  (bsc#1012628).
- ACPI: NFIT: Fix input validation of bus-family (bsc#1012628).
- PM: ACPI: PCI: Drop acpi_pm_set_bridge_wakeup() (bsc#1012628).
- Revert "ACPI / resources: Use AE_CTRL_TERMINATE to terminate
  resources walks" (bsc#1012628).
- ACPI: PNP: compare the string length in the matching_id()
  (bsc#1012628).
- ALSA: hda: Fix regressions on clear and reconfig sysfs
  (bsc#1012628).
- ALSA: hda/ca0132 - Fix AE-5 rear headphone pincfg (bsc#1012628).
- ALSA: hda/realtek: make bass spk volume adjustable on a yoga
  laptop (bsc#1012628).
- ALSA: hda/realtek - Enable headset mic of ASUS X430UN with
  ALC256 (bsc#1012628).
- ALSA: hda/realtek - Enable headset mic of ASUS Q524UQK with
  ALC255 (bsc#1012628).
- ALSA: hda/realtek - Add supported for more Lenovo ALC285
  Headset Button (bsc#1012628).
- ALSA: pcm: oss: Fix a few more UBSAN fixes (bsc#1012628).
- ALSA/hda: apply jack fixup for the Acer Veriton
  N4640G/N6640G/N2510G (bsc#1012628).
- ALSA: hda/realtek: Add quirk for MSI-GP73 (bsc#1012628).
- ALSA: hda/realtek: Apply jack fixup for Quanta NL3
  (bsc#1012628).
- ALSA: hda/realtek: Remove dummy lineout on Acer TravelMate
  P648/P658 (bsc#1012628).
- ALSA: hda/realtek - Supported Dell fixed type headset
  (bsc#1012628).
- ALSA: usb-audio: Add VID to support native DSD reproduction
  on FiiO devices (bsc#1012628).
- ALSA: usb-audio: Disable sample read check if firmware doesn't
  give back (bsc#1012628).
- ALSA: usb-audio: Add alias entry for ASUS PRIME TRX40 PRO-S
  (bsc#1012628).
- ALSA: core: memalloc: add page alignment for iram (bsc#1012628).
- s390/smp: perform initial CPU reset also for SMT siblings
  (bsc#1012628).
- s390/kexec_file: fix diag308 subcode when loading crash kernel
  (bsc#1012628).
- s390/idle: add missing mt_cycles calculation (bsc#1012628).
- s390/idle: fix accounting with machine checks (bsc#1012628).
- s390/dasd: fix hanging device offline processing (bsc#1012628).
- s390/dasd: prevent inconsistent LCU device data (bsc#1012628).
- s390/dasd: fix list corruption of pavgroup group list
  (bsc#1012628).
- s390/dasd: fix list corruption of lcu list (bsc#1012628).
- binder: add flag to clear buffer on txn complete (bsc#1012628).
- ASoC: cx2072x: Fix doubly definitions of Playback and Capture
  streams (bsc#1012628).
- ASoC: AMD Renoir - add DMI table to avoid the ACP mic probe
  (broken BIOS) (bsc#1012628).
- ASoC: AMD Raven/Renoir - fix the PCI probe (PCI revision)
  (bsc#1012628).
- staging: comedi: mf6x4: Fix AI end-of-conversion detection
  (bsc#1012628).
- z3fold: simplify freeing slots (bsc#1012628).
- z3fold: stricter locking and more careful reclaim (bsc#1012628).
- perf/x86/intel: Add event constraint for
  CYCLE_ACTIVITY.STALLS_MEM_ANY (bsc#1012628).
- perf/x86/intel: Fix rtm_abort_event encoding on Ice Lake
  (bsc#1012628).
- perf/x86/intel/lbr: Fix the return type of get_lbr_cycles()
  (bsc#1012628).
- powerpc/perf: Exclude kernel samples while counting events in
  user space (bsc#1012628).
- cpufreq: intel_pstate: Use most recent guaranteed performance
  values (bsc#1012628).
- crypto: ecdh - avoid unaligned accesses in ecdh_set_secret()
  (bsc#1012628).
- crypto: arm/aes-ce - work around Cortex-A57/A72 silion errata
  (bsc#1012628).
- m68k: Fix WARNING splat in pmac_zilog driver (bsc#1012628).
- Documentation: seqlock: s/LOCKTYPE/LOCKNAME/g (bsc#1012628).
- EDAC/i10nm: Use readl() to access MMIO registers (bsc#1012628).
- EDAC/amd64: Fix PCI component registration (bsc#1012628).
- cpuset: fix race between hotplug work and later CPU offline
  (bsc#1012628).
- dyndbg: fix use before null check (bsc#1012628).
- USB: serial: mos7720: fix parallel-port state restore
  (bsc#1012628).
- USB: serial: digi_acceleport: fix write-wakeup deadlocks
  (bsc#1012628).
- USB: serial: keyspan_pda: fix dropped unthrottle interrupts
  (bsc#1012628).
- USB: serial: keyspan_pda: fix write deadlock (bsc#1012628).
- USB: serial: keyspan_pda: fix stalled writes (bsc#1012628).
- USB: serial: keyspan_pda: fix write-wakeup use-after-free
  (bsc#1012628).
- USB: serial: keyspan_pda: fix tx-unthrottle use-after-free
  (bsc#1012628).
- USB: serial: keyspan_pda: fix write unthrottling (bsc#1012628).
- btrfs: do not shorten unpin len for caching block groups
  (bsc#1012628).
- btrfs: update last_byte_to_unpin in switch_commit_roots
  (bsc#1012628).
- btrfs: fix race when defragmenting leads to unnecessary IO
  (bsc#1012628).
- ext4: fix an IS_ERR() vs NULL check (bsc#1012628).
- ext4: fix a memory leak of ext4_free_data (bsc#1012628).
- ext4: fix deadlock with fs freezing and EA inodes (bsc#1012628).
- ext4: don't remount read-only with errors=continue on reboot
  (bsc#1012628).
- RISC-V: Fix usage of memblock_enforce_memory_limit
  (bsc#1012628).
- arm64: dts: ti: k3-am65: mark dss as dma-coherent (bsc#1012628).
- arm64: dts: marvell: keep SMMU disabled by default for Armada
  7040 and 8040 (bsc#1012628).
- KVM: arm64: Introduce handling of AArch32 TTBCR2 traps
  (bsc#1012628).
- KVM: x86: reinstate vendor-agnostic check on SPEC_CTRL cpuid
  bits (bsc#1012628).
- KVM: SVM: Remove the call to sev_platform_status() during setup
  (bsc#1012628).
- iommu/arm-smmu: Allow implementation specific write_s2cr
  (bsc#1012628).
- iommu/arm-smmu-qcom: Read back stream mappings (bsc#1012628).
- iommu/arm-smmu-qcom: Implement S2CR quirk (bsc#1012628).
- ARM: dts: pandaboard: fix pinmux for gpio user button of
  Pandaboard ES (bsc#1012628).
- ARM: dts: at91: sama5d2: fix CAN message ram offset and size
  (bsc#1012628).
- ARM: tegra: Populate OPP table for Tegra20 Ventana
  (bsc#1012628).
- xprtrdma: Fix XDRBUF_SPARSE_PAGES support (bsc#1012628).
- powerpc/32: Fix vmap stack - Properly set r1 before activating
  MMU on syscall too (bsc#1012628).
- powerpc: Fix incorrect stw{, ux, u, x} instructions in
  __set_pte_at (bsc#1012628).
- powerpc/rtas: Fix typo of ibm,open-errinjct in RTAS filter
  (bsc#1012628).
- powerpc/bitops: Fix possible undefined behaviour with fls()
  and fls64() (bsc#1012628).
- powerpc/feature: Add CPU_FTR_NOEXECUTE to G2_LE (bsc#1012628).
- powerpc/xmon: Change printk() to pr_cont() (bsc#1012628).
- powerpc/8xx: Fix early debug when SMC1 is relocated
  (bsc#1012628).
- powerpc/mm: Fix verification of MMU_FTR_TYPE_44x (bsc#1012628).
- powerpc/powernv/npu: Do not attempt NPU2 setup on POWER8NVL NPU
  (bsc#1012628).
- powerpc/powernv/memtrace: Don't leak kernel memory to user space
  (bsc#1012628).
- powerpc/powernv/memtrace: Fix crashing the kernel when enabling
  concurrently (bsc#1012628).
- ovl: make ioctl() safe (bsc#1012628).
- ima: Don't modify file descriptor mode on the fly (bsc#1012628).
- um: Remove use of asprinf in umid.c (bsc#1012628).
- um: Fix time-travel mode (bsc#1012628).
- ceph: fix race in concurrent __ceph_remove_cap invocations
  (bsc#1012628).
- SMB3: avoid confusing warning message on mount to Azure
  (bsc#1012628).
- SMB3.1.1: remove confusing mount warning when no SPNEGO info
  on negprot rsp (bsc#1012628).
- SMB3.1.1: do not log warning message if server doesn't populate
  salt (bsc#1012628).
- ubifs: wbuf: Don't leak kernel memory to flash (bsc#1012628).
- jffs2: Fix GC exit abnormally (bsc#1012628).
- jffs2: Fix ignoring mounting options problem during remounting
  (bsc#1012628).
- fsnotify: generalize handle_inode_event() (bsc#1012628).
- inotify: convert to handle_inode_event() interface
  (bsc#1012628).
- fsnotify: fix events reported to watching parent and child
  (bsc#1012628).
- jfs: Fix array index bounds check in dbAdjTree (bsc#1012628).
- drm/panfrost: Fix job timeout handling (bsc#1012628).
- drm/panfrost: Move the GPU reset bits outside the timeout
  handler (bsc#1012628).
- platform/x86: mlx-platform: remove an unused variable
  (bsc#1012628).
- drm/amd/display: Fix memory leaks in S3 resume (bsc#1012628).
- drm/dp_aux_dev: check aux_dev before use in
  drm_dp_aux_dev_get_by_minor() (bsc#1012628).
- drm/i915: Fix mismatch between misplaced vma check and vma
  insert (bsc#1012628).
- iio: ad_sigma_delta: Don't put SPI transfer buffer on the stack
  (bsc#1012628).
- spi: pxa2xx: Fix use-after-free on unbind (bsc#1012628).
- spi: spi-sh: Fix use-after-free on unbind (bsc#1012628).
- spi: atmel-quadspi: Fix use-after-free on unbind (bsc#1012628).
- spi: spi-mtk-nor: Don't leak SPI master in probe error path
  (bsc#1012628).
- spi: ar934x: Don't leak SPI master in probe error path
  (bsc#1012628).
- spi: davinci: Fix use-after-free on unbind (bsc#1012628).
- spi: fsl: fix use of spisel_boot signal on MPC8309
  (bsc#1012628).
- spi: gpio: Don't leak SPI master in probe error path
  (bsc#1012628).
- spi: mxic: Don't leak SPI master in probe error path
  (bsc#1012628).
- spi: npcm-fiu: Disable clock in probe error path (bsc#1012628).
- spi: pic32: Don't leak DMA channels in probe error path
  (bsc#1012628).
- spi: rb4xx: Don't leak SPI master in probe error path
  (bsc#1012628).
- spi: rpc-if: Fix use-after-free on unbind (bsc#1012628).
- spi: sc18is602: Don't leak SPI master in probe error path
  (bsc#1012628).
- spi: spi-geni-qcom: Fix use-after-free on unbind (bsc#1012628).
- spi: spi-qcom-qspi: Fix use-after-free on unbind (bsc#1012628).
- spi: st-ssc4: Fix unbalanced pm_runtime_disable() in probe
  error path (bsc#1012628).
- spi: synquacer: Disable clock in probe error path (bsc#1012628).
- spi: mt7621: Disable clock in probe error path (bsc#1012628).
- spi: mt7621: Don't leak SPI master in probe error path
  (bsc#1012628).
- spi: atmel-quadspi: Disable clock in probe error path
  (bsc#1012628).
- spi: atmel-quadspi: Fix AHB memory accesses (bsc#1012628).
- soc: qcom: smp2p: Safely acquire spinlock without IRQs
  (bsc#1012628).
- mtd: spinand: Fix OOB read (bsc#1012628).
- mtd: parser: cmdline: Fix parsing of part-names with colons
  (bsc#1012628).
- mtd: core: Fix refcounting for unpartitioned MTDs (bsc#1012628).
- mtd: rawnand: qcom: Fix DMA sync on FLASH_STATUS register read
  (bsc#1012628).
- mtd: rawnand: meson: fix meson_nfc_dma_buffer_release()
  arguments (bsc#1012628).
- scsi: qla2xxx: Fix crash during driver load on big endian
  machines (bsc#1012628).
- scsi: lpfc: Fix invalid sleeping context in
  lpfc_sli4_nvmet_alloc() (bsc#1012628).
- scsi: lpfc: Fix scheduling call while in softirq context in
  lpfc_unreg_rpi (bsc#1012628).
- scsi: lpfc: Re-fix use after free in lpfc_rq_buf_free()
  (bsc#1012628).
- openat2: reject RESOLVE_BENEATH|RESOLVE_IN_ROOT (bsc#1012628).
- iio: buffer: Fix demux update (bsc#1012628).
- iio: adc: rockchip_saradc: fix missing clk_disable_unprepare()
  on error in rockchip_saradc_resume (bsc#1012628).
- iio: imu: st_lsm6dsx: fix edge-trigger interrupts (bsc#1012628).
- iio:light:rpr0521: Fix timestamp alignment and prevent data leak
  (bsc#1012628).
- iio:light:st_uvis25: Fix timestamp alignment and prevent data
  leak (bsc#1012628).
- iio:magnetometer:mag3110: Fix alignment and data leak issues
  (bsc#1012628).
- iio:pressure:mpl3115: Force alignment of buffer (bsc#1012628).
- iio:imu:bmi160: Fix too large a buffer (bsc#1012628).
- iio:imu:bmi160: Fix alignment and data leak issues
  (bsc#1012628).
- iio:adc:ti-ads124s08: Fix buffer being too long (bsc#1012628).
- iio:adc:ti-ads124s08: Fix alignment and data leak issues
  (bsc#1012628).
- md/cluster: block reshape with remote resync job (bsc#1012628).
- md/cluster: fix deadlock when node is doing resync job
  (bsc#1012628).
- pinctrl: sunxi: Always call chained_irq_{enter, exit} in
  sunxi_pinctrl_irq_handler (bsc#1012628).
- clk: ingenic: Fix divider calculation with div tables
  (bsc#1012628).
- clk: mvebu: a3700: fix the XTAL MODE pin to MPP1_9
  (bsc#1012628).
- clk: tegra: Do not return 0 on failure (bsc#1012628).
- counter: microchip-tcb-capture: Fix CMR value check
  (bsc#1012628).
- device-dax/core: Fix memory leak when rmmod dax.ko
  (bsc#1012628).
- dma-buf/dma-resv: Respect num_fences when initializing the
  shared fence list (bsc#1012628).
- driver: core: Fix list corruption after device_del()
  (bsc#1012628).
- xen-blkback: set ring->xenblkd to NULL after kthread_stop()
  (bsc#1012628).
- xen/xenbus: Allow watches discard events before queueing
  (bsc#1012628).
- xen/xenbus: Add 'will_handle' callback support in
  xenbus_watch_path() (bsc#1012628).
- xen/xenbus/xen_bus_type: Support will_handle watch callback
  (bsc#1012628).
- xen/xenbus: Count pending messages for each watch (bsc#1012628).
- xenbus/xenbus_backend: Disallow pending watch messages
  (bsc#1012628).
- memory: jz4780_nemc: Fix an error pointer vs NULL check in
  probe() (bsc#1012628).
- memory: renesas-rpc-if: Fix a node reference leak in
  rpcif_probe() (bsc#1012628).
- memory: renesas-rpc-if: Return correct value to the caller of
  rpcif_manual_xfer() (bsc#1012628).
- memory: renesas-rpc-if: Fix unbalanced pm_runtime_enable in
  rpcif_{enable,disable}_rpm (bsc#1012628).
- libnvdimm/namespace: Fix reaping of invalidated
  block-window-namespace labels (bsc#1012628).
- platform/x86: intel-vbtn: Allow switch events on Acer Switch
  Alpha 12 (bsc#1012628).
- tracing: Disable ftrace selftests when any tracer is running
  (bsc#1012628).
- mt76: add back the SUPPORTS_REORDERING_BUFFER flag
  (bsc#1012628).
- of: fix linker-section match-table corruption (bsc#1012628).
- PCI: Fix pci_slot_release() NULL pointer dereference
  (bsc#1012628).
- regulator: axp20x: Fix DLDO2 voltage control register mask
  for AXP22x (bsc#1012628).
- remoteproc: sysmon: Ensure remote notification ordering
  (bsc#1012628).
- thermal/drivers/cpufreq_cooling: Update cpufreq_state only if
  state has changed (bsc#1012628).
- rtc: ep93xx: Fix NULL pointer dereference in
  ep93xx_rtc_read_time (bsc#1012628).
- Revert: "ring-buffer: Remove HAVE_64BIT_ALIGNED_ACCESS"
  (bsc#1012628).
- null_blk: Fix zone size initialization (bsc#1012628).
- null_blk: Fail zone append to conventional zones (bsc#1012628).
- drm/edid: fix objtool warning in drm_cvt_modes() (bsc#1012628).
- x86/CPU/AMD: Save AMD NodeId as cpu_die_id (bsc#1012628).
- Update config files.
- commit 84f94bc
* Mon Dec 28 2020 mkubecek@suse.cz
- Update to 5.11-rc1
- eliminated 63 patches (61 stable, 2 other)
  - patches.kernel.org/*
  - patches.suse/clk-bcm-dvp-add-module_device_table.patch
  - patches.suse/drm-amdgpu-only-set-DP-subconnector-type-on-DP-and-e.patch
- disable ARM architectures (need config update)
- refresh
  - patches.suse/btrfs-fs-super.c-add-new-super-block-devices-super_block_d.patch
  - patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch
    (renamed to patches.suse/btrfs-use-the-new-VFS-super_block_dev.patch
    to ease frequent refreshes)
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  - patches.suse/supported-flag
- new config options:
  - Processor type and features
  - CONFIG_XEN_PVHVM_GUEST=y
  - CONFIG_X86_SGX=n
  - General architecture-dependent options
  - CONFIG_SECCOMP_CACHE_DEBUG=n
  - Memory Management options
  - CONFIG_GUP_TEST=n
  - Networking support
  - CONFIG_NFT_REJECT_NETDEV=n
  - CONFIG_BRIDGE_CFM=n
  - CONFIG_NET_DSA_TAG_HELLCREEK=n
  - CONFIG_CAN_M_CAN_PCI=n
  - CONFIG_NFC_S3FWRN82_UART=n
  - File systems
  - CONFIG_PSTORE_DEFAULT_KMSG_BYTES=10240
  - CONFIG_CIFS_SWN_UPCALL=n
  - Cryptographic API
  - CONFIG_CRYPTO_DEV_QAT_4XXX=n
  - Library routines
  - CONFIG_DMA_MAP_BENCHMARK=n
  - Kernel hacking
  - CONFIG_DEBUG_KMAP_LOCAL_FORCE_MAP=n
  - CONFIG_FTRACE_RECORD_RECURSION=n
  - CONFIG_RING_BUFFER_VALIDATE_TIME_DELTAS=n
  - Memory Technology Device (MTD) support
  - CONFIG_MTD_NAND_ECC_SW_HAMMING=y
  - CONFIG_MTD_SPI_NOR_SWP_DISABLE=n
  - CONFIG_MTD_SPI_NOR_SWP_DISABLE_ON_VOLATILE=y
  - CONFIG_MTD_SPI_NOR_SWP_KEEP=n
  - Block devices
  - CONFIG_DM_MULTIPATH_IOA=n
  - CONFIG_ZRAM_DEF_COMP_LZORLE=y
  - Network device support
  - CONFIG_MHI_NET=n
  - CONFIG_NET_DSA_HIRSCHMANN_HELLCREEK=n
  - CONFIG_USB_RTL8153_ECM=m
  - Input device support
  - CONFIG_INPUT_DA7280_HAPTICS=n
  - CONFIG_AMD_SFH_HID=n
  - Pin controllers
  - CONFIG_PINCTRL_ALDERLAKE=n
  - CONFIG_PINCTRL_ELKHARTLAKE=n
  - CONFIG_PINCTRL_LAKEFIELD=n
  - Hardware Monitoring support
  - CONFIG_SENSORS_CORSAIR_PSU=n
  - CONFIG_SENSORS_LTC2992=n
  - CONFIG_SENSORS_MAX127=n
  - CONFIG_SENSORS_PM6764TR=n
  - CONFIG_SENSORS_Q54SJ108A2=n
  - CONFIG_SENSORS_SBTSI=n
  - Multimedia support
  - CONFIG_VIDEO_OV02A10=n
  - CONFIG_VIDEO_OV9734=n
  - CONFIG_VIDEO_CCS=n
  - Sound card support
  - CONFIG_SND_SOC_ADI=n
  - CONFIG_SND_SOC_FSL_XCVR=n
  - CONFIG_SND_SOC_SOF_BAYTRAIL_SUPPORT=n
  - CONFIG_SND_SOC_SOF_ALDERLAKE_SUPPORT=n
  - CONFIG_SND_SOC_ADAU1372_I2C=n
  - CONFIG_SND_SOC_ADAU1372_SPI=n
  - CONFIG_SND_SOC_PCM5102A=n
  - CONFIG_SND_SOC_SIMPLE_MUX=n
  - CONFIG_SND_SOC_NAU8315=n
  - CONFIG_SND_SOC_LPASS_WSA_MACRO=n
  - CONFIG_SND_SOC_LPASS_VA_MACRO=n
  - CONFIG_SND_SOC_ADI_AXI_I2S=m
  - CONFIG_SND_SOC_ADI_AXI_SPDIF=m
  - X86 Platform Specific Device Drivers
  - CONFIG_UV_SYSFS=n
  - CONFIG_AMD_PMC=n
  - CONFIG_DELL_WMI_SYSMAN=n
  - CONFIG_INTEL_PMT_CLASS=n
  - CONFIG_INTEL_PMT_TELEMETRY=n
  - CONFIG_INTEL_PMT_CRASHLOG=n
  - Misc drivers
  - CONFIG_MHI_BUS_PCI_GENERIC=n
  - CONFIG_SERIAL_BCM63XX=n
  - CONFIG_MIPI_I3C_HCI=n
  - CONFIG_PTP_1588_CLOCK_OCP=n
  - CONFIG_MFD_INTEL_PMT=n
  - CONFIG_EDAC_IGEN6=n
  - CONFIG_INTEL_IDXD_SVM=n
  - CONFIG_LCD2S=n
  - CONFIG_VDPA_SIM_NET=n
  - CONFIG_EXTCON_USBC_TUSB320=n
  - CONFIG_PWM_DWC=n
  - CONFIG_USB4_DMA_TEST=n
  - CONFIG_SURFACE_PLATFORMS=y
  - CONFIG_SURFACE_GPE=n
  - OF dependent drivers (i386, ppc64/ppc64le, riscv64)
  - MTD_NAND_INTEL_LGM=m
  - PINCTRL_MICROCHIP_SGPIO=n
  - REGULATOR_DA9121=m
  - REGULATOR_PF8X00=m
  - DRM_PANEL_ABT_Y030XX067A=n
  - DRM_PANEL_NOVATEK_NT36672A=n
  - DRM_PANEL_SAMSUNG_SOFEF00=n
  - DRM_PANEL_TDO_TL070WSH30=n
  - DRM_LONTIUM_LT9611UXC=n
  - DRM_ANALOGIX_ANX7625=n
  - RTC_DRV_GOLDFISH=m
  - LITEX_SOC_CONTROLLER=n
  - PWM_ATMEL_TCB=m
  - i386
  - PWM_INTEL_LGM=m
  - DEBUG_KMAP_LOCAL=n
  - s390x
  - DEBUG_USER_ASCE=n
  - riscv64
  - IRQ_TIME_ACCOUNTING
  - POWER_RESET_REGULATOR=y
- commit acbbbf7
* Mon Dec 28 2020 mkubecek@suse.cz
- rpm: drop /usr/bin/env in interpreter specification
  OBS checks don't like /usr/bin/env in script interpreter lines but upstream
  developers tend to use it. A proper solution would be fixing the depedency
  extraction and drop the OBS check error but that's unlikely to happen so
  that we have to work around the problem on our side and rewrite the
  interpreter lines in scripts before collecting files for packages instead.
- commit 0ec5324
* Sun Dec 27 2020 tiwai@suse.de
- media: uvcvideo: Accept invalid bFormatIndex and bFrameIndex
  values (bsc#1180117).
- commit 8684dfe
* Sun Dec 27 2020 tiwai@suse.de
- iwlwifi: dbg: Don't touch the tlv data (bsc#1180344).
- commit cd8100a
* Sat Dec 26 2020 jslaby@suse.cz
- Linux 5.10.3 (bsc#1012628).
- md: fix a warning caused by a race between concurrent
  md_ioctl()s (bsc#1012628).
- nl80211: validate key indexes for cfg80211_registered_device
  (bsc#1012628).
- crypto: af_alg - avoid undefined behavior accessing salg_name
  (bsc#1012628).
- media: msi2500: assign SPI bus number dynamically (bsc#1012628).
- fs: quota: fix array-index-out-of-bounds bug by passing correct
  argument to vfs_cleanup_quota_inode() (bsc#1012628).
- quota: Sanity-check quota file headers on load (bsc#1012628).
- Bluetooth: Fix slab-out-of-bounds read in
  hci_le_direct_adv_report_evt() (bsc#1012628).
- f2fs: prevent creating duplicate encrypted filenames
  (bsc#1012628).
- ext4: prevent creating duplicate encrypted filenames
  (bsc#1012628).
- ubifs: prevent creating duplicate encrypted filenames
  (bsc#1012628).
- fscrypt: add fscrypt_is_nokey_name() (bsc#1012628).
- fscrypt: remove kernel-internal constants from UAPI header
  (bsc#1012628).
- serial_core: Check for port state when tty is in error state
  (bsc#1012628).
- HID: i2c-hid: add Vero K147 to descriptor override
  (bsc#1012628).
- scsi: megaraid_sas: Check user-provided offsets (bsc#1012628).
- f2fs: init dirty_secmap incorrectly (bsc#1012628).
- f2fs: fix to seek incorrect data offset in inline data file
  (bsc#1012628).
- coresight: etm4x: Handle TRCVIPCSSCTLR accesses (bsc#1012628).
- coresight: etm4x: Fix accesses to TRCPROCSELR (bsc#1012628).
- coresight: etm4x: Fix accesses to TRCCIDCTLR1 (bsc#1012628).
- coresight: etm4x: Fix accesses to TRCVMIDCTLR1 (bsc#1012628).
- coresight: etm4x: Skip setting LPOVERRIDE bit for qcom,
  skip-power-up (bsc#1012628).
- coresight: etb10: Fix possible NULL ptr dereference in
  etb_enable_perf() (bsc#1012628).
- coresight: tmc-etr: Fix barrier packet insertion for perf buffer
  (bsc#1012628).
- coresight: tmc-etr: Check if page is valid before dma_map_page()
  (bsc#1012628).
- coresight: tmc-etf: Fix NULL ptr dereference in
  tmc_enable_etf_sink_perf() (bsc#1012628).
- ARM: dts: exynos: fix USB 3.0 pins supply being turned off on
  Odroid XU (bsc#1012628).
- ARM: dts: exynos: fix USB 3.0 VBUS control and over-current
  pins on Exynos5410 (bsc#1012628).
- ARM: dts: exynos: fix roles of USB 3.0 ports on Odroid XU
  (bsc#1012628).
- usb: chipidea: ci_hdrc_imx: Pass DISABLE_DEVICE_STREAMING flag
  to imx6ul (bsc#1012628).
- USB: gadget: f_rndis: fix bitrate for SuperSpeed and above
  (bsc#1012628).
- usb: gadget: f_fs: Re-use SS descriptors for SuperSpeedPlus
  (bsc#1012628).
- USB: gadget: f_midi: setup SuperSpeed Plus descriptors
  (bsc#1012628).
- USB: gadget: f_acm: add support for SuperSpeed Plus
  (bsc#1012628).
- USB: serial: option: add interface-number sanity check to flag
  handling (bsc#1012628).
- usb: mtu3: fix memory corruption in mtu3_debugfs_regset()
  (bsc#1012628).
- soc/tegra: fuse: Fix index bug in get_process_id (bsc#1012628).
- exfat: Avoid allocating upcase table using kcalloc()
  (bsc#1012628).
- x86/split-lock: Avoid returning with interrupts enabled
  (bsc#1012628).
- net: ipconfig: Avoid spurious blank lines in boot log
  (bsc#1012628).
- commit 246b3e0
* Thu Dec 24 2020 nsaenzjulienne@suse.de
- reset: raspberrypi: Don't reset USB if already up (bsc#1180336).
- commit cbfc03c
* Tue Dec 22 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and move to "almost mainline" section:
  patches.suse/clk-bcm-dvp-add-module_device_table.patch
- commit 24deb54
* Mon Dec 21 2020 mkubecek@suse.cz
- config: refresh
- drop USB_SISUSBVGA_CON (no longer accessible)
- commit c403c88
* Mon Dec 21 2020 jslaby@suse.cz
- Linux 5.10.2 (bsc#1012628).
- serial: 8250_omap: Avoid FIFO corruption caused by MDR1 access
  (bsc#1012628).
- ALSA: pcm: oss: Fix potential out-of-bounds shift (bsc#1012628).
- USB: sisusbvga: Make console support depend on BROKEN
  (bsc#1012628).
- USB: UAS: introduce a quirk to set no_write_same (bsc#1012628).
- xhci-pci: Allow host runtime PM as default for Intel Maple
  Ridge xHCI (bsc#1012628).
- xhci-pci: Allow host runtime PM as default for Intel Alpine
  Ridge LP (bsc#1012628).
- usb: xhci: Set quirk for XHCI_SG_TRB_CACHE_SIZE_QUIRK
  (bsc#1012628).
- xhci: Give USB2 ports time to enter U3 in bus suspend
  (bsc#1012628).
- ALSA: usb-audio: Fix control 'access overflow' errors from chmap
  (bsc#1012628).
- ALSA: usb-audio: Fix potential out-of-bounds shift
  (bsc#1012628).
- USB: add RESET_RESUME quirk for Snapscan 1212 (bsc#1012628).
- USB: dummy-hcd: Fix uninitialized array use in init()
  (bsc#1012628).
- USB: legotower: fix logical error in recent commit
  (bsc#1012628).
- ktest.pl: Fix the logic for truncating the size of the log
  file for email (bsc#1012628).
- ktest.pl: If size of log is too big to email, email error
  message (bsc#1012628).
- ptrace: Prevent kernel-infoleak in ptrace_get_syscall_info()
  (bsc#1012628).
- commit 0c7d1c1
* Mon Dec 21 2020 nsaenzjulienne@suse.de
- clk: bcm: dvp: Add MODULE_DEVICE_TABLE() (bsc#1180260).
- commit fa7a177
* Fri Dec 18 2020 tiwai@suse.de
- drm/amdgpu: only set DP subconnector type on DP and eDP
  connectors (bsc#1180227).
- commit 74c3250
* Fri Dec 18 2020 jslaby@suse.cz
- Update config files.
  Just to match my env.
- commit 588066a
* Tue Dec 15 2020 mkubecek@suse.cz
- Linux 5.10.1 (bsc#1012628).
- Revert "dm raid: fix discard limits for raid1 and raid10"
  (bsc#1012628).
- Revert "md: change mddev 'chunk_sectors' from int to unsigned"
  (bsc#1012628).
- commit bc79fb6
* Mon Dec 14 2020 guillaume.gardet@arm.com
- lpae: disable CONFIG_QCOM_PIL_INFO to fix build on armv7
- commit 0c08c2e
* Mon Dec 14 2020 mkubecek@suse.cz
- Update to 5.10 final
- eliminated 1 patch
  - patches.suse/revert-mm-filemap-add-static-for-function-__add_to_p.patch
- update configs
  - NFS_V4_2_READ_PLUS=n (recommended default, unsafe feature)
- commit ff9060b
* Sun Dec 13 2020 dmueller@suse.com
- config.conf: Reenable armv6hl/armv7hl/arm64
- Update config files:
  * Settings copied from x86_64 update
  * arm specific options are =m except if debug or test, =y otherwise
- commit cc424ba
* Sat Dec 12 2020 jslaby@suse.cz
- drm/i915/gt: Declare gen9 has 64 mocs entries! (git-fixes).
- commit c648a46
* Sat Dec 12 2020 jslaby@suse.cz
- Linux 5.9.14 (bsc#1012628).
- usb: gadget: f_fs: Use local copy of descriptors for userspace
  copy (bsc#1012628).
- USB: serial: kl5kusb105: fix memleak on open (bsc#1012628).
- USB: serial: ch341: add new Product ID for CH341A (bsc#1012628).
- USB: serial: ch341: sort device-id entries (bsc#1012628).
- USB: serial: option: add Fibocom NL668 variants (bsc#1012628).
- USB: serial: option: add support for Thales Cinterion EXS82
  (bsc#1012628).
- USB: serial: option: fix Quectel BG96 matching (bsc#1012628).
- speakup: Reject setting the speakup line discipline outside
  of speakup (bsc#1012628).
- ALSA: hda/realtek: Fix bass speaker DAC assignment on Asus
  Zephyrus G14 (bsc#1012628).
- ALSA: hda/realtek: Add mute LED quirk to yet another HP x360
  model (bsc#1012628).
- ALSA: hda/realtek: Enable headset of ASUS UX482EG & B9400CEA
  with ALC294 (bsc#1012628).
- ALSA: hda/realtek - Add new codec supported for ALC897
  (bsc#1012628).
- ALSA: hda/realtek - Fixed Dell AIO wrong sound tone
  (bsc#1012628).
- ALSA: hda/generic: Add option to enforce preferred_dacs pairs
  (bsc#1012628).
- ring-buffer: Update write stamp with the correct ts
  (bsc#1012628).
- ring-buffer: Set the right timestamp in the slow path of
  __rb_reserve_next() (bsc#1012628).
- ring-buffer: Always check to put back before stamp when crossing
  pages (bsc#1012628).
- ftrace: Fix updating FTRACE_FL_TRAMP (bsc#1012628).
- ftrace: Fix DYNAMIC_FTRACE_WITH_DIRECT_CALLS dependency
  (bsc#1012628).
- cifs: allow syscalls to be restarted in __smb_send_rqst()
  (bsc#1012628).
- cifs: fix potential use-after-free in cifs_echo_request()
  (bsc#1012628).
- cifs: refactor create_sd_buf() and and avoid corrupting the
  buffer (bsc#1012628).
- cifs: add NULL check for ses->tcon_ipc (bsc#1012628).
- gfs2: Upgrade shared glocks for atime updates (bsc#1012628).
- gfs2: Fix deadlock between gfs2_{create_inode,inode_lookup}
  and delete_work_func (bsc#1012628).
- s390/pci: fix CPU address in MSI for directed IRQ (bsc#1012628).
- i2c: imx: Fix reset of I2SR_IAL flag (bsc#1012628).
- i2c: imx: Check for I2SR_IAL after every byte (bsc#1012628).
- i2c: imx: Don't generate STOP condition if arbitration has
  been lost (bsc#1012628).
- tracing: Fix userstacktrace option for instances (bsc#1012628).
- thunderbolt: Fix use-after-free in remove_unplugged_switch()
  (bsc#1012628).
- drm/omap: sdi: fix bridge enable/disable (bsc#1012628).
- drm/amdgpu/vcn3.0: stall DPG when WPTR/RPTR reset (bsc#1012628).
- drm/amdgpu/vcn3.0: remove old DPG workaround (bsc#1012628).
- drm/i915/gt: Retain default context state across shrinking
  (bsc#1012628).
- drm/i915/gt: Limit frequency drop to RPe on parking
  (bsc#1012628).
- drm/i915/gt: Program mocs:63 for cache eviction on gen9
  (bsc#1012628).
- KVM: PPC: Book3S HV: XIVE: Fix vCPU id sanity check
  (bsc#1012628).
- scsi: mpt3sas: Fix ioctl timeout (bsc#1012628).
- io_uring: fix recvmsg setup with compat buf-select
  (bsc#1012628).
- dm writecache: advance the number of arguments when reporting
  max_age (bsc#1012628).
- dm writecache: fix the maximum number of arguments
  (bsc#1012628).
- powerpc/64s/powernv: Fix memory corruption when saving SLB
  entries on MCE (bsc#1012628).
- genirq/irqdomain: Add an irq_create_mapping_affinity() function
  (bsc#1012628).
- powerpc/pseries: Pass MSI affinity to irq_create_mapping()
  (bsc#1012628).
- dm: fix bug with RCU locking in dm_blk_report_zones
  (bsc#1012628).
- dm: fix double RCU unlock in dm_dax_zero_page_range() error path
  (bsc#1012628).
- dm: remove invalid sparse __acquires and __releases annotations
  (bsc#1012628).
- x86/uprobes: Do not use prefixes.nbytes when looping over
  prefixes.bytes (bsc#1012628).
- coredump: fix core_pattern parse error (bsc#1012628).
- mm: list_lru: set shrinker map bit when child nr_items is not
  zero (bsc#1012628).
- mm/swapfile: do not sleep with a spin lock held (bsc#1012628).
- hugetlb_cgroup: fix offline of hugetlb cgroup with reservations
  (bsc#1012628).
- Revert "amd/amdgpu: Disable VCN DPG mode for Picasso"
  (bsc#1012628).
- iommu/amd: Set DTE[IntTabLen] to represent 512 IRTEs
  (bsc#1012628).
- mm: memcg/slab: fix obj_cgroup_charge() return value handling
  (bsc#1012628).
- lib/syscall: fix syscall registers retrieval on 32-bit platforms
  (bsc#1012628).
- can: af_can: can_rx_unregister(): remove WARN() statement from
  list operation sanity check (bsc#1012628).
- gfs2: check for empty rgrp tree in gfs2_ri_update (bsc#1012628).
- netfilter: ipset: prevent uninit-value in hash_ip6_add
  (bsc#1012628).
- ASoC: wm_adsp: fix error return code in wm_adsp_load()
  (bsc#1012628).
- gfs2: Fix deadlock dumping resource group glocks (bsc#1012628).
- gfs2: Don't freeze the file system during unmount (bsc#1012628).
- rtw88: debug: Fix uninitialized memory in debugfs code
  (bsc#1012628).
- i2c: qcom: Fix IRQ error misassignement (bsc#1012628).
- i2c: qup: Fix error return code in qup_i2c_bam_schedule_desc()
  (bsc#1012628).
- dm writecache: remove BUG() and fail gracefully instead
  (bsc#1012628).
- Input: i8042 - fix error return code in i8042_setup_aux()
  (bsc#1012628).
- netfilter: nf_tables: avoid false-postive lockdep splat
  (bsc#1012628).
- netfilter: nftables_offload: set address type in control
  dissector (bsc#1012628).
- netfilter: nftables_offload: build mask based from the matching
  bytes (bsc#1012628).
- x86/insn-eval: Use new for_each_insn_prefix() macro to loop
  over prefixes bytes (bsc#1012628).
- Revert "geneve: pull IP header before ECN decapsulation"
  (bsc#1012628).
- bpf: Fix propagation of 32-bit signed bounds from 64-bit bounds
  (bsc#1012628).
- commit 960bcea
* Fri Dec 11 2020 jslaby@suse.cz
- Update patches.suse/tty-Fix-pgrp-locking-in-tiocspgrp.patch
  (bsc#1179745 CVE-2020-29661).
- Update patches.suse/tty-Fix-session-locking.patch (bsc#1179745
  CVE-2020-29660).
  Add CVE numbers.
- commit 1329f77
* Thu Dec 10 2020 ohering@suse.de
- config: disable IP_PNP
  The kernel IP autoconfiguration can only be used in practice when driver of
  the network device to be configured is also built into vmlinux. As we build
  all network device drivers as modules, there is no point keeping IP_PNP
  enabled.
- commit 7e286c2
* Thu Dec 10 2020 mkubecek@suse.cz
- config: refresh
- only update CC_VERSION_TEXT after gcc update
- commit 012c071
* Thu Dec 10 2020 mgorman@suse.de
- Update config files to disable CONFIG_DEBUG_SECTION_MISMATCH (bsc#1177403)
- commit a0a476d
* Tue Dec  8 2020 mkubecek@suse.cz
- revert "mm/filemap: add static for
  function __add_to_page_cache_locked"
  (http://lkml.kernel.org/r/20201207081556.pwxmhgdxayzbofpi@lion.mk-sys.cz).
- fix build on ppc64, ppc64le and riscv64
- commit 9688120
* Tue Dec  8 2020 jslaby@suse.cz
- Linux 5.9.13 (bsc#1012628).
- devlink: Hold rtnl lock while reading netdev attributes
  (bsc#1012628).
- devlink: Make sure devlink instance and port are in same net
  namespace (bsc#1012628).
- ipv6: addrlabel: fix possible memory leak in ip6addrlbl_net_init
  (bsc#1012628).
- net/af_iucv: set correct sk_protocol for child sockets
  (bsc#1012628).
- net: openvswitch: fix TTL decrement action netlink message
  format (bsc#1012628).
- net/tls: missing received data after fast remote close
  (bsc#1012628).
- net/tls: Protect from calling tls_dev_del for TLS RX twice
  (bsc#1012628).
- rose: Fix Null pointer dereference in rose_send_frame()
  (bsc#1012628).
- sock: set sk_err to ee_errno on dequeue from errq (bsc#1012628).
- tcp: Set INET_ECN_xmit configuration in
  tcp_reinit_congestion_control (bsc#1012628).
- tun: honor IOCB_NOWAIT flag (bsc#1012628).
- usbnet: ipheth: fix connectivity with iOS 14 (bsc#1012628).
- vsock/virtio: discard packets only when socket is really closed
  (bsc#1012628).
- mptcp: fix NULL ptr dereference on bad MPJ (bsc#1012628).
- net/packet: fix packet receive on L3 devices without visible
  hard header (bsc#1012628).
- netfilter: bridge: reset skb->pkt_type after
  NF_INET_POST_ROUTING traversal (bsc#1012628).
- ipv4: Fix tos mask in inet_rtm_getroute() (bsc#1012628).
- dt-bindings: net: correct interrupt flags in examples
  (bsc#1012628).
- chelsio/chtls: fix panic during unload reload chtls
  (bsc#1012628).
- ibmvnic: Ensure that SCRQ entry reads are correctly ordered
  (bsc#1012628).
- ibmvnic: Fix TX completion error handling (bsc#1012628).
- tipc: fix incompatible mtu of transmission (bsc#1012628).
- inet_ecn: Fix endianness of checksum update when setting ECT(1)
  (bsc#1012628).
- geneve: pull IP header before ECN decapsulation (bsc#1012628).
- net: ip6_gre: set dev->hard_header_len when using header_ops
  (bsc#1012628).
- dpaa_eth: copy timestamp fields to new skb in A-050385
  workaround (bsc#1012628).
- cxgb3: fix error return code in t3_sge_alloc_qset()
  (bsc#1012628).
- net: pasemi: fix error return code in pasemi_mac_open()
  (bsc#1012628).
- vxlan: fix error return code in __vxlan_dev_create()
  (bsc#1012628).
- chelsio/chtls: fix a double free in chtls_setkey()
  (bsc#1012628).
- net: mvpp2: Fix error return code in mvpp2_open() (bsc#1012628).
- net: skbuff: ensure LSE is pullable before decrementing the
  MPLS ttl (bsc#1012628).
- net: openvswitch: ensure LSE is pullable before reading it
  (bsc#1012628).
- net/sched: act_mpls: ensure LSE is pullable before reading it
  (bsc#1012628).
- net/mlx5: DR, Proper handling of unsupported Connect-X6DX SW
  steering (bsc#1012628).
- net/mlx5: Fix wrong address reclaim when command interface is
  down (bsc#1012628).
- net: mlx5e: fix fs_tcp.c build when IPV6 is not enabled
  (bsc#1012628).
- ALSA: usb-audio: US16x08: fix value count for level meters
  (bsc#1012628).
- Input: xpad - support Ardwiino Controllers (bsc#1012628).
- Input: i8042 - add ByteSpeed touchpad to noloop table
  (bsc#1012628).
- Input: atmel_mxt_ts - fix lost interrupts (bsc#1012628).
- tracing: Fix alignment of static buffer (bsc#1012628).
- tracing: Remove WARN_ON in start_thread() (bsc#1012628).
- uapi: fix statx attribute value overlap for DAX & MOUNT_ROOT
  (bsc#1012628).
- drm/i915/gt: Fixup tgl mocs for PTE tracking (bsc#1012628).
- commit 3dfd18b
* Tue Dec  8 2020 jslaby@suse.cz
- tty: Fix ->session locking (bsc#1179745).
- tty: Fix ->pgrp locking in tiocspgrp() (bsc#1179745).
- commit 9455f8b
* Mon Dec  7 2020 mkubecek@suse.cz
- net/x25: prevent a couple of overflows (bsc#1178590).
- commit 2a06597
* Mon Dec  7 2020 mkubecek@suse.cz
- Update to 5.10-rc7
- refresh
  - patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch
- refresh configs
- commit baa1207
* Wed Dec  2 2020 jslaby@suse.cz
- Linux 5.9.12 (bsc#1012628).
- io_uring: get an active ref_node from files_data (bsc#1012628).
- io_uring: order refnode recycling (bsc#1012628).
- spi: bcm-qspi: Fix use-after-free on unbind (bsc#1012628).
- spi: bcm2835: Fix use-after-free on unbind (bsc#1012628).
- ipv4: use IS_ENABLED instead of ifdef (bsc#1012628).
- IB/hfi1: Ensure correct mm is used at all times (bsc#1012628).
- RDMA/i40iw: Address an mmap handler exploit in i40iw
  (bsc#1012628).
- btrfs: fix missing delalloc new bit for new delalloc ranges
  (bsc#1012628).
- btrfs: tree-checker: add missing return after error in root_item
  (bsc#1012628).
- btrfs: tree-checker: add missing returns after data_ref
  alignment checks (bsc#1012628).
- btrfs: don't access possibly stale fs_info data for printing
  duplicate device (bsc#1012628).
- btrfs: fix lockdep splat when reading qgroup config on mount
  (bsc#1012628).
- rtc: pcf2127: fix a bug when not specify interrupts property
  (bsc#1012628).
- s390: fix fpu restore in entry.S (bsc#1012628).
- mm: fix VM_BUG_ON(PageTail) and BUG_ON(PageWriteback)
  (bsc#1012628).
- smb3: Call cifs reconnect from demultiplex thread (bsc#1012628).
- smb3: Avoid Mid pending list corruption (bsc#1012628).
- smb3: Handle error case during offload read path (bsc#1012628).
- cifs: fix a memleak with modefromsid (bsc#1012628).
- powerpc/64s: Fix KVM system reset handling when
  CONFIG_PPC_PSERIES=y (bsc#1012628).
- powerpc/64s/exception: KVM Fix for host DSI being taken in
  HPT guest MMU context (bsc#1012628).
- KVM: PPC: Book3S HV: XIVE: Fix possible oops when accessing
  ESB page (bsc#1012628).
- KVM: arm64: vgic-v3: Drop the reporting of GICR_TYPER.Last
  for userspace (bsc#1012628).
- KVM: x86: handle !lapic_in_kernel case in kvm_cpu_*_extint
  (bsc#1012628).
- KVM: x86: Fix split-irqchip vs interrupt injection window
  request (bsc#1012628).
- iommu/vt-d: Don't read VCCAP register unless it exists
  (bsc#1012628).
- firmware: xilinx: Use hash-table for api feature check
  (bsc#1012628).
- drm/amdgpu: fix SI UVD firmware validate resume fail
  (bsc#1012628).
- io_uring: fix ITER_BVEC check (bsc#1012628).
- trace: fix potenial dangerous pointer (bsc#1012628).
- arm64: tegra: Correct the UART for Jetson Xavier NX
  (bsc#1012628).
- arm64: tegra: Fix USB_VBUS_EN0 regulator on Jetson TX1
  (bsc#1012628).
- arm64: pgtable: Fix pte_accessible() (bsc#1012628).
- arm64: pgtable: Ensure dirty bit is preserved across
  pte_wrprotect() (bsc#1012628).
- drm/amdgpu: fix a page fault (bsc#1012628).
- drm/amdgpu: update golden setting for sienna_cichlid
  (bsc#1012628).
- drm/amd/amdgpu: fix null pointer in runtime pm (bsc#1012628).
- drm/amd/display: Avoid HDCP initialization in devices without
  output (bsc#1012628).
- HID: uclogic: Add ID for Trust Flex Design Tablet (bsc#1012628).
- HID: ite: Replace ABS_MISC 120/121 events with touchpad on/off
  keypresses (bsc#1012628).
- HID: cypress: Support Varmilo Keyboards' media hotkeys
  (bsc#1012628).
- HID: add support for Sega Saturn (bsc#1012628).
- Input: i8042 - allow insmod to succeed on devices without an
  i8042 controller (bsc#1012628).
- HID: hid-sensor-hub: Fix issue with devices with no report ID
  (bsc#1012628).
- staging: ralink-gdma: fix kconfig dependency bug for DMA_RALINK
  (bsc#1012628).
- HID: add HID_QUIRK_INCREMENT_USAGE_ON_DUPLICATE for Gamevice
  devices (bsc#1012628).
- dmaengine: xilinx_dma: use readl_poll_timeout_atomic variant
  (bsc#1012628).
- x86/xen: don't unbind uninitialized lock_kicker_irq
  (bsc#1012628).
- kunit: fix display of failed expectations for strings
  (bsc#1012628).
- HID: logitech-hidpp: Add HIDPP_CONSUMER_VENDOR_KEYS quirk for
  the Dinovo Edge (bsc#1012628).
- HID: Add Logitech Dinovo Edge battery quirk (bsc#1012628).
- proc: don't allow async path resolution of /proc/self components
  (bsc#1012628).
- nvme: free sq/cq dbbuf pointers when dbbuf set fails
  (bsc#1012628).
- io_uring: handle -EOPNOTSUPP on path resolution (bsc#1012628).
- net: stmmac: dwmac_lib: enlarge dma reset timeout (bsc#1012628).
- vdpasim: fix "mac_pton" undefined error (bsc#1012628).
- vhost: add helper to check if a vq has been setup (bsc#1012628).
- vhost scsi: alloc cmds per vq instead of session (bsc#1012628).
- vhost scsi: fix cmd completion race (bsc#1012628).
- cpuidle: tegra: Annotate tegra_pm_set_cpu_in_lp2() with
  RCU_NONIDLE (bsc#1012628).
- dmaengine: pl330: _prep_dma_memcpy: Fix wrong burst size
  (bsc#1012628).
- scsi: libiscsi: Fix NOP race condition (bsc#1012628).
- scsi: target: iscsi: Fix cmd abort fabric stop race
  (bsc#1012628).
- lockdep: Put graph lock/unlock under lock_recursion protection
  (bsc#1012628).
- perf/x86: fix sysfs type mismatches (bsc#1012628).
- xtensa: uaccess: Add missing __user to strncpy_from_user()
  prototype (bsc#1012628).
- x86/dumpstack: Do not try to access user space code of other
  tasks (bsc#1012628).
- net: dsa: mv88e6xxx: Wait for EEPROM done after HW reset
  (bsc#1012628).
- bus: ti-sysc: Fix reset status check for modules with quirks
  (bsc#1012628).
- bus: ti-sysc: Fix bogus resetdone warning on enable for cpsw
  (bsc#1012628).
- ARM: OMAP2+: Manage MPU state properly for
  omap_enter_idle_coupled() (bsc#1012628).
- phy: tegra: xusb: Fix dangling pointer on probe failure
  (bsc#1012628).
- iwlwifi: mvm: use the HOT_SPOT_CMD to cancel an AUX ROC
  (bsc#1012628).
- iwlwifi: mvm: properly cancel a session protection for P2P
  (bsc#1012628).
- iwlwifi: mvm: write queue_sync_state only for sync
  (bsc#1012628).
- KVM: s390: pv: Mark mm as protected after the set secure
  parameters and improve cleanup (bsc#1012628).
- KVM: s390: remove diag318 reset code (bsc#1012628).
- batman-adv: set .owner to THIS_MODULE (bsc#1012628).
- usb: cdns3: gadget: fix some endian issues (bsc#1012628).
- usb: cdns3: gadget: calculate TD_SIZE based on TD (bsc#1012628).
- phy: qualcomm: usb: Fix SuperSpeed PHY OF dependency
  (bsc#1012628).
- phy: qualcomm: Fix 28 nm Hi-Speed USB PHY OF dependency
  (bsc#1012628).
- arch: pgtable: define MAX_POSSIBLE_PHYSMEM_BITS where needed
  (bsc#1012628).
- bus: ti-sysc: suppress err msg for timers used as
  clockevent/source (bsc#1012628).
- ARM: dts: dra76x: m_can: fix order of clocks (bsc#1012628).
- scsi: ufs: Fix race between shutdown and runtime resume flow
  (bsc#1012628).
- bnxt_en: fix error return code in bnxt_init_one() (bsc#1012628).
- bnxt_en: fix error return code in bnxt_init_board()
  (bsc#1012628).
- video: hyperv_fb: Fix the cache type when mapping the VRAM
  (bsc#1012628).
- bnxt_en: Release PCI regions when DMA mask setup fails during
  probe (bsc#1012628).
- block/keyslot-manager: prevent crash when num_slots=1
  (bsc#1012628).
- cxgb4: fix the panic caused by non smac rewrite (bsc#1012628).
- dpaa2-eth: select XGMAC_MDIO for MDIO bus support (bsc#1012628).
- s390/qeth: make af_iucv TX notification call more robust
  (bsc#1012628).
- s390/qeth: fix af_iucv notification race (bsc#1012628).
- s390/qeth: fix tear down of async TX buffers (bsc#1012628).
- drm/mediatek: dsi: Modify horizontal front/back porch byte
  formula (bsc#1012628).
- bonding: wait for sysfs kobject destruction before freeing
  struct slave (bsc#1012628).
- ibmvnic: fix call_netdevice_notifiers in do_reset (bsc#1012628).
- ibmvnic: notify peers when failover and migration happen
  (bsc#1012628).
- powerpc/64s: Fix allnoconfig build since uaccess flush
  (bsc#1012628).
- iommu: Check return of __iommu_attach_device() (bsc#1012628).
- IB/mthca: fix return value of error branch in mthca_init_cq()
  (bsc#1012628).
- i40e: Fix removing driver while bare-metal VFs pass traffic
  (bsc#1012628).
- firmware: xilinx: Fix SD DLL node reset issue (bsc#1012628).
- spi: imx: fix the unbalanced spi runtime pm management
  (bsc#1012628).
- io_uring: fix shift-out-of-bounds when round up cq size
  (bsc#1012628).
- aquantia: Remove the build_skb path (bsc#1012628).
- nfc: s3fwrn5: use signed integer for parsing GPIO numbers
  (bsc#1012628).
- net: ena: handle bad request id in ena_netdev (bsc#1012628).
- net: ena: set initial DMA width to avoid intel iommu issue
  (bsc#1012628).
- net: ena: fix packet's addresses for rx_offset feature
  (bsc#1012628).
- ibmvnic: fix NULL pointer dereference in reset_sub_crq_queues
  (bsc#1012628).
- ibmvnic: fix NULL pointer dereference in ibmvic_reset_crq
  (bsc#1012628).
- ibmvnic: enhance resetting status check during module exit
  (bsc#1012628).
- optee: add writeback to valid memory type (bsc#1012628).
- x86/tboot: Don't disable swiotlb when iommu is forced on
  (bsc#1012628).
- arm64: tegra: Wrong AON HSP reg property size (bsc#1012628).
- efi/efivars: Set generic ops before loading SSDT (bsc#1012628).
- efivarfs: revert "fix memory leak in efivarfs_create()"
  (bsc#1012628).
- efi: EFI_EARLYCON should depend on EFI (bsc#1012628).
- riscv: Explicitly specify the build id style in vDSO Makefile
  again (bsc#1012628).
- RISC-V: Add missing jump label initialization (bsc#1012628).
- RISC-V: fix barrier() use in <vdso/processor.h> (bsc#1012628).
- net: stmmac: fix incorrect merge of patch upstream
  (bsc#1012628).
- enetc: Let the hardware auto-advance the taprio base-time of 0
  (bsc#1012628).
- ptp: clockmatrix: bug fix for idtcm_strverscmp (bsc#1012628).
- drm/nouveau: fix relocations applying logic and a double-free
  (bsc#1012628).
- can: gs_usb: fix endianess problem with candleLight firmware
  (bsc#1012628).
- platform/x86: thinkpad_acpi: Send tablet mode switch at wakeup
  time (bsc#1012628).
- platform/x86: toshiba_acpi: Fix the wrong variable assignment
  (bsc#1012628).
- RDMA/hns: Fix wrong field of SRQ number the device supports
  (bsc#1012628).
- RDMA/hns: Fix retry_cnt and rnr_cnt when querying QP
  (bsc#1012628).
- RDMA/hns: Bugfix for memory window mtpt configuration
  (bsc#1012628).
- can: m_can: m_can_open(): remove IRQF_TRIGGER_FALLING from
  request_threaded_irq()'s flags (bsc#1012628).
- can: m_can: fix nominal bitiming tseg2 min for version >= 3.1
  (bsc#1012628).
- perf record: Synthesize cgroup events only if needed
  (bsc#1012628).
- perf stat: Use proper cpu for shadow stats (bsc#1012628).
- perf probe: Fix to die_entrypc() returns error correctly
  (bsc#1012628).
- USB: core: Change %%pK for __user pointers to %%px (bsc#1012628).
- usb: gadget: f_midi: Fix memleak in f_midi_alloc (bsc#1012628).
- USB: core: Fix regression in Hercules audio card (bsc#1012628).
- USB: quirks: Add USB_QUIRK_DISCONNECT_SUSPEND quirk for Lenovo
  A630Z TIO built-in usb-audio card (bsc#1012628).
- usb: gadget: Fix memleak in gadgetfs_fill_super (bsc#1012628).
- irqchip/exiu: Fix the index of fwspec for IRQ type
  (bsc#1012628).
- x86/mce: Do not overwrite no_way_out if mce_end() fails
  (bsc#1012628).
- x86/speculation: Fix prctl() when
  spectre_v2_user={seccomp,prctl},ibpb (bsc#1012628).
- x86/resctrl: Remove superfluous kernfs_get() calls to prevent
  refcount leak (bsc#1012628).
- x86/resctrl: Add necessary kernfs_put() calls to prevent
  refcount leak (bsc#1012628).
- drm/amdgpu: add rlc iram and dram firmware support
  (bsc#1012628).
- commit 46922da
* Tue Dec  1 2020 msuchanek@suse.de
- rpm/kernel-{source,binary}.spec: do not include ghost symlinks
  (boo#1179082).
- commit 76a9256
* Tue Dec  1 2020 jslaby@suse.cz
- Update config files.
  Refresh after SOUNDWIRE removal.
- commit fa3b6ea
* Mon Nov 30 2020 ohering@suse.de
- scripts/lib/SUSE/MyBS.pm: properly close prjconf Macros: section
- commit 965157e
* Mon Nov 30 2020 tiwai@suse.de
- Update config files: make CONFIG_SOUNDWIRE=m (bsc#1179201)
  Also turned it off for unrelated platforms
- commit a60b1c2
* Mon Nov 30 2020 mkubecek@suse.cz
- Update to 5.10-rc6
- eliminated 1 patch
  - patches.suse/btrfs-qgroup-don-t-commit-transaction-when-we-have-a.patch
- refresh configs
  - headers only (Factory updated gcc and binutils)
- commit 248e2b4
* Thu Nov 26 2020 jslaby@suse.cz
- Update
  patches.kernel.org/5.9.11-181-sched-Fix-data-race-in-wakeup.patch
  (bsc#1012628 bsc#1175893).
  Add a bsc.
- commit d5a5c02
* Thu Nov 26 2020 nsaenzjulienne@suse.de
- dt-bindings: pwm: Add binding for RPi firmware PWM bus
  (jsc#SLE-16543).
- staging: vchiq: Release firmware handle on unbind
  (jsc#SLE-16543).
- soc: bcm: raspberrypi-power: Release firmware handle on unbind
  (jsc#SLE-16543).
-  - pwm: Add Raspberry Pi Firmware based PWM bus (jsc#SLE-16543).
  - Update configs: Enable pwm driver on arm64/arm32
  - supported.conf: Enable pwm driver
- dt-bindings: pwm: Add binding for RPi firmware PWM bus
  (jsc#SLE-16543).
- staging: vchiq: Release firmware handle on unbind
  (jsc#SLE-16543).
- soc: bcm: raspberrypi-power: Release firmware handle on unbind
  (jsc#SLE-16543).
- reset: raspberrypi: Release firmware handle on unbind
  (jsc#SLE-16543).
-  - pwm: Add Raspberry Pi Firmware based PWM bus (jsc#SLE-16543).
  - Update configs: Enable pwm driver on arm64
  - supported.conf: Enable pwm driver
- input: raspberrypi-ts: Release firmware handle when not needed
  (jsc#SLE-16543).
- gpio: raspberrypi-exp: Release firmware handle on unbind
  (jsc#SLE-16543).
- firmware: raspberrypi: Keep count of all consumers
  (jsc#SLE-16543).
- firmware: raspberrypi: Introduce devm_rpi_firmware_get()
  (jsc#SLE-16543).
- clk: bcm: rpi: Release firmware handle on unbind
  (jsc#SLE-16543).
- input: raspberrypi-ts: Release firmware handle when not needed
  (jsc#SLE-16543).
- gpio: raspberrypi-exp: Release firmware handle on unbind
  (jsc#SLE-16543).
- firmware: raspberrypi: Keep count of all consumers
  (jsc#SLE-16543).
- firmware: raspberrypi: Introduce devm_rpi_firmware_get()
  (jsc#SLE-16543).
- clk: bcm: rpi: Release firmware handle on unbind
  (jsc#SLE-16543).
- commit e8d4edd
* Tue Nov 24 2020 jslaby@suse.cz
- spi: bcm2835aux: Restore err assignment in bcm2835aux_spi_probe
  (git-fixes).
- commit 91426ef
* Tue Nov 24 2020 jslaby@suse.cz
- Linux 5.9.11 (bsc#1012628).
- ah6: fix error return code in ah6_input() (bsc#1012628).
- atm: nicstar: Unmap DMA on send error (bsc#1012628).
- bnxt_en: read EEPROM A2h address using page 0 (bsc#1012628).
- devlink: Add missing genlmsg_cancel() in
  devlink_nl_sb_port_pool_fill() (bsc#1012628).
- enetc: Workaround for MDIO register access issue (bsc#1012628).
- Exempt multicast addresses from five-second neighbor lifetime
  (bsc#1012628).
- inet_diag: Fix error path to cancel the meseage in
  inet_req_diag_fill() (bsc#1012628).
- ipv6: Fix error path to cancel the meseage (bsc#1012628).
- lan743x: fix issue causing intermittent kernel log warnings
  (bsc#1012628).
- lan743x: prevent entire kernel HANG on open, for some platforms
  (bsc#1012628).
- mlxsw: core: Use variable timeout for EMAD retries
  (bsc#1012628).
- net: b44: fix error return code in b44_init_one() (bsc#1012628).
- net: bridge: add missing counters to ndo_get_stats64 callback
  (bsc#1012628).
- netdevsim: set .owner to THIS_MODULE (bsc#1012628).
- net: dsa: mv88e6xxx: Avoid VTU corruption on 6097 (bsc#1012628).
- net: ethernet: mtk-star-emac: fix error return code in
  mtk_star_enable() (bsc#1012628).
- net: ethernet: mtk-star-emac: return ok when xmit drops
  (bsc#1012628).
- net: ethernet: ti: am65-cpts: update ret when ptp_clock is ERROR
  (bsc#1012628).
- net: ethernet: ti: cpsw: fix cpts irq after suspend
  (bsc#1012628).
- net: ethernet: ti: cpsw: fix error return code in cpsw_probe()
  (bsc#1012628).
- net: ftgmac100: Fix crash when removing driver (bsc#1012628).
- net: Have netpoll bring-up DSA management interface
  (bsc#1012628).
- net: ipa: lock when freeing transaction (bsc#1012628).
- netlabel: fix our progress tracking in
  netlbl_unlabel_staticlist() (bsc#1012628).
- netlabel: fix an uninitialized warning in
  netlbl_unlabel_staticlist() (bsc#1012628).
- net: lantiq: Wait for the GPHY firmware to be ready
  (bsc#1012628).
- net/mlx4_core: Fix init_hca fields offset (bsc#1012628).
- net/mlx5e: Fix refcount leak on kTLS RX resync (bsc#1012628).
- net/ncsi: Fix netlink registration (bsc#1012628).
- net: phy: mscc: remove non-MACSec compatible phy (bsc#1012628).
- net: qualcomm: rmnet: Fix incorrect receive packet handling
  during cleanup (bsc#1012628).
- net/smc: fix direct access to ib_gid_addr->ndev in
  smc_ib_determine_gid() (bsc#1012628).
- net: stmmac: Use rtnl_lock/unlock on
  netif_set_real_num_rx_queues() call (bsc#1012628).
- net/tls: fix corrupted data in recvmsg (bsc#1012628).
- net: x25: Increase refcnt of "struct x25_neigh" in
  x25_rx_call_request (bsc#1012628).
- page_frag: Recover from memory pressure (bsc#1012628).
- qed: fix error return code in qed_iwarp_ll2_start()
  (bsc#1012628).
- qed: fix ILT configuration of SRC block (bsc#1012628).
- qlcnic: fix error return code in qlcnic_83xx_restart_hw()
  (bsc#1012628).
- sctp: change to hold/put transport for proto_unreach_timer
  (bsc#1012628).
- tcp: only postpone PROBE_RTT if RTT is < current min_rtt
  estimate (bsc#1012628).
- vsock: forward all packets to the host when no H2G is registered
  (bsc#1012628).
- net/mlx5e: Fix check if netdev is bond slave (bsc#1012628).
- net/mlx5: Add handling of port type in rule deletion
  (bsc#1012628).
- net/mlx5: Clear bw_share upon VF disable (bsc#1012628).
- net/mlx5: Disable QoS when min_rates on all VFs are zero
  (bsc#1012628).
- PM: runtime: Add pm_runtime_resume_and_get to deal with usage
  counter (bsc#1012628).
- net: fec: Fix reference count leak in fec series ops
  (bsc#1012628).
- bnxt_en: Fix counter overflow logic (bsc#1012628).
- bnxt_en: Free port stats during firmware reset (bsc#1012628).
- net: mvneta: fix possible memory leak in
  mvneta_swbm_add_rx_fragment (bsc#1012628).
- net/tls: Fix wrong record sn in async mode of device resync
  (bsc#1012628).
- net: usb: qmi_wwan: Set DTR quirk for MR400 (bsc#1012628).
- Revert "Revert "gpio: omap: Fix lost edge wake-up interrupts""
  (bsc#1012628).
- tools, bpftool: Avoid array index warnings (bsc#1012628).
- habanalabs/gaudi: mask WDT error in QMAN (bsc#1012628).
- pinctrl: rockchip: enable gpio pclk for rockchip_gpio_to_irq
  (bsc#1012628).
- scsi: ufs: Fix unbalanced scsi_block_reqs_cnt caused by
  ufshcd_hold() (bsc#1012628).
- scsi: ufs: Try to save power mode change and UIC cmd completion
  timeout (bsc#1012628).
- pinctrl: mcp23s08: Print error message when regmap init fails
  (bsc#1012628).
- selftests: kvm: Fix the segment descriptor layout to match
  the actual layout (bsc#1012628).
- ACPI: button: Add DMI quirk for Medion Akoya E2228T
  (bsc#1012628).
- arm64: errata: Fix handling of 1418040 with late CPU onlining
  (bsc#1012628).
- arm64: psci: Avoid printing in cpu_psci_cpu_die() (bsc#1012628).
- arm64: smp: Tell RCU about CPUs that fail to come online
  (bsc#1012628).
- um: Call pgtable_pmd_page_dtor() in __pmd_free_tlb()
  (bsc#1012628).
- vfs: remove lockdep bogosity in __sb_start_write (bsc#1012628).
- gfs2: fix possible reference leak in gfs2_check_blk_type
  (bsc#1012628).
- hwmon: (pwm-fan) Fix RPM calculation (bsc#1012628).
- gfs2: Fix case in which ail writes are done to jdata holes
  (bsc#1012628).
- arm64: Add MIDR value for KRYO2XX gold/silver CPU cores
  (bsc#1012628).
- arm64: kpti: Add KRYO2XX gold/silver CPU cores to kpti safelist
  (bsc#1012628).
- arm64: cpu_errata: Apply Erratum 845719 to KRYO2XX Silver
  (bsc#1012628).
- usb: dwc2: Avoid leaving the error_debugfs label unused
  (bsc#1012628).
- arm64: dts: allwinner: beelink-gs1: Enable both RGMII RX/TX
  delay (bsc#1012628).
- arm64: dts: allwinner: Pine H64: Enable both RGMII RX/TX delay
  (bsc#1012628).
- arm64: dts: allwinner: a64: OrangePi Win: Fix ethernet node
  (bsc#1012628).
- arm64: dts: allwinner: a64: Pine64 Plus: Fix ethernet node
  (bsc#1012628).
- arm64: dts: allwinner: h5: OrangePi PC2: Fix ethernet node
  (bsc#1012628).
- ARM: dts: sun8i: r40: bananapi-m2-ultra: Fix ethernet node
  (bsc#1012628).
- Revert "arm: sun8i: orangepi-pc-plus: Set EMAC activity LEDs
  to active high" (bsc#1012628).
- ARM: dts: sun6i: a31-hummingbird: Enable RGMII RX/TX delay on
  Ethernet PHY (bsc#1012628).
- ARM: dts: sun7i: cubietruck: Enable RGMII RX/TX delay on
  Ethernet PHY (bsc#1012628).
- ARM: dts: sun7i: bananapi-m1-plus: Enable RGMII RX/TX delay
  on Ethernet PHY (bsc#1012628).
- ARM: dts: sun8i: h3: orangepi-plus2e: Enable RGMII RX/TX delay
  on Ethernet PHY (bsc#1012628).
- ARM: dts: sun8i: a83t: Enable both RGMII RX/TX delay on Ethernet
  PHY (bsc#1012628).
- ARM: dts: sun9i: Enable both RGMII RX/TX delay on Ethernet PHY
  (bsc#1012628).
- ARM: dts: sunxi: bananapi-m2-plus: Enable RGMII RX/TX delay
  on Ethernet PHY (bsc#1012628).
- arm64: dts: allwinner: h5: libretech-all-h5-cc: Enable RGMII
  RX/TX delay on PHY (bsc#1012628).
- arm64: dts: allwinner: a64: bananapi-m64: Enable RGMII RX/TX
  delay on PHY (bsc#1012628).
- Input: adxl34x - clean up a data type in adxl34x_probe()
  (bsc#1012628).
- MIPS: export has_transparent_hugepage() for modules
  (bsc#1012628).
- dmaengine: idxd: fix wq config registers offset programming
  (bsc#1012628).
- arm64: dts: allwinner: h5: OrangePi Prime: Fix ethernet node
  (bsc#1012628).
- arm64: dts: fsl: fix endianness issue of rcpm (bsc#1012628).
- arm64: dts: imx8mm-beacon-som: Fix Choppy BT audio
  (bsc#1012628).
- arm64: dts imx8mn: Remove non-existent USB OTG2 (bsc#1012628).
- arm: dts: imx6qdl-udoo: fix rgmii phy-mode for ksz9031 phy
  (bsc#1012628).
- ARM: dts: vf610-zii-dev-rev-b: Fix MDIO over clocking
  (bsc#1012628).
- ARM: dts: imx6q-prti6q: fix PHY address (bsc#1012628).
- swiotlb: using SIZE_MAX needs limits.h included (bsc#1012628).
- tee: amdtee: fix memory leak due to reset of global shm list
  (bsc#1012628).
- tee: amdtee: synchronize access to shm list (bsc#1012628).
- dmaengine: xilinx_dma: Fix usage of xilinx_aximcdma_tx_segment
  (bsc#1012628).
- dmaengine: xilinx_dma: Fix SG capability check for MCDMA
  (bsc#1012628).
- ARM: dts: stm32: Fix TA3-GPIO-C key on STM32MP1 DHCOM PDK2
  (bsc#1012628).
- ARM: dts: stm32: Fix LED5 on STM32MP1 DHCOM PDK2 (bsc#1012628).
- ARM: dts: stm32: Define VIO regulator supply on DHCOM
  (bsc#1012628).
- ARM: dts: stm32: Enable thermal sensor support on
  stm32mp15xx-dhcor (bsc#1012628).
- ARM: dts: stm32: Keep VDDA LDO1 always on on DHCOM
  (bsc#1012628).
- arm64: dts: imx8mm: fix voltage for 1.6GHz CPU operating point
  (bsc#1012628).
- ARM: dts: imx50-evk: Fix the chip select 1 IOMUX (bsc#1012628).
- dmaengine: ti: omap-dma: Block PM if SDMA is busy to fix audio
  (bsc#1012628).
- kunit: tool: unmark test_data as binary blobs (bsc#1012628).
- rcu: Don't invoke try_invoke_on_locked_down_task() with irqs
  disabled (bsc#1012628).
- spi: fix client driver breakages when using GPIO descriptors
  (bsc#1012628).
- Input: resistive-adc-touch - fix kconfig dependency on
  IIO_BUFFER (bsc#1012628).
- Input: elan_i2c - fix firmware update on newer ICs
  (bsc#1012628).
- rfkill: Fix use-after-free in rfkill_resume() (bsc#1012628).
- RDMA/pvrdma: Fix missing kfree() in pvrdma_register_device()
  (bsc#1012628).
- RMDA/sw: Don't allow drivers using dma_virt_ops on highmem
  configs (bsc#1012628).
- perf lock: Correct field name "flags" (bsc#1012628).
- perf lock: Don't free "lock_seq_stat" if read_count isn't zero
  (bsc#1012628).
- SUNRPC: Fix oops in the rpc_xdr_buf event class (bsc#1012628).
- drm: bridge: dw-hdmi: Avoid resetting force in the detect
  function (bsc#1012628).
- tools, bpftool: Add missing close before bpftool net attach exit
  (bsc#1012628).
- IB/hfi1: Fix error return code in hfi1_init_dd() (bsc#1012628).
- ip_tunnels: Set tunnel option flag when tunnel metadata is
  present (bsc#1012628).
- can: af_can: prevent potential access of uninitialized member
  in can_rcv() (bsc#1012628).
- can: af_can: prevent potential access of uninitialized member
  in canfd_rcv() (bsc#1012628).
- can: dev: can_restart(): post buffer from the right context
  (bsc#1012628).
- can: ti_hecc: Fix memleak in ti_hecc_probe (bsc#1012628).
- can: mcba_usb: mcba_usb_start_xmit(): first fill skb, then
  pass to can_put_echo_skb() (bsc#1012628).
- can: peak_usb: fix potential integer overflow on shift of a int
  (bsc#1012628).
- can: flexcan: fix failure handling of pm_runtime_get_sync()
  (bsc#1012628).
- can: tcan4x5x: replace depends on REGMAP_SPI with depends on
  SPI (bsc#1012628).
- can: tcan4x5x: tcan4x5x_can_probe(): add missing error checking
  for devm_regmap_init() (bsc#1012628).
- can: tcan4x5x: tcan4x5x_can_remove(): fix order of
  deregistration (bsc#1012628).
- can: m_can: m_can_handle_state_change(): fix state change
  (bsc#1012628).
- can: m_can: m_can_class_free_dev(): introduce new function
  (bsc#1012628).
- can: m_can: Fix freeing of can device from peripherials
  (bsc#1012628).
- can: m_can: m_can_stop(): set device to software init mode
  before closing (bsc#1012628).
- dmaengine: idxd: fix mapping of portal size (bsc#1012628).
- ASoC: Intel: KMB: Fix S24_LE configuration (bsc#1012628).
- ASoC: qcom: lpass-platform: Fix memory leak (bsc#1012628).
- spi: cadence-quadspi: Fix error return code in cqspi_probe
  (bsc#1012628).
- selftests/bpf: Fix error return code in run_getsockopt_test()
  (bsc#1012628).
- MIPS: Alchemy: Fix memleak in alchemy_clk_setup_cpu
  (bsc#1012628).
- drm/sun4i: dw-hdmi: fix error return code in
  sun8i_dw_hdmi_bind() (bsc#1012628).
- net/mlx5: E-Switch, Fail mlx5_esw_modify_vport_rate if qos
  disabled (bsc#1012628).
- bpf, sockmap: Fix partial copy_page_to_iter so progress can
  still be made (bsc#1012628).
- bpf, sockmap: Ensure SO_RCVBUF memory is observed on ingress
  redirect (bsc#1012628).
- can: kvaser_pciefd: Fix KCAN bittiming limits (bsc#1012628).
- can: kvaser_usb: kvaser_usb_hydra: Fix KCAN bittiming limits
  (bsc#1012628).
- dmaengine: fix error codes in channel_register() (bsc#1012628).
- iommu/vt-d: Move intel_iommu_gfx_mapped to Intel IOMMU header
  (bsc#1012628).
- iommu/vt-d: Avoid panic if iommu init fails in tboot system
  (bsc#1012628).
- can: flexcan: flexcan_chip_start(): fix erroneous
  flexcan_transceiver_enable() during bus-off recovery
  (bsc#1012628).
- can: m_can: process interrupt only when not runtime suspended
  (bsc#1012628).
- xfs: fix the minrecs logic when dealing with inode root child
  blocks (bsc#1012628).
- xfs: strengthen rmap record flags checking (bsc#1012628).
- xfs: directory scrub should check the null bestfree entries too
  (bsc#1012628).
- xfs: ensure inobt record walks always make forward progress
  (bsc#1012628).
- xfs: return corresponding errcode if xfs_initialize_perag()
  fail (bsc#1012628).
- ASOC: Intel: kbl_rt5663_rt5514_max98927: Do not try to disable
  disabled clock (bsc#1012628).
- regulator: ti-abb: Fix array out of bound read access on the
  first transition (bsc#1012628).
- libbpf: Fix VERSIONED_SYM_COUNT number parsing (bsc#1012628).
- lib/strncpy_from_user.c: Mask out bytes after NUL terminator
  (bsc#1012628).
- fail_function: Remove a redundant mutex unlock (bsc#1012628).
- xfs: revert "xfs: fix rmap key and record comparison functions"
  (bsc#1012628).
- selftests/seccomp: powerpc: Fix typo in macro variable name
  (bsc#1012628).
- selftests/seccomp: sh: Fix register names (bsc#1012628).
- bpf, sockmap: Skb verdict SK_PASS to self already checked rmem
  limits (bsc#1012628).
- bpf, sockmap: On receive programs try to fast track SK_PASS
  ingress (bsc#1012628).
- bpf, sockmap: Use truesize with sk_rmem_schedule()
  (bsc#1012628).
- bpf, sockmap: Avoid returning unneeded EAGAIN when redirecting
  to self (bsc#1012628).
- efi/arm: set HSCTLR Thumb2 bit correctly for HVC calls from HYP
  (bsc#1012628).
- counter/ti-eqep: Fix regmap max_register (bsc#1012628).
- efi/x86: Free efi_pgd with free_pages() (bsc#1012628).
- sched/fair: Fix overutilized update in enqueue_task_fair()
  (bsc#1012628).
- sched: Fix data-race in wakeup (bsc#1012628).
- sched: Fix rq->nr_iowait ordering (bsc#1012628).
- libfs: fix error cast of negative value in simple_attr_write()
  (bsc#1012628).
- afs: Fix speculative status fetch going out of order wrt to
  modifications (bsc#1012628).
- HID: logitech-hidpp: Add PID for MX Anywhere 2 (bsc#1012628).
- HID: mcp2221: Fix GPIO output handling (bsc#1012628).
- HID: logitech-dj: Handle quad/bluetooth keyboards with a
  builtin trackpad (bsc#1012628).
- HID: logitech-dj: Fix Dinovo Mini when paired with a MX5x00
  receiver (bsc#1012628).
- speakup: Do not let the line discipline be used several times
  (bsc#1012628).
- ALSA: firewire: Clean up a locking issue in copy_resp_to_buf()
  (bsc#1012628).
- ALSA: usb-audio: Add delay quirk for all Logitech USB devices
  (bsc#1012628).
- ALSA: ctl: fix error path at adding user-defined element set
  (bsc#1012628).
- ALSA: mixart: Fix mutex deadlock (bsc#1012628).
- ALSA: hda/realtek - Add supported for Lenovo ThinkPad Headset
  Button (bsc#1012628).
- ALSA: hda/realtek - Add supported mute Led for HP (bsc#1012628).
- ALSA: hda/realtek: Add some Clove SSID in the ALC293(ALC1220)
  (bsc#1012628).
- ALSA: hda/realtek - HP Headset Mic can't detect after boot
  (bsc#1012628).
- tty: serial: imx: fix potential deadlock (bsc#1012628).
- tty: serial: imx: keep console clocks always on (bsc#1012628).
- HID: logitech-dj: Fix an error in mse_bluetooth_descriptor
  (bsc#1012628).
- efivarfs: fix memory leak in efivarfs_create() (bsc#1012628).
- staging: rtl8723bs: Add 024c:0627 to the list of SDIO device-ids
  (bsc#1012628).
- staging: mt7621-pci: avoid to request pci bus resources
  (bsc#1012628).
- iio: light: fix kconfig dependency bug for VCNL4035
  (bsc#1012628).
- ext4: fix bogus warning in ext4_update_dx_flag() (bsc#1012628).
- xfs: fix forkoff miscalculation related to XFS_LITINO(mp)
  (bsc#1012628).
- ACPI: fan: Initialize performance state sysfs attribute
  (bsc#1012628).
- iio: accel: kxcjk1013: Replace is_smo8500_device with an
  acpi_type enum (bsc#1012628).
- iio: accel: kxcjk1013: Add support for KIOX010A ACPI DSM for
  setting tablet-mode (bsc#1012628).
- iio: adc: mediatek: fix unset field (bsc#1012628).
- iio: cros_ec: Use default frequencies when EC returns invalid
  information (bsc#1012628).
- iio: imu: st_lsm6dsx: set 10ms as min shub slave timeout
  (bsc#1012628).
- iio/adc: ingenic: Fix AUX/VBAT readings when touchscreen is used
  (bsc#1012628).
- iio/adc: ingenic: Fix battery VREF for JZ4770 SoC (bsc#1012628).
- iio: adc: stm32-adc: fix a regression when using dma and irq
  (bsc#1012628).
- serial: ar933x_uart: disable clk on error handling path in probe
  (bsc#1012628).
- arm64: dts: agilex/stratix10: Fix qspi node compatible
  (bsc#1012628).
- spi: lpspi: Fix use-after-free on unbind (bsc#1012628).
- spi: Introduce device-managed SPI controller allocation
  (bsc#1012628).
- spi: npcm-fiu: Don't leak SPI master in probe error path
  (bsc#1012628).
- spi: bcm2835aux: Fix use-after-free on unbind (bsc#1012628).
- regulator: pfuze100: limit pfuze-support-disable-sw to
  pfuze{100,200} (bsc#1012628).
- regulator: fix memory leak with repeated
  set_machine_constraints() (bsc#1012628).
- regulator: avoid resolve_supply() infinite recursion
  (bsc#1012628).
- regulator: workaround self-referent regulators (bsc#1012628).
- gfs2: Fix regression in freeze_go_sync (bsc#1012628).
- xtensa: fix TLBTEMP area placement (bsc#1012628).
- xtensa: disable preemption around cache alias management calls
  (bsc#1012628).
- mac80211: minstrel: remove deferred sampling code (bsc#1012628).
- mac80211: minstrel: fix tx status processing corner case
  (bsc#1012628).
- s390: fix system call exit path (bsc#1012628).
- s390/cpum_sf.c: fix file permission for cpum_sfb_size
  (bsc#1012628).
- s390/dasd: fix null pointer dereference for ERP requests
  (bsc#1012628).
- Drivers: hv: vmbus: Allow cleanup of VMBUS_CONNECT_CPU if
  disconnected (bsc#1012628).
- drm/amd/display: Add missing pflip irq for dcn2.0 (bsc#1012628).
- drm/i915: Handle max_bpc==16 (bsc#1012628).
- drm/i915/tgl: Fix Media power gate sequence (bsc#1012628).
- io_uring: don't double complete failed reissue request
  (bsc#1012628).
- mmc: sdhci-pci: Prefer SDR25 timing for High Speed mode for
  BYT-based Intel controllers (bsc#1012628).
- mmc: sdhci-of-arasan: Allow configuring zero tap values
  (bsc#1012628).
- mmc: sdhci-of-arasan: Use Mask writes for Tap delays
  (bsc#1012628).
- mmc: sdhci-of-arasan: Issue DLL reset explicitly (bsc#1012628).
- blk-cgroup: fix a hd_struct leak in blkcg_fill_root_iostats
  (bsc#1012628).
- ptrace: Set PF_SUPERPRIV when checking capability (bsc#1012628).
- seccomp: Set PF_SUPERPRIV when checking capability
  (bsc#1012628).
- fanotify: fix logic of reporting name info with watched parent
  (bsc#1012628).
- x86/microcode/intel: Check patch signature before saving
  microcode for early loading (bsc#1012628).
- mm: never attempt async page lock if we've transferred data
  already (bsc#1012628).
- mm: fix readahead_page_batch for retry entries (bsc#1012628).
- mm: memcg/slab: fix root memcg vmstats (bsc#1012628).
- mm/userfaultfd: do not access vma->vm_mm after calling
  handle_userfault() (bsc#1012628).
- Update config files.
- commit 1b55838
* Tue Nov 24 2020 jslaby@suse.cz
- Update config files (bsc#1179102).
  Set AMIGA_PARTITION=y wherever AFFS_FS=m. The AMIGA_PARTITION's Kconfig
  help suggests: default y if (AMIGA || AFFS_FS=y). And we enable Amiga FS
  in some configs, but don't enable support for Amiga partitions. That is
  a bit pointless. So fix this.
- commit cc720a5
* Mon Nov 23 2020 jslaby@suse.cz
- rpm/kernel-binary.spec.in: use grep -E instead of egrep (bsc#1179045)
  egrep is only a deprecated bash wrapper for "grep -E". So use the latter
  instead.
- commit 63d7072
* Mon Nov 23 2020 jslaby@suse.cz
- kernel-{binary,source}.spec.in: do not create loop symlinks (bsc#1179082)
- rpm/kernel-{binary,source}.spec.in: do not create loop symlinks
  (bsc#1179082)
- commit adf56a8
* Mon Nov 23 2020 jslaby@suse.cz
- rpm/kernel-binary.spec.in: avoid using more barewords (bsc#1179014)
  %%split_extra still contained two.
- commit d9b4c40
* Mon Nov 23 2020 mkubecek@suse.cz
- Update to 5.10-rc5
- refresh configs
  - DMA_VIRT_OPS and dependecies dropped on i386
- commit 8ebabda
* Sun Nov 22 2020 jslaby@suse.cz
- mac80211: free sta in sta_info_insert_finish() on errors
  (git-fixes).
- commit f42c89a
* Sun Nov 22 2020 jslaby@suse.cz
- Linux 5.9.10 (bsc#1012628).
- ACPI: GED: fix -Wformat (bsc#1012628).
- KVM: x86: clflushopt should be treated as a no-op by emulation
  (bsc#1012628).
- perf/x86/intel/uncore: Fix Add BW copypasta (bsc#1012628).
- powerpc/smp: Call rcu_cpu_starting() earlier (bsc#1012628).
- selftests/harness: prettify SKIP message whitespace again
  (bsc#1012628).
- can: proc: can_remove_proc(): silence remove_proc_entry warning
  (bsc#1012628).
- mac80211: always wind down STA state (bsc#1012628).
- Input: sunkbd - avoid use-after-free in teardown paths
  (bsc#1012628).
- leds: lm3697: Fix out-of-bound access (bsc#1012628).
- selftests/powerpc: entry flush test (bsc#1012628).
- powerpc: Only include kup-radix.h for 64-bit Book3S
  (bsc#1012628).
- powerpc/64s: flush L1D after user accesses (bsc#1012628).
- powerpc/64s: flush L1D on kernel entry (bsc#1012628).
- selftests/powerpc: rfi_flush: disable entry flush if present
  (bsc#1012628).
- commit 18ece1c
* Fri Nov 20 2020 msuchanek@suse.de
- kernel-source.spec: Fix build with rpm 4.16 (boo#1179015).
  RPM_BUILD_ROOT is cleared before %%%%install. Do the unpack into
  RPM_BUILD_ROOT in %%%%install
- commit 13bd533
* Fri Nov 20 2020 jslaby@suse.cz
- rpm/kernel-binary.spec.in: avoid using barewords (bsc#1179014)
  Author: Dominique Leuenberger <dimstar@opensuse.org>
- commit 21f8205
* Fri Nov 20 2020 jslaby@suse.cz
- rpm/mkspec: do not build kernel-obs-build on x86_32
  We want to use 64bit kernel due to various bugs (bsc#1178762 to name
  one).
  There is:
  ExportFilter: ^kernel-obs-build.*\.x86_64.rpm$ . i586
  in Factory's prjconf now. No other actively maintained distro (i.e.
  merging packaging branch) builds a x86_32 kernel, hence pushing to
  packaging directly.
- commit 8099b4b
* Thu Nov 19 2020 jslaby@suse.cz
- RDMA/srpt: Fix typo in srpt_unregister_mad_agent docstring
  (git-fixes).
- arm64: kexec_file: Fix sparse warning (git-fixes).
- commit f76e598
* Thu Nov 19 2020 jslaby@suse.cz
- Linux 5.9.9 (bsc#1012628).
- drm/i915: Hold onto an explicit ref to i915_vma_work.pinned
  (bsc#1012628).
- drm/i915/gem: Flush coherency domains on first set-domain-ioctl
  (bsc#1012628).
- mm: memcg: link page counters to root if use_hierarchy is false
  (bsc#1012628).
- nbd: don't update block size after device is started
  (bsc#1012628).
- KVM: arm64: Force PTE mapping on fault resulting in a device
  mapping (bsc#1012628).
- xfrm: interface: fix the priorities for ipip and ipv6 tunnels
  (bsc#1012628).
- ASoC: Intel: kbl_rt5663_max98927: Fix kabylake_ssp_fixup
  function (bsc#1012628).
- genirq: Let GENERIC_IRQ_IPI select IRQ_DOMAIN_HIERARCHY
  (bsc#1012628).
- hv_balloon: disable warning when floor reached (bsc#1012628).
- net: xfrm: fix a race condition during allocing spi
  (bsc#1012628).
- ASoC: codecs: wsa881x: add missing stream rates and format
  (bsc#1012628).
- spi: imx: fix runtime pm support for !CONFIG_PM (bsc#1012628).
- irqchip/sifive-plic: Fix broken irq_set_affinity() callback
  (bsc#1012628).
- kunit: Fix kunit.py --raw_output option (bsc#1012628).
- kunit: Don't fail test suites if one of them is empty
  (bsc#1012628).
- usb: gadget: fsl: fix null pointer checking (bsc#1012628).
- selftests: filter kselftest headers from command in lib.mk
  (bsc#1012628).
- ASoC: codecs: wcd934x: Set digital gain range correctly
  (bsc#1012628).
- ASoC: codecs: wcd9335: Set digital gain range correctly
  (bsc#1012628).
- mtd: spi-nor: Fix address width on flash chips > 16MB
  (bsc#1012628).
- xfs: set xefi_discard when creating a deferred agfl free log
  intent item (bsc#1012628).
- mac80211: don't require VHT elements for HE on 2.4 GHz
  (bsc#1012628).
- netfilter: nftables: fix netlink report logic in flowtable
  and genid (bsc#1012628).
- netfilter: use actual socket sk rather than skb sk when routing
  harder (bsc#1012628).
- netfilter: nf_tables: missing validation from the abort path
  (bsc#1012628).
- netfilter: ipset: Update byte and packet counters regardless
  of whether they match (bsc#1012628).
- irqchip/sifive-plic: Fix chip_data access within a hierarchy
  (bsc#1012628).
- powerpc/eeh_cache: Fix a possible debugfs deadlock
  (bsc#1012628).
- drm/vc4: bo: Add a managed action to cleanup the cache
  (bsc#1012628).
- IB/srpt: Fix memory leak in srpt_add_one (bsc#1012628).
- mm: memcontrol: correct the NR_ANON_THPS counter of hierarchical
  memcg (bsc#1012628).
- drm/panfrost: rename error labels in device_init (bsc#1012628).
- drm/panfrost: move devfreq_init()/fini() in device
  (bsc#1012628).
- drm/panfrost: Fix module unload (bsc#1012628).
- perf trace: Fix segfault when trying to trace events by cgroup
  (bsc#1012628).
- perf tools: Add missing swap for ino_generation (bsc#1012628).
- perf tools: Add missing swap for cgroup events (bsc#1012628).
- ALSA: hda: prevent undefined shift in
  snd_hdac_ext_bus_get_link() (bsc#1012628).
- iommu/vt-d: Fix sid not set issue in intel_svm_bind_gpasid()
  (bsc#1012628).
- iommu/vt-d: Fix a bug for PDP check in prq_event_thread
  (bsc#1012628).
- afs: Fix warning due to unadvanced marshalling pointer
  (bsc#1012628).
- afs: Fix incorrect freeing of the ACL passed to the YFS ACL
  store op (bsc#1012628).
- vfio/pci: Implement ioeventfd thread handler for contended
  memory lock (bsc#1012628).
- can: rx-offload: don't call kfree_skb() from IRQ context
  (bsc#1012628).
- can: dev: can_get_echo_skb(): prevent call to kfree_skb()
  in hard IRQ context (bsc#1012628).
- can: dev: __can_get_echo_skb(): fix real payload length return
  value for RTR frames (bsc#1012628).
- can: can_create_echo_skb(): fix echo skb generation: always
  use skb_clone() (bsc#1012628).
- can: j1939: swap addr and pgn in the send example (bsc#1012628).
- can: j1939: j1939_sk_bind(): return failure if netdev is down
  (bsc#1012628).
- can: ti_hecc: ti_hecc_probe(): add missed
  clk_disable_unprepare() in error path (bsc#1012628).
- can: xilinx_can: handle failure cases of pm_runtime_get_sync
  (bsc#1012628).
- can: peak_usb: add range checking in decode operations
  (bsc#1012628).
- can: peak_usb: peak_usb_get_ts_time(): fix timestamp wrapping
  (bsc#1012628).
- can: peak_canfd: pucan_handle_can_rx(): fix echo management
  when loopback is on (bsc#1012628).
- can: flexcan: remove FLEXCAN_QUIRK_DISABLE_MECR quirk for
  LS1021A (bsc#1012628).
- can: flexcan: flexcan_remove(): disable wakeup completely
  (bsc#1012628).
- xfs: flush new eof page on truncate to avoid post-eof corruption
  (bsc#1012628).
- xfs: fix missing CoW blocks writeback conversion retry
  (bsc#1012628).
- xfs: fix scrub flagging rtinherit even if there is no rt device
  (bsc#1012628).
- io_uring: ensure consistent view of original task ->mm from
  SQPOLL (bsc#1012628).
- spi: fsl-dspi: fix wrong pointer in suspend/resume
  (bsc#1012628).
- PCI: mvebu: Fix duplicate resource requests (bsc#1012628).
- ceph: check session state after bumping session->s_seq
  (bsc#1012628).
- selftests: core: use SKIP instead of XFAIL in close_range_test.c
  (bsc#1012628).
- selftests: clone3: use SKIP instead of XFAIL (bsc#1012628).
- selftests: binderfs: use SKIP instead of XFAIL (bsc#1012628).
- x86/speculation: Allow IBPB to be conditionally enabled on
  CPUs with always-on STIBP (bsc#1012628).
- kbuild: explicitly specify the build id style (bsc#1012628).
- RISC-V: Fix the VDSO symbol generaton for binutils-2.35+
  (bsc#1012628).
- USB: apple-mfi-fastcharge: fix reference leak in
  apple_mfi_fc_set_property (bsc#1012628).
- tpm: efi: Don't create binary_bios_measurements file for an
  empty log (bsc#1012628).
- KVM: arm64: ARM_SMCCC_ARCH_WORKAROUND_1 doesn't return
  SMCCC_RET_NOT_REQUIRED (bsc#1012628).
- ath9k_htc: Use appropriate rs_datalen type (bsc#1012628).
- scsi: ufs: Fix missing brace warning for old compilers
  (bsc#1012628).
- ASoC: mediatek: mt8183-da7219: fix DAPM paths for rt1015
  (bsc#1012628).
- ASoC: qcom: sdm845: set driver name correctly (bsc#1012628).
- ASoC: cs42l51: manage mclk shutdown delay (bsc#1012628).
- ASoC: SOF: loader: handle all SOF_IPC_EXT types (bsc#1012628).
- usb: dwc3: pci: add support for the Intel Alder Lake-S
  (bsc#1012628).
- opp: Reduce the size of critical section in
  _opp_table_kref_release() (bsc#1012628).
- usb: gadget: goku_udc: fix potential crashes in probe
  (bsc#1012628).
- usb: raw-gadget: fix memory leak in gadget_setup (bsc#1012628).
- selftests/ftrace: check for do_sys_openat2 in user-memory test
  (bsc#1012628).
- selftests: pidfd: fix compilation errors due to wait.h
  (bsc#1012628).
- ALSA: hda: Separate runtime and system suspend (bsc#1012628).
- ALSA: hda: Reinstate runtime_allow() for all hda controllers
  (bsc#1012628).
- x86/boot/compressed/64: Introduce sev_status (bsc#1012628).
- gfs2: Free rd_bits later in gfs2_clear_rgrpd to fix
  use-after-free (bsc#1012628).
- gfs2: Add missing truncate_inode_pages_final for sd_aspace
  (bsc#1012628).
- gfs2: check for live vs. read-only file system in gfs2_fitrim
  (bsc#1012628).
- scsi: hpsa: Fix memory leak in hpsa_init_one() (bsc#1012628).
- drm/amdgpu: perform srbm soft reset always on SDMA resume
  (bsc#1012628).
- drm/amd/pm: correct the baco reset sequence for CI ASICs
  (bsc#1012628).
- drm/amd/pm: perform SMC reset on suspend/hibernation
  (bsc#1012628).
- drm/amd/pm: do not use ixFEATURE_STATUS for checking smc running
  (bsc#1012628).
- mac80211: fix use of skb payload instead of header
  (bsc#1012628).
- cfg80211: initialize wdev data earlier (bsc#1012628).
- cfg80211: regulatory: Fix inconsistent format argument
  (bsc#1012628).
- wireguard: selftests: check that route_me_harder packets use
  the right sk (bsc#1012628).
- tracing: Fix the checking of stackidx in __ftrace_trace_stack
  (bsc#1012628).
- Revert "nvme-pci: remove last_sq_tail" (bsc#1012628).
- ARC: [plat-hsdk] Remap CCMs super early in asm boot trampoline
  (bsc#1012628).
- scsi: scsi_dh_alua: Avoid crash during alua_bus_detach()
  (bsc#1012628).
- scsi: mpt3sas: Fix timeouts observed while reenabling IRQ
  (bsc#1012628).
- nvme: introduce nvme_sync_io_queues (bsc#1012628).
- nvme-rdma: avoid race between time out and tear down
  (bsc#1012628).
- nvme-tcp: avoid race between time out and tear down
  (bsc#1012628).
- nvme-rdma: avoid repeated request completion (bsc#1012628).
- nvme-tcp: avoid repeated request completion (bsc#1012628).
- iommu/amd: Increase interrupt remapping table limit to 512
  entries (bsc#1012628).
- s390/smp: move rcu_cpu_starting() earlier (bsc#1012628).
- vfio: platform: fix reference leak in vfio_platform_open
  (bsc#1012628).
- vfio/pci: Bypass IGD init in case of -ENODEV (bsc#1012628).
- i2c: mediatek: move dma reset before i2c reset (bsc#1012628).
- amd/amdgpu: Disable VCN DPG mode for Picasso (bsc#1012628).
- iomap: clean up writeback state logic on writepage error
  (bsc#1012628).
- selftests: proc: fix warning: _GNU_SOURCE redefined
  (bsc#1012628).
- arm64: kexec_file: try more regions if loading segments fails
  (bsc#1012628).
- riscv: Set text_offset correctly for M-Mode (bsc#1012628).
- i2c: sh_mobile: implement atomic transfers (bsc#1012628).
- i2c: designware: call i2c_dw_read_clear_intrbits_slave() once
  (bsc#1012628).
- i2c: designware: slave should do WRITE_REQUESTED before
  WRITE_RECEIVED (bsc#1012628).
- tpm_tis: Disable interrupts on ThinkPad T490s (bsc#1012628).
- mfd: sprd: Add wakeup capability for PMIC IRQ (bsc#1012628).
- pinctrl: intel: Fix 2 kOhm bias which is 833 Ohm (bsc#1012628).
- pinctrl: intel: Set default bias in case no particular value
  given (bsc#1012628).
- gpio: aspeed: fix ast2600 bank properties (bsc#1012628).
- ARM: 9019/1: kprobes: Avoid fortify_panic() when copying
  optprobe template (bsc#1012628).
- bpf: Don't rely on GCC __attribute__((optimize)) to disable GCSE
  (bsc#1012628).
- libbpf, hashmap: Fix undefined behavior in hash_bits
  (bsc#1012628).
- pinctrl: mcp23s08: Use full chunk of memory for regmap
  configuration (bsc#1012628).
- pinctrl: aspeed: Fix GPI only function problem (bsc#1012628).
- net/mlx5e: Fix modify header actions memory leak (bsc#1012628).
- net/mlx5e: Protect encap route dev from concurrent release
  (bsc#1012628).
- net/mlx5e: Use spin_lock_bh for async_icosq_lock (bsc#1012628).
- net/mlx5: Fix deletion of duplicate rules (bsc#1012628).
- net/mlx5: E-switch, Avoid extack error log for disabled vport
  (bsc#1012628).
- net/mlx5e: Fix VXLAN synchronization after function reload
  (bsc#1012628).
- net/mlx5e: Fix incorrect access of RCU-protected xdp_prog
  (bsc#1012628).
- SUNRPC: Fix general protection fault in trace_rpc_xdr_overflow()
  (bsc#1012628).
- NFSD: Fix use-after-free warning when doing inter-server copy
  (bsc#1012628).
- NFSD: fix missing refcount in nfsd4_copy by nfsd4_do_async_copy
  (bsc#1012628).
- tools/bpftool: Fix attaching flow dissector (bsc#1012628).
- bpf: Zero-fill re-used per-cpu map element (bsc#1012628).
- r8169: fix potential skb double free in an error path
  (bsc#1012628).
- r8169: disable hw csum for short packets on all chip versions
  (bsc#1012628).
- pinctrl: qcom: Move clearing pending IRQ to
  .irq_request_resources callback (bsc#1012628).
- pinctrl: qcom: sm8250: Specify PDC map (bsc#1012628).
- nbd: fix a block_device refcount leak in nbd_release
  (bsc#1012628).
- selftest: fix flower terse dump tests (bsc#1012628).
- i40e: Fix MAC address setting for a VF via Host/VM
  (bsc#1012628).
- igc: Fix returning wrong statistics (bsc#1012628).
- lan743x: correctly handle chips with internal PHY (bsc#1012628).
- net: phy: realtek: support paged operations on RTL8201CP
  (bsc#1012628).
- xfs: fix flags argument to rmap lookup when converting shared
  file rmaps (bsc#1012628).
- xfs: set the unwritten bit in rmap lookup flags in
  xchk_bmap_get_rmapextents (bsc#1012628).
- xfs: fix rmap key and record comparison functions (bsc#1012628).
- xfs: fix brainos in the refcount scrubber's rmap fragment
  processor (bsc#1012628).
- lan743x: fix "BUG: invalid wait context" when setting rx mode
  (bsc#1012628).
- xfs: fix a missing unlock on error in xfs_fs_map_blocks
  (bsc#1012628).
- of/address: Fix of_node memory leak in of_dma_is_coherent
  (bsc#1012628).
- ch_ktls: Update cheksum information (bsc#1012628).
- ch_ktls: tcb update fails sometimes (bsc#1012628).
- cosa: Add missing kfree in error path of cosa_write
  (bsc#1012628).
- hwmon: (applesmc) Re-work SMC comms (bsc#1012628).
- NFS: Fix listxattr receive buffer size (bsc#1012628).
- vrf: Fix fast path output packet handling with async Netfilter
  rules (bsc#1012628).
- lan743x: fix use of uninitialized variable (bsc#1012628).
- arm64/mm: Validate hotplug range before creating linear mapping
  (bsc#1012628).
- kernel/watchdog: fix watchdog_allowed_mask not used warning
  (bsc#1012628).
- mm: memcontrol: fix missing wakeup polling thread (bsc#1012628).
- afs: Fix afs_write_end() when called with copied == 0 [ver #3]
  (bsc#1012628).
- perf: Fix get_recursion_context() (bsc#1012628).
- nvme: factor out a nvme_configure_metadata helper (bsc#1012628).
- nvme: freeze the queue over ->lba_shift updates (bsc#1012628).
- nvme: fix incorrect behavior when BLKROSET is called by the user
  (bsc#1012628).
- perf: Simplify group_sched_in() (bsc#1012628).
- perf: Fix event multiplexing for exclusive groups (bsc#1012628).
- firmware: xilinx: fix out-of-bounds access (bsc#1012628).
- erofs: fix setting up pcluster for temporary pages
  (bsc#1012628).
- erofs: derive atime instead of leaving it empty (bsc#1012628).
- ext4: correctly report "not supported" for {usr,grp}jquota
  when !CONFIG_QUOTA (bsc#1012628).
- ext4: unlock xattr_sem properly in ext4_inline_data_truncate()
  (bsc#1012628).
- btrfs: fix potential overflow in cluster_pages_for_defrag on
  32bit arch (bsc#1012628).
- btrfs: ref-verify: fix memory leak in btrfs_ref_tree_mod
  (bsc#1012628).
- btrfs: fix min reserved size calculation in merge_reloc_root
  (bsc#1012628).
- btrfs: dev-replace: fail mount if we don't have replace item
  with target device (bsc#1012628).
- KVM: arm64: Don't hide ID registers from userspace
  (bsc#1012628).
- speakup: Fix var_id_t values and thus keymap (bsc#1012628).
- speakup ttyio: Do not schedule() in ttyio_in_nowait
  (bsc#1012628).
- speakup: Fix clearing selection in safe context (bsc#1012628).
- thunderbolt: Fix memory leak if ida_simple_get() fails in
  enumerate_services() (bsc#1012628).
- thunderbolt: Add the missed ida_simple_remove() in
  ring_request_msix() (bsc#1012628).
- uio: Fix use-after-free in uio_unregister_device()
  (bsc#1012628).
- Revert "usb: musb: convert to
  devm_platform_ioremap_resource_byname" (bsc#1012628).
- usb: cdc-acm: Add DISABLE_ECHO for Renesas USB Download mode
  (bsc#1012628).
- usb: typec: ucsi: Report power supply changes (bsc#1012628).
- xhci: hisilicon: fix refercence leak in xhci_histb_probe
  (bsc#1012628).
- virtio: virtio_console: fix DMA memory allocation for rproc
  serial (bsc#1012628).
- mei: protect mei_cl_mtu from null dereference (bsc#1012628).
- futex: Don't enable IRQs unconditionally in put_pi_state()
  (bsc#1012628).
- jbd2: fix up sparse warnings in checkpoint code (bsc#1012628).
- bootconfig: Extend the magic check range to the preceding 3
  bytes (bsc#1012628).
- mm/compaction: count pages and stop correctly during page
  isolation (bsc#1012628).
- mm/compaction: stop isolation if too many pages are isolated
  and we have pages to migrate (bsc#1012628).
- mm/slub: fix panic in slab_alloc_node() (bsc#1012628).
- mm/vmscan: fix NR_ISOLATED_FILE corruption on 64-bit
  (bsc#1012628).
- mm/gup: use unpin_user_pages() in __gup_longterm_locked()
  (bsc#1012628).
- Revert "kernel/reboot.c: convert simple_strtoul to kstrtoint"
  (bsc#1012628).
- reboot: fix overflow parsing reboot cpu number (bsc#1012628).
- hugetlbfs: fix anon huge page migration race (bsc#1012628).
- ocfs2: initialize ip_next_orphan (bsc#1012628).
- hwmon: (amd_energy) modify the visibility of the counters
  (bsc#1012628).
- selinux: Fix error return code in sel_ib_pkey_sid_slow()
  (bsc#1012628).
- io_uring: round-up cq size before comparing with rounded sq size
  (bsc#1012628).
- gpio: sifive: Fix SiFive gpio probe (bsc#1012628).
- gpio: pcie-idio-24: Fix irq mask when masking (bsc#1012628).
- gpio: pcie-idio-24: Fix IRQ Enable Register value (bsc#1012628).
- gpio: pcie-idio-24: Enable PEX8311 interrupts (bsc#1012628).
- mmc: sdhci-of-esdhc: Handle pulse width detection erratum for
  more SoCs (bsc#1012628).
- mmc: renesas_sdhi_core: Add missing tmio_mmc_host_free()
  at remove (bsc#1012628).
- don't dump the threads that had been already exiting when zapped
  (bsc#1012628).
- drm/amd/display: Add missing pflip irq (bsc#1012628).
- drm/i915: Correctly set SFC capability for video engines
  (bsc#1012628).
- drm/gma500: Fix out-of-bounds access to struct
  drm_device.vblank[] (bsc#1012628).
- NFSv4.2: fix failure to unregister shrinker (bsc#1012628).
- pinctrl: amd: use higher precision for 512 RtcClk (bsc#1012628).
- pinctrl: amd: fix incorrect way to disable debounce filter
  (bsc#1012628).
- swiotlb: fix "x86: Don't panic if can not alloc buffer for
  swiotlb" (bsc#1012628).
- cpufreq: Introduce governor flags (bsc#1012628).
- cpufreq: Introduce CPUFREQ_GOV_STRICT_TARGET (bsc#1012628).
- cpufreq: Add strict_target to struct cpufreq_policy
  (bsc#1012628).
- cpufreq: intel_pstate: Take CPUFREQ_GOV_STRICT_TARGET into
  account (bsc#1012628).
- ethtool: netlink: add missing netdev_features_change() call
  (bsc#1012628).
- IPv6: Set SIT tunnel hard_header_len to zero (bsc#1012628).
- net/af_iucv: fix null pointer dereference on shutdown
  (bsc#1012628).
- net: udp: fix IP header access and skb lookup on Fast/frag0
  UDP GRO (bsc#1012628).
- net: udp: fix UDP header access on Fast/frag0 UDP GRO
  (bsc#1012628).
- net: Update window_clamp if SOCK_RCVBUF is set (bsc#1012628).
- net/x25: Fix null-ptr-deref in x25_connect (bsc#1012628).
- tipc: fix memory leak in tipc_topsrv_start() (bsc#1012628).
- devlink: Avoid overwriting port attributes of registered port
  (bsc#1012628).
- mptcp: provide rmem[0] limit (bsc#1012628).
- tunnels: Fix off-by-one in lower MTU bounds for ICMP/ICMPv6
  replies (bsc#1012628).
- powerpc/603: Always fault when _PAGE_ACCESSED is not set
  (bsc#1012628).
- null_blk: Fix scheduling in atomic with zoned mode
  (bsc#1012628).
- perf scripting python: Avoid declaring function pointers with
  a visibility attribute (bsc#1012628).
- coresight: etm: perf: Sink selection using sysfs is deprecated
  (bsc#1012628).
- coresight: Fix uninitialised pointer bug in etm_setup_aux()
  (bsc#1012628).
- Convert trailing spaces and periods in path components
  (bsc#1012628).
- commit 21e5163
* Thu Nov 19 2020 jslaby@suse.cz
- PCI: Always enable ACS even if no ACS Capability (bsc#1178211).
- commit a40af1e
* Thu Nov 19 2020 jslaby@suse.cz
- loop: Fix occasional uevent drop (bsc#1177900).
- block: add a return value to set_capacity_revalidate_and_notify
  (bsc#1177900).
- commit 98395e1
* Wed Nov 18 2020 jslaby@suse.cz
- btrfs: qgroup: don't commit transaction when we already hold
  the handle (bsc#1178634).
  Update upstream status and take the upstream version.
- commit 5d64ed9
* Mon Nov 16 2020 mkubecek@suse.cz
- Update to 5.10-rc4
- commit ea0f69f
* Thu Nov 12 2020 jslaby@suse.cz
- btrfs: qgroup: don't commit transaction when we have already
  hold a transaction handler (bsc#1178634).
- commit 646ed4a
* Wed Nov 11 2020 jslaby@suse.cz
- spi: bcm2835: remove use of uninitialized gpio flags variable
  (git-fixes).
- tipc: fix a deadlock when flushing scheduled work (git-fixes).
- commit e800bb2
* Wed Nov 11 2020 jslaby@suse.cz
- Update
  patches.kernel.org/5.9.8-001-powercap-restrict-energy-meter-to-root-access.patch
  (bsc#1012628 bsc#1170415 CVE-2020-8694).
  Add CVE reference.
- commit 5b81a9c
* Wed Nov 11 2020 jslaby@suse.cz
- Linux 5.9.8 (bsc#1012628).
- powercap: restrict energy meter to root access (bsc#1012628).
- commit 230b512
* Wed Nov 11 2020 jslaby@suse.cz
- Linux 5.9.7 (bsc#1012628).
- perf/core: Fix a memory leak in perf_event_parse_addr_filter()
  (bsc#1012628).
- drm/i915/gt: Use the local HWSP offset during submission
  (bsc#1012628).
- drm/i915: Fix encoder lookup during PSR atomic check
  (bsc#1012628).
- PM: runtime: Resume the device earlier in
  __device_release_driver() (bsc#1012628).
- PM: runtime: Drop pm_runtime_clean_up_links() (bsc#1012628).
- PM: runtime: Drop runtime PM references to supplier on link
  removal (bsc#1012628).
- ARC: stack unwinding: avoid indefinite looping (bsc#1012628).
- drm/panfrost: Fix a deadlock between the shrinker and madvise
  path (bsc#1012628).
- mac80211: fix regression where EAPOL frames were sent in
  plaintext (bsc#1012628).
- io_uring: fix link lookup racing with link timeout
  (bsc#1012628).
- usb: mtu3: fix panic in mtu3_gadget_stop() (bsc#1012628).
- USB: Add NO_LPM quirk for Kingston flash drive (bsc#1012628).
- usb: dwc3: ep0: Fix delay status handling (bsc#1012628).
- USB: serial: option: add Telit FN980 composition 0x1055
  (bsc#1012628).
- USB: serial: option: add LE910Cx compositions 0x1203, 0x1230,
  0x1231 (bsc#1012628).
- USB: serial: option: add Quectel EC200T module support
  (bsc#1012628).
- USB: serial: cyberjack: fix write-URB completion race
  (bsc#1012628).
- serial: txx9: add missing platform_driver_unregister() on
  error in serial_txx9_init (bsc#1012628).
- serial: 8250_mtk: Fix uart_get_baud_rate warning (bsc#1012628).
- powerpc/40x: Always fault when _PAGE_ACCESSED is not set
  (bsc#1012628).
- powerpc/8xx: Always fault when _PAGE_ACCESSED is not set
  (bsc#1012628).
- s390/pkey: fix paes selftest failure with paes and pkey static
  build (bsc#1012628).
- s390/mm: make pmd/pud_deref() large page aware (bsc#1012628).
- s390/pci: fix hot-plug of PCI function missing bus
  (bsc#1012628).
- entry: Fix the incorrect ordering of lockdep and RCU check
  (bsc#1012628).
- fork: fix copy_process(CLONE_PARENT) race with the exiting
  - >real_parent (bsc#1012628).
- tty: fix crash in release_tty if tty->port is not set
  (bsc#1012628).
- tty: serial: imx: enable earlycon by default if
  IMX_SERIAL_CONSOLE is enabled (bsc#1012628).
- vt: Disable KD_FONT_OP_COPY (bsc#1012628).
- arm64/smp: Move rcu_cpu_starting() earlier (bsc#1012628).
- drm/nouveau/gem: fix "refcount_t: underflow; use-after-free"
  (bsc#1012628).
- drm/nouveau/nouveau: fix the start/end range for migration
  (bsc#1012628).
- usb: cdns3: gadget: suspicious implicit sign extension
  (bsc#1012628).
- ACPI: NFIT: Fix comparison to '-ENXIO' (bsc#1012628).
- drm/vc4: drv: Add error handding for bind (bsc#1012628).
- staging: mmal-vchiq: Fix memory leak for vchiq_instance
  (bsc#1012628).
- nvmet: fix a NULL pointer dereference when tracing the flush
  command (bsc#1012628).
- nvme-rdma: handle unexpected nvme completion data length
  (bsc#1012628).
- vsock: use ns_capable_noaudit() on socket create (bsc#1012628).
- drm/amd/display: adding ddc_gpio_vga_reg_list to ddc reg def'ns
  (bsc#1012628).
- scsi: ibmvscsi: Fix potential race after loss of transport
  (bsc#1012628).
- drm/amd/display: Fixed panic during seamless boot (bsc#1012628).
- drm/amdgpu: add DID for navi10 blockchain SKU (bsc#1012628).
- drm/amdgpu: disable DCN and VCN for navi10 blockchain SKU(v3)
  (bsc#1012628).
- scsi: core: Don't start concurrent async scan on same host
  (bsc#1012628).
- btrfs: add a helper to read the tree_root commit root for
  backref lookup (bsc#1012628).
- btrfs: drop the path before adding qgroup items when enabling
  qgroups (bsc#1012628).
- blk-cgroup: Pre-allocate tree node on blkg_conf_prep
  (bsc#1012628).
- blk-cgroup: Fix memleak on error path (bsc#1012628).
- drm/v3d: Fix double free in v3d_submit_cl_ioctl() (bsc#1012628).
- drm/sun4i: frontend: Fix the scaler phase on A33 (bsc#1012628).
- drm/sun4i: frontend: Reuse the ch0 phase for RGB formats
  (bsc#1012628).
- drm/sun4i: frontend: Rework a bit the phase data (bsc#1012628).
- ARM: dts: mmp3: Add power domain for the camera (bsc#1012628).
- of: Fix reserved-memory overlap detection (bsc#1012628).
- io_uring: don't miss setting IO_WQ_WORK_CONCURRENT
  (bsc#1012628).
- arm64: dts: amlogic: add missing ethernet reset ID
  (bsc#1012628).
- hyperv_fb: Update screen_info after removing old framebuffer
  (bsc#1012628).
- x86/kexec: Use up-to-dated screen_info copy to fill boot params
  (bsc#1012628).
- arm64: dts: amlogic: meson-g12: use the G12A specific dwmac
  compatible (bsc#1012628).
- arm64: dts: meson: add missing g12 rng clock (bsc#1012628).
- ARM: dts: sun4i-a10: fix cpu_alert temperature (bsc#1012628).
- x86/lib: Change .weak to SYM_FUNC_START_WEAK for
  arch/x86/lib/mem*_64.S (bsc#1012628).
- futex: Handle transient "ownerless" rtmutex state correctly
  (bsc#1012628).
- tracing: Fix out of bounds write in get_trace_buf (bsc#1012628).
- spi: bcm2835: fix gpio cs level inversion (bsc#1012628).
- regulator: defer probe when trying to get voltage from
  unresolved supply (bsc#1012628).
- ftrace: Handle tracing when switching between context
  (bsc#1012628).
- ftrace: Fix recursion check for NMI test (bsc#1012628).
- mtd: spi-nor: Don't copy self-pointing struct around
  (bsc#1012628).
- iommu/vt-d: Fix kernel NULL pointer dereference in find_domain()
  (bsc#1012628).
- drm/amdgpu: resolved ASD loading issue on sienna (bsc#1012628).
- drm/amdgpu: update golden setting for sienna_cichlid
  (bsc#1012628).
- ring-buffer: Fix recursion protection transitions between
  interrupt context (bsc#1012628).
- gfs2: Don't call cancel_delayed_work_sync from within delete
  work function (bsc#1012628).
- gfs2: Wake up when sd_glock_disposal becomes zero (bsc#1012628).
- perf hists browser: Increase size of 'buf' in
  perf_evsel__hists_browse() (bsc#1012628).
- mm: always have io_remap_pfn_range() set pgprot_decrypted()
  (bsc#1012628).
- kthread_worker: prevent queuing delayed work from timer_fn
  when it is being canceled (bsc#1012628).
- lib/crc32test: remove extra local_irq_disable/enable
  (bsc#1012628).
- mm: mempolicy: fix potential pte_unmap_unlock pte error
  (bsc#1012628).
- hugetlb_cgroup: fix reservation accounting (bsc#1012628).
- ALSA: usb-audio: Add implicit feedback quirk for MODX
  (bsc#1012628).
- ALSA: usb-audio: Add implicit feedback quirk for Qu-16
  (bsc#1012628).
- ALSA: usb-audio: add usb vendor id as DSD-capable for Khadas
  devices (bsc#1012628).
- ALSA: usb-audio: Add implicit feedback quirk for Zoom UAC-2
  (bsc#1012628).
- ALSA: hda/realtek - Enable headphone for ASUS TM420
  (bsc#1012628).
- ALSA: hda/realtek - Fixed HP headset Mic can't be detected
  (bsc#1012628).
- Fonts: Replace discarded const qualifier (bsc#1012628).
- drm/nouveau/kms/nv50-: Fix clock checking algorithm in
  nv50_dp_mode_valid() (bsc#1012628).
- drm/nouveau/kms/nv50-: Get rid of bogus
  nouveau_conn_mode_valid() (bsc#1012628).
- r8169: work around short packet hw bug on RTL8125 (bsc#1012628).
- net: openvswitch: silence suspicious RCU usage warning
  (bsc#1012628).
- net: dsa: qca8k: Fix port MTU setting (bsc#1012628).
- mptcp: token: fix unititialized variable (bsc#1012628).
- net: fec: fix MDIO probing for some FEC hardware blocks
  (bsc#1012628).
- ip6_tunnel: set inner ipproto before ip6_tnl_encap
  (bsc#1012628).
- sfp: Fix error handing in sfp_probe() (bsc#1012628).
- sctp: Fix COMM_LOST/CANT_STR_ASSOC err reporting on big-endian
  platforms (bsc#1012628).
- powerpc/vnic: Extend "failover pending" window (bsc#1012628).
- net: usb: qmi_wwan: add Telit LE910Cx 0x1230 composition
  (bsc#1012628).
- net: ethernet: ti: cpsw: disable PTPv1 hw timestamping
  advertisement (bsc#1012628).
- ip_tunnel: fix over-mtu packet send fail without
  TUNNEL_DONT_FRAGMENT flags (bsc#1012628).
- ionic: check port ptr before use (bsc#1012628).
- gianfar: Account for Tx PTP timestamp in the skb headroom
  (bsc#1012628).
- gianfar: Replace skb_realloc_headroom with skb_cow_head for PTP
  (bsc#1012628).
- dpaa_eth: fix the RX headroom size alignment (bsc#1012628).
- dpaa_eth: update the buffer layout for non-A050385 erratum
  scenarios (bsc#1012628).
- chelsio/chtls: fix always leaking ctrl_skb (bsc#1012628).
- chelsio/chtls: fix memory leaks caused by a race (bsc#1012628).
- cadence: force nonlinear buffers to be cloned (bsc#1012628).
- ptrace: fix task_join_group_stop() for the case when current
  is traced (bsc#1012628).
- drm/nouveau/device: fix changing endianess code to work on
  older GPUs (bsc#1012628).
- drm/nouveau/kms/nv50-: Program notifier offset before requesting
  disp caps (bsc#1012628).
- drm/i915: Restore ILK-M RPS support (bsc#1012628).
- drm/i915: Reject 90/270 degree rotated initial fbs
  (bsc#1012628).
- drm/i915: Use the active reference on the vma while capturing
  (bsc#1012628).
- drm/i915: Mark ininitial fb obj as WT on eLLC machines to
  avoid rcu lockup during fbdev init (bsc#1012628).
- drm/i915: Exclude low pages (128KiB) of stolen from use
  (bsc#1012628).
- drm/i915: Drop runtime-pm assert from vgpu io accessors
  (bsc#1012628).
- drm/i915/gt: Delay execlist processing for tgl (bsc#1012628).
- drm/i915/gt: Undo forced context restores after trivial
  preemptions (bsc#1012628).
- drm/i915/gt: Initialize reserved and unspecified MOCS indices
  (bsc#1012628).
- drm/i915: Fix TGL DKL PHY DP vswing handling (bsc#1012628).
- drm/i915: Avoid mixing integer types during batch copies
  (bsc#1012628).
- drm/i915: Cancel outstanding work after disabling heartbeats
  on an engine (bsc#1012628).
- drm/i915: Break up error capture compression loops with
  cond_resched() (bsc#1012628).
- drm/i915/gt: Always send a pulse down the engine after disabling
  heartbeat (bsc#1012628).
- drm/i915/gem: Always test execution status on closing the
  context (bsc#1012628).
- drm/i915/gem: Prevent using pgprot_writecombine() if PAT is
  not supported (bsc#1012628).
- drm/i915/gem: Avoid implicit vmap for highmem on x86-32
  (bsc#1012628).
- tipc: fix use-after-free in tipc_bcast_get_mode (bsc#1012628).
- net: core: use list_del_init() instead of list_del() in
  netdev_run_todo() (bsc#1012628).
- commit 35036d7
* Tue Nov 10 2020 dmueller@suse.com
- ARM64: Enable CONFIG_ARM64_SW_TTBR0_PAN
  This can help prevent use-after-free bugs becoming an exploitable
  privilege escalation by ensuring that magic values (such as LIST_POISON)
  will always fault when dereferenced
- commit 5a3f5b3
* Mon Nov  9 2020 mkubecek@suse.cz
- Update to 5.10-rc3
- eliminated 1 patch
  - patches.suse/tty-make-FONTX-ioctl-use-the-tty-pointer-they-were-a.patch
- refresh configs
  - update headers after Factory binutils update
  - drop options no longer available
- commit e72caa5
* Thu Nov  5 2020 jslaby@suse.cz
- Linux 5.9.6 (bsc#1012628).
- ASOC: SOF: Intel: hda-codec: move unused label to correct
  position (bsc#1012628).
- commit fc52788
* Thu Nov  5 2020 jslaby@suse.cz
- Linux 5.9.5 (bsc#1012628).
- xen/events: avoid removing an event channel while handling it
  (bsc#1012628).
- xen/events: add a proper barrier to 2-level uevent unmasking
  (bsc#1012628).
- xen/events: fix race in evtchn_fifo_unmask() (bsc#1012628).
- xen/events: add a new "late EOI" evtchn framework (bsc#1012628).
- xen/blkback: use lateeoi irq binding (bsc#1012628).
- xen/netback: use lateeoi irq binding (bsc#1012628).
- xen/scsiback: use lateeoi irq binding (bsc#1012628).
- xen/pvcallsback: use lateeoi irq binding (bsc#1012628).
- xen/pciback: use lateeoi irq binding (bsc#1012628).
- xen/events: switch user event channels to lateeoi model
  (bsc#1012628).
- xen/events: use a common cpu hotplug hook for event channels
  (bsc#1012628).
- xen/events: defer eoi in case of excessive number of events
  (bsc#1012628).
- xen/events: block rogue events for some time (bsc#1012628).
- firmware: arm_scmi: Fix ARCH_COLD_RESET (bsc#1012628).
- firmware: arm_scmi: Expand SMC/HVC message pool to more than
  one (bsc#1012628).
- tee: client UUID: Skip REE kernel login method as well
  (bsc#1012628).
- firmware: arm_scmi: Add missing Rx size re-initialisation
  (bsc#1012628).
- firmware: arm_scmi: Fix locking in notifications (bsc#1012628).
- firmware: arm_scmi: Fix duplicate workqueue name (bsc#1012628).
- x86/alternative: Don't call text_poke() in lazy TLB mode
  (bsc#1012628).
- ionic: no rx flush in deinit (bsc#1012628).
- RDMA/mlx5: Fix devlink deadlock on net namespace deletion
  (bsc#1012628).
- mlxsw: core: Fix use-after-free in mlxsw_emad_trans_finish()
  (bsc#1012628).
- afs: Fix a use after free in afs_xattr_get_acl() (bsc#1012628).
- afs: Fix afs_launder_page to not clear PG_writeback
  (bsc#1012628).
- RDMA/qedr: Fix memory leak in iWARP CM (bsc#1012628).
- ata: sata_nv: Fix retrieving of active qcs (bsc#1012628).
- arm64: efi: increase EFI PE/COFF header padding to 64 KB
  (bsc#1012628).
- afs: Fix to take ref on page when PG_private is set
  (bsc#1012628).
- afs: Fix page leak on afs_write_begin() failure (bsc#1012628).
- afs: Fix where page->private is set during write (bsc#1012628).
- afs: Wrap page->private manipulations in inline functions
  (bsc#1012628).
- afs: Alter dirty range encoding in page->private (bsc#1012628).
- afs: Fix afs_invalidatepage to adjust the dirty region
  (bsc#1012628).
- afs: Fix dirty-region encoding on ppc32 with 64K pages
  (bsc#1012628).
- vdpasim: fix MAC address configuration (bsc#1012628).
- interconnect: qcom: sdm845: Enable keepalive for the MM1 BCM
  (bsc#1012628).
- lockdep: Fix preemption WARN for spurious IRQ-enable
  (bsc#1012628).
- usb: host: ehci-tegra: Fix error handling in tegra_ehci_probe()
  (bsc#1012628).
- futex: Fix incorrect should_fail_futex() handling (bsc#1012628).
- powerpc/vmemmap: Fix memory leak with vmemmap list allocation
  failures (bsc#1012628).
- powerpc/powernv/smp: Fix spurious DBG() warning (bsc#1012628).
- RDMA/core: Change how failing destroy is handled during uobj
  abort (bsc#1012628).
- f2fs: allocate proper size memory for zstd decompress
  (bsc#1012628).
- powerpc/watchpoint/ptrace: Fix SETHWDEBUG when
  CONFIG_HAVE_HW_BREAKPOINT=N (bsc#1012628).
- mm: fix exec activate_mm vs TLB shootdown and lazy tlb switching
  race (bsc#1012628).
- powerpc: select ARCH_WANT_IRQS_OFF_ACTIVATE_MM (bsc#1012628).
- sparc64: remove mm_cpumask clearing to fix kthread_use_mm race
  (bsc#1012628).
- f2fs: add trace exit in exception path (bsc#1012628).
- f2fs: do sanity check on zoned block device path (bsc#1012628).
- f2fs: fix uninit-value in f2fs_lookup (bsc#1012628).
- f2fs: fix to check segment boundary during SIT page readahead
  (bsc#1012628).
- s390/startup: avoid save_area_sync overflow (bsc#1012628).
- f2fs: compress: fix to disallow enabling compress on non-empty
  file (bsc#1012628).
- s390/ap/zcrypt: revisit ap and zcrypt error handling
  (bsc#1012628).
- um: change sigio_spinlock to a mutex (bsc#1012628).
- f2fs: handle errors of f2fs_get_meta_page_nofail (bsc#1012628).
- afs: Don't assert on unpurgeable server records (bsc#1012628).
- powerpc/64s: handle ISA v3.1 local copy-paste context switches
  (bsc#1012628).
- ARM: 8997/2: hw_breakpoint: Handle inexact watchpoint addresses
  (bsc#1012628).
- NFS4: Fix oops when copy_file_range is attempted with NFS4.0
  source (bsc#1012628).
- xfs: Set xfs_buf type flag when growing summary/bitmap files
  (bsc#1012628).
- xfs: Set xfs_buf's b_ops member when zeroing bitmap/summary
  files (bsc#1012628).
- xfs: log new intent items created as part of finishing recovered
  intent items (bsc#1012628).
- power: supply: bq27xxx: report "not charging" on all types
  (bsc#1012628).
- xfs: change the order in which child and parent defer ops are
  finished (bsc#1012628).
- xfs: fix realtime bitmap/summary file truncation when growing
  rt volume (bsc#1012628).
- io_uring: don't set COMP_LOCKED if won't put (bsc#1012628).
- ath10k: fix retry packets update in station dump (bsc#1012628).
- x86/kaslr: Initialize mem_limit to the real maximum address
  (bsc#1012628).
- drm/ast: Separate DRM driver from PCI code (bsc#1012628).
- drm/amdgpu: restore ras flags when user resets eeprom(v2)
  (bsc#1012628).
- video: fbdev: pvr2fb: initialize variables (bsc#1012628).
- ath10k: start recovery process when payload length exceeds
  max htc length for sdio (bsc#1012628).
- ath10k: fix VHT NSS calculation when STBC is enabled
  (bsc#1012628).
- drm/scheduler: Scheduler priority fixes (v2) (bsc#1012628).
- drm/brige/megachips: Add checking if ge_b850v3_lvds_init()
  is working correctly (bsc#1012628).
- ASoC: SOF: fix a runtime pm issue in SOF when HDMI codec
  doesn't work (bsc#1012628).
- selftests/x86/fsgsbase: Reap a forgotten child (bsc#1012628).
- drm/bridge_connector: Set default status connected for eDP
  connectors (bsc#1012628).
- media: videodev2.h: RGB BT2020 and HSV are always full range
  (bsc#1012628).
- ASoC: AMD: Clean kernel log from deferred probe error messages
  (bsc#1012628).
- misc: fastrpc: fix common struct sg_table related issues
  (bsc#1012628).
- staging: wfx: fix potential use before init (bsc#1012628).
- media: platform: Improve queue set up flow for bug fixing
  (bsc#1012628).
- usb: typec: tcpm: During PR_SWAP, source caps should be sent
  only after tSwapSourceStart (bsc#1012628).
- media: tw5864: check status of tw5864_frameinterval_get
  (bsc#1012628).
- drm/vkms: avoid warning in vkms_get_vblank_timestamp
  (bsc#1012628).
- media: imx274: fix frame interval handling (bsc#1012628).
- mmc: via-sdmmc: Fix data race bug (bsc#1012628).
- drm/bridge/synopsys: dsi: add support for non-continuous HS
  clock (bsc#1012628).
- brcmfmac: increase F2 watermark for BCM4329 (bsc#1012628).
- arm64: topology: Stop using MPIDR for topology information
  (bsc#1012628).
- printk: reduce LOG_BUF_SHIFT range for H8300 (bsc#1012628).
- ia64: kprobes: Use generic kretprobe trampoline handler
  (bsc#1012628).
- selftests/powerpc: Make using_hash_mmu() work on Cell & PowerMac
  (bsc#1012628).
- kgdb: Make "kgdbcon" work properly with "kgdb_earlycon"
  (bsc#1012628).
- bpf: Permit map_ptr arithmetic with opcode add and offset 0
  (bsc#1012628).
- drm: exynos: fix common struct sg_table related issues
  (bsc#1012628).
- xen: gntdev: fix common struct sg_table related issues
  (bsc#1012628).
- drm: lima: fix common struct sg_table related issues
  (bsc#1012628).
- drm: panfrost: fix common struct sg_table related issues
  (bsc#1012628).
- media: uvcvideo: Fix dereference of out-of-bound list iterator
  (bsc#1012628).
- nfc: s3fwrn5: Add missing CRYPTO_HASH dependency (bsc#1012628).
- selftests/bpf: Define string const as global for
  test_sysctl_prog.c (bsc#1012628).
- selinux: access policycaps with READ_ONCE/WRITE_ONCE
  (bsc#1012628).
- samples/bpf: Fix possible deadlock in xdpsock (bsc#1012628).
- drm/amd/display: Check clock table return (bsc#1012628).
- riscv: Define AT_VECTOR_SIZE_ARCH for ARCH_DLINFO (bsc#1012628).
- cpufreq: sti-cpufreq: add stih418 support (bsc#1012628).
- USB: adutux: fix debugging (bsc#1012628).
- uio: free uio id after uio file node is freed (bsc#1012628).
- coresight: Make sysfs functional on topologies with per core
  sink (bsc#1012628).
- drm/amdgpu: No sysfs, not an error condition (bsc#1012628).
- mac80211: add missing queue/hash initialization to 802.3 xmit
  (bsc#1012628).
- usb: xhci: omit duplicate actions when suspending a runtime
  suspended host (bsc#1012628).
- SUNRPC: Mitigate cond_resched() in xprt_transmit()
  (bsc#1012628).
- cpuidle: tegra: Correctly handle result of
  arm_cpuidle_simple_enter() (bsc#1012628).
- arm64/mm: return cpu_all_mask when node is NUMA_NO_NODE
  (bsc#1012628).
- can: flexcan: disable clocks during stop mode (bsc#1012628).
- habanalabs: remove security from ARB_MST_QUIET register
  (bsc#1012628).
- xfs: don't free rt blocks when we're doing a REMAP bunmapi call
  (bsc#1012628).
- xfs: avoid LR buffer overrun due to crafted h_len (bsc#1012628).
- ACPI: Add out of bounds and numa_off protections to
  pxm_to_node() (bsc#1012628).
- octeontx2-af: fix LD CUSTOM LTYPE aliasing (bsc#1012628).
- brcmfmac: Fix warning message after dongle setup failed
  (bsc#1012628).
- ath11k: Use GFP_ATOMIC instead of GFP_KERNEL in
  ath11k_dp_htt_get_ppdu_desc (bsc#1012628).
- ath11k: fix warning caused by lockdep_assert_held (bsc#1012628).
- ath11k: change to disable softirqs for ath11k_regd_update to
  solve deadlock (bsc#1012628).
- drivers/net/wan/hdlc_fr: Correctly handle special skb->protocol
  values (bsc#1012628).
- usb: dwc3: core: do not queue work if dr_mode is not
  USB_DR_MODE_OTG (bsc#1012628).
- bus: mhi: core: Abort suspends due to outgoing pending packets
  (bsc#1012628).
- bus/fsl_mc: Do not rely on caller to provide non NULL mc_io
  (bsc#1012628).
- ACPI: HMAT: Fix handling of changes from ACPI 6.2 to ACPI 6.3
  (bsc#1012628).
- power: supply: test_power: add missing newlines when printing
  parameters by sysfs (bsc#1012628).
- drm/amd/display: HDMI remote sink need mode validation for Linux
  (bsc#1012628).
- drm/amd/display: Avoid set zero in the requested clk
  (bsc#1012628).
- ARC: [dts] fix the errors detected by dtbs_check (bsc#1012628).
- block: Consider only dispatched requests for inflight statistic
  (bsc#1012628).
- btrfs: fix replace of seed device (bsc#1012628).
- md/bitmap: md_bitmap_get_counter returns wrong blocks
  (bsc#1012628).
- f2fs: fix to set SBI_NEED_FSCK flag for inconsistent inode
  (bsc#1012628).
- bnxt_en: Log unknown link speed appropriately (bsc#1012628).
- rpmsg: glink: Use complete_all for open states (bsc#1012628).
- PCI/ACPI: Add Ampere Altra SOC MCFG quirk (bsc#1012628).
- clk: ti: clockdomain: fix static checker warning (bsc#1012628).
- nfsd: rename delegation related tracepoints to make them less
  confusing (bsc#1012628).
- nfsd4: remove check_conflicting_opens warning (bsc#1012628).
- net: 9p: initialize sun_server.sun_path to have addr's value
  only when addr is valid (bsc#1012628).
- ceph: encode inodes' parent/d_name in cap reconnect message
  (bsc#1012628).
- drivers: watchdog: rdc321x_wdt: Fix race condition bugs
  (bsc#1012628).
- jbd2: avoid transaction reuse after reformatting (bsc#1012628).
- ext4: Detect already used quota file early (bsc#1012628).
- KVM: PPC: Book3S HV: Do not allocate HPT for a nested guest
  (bsc#1012628).
- scsi: core: Clean up allocation and freeing of sgtables
  (bsc#1012628).
- gfs2: call truncate_inode_pages_final for address space glocks
  (bsc#1012628).
- gfs2: Fix NULL pointer dereference in gfs2_rgrp_dump
  (bsc#1012628).
- gfs2: use-after-free in sysfs deregistration (bsc#1012628).
- gfs2: add validation checks for size of superblock
  (bsc#1012628).
- Handle STATUS_IO_TIMEOUT gracefully (bsc#1012628).
- cifs: handle -EINTR in cifs_setattr (bsc#1012628).
- arm64: dts: renesas: ulcb: add full-pwr-cycle-in-suspend into
  eMMC nodes (bsc#1012628).
- ARM: dts: omap4: Fix sgx clock rate for 4430 (bsc#1012628).
- memory: emif: Remove bogus debugfs error handling (bsc#1012628).
- ARM: dts: s5pv210: Enable audio on Aries boards (bsc#1012628).
- ARM: dts: s5pv210: remove DMA controller bus node name to fix
  dtschema warnings (bsc#1012628).
- ARM: dts: s5pv210: move fixed clocks under root node
  (bsc#1012628).
- ARM: dts: s5pv210: move PMU node out of clock controller
  (bsc#1012628).
- ARM: dts: s5pv210: remove dedicated 'audio-subsystem' node
  (bsc#1012628).
- ARM: dts: s5pv210: add RTC 32 KHz clock in Aries family
  (bsc#1012628).
- ARM: dts: s5pv210: align SPI GPIO node name with dtschema in
  Aries (bsc#1012628).
- soc: qcom: rpmh-rsc: Sleep waiting for tcs slots to be free
  (bsc#1012628).
- soc: ti: k3: ringacc: add am65x sr2.0 support (bsc#1012628).
- bindings: soc: ti: soc: ringacc: remove ti,dma-ring-reset-quirk
  (bsc#1012628).
- firmware: arm_scmi: Move scmi bus init and exit calls into
  the driver (bsc#1012628).
- arm64: dts: qcom: kitakami: Temporarily disable SDHCI1
  (bsc#1012628).
- nbd: make the config put is called before the notifying the
  waiter (bsc#1012628).
- sgl_alloc_order: fix memory leak (bsc#1012628).
- nvme-rdma: fix crash when connect rejected (bsc#1012628).
- vmlinux.lds.h: Add PGO and AutoFDO input sections (bsc#1012628).
- irqchip/loongson-htvec: Fix initial interrupt clearing
  (bsc#1012628).
- md: fix the checking of wrong work queue (bsc#1012628).
- md/raid5: fix oops during stripe resizing (bsc#1012628).
- mmc: sdhci: Add LTR support for some Intel BYT based controllers
  (bsc#1012628).
- mmc: sdhci-acpi: AMDI0040: Set SDHCI_QUIRK2_PRESET_VALUE_BROKEN
  (bsc#1012628).
- mm: memcg/slab: uncharge during kmem_cache_free_bulk()
  (bsc#1012628).
- seccomp: Make duplicate listener detection non-racy
  (bsc#1012628).
- selftests/x86/fsgsbase: Test PTRACE_PEEKUSER for GSBASE with
  invalid LDT GS (bsc#1012628).
- perf/x86/intel: Fix Ice Lake event constraint table
  (bsc#1012628).
- perf/x86/amd: Fix sampling Large Increment per Cycle events
  (bsc#1012628).
- perf/amd/uncore: Set all slices and threads to restore perf
  stat -a behaviour (bsc#1012628).
- perf/x86/amd/ibs: Don't include randomized bits in
  get_ibs_op_count() (bsc#1012628).
- perf/x86/amd/ibs: Fix raw sample data accumulation
  (bsc#1012628).
- spi: spi-mtk-nor: fix timeout calculation overflow
  (bsc#1012628).
- spi: sprd: Release DMA channel also on probe deferral
  (bsc#1012628).
- extcon: ptn5150: Fix usage of atomic GPIO with sleeping GPIO
  chips (bsc#1012628).
- leds: bcm6328, bcm6358: use devres LED registering function
  (bsc#1012628).
- hwmon: (pmbus/max34440) Fix OC fault limits (bsc#1012628).
- media: uvcvideo: Fix uvc_ctrl_fixup_xu_info() not having any
  effect (bsc#1012628).
- fs: Don't invalidate page buffers in block_write_full_page()
  (bsc#1012628).
- ACPI: configfs: Add missing config_item_put() to fix refcount
  leak (bsc#1012628).
- NFS: fix nfs_path in case of a rename retry (bsc#1012628).
- ACPI: button: fix handling lid state changes when input device
  closed (bsc#1012628).
- ACPI / extlog: Check for RDMSR failure (bsc#1012628).
- ACPI: video: use ACPI backlight for HP 635 Notebook
  (bsc#1012628).
- ACPI: debug: don't allow debugging when ACPI is disabled
  (bsc#1012628).
- PCI/ACPI: Whitelist hotplug ports for D3 if power managed by
  ACPI (bsc#1012628).
- ACPI: EC: PM: Flush EC work unconditionally after wakeup
  (bsc#1012628).
- ACPI: EC: PM: Drop ec_no_wakeup check from
  acpi_ec_dispatch_gpe() (bsc#1012628).
- acpi-cpufreq: Honor _PSD table setting on new AMD CPUs
  (bsc#1012628).
- io-wq: assign NUMA node locality if appropriate (bsc#1012628).
- w1: mxc_w1: Fix timeout resolution problem leading to bus error
  (bsc#1012628).
- fs/kernel_read_file: Remove FIRMWARE_PREALLOC_BUFFER enum
  (bsc#1012628).
- scsi: mptfusion: Fix null pointer dereferences in
  mptscsih_remove() (bsc#1012628).
- scsi: qla2xxx: Fix MPI reset needed message (bsc#1012628).
- scsi: qla2xxx: Fix reset of MPI firmware (bsc#1012628).
- scsi: qla2xxx: Fix crash on session cleanup with unload
  (bsc#1012628).
- PM: runtime: Remove link state checks in rpm_get/put_supplier()
  (bsc#1012628).
- btrfs: qgroup: fix wrong qgroup metadata reserve for delayed
  inode (bsc#1012628).
- btrfs: improve device scanning messages (bsc#1012628).
- btrfs: qgroup: fix qgroup meta rsv leak for subvolume operations
  (bsc#1012628).
- btrfs: sysfs: init devices outside of the chunk_mutex
  (bsc#1012628).
- btrfs: tracepoints: output proper root owner for
  trace_find_free_extent() (bsc#1012628).
- btrfs: reschedule if necessary when logging directory items
  (bsc#1012628).
- btrfs: send, orphanize first all conflicting inodes when
  processing references (bsc#1012628).
- btrfs: send, recompute reference path after orphanization of
  a directory (bsc#1012628).
- btrfs: use kvzalloc() to allocate clone_roots in
  btrfs_ioctl_send() (bsc#1012628).
- btrfs: tree-checker: fix false alert caused by legacy btrfs
  root item (bsc#1012628).
- btrfs: reschedule when cloning lots of extents (bsc#1012628).
- btrfs: cleanup cow block on error (bsc#1012628).
- btrfs: skip devices without magic signature when mounting
  (bsc#1012628).
- btrfs: tree-checker: validate number of chunk stripes and parity
  (bsc#1012628).
- btrfs: fix use-after-free on readahead extent after failure
  to create it (bsc#1012628).
- btrfs: fix readahead hang and use-after-free after removing
  a device (bsc#1012628).
- btrfs: drop the path before adding block group sysfs files
  (bsc#1012628).
- usb: xhci: Workaround for S3 issue on AMD SNPS 3.0 xHC
  (bsc#1012628).
- usb: dwc3: pci: Allow Elkhart Lake to utilize DSM method for
  PM functionality (bsc#1012628).
- usb: dwc3: ep0: Fix ZLP for OUT ep0 requests (bsc#1012628).
- usb: dwc3: gadget: Check MPS of the request length
  (bsc#1012628).
- usb: dwc3: gadget: Reclaim extra TRBs after request completion
  (bsc#1012628).
- usb: dwc3: core: add phy cleanup for probe error handling
  (bsc#1012628).
- usb: dwc3: core: don't trigger runtime pm when remove driver
  (bsc#1012628).
- usb: dwc3: gadget: Resume pending requests after CLEAR_STALL
  (bsc#1012628).
- usb: dwc3: gadget: END_TRANSFER before CLEAR_STALL command
  (bsc#1012628).
- usb: cdns3: Fix on-chip memory overflow issue (bsc#1012628).
- usb: cdc-acm: fix cooldown mechanism (bsc#1012628).
- usb: typec: tcpm: reset hard_reset_count for any disconnect
  (bsc#1012628).
- usb: host: fsl-mph-dr-of: check return of dma_set_mask()
  (bsc#1012628).
- usbcore: Check both id_table and match() when both available
  (bsc#1012628).
- USB: apple-mfi-fastcharge: don't probe unhandled devices
  (bsc#1012628).
- drm/i915: Force VT'd workarounds when running as a guest OS
  (bsc#1012628).
- HID: wacom: Avoid entering wacom_wac_pen_report for pad /
  battery (bsc#1012628).
- tty: serial: 21285: fix lockup on open (bsc#1012628).
- tty: serial: fsl_lpuart: LS1021A has a FIFO size of 16 words,
  like LS1028A (bsc#1012628).
- tracing: Fix race in trace_open and buffer resize call
  (bsc#1012628).
- Revert "vhost-vdpa: fix page pinning leakage in error path"
  (bsc#1012628).
- powerpc: Fix random segfault when freeing hugetlb range
  (bsc#1012628).
- udf: Fix memory leak when mounting (bsc#1012628).
- dmaengine: dma-jz4780: Fix race in jz4780_dma_tx_status
  (bsc#1012628).
- vdpa_sim: Fix DMA mask (bsc#1012628).
- drm/shme-helpers: Fix dma_buf_mmap forwarding bug (bsc#1012628).
- iio: ltc2983: Fix of_node refcounting (bsc#1012628).
- iio: adc: at91-sama5d2_adc: fix DMA conversion crash
  (bsc#1012628).
- iio:imu:inv_mpu6050 Fix dma and ts alignment and data leak
  issues (bsc#1012628).
- iio:imu:st_lsm6dsx: check st_lsm6dsx_shub_read_output return
  (bsc#1012628).
- iio:light:si1145: Fix timestamp alignment and prevent data leak
  (bsc#1012628).
- iio: adc: gyroadc: fix leak of device node iterator
  (bsc#1012628).
- iio: ad7292: Fix of_node refcounting (bsc#1012628).
- iio:adc:ti-adc0832 Fix alignment issue with timestamp
  (bsc#1012628).
- iio:adc:ti-adc12138 Fix alignment issue with timestamp
  (bsc#1012628).
- iio:imu:st_lsm6dsx Fix alignment and data leak issues
  (bsc#1012628).
- iio:gyro:itg3200: Fix timestamp alignment and prevent data leak
  (bsc#1012628).
- powerpc/drmem: Make lmb_size 64 bit (bsc#1012628).
- rcu-tasks: Fix grace-period/unlock race in RCU Tasks Trace
  (bsc#1012628).
- rcu-tasks: Fix low-probability task_struct leak (bsc#1012628).
- rcu-tasks: Enclose task-list scan in rcu_read_lock()
  (bsc#1012628).
- MIPS: DEC: Restore bootmem reservation for firmware working
  memory area (bsc#1012628).
- MIPS: configs: lb60: Fix defconfig not selecting correct board
  (bsc#1012628).
- s390/stp: add locking to sysfs functions (bsc#1012628).
- powerpc/rtas: Restrict RTAS requests from userspace
  (bsc#1012628).
- powerpc: Warn about use of smt_snooze_delay (bsc#1012628).
- powerpc/memhotplug: Make lmb size 64bit (bsc#1012628).
- powerpc/powernv/elog: Fix race while processing OPAL error
  log event (bsc#1012628).
- powerpc/powermac: Fix low_sleep_handler with KUAP and KUEP
  (bsc#1012628).
- powerpc/mce: Avoid nmi_enter/exit in real mode on pseries hash
  (bsc#1012628).
- powerpc: Fix undetected data corruption with P9N DD2.1 VSX CI
  load emulation (bsc#1012628).
- powerpc/32: Fix vmap stack - Do not activate MMU before reading
  task struct (bsc#1012628).
- powerpc/32: Fix vmap stack - Properly set r1 before activating
  MMU (bsc#1012628).
- block: advance iov_iter on bio_add_hw_page failure
  (bsc#1012628).
- io_uring: use type appropriate io_kiocb handler for double poll
  (bsc#1012628).
- remoteproc: Fixup coredump debugfs disable request
  (bsc#1012628).
- gfs2: Make sure we don't miss any delayed withdraws
  (bsc#1012628).
- gfs2: Only access gl_delete for iopen glocks (bsc#1012628).
- NFSv4: Wait for stateid updates after CLOSE/OPEN_DOWNGRADE
  (bsc#1012628).
- NFSv4.2: support EXCHGID4_FLAG_SUPP_FENCE_OPS 4.2 EXCHANGE_ID
  flag (bsc#1012628).
- NFSD: Add missing NFSv2 .pc_func methods (bsc#1012628).
- ubifs: dent: Fix some potential memory leaks while iterating
  entries (bsc#1012628).
- ubifs: xattr: Fix some potential memory leaks while iterating
  entries (bsc#1012628).
- ubifs: journal: Make sure to not dirty twice for auth nodes
  (bsc#1012628).
- ubifs: Fix a memleak after dumping authentication mount options
  (bsc#1012628).
- ubifs: Don't parse authentication mount options in remount
  process (bsc#1012628).
- ubifs: mount_ubifs: Release authentication resource in error
  handling path (bsc#1012628).
- perf vendor events amd: Add L2 Prefetch events for zen1
  (bsc#1012628).
- perf python scripting: Fix printable strings in python3 scripts
  (bsc#1012628).
- ARC: perf: redo the pct irq missing in device-tree handling
  (bsc#1012628).
- ubi: check kthread_should_stop() after the setting of task state
  (bsc#1012628).
- ia64: fix build error with !COREDUMP (bsc#1012628).
- rtc: rx8010: don't modify the global rtc ops (bsc#1012628).
- i2c: imx: Fix external abort on interrupt in exit paths
  (bsc#1012628).
- drm/amdgpu: don't map BO in reserved region (bsc#1012628).
- drm/amd/display: Fix incorrect backlight register offset for
  DCN (bsc#1012628).
- drm/amd/display: Increase timeout for DP Disable (bsc#1012628).
- drm/amdgpu: vcn and jpeg ring synchronization (bsc#1012628).
- drm/amdgpu: update golden setting for sienna_cichlid
  (bsc#1012628).
- drm/amdgpu: correct the gpu reset handling for job != NULL case
  (bsc#1012628).
- drm/amdkfd: Use same SQ prefetch setting as amdgpu
  (bsc#1012628).
- drm/amd/display: Avoid MST manager resource leak (bsc#1012628).
- drm/amdgpu: add function to program pbb mode for sienna cichlid
  (bsc#1012628).
- drm/amdgpu: increase the reserved VM size to 2MB (bsc#1012628).
- ceph: promote to unsigned long long before shifting
  (bsc#1012628).
- libceph: clear con->out_msg on Policy::stateful_server faults
  (bsc#1012628).
- 9P: Cast to loff_t before multiplying (bsc#1012628).
- net/sunrpc: Fix return value for sysctl sunrpc.transports
  (bsc#1012628).
- PCI: qcom: Make sure PCIe is reset before init for rev 2.1.0
  (bsc#1012628).
- ring-buffer: Return 0 on success from ring_buffer_resize()
  (bsc#1012628).
- intel_idle: Ignore _CST if control cannot be taken from the
  platform (bsc#1012628).
- intel_idle: Fix max_cstate for processor models without C-state
  tables (bsc#1012628).
- cpufreq: Avoid configuring old governors as default with
  intel_pstate (bsc#1012628).
- cpufreq: Introduce CPUFREQ_NEED_UPDATE_LIMITS driver flag
  (bsc#1012628).
- cpufreq: intel_pstate: Avoid missing HWP max updates in passive
  mode (bsc#1012628).
- vringh: fix __vringh_iov() when riov and wiov are different
  (bsc#1012628).
- ext4: fix leaking sysfs kobject after failed mount
  (bsc#1012628).
- ext4: fix error handling code in add_new_gdb (bsc#1012628).
- ext4: implement swap_activate aops using iomap (bsc#1012628).
- ext4: fix invalid inode checksum (bsc#1012628).
- ext4: clear buffer verified flag if read meta block from disk
  (bsc#1012628).
- ext4: fix bdev write error check failed when mount fs with ro
  (bsc#1012628).
- ext4: fix bs < ps issue reported with dioread_nolock mount opt
  (bsc#1012628).
- ext4: do not use extent after put_bh (bsc#1012628).
- drm/ttm: fix eviction valuable range check (bsc#1012628).
- mmc: sdhci-of-esdhc: make sure delay chain locked for HS400
  (bsc#1012628).
- mmc: sdhci-of-esdhc: set timeout to max before tuning
  (bsc#1012628).
- mmc: sdhci: Use Auto CMD Auto Select only when v4_mode is true
  (bsc#1012628).
- memory: tegra: Remove GPU from DRM IOMMU group (bsc#1012628).
- memory: brcmstb_dpfe: Fix memory leak (bsc#1012628).
- futex: Adjust absolute futex timeouts with per time namespace
  offset (bsc#1012628).
- drm/amdgpu/swsmu: drop smu i2c bus on navi1x (bsc#1012628).
- drm/amd/pm: increase mclk switch threshold to 200 us
  (bsc#1012628).
- drm/amd/pm: fix pp_dpm_fclk (bsc#1012628).
- drm/amd/swsmu: add missing feature map for sienna_cichlid
  (bsc#1012628).
- drm/amd/psp: Fix sysfs: cannot create duplicate filename
  (bsc#1012628).
- drm/amdgpu: correct the cu and rb info for sienna cichlid
  (bsc#1012628).
- arm64: berlin: Select DW_APB_TIMER_OF (bsc#1012628).
- cachefiles: Handle readpage error correctly (bsc#1012628).
- hil/parisc: Disable HIL driver when it gets stuck (bsc#1012628).
- arm: dts: mt7623: add missing pause for switchport
  (bsc#1012628).
- ARM: aspeed: g5: Do not set sirq polarity (bsc#1012628).
- ARM: dts: s5pv210: fix pinctrl property of "vibrator-en"
  regulator in Aries (bsc#1012628).
- ARM: config: aspeed: Fix selection of media drivers
  (bsc#1012628).
- ARM: samsung: fix PM debug build with DEBUG_LL but !MMU
  (bsc#1012628).
- ARM: s3c24xx: fix missing system reset (bsc#1012628).
- arm64: Change .weak to SYM_FUNC_START_WEAK_PI for
  arch/arm64/lib/mem*.S (bsc#1012628).
- arm64: dts: marvell: espressobin: Add ethernet switch aliases
  (bsc#1012628).
- null_blk: synchronization fix for zoned device (bsc#1012628).
- coresight: cti: Initialize dynamic sysfs attributes
  (bsc#1012628).
- device property: Keep secondary firmware node secondary by type
  (bsc#1012628).
- device property: Don't clear secondary pointer for shared
  primary firmware node (bsc#1012628).
- KVM: arm64: Fix AArch32 handling of DBGD{CCINT,SCRext} and
  DBGVCR (bsc#1012628).
- stop_machine, rcu: Mark functions as notrace (bsc#1012628).
- staging: fieldbus: anybuss: jump to correct label in an error
  path (bsc#1012628).
- staging: comedi: cb_pcidas: Allow 2-channel commands for AO
  subdevice (bsc#1012628).
- staging: octeon: repair "fixed-link" support (bsc#1012628).
- staging: octeon: Drop on uncorrectable alignment or FCS error
  (bsc#1012628).
- cpufreq: Introduce cpufreq_driver_test_flags() (bsc#1012628).
- cpufreq: schedutil: Always call driver if
  CPUFREQ_NEED_UPDATE_LIMITS is set (bsc#1012628).
- vhost_vdpa: Return -EFAULT if copy_from_user() fails
  (bsc#1012628).
- vdpa/mlx5: Fix error return in map_direct_mr() (bsc#1012628).
- time: Prevent undefined behaviour in timespec64_to_ns()
  (bsc#1012628).
- time/sched_clock: Mark sched_clock_read_begin/retry() as notrace
  (bsc#1012628).
- null_blk: Fix zone reset all tracing (bsc#1012628).
- null_blk: Fix locking in zoned mode (bsc#1012628).
- Refresh
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch.
- Update config files.
- commit 4d7e3d5
* Thu Nov  5 2020 jslaby@suse.cz
- Linux 5.9.4 (bsc#1012628).
- x86/copy_mc: Introduce copy_mc_enhanced_fast_string()
  (bsc#1012628).
- x86, powerpc: Rename memcpy_mcsafe() to copy_mc_to_{user,
  kernel}() (bsc#1012628).
- Revert "x86, powerpc: Rename memcpy_mcsafe() to
  copy_mc_to_{user, kernel}()" (bsc#1012628).
- Revert "x86/copy_mc: Introduce copy_mc_enhanced_fast_string()"
  (bsc#1012628).
- commit 1043b8d
* Wed Nov  4 2020 jslaby@suse.cz
- Update
  patches.suse/tty-make-FONTX-ioctl-use-the-tty-pointer-they-were-a.patch
  (bsc#1178123 CVE-2020-25668).
- commit 639997d
* Wed Nov  4 2020 jslaby@suse.cz
- tty: make FONTX ioctl use the tty pointer they were actually
  passed (bsc#1178123 CVE-2020-25668).
- commit 3b8edfa
* Wed Nov  4 2020 tiwai@suse.de
- Updated Copyright line in rpm templates with SUSE LLC
- commit 39a1fcf
* Wed Nov  4 2020 tiwai@suse.de
- rpm/kernel-obs-build.spec.in: Add -q option to modprobe calls (bsc#1178401)
- commit 33ded45
* Wed Nov  4 2020 jslaby@suse.cz
- tty: make FONTX ioctl use the tty pointer they were actually
  passed (bnc#1178421).
- commit fa9aaca
* Tue Nov  3 2020 tiwai@suse.de
- KVM: x86: Fix NULL dereference at kvm_msr_ignored_check()
  (bsc#1178280).
- commit 3711b19
* Tue Nov  3 2020 tiwai@suse.de
- rpm/kernel-binary.spec.in: Fix compressed module handling for in-tree KMP (jsc#SLE-10886)
  The in-tree KMP that is built with SLE kernels have a different scriptlet
  that is embedded in kernel-binary.spec.in rather than *.sh files.
- commit e32ee2c
* Tue Nov  3 2020 jslaby@suse.cz
- vt: keyboard, extend func_buf_lock to readers (bnc#1177766
  CVE-2020-25656).
- vt: keyboard, simplify vt_kdgkbsent (bnc#1177766
  CVE-2020-25656).
- commit c5f9b44
* Mon Nov  2 2020 jslaby@suse.cz
- Refresh patches.suse/vt_ioctl-fix-GIO_UNIMAP-regression.patch.
  Update upstream status.
- commit a2dec54
* Mon Nov  2 2020 mkubecek@suse.cz
- Update to 5.10-rc2
- eliminated 5 patches
  - patches.rpmify/s390-correct-__bootdata-__bootdata_preserved-macros.patch
  - patches.suse/drm-amd-display-Don-t-invoke-kgdb_breakpoint-uncondi.patch
  - patches.suse/drm-amd-display-Fix-kernel-panic-by-dal_gpio_open-er.patch
  - patches.suse/vt_ioctl-fix-GIO_UNIMAP-regression.patch
  - patches.suse/x86-unwind-orc-Fix-inactive-tasks-with-stack-pointer.patch
- refresh configs
  - CPU_FREQ_DEFAULT_GOV_ONDEMAND -> CPU_FREQ_DEFAULT_GOV_SCHEDUTIL (x86)
  - Intel MIC drivers dropped
- commit a51c4bb
* Sun Nov  1 2020 jslaby@suse.cz
- x86/mce: Allow for copy_mc_fragile symbol checksum to be
  generated (git-fixes).
- commit d3f0dc8
* Sun Nov  1 2020 jslaby@suse.cz
- Linux 5.9.3 (bsc#1012628).
- phy: marvell: comphy: Convert internal SMCC firmware return
  codes to errno (bsc#1012628).
- misc: rtsx: do not setting OC_POWER_DOWN reg in
  rtsx_pci_init_ocp() (bsc#1012628).
- io_uring: don't reuse linked_timeout (bsc#1012628).
- xen/gntdev.c: Mark pages as dirty (bsc#1012628).
- mm: mark async iocb read as NOWAIT once some data has been
  copied (bsc#1012628).
- ata: sata_rcar: Fix DMA boundary mask (bsc#1012628).
- PM: runtime: Fix timer_expires data type on 32-bit arches
  (bsc#1012628).
- serial: pl011: Fix lockdep splat when handling magic-sysrq
  interrupt (bsc#1012628).
- serial: qcom_geni_serial: To correct QUP Version detection logic
  (bsc#1012628).
- drm/i915/gem: Serialise debugfs i915_gem_objects with ctx->mutex
  (bsc#1012628).
- mtd: lpddr: Fix bad logic in print_drs_error (bsc#1012628).
- RDMA/addr: Fix race with netevent_callback()/rdma_addr_cancel()
  (bsc#1012628).
- cxl: Rework error message for incompatible slots (bsc#1012628).
- p54: avoid accessing the data mapped to streaming DMA
  (bsc#1012628).
- evm: Check size of security.evm before using it (bsc#1012628).
- bpf: Fix comment for helper bpf_current_task_under_cgroup()
  (bsc#1012628).
- fuse: fix page dereference after free (bsc#1012628).
- ata: ahci: mvebu: Make SATA PHY optional for Armada 3720
  (bsc#1012628).
- PCI: aardvark: Fix initialization with old Marvell's Arm
  Trusted Firmware (bsc#1012628).
- x86/xen: disable Firmware First mode for correctable memory
  errors (bsc#1012628).
- x86/traps: Fix #DE Oops message regression (bsc#1012628).
- arch/x86/amd/ibs: Fix re-arming IBS Fetch (bsc#1012628).
- erofs: avoid duplicated permission check for "trusted." xattrs
  (bsc#1012628).
- net: protect tcf_block_unbind with block lock (bsc#1012628).
- net/smc: fix suppressed return code (bsc#1012628).
- net/smc: fix invalid return code in smcd_new_buf_create()
  (bsc#1012628).
- tipc: fix memory leak caused by tipc_buf_append() (bsc#1012628).
- tcp: Prevent low rmem stalls with SO_RCVLOWAT (bsc#1012628).
- ravb: Fix bit fields checking in ravb_hwtstamp_get()
  (bsc#1012628).
- r8169: fix issue with forced threading in combination with
  shared interrupts (bsc#1012628).
- net/sched: act_mpls: Add softdep on mpls_gso.ko (bsc#1012628).
- net: ipa: command payloads already mapped (bsc#1012628).
- net: hns3: Clear the CMDQ registers before unmapping BAR region
  (bsc#1012628).
- netem: fix zero division in tabledist (bsc#1012628).
- mlxsw: Only advertise link modes supported by both driver and
  device (bsc#1012628).
- mlxsw: core: Fix memory leak on module removal (bsc#1012628).
- ibmvnic: fix ibmvnic_set_mac (bsc#1012628).
- ibmveth: Fix use of ibmveth in a bridge (bsc#1012628).
- gtp: fix an use-before-init in gtp_newlink() (bsc#1012628).
- cxgb4: set up filter action after rewrites (bsc#1012628).
- chelsio/chtls: fix tls record info to user (bsc#1012628).
- chelsio/chtls: fix memory leaks in CPL handlers (bsc#1012628).
- chelsio/chtls: fix deadlock issue (bsc#1012628).
- bnxt_en: Send HWRM_FUNC_RESET fw command unconditionally
  (bsc#1012628).
- bnxt_en: Re-write PCI BARs after PCI fatal error (bsc#1012628).
- bnxt_en: Invoke cancel_delayed_work_sync() for PFs also
  (bsc#1012628).
- bnxt_en: Fix regression in workqueue cleanup logic in
  bnxt_remove_one() (bsc#1012628).
- bnxt_en: Check abort error state in bnxt_open_nic()
  (bsc#1012628).
- efivarfs: Replace invalid slashes with exclamation marks in
  dentries (bsc#1012628).
- x86/copy_mc: Introduce copy_mc_enhanced_fast_string()
  (bsc#1012628).
- x86, powerpc: Rename memcpy_mcsafe() to copy_mc_to_{user,
  kernel}() (bsc#1012628).
- Update config files.
- x86/PCI: Fix intel_mid_pci.c build error when ACPI is not
  enabled (bsc#1012628).
- arm64: link with -z norelro regardless of CONFIG_RELOCATABLE
  (bsc#1012628).
- arm64: Run ARCH_WORKAROUND_2 enabling code on all CPUs
  (bsc#1012628).
- arm64: Run ARCH_WORKAROUND_1 enabling code on all CPUs
  (bsc#1012628).
- fs/kernel_read_file: Remove FIRMWARE_EFI_EMBEDDED enum
  (bsc#1012628).
- efi/arm64: libstub: Deal gracefully with EFI_RNG_PROTOCOL
  failure (bsc#1012628).
- scripts/setlocalversion: make git describe output more reliable
  (bsc#1012628).
- io_uring: Convert advanced XArray uses to the normal API
  (bsc#1012628).
- io_uring: Fix XArray usage in io_uring_add_task_file
  (bsc#1012628).
- io_uring: Fix use of XArray in __io_uring_files_cancel
  (bsc#1012628).
- io_uring: no need to call xa_destroy() on empty xarray
  (bsc#1012628).
- io-wq: fix use-after-free in io_wq_worker_running (bsc#1012628).
- io_wq: Make io_wqe::lock a raw_spinlock_t (bsc#1012628).
- io_uring: reference ->nsproxy for file table commands
  (bsc#1012628).
- io_uring: don't rely on weak ->files references (bsc#1012628).
- io_uring: enable task/files specific overflow flushing
  (bsc#1012628).
- io_uring: return cancelation status from poll/timeout/files
  handlers (bsc#1012628).
- io_uring: unconditionally grab req->task (bsc#1012628).
- io_uring: stash ctx task reference for SQPOLL (bsc#1012628).
- io_uring: move dropping of files into separate helper
  (bsc#1012628).
- io_uring: allow timeout/poll/files killing to take task into
  account (bsc#1012628).
- netfilter: nftables_offload: KASAN slab-out-of-bounds Read in
  nft_flow_rule_create (bsc#1012628).
- cpufreq: Improve code around unlisted freq check (bsc#1012628).
- commit 2793cd6
* Thu Oct 29 2020 jslaby@suse.cz
- tracing, synthetic events: Replace buggy strcat() with seq_buf
  operations (git-fixes).
- commit 4133ad1
* Thu Oct 29 2020 jslaby@suse.cz
- Linux 5.9.2 (bsc#1012628).
- ibmveth: Switch order of ibmveth_helper calls (bsc#1012628).
- ibmveth: Identify ingress large send packets (bsc#1012628).
- cxgb4: handle 4-tuple PEDIT to NAT mode translation
  (bsc#1012628).
- ipv4: Restore flowi4_oif update before call to xfrm_lookup_route
  (bsc#1012628).
- mlx4: handle non-napi callers to napi_poll (bsc#1012628).
- mptcp: fix fallback for MP_JOIN subflows (bsc#1012628).
- mptcp: subflows garbage collection (bsc#1012628).
- net: dsa: microchip: fix race condition (bsc#1012628).
- net: fec: Fix phy_device lookup for phy_reset_after_clk_enable()
  (bsc#1012628).
- net: fec: Fix PHY init after phy_reset_after_clk_enable()
  (bsc#1012628).
- net: fix pos incrementment in ipv6_route_seq_next (bsc#1012628).
- net: ipa: skip suspend/resume activities if not set up
  (bsc#1012628).
- net: mptcp: make DACK4/DACK8 usage consistent among all subflows
  (bsc#1012628).
- net: sched: Fix suspicious RCU usage while accessing
  tcf_tunnel_info (bsc#1012628).
- net/smc: fix use-after-free of delayed events (bsc#1012628).
- net/smc: fix valid DMBE buffer sizes (bsc#1012628).
- net/tls: sendfile fails with ktls offload (bsc#1012628).
- tipc: fix NULL pointer dereference in tipc_named_rcv
  (bsc#1012628).
- tipc: fix the skb_unshare() in tipc_buf_append() (bsc#1012628).
- socket: fix option SO_TIMESTAMPING_NEW (bsc#1012628).
- socket: don't clear SOCK_TSTAMP_NEW when SO_TIMESTAMPNS is
  disabled (bsc#1012628).
- can: m_can_platform: don't call m_can_class_suspend in runtime
  suspend (bsc#1012628).
- can: j1935: j1939_tp_tx_dat_new(): fix missing initialization
  of skbcnt (bsc#1012628).
- net: j1939: j1939_session_fresh_new(): fix missing
  initialization of skbcnt (bsc#1012628).
- binder: fix UAF when releasing todo list (bsc#1012628).
- ALSA: bebob: potential info leak in hwdep_read() (bsc#1012628).
- ALSA: hda: fix jack detection with Realtek codecs when in D3
  (bsc#1012628).
- ALSA: hda/hdmi: fix incorrect locking in hdmi_pcm_close
  (bsc#1012628).
- tipc: re-configure queue limit for broadcast link (bsc#1012628).
- tipc: fix incorrect setting window for bcast link (bsc#1012628).
- chelsio/chtls: fix socket lock (bsc#1012628).
- chelsio/chtls: correct netdevice for vlan interface
  (bsc#1012628).
- chelsio/chtls: fix panic when server is on ipv6 (bsc#1012628).
- chelsio/chtls: Fix panic when listen on multiadapter
  (bsc#1012628).
- chelsio/chtls: correct function return and return type
  (bsc#1012628).
- chelsio/chtls: fix writing freed memory (bsc#1012628).
- ibmvnic: save changed mac address to adapter->mac_addr
  (bsc#1012628).
- icmp: randomize the global rate limiter (bsc#1012628).
- mptcp: initialize mptcp_options_received's ahmac (bsc#1012628).
- net: ftgmac100: Fix Aspeed ast2600 TX hang issue (bsc#1012628).
- net: hdlc: In hdlc_rcv, check to make sure dev is an HDLC device
  (bsc#1012628).
- net: hdlc_raw_eth: Clear the IFF_TX_SKB_SHARING flag after
  calling ether_setup (bsc#1012628).
- net: Properly typecast int values to set sk_max_pacing_rate
  (bsc#1012628).
- net/sched: act_ct: Fix adding udp port mangle operation
  (bsc#1012628).
- net/sched: act_tunnel_key: fix OOB write in case of IPv6 ERSPAN
  tunnels (bsc#1012628).
- netsec: ignore 'phy-mode' device property on ACPI systems
  (bsc#1012628).
- nexthop: Fix performance regression in nexthop deletion
  (bsc#1012628).
- nfc: Ensure presence of NFC_ATTR_FIRMWARE_NAME attribute in
  nfc_genl_fw_download() (bsc#1012628).
- r8169: fix operation under forced interrupt threading
  (bsc#1012628).
- selftests: forwarding: Add missing 'rp_filter' configuration
  (bsc#1012628).
- selftests: rtnetlink: load fou module for kci_test_encap_fou()
  test (bsc#1012628).
- tcp: fix to update snd_wl1 in bulk receiver fast path
  (bsc#1012628).
- net: ethernet: mtk-star-emac: select REGMAP_MMIO (bsc#1012628).
- net/sched: act_gate: Unlock ->tcfa_lock in
  tc_setup_flow_action() (bsc#1012628).
- ixgbe: fix probing of multi-port devices with one MDIO
  (bsc#1012628).
- mptcp: MPTCP_KUNIT_TESTS should depend on MPTCP instead of
  selecting it (bsc#1012628).
- net: openvswitch: fix to make sure flow_lookup() is not
  preempted (bsc#1012628).
- sfc: move initialisation of efx->filter_sem to efx_init_struct()
  (bsc#1012628).
- ALSA: hda - Don't register a cb func if it is registered already
  (bsc#1012628).
- ALSA: hda - Fix the return value if cb func is already
  registered (bsc#1012628).
- ALSA: usb-audio: Line6 Pod Go interface requires static clock
  rate quirk (bsc#1012628).
- ALSA: hda/realtek - The front Mic on a HP machine doesn't work
  (bsc#1012628).
- ALSA: hda/realtek - set mic to auto detect on a HP AIO machine
  (bsc#1012628).
- ALSA: hda/realtek - Add mute Led support for HP Elitebook 845 G7
  (bsc#1012628).
- ALSA: hda/realtek: Enable audio jacks of ASUS D700SA with ALC887
  (bsc#1012628).
- cifs: remove bogus debug code (bsc#1012628).
- cifs: Return the error from crypt_message when enc/dec key
  not found (bsc#1012628).
- SMB3: Resolve data corruption of TCP server info fields
  (bsc#1012628).
- SMB3.1.1: Fix ids returned in POSIX query dir (bsc#1012628).
- smb3: do not try to cache root directory if dir leases not
  supported (bsc#1012628).
- smb3: fix stat when special device file and mounted with
  modefromsid (bsc#1012628).
- arm64: Make use of ARCH_WORKAROUND_1 even when KVM is not
  enabled (bsc#1012628).
- KVM: nVMX: Morph notification vector IRQ on nested VM-Enter
  to pending PI (bsc#1012628).
- KVM: nVMX: Reset the segment cache when stuffing guest segs
  (bsc#1012628).
- KVM: nVMX: Reload vmcs01 if getting vmcs12's pages fails
  (bsc#1012628).
- KVM: x86/mmu: Commit zap of remaining invalid pages when
  recovering lpages (bsc#1012628).
- KVM: x86: Intercept LA57 to inject #GP fault when it's reserved
  (bsc#1012628).
- KVM: SVM: Initialize prev_ga_tag before use (bsc#1012628).
- ima: Don't ignore errors from crypto_shash_update()
  (bsc#1012628).
- crypto: caam - add xts check for block length equal to zero
  (bsc#1012628).
- crypto: algif_aead - Do not set MAY_BACKLOG on the async path
  (bsc#1012628).
- crypto: caam/qi - add fallback for XTS with more than 8B IV
  (bsc#1012628).
- crypto: caam/qi - add support for more XTS key lengths
  (bsc#1012628).
- crypto: caam/jr - add fallback for XTS with more than 8B IV
  (bsc#1012628).
- crypto: caam/jr - add support for more XTS key lengths
  (bsc#1012628).
- crypto: caam/qi2 - add fallback for XTS with more than 8B IV
  (bsc#1012628).
- crypto: caam/qi2 - add support for more XTS key lengths
  (bsc#1012628).
- RAS/CEC: Fix cec_init() prototype (bsc#1012628).
- sched/fair: Fix wrong negative conversion in
  find_energy_efficient_cpu() (bsc#1012628).
- microblaze: fix kbuild redundant file warning (bsc#1012628).
- EDAC/i5100: Fix error handling order in i5100_init_one()
  (bsc#1012628).
- EDAC/aspeed: Fix handling of platform_get_irq() error
  (bsc#1012628).
- EDAC/ti: Fix handling of platform_get_irq() error (bsc#1012628).
- perf/x86/intel/ds: Fix x86_pmu_stop warning for large PEBS
  (bsc#1012628).
- x86/fpu: Allow multiple bits in clearcpuid= parameter
  (bsc#1012628).
- irqchip/ti-sci-inta: Fix unsigned comparison to zero
  (bsc#1012628).
- irqchip/ti-sci-intr: Fix unsigned comparison to zero
  (bsc#1012628).
- arm64: kprobe: add checks for ARMv8.3-PAuth combined
  instructions (bsc#1012628).
- seqlock: Unbreak lockdep (bsc#1012628).
- drivers/perf: xgene_pmu: Fix uninitialized resource struct
  (bsc#1012628).
- drivers/perf: thunderx2_pmu: Fix memory resource error handling
  (bsc#1012628).
- sched/fair: Fix wrong cpu selecting from isolated domain
  (bsc#1012628).
- sched/fair: Use dst group while checking imbalance for NUMA
  balancer (bsc#1012628).
- arm64: perf: Add missing ISB in armv8pmu_enable_counter()
  (bsc#1012628).
- perf/x86/intel/uncore: Update Ice Lake uncore units
  (bsc#1012628).
- perf/x86/intel/uncore: Reduce the number of CBOX counters
  (bsc#1012628).
- perf/x86/intel/uncore: Fix for iio mapping on Skylake Server
  (bsc#1012628).
- perf/x86/intel/uncore: Fix the scale of the IMC free-running
  events (bsc#1012628).
- x86/nmi: Fix nmi_handle() duration miscalculation (bsc#1012628).
- x86/events/amd/iommu: Fix sizeof mismatch (bsc#1012628).
- pinctrl: qcom: Set IRQCHIP_SET_TYPE_MASKED and
  IRQCHIP_MASK_ON_SUSPEND flags (bsc#1012628).
- pinctrl: qcom: Use return value from irq_set_wake() call
  (bsc#1012628).
- perf/x86: Fix n_pair for cancelled txn (bsc#1012628).
- lockdep: Fix usage_traceoverflow (bsc#1012628).
- lockdep: Fix lockdep recursion (bsc#1012628).
- lockdep: Revert "lockdep: Use raw_cpu_*() for per-cpu variables"
  (bsc#1012628).
- perf/core: Fix race in the perf_mmap_close() function
  (bsc#1012628).
- regulator: set of_node for qcom vbus regulator (bsc#1012628).
- crypto: algif_skcipher - EBUSY on aio should be an error
  (bsc#1012628).
- crypto: mediatek - Fix wrong return value in
  mtk_desc_ring_alloc() (bsc#1012628).
- crypto: ixp4xx - Fix the size used in a 'dma_free_coherent()'
  call (bsc#1012628).
- crypto: picoxcell - Fix potential race condition bug
  (bsc#1012628).
- media: vivid: Fix global-out-of-bounds read in
  precalculate_color() (bsc#1012628).
- media: tuner-simple: fix regression in simple_set_radio_freq
  (bsc#1012628).
- crypto: ccree - fix runtime PM imbalance on error (bsc#1012628).
- media: Revert "media: exynos4-is: Add missed check for
  pinctrl_lookup_state()" (bsc#1012628).
- media: hantro: h264: Get the correct fallback reference buffer
  (bsc#1012628).
- media: hantro: postproc: Fix motion vector space allocation
  (bsc#1012628).
- media: ov5640: Correct Bit Div register in clock tree diagram
  (bsc#1012628).
- media: i2c: fix error check on max9286_read call (bsc#1012628).
- media: m5mols: Check function pointer in m5mols_sensor_power
  (bsc#1012628).
- fscrypt: restrict IV_INO_LBLK_32 to ino_bits <= 32
  (bsc#1012628).
- media: uvcvideo: Set media controller entity functions
  (bsc#1012628).
- media: uvcvideo: Silence shift-out-of-bounds warning
  (bsc#1012628).
- media: staging/intel-ipu3: css: Correctly reset some memory
  (bsc#1012628).
- media: omap3isp: Fix memleak in isp_probe (bsc#1012628).
- media: i2c: ov5640: Remain in power down for DVP mode unless
  streaming (bsc#1012628).
- media: i2c: ov5640: Separate out mipi configuration from s_power
  (bsc#1012628).
- media: i2c: ov5640: Enable data pins on poweron for DVP mode
  (bsc#1012628).
- media: rcar_drif: Fix fwnode reference leak when parsing DT
  (bsc#1012628).
- media: rcar_drif: Allocate v4l2_async_subdev dynamically
  (bsc#1012628).
- media: rcar-csi2: Allocate v4l2_async_subdev dynamically
  (bsc#1012628).
- media: i2c: max9286: Allocate v4l2_async_subdev dynamically
  (bsc#1012628).
- crypto: sa2ul - fix compiler warning produced by clang
  (bsc#1012628).
- spi: fsi: Handle 9 to 15 byte transfers lengths (bsc#1012628).
- spi: fsi: Fix use of the bneq+ sequencer instruction
  (bsc#1012628).
- spi: fsi: Implement restricted size for certain controllers
  (bsc#1012628).
- spi: dw-pci: free previously allocated IRQs if desc->setup()
  fails (bsc#1012628).
- crypto: sa2ul - Select CRYPTO_AUTHENC (bsc#1012628).
- crypto: omap-sham - fix digcnt register handling with
  export/import (bsc#1012628).
- crypto: sa2ul - Fix pm_runtime_get_sync() error checking
  (bsc#1012628).
- selftests/seccomp: Use __NR_mknodat instead of __NR_mknod
  (bsc#1012628).
- selftests/seccomp: Refactor arch register macros to avoid
  xtensa special case (bsc#1012628).
- selftests/seccomp: powerpc: Fix seccomp return value testing
  (bsc#1012628).
- regmap: debugfs: Fix more error path regressions (bsc#1012628).
- hwmon: (pmbus/max34440) Fix status register reads for
  MAX344{51,60,61} (bsc#1012628).
- hwmon: (w83627ehf) Fix a resource leak in probe (bsc#1012628).
- cypto: mediatek - fix leaks in mtk_desc_ring_alloc
  (bsc#1012628).
- crypto: stm32/crc32 - Avoid lock if hardware is already used
  (bsc#1012628).
- crypto: sun8i-ce - handle endianness of t_common_ctl
  (bsc#1012628).
- media: mx2_emmaprp: Fix memleak in emmaprp_probe (bsc#1012628).
- media: mtk-mdp: Fix Null pointer dereference when calling
  list_add (bsc#1012628).
- media: tc358743: initialize variable (bsc#1012628).
- media: tc358743: cleanup tc358743_cec_isr (bsc#1012628).
- nvme: fix error handling in nvme_ns_report_zones (bsc#1012628).
- media: rcar-vin: Fix a reference count leak (bsc#1012628).
- media: rockchip/rga: Fix a reference count leak (bsc#1012628).
- media: platform: fcp: Fix a reference count leak (bsc#1012628).
- media: camss: Fix a reference count leak (bsc#1012628).
- media: s5p-mfc: Fix a reference count leak (bsc#1012628).
- media: stm32-dcmi: Fix a reference count leak (bsc#1012628).
- media: ti-vpe: Fix a missing check and reference count leak
  (bsc#1012628).
- regulator: resolve supply after creating regulator
  (bsc#1012628).
- pinctrl: bcm: fix kconfig dependency warning when !GPIOLIB
  (bsc#1012628).
- spi: spi-s3c64xx: swap s3c64xx_spi_set_cs() and
  s3c64xx_enable_datapath() (bsc#1012628).
- spi: spi-s3c64xx: Check return values (bsc#1012628).
- hwmon: (bt1-pvt) Test sensor power supply on probe
  (bsc#1012628).
- hwmon: (bt1-pvt) Cache current update timeout (bsc#1012628).
- hwmon: (bt1-pvt) Wait for the completion with timeout
  (bsc#1012628).
- spi: imx: Fix freeing of DMA channels if spi_bitbang_start()
  fails (bsc#1012628).
- btrfs: add owner and fs_info to alloc_state io_tree
  (bsc#1012628).
- blk-mq: move cancel of hctx->run_work to the front of
  blk_exit_queue (bsc#1012628).
- ath10k: provide survey info as accumulated data (bsc#1012628).
- drm/vkms: fix xrgb on compute crc (bsc#1012628).
- Bluetooth: hci_uart: Cancel init work before unregistering
  (bsc#1012628).
- drm/amd/display: Fix wrong return value in
  dm_update_plane_state() (bsc#1012628).
- drm/vgem: add missing platform_device_unregister() in
  vgem_init() (bsc#1012628).
- drm/vkms: add missing platform_device_unregister() in
  vkms_init() (bsc#1012628).
- drm: panel: Fix bus format for OrtusTech COM43H4M85ULC panel
  (bsc#1012628).
- ath6kl: prevent potential array overflow in ath6kl_add_new_sta()
  (bsc#1012628).
- ath9k: Fix potential out of bounds in
  ath9k_htc_txcompletion_cb() (bsc#1012628).
- ath10k: Fix the size used in a 'dma_free_coherent()' call in
  an error handling path (bsc#1012628).
- wcn36xx: Fix reported 802.11n rx_highest rate wcn3660/wcn3680
  (bsc#1012628).
- ASoC: qcom: lpass-platform: fix memory leak (bsc#1012628).
- ASoC: qcom: lpass-cpu: fix concurrency issue (bsc#1012628).
- ath11k: Fix possible memleak in ath11k_qmi_init_service
  (bsc#1012628).
- brcmfmac: check ndev pointer (bsc#1012628).
- mwifiex: Do not use GFP_KERNEL in atomic context (bsc#1012628).
- drm/malidp: Use struct drm_gem_object_funcs.get_sg_table
  internally (bsc#1012628).
- staging: rtl8192u: Do not use GFP_KERNEL in atomic context
  (bsc#1012628).
- drm/amd/display: fix potential integer overflow when shifting
  32 bit variable bl_pwm (bsc#1012628).
- selftests/bpf: Fix test_vmlinux test to use
  bpf_probe_read_user() (bsc#1012628).
- drm/gma500: fix error check (bsc#1012628).
- scsi: qla4xxx: Fix an error handling path in
  'qla4xxx_get_host_stats()' (bsc#1012628).
- scsi: qla2xxx: Fix the size used in a 'dma_free_coherent()'
  call (bsc#1012628).
- scsi: qla2xxx: Fix wrong return value in
  qlt_chk_unresolv_exchg() (bsc#1012628).
- scsi: qla2xxx: Fix wrong return value in qla_nvme_register_hba()
  (bsc#1012628).
- scsi: csiostor: Fix wrong return value in csio_hw_prep_fw()
  (bsc#1012628).
- libbpf: Fix unintentional success return code in
  bpf_object__load (bsc#1012628).
- wilc1000: Fix memleak in wilc_sdio_probe (bsc#1012628).
- wilc1000: Fix memleak in wilc_bus_probe (bsc#1012628).
- rtw88: don't treat NULL pointer as an array (bsc#1012628).
- selftests/livepatch: Do not check order when using "comm"
  for dmesg checking (bsc#1012628).
- backlight: sky81452-backlight: Fix refcount imbalance on error
  (bsc#1012628).
- staging: wfx: fix frame reordering (bsc#1012628).
- staging: emxx_udc: Fix passing of NULL to dma_alloc_coherent()
  (bsc#1012628).
- VMCI: check return value of get_user_pages_fast() for errors
  (bsc#1012628).
- mm/error_inject: Fix allow_error_inject function signatures
  (bsc#1012628).
- drm: panel: Fix bpc for OrtusTech COM43H4M85ULC panel
  (bsc#1012628).
- samples/bpf: Fix to xdpsock to avoid recycling frames
  (bsc#1012628).
- ima: Pre-parse the list of keyrings in a KEY_CHECK rule
  (bsc#1012628).
- ima: Fail rule parsing when asymmetric key measurement isn't
  supportable (bsc#1012628).
- drm/crc-debugfs: Fix memleak in crc_control_write (bsc#1012628).
- Bluetooth: Clear suspend tasks on unregister (bsc#1012628).
- selftests: vm: add fragment CONFIG_GUP_BENCHMARK (bsc#1012628).
- scsi: ufs: Make ufshcd_print_trs() consider
  UFSHCD_QUIRK_PRDT_BYTE_GRAN (bsc#1012628).
- binder: Remove bogus warning on failed same-process transaction
  (bsc#1012628).
- drm/amdgpu: fix max_entries calculation v4 (bsc#1012628).
- soundwire: stream: fix NULL/IS_ERR confusion (bsc#1012628).
- soundwire: intel: fix NULL/ERR_PTR confusion (bsc#1012628).
- tty: serial: earlycon dependency (bsc#1012628).
- tty: hvcs: Don't NULL tty->driver_data until hvcs_cleanup()
  (bsc#1012628).
- pty: do tty_flip_buffer_push without port->lock in pty_write
  (bsc#1012628).
- pwm: lpss: Fix off by one error in base_unit math in
  pwm_lpss_prepare() (bsc#1012628).
- pwm: lpss: Add range limit check for the base_unit register
  value (bsc#1012628).
- drivers/virt/fsl_hypervisor: Fix error handling path
  (bsc#1012628).
- sfc: don't double-down() filters in ef100_reset() (bsc#1012628).
- ath11k: fix a double free and a memory leak (bsc#1012628).
- video: fbdev: vga16fb: fix setting of pixclock because a
  pass-by-value error (bsc#1012628).
- video: fbdev: sis: fix null ptr dereference (bsc#1012628).
- video: fbdev: radeon: Fix memleak in radeonfb_pci_register
  (bsc#1012628).
- ASoC: fsl: imx-es8328: add missing put_device() call in
  imx_es8328_probe() (bsc#1012628).
- scsi: ufs: ufs-mediatek: Eliminate error message for unbound
  mphy (bsc#1012628).
- scsi: ufs: ufs-mediatek: Fix HOST_PA_TACTIVATE quirk
  (bsc#1012628).
- HID: roccat: add bounds checking in kone_sysfs_write_settings()
  (bsc#1012628).
- ath11k: fix uninitialized return in
  ath11k_spectral_process_data() (bsc#1012628).
- drm/msm: Avoid div-by-zero in dpu_crtc_atomic_check()
  (bsc#1012628).
- drm/panfrost: Ensure GPU quirks are always initialised
  (bsc#1012628).
- iomap: Clear page error before beginning a write (bsc#1012628).
- iomap: Mark read blocks uptodate in write_begin (bsc#1012628).
- selftests/lkdtm: Use "comm" instead of "diff" for dmesg
  (bsc#1012628).
- Bluetooth: Fix memory leak in read_adv_mon_features()
  (bsc#1012628).
- Bluetooth: Re-order clearing suspend tasks (bsc#1012628).
- pinctrl: mcp23s08: Fix mcp23x17_regmap initialiser
  (bsc#1012628).
- pinctrl: mcp23s08: Fix mcp23x17 precious range (bsc#1012628).
- pinctrl: devicetree: Keep deferring even on timeout
  (bsc#1012628).
- drm/msm/adreno: fix probe without iommu (bsc#1012628).
- s390/bpf: Fix multiple tail calls (bsc#1012628).
- net/mlx5: Fix uninitialized variable warning (bsc#1012628).
- net/mlx5: Don't call timecounter cyc2time directly from 1PPS
  flow (bsc#1012628).
- scsi: mpt3sas: Fix sync irqs (bsc#1012628).
- net: stmmac: Fix incorrect location to set real_num_rx|tx_queues
  (bsc#1012628).
- net: stmmac: use netif_tx_start|stop_all_queues() function
  (bsc#1012628).
- xfs: force the log after remapping a synchronous-writes file
  (bsc#1012628).
- cpufreq: armada-37xx: Add missing MODULE_DEVICE_TABLE
  (bsc#1012628).
- drm: mxsfb: check framebuffer pitch (bsc#1012628).
- cpufreq: qcom: Don't add frequencies without an OPP
  (bsc#1012628).
- ima: Fix NULL pointer dereference in ima_file_hash
  (bsc#1012628).
- ASoC: topology: disable size checks for bytes_ext controls if
  needed (bsc#1012628).
- ASoC: tlv320adcx140: Fix digital gain range (bsc#1012628).
- coresight: etm4x: Fix etm4_count race by moving cpuhp callbacks
  to init (bsc#1012628).
- coresight: cti: disclaim device only when it's claimed
  (bsc#1012628).
- coresight: cti: remove pm_runtime_get_sync() from CPU hotplug
  (bsc#1012628).
- coresight: etm4x: Ensure default perf settings filter
  user/kernel (bsc#1012628).
- coresight: etm4x: Fix issues within reset interface of sysfs
  (bsc#1012628).
- coresight: cti: Write regsiters directly in cti_enable_hw()
  (bsc#1012628).
- coresight: etm4x: Handle unreachable sink in perf mode
  (bsc#1012628).
- coresight: etm4x: Fix issues on trcseqevr access (bsc#1012628).
- nvmem: core: fix missing of_node_put() in of_nvmem_device_get()
  (bsc#1012628).
- selftests: mptcp: interpret \n as a new line (bsc#1012628).
- dmaengine: ti: k3-udma-glue: fix channel enable functions
  (bsc#1012628).
- selftests/bpf: Fix endianness issue in sk_assign (bsc#1012628).
- selftests/bpf: Fix endianness issue in test_sockopt_sk
  (bsc#1012628).
- Bluetooth: Fix auto-creation of hci_conn at Conn Complete event
  (bsc#1012628).
- xhci: don't create endpoint debugfs entry before ring buffer
  is set (bsc#1012628).
- drm/msm: Fix the a650 hw_apriv check (bsc#1012628).
- net: dsa: rtl8366: Check validity of passed VLANs (bsc#1012628).
- net: dsa: rtl8366: Refactor VLAN/PVID init (bsc#1012628).
- net: dsa: rtl8366: Skip PVID setting if not requested
  (bsc#1012628).
- net: wilc1000: clean up resource in error path of init mon
  interface (bsc#1012628).
- ASoC: tas2770: Fix calling reset in probe (bsc#1012628).
- ASoC: tas2770: Add missing bias level power states
  (bsc#1012628).
- ASoC: tas2770: Fix required DT properties in the code
  (bsc#1012628).
- ASoC: tas2770: Fix error handling with update_bits
  (bsc#1012628).
- ASoC: tlv320aic32x4: Fix bdiv clock rate derivation
  (bsc#1012628).
- net: dsa: rtl8366rb: Support all 4096 VLANs (bsc#1012628).
- ASoC: SOF: control: add size checks for ext_bytes control .put()
  (bsc#1012628).
- ASoC: tas2770: Fix unbalanced calls to pm_runtime (bsc#1012628).
- spi: omap2-mcspi: Improve performance waiting for CHSTAT
  (bsc#1012628).
- ath11k: Add checked value for ath11k_ahb_remove (bsc#1012628).
- ath6kl: wmi: prevent a shift wrapping bug in
  ath6kl_wmi_delete_pstream_cmd() (bsc#1012628).
- drm: rcar-du: Put reference to VSP device (bsc#1012628).
- phy: rockchip-dphy-rx0: Include linux/delay.h (bsc#1012628).
- dmaengine: dmatest: Check list for emptiness before access
  its last entry (bsc#1012628).
- ASoC: cros_ec_codec: fix kconfig dependency warning for
  SND_SOC_CROS_EC_CODEC (bsc#1012628).
- misc: mic: scif: Fix error handling path (bsc#1012628).
- ALSA: seq: oss: Avoid mutex lock for a long-time ioctl
  (bsc#1012628).
- net/mlx5e: IPsec: Use kvfree() for memory allocated with
  kvzalloc() (bsc#1012628).
- usb: dwc2: Fix parameter type in function pointer prototype
  (bsc#1012628).
- usb: dwc3: core: Properly default unspecified speed
  (bsc#1012628).
- usb: dwc2: Add missing cleanups when usb_add_gadget_udc()
  fails (bsc#1012628).
- rtw88: Fix probe error handling race with firmware loading
  (bsc#1012628).
- rtw88: Fix potential probe error handling race with wow firmware
  loading (bsc#1012628).
- mt76: mt7615: hold mt76 lock queueing wd in
  mt7615_queue_key_update (bsc#1012628).
- mt76: mt7615: release mutex in mt7615_reset_test_set
  (bsc#1012628).
- mt76: mt7663s: fix resume failure (bsc#1012628).
- mt76: mt7615: fix possible memory leak in mt7615_tm_set_tx_power
  (bsc#1012628).
- mt76: mt7615: fix a possible NULL pointer dereference in
  mt7615_pm_wake_work (bsc#1012628).
- mt76: fix a possible NULL pointer dereference in
  mt76_testmode_dump (bsc#1012628).
- mt76: mt7663u: fix dma header initialization (bsc#1012628).
- mt76: mt7615: move drv_own/fw_own in mt7615_mcu_ops
  (bsc#1012628).
- mt76: mt7622: fix fw hang on mt7622 (bsc#1012628).
- mt76: mt7915: fix possible memory leak in mt7915_mcu_add_beacon
  (bsc#1012628).
- quota: clear padding in v2r1_mem2diskdqb() (bsc#1012628).
- slimbus: core: check get_addr before removing laddr ida
  (bsc#1012628).
- slimbus: core: do not enter to clock pause mode in core
  (bsc#1012628).
- slimbus: qcom-ngd-ctrl: disable ngd in qmi server down callback
  (bsc#1012628).
- drm/vc4: crtc: Rework a bit the CRTC state code (bsc#1012628).
- ASoC: fsl_sai: Instantiate snd_soc_dai_driver (bsc#1012628).
- HID: hid-input: fix stylus battery reporting (bsc#1012628).
- tty: hvc: fix link error with CONFIG_SERIAL_CORE_CONSOLE=n
  (bsc#1012628).
- tty: serial: imx: fix link error with
  CONFIG_SERIAL_CORE_CONSOLE=n (bsc#1012628).
- nvmem: core: fix possibly memleak when use
  nvmem_cell_info_to_nvmem_cell() (bsc#1012628).
- hv: clocksource: Add notrace attribute to
  read_hv_sched_clock_*() functions (bsc#1012628).
- nl80211: fix OBSS PD min and max offset validation
  (bsc#1012628).
- iomap: Use kzalloc to allocate iomap_page (bsc#1012628).
- coresight: etm: perf: Fix warning caused by etm_setup_aux
  failure (bsc#1012628).
- coresight: cti: Fix remove sysfs link error (bsc#1012628).
- coresight: cti: Fix bug clearing sysfs links on callback
  (bsc#1012628).
- coresight: etm4x: Fix save and restore of TRCVMIDCCTLR1 register
  (bsc#1012628).
- ibmvnic: set up 200GBPS speed (bsc#1012628).
- bpf: disallow attaching modify_return tracing functions to
  other BPF programs (bsc#1012628).
- selftests: Remove fmod_ret from test_overhead (bsc#1012628).
- qtnfmac: fix resource leaks on unsupported iftype error return
  path (bsc#1012628).
- pinctrl: aspeed: Use the right pinconf mask (bsc#1012628).
- iommu/qcom: add missing put_device() call in
  qcom_iommu_of_xlate() (bsc#1012628).
- iio: adc: stm32-adc: fix runtime autosuspend delay when slow
  polling (bsc#1012628).
- net: enic: Cure the enic api locking trainwreck (bsc#1012628).
- selftests/bpf: Fix endianness issues in
  sk_lookup/ctx_narrow_access (bsc#1012628).
- pinctrl: tigerlake: Fix register offsets for TGL-H variant
  (bsc#1012628).
- serial: 8250: Discard RTS/DTS setting from clock update method
  (bsc#1012628).
- serial: 8250: Skip uninitialized TTY port baud rate update
  (bsc#1012628).
- serial: 8250_dw: Fix clk-notifier/port suspend deadlock
  (bsc#1012628).
- mfd: syscon: Don't free allocated name for regmap_config
  (bsc#1012628).
- mfd: sm501: Fix leaks in probe() (bsc#1012628).
- dm: fix missing imposition of queue_limits from dm_wq_work()
  thread (bsc#1012628).
- pinctrl: single: fix pinctrl_spec.args_count bounds check
  (bsc#1012628).
- pinctrl: single: fix debug output when #pinctrl-cells = 2
  (bsc#1012628).
- staging: rtl8712: Fix enqueue_reorder_recvframe() (bsc#1012628).
- ASoC: wm_adsp: Pass full name to snd_ctl_notify (bsc#1012628).
- iwlwifi: mvm: split a print to avoid a WARNING in ROC
  (bsc#1012628).
- iwlwifi: dbg: remove no filter condition (bsc#1012628).
- iwlwifi: dbg: run init_cfg function once per driver load
  (bsc#1012628).
- usb: gadget: f_ncm: fix ncm_bitrate for SuperSpeed and above
  (bsc#1012628).
- usb: gadget: u_serial: clear suspended flag when disconnecting
  (bsc#1012628).
- usb: gadget: u_ether: enable qmult on SuperSpeed Plus as well
  (bsc#1012628).
- bus: mhi: core: Fix the building of MHI module (bsc#1012628).
- ocxl: fix kconfig dependency warning for OCXL (bsc#1012628).
- nl80211: fix non-split wiphy information (bsc#1012628).
- usb: dwc2: Fix INTR OUT transfers in DDMA mode (bsc#1012628).
- scsi: target: tcmu: Fix warning: 'page' may be used
  uninitialized (bsc#1012628).
- scsi: be2iscsi: Fix a theoretical leak in beiscsi_create_eqs()
  (bsc#1012628).
- dmaengine: ioat: Allocate correct size for descriptor chunk
  (bsc#1012628).
- staging: qlge: fix build breakage with dumping enabled
  (bsc#1012628).
- ipmi_si: Fix wrong return value in try_smi_init() (bsc#1012628).
- tracing: Fix parse_synth_field() error handling (bsc#1012628).
- ASoC: mediatek: mt8183-da7219: fix wrong ops for I2S3
  (bsc#1012628).
- staging: wfx: fix BA sessions for older firmwares (bsc#1012628).
- platform/x86: mlx-platform: Remove PSU EEPROM configuration
  (bsc#1012628).
- dm: fix request-based DM to not bounce through indirect
  dm_submit_bio (bsc#1012628).
- mwifiex: fix double free (bsc#1012628).
- drm/panfrost: increase readl_relaxed_poll_timeout values
  (bsc#1012628).
- drm/amdgpu: Fix invalid number of character '{' in
  amdgpu_acpi_init (bsc#1012628).
- ipvs: clear skb->tstamp in forwarding path (bsc#1012628).
- bpf, sockmap: Remove skb_orphan and let normal skb_kfree do
  cleanup (bsc#1012628).
- net: korina: fix kfree of rx/tx descriptor array (bsc#1012628).
- netfilter: nf_log: missing vlan offload tag and proto
  (bsc#1012628).
- mm/swapfile.c: fix potential memory leak in sys_swapon
  (bsc#1012628).
- mm: memcg/slab: fix racy access to page->mem_cgroup in
  mem_cgroup_from_obj() (bsc#1012628).
- mm/memcg: fix device private memcg accounting (bsc#1012628).
- mm/mmap.c: replace do_brk with do_brk_flags in comment of
  insert_vm_struct() (bsc#1012628).
- mm/page_alloc.c: fix freeing non-compound pages (bsc#1012628).
- mm, oom_adj: don't loop through tasks in __set_oom_adj when
  not necessary (bsc#1012628).
- fs: fix NULL dereference due to data race in prepend_path()
  (bsc#1012628).
- selftests/ftrace: Change synthetic event name for
  inter-event-combined test (bsc#1012628).
- tracing: Handle synthetic event array field type checking
  correctly (bsc#1012628).
- i3c: master add i3c_master_attach_boardinfo to preserve
  boardinfo (bsc#1012628).
- IB/mlx4: Fix starvation in paravirt mux/demux (bsc#1012628).
- IB/mlx4: Adjust delayed work when a dup is observed
  (bsc#1012628).
- powerpc/pseries: Fix missing of_node_put() in rng_init()
  (bsc#1012628).
- powerpc/icp-hv: Fix missing of_node_put() in success path
  (bsc#1012628).
- rcu/tree: Force quiescent state on callback overload
  (bsc#1012628).
- rcutorture: Properly set rcu_fwds for OOM handling
  (bsc#1012628).
- refperf: Avoid null pointer dereference when buf fails to
  allocate (bsc#1012628).
- RDMA/ucma: Fix locking for ctx->events_reported (bsc#1012628).
- RDMA/ucma: Add missing locking around rdma_leave_multicast()
  (bsc#1012628).
- mtd: lpddr: fix excessive stack usage with clang (bsc#1012628).
- RDMA/hns: Add a check for current state before modifying QP
  (bsc#1012628).
- RDMA/umem: Fix signature of stub ib_umem_find_best_pgsz()
  (bsc#1012628).
- powerpc/pseries: explicitly reschedule during drmem_lmb list
  traversal (bsc#1012628).
- pseries/drmem: don't cache node id in drmem_lmb struct
  (bsc#1012628).
- RDMA/mlx5: Fix potential race between destroy and CQE poll
  (bsc#1012628).
- mtd: mtdoops: Don't write panic data twice (bsc#1012628).
- selftests/powerpc: Fix prefixes in alignment_handler signal
  handler (bsc#1012628).
- perf tools: Make GTK2 support opt-in (bsc#1012628).
- tools feature: Add missing -lzstd to the fast path feature
  detection (bsc#1012628).
- ARM: 9007/1: l2c: fix prefetch bits init in L2X0_AUX_CTRL
  using DT values (bsc#1012628).
- xfs: fix finobt btree block recovery ordering (bsc#1012628).
- m68knommu: include SDHC support only when hardware has it
  (bsc#1012628).
- arc: plat-hsdk: fix kconfig dependency warning when
  !RESET_CONTROLLER (bsc#1012628).
- ida: Free allocated bitmap in error path (bsc#1012628).
- xfs: limit entries returned when counting fsmap records
  (bsc#1012628).
- xfs: fix deadlock and streamline xfs_getfsmap performance
  (bsc#1012628).
- nfs: add missing "posix" local_lock constant table definition
  (bsc#1012628).
- xfs: fix high key handling in the rt allocator's query_range
  function (bsc#1012628).
- RDMA/rtrs-srv: Incorporate ib_register_client into rtrs server
  init (bsc#1012628).
- RDMA/core: Delete function indirection for alloc/free kernel CQ
  (bsc#1012628).
- RDMA: Allow fail of destroy CQ (bsc#1012628).
- RDMA: Change XRCD destroy return value (bsc#1012628).
- RDMA: Restore ability to return error for destroy WQ
  (bsc#1012628).
- RDMA/umem: Fix ib_umem_find_best_pgsz() for mappings that
  cross a page boundary (bsc#1012628).
- RDMA/umem: Prevent small pages from being returned by
  ib_umem_find_best_pgsz() (bsc#1012628).
- RDMA/qedr: Fix qp structure memory leak (bsc#1012628).
- RDMA/qedr: Fix doorbell setting (bsc#1012628).
- RDMA/qedr: Fix use of uninitialized field (bsc#1012628).
- RDMA/qedr: Fix return code if accept is called on a destroyed qp
  (bsc#1012628).
- RDMA/qedr: Fix inline size returned for iWARP (bsc#1012628).
- powerpc/pseries/svm: Allocate SWIOTLB buffer anywhere in memory
  (bsc#1012628).
- powerpc/watchpoint: Fix quadword instruction handling on p10
  predecessors (bsc#1012628).
- powerpc/watchpoint: Fix handling of vector instructions
  (bsc#1012628).
- powerpc/watchpoint: Add hw_len wherever missing (bsc#1012628).
- powerpc/book3s64/hash/4k: Support large linear mapping range
  with 4K (bsc#1012628).
- powerpc/tau: Use appropriate temperature sample interval
  (bsc#1012628).
- powerpc/tau: Convert from timer to workqueue (bsc#1012628).
- powerpc/tau: Remove duplicated set_thresholds() call
  (bsc#1012628).
- powerpc/tau: Check processor type before enabling TAU interrupt
  (bsc#1012628).
- powerpc/tau: Disable TAU between measurements (bsc#1012628).
- powerpc/kasan: Fix CONFIG_KASAN_VMALLOC for 8xx (bsc#1012628).
- powerpc/64s/radix: Fix mm_cpumask trimming race vs
  kthread_use_mm (bsc#1012628).
- powerpc/papr_scm: Fix warning triggered by perf_stats_show()
  (bsc#1012628).
- RDMA/cma: Combine cma_ndev_work with cma_work (bsc#1012628).
- RDMA/cma: Remove dead code for kernel rdmacm multicast
  (bsc#1012628).
- RDMA/cma: Consolidate the destruction of a cma_multicast in
  one place (bsc#1012628).
- RDMA/cma: Fix use after free race in roce multicast join
  (bsc#1012628).
- perf intel-pt: Fix "context_switch event has no tid" error
  (bsc#1012628).
- perf metricgroup: Fix uncore metric expressions (bsc#1012628).
- RDMA/qedr: Fix resource leak in qedr_create_qp (bsc#1012628).
- RDMA/hns: Set the unsupported wr opcode (bsc#1012628).
- RDMA/mlx5: Use set_mkc_access_pd_addr_fields() in reg_create()
  (bsc#1012628).
- RDMA/mlx5: Make mkeys always owned by the kernel's PD when
  not enabled (bsc#1012628).
- RDMA/mlx5: Disable IB_DEVICE_MEM_MGT_EXTENSIONS if IB_WR_REG_MR
  can't work (bsc#1012628).
- i40iw: Add support to make destroy QP synchronous (bsc#1012628).
- perf stat: Skip duration_time in setup_system_wide
  (bsc#1012628).
- RDMA/hns: Add check for the validity of sl configuration
  (bsc#1012628).
- RDMA/hns: Solve the overflow of the calc_pg_sz() (bsc#1012628).
- RDMA/hns: Fix the wrong value of rnr_retry when querying qp
  (bsc#1012628).
- RDMA/hns: Fix configuration of ack_req_freq in QPC
  (bsc#1012628).
- RDMA/hns: Fix missing sq_sig_type when querying QP
  (bsc#1012628).
- RDMA/mlx5: Fix type warning of sizeof in
  __mlx5_ib_alloc_counters() (bsc#1012628).
- mtd: hyperbus: hbmc-am654: Fix direct mapping setup flash access
  (bsc#1012628).
- mtd: rawnand: stm32_fmc2: fix a buffer overflow (bsc#1012628).
- mtd: rawnand: vf610: disable clk on error handling path in probe
  (bsc#1012628).
- mtd: spinand: gigadevice: Only one dummy byte in QUADIO
  (bsc#1012628).
- mtd: spinand: gigadevice: Add QE Bit (bsc#1012628).
- mtd: rawnand: ams-delta: Fix non-OF build warning (bsc#1012628).
- kdb: Fix pager search for multi-line strings (bsc#1012628).
- overflow: Include header file with SIZE_MAX declaration
  (bsc#1012628).
- mtd: parsers: bcm63xx: Do not make it modular (bsc#1012628).
- RDMA/ipoib: Set rtnl_link_ops for ipoib interfaces
  (bsc#1012628).
- powerpc/64: fix irq replay missing preempt (bsc#1012628).
- powerpc/64: fix irq replay pt_regs->softe value (bsc#1012628).
- powerpc: PPC_SECURE_BOOT should not require PowerNV
  (bsc#1012628).
- powerpc/perf: Exclude pmc5/6 from the irrelevant PMU group
  constraints (bsc#1012628).
- powerpc/perf/hv-gpci: Fix starting index value (bsc#1012628).
- perf stat: Fix out of bounds CPU map access when handling
  armv8_pmu events (bsc#1012628).
- i3c: master: Fix error return in cdns_i3c_master_probe()
  (bsc#1012628).
- powerpc/security: Fix link stack flush instruction
  (bsc#1012628).
- powerpc/book3s64/radix: Make radix_mem_block_size 64bit
  (bsc#1012628).
- powerpc/papr_scm: Add PAPR command family to pass-through
  command-set (bsc#1012628).
- cpufreq: powernv: Fix frame-size-overflow in
  powernv_cpufreq_reboot_notifier (bsc#1012628).
- IB/rdmavt: Fix sizeof mismatch (bsc#1012628).
- RDMA/rxe: Fix skb lifetime in rxe_rcv_mcast_pkt() (bsc#1012628).
- f2fs: reject CASEFOLD inode flag without casefold feature
  (bsc#1012628).
- um: vector: Use GFP_ATOMIC under spin lock (bsc#1012628).
- um: time-travel: Fix IRQ handling in
  time_travel_handle_message() (bsc#1012628).
- thermal: core: Adding missing nlmsg_free() in
  thermal_genl_sampling_temp() (bsc#1012628).
- maiblox: mediatek: Fix handling of platform_get_irq() error
  (bsc#1012628).
- perf trace: Fix off by ones in memset() after realloc() in
  arches using libaudit (bsc#1012628).
- selftests/powerpc: Fix eeh-basic.sh exit codes (bsc#1012628).
- f2fs: wait for sysfs kobject removal before freeing f2fs_sb_info
  (bsc#1012628).
- afs: Fix rapid cell addition/removal by not using RCU on cells
  tree (bsc#1012628).
- afs: Fix cell refcounting by splitting the usage counter
  (bsc#1012628).
- afs: Fix cell purging with aliases (bsc#1012628).
- afs: Fix cell removal (bsc#1012628).
- RDMA/rxe: Handle skb_clone() failure in rxe_recv.c
  (bsc#1012628).
- mm/page_owner: change split_page_owner to take a count
  (bsc#1012628).
- mm/huge_memory: fix split assumption of page size (bsc#1012628).
- mm: fix a race during THP splitting (bsc#1012628).
- lib/crc32.c: fix trivial typo in preprocessor condition
  (bsc#1012628).
- ramfs: fix nommu mmap with gaps in the page cache (bsc#1012628).
- rapidio: fix error handling path (bsc#1012628).
- rapidio: fix the missed put_device() for rio_mport_add_riodev
  (bsc#1012628).
- mailbox: avoid timer start from callback (bsc#1012628).
- clk: meson: axg-audio: separate axg and g12a regmap tables
  (bsc#1012628).
- rtc: ds1307: Clear OSF flag on DS1388 when setting time
  (bsc#1012628).
- i2c: rcar: Auto select RESET_CONTROLLER (bsc#1012628).
- clk: meson: g12a: mark fclk_div2 as critical (bsc#1012628).
- PCI: designware-ep: Fix the Header Type check (bsc#1012628).
- PCI: aardvark: Fix compilation on s390 (bsc#1012628).
- PCI: aardvark: Check for errors from pci_bridge_emul_init()
  call (bsc#1012628).
- PCI: iproc: Set affinity mask on MSI interrupts (bsc#1012628).
- rpmsg: smd: Fix a kobj leak in in qcom_smd_parse_edge()
  (bsc#1012628).
- rpmsg: Avoid double-free in mtk_rpmsg_register_device
  (bsc#1012628).
- remoteproc: stm32: Fix pointer assignement (bsc#1012628).
- PCI/IOV: Mark VFs as not implementing PCI_COMMAND_MEMORY
  (bsc#1012628).
- vfio: add a singleton check for vfio_group_pin_pages
  (bsc#1012628).
- s390/pci: Mark all VFs as not implementing PCI_COMMAND_MEMORY
  (bsc#1012628).
- vfio/pci: Decouple PCI_COMMAND_MEMORY bit checks from is_virtfn
  (bsc#1012628).
- vfio: fix a missed vfio group put in vfio_pin_pages
  (bsc#1012628).
- vfio/type1: fix dirty bitmap calculation in vfio_dma_rw
  (bsc#1012628).
- clk: qcom: gcc-sdm660: Fix wrong parent_map (bsc#1012628).
- clk: keystone: sci-clk: fix parsing assigned-clock data during
  probe (bsc#1012628).
- pwm: rockchip: Keep enabled PWMs running while probing
  (bsc#1012628).
- pwm: img: Fix null pointer access in probe (bsc#1012628).
- nfsd: Cache R, RW, and W opens separately (bsc#1012628).
- remoteproc/mediatek: fix null pointer dereference on null scp
  pointer (bsc#1012628).
- PCI: hv: Fix hibernation in case interrupts are not re-created
  (bsc#1012628).
- clk: rockchip: Initialize hw to error to avoid undefined
  behavior (bsc#1012628).
- clk: mediatek: add UART0 clock support (bsc#1012628).
- module: statically initialize init section freeing data
  (bsc#1012628).
- clk: at91: clk-main: update key before writing AT91_CKGR_MOR
  (bsc#1012628).
- clk: bcm2835: add missing release if devm_clk_hw_register fails
  (bsc#1012628).
- kbuild: deb-pkg: do not build linux-headers package if
  CONFIG_MODULES=n (bsc#1012628).
- watchdog: Fix memleak in watchdog_cdev_register (bsc#1012628).
- watchdog: Use put_device on error (bsc#1012628).
- watchdog: sp5100: Fix definition of EFCH_PM_DECODEEN3
  (bsc#1012628).
- clk: at91: sam9x60: support only two programmable clocks
  (bsc#1012628).
- svcrdma: fix bounce buffers for unaligned offsets and multiple
  pages (bsc#1012628).
- ext4: fix dead loop in ext4_mb_new_blocks (bsc#1012628).
- ext4: discard preallocations before releasing group lock
  (bsc#1012628).
- ext4: disallow modifying DAX inode flag if inline_data has
  been set (bsc#1012628).
- ext4: limit entries returned when counting fsmap records
  (bsc#1012628).
- vfio/pci: Clear token on bypass registration failure
  (bsc#1012628).
- vfio iommu type1: Fix memory leak in vfio_iommu_type1_pin_pages
  (bsc#1012628).
- clk: qcom: gdsc: Keep RETAIN_FF bit set if gdsc is already on
  (bsc#1012628).
- clk: imx8mq: Fix usdhc parents order (bsc#1012628).
- SUNRPC: fix copying of multiple pages in gss_read_proxy_verf()
  (bsc#1012628).
- NFSv4.2: Fix NFS4ERR_STALE error when doing inter server copy
  (bsc#1012628).
- platform/chrome: cros_ec_typec: Send enum values to
  usb_role_switch_set_role() (bsc#1012628).
- platform/chrome: cros_ec_lightbar: Reduce ligthbar get version
  command (bsc#1012628).
- Input: elants_i2c - fix typo for an attribute to show
  calibration count (bsc#1012628).
- Input: imx6ul_tsc - clean up some errors in imx6ul_tsc_resume()
  (bsc#1012628).
- Input: stmfts - fix a & vs && typo (bsc#1012628).
- Input: ep93xx_keypad - fix handling of platform_get_irq()
  error (bsc#1012628).
- Input: omap4-keypad - fix handling of platform_get_irq() error
  (bsc#1012628).
- Input: twl4030_keypad - fix handling of platform_get_irq()
  error (bsc#1012628).
- Input: sun4i-ps2 - fix handling of platform_get_irq() error
  (bsc#1012628).
- KVM: x86: emulating RDPID failure shall return #UD rather than
  [#]GP (bsc#1012628).
- KVM: nSVM: CR3 MBZ bits are only 63:52 (bsc#1012628).
- scsi: bfa: Fix error return in bfad_pci_init() (bsc#1012628).
- arm64: mm: use single quantity to represent the PA to VA
  translation (bsc#1012628).
- bpf: Enforce id generation for all may-be-null register type
  (bsc#1012628).
- net: dsa: seville: the packet buffer is 2 megabits, not
  megabytes (bsc#1012628).
- netfilter: conntrack: connection timeout after re-register
  (bsc#1012628).
- netfilter: ebtables: Fixes dropping of small packets in bridge
  nat (bsc#1012628).
- vdpa/mlx5: Make use of a specific 16 bit endianness API
  (bsc#1012628).
- vdpa/mlx5: Fix failure to bring link up (bsc#1012628).
- vdpa/mlx5: Setup driver only if VIRTIO_CONFIG_S_DRIVER_OK
  (bsc#1012628).
- netfilter: nf_fwd_netdev: clear timestamp in forwarding path
  (bsc#1012628).
- soc: xilinx: Fix error code in zynqmp_pm_probe() (bsc#1012628).
- arm64: dts: meson: vim3: correct led polarity (bsc#1012628).
- ARM: dts: imx6sl: fix rng node (bsc#1012628).
- ARM: at91: pm: of_node_put() after its usage (bsc#1012628).
- ARM: s3c24xx: fix mmc gpio lookup tables (bsc#1012628).
- memory: brcmstb_dpfe: fix array index out of bounds
  (bsc#1012628).
- ARM: dts: sun8i: r40: bananapi-m2-ultra: Fix dcdc1 regulator
  (bsc#1012628).
- arm64: dts: allwinner: h5: remove Mali GPU PMU module
  (bsc#1012628).
- memory: omap-gpmc: Fix a couple off by ones (bsc#1012628).
- memory: omap-gpmc: Fix build error without CONFIG_OF
  (bsc#1012628).
- arm64: dts: qcom: msm8992: Fix UART interrupt property
  (bsc#1012628).
- arm64: dts: qcom: sdm845-db845c: Fix hdmi nodes (bsc#1012628).
- arm64: dts: qcom: sm8150: fix up primary USB nodes
  (bsc#1012628).
- arm64: dts: qcom: sc7180: Fix the LLCC base register size
  (bsc#1012628).
- memory: fsl-corenet-cf: Fix handling of platform_get_irq()
  error (bsc#1012628).
- firmware: arm_scmi: Fix NULL pointer dereference in
  mailbox_chan_free (bsc#1012628).
- arm64: dts: mt8173-elm: fix supported values for
  regulator-allowed-modes of da9211 (bsc#1012628).
- arm64: dts: qcom: sm8250: Rename UART2 node to UART12
  (bsc#1012628).
- dmaengine: ti: k3-udma-glue: Fix parameters for rx ring pair
  request (bsc#1012628).
- arm64: dts: imx8mq: Add missing interrupts to GPC (bsc#1012628).
- arm64: dts: qcom: sc7180: Drop flags on mdss irqs (bsc#1012628).
- arm64: dts: sdm845: Fixup OPP table for all qup devices
  (bsc#1012628).
- soc: qcom: pdr: Fixup array type of get_domain_list_resp message
  (bsc#1012628).
- arm64: dts: qcom: msm8916: Remove one more thermal trip point
  unit name (bsc#1012628).
- arm64: dts: qcom: pm8916: Remove invalid reg size from wcd_codec
  (bsc#1012628).
- arm64: dts: qcom: msm8916: Fix MDP/DSI interrupts (bsc#1012628).
- soc: qcom: apr: Fixup the error displayed on lookup failure
  (bsc#1012628).
- dt-bindings: crypto: Specify that allwinner, sun8i-a33-crypto
  needs reset (bsc#1012628).
- arm64: dts: renesas: r8a77990: Fix MSIOF1 DMA channels
  (bsc#1012628).
- arm64: dts: renesas: r8a774c0: Fix MSIOF1 DMA channels
  (bsc#1012628).
- arm64: dts: mt8173: elm: Fix nor_flash node property
  (bsc#1012628).
- arm64: dts: ti: k3-j721e: Rename mux header and update macro
  names (bsc#1012628).
- arm64: dts: actions: limit address range for pinctrl node
  (bsc#1012628).
- ARM: dts: owl-s500: Fix incorrect PPI interrupt specifiers
  (bsc#1012628).
- soc: fsl: qbman: Fix return value on success (bsc#1012628).
- ARM: OMAP2+: Restore MPU power domain if cpu_cluster_pm_enter()
  fails (bsc#1012628).
- ARM: dts: stm32: Fix sdmmc2 pins on AV96 (bsc#1012628).
- ARM: dts: stm32: lxa-mc1: Fix kernel warning about PHY delays
  (bsc#1012628).
- ARM: dts: stm32: Move ethernet PHY into DH SoM DT (bsc#1012628).
- ARM: dts: stm32: Swap PHY reset GPIO and TSC2004 IRQ on DHCOM
  SOM (bsc#1012628).
- ARM: dts: stm32: Fix DH PDK2 display PWM channel (bsc#1012628).
- ARM: dts: iwg20d-q7-common: Fix touch controller probe failure
  (bsc#1012628).
- soc: mediatek: cmdq: add clear option in cmdq_pkt_wfe api
  (bsc#1012628).
- drm/mediatek: reduce clear event (bsc#1012628).
- arm64: dts: zynqmp: Remove additional compatible string for
  i2c IPs (bsc#1012628).
- ARM: dts: meson8: remove two invalid interrupt lines from the
  GPU node (bsc#1012628).
- lightnvm: fix out-of-bounds write to array devices->info[]
  (bsc#1012628).
- powerpc/powernv/dump: Fix race while processing OPAL dump
  (bsc#1012628).
- powerpc/64s: Remove TM from Power10 features (bsc#1012628).
- powerpc/pseries: Avoid using addr_to_pfn in real mode
  (bsc#1012628).
- nvmet: fix uninitialized work for zero kato (bsc#1012628).
- nvmet: limit passthru MTDS by BIO_MAX_PAGES (bsc#1012628).
- KVM: ioapic: break infinite recursion on lazy EOI (bsc#1012628).
- NTB: hw: amd: fix an issue about leak system resources
  (bsc#1012628).
- ntb: intel: Fix memleak in intel_ntb_pci_probe (bsc#1012628).
- sched/features: Fix !CONFIG_JUMP_LABEL case (bsc#1012628).
- perf: correct SNOOPX field offset (bsc#1012628).
- random32: make prandom_u32() output unpredictable (bsc#1012628).
- i2c: core: Restore acpi_walk_dep_device_list() getting called
  after registering the ACPI i2c devs (bsc#1012628).
- md/bitmap: fix memory leak of temporary bitmap (bsc#1012628).
- block: ratelimit handle_bad_sector() message (bsc#1012628).
- x86/dumpstack: Fix misleading instruction pointer error message
  (bsc#1012628).
- crypto: ccp - fix error handling (bsc#1012628).
- x86/asm: Replace __force_order with a memory clobber
  (bsc#1012628).
- x86/mce: Add Skylake quirk for patrol scrub reported errors
  (bsc#1012628).
- media: firewire: fix memory leak (bsc#1012628).
- media: ati_remote: sanity check for both endpoints
  (bsc#1012628).
- media: st-delta: Fix reference count leak in delta_run_work
  (bsc#1012628).
- media: sti: Fix reference count leaks (bsc#1012628).
- media: exynos4-is: Fix several reference count leaks due to
  pm_runtime_get_sync (bsc#1012628).
- media: exynos4-is: Fix a reference count leak due to
  pm_runtime_get_sync (bsc#1012628).
- media: exynos4-is: Fix a reference count leak (bsc#1012628).
- media: vsp1: Fix runtime PM imbalance on error (bsc#1012628).
- media: platform: s3c-camif: Fix runtime PM imbalance on error
  (bsc#1012628).
- media: platform: sti: hva: Fix runtime PM imbalance on error
  (bsc#1012628).
- media: bdisp: Fix runtime PM imbalance on error (bsc#1012628).
- media: media/pci: prevent memory leak in bttv_probe
  (bsc#1012628).
- x86/mce: Annotate mce_rd/wrmsrl() with noinstr (bsc#1012628).
- crypto: hisilicon - fixed memory allocation error (bsc#1012628).
- spi: fsi: Fix clock running too fast (bsc#1012628).
- blk-mq: always allow reserved allocation in hctx_may_queue
  (bsc#1012628).
- x86/mce: Make mce_rdmsrl() panic on an inaccessible MSR
  (bsc#1012628).
- media: uvcvideo: Ensure all probed info is returned to v4l2
  (bsc#1012628).
- mmc: sdio: Check for CISTPL_VERS_1 buffer size (bsc#1012628).
- media: saa7134: avoid a shift overflow (bsc#1012628).
- media: atomisp: fix memleak in ia_css_stream_create
  (bsc#1012628).
- media: venus: fixes for list corruption (bsc#1012628).
- notifier: Fix broken error handling pattern (bsc#1012628).
- fs: dlm: fix configfs memory leak (bsc#1012628).
- media: venus: core: Fix error handling in probe (bsc#1012628).
- media: venus: core: Fix runtime PM imbalance in venus_probe
  (bsc#1012628).
- ntfs: add check for mft record size in superblock (bsc#1012628).
- ip_gre: set dev->hard_header_len and dev->needed_headroom
  properly (bsc#1012628).
- mac80211: handle lack of sband->bitrates in rates (bsc#1012628).
- staging: wfx: fix handling of MMIC error (bsc#1012628).
- libbpf: Close map fd if init map slots failed (bsc#1012628).
- bpf: Use raw_spin_trylock() for pcpu_freelist_push/pop in NMI
  (bsc#1012628).
- PM: hibernate: remove the bogus call to get_gendisk() in
  software_resume() (bsc#1012628).
- scsi: mvumi: Fix error return in mvumi_io_attach()
  (bsc#1012628).
- scsi: target: core: Add CONTROL field for trace events
  (bsc#1012628).
- mic: vop: copy data to kernel space then write to io memory
  (bsc#1012628).
- misc: vop: add round_up(x,4) for vring_size to avoid kernel
  panic (bsc#1012628).
- usb: dwc3: Add splitdisable quirk for Hisilicon Kirin Soc
  (bsc#1012628).
- usb: gadget: function: printer: fix use-after-free in
  __lock_acquire (bsc#1012628).
- rtw88: pci: Power cycle device during shutdown (bsc#1012628).
- udf: Limit sparing table size (bsc#1012628).
- udf: Avoid accessing uninitialized data on failed inode read
  (bsc#1012628).
- rtw88: increse the size of rx buffer size (bsc#1012628).
- USB: cdc-acm: handle broken union descriptors (bsc#1012628).
- mt76: mt7915: do not do any work in napi poll after calling
  napi_complete_done() (bsc#1012628).
- usb: dwc3: simple: add support for Hikey 970 (bsc#1012628).
- habanalabs: cast to u64 before shift > 31 bits (bsc#1012628).
- can: flexcan: flexcan_chip_stop(): add error handling and
  propagate error value (bsc#1012628).
- HID: multitouch: Lenovo X1 Tablet Gen3 trackpoint and buttons
  (bsc#1012628).
- ath9k: hif_usb: fix race condition between usb_get_urb()
  and usb_kill_anchored_urbs() (bsc#1012628).
- drm/panfrost: add Amlogic GPU integration quirks (bsc#1012628).
- drm/panfrost: add amlogic reset quirk callback (bsc#1012628).
- drm/panfrost: add support for vendor quirk (bsc#1012628).
- bpf: Limit caller's stack depth 256 for subprogs with tailcalls
  (bsc#1012628).
- dma-direct: Fix potential NULL pointer dereference
  (bsc#1012628).
- misc: rtsx: Fix memory leak in rtsx_pci_probe (bsc#1012628).
- reiserfs: only call unlock_new_inode() if I_NEW (bsc#1012628).
- opp: Prevent memory leak in dev_pm_opp_attach_genpd()
  (bsc#1012628).
- xfs: make sure the rt allocator doesn't run off the end
  (bsc#1012628).
- usb: ohci: Default to per-port over-current protection
  (bsc#1012628).
- drm: fix double free for gbo in drm_gem_vram_init and
  drm_gem_vram_create (bsc#1012628).
- Bluetooth: Only mark socket zapped after unlocking
  (bsc#1012628).
- drm/msm/a6xx: fix a potential overflow issue (bsc#1012628).
- drm/xlnx: Use devm_drm_dev_alloc (bsc#1012628).
- iomap: fix WARN_ON_ONCE() from unprivileged users (bsc#1012628).
- scsi: ibmvfc: Fix error return in ibmvfc_probe() (bsc#1012628).
- scsi: qla2xxx: Warn if done() or free() are called on an
  already freed srb (bsc#1012628).
- selftests/bpf: Fix test_sysctl_loop{1, 2} failure due to clang
  change (bsc#1012628).
- soundwire: cadence: fix race condition between suspend and
  Slave device alerts (bsc#1012628).
- brcmsmac: fix memory leak in wlc_phy_attach_lcnphy
  (bsc#1012628).
- rtl8xxxu: prevent potential memory leak (bsc#1012628).
- Fix use after free in get_capset_info callback (bsc#1012628).
- HID: ite: Add USB id match for Acer One S1003 keyboard dock
  (bsc#1012628).
- scsi: qedf: Return SUCCESS if stale rport is encountered
  (bsc#1012628).
- scsi: qedi: Mark all connections for recovery on link down event
  (bsc#1012628).
- scsi: qedi: Protect active command list to avoid list corruption
  (bsc#1012628).
- scsi: qedi: Fix list_del corruption while removing active I/O
  (bsc#1012628).
- fbmem: add margin check to fb_check_caps() (bsc#1012628).
- tty: ipwireless: fix error handling (bsc#1012628).
- Bluetooth: btusb: Fix memleak in btusb_mtk_submit_wmt_recv_urb
  (bsc#1012628).
- ipvs: Fix uninit-value in do_ip_vs_set_ctl() (bsc#1012628).
- reiserfs: Fix memory leak in reiserfs_parse_options()
  (bsc#1012628).
- s390/qeth: strictly order bridge address events (bsc#1012628).
- mwifiex: don't call del_timer_sync() on uninitialized timer
  (bsc#1012628).
- ALSA: hda/ca0132 - Add AE-7 microphone selection commands
  (bsc#1012628).
- ALSA: hda/ca0132 - Add new quirk ID for SoundBlaster AE-7
  (bsc#1012628).
- ASoC: SOF: Add topology filename override based on dmi data
  match (bsc#1012628).
- ASoC: Intel: sof_rt5682: override quirk data for
  tgl_max98373_rt5682 (bsc#1012628).
- scsi: smartpqi: Avoid crashing kernel for controller issues
  (bsc#1012628).
- brcm80211: fix possible memleak in brcmf_proto_msgbuf_attach
  (bsc#1012628).
- usb: core: Solve race condition in anchor cleanup functions
  (bsc#1012628).
- soundwire: intel: reinitialize IP+DSP in .prepare(), but only
  when resuming (bsc#1012628).
- scsi: ufs: ufs-qcom: Fix race conditions caused by
  ufs_qcom_testbus_config() (bsc#1012628).
- drm/amd/display: Screen corruption on dual displays (DP+USB-C)
  (bsc#1012628).
- dmaengine: dw: Add DMA-channels mask cell support (bsc#1012628).
- dmaengine: dw: Activate FIFO-mode for memory peripherals only
  (bsc#1012628).
- drm/hisilicon: Code refactoring for hibmc_drv_de (bsc#1012628).
- drm/amd/display: Disconnect pipe separetely when disable pipe
  split (bsc#1012628).
- drm/panfrost: perfcnt: fix ref count leak in
  panfrost_perfcnt_enable_locked (bsc#1012628).
- ath10k: check idx validity in __ath10k_htt_rx_ring_fill_n()
  (bsc#1012628).
- net: korina: cast KSEG0 address to pointer in kfree
  (bsc#1012628).
- s390/qeth: don't let HW override the configured port role
  (bsc#1012628).
- tty: serial: lpuart: fix lpuart32_write usage (bsc#1012628).
- tty: serial: fsl_lpuart: fix lpuart32_poll_get_char
  (bsc#1012628).
- usb: gadget: bcm63xx_udc: fix up the error of undeclared
  usb_debug_root (bsc#1012628).
- usb: cdc-acm: add quirk to blacklist ETAS ES58X devices
  (bsc#1012628).
- USB: cdc-wdm: Make wdm_flush() interruptible and add wdm_fsync()
  (bsc#1012628).
- usb: cdns3: gadget: free interrupt after gadget has deleted
  (bsc#1012628).
- eeprom: at25: set minimum read/write access stride to 1
  (bsc#1012628).
- usb: gadget: f_ncm: allow using NCM in SuperSpeed Plus gadgets
  (bsc#1012628).
- Update config files.
- commit 2daaf9a
* Thu Oct 29 2020 jslaby@suse.cz
- Refresh patches.suse/vt_ioctl-fix-GIO_UNIMAP-regression.patch.
- Refresh
  patches.suse/x86-unwind-orc-Fix-inactive-tasks-with-stack-pointer.patch.
  Update upstream statuses.
- commit 8eeec3f
* Thu Oct 29 2020 tiwai@suse.de
- rpm/kernel-module-subpackage: make Group tag optional (bsc#1163592)
- commit 552ec97
* Mon Oct 26 2020 mkubecek@suse.cz
- s390: correct __bootdata / __bootdata_preserved macros
  (http://lkml.kernel.org/r/20201026104811.22ta4pby2chmz4pv@lion.mk-sys.cz).
- commit e4bed42
* Mon Oct 26 2020 jslaby@suse.cz
- vt_ioctl: fix GIO_UNIMAP regression (5.9 GIO_UNIMAP regression).
- commit 15946ea
* Mon Oct 26 2020 mkubecek@suse.cz
- Update to 5.10-rc1
- eliminated 17 patches (16 stable, 1 other)
  - patches.kernel.org/*
  - patches.suse/coresight-fix-offset-by-one-error-in-counting-ports.patch
- disable ARM architectures (need config update)
- refresh
  - patches.suse/apparmor-compatibility-with-v2.x-net.patch
  - patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch
  - patches.suse/btrfs-fs-super.c-add-new-super-block-devices-super_block_d.patch
  - patches.suse/readahead-request-tunables.patch
- new config options:
  - General setup
  - CONFIG_BPF_PRELOAD=n
  - Power management and ACPI options
  - CONFIG_ACPI_DPTF=y
  - CONFIG_DPTF_PCH_FIVR=m
  - General architecture-dependent options
  - CONFIG_STATIC_CALL_SELFTEST=n
  - Networking support
  - CONFIG_XFRM_USER_COMPAT=m
  - CONFIG_CAN_ISOTP=m
  - CONFIG_CAN_MCP251XFD=m
  - CONFIG_CAN_MCP251XFD_SANITY=n
  - File systems
  - CONFIG_XFS_SUPPORT_V4=y
  - CONFIG_FUSE_DAX=y
  - CONFIG_NFSD_V4_2_INTER_SSC=y
  - Cryptographic API
  - CONFIG_CRYPTO_SM2=m
  - CONFIG_CRYPTO_USER_API_RNG_CAVP=n
  - CONFIG_CRYPTO_USER_API_ENABLE_OBSOLETE=y
  - Library routines
  - CONFIG_FONT_6x8=y
  - Kernel hacking
  - CONFIG_KGDB_HONOUR_BLOCKLIST=y
  - CONFIG_SCF_TORTURE_TEST=n
  - CONFIG_CSD_LOCK_WAIT_DEBUG=n
  - CONFIG_RCU_SCALE_TEST=m
  - CONFIG_FAULT_INJECTION_USERCOPY=n
  - CONFIG_TEST_FREE_PAGES=n
  - PCI support
  - CONFIG_PCIE_BUS_TUNE_OFF=n
  - CONFIG_PCIE_BUS_DEFAULT=y
  - CONFIG_PCIE_BUS_SAFE=n
  - CONFIG_PCIE_BUS_PERFORMANCE=n
  - CONFIG_PCIE_BUS_PEER2PEER=n
  - Network device support
  - CONFIG_NET_DSA_MSCC_SEVILLE=m
  - CONFIG_CHELSIO_INLINE_CRYPTO=y
  - CONFIG_PRESTERA=m
  - CONFIG_PRESTERA_PCI=m
  - CONFIG_ATH11K=m
  - CONFIG_ATH11K_PCI=m
  - CONFIG_ATH11K_DEBUG=n
  - CONFIG_ATH11K_DEBUGFS=n
  - CONFIG_ATH11K_TRACING=n
  - CONFIG_USB_LGM_PHY=m
  - CONFIG_PHY_INTEL_LGM_EMMC=m
  - Input device support
  - CONFIG_JOYSTICK_ADC=m
  - CONFIG_TOUCHSCREEN_ZINITIX=m
  - CONFIG_RMI4_F3A=y
  - CONFIG_HID_VIVALDI=m
  - Character devices
  - CONFIG_HW_RANDOM_XIPHERA=m
  - GPIO Support
  - CONFIG_GPIO_CDEV=y
  - CONFIG_GPIO_CDEV_V1=y
  - Power management
  - CONFIG_CHARGER_BQ25980=m
  - CONFIG_SENSORS_MR75203=m
  - CONFIG_SENSORS_ADM1266=m
  - CONFIG_SENSORS_MP2975=m
  - ACPI INT340X thermal drivers
  - CONFIG_REGULATOR_RASPBERRYPI_TOUCHSCREEN_ATTINY=m
  - CONFIG_REGULATOR_RT4801=m
  - CONFIG_REGULATOR_RTMV20=m
  - Multifunction device drivers
  - CONFIG_MFD_SL28CPLD=n
  - CONFIG_MFD_INTEL_M10_BMC=n
  - Graphics support
  - CONFIG_DRM_AMD_DC_SI=y
  - CONFIG_BACKLIGHT_KTD253=m
  - CONFIG_VIDEO_ZORAN=m
  - CONFIG_VIDEO_ZORAN_DC30=m
  - CONFIG_VIDEO_ZORAN_ZR36060=m
  - CONFIG_VIDEO_ZORAN_BUZ=m
  - CONFIG_VIDEO_ZORAN_DC10=m
  - CONFIG_VIDEO_ZORAN_LML33=m
  - CONFIG_VIDEO_ZORAN_LML33R10=m
  - CONFIG_VIDEO_ZORAN_AVS6EYES=m
  - Sound card support
  - CONFIG_SND_SOC_INTEL_CATPT=m
  - CONFIG_SND_SOC_SOF_BROADWELL_SUPPORT=y
  - CONFIG_SND_SOC_SOF_INTEL_SOUNDWIRE_LINK=y
  - CONFIG_SND_SOC_INTEL_SOUNDWIRE_SOF_MACH=m
  - CONFIG_SND_SOC_CS4234=n
  - CONFIG_SND_SOC_TAS2764=n
  - CONFIG_SOUNDWIRE_QCOM=m
  - USB support
  - CONFIG_USB_FEW_INIT_RETRIES=n
  - CONFIG_TYPEC_TCPCI_MAXIM=m
  - CONFIG_TYPEC_STUSB160X=m
  - CONFIG_USB4_DEBUGFS_WRITE=n
  - Virtualization
  - CONFIG_NITRO_ENCLAVES=m
  - Industrial I/O support
  - CONFIG_IIO_BUFFER_DMA=m
  - CONFIG_IIO_BUFFER_DMAENGINE=m
  - CONFIG_ADXRS290=n
  - CONFIG_HDC2010=n
  - CONFIG_AS73211=n
  - Misc drivers
  - CONFIG_MHI_BUS_DEBUG=y
  - CONFIG_INTEL_MEI_VIRTIO=m
  - CONFIG_RTC_DRV_RV3032=m
  - CONFIG_LEDS_LP50XX=m
  - CONFIG_SPMI_HISI3670=n
  - CONFIG_MST_IRQ=y
  - OF dependent drivers (i386, ppc64/ppc64le, riscv64)
  - HISI_HIKEY_USB=m
  - DRM_PANEL_MANTIX_MLAF057WE51=n
  - DRM_PANEL_SAMSUNG_S6E63M0_SPI=n
  - DRM_PANEL_SAMSUNG_S6E63M0_DSI=n
  - DRM_LONTIUM_LT9611=n
  - DRM_TOSHIBA_TC358762=n
  - DRM_TOSHIBA_TC358775=n
  - DRM_CDNS_MHDP8546=n
  - MFD_HI6421_SPMI=m
  - REGULATOR_HI6421V600=m
  - i386
  - DRM_PANEL_SAMSUNG_S6E63M0_SPI=m
  - DRM_PANEL_SAMSUNG_S6E63M0_DSI=m
  - PHY_INTEL_LGM_COMBO=y
  - ppc64 / ppc64le
  - PPC_RTAS_FILTER=y
  - I2C_SLAVE_TESTUNIT=n
  - s390x
  - PCS_XPCS=m
  - VFIO_PCI_ZDEV=y
  - ZCRYPT_DEBUG=n
  - DEBUG_WX=n
  - PTDUMP_DEBUGFS=n
  - riscv64
  - EFI=y
  - FIRMWARE_MEMMAP=y
  - GOOGLE_FIRMWARE=n
  - EFI_VARS_PSTORE=m
  - EFI_VARS_PSTORE_DEFAULT_DISABLE=n
  - EFI_BOOTLOADER_CONTROL=m
  - EFI_CAPSULE_LOADER=m
  - EFI_TEST=n
  - RESET_ATTACK_MITIGATION=n
  - EFI_DISABLE_PCI_DMA=n
  - FB_EFI=y
  - MMC_DW=m
  - MMC_DW_PLTFM=m
  - MMC_DW_BLUEFIELD=m
  - MMC_DW_EXYNOS=m
  - MMC_DW_HI3798CV200=m
  - MMC_DW_K3=m
  - MMC_DW_PCI=m
  - RTC_DRV_EFI=m
  - EFIVAR_FS=m
- commit 3c50825
* Sun Oct 25 2020 mkubecek@suse.cz
- kernel-binary.spec.in: pack scripts/module.lds into kernel-$flavor-devel
  Since mainline commit 596b0474d3d9 ("kbuild: preprocess module linker
  script") in 5.10-rc1, scripts/module.lds linker script is needed to build
  out of tree modules. Add it into kernel-$flavor-devel subpackage.
- commit fe37c16
* Fri Oct 23 2020 tiwai@suse.de
- drm/amd/display: Don't invoke kgdb_breakpoint() unconditionally
  (bsc#1177973).
- drm/amd/display: Fix kernel panic by dal_gpio_open() error
  (bsc#1177973).
- commit 3f21462
* Mon Oct 19 2020 tiwai@suse.de
- rpm/split-modules: Avoid errors even if Module.* are not present
- commit 752fbc6
* Sun Oct 18 2020 mkubecek@suse.cz
- series.conf: cleanup
- move to "almost mainline" section:
  patches.suse/coresight-fix-offset-by-one-error-in-counting-ports.patch
- commit 8e0635b
* Sun Oct 18 2020 jslaby@suse.cz
- Refresh
  patches.suse/coresight-fix-offset-by-one-error-in-counting-ports.patch.
  Update upstream status.
- commit 7b40cc9
* Sun Oct 18 2020 jslaby@suse.cz
- Linux 5.9.1 (bsc#1012628).
- Bluetooth: MGMT: Fix not checking if BT_HS is enabled
  (bsc#1012628).
- media: usbtv: Fix refcounting mixup (bsc#1012628).
- USB: serial: option: add Cellient MPL200 card (bsc#1012628).
- USB: serial: option: Add Telit FT980-KS composition
  (bsc#1012628).
- staging: comedi: check validity of wMaxPacketSize of usb
  endpoints found (bsc#1012628).
- USB: serial: pl2303: add device-id for HP GC device
  (bsc#1012628).
- USB: serial: ftdi_sio: add support for FreeCalypso JTAG+UART
  adapters (bsc#1012628).
- vt_ioctl: make VT_RESIZEX behave like VT_RESIZE (bsc#1012628).
- reiserfs: Initialize inode keys properly (bsc#1012628).
- reiserfs: Fix oops during mount (bsc#1012628).
- Revert "drm/amdgpu: Fix NULL dereference in dpm sysfs handlers"
  (bsc#1012628).
- crypto: bcm - Verify GCM/CCM key length in setkey (bsc#1012628).
- crypto: qat - check cipher length for aead AES-CBC-HMAC-SHA
  (bsc#1012628).
- commit b7f511b
* Fri Oct 16 2020 mkubecek@suse.cz
- update patches metadata
- update upstream references:
  patches.suse/Bluetooth-A2MP-Fix-not-initializing-all-members.patch
  patches.suse/Bluetooth-L2CAP-Fix-calling-sk_filter-on-non-socket-.patch
- commit b1f22f7
* Thu Oct 15 2020 jslaby@suse.cz
- x86/unwind/orc: Fix inactive tasks with stack pointer in %%sp
  on GCC 10 compiled kernels (bsc#1176907).
- commit c680e93
* Thu Oct 15 2020 jslaby@suse.cz
- Bluetooth: L2CAP: Fix calling sk_filter on non-socket based
  channel (bsc#1177724 CVE-2020-12351).
- commit 8f9e7d2
* Thu Oct 15 2020 tiwai@suse.de
- Bluetooth: A2MP: Fix not initializing all members
  (CVE-2020-12352 bsc#1177725).
- commit 74ef4a4
* Wed Oct 14 2020 tiwai@suse.de
- Update config files: CONFIG_PINCTRL_AMD=y for fixing dependency (bsc#1177049)
- commit 233d0fc
* Wed Oct 14 2020 jslaby@suse.cz
- platform/x86: intel-vbtn: Revert "Fix SW_TABLET_MODE always
  reporting 1 on the HP Pavilion 11 x360" (git-fixes).
- net_sched: check error pointer in tcf_dump_walker() (git-fixes).
- net_sched: remove a redundant goto chain check (git-fixes).
- net: qrtr: ns: Fix the incorrect usage of rcu_read_lock()
  (git-fixes).
- commit db08e19
* Wed Oct 14 2020 jslaby@suse.cz
- platform/x86: intel-vbtn: Switch to an allow-list for
  SW_TABLET_MODE reporting (bsc#1012628 bsc#1175599)
- commit 4144623
* Wed Oct 14 2020 jslaby@suse.cz
- Linux 5.8.15 (bsc#1012628).
- net_sched: commit action insertions together (bsc#1012628).
- net_sched: defer tcf_idr_insert() in tcf_action_init_1()
  (bsc#1012628).
- net: qrtr: ns: Protect radix_tree_deref_slot() using rcu read
  locks (bsc#1012628).
- net: usb: rtl8150: set random MAC address when
  set_ethernet_addr() fails (bsc#1012628).
- Input: ati_remote2 - add missing newlines when printing module
  parameters (bsc#1012628).
- tty/vt: Do not warn when huge selection requested (bsc#1012628).
- net/mlx5e: Fix driver's declaration to support GRE offload
  (bsc#1012628).
- net/tls: race causes kernel panic (bsc#1012628).
- net: bridge: fdb: don't flush ext_learn entries (bsc#1012628).
- net/core: check length before updating Ethertype in
  skb_mpls_{push,pop} (bsc#1012628).
- netlink: fix policy dump leak (bsc#1012628).
- tcp: fix receive window update in tcp_add_backlog()
  (bsc#1012628).
- mm: khugepaged: recalculate min_free_kbytes after memory
  hotplug as expected by khugepaged (bsc#1012628).
- mm: validate inode in mapping_set_error() (bsc#1012628).
- mmc: core: don't set limits.discard_granularity as 0
  (bsc#1012628).
- perf: Fix task_function_call() error handling (bsc#1012628).
- afs: Fix deadlock between writeback and truncate (bsc#1012628).
- net: mscc: ocelot: divide watermark value by 60 when writing
  to SYS_ATOP (bsc#1012628).
- net: mscc: ocelot: extend watermark encoding function
  (bsc#1012628).
- net: mscc: ocelot: split writes to pause frame enable bit and
  to thresholds (bsc#1012628).
- net: mscc: ocelot: rename ocelot_board.c to ocelot_vsc7514.c
  (bsc#1012628).
- rxrpc: Fix server keyring leak (bsc#1012628).
- rxrpc: The server keyring isn't network-namespaced
  (bsc#1012628).
- rxrpc: Fix some missing _bh annotations on locking
  conn->state_lock (bsc#1012628).
- rxrpc: Downgrade the BUG() for unsupported token type in
  rxrpc_read() (bsc#1012628).
- rxrpc: Fix rxkad token xdr encoding (bsc#1012628).
- net: mvneta: fix double free of txq->buf (bsc#1012628).
- vhost-vdpa: fix page pinning leakage in error path
  (bsc#1012628).
- vhost-vdpa: fix vhost_vdpa_map() on error condition
  (bsc#1012628).
- net: hinic: fix DEVLINK build errors (bsc#1012628).
- net: stmmac: Modify configuration method of EEE timers
  (bsc#1012628).
- net/mlx5e: Fix race condition on nhe->n pointer in neigh update
  (bsc#1012628).
- net/mlx5e: Fix VLAN create flow (bsc#1012628).
- net/mlx5e: Fix VLAN cleanup flow (bsc#1012628).
- net/mlx5e: Fix return status when setting unsupported FEC mode
  (bsc#1012628).
- net/mlx5e: Add resiliency in Striding RQ mode for packets
  larger than MTU (bsc#1012628).
- net/mlx5: Fix request_irqs error flow (bsc#1012628).
- net/mlx5: Add retry mechanism to the command entry index
  allocation (bsc#1012628).
- net/mlx5: poll cmd EQ in case of command timeout (bsc#1012628).
- net/mlx5: Avoid possible free of command entry while timeout
  comp handler (bsc#1012628).
- net/mlx5: Fix a race when moving command interface to polling
  mode (bsc#1012628).
- pipe: Fix memory leaks in create_pipe_files() (bsc#1012628).
- octeontx2-pf: Fix synchnorization issue in mbox (bsc#1012628).
- octeontx2-pf: Fix the device state on error (bsc#1012628).
- octeontx2-pf: Fix TCP/UDP checksum offload for IPv6 frames
  (bsc#1012628).
- octeontx2-af: Fix enable/disable of default NPC entries
  (bsc#1012628).
- net: phy: realtek: fix rtl8211e rx/tx delay config
  (bsc#1012628).
- virtio-net: don't disable guest csum when disable LRO
  (bsc#1012628).
- net: usb: ax88179_178a: fix missing stop entry in driver_info
  (bsc#1012628).
- r8169: fix RTL8168f/RTL8411 EPHY config (bsc#1012628).
- mlxsw: spectrum_acl: Fix mlxsw_sp_acl_tcam_group_add()'s error
  path (bsc#1012628).
- mdio: fix mdio-thunder.c dependency & build error (bsc#1012628).
- bonding: set dev->needed_headroom in bond_setup_by_slave()
  (bsc#1012628).
- net: ethernet: cavium: octeon_mgmt: use phy_start and phy_stop
  (bsc#1012628).
- net: stmmac: Fix clock handling on remove path (bsc#1012628).
- vmxnet3: fix cksum offload issues for non-udp tunnels
  (bsc#1012628).
- ice: fix memory leak in ice_vsi_setup (bsc#1012628).
- ice: fix memory leak if register_netdev_fails (bsc#1012628).
- iavf: Fix incorrect adapter get in iavf_resume (bsc#1012628).
- iavf: use generic power management (bsc#1012628).
- xfrm: Use correct address family in xfrm_state_find
  (bsc#1012628).
- net: dsa: felix: convert TAS link speed based on phylink speed
  (bsc#1012628).
- hinic: fix wrong return value of mac-set cmd (bsc#1012628).
- hinic: add log in exception handling processes (bsc#1012628).
- platform/x86: fix kconfig dependency warning for FUJITSU_LAPTOP
  (bsc#1012628).
- platform/x86: fix kconfig dependency warning for LG_LAPTOP
  (bsc#1012628).
- net: stmmac: removed enabling eee in EEE set callback
  (bsc#1012628).
- xsk: Do not discard packet when NETDEV_TX_BUSY (bsc#1012628).
- xfrm: clone whole liftime_cur structure in xfrm_do_migrate
  (bsc#1012628).
- xfrm: clone XFRMA_SEC_CTX in xfrm_do_migrate (bsc#1012628).
- xfrm: clone XFRMA_REPLAY_ESN_VAL in xfrm_do_migrate
  (bsc#1012628).
- xfrm: clone XFRMA_SET_MARK in xfrm_do_migrate (bsc#1012628).
- iommu/vt-d: Fix lockdep splat in iommu_flush_dev_iotlb()
  (bsc#1012628).
- btrfs: move btrfs_rm_dev_replace_free_srcdev outside of all
  locks (bsc#1012628).
- drm/amd/display: fix return value check for hdcp_work
  (bsc#1012628).
- drm/amd/pm: Removed fixed clock in auto mode DPM (bsc#1012628).
- io_uring: fix potential ABBA deadlock in ->show_fdinfo()
  (bsc#1012628).
- btrfs: move btrfs_scratch_superblocks into
  btrfs_dev_replace_finishing (bsc#1012628).
- drm/amdgpu: prevent double kfree ttm->sg (bsc#1012628).
- openvswitch: handle DNAT tuple collision (bsc#1012628).
- net: team: fix memory leak in __team_options_register
  (bsc#1012628).
- team: set dev->needed_headroom in team_setup_by_port()
  (bsc#1012628).
- sctp: fix sctp_auth_init_hmacs() error path (bsc#1012628).
- i2c: owl: Clear NACK and BUS error bits (bsc#1012628).
- i2c: meson: fixup rate calculation with filter delay
  (bsc#1012628).
- i2c: meson: keep peripheral clock enabled (bsc#1012628).
- i2c: meson: fix clock setting overwrite (bsc#1012628).
- cifs: Fix incomplete memory allocation on setxattr path
  (bsc#1012628).
- espintcp: restore IP CB before handing the packet to xfrm
  (bsc#1012628).
- xfrmi: drop ignore_df check before updating pmtu (bsc#1012628).
- nvme-tcp: check page by sendpage_ok() before calling
  kernel_sendpage() (bsc#1012628).
- tcp: use sendpage_ok() to detect misused .sendpage
  (bsc#1012628).
- net: introduce helper sendpage_ok() in include/linux/net.h
  (bsc#1012628).
- mm/khugepaged: fix filemap page_to_pgoff(page) != offset
  (bsc#1012628).
- gpiolib: Disable compat ->read() code in UML case (bsc#1012628).
- RISC-V: Make sure memblock reserves the memory containing DT
  (bsc#1012628).
- macsec: avoid use-after-free in macsec_handle_frame()
  (bsc#1012628).
- nvme-core: put ctrl ref when module ref get fail (bsc#1012628).
- platform/x86: thinkpad_acpi: re-initialize ACPI buffer size
  when reuse (bsc#1012628).
- r8169: consider that PHY reset may still be in progress after
  applying firmware (bsc#1012628).
- bpf: Prevent .BTF section elimination (bsc#1012628).
- bpf: Fix sysfs export of empty BTF section (bsc#1012628).
- platform/x86: asus-wmi: Fix SW_TABLET_MODE always reporting
  1 on many different models (bsc#1012628).
- platform/x86: thinkpad_acpi: initialize tp_nvram_state variable
  (bsc#1012628).
- platform/x86: intel-vbtn: Fix SW_TABLET_MODE always reporting
  1 on the HP Pavilion 11 x360 (bsc#1012628).
- Platform: OLPC: Fix memleak in olpc_ec_probe (bsc#1012628).
- splice: teach splice pipe reading about empty pipe buffers
  (bsc#1012628).
- usermodehelper: reset umask to default before executing user
  process (bsc#1012628).
- vhost: Use vhost_get_used_size() in vhost_vring_set_addr()
  (bsc#1012628).
- vhost: Don't call access_ok() when using IOTLB (bsc#1012628).
- block/scsi-ioctl: Fix kernel-infoleak in
  scsi_put_cdrom_generic_arg() (bsc#1012628).
- partitions/ibm: fix non-DASD devices (bsc#1012628).
- drm/nouveau/mem: guard against NULL pointer access in mem_del
  (bsc#1012628).
- drm/nouveau/device: return error for unknown chipsets
  (bsc#1012628).
- net: wireless: nl80211: fix out-of-bounds access in
  nl80211_del_key() (bsc#1012628).
- exfat: fix use of uninitialized spinlock on error path
  (bsc#1012628).
- crypto: arm64: Use x16 with indirect branch to bti_c
  (bsc#1012628).
- bpf: Fix scalar32_min_max_or bounds tracking (bsc#1012628).
- Revert "ravb: Fixed to be able to unload modules" (bsc#1012628).
- fbcon: Fix global-out-of-bounds read in fbcon_get_font()
  (bsc#1012628).
- Fonts: Support FONT_EXTRA_WORDS macros for built-in fonts
  (bsc#1012628).
- fbdev, newport_con: Move FONT_EXTRA_WORDS macros into
  linux/font.h (bsc#1012628).
- commit 1dc82dd
* Tue Oct 13 2020 tiwai@suse.de
- Add the support for kernel-FLAVOR-optional subpackage (jsc#SLE-11796)
  This change allows to create kernel-*-optional subpackage containing
  the modules that are not shipped on SLE but only on Leap.  Those
  modules are marked in the new "-!optional" marker in supported.conf.
  Flip split_optional definition in kernel-binaries.spec.in for the
  branch that needs the splitting.
- commit 1fa25f8
* Mon Oct 12 2020 mkubecek@suse.cz
- Update to 5.9 final
- eliminated 1 patch
  - patches.suse/bpf-Fix-unresolved-symbol-build-error-with-resolve_b.patch
- update configs
  - MLX5_VDPA=y, MLX5_VDPA_NET=m
  - restore FB_ARMCLCD (y on armv6hl and armv7hl, n on arm64)
- commit 11733e1
* Fri Oct  9 2020 mkubecek@suse.cz
- config: disable DEBUG_INFO_BTF in s390x/zfcpdump
  Even if the build has been fixed, there is little use for BTF debug
  information in kernel-zfcpdump so disable it there.
- commit e7595e7
* Thu Oct  8 2020 msuchanek@suse.de
- kernel-binary.spec.in: Exclude .config.old from kernel-devel
  - use tar excludes for .kernel-binary.spec.buildenv
- commit 939a79b
* Wed Oct  7 2020 msuchanek@suse.de
- kernel-binary.spec.in: Package the obj_install_dir as explicit filelist.
- commit 5587762
* Wed Oct  7 2020 jslaby@suse.cz
- Update config files.
  Only run_oldconfig.sh to sync up.
- commit cea47bb
* Wed Oct  7 2020 jslaby@suse.cz
- Linux 5.8.14 (bsc#1012628).
- io_uring: always delete double poll wait entry on match
  (bsc#1012628).
- btrfs: fix filesystem corruption after a device replace
  (bsc#1012628).
- mmc: sdhci: Workaround broken command queuing on Intel GLK
  based IRBIS models (bsc#1012628).
- USB: gadget: f_ncm: Fix NDP16 datagram validation (bsc#1012628).
- Revert "usbip: Implement a match function to fix usbip"
  (bsc#1012628).
- usbcore/driver: Fix specific driver selection (bsc#1012628).
- usbcore/driver: Fix incorrect downcast (bsc#1012628).
- usbcore/driver: Accommodate usbip (bsc#1012628).
- gpio: siox: explicitly support only threaded irqs (bsc#1012628).
- gpio: mockup: fix resource leak in error path (bsc#1012628).
- gpio: tc35894: fix up tc35894 interrupt configuration
  (bsc#1012628).
- gpio: amd-fch: correct logic of GPIO_LINE_DIRECTION
  (bsc#1012628).
- clk: samsung: Keep top BPLL mux on Exynos542x enabled
  (bsc#1012628).
- clk: socfpga: stratix10: fix the divider for the
  emac_ptp_free_clk (bsc#1012628).
- scsi: iscsi: iscsi_tcp: Avoid holding spinlock while calling
  getpeername() (bsc#1012628).
- i2c: i801: Exclude device from suspend direct complete
  optimization (bsc#1012628).
- Input: i8042 - add nopnp quirk for Acer Aspire 5 A515
  (bsc#1012628).
- iio: adc: qcom-spmi-adc5: fix driver name (bsc#1012628).
- ftrace: Move RCU is watching check after recursion check
  (bsc#1012628).
- tracing: Fix trace_find_next_entry() accounting of temp buffer
  size (bsc#1012628).
- memstick: Skip allocating card when removing host (bsc#1012628).
- xen/events: don't use chip_data for legacy IRQs (bsc#1012628).
- clocksource/drivers/timer-gx6605s: Fixup counter reload
  (bsc#1012628).
- vboxsf: Fix the check for the old binary mount-arguments struct
  (bsc#1012628).
- mt76: mt7915: use ieee80211_free_txskb to free tx skbs
  (bsc#1012628).
- libbpf: Remove arch-specific include path in Makefile
  (bsc#1012628).
- drivers/net/wan/hdlc_fr: Add needed_headroom for PVC devices
  (bsc#1012628).
- Revert "wlcore: Adding suppoprt for IGTK key in wlcore driver"
  (bsc#1012628).
- drm/sun4i: mixer: Extend regmap max_register (bsc#1012628).
- hv_netvsc: Cache the current data path to avoid duplicate call
  and message (bsc#1012628).
- net: dec: de2104x: Increase receive ring size for Tulip
  (bsc#1012628).
- rndis_host: increase sleep time in the query-response loop
  (bsc#1012628).
- nvme-pci: disable the write zeros command for Intel 600P/P3100
  (bsc#1012628).
- nvme-core: get/put ctrl and transport module in
  nvme_dev_open/release() (bsc#1012628).
- fuse: fix the ->direct_IO() treatment of iov_iter (bsc#1012628).
- drivers/net/wan/lapbether: Make skb->protocol consistent with
  the header (bsc#1012628).
- drivers/net/wan/hdlc: Set skb->protocol before transmitting
  (bsc#1012628).
- mac80211: Fix radiotap header channel flag for 6GHz band
  (bsc#1012628).
- mac80211: do not allow bigger VHT MPDUs than the hardware
  supports (bsc#1012628).
- tracing: Make the space reserved for the pid wider
  (bsc#1012628).
- tools/io_uring: fix compile breakage (bsc#1012628).
- io_uring: mark statx/files_update/epoll_ctl as non-SQPOLL
  (bsc#1012628).
- cpuidle: psci: Fix suspicious RCU usage (bsc#1012628).
- spi: fsl-espi: Only process interrupts for expected events
  (bsc#1012628).
- net: dsa: felix: fix some key offsets for IP4_TCP_UDP VCAP
  IS2 entries (bsc#1012628).
- nvme-pci: fix NULL req in completion handler (bsc#1012628).
- nvme-fc: fail new connections to a deleted host or remote port
  (bsc#1012628).
- scripts/kallsyms: skip ppc compiler stub *.long_branch.* /
  * .plt_branch.* (bsc#1012628).
- gpio: sprd: Clear interrupt when setting the type as edge
  (bsc#1012628).
- phy: ti: am654: Fix a leak in serdes_am654_probe()
  (bsc#1012628).
- pinctrl: mvebu: Fix i2c sda definition for 98DX3236
  (bsc#1012628).
- nfs: Fix security label length not being reset (bsc#1012628).
- NFSv4.2: fix client's attribute cache management for
  copy_file_range (bsc#1012628).
- pNFS/flexfiles: Ensure we initialise the mirror bsizes correctly
  on read (bsc#1012628).
- clk: tegra: Always program PLL_E when enabled (bsc#1012628).
- clk: tegra: Fix missing prototype for
  tegra210_clk_register_emc() (bsc#1012628).
- dmaengine: dmatest: Prevent to run on misconfigured channel
  (bsc#1012628).
- clk: samsung: exynos4: mark 'chipid' clock as CLK_IGNORE_UNUSED
  (bsc#1012628).
- scsi: target: Fix lun lookup for TARGET_SCF_LOOKUP_LUN_FROM_TAG
  case (bsc#1012628).
- iommu/exynos: add missing put_device() call in
  exynos_iommu_of_xlate() (bsc#1012628).
- gpio: pca953x: Fix uninitialized pending variable (bsc#1012628).
- gpio/aspeed-sgpio: enable access to all 80 input & output sgpios
  (bsc#1012628).
- gpio/aspeed-sgpio: don't enable all interrupts by default
  (bsc#1012628).
- gpio: aspeed: fix ast2600 bank properties (bsc#1012628).
- i2c: cpm: Fix i2c_ram structure (bsc#1012628).
- i2c: npcm7xx: Clear LAST bit after a failed transaction
  (bsc#1012628).
- Input: trackpoint - enable Synaptics trackpoints (bsc#1012628).
- blk-mq: call commit_rqs while list empty but error happen
  (bsc#1012628).
- scripts/dtc: only append to HOST_EXTRACFLAGS instead of
  overwriting (bsc#1012628).
- autofs: use __kernel_write() for the autofs pipe writing
  (bsc#1012628).
- pinctrl: qcom: sm8250: correct sdc2_clk (bsc#1012628).
- pinctrl: mediatek: check mtk_is_virt_gpio input parameter
  (bsc#1012628).
- gpio: pca953x: Correctly initialize registers 6 and 7 for
  PCA957x (bsc#1012628).
- iommu/amd: Fix the overwritten field in IVMD header
  (bsc#1012628).
- pipe: remove pipe_wait() and fix wakeup race with splice
  (bsc#1012628).
- random32: Restore __latent_entropy attribute on net_rand_state
  (bsc#1012628).
- gpiolib: Fix line event handling in syscall compatible mode
  (bsc#1012628).
- drm/i915/gvt: Fix port number for BDW on EDID region setup
  (bsc#1012628).
- scsi: sd: sd_zbc: Fix handling of host-aware ZBC disks
  (bsc#1012628).
- scsi: sd: sd_zbc: Fix ZBC disk initialization (bsc#1012628).
- epoll: do not insert into poll queues until all sanity checks
  are done (bsc#1012628).
- epoll: replace ->visited/visited_list with generation count
  (bsc#1012628).
- epoll: EPOLL_CTL_ADD: close the race in decision to take fast
  path (bsc#1012628).
- ep_create_wakeup_source(): dentry name can change under
  you.. (bsc#1012628).
- commit e882d6e
* Mon Oct  5 2020 afaerber@suse.com
- rpm/mkspec-dtb: Update for 5.9
  arch/arm64/boot/dts/al subdir has been renamed to amazon.
- commit e450c4d
* Mon Oct  5 2020 tiwai@suse.de
- platform/x86: intel-vbtn: Switch to an allow-list for
  SW_TABLET_MODE reporting (bsc#1175599).
- commit 5672f81
* Mon Oct  5 2020 afaerber@suse.com
- config: armv7hl: Update to 5.9-rc8
- commit 2a6c374
* Mon Oct  5 2020 afaerber@suse.com
- config: armv6hl: Update to 5.9-rc8
- commit 52c5e56
* Mon Oct  5 2020 afaerber@suse.com
- config: arm64: Update to 5.9-rc8
- commit bbcb0ce
* Mon Oct  5 2020 mkubecek@suse.cz
- Update to 5.9-rc8
- commit f75a311
* Sun Oct  4 2020 mkubecek@suse.cz
- bpf: Fix "unresolved symbol" build error with resolve_btfids
  (http://lkml.kernel.org/r/20200929101737.3ufw36bngkmzppqk@lion.mk-sys.cz).
  Fixes s390x/zfcpdump build failure.
- commit c27d6ab
* Fri Oct  2 2020 jdelvare@suse.de
- drm/amdgpu: restore proper ref count in
  amdgpu_display_crtc_set_config (git-fixes).
- commit 08db7a3
* Fri Oct  2 2020 mkubecek@suse.cz
- config: disable SECURITY_SELINUX_DISABLE also in arm*/* (bsc#1176923)
  The arm configs (both 64-bit and 32-bit) are currently disabled so that
  they cannot be updated the usual way. Apply the changes manually.
- commit a1b15af
* Fri Oct  2 2020 mkubecek@suse.cz
- config: disable SECURITY_SELINUX_DISABLE (bsc#1176923)
- commit 9702a5f
* Thu Oct  1 2020 jslaby@suse.cz
- Linux 5.8.13 (bsc#1012628).
- device_cgroup: Fix RCU list debugging warning (bsc#1012628).
- ASoC: pcm3168a: ignore 0 Hz settings (bsc#1012628).
- ASoC: wm8994: Skip setting of the WM8994_MICBIAS register for
  WM1811 (bsc#1012628).
- ASoC: wm8994: Ensure the device is resumed in wm89xx_mic_detect
  functions (bsc#1012628).
- ASoC: Intel: bytcr_rt5640: Add quirk for MPMAN Converter9 2-in-1
  (bsc#1012628).
- clk: versatile: Add of_node_put() before return statement
  (bsc#1012628).
- RISC-V: Take text_mutex in ftrace_init_nop() (bsc#1012628).
- i2c: aspeed: Mask IRQ status to relevant bits (bsc#1012628).
- s390/init: add missing __init annotations (bsc#1012628).
- lockdep: fix order in trace_hardirqs_off_caller() (bsc#1012628).
- EDAC/ghes: Check whether the driver is on the safe list
  correctly (bsc#1012628).
- drm/amdkfd: fix a memory leak issue (bsc#1012628).
- drm/amd/display: Don't use DRM_ERROR() for DTM add topology
  (bsc#1012628).
- drm/amd/display: update nv1x stutter latencies (bsc#1012628).
- drm/amdgpu/dc: Require primary plane to be enabled whenever
  the CRTC is (bsc#1012628).
- drm/amd/display: Don't log hdcp module warnings in dmesg
  (bsc#1012628).
- objtool: Fix noreturn detection for ignored functions
  (bsc#1012628).
- i2c: mediatek: Send i2c master code at more than 1MHz
  (bsc#1012628).
- riscv: Fix Kendryte K210 device tree (bsc#1012628).
- ieee802154: fix one possible memleak in ca8210_dev_com_init
  (bsc#1012628).
- ieee802154/adf7242: check status of adf7242_read_reg
  (bsc#1012628).
- clocksource/drivers/h8300_timer8: Fix wrong return value in
  h8300_8timer_init() (bsc#1012628).
- mwifiex: Increase AES key storage size to 256 bits
  (bsc#1012628).
- batman-adv: bla: fix type misuse for backbone_gw hash indexing
  (bsc#1012628).
- libbpf: Fix build failure from uninitialized variable warning
  (bsc#1012628).
- atm: eni: fix the missed pci_disable_device() for eni_init_one()
  (bsc#1012628).
- batman-adv: mcast/TT: fix wrongly dropped or rerouted packets
  (bsc#1012628).
- netfilter: ctnetlink: add a range check for l3/l4 protonum
  (bsc#1012628).
- netfilter: ctnetlink: fix mark based dump filtering regression
  (bsc#1012628).
- netfilter: conntrack: nf_conncount_init is failing with IPv6
  disabled (bsc#1012628).
- netfilter: nft_meta: use socket user_ns to retrieve skuid and
  skgid (bsc#1012628).
- mac802154: tx: fix use-after-free (bsc#1012628).
- bpf: Fix clobbering of r2 in bpf_gen_ld_abs (bsc#1012628).
- tools/libbpf: Avoid counting local symbols in ABI check
  (bsc#1012628).
- drm/vc4/vc4_hdmi: fill ASoC card owner (bsc#1012628).
- net: qed: Disable aRFS for NPAR and 100G (bsc#1012628).
- net: qede: Disable aRFS for NPAR and 100G (bsc#1012628).
- net: qed: RDMA personality shouldn't fail VF load (bsc#1012628).
- igc: Fix wrong timestamp latency numbers (bsc#1012628).
- igc: Fix not considering the TX delay for timestamps
  (bsc#1012628).
- drm/sun4i: sun8i-csc: Secondary CSC register correction
  (bsc#1012628).
- spi: spi-fsl-dspi: use XSPI mode instead of DMA for DPAA2 SoCs
  (bsc#1012628).
- RDMA/core: Fix ordering of CQ pool destruction (bsc#1012628).
- batman-adv: Add missing include for in_interrupt()
  (bsc#1012628).
- xsk: Fix number of pinned pages/umem size discrepancy
  (bsc#1012628).
- nvme-tcp: fix kconfig dependency warning when !CRYPTO
  (bsc#1012628).
- batman-adv: mcast: fix duplicate mcast packets in BLA backbone
  from LAN (bsc#1012628).
- batman-adv: mcast: fix duplicate mcast packets in BLA backbone
  from mesh (bsc#1012628).
- batman-adv: mcast: fix duplicate mcast packets from BLA backbone
  to mesh (bsc#1012628).
- bpf: Fix a rcu warning for bpffs map pretty-print (bsc#1012628).
- lib80211: fix unmet direct dependendices config warning when
  !CRYPTO (bsc#1012628).
- mac80211: do not disable HE if HT is missing on 2.4 GHz
  (bsc#1012628).
- cfg80211: fix 6 GHz channel conversion (bsc#1012628).
- mac80211: fix 80 MHz association to 160/80+80 AP on 6 GHz
  (bsc#1012628).
- ALSA: asihpi: fix iounmap in error handler (bsc#1012628).
- io_uring: fix openat/openat2 unified prep handling
  (bsc#1012628).
- SUNRPC: Fix svc_flush_dcache() (bsc#1012628).
- regmap: fix page selection for noinc reads (bsc#1012628).
- regmap: fix page selection for noinc writes (bsc#1012628).
- net/mlx5e: mlx5e_fec_in_caps() returns a boolean (bsc#1012628).
- MIPS: Loongson-3: Fix fp register access if MSA enabled
  (bsc#1012628).
- PM / devfreq: tegra30: Disable clock on error in probe
  (bsc#1012628).
- MIPS: Add the missing 'CPU_1074K' into __get_cpu_type()
  (bsc#1012628).
- regulator: axp20x: fix LDO2/4 description (bsc#1012628).
- spi: bcm-qspi: Fix probe regression on iProc platforms
  (bsc#1012628).
- KVM: x86: Reset MMU context if guest toggles CR4.SMAP or CR4.PKE
  (bsc#1012628).
- KVM: SVM: Add a dedicated INVD intercept routine (bsc#1012628).
- mm: validate pmd after splitting (bsc#1012628).
- arch/x86/lib/usercopy_64.c: fix __copy_user_flushcache()
  cache writeback (bsc#1012628).
- x86/irq: Make run_on_irqstack_cond() typesafe (bsc#1012628).
- x86/ioapic: Unbreak check_timer() (bsc#1012628).
- scsi: lpfc: Fix initial FLOGI failure due to BBSCN not supported
  (bsc#1012628).
- ALSA: usb-audio: Add delay quirk for H570e USB headsets
  (bsc#1012628).
- ALSA: hda/realtek - Couldn't detect Mic if booting with headset
  plugged (bsc#1012628).
- ALSA: hda/realtek: Enable front panel headset LED on Lenovo
  ThinkStation P520 (bsc#1012628).
- lib/string.c: implement stpcpy (bsc#1012628).
- tracing: fix double free (bsc#1012628).
- s390/dasd: Fix zero write for FBA devices (bsc#1012628).
- mt76: mt7615: use v1 MCU API on MT7615 to fix issues with
  adding/removing stations (bsc#1012628).
- lib/bootconfig: Fix a bug of breaking existing tree nodes
  (bsc#1012628).
- lib/bootconfig: Fix to remove tailing spaces after value
  (bsc#1012628).
- kprobes: Fix to check probe enabled before
  disarm_kprobe_ftrace() (bsc#1012628).
- kprobes: tracing/kprobes: Fix to kill kprobes on initmem after
  boot (bsc#1012628).
- btrfs: fix put of uninitialized kobject after seed device delete
  (bsc#1012628).
- btrfs: fix overflow when copying corrupt csums for a message
  (bsc#1012628).
- media: cec-adap.c: don't use flush_scheduled_work()
  (bsc#1012628).
- MIPS: Loongson2ef: Disable Loongson MMI instructions
  (bsc#1012628).
- dmabuf: fix NULL pointer dereference in dma_buf_release()
  (bsc#1012628).
- mm, THP, swap: fix allocating cluster for swapfile by mistake
  (bsc#1012628).
- mm/gup: fix gup_fast with dynamic page table folding
  (bsc#1012628).
- mm: replace memmap_context by meminit_context (bsc#1012628).
- mm: don't rely on system state to detect hot-plug operations
  (bsc#1012628).
- s390/zcrypt: Fix ZCRYPT_PERDEV_REQCNT ioctl (bsc#1012628).
- io_uring: ensure open/openat2 name is cleaned on cancelation
  (bsc#1012628).
- KVM: arm64: Assume write fault on S1PTW permission fault on
  instruction fetch (bsc#1012628).
- dm: fix bio splitting and its bio completion order for regular
  IO (bsc#1012628).
- clocksource/drivers/timer-ti-dm: Do reset before enable
  (bsc#1012628).
- commit ea492d4
* Wed Sep 30 2020 ohering@suse.de
- rpm/constraints.in: recognize also kernel-source-azure (bsc#1176732)
- commit 7214bbe
* Mon Sep 28 2020 jslaby@suse.cz
- hv_netvsc: Switch the data path at the right time during
  hibernation (git-fixes).
- commit 79e03c2
* Mon Sep 28 2020 jslaby@suse.cz
- Linux 5.8.12 (bsc#1012628).
- net/mlx5e: Fix endianness when calculating pedit mask first bit
  (bsc#1012628).
- net/mlx5e: Use synchronize_rcu to sync with NAPI (bsc#1012628).
- net/mlx5e: Use RCU to protect rq->xdp_prog (bsc#1012628).
- Revert "netns: don't disable BHs when locking "nsid_lock""
  (bsc#1012628).
- net: macb: fix for pause frame receive enable bit (bsc#1012628).
- net: dsa: microchip: ksz8795: really set the correct number
  of ports (bsc#1012628).
- net: dsa: link interfaces with the DSA master to get rid of
  lockdep warnings (bsc#1012628).
- hv_netvsc: Fix hibernation for mlx5 VF driver (bsc#1012628).
- hinic: fix rewaking txq after netif_tx_disable (bsc#1012628).
- net/mlx5e: Fix memory leak of tunnel info when rule under
  multipath not ready (bsc#1012628).
- net: ipa: fix u32_replace_bits by u32p_xxx version
  (bsc#1012628).
- wireguard: peerlookup: take lock before checking hash in
  replace operation (bsc#1012628).
- wireguard: noise: take lock when removing handshake entry from
  table (bsc#1012628).
- net: ethernet: ti: cpsw_new: fix suspend/resume (bsc#1012628).
- net: add __must_check to skb_put_padto() (bsc#1012628).
- net: qrtr: check skb_put_padto() return value (bsc#1012628).
- net: phy: Do not warn in phy_stop() on PHY_DOWN (bsc#1012628).
- net: phy: Avoid NPD upon phy_detach() when driver is unbound
  (bsc#1012628).
- net: lantiq: Disable IRQs only if NAPI gets scheduled
  (bsc#1012628).
- net: lantiq: Use napi_complete_done() (bsc#1012628).
- net: lantiq: use netif_tx_napi_add() for TX NAPI (bsc#1012628).
- net: lantiq: Wake TX queue again (bsc#1012628).
- bnxt_en: Protect bnxt_set_eee() and bnxt_set_pauseparam()
  with mutex (bsc#1012628).
- bnxt_en: return proper error codes in bnxt_show_temp
  (bsc#1012628).
- bnxt_en: Use memcpy to copy VPD field info (bsc#1012628).
- net/mlx5e: TLS, Do not expose FPGA TLS counter if not supported
  (bsc#1012628).
- net/mlx5e: Enable adding peer miss rules only if merged eswitch
  is supported (bsc#1012628).
- tipc: use skb_unshare() instead in tipc_buf_append()
  (bsc#1012628).
- tipc: fix shutdown() of connection oriented socket
  (bsc#1012628).
- tipc: Fix memory leak in tipc_group_create_member()
  (bsc#1012628).
- taprio: Fix allowing too small intervals (bsc#1012628).
- nfp: use correct define to return NONE fec (bsc#1012628).
- net: sctp: Fix IPv6 ancestor_size calc in sctp_copy_descendant
  (bsc#1012628).
- net: sch_generic: aviod concurrent reset and enqueue op for
  lockless qdisc (bsc#1012628).
- net: sched: initialize with 0 before setting erspan md->u
  (bsc#1012628).
- net: phy: call phy_disable_interrupts() in phy_attach_direct()
  instead (bsc#1012628).
- net/mlx5: Fix FTE cleanup (bsc#1012628).
- net: ipv6: fix kconfig dependency warning for IPV6_SEG6_HMAC
  (bsc#1012628).
- net: Fix bridge enslavement failure (bsc#1012628).
- net: dsa: rtl8366: Properly clear member config (bsc#1012628).
- net: DCB: Validate DCB_ATTR_DCB_BUFFER argument (bsc#1012628).
- net: bridge: br_vlan_get_pvid_rcu() should dereference the
  VLAN group under RCU (bsc#1012628).
- ipv6: avoid lockdep issue in fib6_del() (bsc#1012628).
- ipv4: Update exception handling for multipath routes via same
  device (bsc#1012628).
- ipv4: Initialize flowi4_multipath_hash in data path
  (bsc#1012628).
- ip: fix tos reflection in ack and reset packets (bsc#1012628).
- hinic: bump up the timeout of SET_FUNC_STATE cmd (bsc#1012628).
- hdlc_ppp: add range checks in ppp_cp_parse_cr() (bsc#1012628).
- geneve: add transport ports in route lookup for geneve
  (bsc#1012628).
- cxgb4: Fix offset when clearing filter byte counters
  (bsc#1012628).
- cxgb4: fix memory leak during module unload (bsc#1012628).
- bnxt_en: Fix NULL ptr dereference crash in bnxt_fw_reset_task()
  (bsc#1012628).
- bnxt_en: Avoid sending firmware messages when AER error is
  detected (bsc#1012628).
- act_ife: load meta modules before tcf_idr_check_alloc()
  (bsc#1012628).
- ibmvnic: add missing parenthesis in do_reset() (bsc#1012628).
- ibmvnic fix NULL tx_pools and rx_tools issue at do_reset
  (bsc#1012628).
- commit 4416947
* Mon Sep 28 2020 mkubecek@suse.cz
- Update to 5.9-rc7
- eliminated 1 patch
  - patches.suse/dax-Fix-compilation-for-CONFIG_DAX-CONFIG_FS_DAX.patch
- commit a5f5f07
* Sun Sep 27 2020 tiwai@suse.de
- i2c: core: Call i2c_acpi_install_space_handler() before
  i2c_acpi_register_devices() (bsc#1176971).
- commit 4178df3
* Thu Sep 24 2020 jslaby@suse.cz
- mptcp: sendmsg: reset iter on error redux (git-fixes).
- commit f4bb27a
* Thu Sep 24 2020 jslaby@suse.cz
- Linux 5.8.11 (bsc#1012628).
- RDMA/bnxt_re: Restrict the max_gids to 256 (bsc#1012628).
- dt-bindings: spi: Fix spi-bcm-qspi compatible ordering
  (bsc#1012628).
- mptcp: sendmsg: reset iter on error (bsc#1012628).
- net: handle the return value of pskb_carve_frag_list() correctly
  (bsc#1012628).
- dt-bindings: PCI: intel,lgm-pcie: Fix matching on all
  snps,dw-pcie instances (bsc#1012628).
- hv_netvsc: Remove "unlikely" from netvsc_select_queue
  (bsc#1012628).
- loop: Set correct device size when using LOOP_CONFIGURE
  (bsc#1012628).
- xprtrdma: Release in-flight MRs on disconnect (bsc#1012628).
- NFSv4.1 handle ERR_DELAY error reclaiming locking state on
  delegation recall (bsc#1012628).
- phy: omap-usb2-phy: disable PHY charger detect (bsc#1012628).
- habanalabs: prevent user buff overflow (bsc#1012628).
- habanalabs: fix report of RAZWI initiator coordinates
  (bsc#1012628).
- scsi: pm8001: Fix memleak in pm8001_exec_internal_task_abort
  (bsc#1012628).
- scsi: libfc: Fix for double free() (bsc#1012628).
- scsi: lpfc: Fix FLOGI/PLOGI receive race condition in pt2pt
  discovery (bsc#1012628).
- scsi: lpfc: Extend the RDF FPIN Registration descriptor for
  additional events (bsc#1012628).
- regulator: pwm: Fix machine constraints application
  (bsc#1012628).
- spi: spi-loopback-test: Fix out-of-bounds read (bsc#1012628).
- interconnect: Show bandwidth for disabled paths as zero in
  debugfs (bsc#1012628).
- NFS: Zero-stateid SETATTR should first return delegation
  (bsc#1012628).
- SUNRPC: stop printk reading past end of string (bsc#1012628).
- rapidio: Replace 'select' DMAENGINES 'with depends on'
  (bsc#1012628).
- cifs: fix DFS mount with cifsacl/modefromsid (bsc#1012628).
- openrisc: Fix cache API compile issue when not inlining
  (bsc#1012628).
- nvme-fc: cancel async events before freeing event struct
  (bsc#1012628).
- nvme-rdma: cancel async events before freeing event struct
  (bsc#1012628).
- nvme-tcp: cancel async events before freeing event struct
  (bsc#1012628).
- block: only call sched requeue_request() for scheduled requests
  (bsc#1012628).
- f2fs: fix indefinite loop scanning for free nid (bsc#1012628).
- f2fs: Return EOF on unaligned end of file DIO read
  (bsc#1012628).
- i2c: algo: pca: Reapply i2c bus settings after reset
  (bsc#1012628).
- spi: Fix memory leak on splited transfers (bsc#1012628).
- KVM: MIPS: Change the definition of kvm type (bsc#1012628).
- clk: davinci: Use the correct size when allocating memory
  (bsc#1012628).
- clk: rockchip: Fix initialization of mux_pll_src_4plls_p
  (bsc#1012628).
- ASoC: Intel: skl_hda_dsp_generic: Fix NULLptr dereference in
  autosuspend delay (bsc#1012628).
- ASoC: qcom: Set card->owner to avoid warnings (bsc#1012628).
- ASoC: rt1308-sdw: Fix return check for devm_regmap_init_sdw()
  (bsc#1012628).
- ASoC: rt711: Fix return check for devm_regmap_init_sdw()
  (bsc#1012628).
- ASoC: rt715: Fix return check for devm_regmap_init_sdw()
  (bsc#1012628).
- ASoC: rt700: Fix return check for devm_regmap_init_sdw()
  (bsc#1012628).
- ASoC: qcom: common: Fix refcount imbalance on error
  (bsc#1012628).
- drm/mediatek: dsi: Fix scrolling of panel with small hfp or hbp
  (bsc#1012628).
- powerpc/book3s64/radix: Fix boot failure with large amount of
  guest memory (bsc#1012628).
- ASoC: soc-core: add snd_soc_find_dai_with_mutex() (bsc#1012628).
- ASoC: meson: axg-toddr: fix channel order on g12 platforms
  (bsc#1012628).
- ASoC: tlv320adcx140: Fix accessing uninitialized adcx140->dev
  (bsc#1012628).
- ASoC: Intel: haswell: Fix power transition refactor
  (bsc#1012628).
- ASoC: core: Do not cleanup uninitialized dais on soc_pcm_open
  failure (bsc#1012628).
- Drivers: hv: vmbus: hibernation: do not hang forever in
  vmbus_bus_resume() (bsc#1012628).
- scsi: libsas: Fix error path in sas_notify_lldd_dev_found()
  (bsc#1012628).
- arm64: Allow CPUs unffected by ARM erratum 1418040 to come in
  late (bsc#1012628).
- Drivers: hv: vmbus: Add timeout to vmbus_wait_for_unload
  (bsc#1012628).
- perf test: Fix the "signal" test inline assembly (bsc#1012628).
- perf record: Don't clear event's period if set by a term
  (bsc#1012628).
- MIPS: SNI: Fix MIPS_L1_CACHE_SHIFT (bsc#1012628).
- perf test: Free aliases for PMU event map aliases test
  (bsc#1012628).
- perf metric: Fix some memory leaks (bsc#1012628).
- perf evlist: Fix cpu/thread map leak (bsc#1012628).
- perf parse-event: Fix memory leak in evsel->unit (bsc#1012628).
- perf test: Free formats for perf pmu parse test (bsc#1012628).
- drm/i915/gem: Reduce context termination list iteration guard
  to RCU (bsc#1012628).
- fbcon: Fix user font detection test at fbcon_resize()
  (bsc#1012628).
- MIPS: SNI: Fix spurious interrupts (bsc#1012628).
- drm/mediatek: Use CPU when fail to get cmdq event (bsc#1012628).
- drm/mediatek: Add missing put_device() call in
  mtk_ddp_comp_init() (bsc#1012628).
- drm/mediatek: Add exception handing in mtk_drm_probe() if
  component init fail (bsc#1012628).
- drm/mediatek: Add missing put_device() call in
  mtk_drm_kms_init() (bsc#1012628).
- drm/mediatek: Add missing put_device() call in
  mtk_hdmi_dt_parse_pdata() (bsc#1012628).
- arm64: bpf: Fix branch offset in JIT (bsc#1012628).
- iommu/amd: Fix potential @entry null deref (bsc#1012628).
- iommu/amd: Restore IRTE.RemapEn bit for
  amd_iommu_activate_guest_mode (bsc#1012628).
- kconfig: qconf: use delete[] instead of delete to free array
  (again) (bsc#1012628).
- i2c: mediatek: Fix generic definitions for bus frequency
  (bsc#1012628).
- i2c: mxs: use MXS_DMA_CTRL_WAIT4END instead of DMA_CTRL_ACK
  (bsc#1012628).
- riscv: Add sfence.vma after early page table changes
  (bsc#1012628).
- locking/lockdep: Fix "USED" <- "IN-NMI" inversions
  (bsc#1012628).
- efi: efibc: check for efivars write capability (bsc#1012628).
- locking/percpu-rwsem: Use this_cpu_{inc,dec}() for read_count
  (bsc#1012628).
- x86/unwind/fp: Fix FP unwinding in ret_from_fork (bsc#1012628).
- drm/kfd: fix a system crash issue during GPU recovery
  (bsc#1012628).
- drm/i915/gem: Delay tracking the GEM context until it is
  registered (bsc#1012628).
- drm/i915: Filter wake_flags passed to default_wake_function
  (bsc#1012628).
- USB: quirks: Add USB_QUIRK_IGNORE_REMOTE_WAKEUP quirk for BYD
  zhaoxin notebook (bsc#1012628).
- USB: UAS: fix disconnect by unplugging a hub (bsc#1012628).
- usblp: fix race between disconnect() and read() (bsc#1012628).
- usb: typec: ucsi: acpi: Increase command completion timeout
  value (bsc#1012628).
- usb: typec: ucsi: Prevent mode overrun (bsc#1012628).
- i2c: i801: Fix resume bug (bsc#1012628).
- Revert "ALSA: hda - Fix silent audio output and corrupted
  input on MSI X570-A PRO" (bsc#1012628).
- ALSA: hda: fixup headset for ASUS GX502 laptop (bsc#1012628).
- ALSA: hda/realtek - The Mic on a RedmiBook doesn't work
  (bsc#1012628).
- percpu: fix first chunk size calculation for populated bitmap
  (bsc#1012628).
- Input: trackpoint - add new trackpoint variant IDs
  (bsc#1012628).
- Input: i8042 - add Entroware Proteus EL07R4 to nomux and reset
  lists (bsc#1012628).
- thunderbolt: Retry DROM read once if parsing fails
  (bsc#1012628).
- serial: 8250_pci: Add Realtek 816a and 816b (bsc#1012628).
- serial: core: fix port-lock initialisation (bsc#1012628).
- serial: core: fix console port-lock regression (bsc#1012628).
- x86/boot/compressed: Disable relocation relaxation
  (bsc#1012628).
- ksm: reinstate memcg charge on copied pages (bsc#1012628).
- kprobes: fix kill kprobe which has been marked as gone
  (bsc#1012628).
- mm/thp: fix __split_huge_pmd_locked() for migration PMD
  (bsc#1012628).
- s390: add 3f program exception handler (bsc#1012628).
- s390/pci: fix leak of DMA tables on hard unplug (bsc#1012628).
- s390/zcrypt: fix kmalloc 256k failure (bsc#1012628).
- ehci-hcd: Move include to keep CRC stable (bsc#1012628).
- arm64: paravirt: Initialize steal time when cpu is online
  (bsc#1012628).
- powerpc/dma: Fix dma_map_ops::get_required_mask (bsc#1012628).
- selftests/vm: fix display of page size in map_hugetlb
  (bsc#1012628).
- dm/dax: Fix table reference counts (bsc#1012628).
- mm/memory_hotplug: drain per-cpu pages again during memory
  offline (bsc#1012628).
- dm: Call proper helper to determine dax support (bsc#1012628).
- dax: Fix compilation for CONFIG_DAX && !CONFIG_FS_DAX
  (bsc#1012628).
- mm: memcg: fix memcg reclaim soft lockup (bsc#1012628).
- nvme-loop: set ctrl state connecting after init (bsc#1012628).
- commit f26e9c9
* Tue Sep 22 2020 msuchanek@suse.de
- kernel-syms.spec.in: Also use bz compression (boo#1175882).
- commit ecaf78d
* Tue Sep 22 2020 mkubecek@suse.cz
- dax: Fix compilation for CONFIG_DAX && !CONFIG_FS_DAX
  (http://lkml.kernel.org/r/20200921010359.GO3027113@arch-chirva.localdomain).
- commit 289d4e9
* Mon Sep 21 2020 jslaby@suse.cz
- Update
  patches.kernel.org/5.8.10-047-block-restore-a-specific-error-code-in-bdev_de.patch
  (bsc#1012628 bsc#1176770).
  Add a reference.
- commit af3e800
* Mon Sep 21 2020 tiwai@suse.de
- Update config files: turn off CONFIG_SND_CTL_VALIDATION again (bsc#1176200)
  This causes errors on ASoC SOF driver.
- commit b7791aa
* Mon Sep 21 2020 mkubecek@suse.cz
- Update to 5.9-rc6
- refresh configs
  - drop VGACON_SOFT_SCROLLBACK and related
- commit bf46e69
* Mon Sep 21 2020 glin@suse.com
- rpm/kernel-cert-subpackage: add CA check on key enrollment (bsc#1173115)
  To avoid the unnecessary key enrollment, when enrolling the signing key
  of the kernel package, "--ca-check" is added to mokutil so that mokutil
  will ignore the request if the CA of the signing key already exists in
  MokList or UEFI db.
  Since the macro, %%_suse_kernel_module_subpackage, is only defined in a
  kernel module package (KMP), it's used to determine whether the %%post
  script is running in a kernel package, or a kernel module package.
- commit b15c9bf
* Fri Sep 18 2020 jslaby@suse.cz
- RDMA/bnxt_re: Remove set but not used variable 'qplib_ctx'
  (git-fixes).
- commit 33939e8
* Fri Sep 18 2020 glin@suse.com
- rpm/macros.kernel-source: pass -c proerly in kernel module package (bsc#1176698)
  The "-c" option wasn't passed down to %%_kernel_module_package so the
  ueficert subpackage wasn't generated even if the certificate is
  specified in the spec file.
- commit 34808fb
* Thu Sep 17 2020 jslaby@suse.cz
- Linux 5.8.10 (bsc#1012628).
- gcov: add support for GCC 10.1 (bsc#1012628).
- drm/msm/gpu: make ringbuffer readonly (bsc#1012628).
- usb: typec: intel_pmc_mux: Do not configure SBU and HSL
  Orientation in Alternate modes (bsc#1012628).
- usb: typec: intel_pmc_mux: Do not configure Altmode HPD High
  (bsc#1012628).
- usb: typec: intel_pmc_mux: Un-register the USB role switch
  (bsc#1012628).
- usb: typec: ucsi: acpi: Check the _DEP dependencies
  (bsc#1012628).
- usb: Fix out of sync data toggle if a configured device is
  reconfigured (bsc#1012628).
- USB: serial: option: add support for SIM7070/SIM7080/SIM7090
  modules (bsc#1012628).
- USB: serial: option: support dynamic Quectel USB compositions
  (bsc#1012628).
- USB: serial: ftdi_sio: add IDs for Xsens Mti USB converter
  (bsc#1012628).
- usb: core: fix slab-out-of-bounds Read in read_descriptors
  (bsc#1012628).
- phy: qcom-qmp: Use correct values for ipq8074 PCIe Gen2 PHY init
  (bsc#1012628).
- staging: greybus: audio: fix uninitialized value issue
  (bsc#1012628).
- video: fbdev: fix OOB read in vga_8planes_imageblit()
  (bsc#1012628).
- ARM: dts: vfxxx: Add syscon compatible with OCOTP (bsc#1012628).
- arm64: dts: imx8mp: correct sdma1 clk setting (bsc#1012628).
- test_firmware: Test platform fw loading on non-EFI systems
  (bsc#1012628).
- debugfs: Fix module state check condition (bsc#1012628).
- Revert "usb: dwc3: meson-g12a: fix shared reset control use"
  (bsc#1012628).
- KVM: fix memory leak in kvm_io_bus_unregister_dev()
  (bsc#1012628).
- kvm x86/mmu: use KVM_REQ_MMU_SYNC to sync when needed
  (bsc#1012628).
- KVM: arm64: Do not try to map PUDs when they are folded into
  PMD (bsc#1012628).
- KVM: VMX: Don't freeze guest when event delivery causes an
  APIC-access exit (bsc#1012628).
- vgacon: remove software scrollback support (bsc#1012628).
- fbcon: remove now unusued 'softback_lines' cursor() argument
  (bsc#1012628).
- fbcon: remove soft scrollback code (bsc#1012628).
- RDMA/mlx4: Read pkey table length instead of hardcoded value
  (bsc#1012628).
- RDMA/rxe: Fix the parent sysfs read when the interface has 15
  chars (bsc#1012628).
- rbd: require global CAP_SYS_ADMIN for mapping and unmapping
  (bsc#1012628).
- nvme: Revert: Fix controller creation races with teardown flow
  (bsc#1012628).
- mmc: sdhci-of-esdhc: Don't walk device-tree on every interrupt
  (bsc#1012628).
- mmc: sdio: Use mmc_pre_req() / mmc_post_req() (bsc#1012628).
- drm/msm: Disable the RPTR shadow (bsc#1012628).
- drm/msm: Disable preemption on all 5xx targets (bsc#1012628).
- drm/msm: Split the a5xx preemption record (bsc#1012628).
- drm/tve200: Stabilize enable/disable (bsc#1012628).
- scsi: target: iscsi: Fix hang in iscsit_access_np() when
  getting tpg->np_login_sem (bsc#1012628).
- scsi: lpfc: Fix setting IRQ affinity with an empty CPU mask
  (bsc#1012628).
- scsi: target: iscsi: Fix data digest calculation (bsc#1012628).
- misc: eeprom: at24: register nvmem only after eeprom is ready
  to use (bsc#1012628).
- regulator: core: Fix slab-out-of-bounds in
  regulator_unlock_recursive() (bsc#1012628).
- regulator: plug of_node leak in regulator_register()'s error
  path (bsc#1012628).
- regulator: push allocation in set_consumer_device_supply()
  out of lock (bsc#1012628).
- regulator: push allocations in create_regulator() outside of
  lock (bsc#1012628).
- regulator: push allocation in regulator_init_coupling()
  outside of lock (bsc#1012628).
- kobject: Restore old behaviour of kobject_del(NULL)
  (bsc#1012628).
- thunderbolt: Disable ports that are not implemented
  (bsc#1012628).
- btrfs: fix wrong address when faulting in pages in the search
  ioctl (bsc#1012628).
- btrfs: free data reloc tree on failed mount (bsc#1012628).
- btrfs: fix lockdep splat in add_missing_dev (bsc#1012628).
- btrfs: require only sector size alignment for parent eb bytenr
  (bsc#1012628).
- staging: wlan-ng: fix out of bounds read in
  prism2sta_probe_usb() (bsc#1012628).
- iio:accel:mma8452: Fix timestamp alignment and prevent data leak
  (bsc#1012628).
- iio:accel:mma7455: Fix timestamp alignment and prevent data leak
  (bsc#1012628).
- iio: accel: kxsd9: Fix alignment of local buffer (bsc#1012628).
- iio:chemical:ccs811: Fix timestamp alignment and prevent data
  leak (bsc#1012628).
- iio:light:max44000 Fix timestamp alignment and prevent data leak
  (bsc#1012628).
- iio:magnetometer:ak8975 Fix alignment and data leak issues
  (bsc#1012628).
- iio:adc:ti-adc081c Fix alignment and data leak issues
  (bsc#1012628).
- iio:adc:max1118 Fix alignment of timestamp and data leak issues
  (bsc#1012628).
- iio:adc:ina2xx Fix timestamp alignment issue (bsc#1012628).
- iio:adc:ti-adc084s021 Fix alignment and data leak issues
  (bsc#1012628).
- iio:accel:bmc150-accel: Fix timestamp alignment and prevent
  data leak (bsc#1012628).
- iio:proximity:mb1232: Fix timestamp alignment and prevent data
  leak (bsc#1012628).
- iio:light:ltr501 Fix timestamp alignment issue (bsc#1012628).
- iio: cros_ec: Set Gyroscope default frequency to 25Hz
  (bsc#1012628).
- iio: adc: ti-ads1015: fix conversion when CONFIG_PM is not set
  (bsc#1012628).
- iio: adc: mcp3422: fix locking on error path (bsc#1012628).
- iio: adc: mcp3422: fix locking scope (bsc#1012628).
- gcov: Disable gcov build with GCC 10 (bsc#1012628).
- iommu/amd: Do not use IOMMUv2 functionality when SME is active
  (bsc#1012628).
- iommu/amd: Do not force direct mapping when SME is active
  (bsc#1012628).
- drm/amdgpu: Fix bug in reporting voltage for CIK (bsc#1012628).
- drivers/net/wan/hdlc: Change the default of hard_header_len to 0
  (bsc#1012628).
- ALSA: hda: use consistent HDAudio spelling in comments/docs
  (bsc#1012628).
- ALSA: hda: fix a runtime pm issue in SOF when integrated GPU
  is disabled (bsc#1012628).
- ALSA: hda: hdmi - add Rocketlake support (bsc#1012628).
- arm64/module: set trampoline section flags regardless of
  CONFIG_DYNAMIC_FTRACE (bsc#1012628).
- cpufreq: intel_pstate: Fix intel_pstate_get_hwp_max() for
  turbo disabled (bsc#1012628).
- cpufreq: intel_pstate: Refuse to turn off with HWP enabled
  (bsc#1012628).
- ARC: [plat-hsdk]: Switch ethernet phy-mode to rgmii-id
  (bsc#1012628).
- HID: elan: Fix memleak in elan_input_configured (bsc#1012628).
- drivers/net/wan/hdlc_cisco: Add hard_header_len (bsc#1012628).
- HID: microsoft: Add rumble support for the 8bitdo SN30 Pro+
  controller (bsc#1012628).
- HID: quirks: Set INCREMENT_USAGE_ON_DUPLICATE for all Saitek
  X52 devices (bsc#1012628).
- nvme-pci: cancel nvme device request before disabling
  (bsc#1012628).
- nvme-rdma: fix reset hang if controller died in the middle of
  a reset (bsc#1012628).
- nvme-rdma: fix timeout handler (bsc#1012628).
- nvme-rdma: serialize controller teardown sequences
  (bsc#1012628).
- nvme-tcp: fix reset hang if controller died in the middle of
  a reset (bsc#1012628).
- nvme-tcp: fix timeout handler (bsc#1012628).
- nvme-tcp: serialize controller teardown sequences (bsc#1012628).
- nvme: have nvme_wait_freeze_timeout return if it timed out
  (bsc#1012628).
- nvme-fabrics: don't check state NVME_CTRL_NEW for request
  acceptance (bsc#1012628).
- nvmet-tcp: Fix NULL dereference when a connect data comes in
  h2cdata pdu (bsc#1012628).
- media: gpio-ir-tx: spinlock is not needed to disable interrupts
  (bsc#1012628).
- irqchip/eznps: Fix build error for !ARC700 builds (bsc#1012628).
- ARC: show_regs: fix r12 printing and simplify (bsc#1012628).
- xfs: initialize the shortform attr header padding entry
  (bsc#1012628).
- cfg80211: Adjust 6 GHz frequency to channel conversion
  (bsc#1012628).
- mac80211: reduce packet loss event false positives
  (bsc#1012628).
- wireless: fix wrong 160/80+80 MHz setting (bsc#1012628).
- drivers/net/wan/lapbether: Set network_header before
  transmitting (bsc#1012628).
- xfs: fix off-by-one in inode alloc block reservation calculation
  (bsc#1012628).
- net: hns3: Fix for geneve tx checksum bug (bsc#1012628).
- drivers/dma/dma-jz4780: Fix race condition between probe and
  irq handler (bsc#1012628).
- ALSA: hda/tegra: Program WAKEEN register for Tegra
  (bsc#1012628).
- ALSA: hda: Fix 2 channel swapping for Tegra (bsc#1012628).
- scsi: qedf: Fix null ptr reference in qedf_stag_change_work
  (bsc#1012628).
- firestream: Fix memleak in fs_open (bsc#1012628).
- NFC: st95hf: Fix memleak in st95hf_in_send_cmd (bsc#1012628).
- drivers/net/wan/lapbether: Added needed_tailroom (bsc#1012628).
- netfilter: nft_set_rbtree: Detect partial overlap with start
  endpoint match (bsc#1012628).
- netfilter: conntrack: allow sctp hearbeat after connection
  re-use (bsc#1012628).
- MIPS: Loongson64: Do not override watch and ejtag feature
  (bsc#1012628).
- dmaengine: acpi: Put the CSRT table after using it
  (bsc#1012628).
- ARC: HSDK: wireup perf irq (bsc#1012628).
- KVM: x86: always allow writing '0' to MSR_KVM_ASYNC_PF_EN
  (bsc#1012628).
- KVM: nVMX: Fix the update value of nested load
  IA32_PERF_GLOBAL_CTRL control (bsc#1012628).
- arm64: dts: ns2: Fixed QSPI compatible string (bsc#1012628).
- ARM: dts: BCM5301X: Fixed QSPI compatible string (bsc#1012628).
- ARM: dts: NSP: Fixed QSPI compatible string (bsc#1012628).
- ARM: dts: bcm: HR2: Fixed QSPI compatible string (bsc#1012628).
- IB/isert: Fix unaligned immediate-data handling (bsc#1012628).
- RDMA/rtrs-srv: Set .release function for rtrs srv device during
  device init (bsc#1012628).
- block: Set same_page to false in __bio_try_merge_page if ret
  is false (bsc#1012628).
- spi: stm32: fix pm_runtime_get_sync() error checking
  (bsc#1012628).
- nvme-fabrics: allow to queue requests for live queues
  (bsc#1012628).
- seccomp: don't leak memory when filter install races
  (bsc#1012628).
- block: restore a specific error code in bdev_del_partition
  (bsc#1012628).
- i2c: npcm7xx: Fix timeout calculation (bsc#1012628).
- btrfs: fix NULL pointer dereference after failure to create
  snapshot (bsc#1012628).
- spi: stm32: Rate-limit the 'Communication suspended' message
  (bsc#1012628).
- mmc: sdhci-msm: Add retries when all tuning phases are found
  valid (bsc#1012628).
- mmc: sdhci-acpi: Clear amd_sdhci_host on reset (bsc#1012628).
- ARM: dts: imx6sx: fix the pad QSPI1B_SCLK mux mode for uart3
  (bsc#1012628).
- KVM: arm64: Update page shift if stage 2 block mapping not
  supported (bsc#1012628).
- drm/sun4i: backend: Disable alpha on the lowest plane on the
  A20 (bsc#1012628).
- drm/sun4i: backend: Support alpha property on lowest plane
  (bsc#1012628).
- drm/sun4i: Fix DE2 YVU handling (bsc#1012628).
- padata: fix possible padata_works_lock deadlock (bsc#1012628).
- interconnect: qcom: Fix small BW votes being truncated to zero
  (bsc#1012628).
- Revert "kbuild: use -flive-patching when CONFIG_LIVEPATCH is
  enabled" (bsc#1012628).
- soundwire: fix double free of dangling pointer (bsc#1012628).
- scsi: mpt3sas: Don't call disable_irq from IRQ poll handler
  (bsc#1012628).
- scsi: megaraid_sas: Don't call disable_irq from process IRQ poll
  (bsc#1012628).
- RDMA/core: Fix reported speed and width (bsc#1012628).
- RDMA/core: Fix unsafe linked list traversal after failing to
  allocate CQ (bsc#1012628).
- drm/virtio: fix unblank (bsc#1012628).
- scsi: libsas: Set data_dir as DMA_NONE if libata marks qc as
  NODATA (bsc#1012628).
- scsi: qla2xxx: Fix regression on sparc64 (bsc#1012628).
- drm/sun4i: Fix dsi dcs long write function (bsc#1012628).
- arm64: dts: imx8mq: Fix TMU interrupt property (bsc#1012628).
- drm/sun4i: add missing put_device() call in
  sun8i_r40_tcon_tv_set_mux() (bsc#1012628).
- RDMA/bnxt_re: Remove the qp from list only if the qp destroy
  succeeds (bsc#1012628).
- RDMA/bnxt_re: Fix driver crash on unaligned PSN entry address
  (bsc#1012628).
- RDMA/bnxt_re: Static NQ depth allocation (bsc#1012628).
- RDMA/bnxt_re: Fix the qp table indexing (bsc#1012628).
- RDMA/bnxt_re: Do not report transparent vlan from QP1
  (bsc#1012628).
- RDMA/rxe: Fix panic when calling kmem_cache_create()
  (bsc#1012628).
- RDMA/rxe: Drop pointless checks in rxe_init_ports (bsc#1012628).
- RDMA/rxe: Fix memleak in rxe_mem_init_user (bsc#1012628).
- RDMA/rtrs-srv: Replace device_register with device_initialize
  and device_add (bsc#1012628).
- ARM: dts: imx7d-zii-rmu2: fix rgmii phy-mode for ksz9031 phy
  (bsc#1012628).
- arm64: dts: imx: Add missing imx8mm-beacon-kit.dtb to build
  (bsc#1012628).
- ARM: dts: imx7ulp: Correct gpio ranges (bsc#1012628).
- ARM: dts: ls1021a: fix QuadSPI-memory reg range (bsc#1012628).
- selftests/timers: Turn off timeout setting (bsc#1012628).
- ARM: dts: omap5: Fix DSI base address and clocks (bsc#1012628).
- ARM: dts: socfpga: fix register entry for timer3 on Arria10
  (bsc#1012628).
- regulator: remove superfluous lock in
  regulator_resolve_coupling() (bsc#1012628).
- regulator: push allocation in regulator_ena_gpio_request()
  out of lock (bsc#1012628).
- ARM: dts: logicpd-som-lv-baseboard: Fix missing video
  (bsc#1012628).
- ARM: dts: logicpd-som-lv-baseboard: Fix broken audio
  (bsc#1012628).
- ARM: dts: logicpd-torpedo-baseboard: Fix broken audio
  (bsc#1012628).
- ARM: OMAP2+: Fix an IS_ERR() vs NULL check in _get_pwrdm()
  (bsc#1012628).
- commit 83e873a
* Mon Sep 14 2020 mkubecek@suse.cz
- Update to 5.9-rc5
- eliminated 2 patches
  patches.suse/drm-virtio-fix-unblank.patch
  patches.suse/firmware_loader-fix-memory-leak-for-paged-buffer.patch
- commit e921ea1
* Sat Sep 12 2020 jslaby@suse.cz
- Linux 5.8.9 (bsc#1012628).
- mptcp: free acked data before waiting for more memory
  (bsc#1012628).
- net: disable netpoll on fresh napis (bsc#1012628).
- tipc: fix using smp_processor_id() in preemptible (bsc#1012628).
- tipc: fix shutdown() of connectionless socket (bsc#1012628).
- taprio: Fix using wrong queues in gate mask (bsc#1012628).
- sctp: not disable bh in the whole sctp_get_port_local()
  (bsc#1012628).
- net: usb: dm9601: Add USB ID of Keenetic Plus DSL (bsc#1012628).
- netlabel: fix problems with mapping removal (bsc#1012628).
- ipv6: Fix sysctl max for fib_multipath_hash_policy
  (bsc#1012628).
- ipv4: Silence suspicious RCU usage warning (bsc#1012628).
- RDMA/cma: Execute rdma_cm destruction from a handler properly
  (bsc#1012628).
- RDMA/cma: Remove unneeded locking for req paths (bsc#1012628).
- RDMA/cma: Using the standard locking pattern when delivering
  the removal event (bsc#1012628).
- RDMA/cma: Simplify DEVICE_REMOVAL for internal_id (bsc#1012628).
- io_uring: fix linked deferred ->files cancellation
  (bsc#1012628).
- io_uring: fix cancel of deferred reqs with ->files
  (bsc#1012628).
- commit 52f63c2
* Thu Sep 10 2020 jslaby@suse.cz
- Linux 5.8.8 (bsc#1012628).
- hwmon: (pmbus/isl68137) remove READ_TEMPERATURE_1 telemetry
  for RAA228228 (bsc#1012628).
- HID: quirks: Always poll three more Lenovo PixArt mice
  (bsc#1012628).
- drm/msm/dpu: Fix reservation failures in modeset (bsc#1012628).
- drm/msm/dpu: Fix scale params in plane validation (bsc#1012628).
- drm/msm/dpu: fix unitialized variable error (bsc#1012628).
- tty: serial: qcom_geni_serial: Drop __init from
  qcom_geni_console_setup (bsc#1012628).
- drm/msm: add shutdown support for display platform_driver
  (bsc#1012628).
- hwmon: (applesmc) check status earlier (bsc#1012628).
- nvmet: Disable keep-alive timer when kato is cleared to 0h
  (bsc#1012628).
- drm/msm: enable vblank during atomic commits (bsc#1012628).
- habanalabs: unmap PCI bars upon iATU failure (bsc#1012628).
- habanalabs: validate packet id during CB parse (bsc#1012628).
- habanalabs: set clock gating according to mask (bsc#1012628).
- habanalabs: proper handling of alloc size in coresight
  (bsc#1012628).
- habanalabs: set max power according to card type (bsc#1012628).
- habanalabs: validate FW file size (bsc#1012628).
- habanalabs: check correct vmalloc return code (bsc#1012628).
- drm/msm/a6xx: fix gmu start on newer firmware (bsc#1012628).
- gfs2: add some much needed cleanup for log flushes that fail
  (bsc#1012628).
- hv_utils: return error if host timesysnc update is stale
  (bsc#1012628).
- hv_utils: drain the timesync packets on onchannelcallback
  (bsc#1012628).
- ceph: don't allow setlease on cephfs (bsc#1012628).
- i2c: iproc: Fix shifting 31 bits (bsc#1012628).
- drm/omap: fix incorrect lock state (bsc#1012628).
- irqchip/ingenic: Leave parent IRQ unmasked on suspend
  (bsc#1012628).
- cpuidle: Fixup IRQ state (bsc#1012628).
- nbd: restore default timeout when setting it to zero
  (bsc#1012628).
- s390: don't trace preemption in percpu macros (bsc#1012628).
- drm/amd/display: should check error using DC_OK (bsc#1012628).
- drm/amd/display: Reject overlay plane configurations in
  multi-display scenarios (bsc#1012628).
- drivers: gpu: amd: Initialize amdgpu_dm_backlight_caps object
  to 0 in amdgpu_dm_update_backlight_caps (bsc#1012628).
- drm/amd/display: Revert HDCP disable sequence change
  (bsc#1012628).
- drm/amd/display: Fix passive dongle mistaken as active dongle
  in EDID emulation (bsc#1012628).
- drm/amd/display: Keep current gain when ABM disable immediately
  (bsc#1012628).
- drm/amd/display: Retry AUX write when fail occurs (bsc#1012628).
- drm/amd/display: Fix memleak in amdgpu_dm_mode_config_init
  (bsc#1012628).
- xen/xenbus: Fix granting of vmalloc'd memory (bsc#1012628).
- fsldma: fix very broken 32-bit ppc ioread64 functionality
  (bsc#1012628).
- dmaengine: of-dma: Fix of_dma_router_xlate's of_dma_xlate
  handling (bsc#1012628).
- batman-adv: Avoid uninitialized chaddr when handling DHCP
  (bsc#1012628).
- batman-adv: Fix own OGM check in aggregated OGMs (bsc#1012628).
- batman-adv: bla: use netif_rx_ni when not in interrupt context
  (bsc#1012628).
- dmaengine: at_hdmac: check return value of
  of_find_device_by_node() in at_dma_xlate() (bsc#1012628).
- dmaengine: at_hdmac: add missing put_device() call in
  at_dma_xlate() (bsc#1012628).
- dmaengine: at_hdmac: add missing kfree() call in at_dma_xlate()
  (bsc#1012628).
- rxrpc: Keep the ACK serial in a var in rxrpc_input_ack()
  (bsc#1012628).
- rxrpc: Fix loss of RTT samples due to interposed ACK
  (bsc#1012628).
- rxrpc: Make rxrpc_kernel_get_srtt() indicate validity
  (bsc#1012628).
- MIPS: mm: BMIPS5000 has inclusive physical caches (bsc#1012628).
- MIPS: BMIPS: Also call bmips_cpu_setup() for secondary cores
  (bsc#1012628).
- mmc: sdhci-acpi: Fix HS400 tuning for AMDI0040 (bsc#1012628).
- perf sched timehist: Fix use of CPU list with summary option
  (bsc#1012628).
- perf top: Skip side-band event setup if HAVE_LIBBPF_SUPPORT
  is not set (bsc#1012628).
- netfilter: nf_tables: add NFTA_SET_USERDATA if not null
  (bsc#1012628).
- netfilter: nf_tables: incorrect enum nft_list_attributes
  definition (bsc#1012628).
- netfilter: nf_tables: fix destination register zeroing
  (bsc#1012628).
- net: hns: Fix memleak in hns_nic_dev_probe (bsc#1012628).
- net: systemport: Fix memleak in bcm_sysport_probe (bsc#1012628).
- ravb: Fixed to be able to unload modules (bsc#1012628).
- net: arc_emac: Fix memleak in arc_mdio_probe (bsc#1012628).
- bpf: Fix a buffer out-of-bound access when filling raw_tp
  link_info (bsc#1012628).
- dmaengine: pl330: Fix burst length if burst size is smaller
  than bus width (bsc#1012628).
- dmaengine: ti: k3-udma: Fix the TR initialization for
  prep_slave_sg (bsc#1012628).
- gtp: add GTPA_LINK info to msg sent to userspace (bsc#1012628).
- net: ethernet: ti: cpsw: fix clean up of vlan mc entries for
  host port (bsc#1012628).
- net: ethernet: ti: cpsw_new: fix clean up of vlan mc entries
  for host port (bsc#1012628).
- bnxt_en: Don't query FW when netif_running() is false
  (bsc#1012628).
- bnxt_en: Check for zero dir entries in NVRAM (bsc#1012628).
- bnxt_en: Fix ethtool -S statitics with XDP or TCs enabled
  (bsc#1012628).
- bnxt_en: Fix PCI AER error recovery flow (bsc#1012628).
- bnxt_en: Fix possible crash in bnxt_fw_reset_task()
  (bsc#1012628).
- bnxt_en: fix HWRM error when querying VF temperature
  (bsc#1012628).
- xfs: finish dfops on every insert range shift iteration
  (bsc#1012628).
- xfs: fix boundary test in xfs_attr_shortform_verify
  (bsc#1012628).
- bnxt: don't enable NAPI until rings are ready (bsc#1012628).
- media: vicodec: add missing v4l2_ctrl_request_hdl_put()
  (bsc#1012628).
- media: cedrus: Add missing v4l2_ctrl_request_hdl_put()
  (bsc#1012628).
- net: ethernet: ti: cpsw_new: fix error handling in
  cpsw_ndo_vlan_rx_kill_vid() (bsc#1012628).
- media: i2c: imx214: select V4L2_FWNODE (bsc#1012628).
- selftests/bpf: Fix massive output from test_maps (bsc#1012628).
- net: dsa: mt7530: fix advertising unsupported 1000baseT_Half
  (bsc#1012628).
- netfilter: nfnetlink: nfnetlink_unicast() reports EAGAIN
  instead of ENOBUFS (bsc#1012628).
- nvmet-fc: Fix a missed _irqsave version of spin_lock in
  'nvmet_fc_fod_op_done()' (bsc#1012628).
- nvme: fix controller instance leak (bsc#1012628).
- netfilter: conntrack: do not auto-delete clash entries on reply
  (bsc#1012628).
- opp: Don't drop reference for an OPP table that was never parsed
  (bsc#1012628).
- cxgb4: fix thermal zone device registration (bsc#1012628).
- net: ethernet: ti: am65-cpsw: fix rmii 100Mbit link mode
  (bsc#1012628).
- MIPS: perf: Fix wrong check condition of Loongson event IDs
  (bsc#1012628).
- block: fix locking in bdev_del_partition (bsc#1012628).
- perf top/report: Fix infinite loop in the TUI for grouped events
  (bsc#1012628).
- perf cs-etm: Fix corrupt data after perf inject from
  (bsc#1012628).
- perf intel-pt: Fix corrupt data after perf inject from
  (bsc#1012628).
- perf tools: Correct SNOOPX field offset (bsc#1012628).
- net: ethernet: mlx4: Fix memory allocation in mlx4_buddy_init()
  (bsc#1012628).
- fix regression in "epoll: Keep a reference on files added to
  the check list" (bsc#1012628).
- net: bcmgenet: fix mask check in bcmgenet_validate_flow()
  (bsc#1012628).
- net: gemini: Fix another missing clk_disable_unprepare()
  in probe (bsc#1012628).
- nfp: flower: fix ABI mismatch between driver and firmware
  (bsc#1012628).
- net: dp83867: Fix WoL SecureOn password (bsc#1012628).
- MIPS: add missing MSACSR and upper MSA initialization
  (bsc#1012628).
- MIPS: SNI: Fix SCSI interrupt (bsc#1012628).
- xfs: fix xfs_bmap_validate_extent_raw when checking attr fork
  of rt files (bsc#1012628).
- perf jevents: Fix suspicious code in fixregex() (bsc#1012628).
- perf stat: Turn off summary for interval mode by default
  (bsc#1012628).
- perf bench: The do_run_multi_threaded() function must use
  IS_ERR(perf_session__new()) (bsc#1012628).
- tg3: Fix soft lockup when tg3_reset_task() fails (bsc#1012628).
- x86, fakenuma: Fix invalid starting node ID (bsc#1012628).
- iommu/vt-d: Serialize IOMMU GCMD register modifications
  (bsc#1012628).
- thermal: ti-soc-thermal: Fix bogus thermal shutdowns for
  omap4430 (bsc#1012628).
- thermal: qcom-spmi-temp-alarm: Don't suppress negative temp
  (bsc#1012628).
- iommu/amd: Restore IRTE.RemapEn bit after programming IRTE
  (bsc#1012628).
- iommu/amd: Use cmpxchg_double() when updating 128-bit IRTE
  (bsc#1012628).
- include/linux/log2.h: add missing () around n in
  roundup_pow_of_two() (bsc#1012628).
- iommu/vt-d: Handle 36bit addressing for x86-32 (bsc#1012628).
- tracing/kprobes, x86/ptrace: Fix regs argument order for i386
  (bsc#1012628).
- x86/entry: Fix AC assertion (bsc#1012628).
- x86/debug: Allow a single level of #DB recursion (bsc#1012628).
- ext2: don't update mtime on COW faults (bsc#1012628).
- xfs: don't update mtime on COW faults (bsc#1012628).
- ARC: perf: don't bail setup if pct irq missing in device-tree
  (bsc#1012628).
- arc: fix memory initialization for systems with two memory banks
  (bsc#1012628).
- btrfs: drop path before adding new uuid tree entry
  (bsc#1012628).
- btrfs: fix potential deadlock in the search ioctl (bsc#1012628).
- btrfs: allocate scrub workqueues outside of locks (bsc#1012628).
- btrfs: set the correct lockdep class for new nodes
  (bsc#1012628).
- btrfs: set the lockdep class for log tree extent buffers
  (bsc#1012628).
- btrfs: block-group: fix free-space bitmap threshold
  (bsc#1012628).
- btrfs: tree-checker: fix the error message for transid error
  (bsc#1012628).
- Bluetooth: Return NOTIFY_DONE for hci_suspend_notifier
  (bsc#1012628).
- x86/mm/32: Bring back vmalloc faulting on x86_32 (bsc#1012628).
- ALSA: ca0106: fix error code handling (bsc#1012628).
- ALSA: usb-audio: Add basic capture support for Pioneer DJ
  DJM-250MK2 (bsc#1012628).
- ALSA: usb-audio: Add implicit feedback quirk for UR22C
  (bsc#1012628).
- ALSA: pcm: oss: Remove superfluous WARN_ON() for mulaw sanity
  check (bsc#1012628).
- ALSA: hda/hdmi: always check pin power status in i915 pin fixup
  (bsc#1012628).
- ALSA: firewire-digi00x: exclude Avid Adrenaline from detection
  (bsc#1012628).
- ALSA: hda - Fix silent audio output and corrupted input on
  MSI X570-A PRO (bsc#1012628).
- ALSA; firewire-tascam: exclude Tascam FE-8 from detection
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Samsung Galaxy Book Ion
  NT950XCJ-X716A (bsc#1012628).
- ALSA: hda/realtek - Improved routing for Thinkpad X1 7th/8th
  Gen (bsc#1012628).
- arm64: dts: mt7622: add reset node for mmc device (bsc#1012628).
- mmc: mediatek: add optional module reset property (bsc#1012628).
- mmc: dt-bindings: Add resets/reset-names for Mediatek MMC
  bindings (bsc#1012628).
- mmc: sdhci-pci: Fix SDHCI_RESET_ALL for CQHCI for Intel
  GLK-based controllers (bsc#1012628).
- media: rc: do not access device via sysfs after
  rc_unregister_device() (bsc#1012628).
- media: rc: uevent sysfs file races with rc_unregister_device()
  (bsc#1012628).
- affs: fix basic permission bits to actually work (bsc#1012628).
- block: allow for_each_bvec to support zero len bvec
  (bsc#1012628).
- block: ensure bdi->io_pages is always initialized (bsc#1012628).
- io_uring: set table->files[i] to NULL when io_sqe_file_register
  failed (bsc#1012628).
- io_uring: fix removing the wrong file in __io_sqe_files_update()
  (bsc#1012628).
- s390: fix GENERIC_LOCKBREAK dependency typo in Kconfig
  (bsc#1012628).
- libata: implement ATA_HORKAGE_MAX_TRIM_128M and apply to
  Sandisks (bsc#1012628).
- mips/oprofile: Fix fallthrough placement (bsc#1012628).
- blk-iocost: ioc_pd_free() shouldn't assume irq disabled
  (bsc#1012628).
- blk-stat: make q->stats->lock irqsafe (bsc#1012628).
- dmaengine: dw-edma: Fix scatter-gather address calculation
  (bsc#1012628).
- drm/i915: Fix sha_text population code (bsc#1012628).
- drm/amd/pm: avoid false alarm due to confusing
  softwareshutdowntemp setting (bsc#1012628).
- drm/amdgpu: Specify get_argument function for ci_smu_funcs
  (bsc#1012628).
- dm writecache: handle DAX to partitions on persistent memory
  correctly (bsc#1012628).
- dm mpath: fix racey management of PG initialization
  (bsc#1012628).
- dm integrity: fix error reporting in bitmap mode after creation
  (bsc#1012628).
- dm crypt: Initialize crypto wait structures (bsc#1012628).
- dm cache metadata: Avoid returning cmd->bm wild pointer on error
  (bsc#1012628).
- dm thin metadata: Avoid returning cmd->bm wild pointer on error
  (bsc#1012628).
- dm thin metadata: Fix use-after-free in dm_bm_set_read_only
  (bsc#1012628).
- mm: slub: fix conversion of freelist_corrupted() (bsc#1012628).
- mm: track page table modifications in __apply_to_page_range()
  (bsc#1012628).
- mm: madvise: fix vma user-after-free (bsc#1012628).
- mm/rmap: fixup copying of soft dirty and uffd ptes
  (bsc#1012628).
- io_uring: no read/write-retry on -EAGAIN error and O_NONBLOCK
  marked file (bsc#1012628).
- perf record: Correct the help info of option "--no-bpf-event"
  (bsc#1012628).
- kconfig: streamline_config.pl: check defined(ENV variable)
  before using it (bsc#1012628).
- sdhci: tegra: Add missing TMCLK for data timeout (bsc#1012628).
- checkpatch: fix the usage of capture group ( ... )
  (bsc#1012628).
- mm/migrate: fixup setting UFFD_WP flag (bsc#1012628).
- mm/hugetlb: try preferred node first when alloc gigantic page
  from cma (bsc#1012628).
- mm/hugetlb: fix a race between hugetlb sysctl handlers
  (bsc#1012628).
- mm/khugepaged.c: fix khugepaged's request size in collapse_file
  (bsc#1012628).
- cfg80211: regulatory: reject invalid hints (bsc#1012628).
- net: usb: Fix uninit-was-stored issue in asix_read_phy_addr()
  (bsc#1012628).
- commit 8b2a0ec
* Tue Sep  8 2020 mbenes@suse.cz
- rpm/kernel-binary.spec.in: pack .ipa-clones files for live patching
  When -fdump-ipa-clones option is enabled, GCC reports about its cloning
  operation during IPA optimizations. We use the information for live
  patches preparation, because it is crucial to know if and how functions
  are optimized.
  Currently, we create the needed .ipa-clones dump files manually. It is
  unnecessary, because the files may be created automatically during our
  kernel build. Prepare for the step and provide the resulting files in
  - livepatch-devel package.
- commit 98e5a9d
* Mon Sep  7 2020 msuchanek@suse.de
- rpm/kernel-source.spec.in: Also use bz compression (boo#1175882).
- commit 375ec84
* Mon Sep  7 2020 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Also sign ppc64 kernels (jsc#SLE-15857
  jsc#SLE-13618).
- commit 971fc3d
* Mon Sep  7 2020 yousaf.kaukab@suse.com
- coresight: fix offset by one error in counting ports
  (bsc#1175054).
- commit 1169fee
* Mon Sep  7 2020 tiwai@suse.de
- Update config files: add CONFIG_GCOV_KENREL=n
  Define this explicitly as kbuild bot still uses gcc9 for testing
- commit 0dcb9bb
* Mon Sep  7 2020 tiwai@suse.de
- Update config files: enable a few missing Intel SOF and SST ASoC entries (bsc#1176200)
- commit 074fdcf
* Mon Sep  7 2020 mkubecek@suse.cz
- Update to 5.9-rc4
- eliminated 1 patch
  - patches.suse/net-packet-fix-overflow-in-tpacket_rcv.patch
- update configs
  - new config option:
  - XEN_UNPOPULATED_ALLOC=y (x86_64 only)
- commit 2817e6d
* Sun Sep  6 2020 jslaby@suse.cz
- Revert "ALSA: hda: Add support for Loongson 7A1000 controller"
  (git-fixes).
- commit 7fc52c0
* Sun Sep  6 2020 jslaby@suse.cz
- Linux 5.8.7 (bsc#1012628).
- scsi: target: tcmu: Optimize use of flush_dcache_page
  (bsc#1012628).
- nl80211: fix NL80211_ATTR_HE_6GHZ_CAPABILITY usage
  (bsc#1012628).
- sdhci: tegra: Remove SDHCI_QUIRK_DATA_TIMEOUT_USES_SDCLK for
  Tegra186 (bsc#1012628).
- sdhci: tegra: Remove SDHCI_QUIRK_DATA_TIMEOUT_USES_SDCLK for
  Tegra210 (bsc#1012628).
- arm64: tegra: Add missing timeout clock to Tegra210 SDMMC
  (bsc#1012628).
- arm64: tegra: Add missing timeout clock to Tegra186 SDMMC nodes
  (bsc#1012628).
- arm64: tegra: Add missing timeout clock to Tegra194 SDMMC nodes
  (bsc#1012628).
- dt-bindings: mmc: tegra: Add tmclk for Tegra210 and later
  (bsc#1012628).
- KVM: arm64: Survive synchronous exceptions caused by AT
  instructions (bsc#1012628).
- KVM: arm64: Add kvm_extable for vaxorcism code (bsc#1012628).
- media: media/v4l2-core: Fix kernel-infoleak in video_put_user()
  (bsc#1012628).
- perf record/stat: Explicitly call out event modifiers in the
  documentation (bsc#1012628).
- selftests/x86/test_vsyscall: Improve the process_vm_readv()
  test (bsc#1012628).
- mm: fix pin vs. gup mismatch with gate pages (bsc#1012628).
- netfilter: nft_set_rbtree: Handle outcomes of tree rotations
  in overlap detection (bsc#1012628).
- HID: core: Sanitize event code and type when mapping input
  (bsc#1012628).
- HID: core: Correctly handle ReportSize being zero (bsc#1012628).
- commit dccac66
* Sun Sep  6 2020 jslaby@suse.cz
- Linux 5.8.6 (bsc#1012628).
- ALSA: usb-audio: Update documentation comment for MS2109 quirk
  (bsc#1012628).
- dma-pool: Fix an uninitialized variable bug in
  atomic_pool_expand() (bsc#1012628).
- drm/vmwgfx/ldu: Use drm_mode_config_reset (bsc#1012628).
- drm/vmwgfx/sou: Use drm_mode_config_reset (bsc#1012628).
- drm/vmwgfx/stdu: Use drm_mode_config_reset (bsc#1012628).
- HID: hiddev: Fix slab-out-of-bounds write in
  hiddev_ioctl_usage() (bsc#1012628).
- mm/page_counter: fix various data races at memsw (bsc#1012628).
- fbmem: pull fbcon_update_vcs() out of fb_set_var()
  (bsc#1012628).
- drm/atomic-helper: reset vblank on crtc reset (bsc#1012628).
- io_uring: make offset == -1 consistent with preadv2/pwritev2
  (bsc#1012628).
- io_uring: don't use poll handler if file can't be nonblocking
  read/written (bsc#1012628).
- io_uring: don't recurse on tsk->sighand->siglock with signalfd
  (bsc#1012628).
- usb: typec: tcpm: Fix Fix source hard reset response for TDA
  2.3.1.1 and TDA 2.3.1.2 failures (bsc#1012628).
- usb: typec: ucsi: Hold con->lock for the entire duration of
  ucsi_register_port() (bsc#1012628).
- usb: typec: ucsi: Rework ppm_lock handling (bsc#1012628).
- usb: typec: ucsi: Fix 2 unlocked ucsi_run_command calls
  (bsc#1012628).
- usb: typec: ucsi: Fix AB BA lock inversion (bsc#1012628).
- USB: Fix device driver race (bsc#1012628).
- USB: Also match device drivers using the ->match vfunc
  (bsc#1012628).
- usb: storage: Add unusual_uas entry for Sony PSZ drives
  (bsc#1012628).
- USB: cdc-acm: rework notification_buffer resizing (bsc#1012628).
- usb: dwc3: gadget: Handle ZLP for sg requests (bsc#1012628).
- usb: dwc3: gadget: Fix handling ZLP (bsc#1012628).
- usb: dwc3: gadget: Don't setup more than requested
  (bsc#1012628).
- USB: gadget: u_f: Unbreak offset calculation in VLAs
  (bsc#1012628).
- USB: gadget: f_ncm: add bounds checks to ncm_unwrap_ntb()
  (bsc#1012628).
- USB: gadget: u_f: add overflow checks to VLA macros
  (bsc#1012628).
- usb: host: ohci-exynos: Fix error handling in
  exynos_ohci_probe() (bsc#1012628).
- USB: Ignore UAS for JMicron JMS567 ATA/ATAPI Bridge
  (bsc#1012628).
- USB: quirks: Ignore duplicate endpoint on Sound Devices MixPre-D
  (bsc#1012628).
- USB: quirks: Add no-lpm quirk for another Raydium touchscreen
  (bsc#1012628).
- usb: uas: Add quirk for PNY Pro Elite (bsc#1012628).
- USB: yurex: Fix bad gfp argument (bsc#1012628).
- drm/amd/pm: correct the thermal alert temperature limit settings
  (bsc#1012628).
- drm/amd/pm: correct Vega20 swctf limit setting (bsc#1012628).
- drm/amd/pm: correct Vega12 swctf limit setting (bsc#1012628).
- drm/amd/pm: correct Vega10 swctf limit setting (bsc#1012628).
- drm/amd/powerplay: Fix hardmins not being sent to SMU for RV
  (bsc#1012628).
- drm/amdgpu/gfx10: refine mgcg setting (bsc#1012628).
- drm/amd/display: use correct scale for actual_brightness
  (bsc#1012628).
- drm/amdgpu: Fix buffer overflow in INFO ioctl (bsc#1012628).
- drm/modeset-lock: Take the modeset BKL for legacy drivers
  (bsc#1012628).
- drm/dp_mst: Don't return error code when crtc is null
  (bsc#1012628).
- drm/etnaviv: fix external abort seen on GC600 rev 0x19
  (bsc#1012628).
- drm/i915: Fix cmd parser desc matching with masks (bsc#1012628).
- x86/hotplug: Silence APIC only after all interrupts are migrated
  (bsc#1012628).
- x86/irq: Unbreak interrupt affinity setting (bsc#1012628).
- irqchip/stm32-exti: Avoid losing interrupts due to clearing
  pending bits by mistake (bsc#1012628).
- genirq/matrix: Deal with the sillyness of for_each_cpu() on UP
  (bsc#1012628).
- usbip: Implement a match function to fix usbip (bsc#1012628).
- crypto: af_alg - Work around empty control messages without
  MSG_MORE (bsc#1012628).
- device property: Fix the secondary firmware node handling in
  set_primary_fwnode() (bsc#1012628).
- powerpc/perf: Fix crashes with generic_compat_pmu & BHRB
  (bsc#1012628).
- powerpc/32s: Disable VMAP stack which CONFIG_ADB_PMU
  (bsc#1012628).
- PM: sleep: core: Fix the handling of pending runtime resume
  requests (bsc#1012628).
- arm64: vdso32: make vdso32 install conditional (bsc#1012628).
- KVM: arm64: Set HCR_EL2.PTW to prevent AT taking synchronous
  exception (bsc#1012628).
- io-wq: fix hang after cancelling pending hashed work
  (bsc#1012628).
- xhci: Always restore EP_SOFT_CLEAR_TOGGLE even if ep reset
  failed (bsc#1012628).
- xhci: Do warm-reset when both CAS and XDEV_RESUME are set
  (bsc#1012628).
- usb: host: xhci: fix ep context print mismatch in debugfs
  (bsc#1012628).
- usb: host: xhci-tegra: fix tegra_xusb_get_phy() (bsc#1012628).
- usb: host: xhci-tegra: otg usb2/usb3 port init (bsc#1012628).
- usb: renesas-xhci: remove version check (bsc#1012628).
- XEN uses irqdesc::irq_data_common::handler_data to store a
  per interrupt XEN data pointer which contains XEN specific
  information (bsc#1012628).
- writeback: Fix sync livelock due to b_dirty_time processing
  (bsc#1012628).
- writeback: Avoid skipping inode writeback (bsc#1012628).
- writeback: Protect inode->i_io_list with inode->i_lock
  (bsc#1012628).
- io_uring: clear req->result on IOPOLL re-issue (bsc#1012628).
- serial: 8250: change lock order in serial8250_do_startup()
  (bsc#1012628).
- serial: 8250_exar: Fix number of ports for Commtech PCIe cards
  (bsc#1012628).
- serial: stm32: avoid kernel warning on absence of optional IRQ
  (bsc#1012628).
- serial: pl011: Don't leak amba_ports entry on driver register
  error (bsc#1012628).
- serial: pl011: Fix oops on -EPROBE_DEFER (bsc#1012628).
- serial: samsung: Removes the IRQ not found warning
  (bsc#1012628).
- vt_ioctl: change VT_RESIZEX ioctl to check for error return
  from vc_resize() (bsc#1012628).
- vt: defer kfree() of vc_screenbuf in vc_do_resize()
  (bsc#1012628).
- USB: lvtest: return proper error code in probe (bsc#1012628).
- fbcon: prevent user font height or width change from causing
  potential out-of-bounds access (bsc#1012628).
- btrfs: detect nocow for swap after snapshot delete
  (bsc#1012628).
- btrfs: fix space cache memory leak after transaction abort
  (bsc#1012628).
- btrfs: check the right error variable in
  btrfs_del_dir_entries_in_log (bsc#1012628).
- btrfs: reset compression level for lzo on remount (bsc#1012628).
- blk-mq: order adding requests to hctx->dispatch and checking
  SCHED_RESTART (bsc#1012628).
- HID: i2c-hid: Always sleep 60ms after I2C_HID_PWR_ON commands
  (bsc#1012628).
- block: loop: set discard granularity and alignment for block
  device backed loop (bsc#1012628).
- block: fix get_max_io_size() (bsc#1012628).
- hwmon: (gsc-hwmon) Scale temperature to millidegrees
  (bsc#1012628).
- arm64: Allow booting of late CPUs affected by erratum 1418040
  (bsc#1012628).
- arm64: Move handling of erratum 1418040 into C code
  (bsc#1012628).
- bpf: selftests: global_funcs: Check err_str before strstr
  (bsc#1012628).
- libbpf: Fix map index used in error message (bsc#1012628).
- powerpc/perf: Fix soft lockups due to missed interrupt
  accounting (bsc#1012628).
- ext4: limit the length of per-inode prealloc list (bsc#1012628).
- bpf: Avoid visit same object multiple times (bsc#1012628).
- bpf: Fix a rcu_sched stall issue with bpf task/task_file
  iterator (bsc#1012628).
- drm/amdkfd: fix the wrong sdma instance query for renoir
  (bsc#1012628).
- drm/amdgpu: fix NULL pointer access issue when unloading driver
  (bsc#1012628).
- net: gianfar: Add of_node_put() before goto statement
  (bsc#1012628).
- macvlan: validate setting of multiple remote source MAC
  addresses (bsc#1012628).
- Revert "scsi: qla2xxx: Fix crash on qla2x00_mailbox_command"
  (bsc#1012628).
- scsi: qla2xxx: Fix null pointer access during disconnect from
  subsystem (bsc#1012628).
- scsi: qla2xxx: Check if FW supports MQ before enabling
  (bsc#1012628).
- scsi: qla2xxx: Fix login timeout (bsc#1012628).
- scsi: qla2xxx: Indicate correct supported speeds for Mezz card
  (bsc#1012628).
- scsi: qla2xxx: Flush I/O on zone disable (bsc#1012628).
- scsi: qla2xxx: Flush all sessions on zone disable (bsc#1012628).
- scsi: scsi_debug: Fix scp is NULL errors (bsc#1012628).
- scsi: ufs: Clean up completed request without interrupt
  notification (bsc#1012628).
- scsi: ufs: Improve interrupt handling for shared interrupts
  (bsc#1012628).
- scsi: ufs: Fix possible infinite loop in ufshcd_hold
  (bsc#1012628).
- scsi: fcoe: Fix I/O path allocation (bsc#1012628).
- selftests: disable rp_filter for icmp_redirect.sh (bsc#1012628).
- ALSA: usb-audio: ignore broken processing/extension unit
  (bsc#1012628).
- ASoC: wm8994: Avoid attempts to read unreadable registers
  (bsc#1012628).
- s390/cio: add cond_resched() in the slow_eval_known_fn() loop
  (bsc#1012628).
- ALSA: hda/realtek: Add model alc298-samsung-headphone
  (bsc#1012628).
- drivers/net/wan/hdlc_x25: Added needed_headroom and a skb->len
  check (bsc#1012628).
- dma-pool: Only allocate from CMA when in same memory zone
  (bsc#1012628).
- dma-pool: fix coherent pool allocations for IOMMU mappings
  (bsc#1012628).
- can: j1939: transport: j1939_xtp_rx_dat_one(): compare own
  packets to detect corruptions (bsc#1012628).
- selftests/bpf: Correct various core_reloc 64-bit assumptions
  (bsc#1012628).
- selftests/bpf: Fix btf_dump test cases on 32-bit arches
  (bsc#1012628).
- selftest/bpf: Fix compilation warnings in 32-bit mode
  (bsc#1012628).
- tools/bpftool: Fix compilation warnings in 32-bit mode
  (bsc#1012628).
- libbpf: Prevent overriding errno when logging errors
  (bsc#1012628).
- netfilter: avoid ipv6 -> nf_defrag_ipv6 module dependency
  (bsc#1012628).
- selftests/bpf: Fix segmentation fault in test_progs
  (bsc#1012628).
- drm/amd/display: Switch to immediate mode for updating
  infopackets (bsc#1012628).
- drm/amd/display: Fix LFC multiplier changing erratically
  (bsc#1012628).
- drm/amd/powerplay: correct UVD/VCE PG state on custom pptable
  uploading (bsc#1012628).
- drm/amd/powerplay: correct Vega20 cached smu feature state
  (bsc#1012628).
- spi: stm32: always perform registers configuration prior to
  transfer (bsc#1012628).
- spi: stm32: fix stm32_spi_prepare_mbr in case of odd clk_rate
  (bsc#1012628).
- spi: stm32: fix fifo threshold level in case of short transfer
  (bsc#1012628).
- spi: stm32h7: fix race condition at end of transfer
  (bsc#1012628).
- fs: prevent BUG_ON in submit_bh_wbc() (bsc#1012628).
- ext4: correctly restore system zone info when remount fails
  (bsc#1012628).
- ext4: handle error of ext4_setup_system_zone() on remount
  (bsc#1012628).
- ext4: handle option set by mount flags correctly (bsc#1012628).
- jbd2: abort journal if free a async write error metadata buffer
  (bsc#1012628).
- ext4: abort the filesystem if failed to async write metadata
  buffer (bsc#1012628).
- drm/virtio: fix memory leak in virtio_gpu_cleanup_object()
  (bsc#1012628).
- ext4: skip non-loaded groups at cr=0/1 when scanning for good
  groups (bsc#1012628).
- ext4: handle read only external journal device (bsc#1012628).
- ext4: don't BUG on inconsistent journal feature (bsc#1012628).
- jbd2: make sure jh have b_transaction set in
  refile/unfile_buffer (bsc#1012628).
- spi: stm32: clear only asserted irq flags on interrupt
  (bsc#1012628).
- video: fbdev: controlfb: Fix build for COMPILE_TEST=y &&
  PPC_PMAC=n (bsc#1012628).
- usb: gadget: f_tcm: Fix some resource leaks in some error paths
  (bsc#1012628).
- vdpa: ifcvf: free config irq in ifcvf_free_irq() (bsc#1012628).
- vdpa: ifcvf: return err when fail to request config irq
  (bsc#1012628).
- i2c: rcar: in slave mode, clear NACK earlier (bsc#1012628).
- i2c: core: Don't fail PRP0001 enumeration when no ID table exist
  (bsc#1012628).
- drm/etnaviv: always start/stop scheduler in timeout processing
  (bsc#1012628).
- habanalabs: Fix memory corruption in debugfs (bsc#1012628).
- null_blk: fix passing of REQ_FUA flag in null_handle_rq
  (bsc#1012628).
- nvme: multipath: round-robin: fix single non-optimized path case
  (bsc#1012628).
- nvme-fc: Fix wrong return value in __nvme_fc_init_request()
  (bsc#1012628).
- nvmet: fix a memory leak (bsc#1012628).
- blkcg: fix memleak for iolatency (bsc#1012628).
- blk-mq: insert request not through ->queue_rq into sw/scheduler
  queue (bsc#1012628).
- hwmon: (nct7904) Correct divide by 0 (bsc#1012628).
- bfq: fix blkio cgroup leakage v4 (bsc#1012628).
- block: Fix page_is_mergeable() for compound pages (bsc#1012628).
- drm/msm/adreno: fix updating ring fence (bsc#1012628).
- block: virtio_blk: fix handling single range discard request
  (bsc#1012628).
- block: respect queue limit of max discard segment (bsc#1012628).
- nfsd: fix oops on mixed NFSv4/NFSv3 client access (bsc#1012628).
- ALSA: usb-audio: Add capture support for Saffire 6 (USB 1.1)
  (bsc#1012628).
- cpufreq: intel_pstate: Fix EPP setting via sysfs in active mode
  (bsc#1012628).
- PM / devfreq: Fix the wrong end with semicolon (bsc#1012628).
- PCI: qcom: Add missing reset for ipq806x (bsc#1012628).
- PCI: qcom: Change duplicate PCI reset to phy reset
  (bsc#1012628).
- PCI: qcom: Add missing ipq806x clocks in PCIe driver
  (bsc#1012628).
- net: openvswitch: introduce common code for flushing flows
  (bsc#1012628).
- arm64: Fix __cpu_logical_map undefined issue (bsc#1012628).
- efi: provide empty efi_enter_virtual_mode implementation
  (bsc#1012628).
- pinctrl: mediatek: fix build for tristate changes (bsc#1012628).
- pinctrl: mediatek: avoid virtual gpio trying to set reg
  (bsc#1012628).
- brcmfmac: Set timeout value when configuring power save
  (bsc#1012628).
- mmc: sdhci-of-arasan: fix timings allocation code (bsc#1012628).
- USB: sisusbvga: Fix a potential UB casued by left shifting a
  negative value (bsc#1012628).
- dmaengine: idxd: fix PCI_MSI build errors (bsc#1012628).
- powerpc/spufs: add CONFIG_COREDUMP dependency (bsc#1012628).
- KVM: arm64: Fix symbol dependency in __hyp_call_panic_nvhe
  (bsc#1012628).
- drm/amd/display: fix compilation error on allmodconfig
  (bsc#1012628).
- drm/amd/display: change global buffer to local buffer
  (bsc#1012628).
- media: i2c: imx290: fix reset GPIO pin handling (bsc#1012628).
- media: davinci: vpif_capture: fix potential double free
  (bsc#1012628).
- hugetlbfs: prevent filesystem stacking of hugetlbfs
  (bsc#1012628).
- EDAC/ie31200: Fallback if host bridge device is already
  initialized (bsc#1012628).
- i2c: i801: Add support for Intel Tiger Lake PCH-H (bsc#1012628).
- scsi: fcoe: Memory leak fix in fcoe_sysfs_fcf_del()
  (bsc#1012628).
- ceph: do not access the kiocb after aio requests (bsc#1012628).
- ceph: fix potential mdsc use-after-free crash (bsc#1012628).
- netfilter: nf_tables: report EEXIST on overlaps (bsc#1012628).
- scsi: iscsi: Do not put host in iscsi_set_flashnode_param()
  (bsc#1012628).
- btrfs: make btrfs_qgroup_check_reserved_leak take btrfs_inode
  (bsc#1012628).
- btrfs: file: reserve qgroup space after the hole punch range
  is locked (bsc#1012628).
- locking/lockdep: Fix overflow in presentation of average
  lock-time (bsc#1012628).
- drm/nouveau: Fix reference count leak in
  nouveau_connector_detect (bsc#1012628).
- drm/nouveau: fix reference count leak in nv50_disp_atomic_commit
  (bsc#1012628).
- drm/nouveau/drm/noveau: fix reference count leak in
  nouveau_fbcon_open (bsc#1012628).
- f2fs: fix use-after-free issue (bsc#1012628).
- HID: quirks: add NOGET quirk for Logitech GROUP (bsc#1012628).
- ASoC: Intel: sof_sdw_rt711: remove properties in card remove
  (bsc#1012628).
- cec-api: prevent leaking memory through hole in structure
  (bsc#1012628).
- gpu: host1x: Put gather's BO on pinning error (bsc#1012628).
- ALSA: hda: Add support for Loongson 7A1000 controller
  (bsc#1012628).
- mips/vdso: Fix resource leaks in genvdso.c (bsc#1012628).
- rtlwifi: rtl8192cu: Prevent leaking urb (bsc#1012628).
- ARM: dts: ls1021a: output PPS signal on FIPER2 (bsc#1012628).
- PCI: Fix pci_create_slot() reference count leak (bsc#1012628).
- omapfb: fix multiple reference count leaks due to
  pm_runtime_get_sync (bsc#1012628).
- MIPS: KVM: Limit Trap-and-Emulate to MIPS32R2 only
  (bsc#1012628).
- f2fs: fix error path in do_recover_data() (bsc#1012628).
- f2fs: remove write attribute of main_blkaddr sysfs node
  (bsc#1012628).
- selftests/powerpc: Purge extra count_pmc() calls of ebb
  selftests (bsc#1012628).
- scsi: target: Fix xcopy sess release leak (bsc#1012628).
- xfs: Don't allow logging of XFS_ISTALE inodes (bsc#1012628).
- scsi: lpfc: Fix shost refcount mismatch when deleting vport
  (bsc#1012628).
- drm/amdgpu/pm: fix ref count leak when pm_runtime_get_sync fails
  (bsc#1012628).
- drm/amdkfd: fix ref count leak when pm_runtime_get_sync fails
  (bsc#1012628).
- drm/amdgpu/fence: fix ref count leak when pm_runtime_get_sync
  fails (bsc#1012628).
- drm/amdgpu/display: fix ref count leak when pm_runtime_get_sync
  fails (bsc#1012628).
- drm/amdgpu: fix ref count leak in amdgpu_display_crtc_set_config
  (bsc#1012628).
- drm/amd/display: fix ref count leak in amdgpu_drm_ioctl
  (bsc#1012628).
- drm/amdgpu: fix ref count leak in amdgpu_driver_open_kms
  (bsc#1012628).
- drm/radeon: fix multiple reference count leak (bsc#1012628).
- drm/amdkfd: Fix reference count leaks (bsc#1012628).
- platform/chrome: cros_ec_sensorhub: Fix EC timestamp overflow
  (bsc#1012628).
- iommu/iova: Don't BUG on invalid PFNs (bsc#1012628).
- mfd: intel-lpss: Add Intel Tiger Lake PCH-H PCI IDs
  (bsc#1012628).
- scsi: target: tcmu: Fix crash on ARM during cmd completion
  (bsc#1012628).
- staging: rts5208: fix memleaks on error handling paths in probe
  (bsc#1012628).
- blktrace: ensure our debugfs dir exists (bsc#1012628).
- gcc-plugins/stackleak: Don't instrument itself (bsc#1012628).
- media: pci: ttpci: av7110: fix possible buffer overflow caused
  by bad DMA value in debiirq() (bsc#1012628).
- powerpc/xive: Ignore kmemleak false positives (bsc#1012628).
- arm64: dts: qcom: msm8916: Pull down PDM GPIOs during sleep
  (bsc#1012628).
- mfd: intel-lpss: Add Intel Emmitsburg PCH PCI IDs (bsc#1012628).
- ASoC: tegra: Fix reference count leaks (bsc#1012628).
- ASoC: img-parallel-out: Fix a reference count leak
  (bsc#1012628).
- ASoC: img: Fix a reference count leak in img_i2s_in_set_fmt
  (bsc#1012628).
- EDAC/mc: Call edac_inc_ue_error() before panic (bsc#1012628).
- drm/amdgpu: fix RAS memory leak in error case (bsc#1012628).
- ALSA: hda/hdmi: Use force connectivity quirk on another HP
  desktop (bsc#1012628).
- ALSA: hda/realtek: Fix pin default on Intel NUC 8 Rugged
  (bsc#1012628).
- ALSA: pci: delete repeated words in comments (bsc#1012628).
- ALSA: hda/hdmi: Add quirk to force connectivity (bsc#1012628).
- ASoC: intel/skl/hda - fix probe regression on systems without
  i915 (bsc#1012628).
- khugepaged: khugepaged_test_exit() check mmget_still_valid()
  (bsc#1012628).
- commit 6e8d15c
* Fri Sep  4 2020 mkubecek@suse.cz
- net/packet: fix overflow in tpacket_rcv (CVE-2020-14386
  bsc#1176069).
- commit eba56bd
* Mon Aug 31 2020 mkubecek@suse.cz
- Update to 5.9-rc3
- eliminated 1 patch
  - patches.suse/Revert-HID-usbhid-do-not-sleep-when-opening-device.patch
- update configs
  - new config option:
  - PPC_PROT_SAO_LPAR=n (ppc64 and ppc64le)
- commit 3cc13d8
* Sun Aug 30 2020 mkubecek@suse.cz
- series.conf: whitespace cleanup
- commit efc1fed
* Fri Aug 28 2020 msuchanek@suse.de
- obsolete_kmp: provide newer version than the obsoleted one
  (boo#1170232).
- commit c5ecb27
* Fri Aug 28 2020 tiwai@suse.de
- fs/cachefiles: Drop superfluous readpages aops NULL check
  (bsc#1175245).
- commit e4cd10b
* Thu Aug 27 2020 jslaby@suse.cz
- Linux 5.8.5 (bsc#1012628).
- binfmt_flat: revert "binfmt_flat: don't offset the data start"
  (bsc#1012628).
- io_uring: fix missing ->mm on exit (bsc#1012628).
- netlink: fix state reallocation in policy export (bsc#1012628).
- ethtool: Don't omit the netlink reply if no features were
  changed (bsc#1012628).
- ethtool: Account for hw_features in netlink interface
  (bsc#1012628).
- ethtool: Fix preserving of wanted feature bits in netlink
  interface (bsc#1012628).
- net: ena: Make missed_tx stat incremental (bsc#1012628).
- tipc: fix uninit skb->data in tipc_nl_compat_dumpit()
  (bsc#1012628).
- tipc: call rcu_read_lock() in tipc_aead_encrypt_done()
  (bsc#1012628).
- net/smc: Prevent kernel-infoleak in __smc_diag_dump()
  (bsc#1012628).
- net: sctp: Fix negotiation of the number of data streams
  (bsc#1012628).
- net/sched: act_ct: Fix skb double-free in
  tcf_ct_handle_fragments() error flow (bsc#1012628).
- net: qrtr: fix usage of idr in port assignment to socket
  (bsc#1012628).
- net: nexthop: don't allow empty NHA_GROUP (bsc#1012628).
- net: Fix potential wrong skb->protocol in skb_vlan_untag()
  (bsc#1012628).
- gre6: Fix reception with IP6_TNL_F_RCV_DSCP_COPY (bsc#1012628).
- commit 4d7a832
* Thu Aug 27 2020 mkubecek@suse.cz
- Update upstream reference:
  patches.suse/Revert-HID-usbhid-do-not-sleep-when-opening-device.patch.
- commit 993f7ee
* Wed Aug 26 2020 jslaby@suse.cz
- Linux 5.8.4 (bsc#1012628).
- drm/vgem: Replace opencoded version of drm_gem_dumb_map_offset()
  (bsc#1012628).
- drm/panel-simple: Fix inverted V/H SYNC for Frida FRD350H54004
  panel (bsc#1012628).
- drm/ast: Remove unused code paths for AST 1180 (bsc#1012628).
- drm/ast: Initialize DRAM type before posting GPU (bsc#1012628).
- khugepaged: adjust VM_BUG_ON_MM() in __khugepaged_enter()
  (bsc#1012628).
- ALSA: hda: avoid reset of sdo_limit (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Samsung Galaxy Flex Book
  (bsc#1012628).
- ALSA: hda/realtek: Add quirk for Samsung Galaxy Book Ion
  (bsc#1012628).
- can: j1939: transport: j1939_session_tx_dat(): fix
  use-after-free read in j1939_tp_txtimer() (bsc#1012628).
- can: j1939: socket: j1939_sk_bind(): make sure ml_priv is
  allocated (bsc#1012628).
- spi: Prevent adding devices below an unregistering controller
  (bsc#1012628).
- io_uring: find and cancel head link async work on files exit
  (bsc#1012628).
- mm/vunmap: add cond_resched() in vunmap_pmd_range (bsc#1012628).
- romfs: fix uninitialized memory leak in romfs_dev_read()
  (bsc#1012628).
- kernel/relay.c: fix memleak on destroy relay channel
  (bsc#1012628).
- uprobes: __replace_page() avoid BUG in munlock_vma_page()
  (bsc#1012628).
- squashfs: avoid bio_alloc() failure with 1Mbyte blocks
  (bsc#1012628 bsc#1175308).
- mm: include CMA pages in lowmem_reserve at boot (bsc#1012628).
- mm, page_alloc: fix core hung in free_pcppages_bulk()
  (bsc#1012628).
- ASoC: amd: renoir: restore two more registers during resume
  (bsc#1012628).
- RDMA/hfi1: Correct an interlock issue for TID RDMA WRITE request
  (bsc#1012628).
- opp: Enable resources again if they were disabled earlier
  (bsc#1012628).
- opp: Put opp table in dev_pm_opp_set_rate() for empty tables
  (bsc#1012628).
- opp: Put opp table in dev_pm_opp_set_rate() if _set_opp_bw()
  fails (bsc#1012628).
- ext4: do not block RWF_NOWAIT dio write on unallocated space
  (bsc#1012628).
- ext4: fix checking of directory entry validity for inline
  directories (bsc#1012628).
- jbd2: add the missing unlock_buffer() in the error path of
  jbd2_write_superblock() (bsc#1012628).
- scsi: zfcp: Fix use-after-free in request timeout handlers
  (bsc#1012628).
- selftests: kvm: Use a shorter encoding to clear RAX
  (bsc#1012628).
- s390/pci: fix zpci_bus_link_virtfn() (bsc#1012628).
- s390/pci: re-introduce zpci_remove_device() (bsc#1012628).
- s390/pci: fix PF/VF linking on hot plug (bsc#1012628).
- s390/pci: ignore stale configuration request event
  (bsc#1012628).
- mm/memory.c: skip spurious TLB flush for retried page fault
  (bsc#1012628).
- drm: amdgpu: Use the correct size when allocating memory
  (bsc#1012628).
- drm/amdgpu/display: use GFP_ATOMIC in
  dcn20_validate_bandwidth_internal (bsc#1012628).
- drm/amd/display: Fix incorrect backlight register offset for
  DCN (bsc#1012628).
- drm/amd/display: Fix EDID parsing after resume from suspend
  (bsc#1012628).
- drm/amd/display: Blank stream before destroying HDCP session
  (bsc#1012628).
- drm/amd/display: Fix DFPstate hang due to view port changed
  (bsc#1012628).
- drm/amd/display: fix pow() crashing when given base 0
  (bsc#1012628).
- drm/i915/pmu: Prefer drm_WARN_ON over WARN_ON (bsc#1012628).
- drm/i915: Provide the perf pmu.module (bsc#1012628).
- scsi: ufs: Add DELAY_BEFORE_LPM quirk for Micron devices
  (bsc#1012628).
- scsi: target: tcmu: Fix crash in tcmu_flush_dcache_range on ARM
  (bsc#1012628).
- media: budget-core: Improve exception handling in
  budget_register() (bsc#1012628).
- media: coda: jpeg: add NULL check after kmalloc (bsc#1012628).
- f2fs: fix to check page dirty status before writeback
  (bsc#1012628).
- rtc: goldfish: Enable interrupt in set_alarm() when necessary
  (bsc#1012628).
- media: vpss: clean up resources in init (bsc#1012628).
- f2fs: should avoid inode eviction in synchronous path
  (bsc#1012628).
- Input: psmouse - add a newline when printing 'proto' by sysfs
  (bsc#1012628).
- MIPS: Fix unable to reserve memory for Crash kernel
  (bsc#1012628).
- m68knommu: fix overwriting of bits in ColdFire V3 cache control
  (bsc#1012628).
- svcrdma: Fix another Receive buffer leak (bsc#1012628).
- xfs: fix inode quota reservation checks (bsc#1012628).
- drm/ttm: fix offset in VMAs with a pg_offs in ttm_bo_vm_access
  (bsc#1012628).
- riscv: Fixup static_obj() fail (bsc#1012628).
- jffs2: fix UAF problem (bsc#1012628).
- ceph: fix use-after-free for fsc->mdsc (bsc#1012628).
- swiotlb-xen: use vmalloc_to_page on vmalloc virt addresses
  (bsc#1012628).
- cpufreq: intel_pstate: Fix cpuinfo_max_freq when
  MSR_TURBO_RATIO_LIMIT is 0 (bsc#1012628).
- scsi: libfc: Free skb in fc_disc_gpn_id_resp() for valid cases
  (bsc#1012628).
- virtio_ring: Avoid loop when vq is broken in virtqueue_poll
  (bsc#1012628).
- media: camss: fix memory leaks on error handling paths in probe
  (bsc#1012628).
- tools/testing/selftests/cgroup/cgroup_util.c: cg_read_strcmp:
  fix null pointer dereference (bsc#1012628).
- xfs: Fix UBSAN null-ptr-deref in xfs_sysfs_init (bsc#1012628).
- alpha: fix annotation of io{read,write}{16,32}be()
  (bsc#1012628).
- fat: fix fat_ra_init() for data clusters == 0 (bsc#1012628).
- fs/signalfd.c: fix inconsistent return codes for signalfd4
  (bsc#1012628).
- ext4: fix potential negative array index in do_split()
  (bsc#1012628).
- drm/virtio: fix missing dma_fence_put() in
  virtio_gpu_execbuffer_ioctl() (bsc#1012628).
- ext4: don't allow overlapping system zones (bsc#1012628).
- ext4: check journal inode extents more carefully (bsc#1012628).
- netfilter: nf_tables: nft_exthdr: the presence return value
  should be little-endian (bsc#1012628).
- spi: stm32: fixes suspend/resume management (bsc#1012628).
- ASoC: q6afe-dai: mark all widgets registers as SND_SOC_NOPM
  (bsc#1012628).
- ASoC: q6routing: add dummy register read/write function
  (bsc#1012628).
- tools/bpftool: Make skeleton code C++17-friendly by dropping
  typeof() (bsc#1012628).
- bpf: sock_ops ctx access may stomp registers in corner case
  (bsc#1012628).
- bpf: sock_ops sk access may stomp registers when dst_reg =
  src_reg (bsc#1012628).
- libbpf: Fix BTF-defined map-in-map initialization on 32-bit
  host arches (bsc#1012628).
- can: j1939: fix kernel-infoleak in j1939_sk_sock2sockaddr_can()
  (bsc#1012628).
- can: j1939: transport: j1939_simple_recv(): ignore local J1939
  messages send not by J1939 stack (bsc#1012628).
- can: j1939: transport: add j1939_session_skb_find_by_offset()
  function (bsc#1012628).
- igc: Fix PTP initialization (bsc#1012628).
- i40e: Set RX_ONLY mode for unicast promiscuous on VLAN
  (bsc#1012628).
- i40e: Fix crash during removing i40e driver (bsc#1012628).
- net: fec: correct the error path for regulator disable in probe
  (bsc#1012628).
- bonding: show saner speed for broadcast mode (bsc#1012628).
- can: j1939: fix support for multipacket broadcast message
  (bsc#1012628).
- can: j1939: cancel rxtimer on multipacket broadcast session
  complete (bsc#1012628).
- can: j1939: abort multipacket broadcast session when timeout
  occurs (bsc#1012628).
- can: j1939: add rxtimer for multipacket broadcast session
  (bsc#1012628).
- bonding: fix a potential double-unregister (bsc#1012628).
- ipvlan: fix device features (bsc#1012628).
- s390/runtime_instrumentation: fix storage key handling
  (bsc#1012628).
- s390/ptrace: fix storage key handling (bsc#1012628).
- ASoC: msm8916-wcd-analog: fix register Interrupt offset
  (bsc#1012628).
- ASoC: intel: Fix memleak in sst_media_open (bsc#1012628).
- watch_queue: Limit the number of watches a user can hold
  (bsc#1012628).
- vfio-pci: Avoid recursive read-lock usage (bsc#1012628).
- vfio/type1: Add proper error unwind for vfio_iommu_replay()
  (bsc#1012628).
- arch/ia64: Restore arch-specific pgd_offset_k implementation
  (bsc#1012628).
- kvm: x86: Toggling CR4.SMAP does not load PDPTEs in PAE mode
  (bsc#1012628).
- kvm: x86: Toggling CR4.PKE does not load PDPTEs in PAE mode
  (bsc#1012628).
- of/address: check for invalid range.cpu_addr (bsc#1012628).
- scsi: ufs: ti-j721e-ufs: Fix error return in
  ti_j721e_ufs_probe() (bsc#1012628).
- scsi: ufs: Add quirk to fix mishandling utrlclr/utmrlclr
  (bsc#1012628).
- scsi: ufs: Add quirk to disallow reset of interrupt aggregation
  (bsc#1012628).
- scsi: ufs: Add quirk to enable host controller without hce
  (bsc#1012628).
- scsi: ufs: Introduce UFSHCD_QUIRK_PRDT_BYTE_GRAN quirk
  (bsc#1012628).
- scsi: ufs: Add quirk to fix abnormal ocs fatal error
  (bsc#1012628).
- scsi: ufs-pci: Add quirk for broken auto-hibernate for Intel
  EHL (bsc#1012628).
- scsi: ufs: Fix interrupt error message for shared interrupts
  (bsc#1012628).
- Revert "scsi: qla2xxx: Disable T10-DIF feature with FC-NVMe
  during probe" (bsc#1012628).
- kconfig: qconf: do not limit the pop-up menu to the first row
  (bsc#1012628).
- kconfig: qconf: fix signal connection to invalid slots
  (bsc#1012628).
- efi: avoid error message when booting under Xen (bsc#1012628).
- Fix build error when CONFIG_ACPI is not set/enabled:
  (bsc#1012628).
- RDMA/bnxt_re: Do not add user qps to flushlist (bsc#1012628).
- Revert "RDMA/hns: Reserve one sge in order to avoid local
  length error" (bsc#1012628).
- afs: Fix key ref leak in afs_put_operation() (bsc#1012628).
- kconfig: qconf: remove qInfo() to get back Qt4 support
  (bsc#1012628).
- afs: Fix NULL deref in afs_dynroot_depopulate() (bsc#1012628).
- ARM64: vdso32: Install vdso32 from vdso_install (bsc#1012628).
- powerpc/fixmap: Fix the size of the early debug area
  (bsc#1012628).
- bpf: Use get_file_rcu() instead of get_file() for task_file
  iterator (bsc#1012628).
- powerpc/pseries/hotplug-cpu: wait indefinitely for vCPU death
  (bsc#1012628).
- net: ena: Prevent reset after device destruction (bsc#1012628).
- net: ena: Change WARN_ON expression in ena_del_napi_in_range()
  (bsc#1012628).
- net: gemini: Fix missing free_netdev() in error path of
  gemini_ethernet_port_probe() (bsc#1012628).
- selftests/bpf: Remove test_align leftovers (bsc#1012628).
- hv_netvsc: Fix the queue_mapping in netvsc_vf_xmit()
  (bsc#1012628).
- net: dsa: b53: check for timeout (bsc#1012628).
- epoll: Keep a reference on files added to the check list
  (bsc#1012628).
- powerpc: Fix P10 PVR revision in /proc/cpuinfo for SMT4 cores
  (bsc#1012628).
- powerpc/pseries: Do not initiate shutdown when system is
  running on UPS (bsc#1012628).
- EDAC/{i7core,sb,pnd2,skx}: Fix error event severity
  (bsc#1012628).
- efi/x86: Mark kernel rodata non-executable for mixed mode
  (bsc#1012628).
- efi: add missed destroy_workqueue when efisubsys_init fails
  (bsc#1012628).
- efi/libstub: Stop parsing arguments at "--" (bsc#1012628).
- efi/libstub: Handle NULL cmdline (bsc#1012628).
- efi/libstub: Handle unterminated cmdline (bsc#1012628).
- do_epoll_ctl(): clean the failure exits up a bit (bsc#1012628).
- KVM: Pass MMU notifier range flags to kvm_unmap_hva_range()
  (bsc#1012628).
- KVM: arm64: Only reschedule if MMU_NOTIFIER_RANGE_BLOCKABLE
  is not set (bsc#1012628).
- Revert "drm/amd/display: Improve DisplayPort monitor interop"
  (bsc#1012628).
- Delete
  patches.suse/squashfs-avoid-bio_alloc-failure-with-1Mbyte-blocks.patch.
- Update config files.
- commit 64fe492
* Wed Aug 26 2020 alnovak@suse.cz
- Mark the kernel properly released.
  There perhaps was a typo, when SUSE_KERNEL_RELEASED missed the trailing
  "D" - this leads to our kernels being marked as "Unreleased kernel".
  SUSE_KERNEL_RELEASED is defined in rpm/kernel-binary.spec.in.
  To fix that, it should be enough to switch from SUSE_KERNEL_RELEASE to
  SUSE_KERNEL_RELEASED.
- commit 1a2deff
* Tue Aug 25 2020 jslaby@suse.cz
- Update
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch
  (bsc#865869 bsc#1175657).
  Add the second bsc reference.
- commit fb64fba
* Mon Aug 24 2020 mkubecek@suse.cz
- Revert "HID: usbhid: do not sleep when opening device".
- commit 4229f31
* Mon Aug 24 2020 wqu@suse.com
- Refresh
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch.
- commit 31073f8
* Mon Aug 24 2020 wqu@suse.com
- Refresh
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch.
- commit 74987e4
* Mon Aug 24 2020 mkubecek@suse.cz
- Update to 5.9-rc2
- eliminated 1 patch
  - patches.suse/squashfs-avoid-bio_alloc-failure-with-1Mbyte-blocks.patch
- refresh configs
- commit 7bec2d7
* Sun Aug 23 2020 mkubecek@suse.cz
- series.conf: cleanup
  Move an "almost mainline" patch to "almost mainline" section.
- commit 4e4b6b0
* Fri Aug 21 2020 jslaby@suse.cz
- Linux 5.8.3 (bsc#1012628).
- smb3: warn on confusing error scenario with sec=krb5
  (bsc#1012628).
- SMB3: Fix mkdir when idsfromsid configured on mount
  (bsc#1012628).
- genirq/affinity: Make affinity setting if activated opt-in
  (bsc#1012628).
- genirq: Unlock irq descriptor after errors (bsc#1012628).
- genirq/PM: Always unlock IRQ descriptor in rearm_wake_irq()
  (bsc#1012628).
- PCI: hotplug: ACPI: Fix context refcounting in
  acpiphp_grab_context() (bsc#1012628).
- PCI/ATS: Add pci_pri_supported() to check device or associated
  PF (bsc#1012628).
- PCI: Mark AMD Navi10 GPU rev 0x00 ATS as broken (bsc#1012628).
- PCI: Add device even if driver attach failed (bsc#1012628).
- PCI: qcom: Define some PARF params needed for ipq8064 SoC
  (bsc#1012628).
- PCI: qcom: Add support for tx term offset for rev 2.1.0
  (bsc#1012628).
- btrfs: allow use of global block reserve for balance item
  deletion (bsc#1012628).
- btrfs: free anon block device right after subvolume deletion
  (bsc#1012628).
- btrfs: don't allocate anonymous block device for user invisible
  roots (bsc#1012628).
- btrfs: preallocate anon block device at first phase of snapshot
  creation (bsc#1012628).
- btrfs: ref-verify: fix memory leak in add_block_entry
  (bsc#1012628).
- btrfs: only commit the delayed inode when doing a full fsync
  (bsc#1012628).
- btrfs: stop incremening log_batch for the log root tree when
  syncing log (bsc#1012628).
- btrfs: only commit delayed items at fsync if we are logging
  a directory (bsc#1012628).
- btrfs: remove no longer needed use of log_writers for the log
  root tree (bsc#1012628).
- btrfs: don't traverse into the seed devices in show_devname
  (bsc#1012628).
- btrfs: pass checksum type via BTRFS_IOC_FS_INFO ioctl
  (bsc#1012628).
- btrfs: open device without device_list_mutex (bsc#1012628).
- btrfs: move the chunk_mutex in btrfs_read_chunk_tree
  (bsc#1012628).
- btrfs: relocation: review the call sites which can be
  interrupted by signal (bsc#1012628).
- btrfs: add missing check for nocow and compression inode flags
  (bsc#1012628).
- btrfs: avoid possible signal interruption of
  btrfs_drop_snapshot() on relocation tree (bsc#1012628).
- btrfs: return EROFS for BTRFS_FS_STATE_ERROR cases
  (bsc#1012628).
- btrfs: sysfs: use NOFS for device creation (bsc#1012628).
- btrfs: don't WARN if we abort a transaction with EROFS
  (bsc#1012628).
- btrfs: fix race between page release and a fast fsync
  (bsc#1012628).
- btrfs: don't show full path of bind mounts in subvol=
  (bsc#1012628).
- btrfs: fix messages after changing compression level by remount
  (bsc#1012628).
- btrfs: only search for left_info if there is no right_info in
  try_merge_free_space (bsc#1012628).
- btrfs: inode: fix NULL pointer dereference if inode doesn't
  need compression (bsc#1012628).
- btrfs: fix memory leaks after failure to lookup checksums
  during inode logging (bsc#1012628).
- btrfs: trim: fix underflow in trim length to prevent access
  beyond device boundary (bsc#1012628).
- btrfs: make sure SB_I_VERSION doesn't get unset by remount
  (bsc#1012628).
- btrfs: fix return value mixup in btrfs_get_extent (bsc#1012628).
- btrfs: check correct variable after allocation in
  btrfs_backref_iter_alloc (bsc#1012628).
- arm64: dts: qcom: sc7180: Drop the unused non-MSA SID
  (bsc#1012628).
- arm64: perf: Correct the event index in sysfs (bsc#1012628).
- dt-bindings: iio: io-channel-mux: Fix compatible string in
  example code (bsc#1012628).
- iio: dac: ad5592r: fix unbalanced mutex unlocks in
  ad5592r_read_raw() (bsc#1012628).
- iio: imu: st_lsm6dsx: reset hw ts after resume (bsc#1012628).
- xtensa: add missing exclusive access state management
  (bsc#1012628).
- xtensa: fix xtensa_pmu_setup prototype (bsc#1012628).
- cifs: Fix leak when handling lease break for cached root fid
  (bsc#1012628).
- powerpc/ptdump: Fix build failure in hashpagetable.c
  (bsc#1012628).
- powerpc: Allow 4224 bytes of stack expansion for the signal
  frame (bsc#1012628).
- powerpc: Fix circular dependency between percpu.h and mmu.h
  (bsc#1012628).
- pinctrl: ingenic: Enhance support for IRQ_TYPE_EDGE_BOTH
  (bsc#1012628).
- pinctrl: ingenic: Properly detect GPIO direction when configured
  for IRQ (bsc#1012628).
- media: venus: fix multiple encoder crash (bsc#1012628).
- media: vsp1: dl: Fix NULL pointer dereference on unbind
  (bsc#1012628).
- net: ethernet: stmmac: Disable hardware multicast filter
  (bsc#1012628).
- net: stmmac: dwmac1000: provide multicast filter fallback
  (bsc#1012628).
- irqchip/loongson-liointc: Fix misuse of gc->mask_cache
  (bsc#1012628).
- irqchip/gic-v4.1: Ensure accessing the correct RD when writing
  INVALLR (bsc#1012628).
- pidfd: Add missing sock updates for pidfd_getfd() (bsc#1012628).
- net/compat: Add missing sock updates for SCM_RIGHTS
  (bsc#1012628).
- selftests/seccomp: Set NNP for TSYNC ESRCH flag test
  (bsc#1012628).
- md/raid5: Fix Force reconstruct-write io stuck in degraded raid5
  (bsc#1012628).
- bcache: allocate meta data pages as compound pages
  (bsc#1012628).
- bcache: fix overflow in offset_to_stripe() (bsc#1012628).
- bcache: avoid nr_stripes overflow in bcache_device_init()
  (bsc#1012628).
- bcache: fix bio_{start,end}_io_acct with proper device
  (bsc#1012628).
- bcache: use disk_{start,end}_io_acct() to count I/O for bcache
  device (bsc#1012628).
- mac80211: fix misplaced while instead of if (bsc#1012628).
- appletalk: Fix atalk_proc_init() return path (bsc#1012628).
- driver core: Avoid binding drivers to dead devices
  (bsc#1012628).
- MIPS: CPU#0 is not hotpluggable (bsc#1012628).
- MIPS: qi_lb60: Fix routing to audio amplifier (bsc#1012628).
- MIPS: SGI-IP27: always enable NUMA in Kconfig (bsc#1012628).
- ext2: fix missing percpu_counter_inc (bsc#1012628).
- khugepaged: collapse_pte_mapped_thp() flush the right range
  (bsc#1012628).
- mm/hugetlb: fix calculation of
  adjust_range_if_pmd_sharing_possible (bsc#1012628).
- khugepaged: collapse_pte_mapped_thp() protect the pmd lock
  (bsc#1012628).
- khugepaged: retract_page_tables() remember to test exit
  (bsc#1012628).
- hugetlbfs: remove call to huge_pte_alloc without i_mmap_rwsem
  (bsc#1012628).
- mm/shuffle: don't move pages between zones and don't read
  garbage memmaps (bsc#1012628).
- mm: fix kthread_use_mm() vs TLB invalidate (bsc#1012628).
- ocfs2: change slot number type s16 to u16 (bsc#1012628).
- mm/page_counter.c: fix protection usage propagation
  (bsc#1012628).
- cma: don't quit at first error when activating reserved areas
  (bsc#1012628).
- mm/memory_hotplug: fix unpaired mem_hotplug_begin/done
  (bsc#1012628).
- ftrace: Setup correct FTRACE_FL_REGS flags for module
  (bsc#1012628).
- kprobes: Fix NULL pointer dereference at kprobe_ftrace_handler
  (bsc#1012628).
- tracing/hwlat: Honor the tracing_cpumask (bsc#1012628).
- tracing: Use trace_sched_process_free() instead of exit()
  for pid tracing (bsc#1012628).
- watchdog: f71808e_wdt: indicate WDIOF_CARDRESET support in
  watchdog_info.options (bsc#1012628).
- watchdog: f71808e_wdt: remove use of wrong watchdog_info option
  (bsc#1012628).
- watchdog: f71808e_wdt: clear watchdog timeout occurred flag
  (bsc#1012628).
- ceph: set sec_context xattr on symlink creation (bsc#1012628).
- ceph: handle zero-length feature mask in session messages
  (bsc#1012628).
- pseries: Fix 64 bit logical memory block panic (bsc#1012628).
- dm ebs: Fix incorrect checking for REQ_OP_FLUSH (bsc#1012628).
- dm: don't call report zones for more than the user requested
  (bsc#1012628).
- module: Correctly truncate sysfs sections output (bsc#1012628).
- bootconfig: Fix to find the initargs correctly (bsc#1012628).
- perf probe: Fix wrong variable warning when the probe point
  is not found (bsc#1012628).
- perf probe: Fix memory leakage when the probe point is not found
  (bsc#1012628).
- perf intel-pt: Fix FUP packet state (bsc#1012628).
- perf intel-pt: Fix duplicate branch after CBR (bsc#1012628).
- gfs2: Fix refcount leak in gfs2_glock_poke (bsc#1012628).
- gfs2: Never call gfs2_block_zero_range with an open transaction
  (bsc#1012628).
- remoteproc: qcom: q6v5: Update running state before requesting
  stop (bsc#1012628).
- remoteproc: qcom_q6v5_mss: Validate MBA firmware size before
  load (bsc#1012628).
- remoteproc: qcom_q6v5_mss: Validate modem blob firmware size
  before load (bsc#1012628).
- libnvdimm: Validate command family indices (bsc#1012628).
- drm/imx: imx-ldb: Disable both channels for split mode in
  enc->disable() (bsc#1012628).
- drm/ingenic: Fix incorrect assumption about plane->index
  (bsc#1012628).
- crypto: algif_aead - Only wake up when ctx->more is zero
  (bsc#1012628).
- mfd: arizona: Ensure 32k clock is put on driver unbind and error
  (bsc#1012628).
- octeontx2-af: change (struct qmem)->entry_sz from u8 to u16
  (bsc#1012628).
- mtd: rawnand: fsl_upm: Remove unused mtd var (bsc#1012628).
- mtd: rawnand: brcmnand: ECC error handling on EDU transfers
  (bsc#1012628).
- platform/chrome: cros_ec_ishtp: Fix a double-unlock issue
  (bsc#1012628).
- drm/amdgpu/debugfs: fix memory leak when pm_runtime_get_sync
  failed (bsc#1012628).
- RDMA/ipoib: Return void from ipoib_ib_dev_stop() (bsc#1012628).
- RDMA/ipoib: Fix ABBA deadlock with ipoib_reap_ah()
  (bsc#1012628).
- rtc: cpcap: fix range (bsc#1012628).
- media: staging: rkisp1: remove macro RKISP1_DIR_SINK_SRC
  (bsc#1012628).
- media: staging: rkisp1: rename macros 'RKISP1_DIR_*' to
  'RKISP1_ISP_SD_*' (bsc#1012628).
- media: staging: rkisp1: rsz: set default format if the given
  format is not RKISP1_ISP_SD_SRC (bsc#1012628).
- media: rockchip: rga: Introduce color fmt macros and refactor
  CSC mode logic (bsc#1012628).
- media: rockchip: rga: Only set output CSC mode for RGB input
  (bsc#1012628).
- IB/uverbs: Set IOVA on IB MR in uverbs layer (bsc#1012628).
- sched/uclamp: Protect uclamp fast path code with static key
  (bsc#1012628).
- selftests/bpf: Test_progs indicate to shell on non-actions
  (bsc#1012628).
- bpf: selftests: Restore netns after each test (bsc#1012628).
- selftests/bpf: test_progs use another shell exit on non-actions
  (bsc#1012628).
- selftests/bpf: test_progs avoid minus shell exit codes
  (bsc#1012628).
- USB: serial: ftdi_sio: make process-packet buffer unsigned
  (bsc#1012628).
- USB: serial: ftdi_sio: clean up receive processing
  (bsc#1012628).
- crypto: af_alg - Fix regression on empty requests (bsc#1012628).
- devres: keep both device name and resource name in pretty name
  (bsc#1012628).
- RDMA/counter: Only bind user QPs in auto mode (bsc#1012628).
- RDMA/counter: Allow manually bind QPs with different pids to
  same counter (bsc#1012628).
- mmc: renesas_sdhi_internal_dmac: clean up the code for dma
  complete (bsc#1012628).
- rtw88: pci: disable aspm for platform inter-op with module
  parameter (bsc#1012628).
- rtc: pl031: fix set_alarm by adding back call to
  alarm_irq_enable (bsc#1012628).
- crypto: caam - Remove broken arc4 support (bsc#1012628).
- gpu: ipu-v3: image-convert: Combine rotate/no-rotate irq
  handlers (bsc#1012628).
- gpu: ipu-v3: image-convert: Wait for all EOFs before completing
  a tile (bsc#1012628).
- dm rq: don't call blk_mq_queue_stopped() in dm_stop_queue()
  (bsc#1012628).
- ima: Fail rule parsing when appraise_flag=blacklist is
  unsupportable (bsc#1012628).
- f2fs: compress: fix to avoid memory leak on cc->cpages
  (bsc#1012628).
- clk: actions: Fix h_clk for Actions S500 SoC (bsc#1012628).
- selftests/powerpc: ptrace-pkey: Rename variables to make it
  easier to follow code (bsc#1012628).
- selftests/powerpc: ptrace-pkey: Update the test to mark an
  invalid pkey correctly (bsc#1012628).
- selftests/powerpc: ptrace-pkey: Don't update expected UAMOR
  value (bsc#1012628).
- iommu/omap: Check for failure of a call to omap_iommu_dump_ctx
  (bsc#1012628).
- clk: qcom: gcc: fix sm8150 GPU and NPU clocks (bsc#1012628).
- clk: qcom: clk-alpha-pll: remove unused/incorrect PLL_CAL_VAL
  (bsc#1012628).
- iommu/vt-d: Handle non-page aligned address (bsc#1012628).
- iommu/vt-d: Enforce PASID devTLB field mask (bsc#1012628).
- iommu/vt-d: Warn on out-of-range invalidation address
  (bsc#1012628).
- iommu/vt-d: Disable multiple GPASID-dev bind (bsc#1012628).
- i2c: rcar: slave: only send STOP event when we have been
  addressed (bsc#1012628).
- f2fs: compress: fix to update isize when overwriting compressed
  file (bsc#1012628).
- clk: qcom: gcc-sdm660: Fix up gcc_mss_mnoc_bimc_axi_clk
  (bsc#1012628).
- clk: clk-atlas6: fix return value check in atlas6_clk_init()
  (bsc#1012628).
- nvme: fix deadlock in disconnect during scan_work and/or
  ana_work (bsc#1012628).
- sched/uclamp: Fix a deadlock when enabling uclamp static key
  (bsc#1012628).
- pwm: bcm-iproc: handle clk_get_rate() return (bsc#1012628).
- perf tools: Fix term parsing for raw syntax (bsc#1012628).
- tools build feature: Use CC and CXX from parent (bsc#1012628).
- i2c: rcar: avoid race when unregistering slave (bsc#1012628).
- nfs: ensure correct writeback errors are returned on close()
  (bsc#1012628).
- ubi: fastmap: Don't produce the initial next anchor PEB when
  fastmap is disabled (bsc#1012628).
- ubi: fastmap: Free fastmap next anchor peb during detach
  (bsc#1012628).
- ubifs: Fix wrong orphan node deletion in ubifs_jnl_update|rename
  (bsc#1012628).
- clk: hsdk: Fix bad dependency on IOMEM (bsc#1012628).
- libnvdimm/security: fix a typo (bsc#1012628).
- libnvdimm/security: ensure sysfs poll thread woke up and fetch
  updated attr (bsc#1012628).
- openrisc: Fix oops caused when dumping stack (bsc#1012628).
- perf evsel: Don't set sample_regs_intr/sample_regs_user for
  dummy event (bsc#1012628).
- scsi: lpfc: nvmet: Avoid hang / use-after-free again when
  destroying targetport (bsc#1012628).
- nfs: nfs_file_write() should check for writeback errors
  (bsc#1012628).
- watchdog: initialize device before misc_register (bsc#1012628).
- watchdog: rti-wdt: balance pm runtime enable calls
  (bsc#1012628).
- md-cluster: Fix potential error pointer dereference in
  resize_bitmaps() (bsc#1012628).
- kprobes: Fix compiler warning for !CONFIG_KPROBES_ON_FTRACE
  (bsc#1012628).
- x86/tsr: Fix tsc frequency enumeration bug on Lightning Mountain
  SoC (bsc#1012628).
- x86/bugs/multihit: Fix mitigation reporting when VMX is not
  in use (bsc#1012628).
- selftests/bpf: Prevent runqslower from racing on building
  bpftool (bsc#1012628).
- Input: sentelic - fix error return when fsp_reg_write fails
  (bsc#1012628).
- perf record: Skip side-band event setup if HAVE_LIBBPF_SUPPORT
  is not set (bsc#1012628).
- selftests/bpf: Fix silent Makefile output (bsc#1012628).
- vdpa: Fix pointer math bug in vdpasim_get_config()
  (bsc#1012628).
- drm/vmwgfx: Use correct vmw_legacy_display_unit pointer
  (bsc#1012628).
- drm/vmwgfx: Fix two list_for_each loop exit tests (bsc#1012628).
- s390/test_unwind: fix possible memleak in test_unwind()
  (bsc#1012628).
- s390/Kconfig: add missing ZCRYPT dependency to VFIO_AP
  (bsc#1012628).
- net: qcom/emac: add missed clk_disable_unprepare in error path
  of emac_clks_phase1_init (bsc#1012628).
- nfs: Fix getxattr kernel panic and memory overflow
  (bsc#1012628).
- NFS: Fix flexfiles read failover (bsc#1012628).
- lib/test_lockup.c: fix return value of test_lockup_init()
  (bsc#1012628).
- fs/minix: set s_maxbytes correctly (bsc#1012628).
- fs/minix: fix block limit check for V1 filesystems
  (bsc#1012628).
- fs/minix: remove expected error message in block_to_path()
  (bsc#1012628).
- fs/ufs: avoid potential u32 multiplication overflow
  (bsc#1012628).
- test_kmod: avoid potential double free in
  trigger_config_run_type() (bsc#1012628).
- i2c: iproc: fix race between client unreg and isr (bsc#1012628).
- mfd: dln2: Run event handler loop under spinlock (bsc#1012628).
- crypto: algif_aead - fix uninitialized ctx->init (bsc#1012628).
- ALSA: echoaudio: Fix potential Oops in snd_echo_resume()
  (bsc#1012628).
- perf bench mem: Always memset source before memcpy
  (bsc#1012628).
- tools build feature: Quote CC and CXX for their arguments
  (bsc#1012628).
- perf/x86/rapl: Fix missing psys sysfs attributes (bsc#1012628).
- sh: landisk: Add missing initialization of sh_io_port_base
  (bsc#1012628).
- sh: fault: Fix duplicate printing of "PC:" (bsc#1012628).
- drm/i915/gt: Force the GT reset on shutdown (bsc#1012628).
- drm/panfrost: Use kvfree() to free bo->sgts (bsc#1012628).
- drm/dp_mst: Fix the DDC I2C device registration of an MST port
  (bsc#1012628).
- drm/dp_mst: Fix timeout handling of MST down messages
  (bsc#1012628).
- drm/dp_mst: Fix the DDC I2C device unregistration of an MST port
  (bsc#1012628).
- drm/omap: force runtime PM suspend on system suspend
  (bsc#1012628).
- drm/tidss: fix modeset init for DPI panels (bsc#1012628).
- drm: Added orientation quirk for ASUS tablet model T103HAF
  (bsc#1012628).
- drm: fix drm_dp_mst_port refcount leaks in
  drm_dp_mst_allocate_vcpi (bsc#1012628).
- drm/amdgpu: Fix bug where DPM is not enabled after hibernate
  and resume (bsc#1012628).
- drm/amd/display: Fix dmesg warning from setting abm level
  (bsc#1012628).
- drm/amd/display: dchubbub p-state warning during surface planes
  switch (bsc#1012628).
- Disable patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch
  (does not build).
- Update config files.
- commit bad027a
* Fri Aug 21 2020 jwiesner@suse.com
- bonding: fix active-backup failover for current ARP slave
  (bsc#1174771).
- commit 1874dbd
* Thu Aug 20 2020 jslaby@suse.cz
- drm/virtio: fix unblank (make virtio gpu work again).
- commit 42af09b
* Wed Aug 19 2020 jslaby@suse.cz
- recordmcount: Fix build failure on non arm64 (git-fixes).
- ALSA: hda/realtek - Fix unused variable warning (git-fixes).
- vdpa_sim: init iommu lock (git-fixes).
- commit 71b519a
* Wed Aug 19 2020 nstange@suse.de
- rpm/kernel-binary.spec.in: restrict livepatch metapackage to default flavor
  It has been reported that the kernel-*-livepatch metapackage got
  erroneously enabled for SLE15-SP3's new -preempt flavor, leading to a
  unresolvable dependency to a non-existing kernel-livepatch-x.y.z-preempt
  package.
  As SLE12 and SLE12-SP1 have run out of livepatching support, the need to
  build said metapackage for the -xen flavor is gone and the only remaining
  flavor for which they're still wanted is -default.
  Restrict the build of the kernel-*-livepatch metapackage to the -default
  flavor.
- commit 58949f3
* Wed Aug 19 2020 jslaby@suse.cz
- Update config files.
  Only gcc+ld texts updated.
- commit b1b5b8e
* Wed Aug 19 2020 jslaby@suse.cz
- Linux 5.8.2 (bnc#1012628).
- tracepoint: Mark __tracepoint_string's __used (bnc#1012628).
- kunit: capture stderr on all make subprocess calls
  (bnc#1012628).
- io_uring: abstract out task work running (bnc#1012628).
- HID: input: Fix devices that return multiple bytes in battery
  report (bnc#1012628).
- ARM: dts: stm32: fix uart nodes ordering in stm32mp15-pinctrl
  (bnc#1012628).
- ARM: dts: stm32: fix uart7_pins_a comments in stm32mp15-pinctrl
  (bnc#1012628).
- x86/mce/inject: Fix a wrong assignment of i_mce.status
  (bnc#1012628).
- perf/x86/intel/uncore: Fix oops when counting IMC uncore events
  on some TGL (bnc#1012628).
- x86, sched: check for counters overflow in frequency invariant
  accounting (bnc#1012628).
- x86, sched: Bail out of frequency invariance if turbo frequency
  is unknown (bnc#1012628).
- x86, sched: Bail out of frequency invariance if
  turbo_freq/base_freq gives 0 (bnc#1012628).
- sched/fair: Fix NOHZ next idle balance (bnc#1012628).
- sched: correct SD_flags returned by tl->sd_flags()
  (bnc#1012628).
- arm64: dts: rockchip: fix rk3368-lion gmac reset gpio
  (bnc#1012628).
- arm64: dts: rockchip: fix rk3399-puma vcc5v0-host gpio
  (bnc#1012628).
- arm64: dts: rockchip: fix rk3399-puma gmac reset gpio
  (bnc#1012628).
- EDAC: Fix reference count leaks (bnc#1012628).
- crc-t10dif: Fix potential crypto notify dead-lock (bnc#1012628).
- arm64: dts: qcom: msm8916: Replace invalid bias-pull-none
  property (bnc#1012628).
- memory: tegra: Fix an error handling path in
  tegra186_emc_probe() (bnc#1012628).
- blktrace: fix debugfs use after free (bnc#1012628).
- soc: qcom: rpmh-rsc: Don't use ktime for timeout in
  write_tcs_reg_sync() (bnc#1012628).
- crypto: ccree - fix resource leak on error path (bnc#1012628).
- ARM: exynos: MCPM: Restore big.LITTLE cpuidle support
  (bnc#1012628).
- rcu/tree: Repeat the monitor if any free channel is busy
  (bnc#1012628).
- firmware: arm_scmi: Fix SCMI genpd domain probing (bnc#1012628).
- arm64: dts: sun50i-pinephone: dldo4 must not be >= 1.8V
  (bnc#1012628).
- arm64: dts: exynos: Fix silent hang after boot on Espresso
  (bnc#1012628).
- sched/uclamp: Fix initialization of struct uclamp_rq
  (bnc#1012628).
- crypto: qat - allow xts requests not multiple of block
  (bnc#1012628).
- clk: scmi: Fix min and max rate when registering clocks with
  discrete rates (bnc#1012628).
- m68k: mac: Don't send IOP message until channel is idle
  (bnc#1012628).
- m68k: mac: Fix IOP status/control register writes (bnc#1012628).
- platform/x86: intel-hid: Fix return value check in
  check_acpi_dev() (bnc#1012628).
- platform/x86: intel-vbtn: Fix return value check in
  check_acpi_dev() (bnc#1012628).
- ARM: dts: gose: Fix ports node name for adv7180 (bnc#1012628).
- arm64: dts: renesas: Fix SD Card/eMMC interface device node
  names (bnc#1012628).
- ARM: dts: gose: Fix ports node name for adv7612 (bnc#1012628).
- ARM: at91: pm: add missing put_device() call in
  at91_pm_sram_init() (bnc#1012628).
- ARM: dts: exynos: Disable frequency scaling for FSYS bus on
  Odroid XU3 family (bnc#1012628).
- reset: intel: fix a compile warning about REG_OFFSET redefined
  (bnc#1012628).
- ARM: dts: at91: sama5d3_xplained: change phy-mode (bnc#1012628).
- ARM: dts: sunxi: bananapi-m2-plus-v1.2: Add regulator supply
  to all CPU cores (bnc#1012628).
- ARM: dts: sunxi: bananapi-m2-plus-v1.2: Fix CPU supply voltages
  (bnc#1012628).
- ARM: dts: stm32: Fix spi4 pins in stm32mp15-pinctrl
  (bnc#1012628).
- spi: dw-dma: Fix Tx DMA channel working too fast (bnc#1012628).
- spi: lantiq: fix: Rx overflow error in full duplex mode
  (bnc#1012628).
- crypto: x86/crc32c - fix building with clang ias (bnc#1012628).
- tpm: Require that all digests are present in TCG_PCR_EVENT2
  structures (bnc#1012628).
- recordmcount: only record relocation of type R_AARCH64_CALL26
  on arm64 (bnc#1012628).
- regulator: fix memory leak on error path of regulator_register()
  (bnc#1012628).
- io_uring: fix sq array offset calculation (bnc#1012628).
- arm64: dts: meson: misc fixups for w400 dtsi (bnc#1012628).
- arm64: dts: meson: fix mmc0 tuning error on Khadas VIM3
  (bnc#1012628).
- soc: qcom: pdr: Reorder the PD state indication ack
  (bnc#1012628).
- spi: rockchip: Fix error in SPI slave pio read (bnc#1012628).
- ARM: socfpga: PM: add missing put_device() call in
  socfpga_setup_ocram_self_refresh() (bnc#1012628).
- iocost: Fix check condition of iocg abs_vdebt (bnc#1012628).
- scripts/selinux/mdp: fix initial SID handling (bnc#1012628).
- irqchip/ti-sci-inta: Fix return value about
  devm_ioremap_resource() (bnc#1012628).
- seccomp: Fix ioctl number for SECCOMP_IOCTL_NOTIF_ID_VALID
  (bnc#1012628).
- md: raid0/linear: fix dereference before null check on pointer
  mddev (bnc#1012628).
- irqchip/loongson-htvec: Fix potential resource leak
  (bnc#1012628).
- irqchip/loongson-htvec: Check return value of
  irq_domain_translate_onecell() (bnc#1012628).
- irqchip/loongson-pch-pic: Check return value of
  irq_domain_translate_twocell() (bnc#1012628).
- irqchip/loongson-liointc: Fix potential dead lock (bnc#1012628).
- kunit: tool: fix broken default args in unit tests
  (bnc#1012628).
- kunit: tool: fix improper treatment of file location
  (bnc#1012628).
- irqchip/irq-bcm7038-l1: Guard uses of cpu_logical_map
  (bnc#1012628).
- irqchip/gic-v4.1: Use GFP_ATOMIC flag in allocate_vpe_l1_table()
  (bnc#1012628).
- nvme-tcp: fix controller reset hang during traffic
  (bnc#1012628).
- nvme-rdma: fix controller reset hang during traffic
  (bnc#1012628).
- nvme-multipath: fix logic for non-optimized paths (bnc#1012628).
- nvme-multipath: do not fall back to __nvme_find_path() for
  non-optimized paths (bnc#1012628).
- irqchip/loongson-pch-pic: Fix the misused irq flow handler
  (bnc#1012628).
- block: don't do revalidate zones on invalid devices
  (bnc#1012628).
- drm/tilcdc: fix leak & null ref in panel_connector_get_modes
  (bnc#1012628).
- soc: qcom: rpmh-rsc: Set suppress_bind_attrs flag (bnc#1012628).
- net: mscc: ocelot: fix encoding destination ports into multicast
  IPv4 address (bnc#1012628).
- ARM: exynos: clear L310_AUX_CTRL_FULL_LINE_ZERO in default
  l2c_aux_val (bnc#1012628).
- Bluetooth: add a mutex lock to avoid UAF in do_enale_set
  (bnc#1012628).
- loop: be paranoid on exit and prevent new additions / removals
  (bnc#1012628).
- io_uring: fix req->work corruption (bnc#1012628).
- fs/btrfs: Add cond_resched() for try_release_extent_mapping()
  stalls (bnc#1012628).
- drm/amdgpu: avoid dereferencing a NULL pointer (bnc#1012628).
- drm/radeon: Fix reference count leaks caused by
  pm_runtime_get_sync (bnc#1012628).
- crypto: aesni - Fix build with LLVM_IAS=1 (bnc#1012628).
- video: fbdev: savage: fix memory leak on error handling path
  in probe (bnc#1012628).
- video: fbdev: neofb: fix memory leak in neo_scan_monitor()
  (bnc#1012628).
- bus: ti-sysc: Add missing quirk flags for usb_host_hs
  (bnc#1012628).
- md-cluster: fix wild pointer of unlock_all_bitmaps()
  (bnc#1012628).
- rtw88: 8822ce: add support for device ID 0xc82f (bnc#1012628).
- drm/nouveau/kms/nv50-: Fix disabling dithering (bnc#1012628).
- arm64: dts: hisilicon: hikey: fixes to comply with adi,
  adv7533 DT binding (bnc#1012628).
- drm/etnaviv: fix ref count leak via pm_runtime_get_sync
  (bnc#1012628).
- ionic: rearrange reset and bus-master control (bnc#1012628).
- memory: samsung: exynos5422-dmc: Do not ignore return code of
  regmap_read() (bnc#1012628).
- drm/nouveau: fix reference count leak in
  nouveau_debugfs_strap_peek (bnc#1012628).
- drm/nouveau: fix multiple instances of reference count leaks
  (bnc#1012628).
- mmc: sdhci-cadence: do not use hardware tuning for SD mode
  (bnc#1012628).
- btrfs: fix lockdep splat from btrfs_dump_space_info
  (bnc#1012628).
- usb: mtu3: clear dual mode of u3port when disable device
  (bnc#1012628).
- drm: msm: a6xx: fix gpu failure after system resume
  (bnc#1012628).
- drm/msm: Fix a null pointer access in msm_gem_shrinker_count()
  (bnc#1012628).
- drm/debugfs: fix plain echo to connector "force" attribute
  (bnc#1012628).
- drm/radeon: disable AGP by default (bnc#1012628).
- net: phy: mscc: restore the base page in
  vsc8514/8584_config_init (bnc#1012628).
- irqchip/irq-mtk-sysirq: Replace spinlock with raw_spinlock
  (bnc#1012628).
- mm/mmap.c: Add cond_resched() for exit_mmap() CPU stalls
  (bnc#1012628).
- drm/amd/display: Improve DisplayPort monitor interop
  (bnc#1012628).
- drm/amdgpu/debugfs: fix ref count leak when pm_runtime_get_sync
  fails (bnc#1012628).
- drm/amdgpu/display bail early in dm_pp_get_static_clocks
  (bnc#1012628).
- drm/amdgpu/display: properly guard the calls to swSMU functions
  (bnc#1012628).
- drm/amd/display: allow query ddc data over aux to be read only
  operation (bnc#1012628).
- drm/amd/powerplay: fix compile error with ARCH=arc
  (bnc#1012628).
- bpf: Fix fds_example SIGSEGV error (bnc#1012628).
- Bluetooth: hci_qca: Bug fixes for SSR (bnc#1012628).
- brcmfmac: keep SDIO watchdog running when console_interval is
  non-zero (bnc#1012628).
- brcmfmac: To fix Bss Info flag definition Bug (bnc#1012628).
- brcmfmac: set state of hanger slot to FREE when flushing PSQ
  (bnc#1012628).
- platform/x86: asus-nb-wmi: add support for ASUS ROG Zephyrus
  G14 and G15 (bnc#1012628).
- iwlegacy: Check the return value of pcie_capability_read_*()
  (bnc#1012628).
- gpu: host1x: debug: Fix multiple channels emitting messages
  simultaneously (bnc#1012628).
- drm/amd/powerplay: suppress compile error around BUG_ON
  (bnc#1012628).
- ionic: update eid test for overflow (bnc#1012628).
- x86/uaccess: Make __get_user_size() Clang compliant on 32-bit
  (bnc#1012628).
- mmc: sdhci-pci-o2micro: Bug fix for O2 host controller Seabird1
  (bnc#1012628).
- usb: gadget: net2280: fix memory leak on probe error handling
  paths (bnc#1012628).
- bdc: Fix bug causing crash after multiple disconnects
  (bnc#1012628).
- usb: bdc: Halt controller on suspend (bnc#1012628).
- dyndbg: fix a BUG_ON in ddebug_describe_flags (bnc#1012628).
- bcache: fix super block seq numbers comparision in
  register_cache_set() (bnc#1012628).
- btrfs: allow btrfs_truncate_block() to fallback to nocow for
  data space reservation (bnc#1012628).
- btrfs: qgroup: free per-trans reserved space when a subvolume
  gets dropped (bnc#1012628).
- ACPICA: Do not increment operation_region reference counts
  for field units (bnc#1012628).
- io_uring: fix racy overflow count reporting (bnc#1012628).
- io_uring: fix stalled deferred requests (bnc#1012628).
- crypto: caam - silence .setkey in case of bad key length
  (bnc#1012628).
- drm/msm: ratelimit crtc event overflow error (bnc#1012628).
- drm/gem: Fix a leak in drm_gem_objects_lookup() (bnc#1012628).
- drm/bridge: ti-sn65dsi86: Clear old error bits before AUX
  transfers (bnc#1012628).
- drm/bridge: ti-sn65dsi86: Fix off-by-one error in clock choice
  (bnc#1012628).
- drm/amdgpu: use the unlocked drm_gem_object_put (bnc#1012628).
- agp/intel: Fix a memory leak on module initialisation failure
  (bnc#1012628).
- mwifiex: Fix firmware filename for sd8977 chipset (bnc#1012628).
- mwifiex: Fix firmware filename for sd8997 chipset (bnc#1012628).
- btmrvl: Fix firmware filename for sd8977 chipset (bnc#1012628).
- btmrvl: Fix firmware filename for sd8997 chipset (bnc#1012628).
- video: fbdev: sm712fb: fix an issue about iounmap for a wrong
  address (bnc#1012628).
- console: newport_con: fix an issue about leak related system
  resources (bnc#1012628).
- video: pxafb: Fix the function used to balance a
  'dma_alloc_coherent()' call (bnc#1012628).
- Bluetooth: hci_qca: Fix an error pointer dereference
  (bnc#1012628).
- drm/mm: fix hole size comparison (bnc#1012628).
- Bluetooth: hci_qca: Only remove TX clock vote after TX is
  completed (bnc#1012628).
- Bluetooth: Allow suspend even when preparation has failed
  (bnc#1012628).
- ath10k: Acquire tx_lock in tx error paths (bnc#1012628).
- Bluetooth: hci_qca: Bug fix during SSR timeout (bnc#1012628).
- Bluetooth: hci_qca: Increase SoC idle timeout to 200ms
  (bnc#1012628).
- iio: improve IIO_CONCENTRATION channel type description
  (bnc#1012628).
- iio: amplifiers: ad8366: Change devm_gpiod_get() to optional
  and add the missed check (bnc#1012628).
- scsi: ufs: Fix imprecise load calculation in devfreq window
  (bnc#1012628).
- drm/etnaviv: Fix error path on failure to enable bus clk
  (bnc#1012628).
- drm/panfrost: Fix inbalance of devfreq record_busy/idle()
  (bnc#1012628).
- drm/arm: fix unintentional integer overflow on left shift
  (bnc#1012628).
- clk: bcm63xx-gate: fix last clock availability (bnc#1012628).
- powerpc/mm: Fix typo in IS_ENABLED() (bnc#1012628).
- powerpc/fixmap: Fix FIX_EARLY_DEBUG_BASE when page size is 256k
  (bnc#1012628).
- leds: lm355x: avoid enum conversion warning (bnc#1012628).
- ASoC: fsl_easrc: Fix uninitialized scalar variable in
  fsl_easrc_set_ctx_format (bnc#1012628).
- Bluetooth: btusb: fix up firmware download sequence
  (bnc#1012628).
- Bluetooth: btmtksdio: fix up firmware download sequence
  (bnc#1012628).
- media: cxusb-analog: fix V4L2 dependency (bnc#1012628).
- media: marvell-ccic: Add missed v4l2_async_notifier_cleanup()
  (bnc#1012628).
- media: omap3isp: Add missed v4l2_ctrl_handler_free() for
  preview_init_entities() (bnc#1012628).
- staging: most: avoid null pointer dereference when iface is null
  (bnc#1012628).
- dpaa2-eth: fix condition for number of buffer acquire retries
  (bnc#1012628).
- ASoC: SOF: nocodec: add missing .owner field (bnc#1012628).
- ASoC: Intel: cml_rt1011_rt5682: add missing .owner field
  (bnc#1012628).
- ASoC: Intel: sof_sdw: add missing .owner field (bnc#1012628).
- ASoC: Intel: bxt_rt298: add missing .owner field (bnc#1012628).
- ASoC: Intel: Boards: cml_rt1011_rt5682: use statically define
  codec config (bnc#1012628).
- net: atlantic: MACSec offload statistics checkpatch fix
  (bnc#1012628).
- scsi: cumana_2: Fix different dev_id between request_irq()
  and free_irq() (bnc#1012628).
- scsi: ufs: Disable WriteBooster capability for non-supported
  UFS devices (bnc#1012628).
- drm/mipi: use dcs write for mipi_dsi_dcs_set_tear_scanline
  (bnc#1012628).
- cxl: Fix kobject memleak (bnc#1012628).
- lkdtm: Avoid more compiler optimizations for bad writes
  (bnc#1012628).
- selftests/lkdtm: Reset WARN_ONCE to avoid false negatives
  (bnc#1012628).
- lkdtm: Make arch-specific tests always available (bnc#1012628).
- net: ethernet: ti: am65-cpsw-nuss: restore vlan configuration
  while down/up (bnc#1012628).
- tracing: Move pipe reference to trace array instead of
  current_tracer (bnc#1012628).
- scsi: qla2xxx: Make __qla2x00_alloc_iocbs() initialize 32 bits
  of request_t.handle (bnc#1012628).
- drm/amdgpu/debugfs: fix memory leak when
  amdgpu_virt_enable_access_debugfs failed (bnc#1012628).
- drm/amdgpu: ensure 0 is returned for success in
  jpeg_v2_5_wait_for_idle (bnc#1012628).
- drm/radeon: fix array out-of-bounds read and write issues
  (bnc#1012628).
- staging: vchiq_arm: Add a matching unregister call
  (bnc#1012628).
- iavf: fix error return code in iavf_init_get_resources()
  (bnc#1012628).
- iavf: Fix updating statistics (bnc#1012628).
- dma-buf: fix dma-fence-chain out of order test (bnc#1012628).
- RDMA/core: Fix bogus WARN_ON during
  ib_unregister_device_queued() (bnc#1012628).
- scsi: powertec: Fix different dev_id between request_irq()
  and free_irq() (bnc#1012628).
- scsi: eesox: Fix different dev_id between request_irq() and
  free_irq() (bnc#1012628).
- ipvs: allow connection reuse for unconfirmed conntrack
  (bnc#1012628).
- media: firewire: Using uninitialized values in node_probe()
  (bnc#1012628).
- media: allegro: Fix some NULL vs IS_ERR() checks in probe
  (bnc#1012628).
- media: staging: rkisp1: rsz: supported formats are the isp's
  src formats, not sink formats (bnc#1012628).
- media: staging: rkisp1: rsz: fix resolution limitation on sink
  pad (bnc#1012628).
- media: tvp5150: Add missed media_entity_cleanup() (bnc#1012628).
- media: exynos4-is: Add missed check for pinctrl_lookup_state()
  (bnc#1012628).
- media: cros-ec-cec: do not bail on device_init_wakeup failure
  (bnc#1012628).
- xfs: preserve rmapbt swapext block reservation from freed blocks
  (bnc#1012628).
- xfs: don't eat an EIO/ENOSPC writeback error when scrubbing
  data fork (bnc#1012628).
- xfs: fix reflink quota reservation accounting error
  (bnc#1012628).
- RDMA/rxe: Skip dgid check in loopback mode (bnc#1012628).
- PCI: Fix pci_cfg_wait queue locking problem (bnc#1012628).
- samples: bpf: Fix bpf programs with kprobe/sys_connect event
  (bnc#1012628).
- drm/stm: repair runtime power management (bnc#1012628).
- kobject: Avoid premature parent object freeing in
  kobject_cleanup() (bnc#1012628).
- leds: core: Flush scheduled work for system suspend
  (bnc#1012628).
- drm: panel: simple: Fix bpc for LG LB070WV8 panel (bnc#1012628).
- phy: cadence: salvo: fix wrong bit definition (bnc#1012628).
- dt-bindings: phy: uniphier: Fix incorrect clocks and clock-names
  for PXs3 usb3-hsphy (bnc#1012628).
- phy: exynos5-usbdrd: Calibrating makes sense only for USB2.0
  PHY (bnc#1012628).
- mmc: sdhci-of-arasan: Add missed checks for devm_clk_register()
  (bnc#1012628).
- drm/bridge: sil_sii8620: initialize return of sii8620_readb
  (bnc#1012628).
- scsi: scsi_debug: Add check for sdebug_max_queue during module
  init (bnc#1012628).
- bpfilter: Initialize pos variable (bnc#1012628).
- mwifiex: Prevent memory corruption handling keys (bnc#1012628).
- kernfs: do not call fsnotify() with name without a parent
  (bnc#1012628).
- powerpc/pseries: remove cede offline state for CPUs
  (bnc#1012628).
- powerpc/rtas: don't online CPUs for partition suspend
  (bnc#1012628).
- powerpc/vdso: Fix vdso cpu truncation (bnc#1012628).
- Bluetooth: Fix update of connection state in `hci_encrypt_cfm`
  (bnc#1012628).
- RDMA/qedr: SRQ's bug fixes (bnc#1012628).
- RDMA/qedr: Add EDPM mode type for user-fw compatibility
  (bnc#1012628).
- RDMA/qedr: Add EDPM max size to alloc ucontext response
  (bnc#1012628).
- RDMA/rxe: Prevent access to wr->next ptr afrer wr is posted
  to send queue (bnc#1012628).
- ima: Have the LSM free its audit rule (bnc#1012628).
- ima: Free the entire rule when deleting a list of rules
  (bnc#1012628).
- ima: Free the entire rule if it fails to parse (bnc#1012628).
- ima: Fail rule parsing when buffer hook functions have an
  invalid action (bnc#1012628).
- ima: Fail rule parsing when the KEXEC_CMDLINE hook is combined
  with an invalid cond (bnc#1012628).
- ima: Fail rule parsing when the KEY_CHECK hook is combined
  with an invalid cond (bnc#1012628).
- staging: rtl8192u: fix a dubious looking mask before a shift
  (bnc#1012628).
- ASoC: meson: fixes the missed kfree() for
  axg_card_add_tdm_loopback (bnc#1012628).
- PCI/ASPM: Add missing newline in sysfs 'policy' (bnc#1012628).
- go7007: add sanity checking for endpoints (bnc#1012628).
- media: s5p-g2d: Fix a memory leak in an error handling path in
  'g2d_probe()' (bnc#1012628).
- phy: renesas: rcar-gen3-usb2: move irq registration to init
  (bnc#1012628).
- powerpc/mm/radix: Free PUD table when freeing pagetable
  (bnc#1012628).
- powerpc/book3s64/pkeys: Use PVR check instead of cpu feature
  (bnc#1012628).
- drm/imx: fix use after free (bnc#1012628).
- drm/imx: tve: fix regulator_disable error path (bnc#1012628).
- gpu: ipu-v3: Restore RGB32, BGR32 (bnc#1012628).
- spi: lantiq-ssc: Fix warning by using WQ_MEM_RECLAIM
  (bnc#1012628).
- PCI: loongson: Use DECLARE_PCI_FIXUP_EARLY for
  bridge_class_quirk() (bnc#1012628).
- USB: serial: iuu_phoenix: fix led-activity helpers
  (bnc#1012628).
- clk: qcom: gcc: Make disp gpll0 branch aon for sc7180/sdm845
  (bnc#1012628).
- usb: core: fix quirks_param_set() writing to a const pointer
  (bnc#1012628).
- thermal: ti-soc-thermal: Fix reversed condition in
  ti_thermal_expose_sensor() (bnc#1012628).
- coresight: etmv4: Fix resource selector constant (bnc#1012628).
- coresight: etmv4: Counter values not saved on disable
  (bnc#1012628).
- coresight: tmc: Fix TMC mode read in tmc_read_unprepare_etb()
  (bnc#1012628).
- coresight: etm4x: Fix save/restore during cpu idle
  (bnc#1012628).
- powerpc/perf: Fix missing is_sier_aviable() during build
  (bnc#1012628).
- mt76: mt7663u: fix memory leak in set key (bnc#1012628).
- mt76: mt7663u: fix potential memory leak in mcu message handler
  (bnc#1012628).
- mt76: mt7615: fix potential memory leak in mcu message handler
  (bnc#1012628).
- mt76: mt7915: potential array overflow in
  mt7915_mcu_tx_rate_report() (bnc#1012628).
- mt76: mt7915: add missing CONFIG_MAC80211_DEBUGFS (bnc#1012628).
- mt76: mt7615: fix possible memory leak in
  mt7615_mcu_wtbl_sta_add (bnc#1012628).
- phy: armada-38x: fix NETA lockup when repeatedly switching
  speeds (bnc#1012628).
- s390/bpf: Fix sign extension in branch_ku (bnc#1012628).
- s390/bpf: Use brcl for jumping to exit_ip if necessary
  (bnc#1012628).
- s390/bpf: Tolerate not converging code shrinking (bnc#1012628).
- tools/bpftool: Fix error handing in do_skeleton() (bnc#1012628).
- ASoC: tas2770: Fix reset gpio property name (bnc#1012628).
- qed: Fix ILT and XRCD bitmap memory leaks (bnc#1012628).
- ASoC: hdac_hda: fix deadlock after PCM open error (bnc#1012628).
- powerpc/spufs: Fix the type of ret in spufs_arch_write_note
  (bnc#1012628).
- PCI: rcar: Fix runtime PM imbalance on error (bnc#1012628).
- MIPS: OCTEON: add missing put_device() call in
  dwc3_octeon_device_init() (bnc#1012628).
- thermal: int340x: processor_thermal: fix: update Jasper Lake
  PCI id (bnc#1012628).
- usb: dwc3: meson-g12a: fix shared reset control use
  (bnc#1012628).
- usb: dwc2: Fix error path in gadget registration (bnc#1012628).
- usb: gadget: f_uac2: fix AC Interface Header Descriptor
  wTotalLength (bnc#1012628).
- scsi: megaraid_sas: Clear affinity hint (bnc#1012628).
- scsi: mesh: Fix panic after host or bus reset (bnc#1012628).
- scsi: core: Add missing scsi_device_put() in scsi_host_block()
  (bnc#1012628).
- net: dsa: mv88e6xxx: MV88E6097 does not support jumbo
  configuration (bnc#1012628).
- bpf: Fix pos computation for bpf_iter seq_ops->start()
  (bnc#1012628).
- powerpc/watchpoint: Fix 512 byte boundary limit (bnc#1012628).
- powerpc/watchpoint: Fix DAWR exception constraint (bnc#1012628).
- powerpc/watchpoint: Fix DAWR exception for CACHEOP
  (bnc#1012628).
- macintosh/via-macii: Access autopoll_devs when inside lock
  (bnc#1012628).
- gpio: regmap: fix type clash (bnc#1012628).
- PCI: cadence: Fix cdns_pcie_{host|ep}_setup() error path
  (bnc#1012628).
- PCI: cadence: Fix updating Vendor ID and Subsystem Vendor ID
  register (bnc#1012628).
- RDMA/core: Fix return error value in _ib_modify_qp() to negative
  (bnc#1012628).
- Smack: fix another vsscanf out of bounds (bnc#1012628).
- Smack: prevent underflow in smk_set_cipso() (bnc#1012628).
- power: supply: check if calc_soc succeeded in
  pm860x_init_battery (bnc#1012628).
- Bluetooth: btusb: Fix and detect most of the Chinese Bluetooth
  controllers (bnc#1012628).
- Bluetooth: hci_h5: Set HCI_UART_RESET_ON_INIT to correct flags
  (bnc#1012628).
- Bluetooth: hci_serdev: Only unregister device if it was
  registered (bnc#1012628).
- bpf: Fix bpf_ringbuf_output() signature to return long
  (bnc#1012628).
- Bluetooth: Fix suspend notifier race (bnc#1012628).
- Bluetooth: hci_qca: Stop collecting memdump again for command
  timeout during SSR (bnc#1012628).
- net: dsa: rtl8366: Fix VLAN semantics (bnc#1012628).
- net: dsa: rtl8366: Fix VLAN set-up (bnc#1012628).
- xfs: fix inode allocation block res calculation precedence
  (bnc#1012628).
- xfs: clear XFS_DQ_FREEING if we can't lock the dquot buffer
  to flush (bnc#1012628).
- selftests/powerpc: Squash spurious errors due to device removal
  (bnc#1012628).
- powerpc/32s: Fix CONFIG_BOOK3S_601 uses (bnc#1012628).
- powerpc/boot: Fix CONFIG_PPC_MPC52XX references (bnc#1012628).
- selftests/powerpc: Fix CPU affinity for child process
  (bnc#1012628).
- nvmem: sprd: Fix return value of sprd_efuse_probe()
  (bnc#1012628).
- RDMA/rtrs-clt: add an additional random 8 seconds before
  reconnecting (bnc#1012628).
- RDMA/rtrs: remove WQ_MEM_RECLAIM for rtrs_wq (bnc#1012628).
- RDMA/netlink: Remove CAP_NET_RAW check when dump a raw QP
  (bnc#1012628).
- PCI: Release IVRS table in AMD ACS quirk (bnc#1012628).
- cpufreq: ap806: fix cpufreq driver needs ap cpu clk
  (bnc#1012628).
- powerpc/pseries/hotplug-cpu: Remove double free in error path
  (bnc#1012628).
- selftests/powerpc: Fix online CPU selection (bnc#1012628).
- RDMA/hns: Fix error during modify qp RTS2RTS (bnc#1012628).
- RDMA/hns: Fix the unneeded process when getting a general type
  of CQE error (bnc#1012628).
- ASoC: meson: axg-tdm-interface: fix link fmt setup
  (bnc#1012628).
- ASoC: meson: axg-tdmin: fix g12a skew (bnc#1012628).
- ASoC: meson: axg-tdm-formatters: fix sclk inversion
  (bnc#1012628).
- ASoC: soc-core: Fix regression causing sysfs entries to
  disappear (bnc#1012628).
- net: ll_temac: Use devm_platform_ioremap_resource_byname()
  (bnc#1012628).
- drm/msm/dpu: don't use INTF_INPUT_CTRL feature on sdm845
  (bnc#1012628).
- libbpf: Fix register in PT_REGS MIPS macros (bnc#1012628).
- MIPS: only register FTLBPar exception handler for supported
  models (bnc#1012628).
- ASoC: core: use less strict tests for dailink capabilities
  (bnc#1012628).
- ASoC: meson: cards: deal dpcm flag change (bnc#1012628).
- ASoC: fsl_sai: Fix value of FSL_SAI_CR1_RFW_MASK (bnc#1012628).
- s390/qeth: tolerate pre-filled RX buffer (bnc#1012628).
- s390/qeth: don't process empty bridge port events (bnc#1012628).
- ice: Clear and free XLT entries on reset (bnc#1012628).
- ice: Graceful error handling in HW table calloc failure
  (bnc#1012628).
- netfilter: nft_meta: fix iifgroup matching (bnc#1012628).
- rtw88: fix LDPC field for RA info (bnc#1012628).
- rtw88: fix short GI capability based on current bandwidth
  (bnc#1012628).
- rtw88: coex: only skip coex triggered by BT info (bnc#1012628).
- qtnfmac: Missing platform_device_unregister() on error in
  qtnf_core_mac_alloc() (bnc#1012628).
- wl1251: fix always return 0 error (bnc#1012628).
- tools, build: Propagate build failures from
  tools/build/Makefile.build (bnc#1012628).
- tools, bpftool: Fix wrong return value in do_dump()
  (bnc#1012628).
- net/mlx5: DR, Change push vlan action sequence (bnc#1012628).
- net/mlx5: Delete extra dump stack that gives nothing
  (bnc#1012628).
- ftrace: Fix ftrace_trace_task return value (bnc#1012628).
- net: mvpp2: fix memory leak in mvpp2_rx (bnc#1012628).
- net: ethernet: aquantia: Fix wrong return value (bnc#1012628).
- liquidio: Fix wrong return value in cn23xx_get_pf_num()
  (bnc#1012628).
- net: sgi: ioc3-eth: Fix the size used in some
  'dma_free_coherent()' calls (bnc#1012628).
- net: spider_net: Fix the size used in a 'dma_free_coherent()'
  call (bnc#1012628).
- fsl/fman: use 32-bit unsigned integer (bnc#1012628).
- fsl/fman: fix dereference null return value (bnc#1012628).
- fsl/fman: fix unreachable code (bnc#1012628).
- fsl/fman: check dereferencing null pointer (bnc#1012628).
- fsl/fman: fix eth hash table allocation (bnc#1012628).
- gpio: don't use same lockdep class for all
  devm_gpiochip_add_data users (bnc#1012628).
- net: thunderx: use spin_lock_bh in nicvf_set_rx_mode_task()
  (bnc#1012628).
- net: macb: Properly handle phylink on at91sam9x (bnc#1012628).
- dpaa2-eth: Fix passing zero to 'PTR_ERR' warning (bnc#1012628).
- hv_netvsc: do not use VF device if link is down (bnc#1012628).
- Revert "vxlan: fix tos value before xmit" (bnc#1012628).
- selftests/net: relax cpu affinity requirement in msg_zerocopy
  test (bnc#1012628).
- net: thunderx: initialize VF's mailbox mutex before first usage
  (bnc#1012628).
- media: mtk-mdp: Fix a refcounting bug on error in init
  (bnc#1012628).
- dlm: Fix kobject memleak (bnc#1012628).
- ocfs2: fix unbalanced locking (bnc#1012628).
- pinctrl-single: fix pcs_parse_pinconf() return value
  (bnc#1012628).
- mtd: rawnand: brcmnand: Don't default to edu transfer
  (bnc#1012628).
- svcrdma: Fix page leak in svc_rdma_recv_read_chunk()
  (bnc#1012628).
- nfsd: avoid a NULL dereference in __cld_pipe_upcall()
  (bnc#1012628).
- SUNRPC: Fix ("SUNRPC: Add "@len" parameter to gss_unwrap()")
  (bnc#1012628).
- x86/fsgsbase/64: Fix NULL deref in 86_fsgsbase_read_task
  (bnc#1012628).
- crypto: aesni - add compatibility with IAS (bnc#1012628).
- af_packet: TPACKET_V3: fix fill status rwlock imbalance
  (bnc#1012628).
- drivers/net/wan/lapbether: Added needed_headroom and a skb->len
  check (bnc#1012628).
- net: Fix potential memory leak in proto_register()
  (bnc#1012628).
- net/nfc/rawsock.c: add CAP_NET_RAW check (bnc#1012628).
- net: phy: fix memory leak in device-create error path
  (bnc#1012628).
- net: Set fput_needed iff FDPUT_FPUT is set (bnc#1012628).
- net/tls: Fix kmap usage (bnc#1012628).
- tcp: correct read of TFO keys on big endian systems
  (bnc#1012628).
- vmxnet3: use correct tcp hdr length when packet is encapsulated
  (bnc#1012628).
- net: refactor bind_bucket fastreuse into helper (bnc#1012628).
- net: initialize fastreuse on inet_inherit_port (bnc#1012628).
- vsock: fix potential null pointer dereference in vsock_poll()
  (bnc#1012628).
- net: phy: marvell10g: fix null pointer dereference
  (bnc#1012628).
- r8152: Use MAC address from correct device tree node
  (bnc#1012628).
- USB: serial: cp210x: re-enable auto-RTS on open (bnc#1012628).
- USB: serial: cp210x: enable usb generic throttle/unthrottle
  (bnc#1012628).
- usb: cdns3: gadget: always zeroed TRB buffer when enable
  endpoint (bnc#1012628).
- iommu/vt-d: Skip TE disabling on quirky gfx dedicated iommu
  (bnc#1012628).
- vdpasim: protect concurrent access to iommu iotlb (bnc#1012628).
- ALSA: hda - fix the micmute led status for Lenovo ThinkCentre
  AIO (bnc#1012628).
- ALSA: hda - reverse the setting value in the micmute_led_set
  (bnc#1012628).
- ALSA: usb-audio: Creative USB X-Fi Pro SB1095 volume knob
  support (bnc#1012628).
- ALSA: usb-audio: work around streaming quirk for MacroSilicon
  MS2109 (bnc#1012628).
- ALSA: usb-audio: add quirk for Pioneer DDJ-RB (bnc#1012628).
- tpm: Unify the mismatching TPM space buffer sizes (bnc#1012628).
- pstore: Fix linking when crypto API disabled (bnc#1012628).
- crypto: hisilicon - don't sleep of CRYPTO_TFM_REQ_MAY_SLEEP
  was not specified (bnc#1012628).
- crypto: qat - fix double free in qat_uclo_create_batch_init_list
  (bnc#1012628).
- crypto: ccp - Fix use of merged scatterlists (bnc#1012628).
- crypto: cpt - don't sleep of CRYPTO_TFM_REQ_MAY_SLEEP was not
  specified (bnc#1012628).
- tick/nohz: Narrow down noise while setting current task's tick
  dependency (bnc#1012628).
- bitfield.h: don't compile-time validate _val in FIELD_FIT
  (bnc#1012628).
- fs/minix: check return value of sb_getblk() (bnc#1012628).
- fs/minix: don't allow getting deleted inodes (bnc#1012628).
- fs/minix: reject too-large maximum file size (bnc#1012628).
- kvm: x86: replace kvm_spec_ctrl_test_value with runtime test
  on the host (bnc#1012628).
- 9p: Fix memory leak in v9fs_mount (bnc#1012628).
- driver core: Fix probe_count imbalance in really_probe()
  (bnc#1012628).
- media: media-request: Fix crash if memory allocation fails
  (bnc#1012628).
- drm/ttm/nouveau: don't call tt destroy callback on alloc failure
  (bnc#1012628).
- io_uring: set ctx sq/cq entry count earlier (bnc#1012628).
- io_uring: use TWA_SIGNAL for task_work uncondtionally
  (bnc#1012628).
- io_uring: fail poll arm on queue proc failure (bnc#1012628).
- io_uring: sanitize double poll handling (bnc#1012628).
- NFS: Don't move layouts to plh_return_segs list while in use
  (bnc#1012628).
- NFS: Don't return layout segments that are in use (bnc#1012628).
- cpufreq: Fix locking issues with governors (bnc#1012628).
- cpufreq: dt: fix oops on armada37xx (bnc#1012628).
- MIPS: VZ: Only include loongson_regs.h for CPU_LOONGSON64
  (bnc#1012628).
- include/asm-generic/vmlinux.lds.h: align ro_after_init
  (bnc#1012628).
- PM / devfreq: rk3399_dmc: Fix kernel oops when rockchip,pmu
  is absent (bnc#1012628).
- PM / devfreq: Fix indentaion of devfreq_summary debugfs node
  (bnc#1012628).
- spi: spidev: Align buffers for DMA (bnc#1012628).
- mtd: rawnand: qcom: avoid write to unavailable register
  (bnc#1012628).
- mtd: spi-nor: intel-spi: Simulate WRDI command (bnc#1012628).
- erofs: fix extended inode could cross boundary (bnc#1012628).
- Revert "mm/vmstat.c: do not show lowmem reserve protection
  information of empty zone" (bnc#1012628).
- Revert "parisc: Improve interrupt handling in
  arch_spin_lock_flags()" (bnc#1012628).
- Revert "parisc: Drop LDCW barrier in CAS code when running UP"
  (bnc#1012628).
- Revert "parisc: Use ldcw instruction for SMP spinlock release
  barrier" (bnc#1012628).
- Revert "parisc: Revert "Release spinlocks using ordered store""
  (bnc#1012628).
- parisc: Do not use an ordered store in pa_tlb_lock()
  (bnc#1012628).
- parisc: Implement __smp_store_release and __smp_load_acquire
  barriers (bnc#1012628).
- parisc: mask out enable and reserved bits from sba imask
  (bnc#1012628).
- ARM: dts: exynos: Extend all Exynos5800 A15's OPPs with max
  voltage data (bnc#1012628).
- ARM: 8992/1: Fix unwind_frame for clang-built kernels
  (bnc#1012628).
- firmware: qcom_scm: Fix legacy convention SCM accessors
  (bnc#1012628).
- irqdomain/treewide: Free firmware node after domain removal
  (bnc#1012628).
- firmware_loader: EFI firmware loader must handle pre-allocated
  buffer (bnc#1012628).
- xen/balloon: fix accounting in alloc_xenballooned_pages error
  path (bnc#1012628).
- xen/balloon: make the balloon wait interruptible (bnc#1012628).
- xen/gntdev: Fix dmabuf import with non-zero sgt offset
  (bnc#1012628).
- drm/xen-front: Fix misused IS_ERR_OR_NULL checks (bnc#1012628).
- s390/dasd: fix inability to use DASD with DIAG driver
  (bnc#1012628).
- s390/numa: set node distance to LOCAL_DISTANCE (bnc#1012628).
- s390/gmap: improve THP splitting (bnc#1012628).
- io_uring: Fix NULL pointer dereference in loop_rw_iter()
  (bnc#1012628).
- io_uring: hold 'ctx' reference around task_work queue + execute
  (bnc#1012628).
- io_uring: add missing REQ_F_COMP_LOCKED for nested requests
  (bnc#1012628).
- io_uring: enable lookup of links holding inflight files
  (bnc#1012628).
- task_work: only grab task signal lock when needed (bnc#1012628).
- Update config files (ARMADA_AP_CPU_CLK autoselected).
- commit e2a4265
* Wed Aug 19 2020 tiwai@suse.de
- squashfs: avoid bio_alloc() failure with 1Mbyte blocks
  (bsc#1175308).
- commit 8f3c2bf
* Tue Aug 18 2020 mkubecek@suse.cz
- config: restore PHYLIB=m in */vanilla
  As the PHYLIB/ETHTOOL_NETLINK dependency fix is now in 5.9-rc1 tarball,
  we can apply the changes from commit 4756d9edf730 ("config: restore
  PHYLIB=m") also to vanilla configs.
- commit 4d4447f
* Tue Aug 18 2020 mkubecek@suse.cz
- Update to 5.9-rc1
- eliminated 50 patches (39 stable, 11 other)
- disable ARM architectures (need config update)
- disable (needs update)
  - patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch
- refresh
  - patches.rpmify/Add-ksym-provides-tool.patch
  - patches.suse/acpi_thermal_passive_blacklist.patch
  - patches.suse/add-product-identifying-information-to-vmcoreinfo.patch
  - patches.suse/apparmor-compatibility-with-v2.x-net.patch
  - patches.suse/b43-missing-firmware-info.patch
  - patches.suse/dm-mpath-no-partitions-feature
  - patches.suse/vfs-add-super_operations-get_inode_dev
- new config options:
  - General setup
  - KERNEL_ZSTD=n
  - RD_ZSTD=y
  - File systems
  - FS_ENCRYPTION_INLINE_CRYPT=y
  - TMPFS_INODE64=y
  - Kernel hacking
  - DEBUG_FORCE_FUNCTION_ALIGN_32B=n
  - DEBUG_FS_ALLOW_ALL=y
  - DEBUG_FS_DISALLOW_MOUNT=n
  - DEBUG_FS_ALLOW_NONE=n
  - RCU_REF_SCALE_TEST=n
  - TEST_FPU=n
  - PCI support
  - PCI_J721E_HOST=n
  - PCI_J721E_EP=n
  - Storage
  - NVME_TARGET_PASSTHRU=n
  - SCSI_UFS_CRYPTO=y
  - BCACHE_ASYNC_REGISTRATION=y
  - Network device support
  - MLX5_IPSEC=y
  - MT7663S=m
  - WLAN_VENDOR_MICROCHIP=y
  - RTW88_8821CE=m
  - Character devices
  - HW_RANDOM_BA431=m
  - SERIAL_IMX_EARLYCON=n
  - Power management
  - CHARGER_BQ2515X=m
  - SENSORS_CORSAIR_CPRO=m
  - THERMAL_NETLINK=y
  - REGULATOR_PCA9450=m
  - REGULATOR_QCOM_USB_VBUS=m
  - REGULATOR_QCOM_LABIBB=m
  - REGULATOR_FAN53880=m
  - REGULATOR_SY8827N=m
  - Multimedia support
  - VIDEO_RDACM20=m
  - VIDEO_DW9768=m
  - VIDEO_MAX9286=m
  - Graphics support
  - DRM_AMD_DC_DCN3_0=y
  - NOUVEAU_DEBUG_PUSH=n
  - DRM_PANEL_SITRONIX_ST7703=n
  - Sound card support
  - SND_HDA_INTEL_HDMI_SILENT_STREAM=y
  - SND_SOC_MAX98373_SDW=m
  - USB support
  - USB_OTG_PRODUCTLIST=n
  - USB_OTG_DISABLE_EXTERNAL_HUB=n
  - X86 Platform Specific Device Drivers
  - INTEL_ATOMISP2_LED=m
  - Industrial I/O support
  - SCD30_CORE=n
  - INV_ICM42600_I2C=n
  - INV_ICM42600_SPI=n
  - Misc drivers
  - SPI_LANTIQ_SSC=n
  - PINCTRL_EMMITSBURG=m
  - GPIO_PCA9570=m
  - IR_TOY=m
  - CEC_CH7322=m
  - LEDS_CLASS_MULTICOLOR=m
  - XILINX_ZYNQMP_DPDMA=m
  - MLX5_VDPA=n
  - CLK_HSDK=n
  - i386
  - REGULATOR_CROS_EC=m
  - ppc
  - PPC_QUEUED_SPINLOCKS=y
  - s390x
  - BPF_KPROBE_OVERRIDE=n
  - FAIL_FUNCTION=n
  - riscv64
  - NO_HZ_IDLE=y
  - VIRT_CPU_ACCOUNTING_GEN=y
  - JUMP_LABEL=y
  - STATIC_KEYS_SELFTEST=n
  - STACKPROTECTOR=y
  - STACKPROTECTOR_STRONG=y
  - SND_SOC_MAX98373_I2C=m
  - DEBUG_KMEMLEAK=n
  - DEBUG_VM_PGTABLE=n
  - PROVE_LOCKING=n
  - LOCK_STAT=n
  - DEBUG_WW_MUTEX_SLOWPATH=n
  - DEBUG_LOCK_ALLOC=n
  - KCOV=n
  - CONTEXT_TRACKING_FORCE=n
- commit 6a30651
* Mon Aug 17 2020 tiwai@suse.de
- firmware_loader: fix memory leak for paged buffer (bsc#1175367).
- commit 996bcd6
* Fri Aug 14 2020 jslaby@suse.cz
- r8169: add support for RTL8125B (bsc#1174875).
- r8169: rename RTL8125 to RTL8125A (bsc#1174875).
- commit d6761b2
* Wed Aug 12 2020 duwe@suse.de
- rpm/modules.fips:
  * add ecdh_generic (boo#1173813)
- commit 42f38df
* Wed Aug 12 2020 jslaby@suse.cz
- Update config files (bsc#1174058).
  Enable GENERIC_IRQ_DEBUGFS.
  This (automatically) sets GENERIC_IRQ_INJECTION=y on some platforms and
  aligns them with x86.
- commit 7e5ee01
* Wed Aug 12 2020 jslaby@suse.cz
- Linux 5.8.1 (bnc#1012628).
- scsi: ufs: Fix and simplify setup_xfer_req variant operation
  (bnc#1012628).
- USB: serial: qcserial: add EM7305 QDL product ID (bnc#1012628).
- USB: iowarrior: fix up report size handling for some devices
  (bnc#1012628).
- usb: xhci: define IDs for various ASMedia host controllers
  (bnc#1012628).
- usb: xhci: Fix ASMedia ASM1142 DMA addressing (bnc#1012628).
- Revert "ALSA: hda: call runtime_allow() for all hda controllers"
  (bnc#1012628).
- ALSA: hda/realtek: Add alc269/alc662 pin-tables for Loongson-3
  laptops (bnc#1012628).
- ALSA: hda/ca0132 - Add new quirk ID for Recon3D (bnc#1012628).
- ALSA: hda/ca0132 - Fix ZxR Headphone gain control get value
  (bnc#1012628).
- ALSA: hda/ca0132 - Fix AE-5 microphone selection commands
  (bnc#1012628).
- ALSA: seq: oss: Serialize ioctls (bnc#1012628).
- staging: android: ashmem: Fix lockdep warning for write
  operation (bnc#1012628).
- staging: rtl8712: handle firmware load failure (bnc#1012628).
- Staging: rtl8188eu: rtw_mlme: Fix uninitialized variable
  authmode (bnc#1012628).
- Bluetooth: Fix slab-out-of-bounds read in
  hci_extended_inquiry_result_evt() (bnc#1012628).
- Bluetooth: Prevent out-of-bounds read in
  hci_inquiry_result_evt() (bnc#1012628).
- Bluetooth: Prevent out-of-bounds read in
  hci_inquiry_result_with_rssi_evt() (bnc#1012628).
- omapfb: dss: Fix max fclk divider for omap36xx (bnc#1012628).
- binder: Prevent context manager from incrementing ref 0
  (bnc#1012628).
- Smack: fix use-after-free in smk_write_relabel_self()
  (bnc#1012628).
- scripts: add dummy report mode to add_namespace.cocci
  (bnc#1012628).
- lkdtm/heap: Avoid edge and middle of slabs (bnc#1012628).
- mtd: properly check all write ioctls for permissions
  (bnc#1012628).
- leds: wm831x-status: fix use-after-free on unbind (bnc#1012628).
- leds: lm36274: fix use-after-free on unbind (bnc#1012628).
- leds: da903x: fix use-after-free on unbind (bnc#1012628).
- leds: lm3533: fix use-after-free on unbind (bnc#1012628).
- leds: 88pm860x: fix use-after-free on unbind (bnc#1012628).
- gpio: max77620: Fix missing release of interrupt (bnc#1012628).
- xattr: break delegations in {set,remove}xattr (bnc#1012628).
- Revert "powerpc/kasan: Fix shadow pages allocation failure"
  (bnc#1012628).
- powerpc/kasan: Fix shadow pages allocation failure
  (bnc#1012628).
- PCI: tegra: Revert tegra124 raw_violation_fixup (bnc#1012628).
- ima: move APPRAISE_BOOTPARAM dependency on ARCH_POLICY to
  runtime (bnc#1012628).
- random32: move the pseudo-random 32-bit definitions to prandom.h
  (bnc#1012628).
- random: random.h should include archrandom.h, not the other
  way around (bnc#1012628).
- arm64: kaslr: Use standard early random function (bnc#1012628).
- commit 7303946
* Mon Aug 10 2020 tiwai@suse.de
- ALSA: usb-audio: fix overeager device match for MacroSilicon
  MS2109 (bsc#1174625).
- commit e0b3a44
* Sun Aug  9 2020 mkubecek@suse.cz
- config: refresh
- only headers update (gcc 10.1.1 -> 10.2.1)
- commit 2efb7ba
* Tue Aug  4 2020 nsaenzjulienne@suse.de
- clk: bcm2835: Do not use prediv with bcm2711's PLLs
  (bsc#1174865).
- commit bb9b402
* Mon Aug  3 2020 afaerber@suse.com
- config: armv7hl: Update to 5.8
- commit ede84e7
* Mon Aug  3 2020 afaerber@suse.com
- config: armv6hl: Update to 5.8
- commit ecdaa95
* Mon Aug  3 2020 schwab@suse.de
- config: refresh riscv64/default
- commit d1aeef8
* Mon Aug  3 2020 jslaby@suse.cz
- Fix for missing check in vgacon scrollback handling (bsc#1174205
  CVE-2020-14331).
  Update to the latest findings/submission.
- commit e91a540
* Mon Aug  3 2020 mkubecek@suse.cz
- Update to 5.8 final
- refresh configs (headers only)
- commit c02ba5f
* Sat Aug  1 2020 jslaby@suse.cz
- Linux 5.7.12 (bnc#1012628).
- regmap: debugfs: check count when read regmap file
  (bnc#1012628).
- io_uring: ensure double poll additions work with both request
  types (bnc#1012628).
- tipc: allow to build NACK message in link timeout function
  (bnc#1012628).
- udp: Improve load balancing for SO_REUSEPORT (bnc#1012628).
- udp: Copy has_conns in reuseport_grow() (bnc#1012628).
- sctp: shrink stream outq when fails to do addstream reconf
  (bnc#1012628).
- sctp: shrink stream outq only when new outcnt < old outcnt
  (bnc#1012628).
- AX.25: Prevent integer overflows in connect and sendmsg
  (bnc#1012628).
- tcp: allow at most one TLP probe per flight (bnc#1012628).
- rxrpc: Fix sendmsg() returning EPIPE due to recvmsg() returning
  ENODATA (bnc#1012628).
- rtnetlink: Fix memory(net_device) leak when ->newlink fails
  (bnc#1012628).
- qrtr: orphan socket in qrtr_release() (bnc#1012628).
- net: udp: Fix wrong clean up for IS_UDPLITE macro (bnc#1012628).
- net-sysfs: add a newline when printing 'tx_timeout' by sysfs
  (bnc#1012628).
- net/sched: act_ct: fix restore the qdisc_skb_cb after defrag
  (bnc#1012628).
- ip6_gre: fix null-ptr-deref in ip6gre_init_net() (bnc#1012628).
- drivers/net/wan/x25_asy: Fix to make it work (bnc#1012628).
- dev: Defer free of skbs in flush_backlog (bnc#1012628).
- AX.25: Prevent out-of-bounds read in ax25_sendmsg()
  (bnc#1012628).
- AX.25: Fix out-of-bounds read in ax25_connect() (bnc#1012628).
- commit 9c98feb
* Wed Jul 29 2020 jslaby@suse.cz
- Refresh
  patches.suse/vgacon-fix-out-of-bounds-write-to-the-scrollback-buf.patch.
  Update according to the latest findings.
- commit 5015994
* Wed Jul 29 2020 jslaby@suse.cz
- Linux 5.7.11 (bnc#1012628).
- gpio: arizona: handle pm_runtime_get_sync failure case
  (bnc#1012628).
- gpio: arizona: put pm_runtime in case of failure (bnc#1012628).
- pinctrl: amd: fix npins for uart0 in kerncz_groups
  (bnc#1012628).
- bpf: Set the number of exception entries properly for
  subprograms (bnc#1012628).
- mac80211: allow rx of mesh eapol frames with default rx key
  (bnc#1012628).
- scsi: scsi_transport_spi: Fix function pointer check
  (bnc#1012628).
- xtensa: fix __sync_fetch_and_{and,or}_4 declarations
  (bnc#1012628).
- xtensa: update *pos in cpuinfo_op.next (bnc#1012628).
- scsi: mpt3sas: Fix unlock imbalance (bnc#1012628).
- drivers/net/wan/lapbether: Fixed the value of hard_header_len
  (bnc#1012628).
- ALSA: hda/hdmi: fix failures at PCM open on Intel ICL and later
  (bnc#1012628).
- net: sky2: initialize return of gm_phy_read (bnc#1012628).
- drm/nouveau/i2c/g94-: increase NV_PMGR_DP_AUXCTL_TRANSACTREQ
  timeout (bnc#1012628).
- scsi: mpt3sas: Fix error returns in BRM_status_show
  (bnc#1012628).
- scsi: dh: Add Fujitsu device to devinfo and dh lists
  (bnc#1012628).
- dm: use bio_uninit instead of bio_disassociate_blkg
  (bnc#1012628).
- drivers/firmware/psci: Fix memory leakage in
  alloc_init_cpu_groups() (bnc#1012628).
- fuse: fix weird page warning (bnc#1012628).
- irqdomain/treewide: Keep firmware node unconditionally allocated
  (bnc#1012628).
- drm/nouveau/nouveau: fix page fault on device private memory
  (bnc#1012628).
- drm/amd/display: Check DMCU Exists Before Loading (bnc#1012628).
- drm/amd/display: add dmcub check on RENOIR (bnc#1012628).
- SUNRPC reverting d03727b248d0 ("NFSv4 fix CLOSE not waiting
  for direct IO compeletion") (bnc#1012628).
- exfat: fix overflow issue in exfat_cluster_to_sector()
  (bnc#1012628).
- exfat: fix wrong hint_stat initialization in
  exfat_find_dir_entry() (bnc#1012628).
- exfat: fix wrong size update of stream entry by typo
  (bnc#1012628).
- exfat: fix name_hash computation on big endian systems
  (bnc#1012628).
- btrfs: reloc: clear DEAD_RELOC_TREE bit for orphan roots to
  prevent runaway balance (bnc#1012628).
- uprobes: Change handle_swbp() to send SIGTRAP with
  si_code=SI_KERNEL, to fix GDB regression (bnc#1012628).
- ALSA: hda/realtek: Fixed ALC298 sound bug by adding quirk for
  Samsung Notebook Pen S (bnc#1012628).
- ALSA: info: Drop WARN_ON() from buffer NULL sanity check
  (bnc#1012628).
- ASoC: rt5670: Correct RT5670_LDO_SEL_MASK (bnc#1012628).
- ASoC: Intel: cht_bsw_rt5672: Change bus format to I2S 2 channel
  (bnc#1012628).
- s390/cpum_cf,perf: change DFLT_CCERROR counter name
  (bnc#1012628).
- btrfs: fix double free on ulist after backref resolution failure
  (bnc#1012628).
- btrfs: fix mount failure caused by race with umount
  (bnc#1012628).
- btrfs: fix page leaks after failure to lock page for delalloc
  (bnc#1012628).
- mt76: mt76x02: fix handling MCU timeouts during hw restart
  (bnc#1012628).
- efi/efivars: Expose RT service availability via efivars
  abstraction (bnc#1012628).
- bnxt_en: Fix race when modifying pause settings (bnc#1012628).
- bnxt_en: Init ethtool link settings after reading updated PHY
  configuration (bnc#1012628).
- bnxt_en: Fix completion ring sizing with TPA enabled
  (bnc#1012628).
- fpga: dfl: pci: reduce the scope of variable 'ret'
  (bnc#1012628).
- fpga: dfl: fix bug in port reset handshake (bnc#1012628).
- hippi: Fix a size used in a 'pci_free_consistent()' in an
  error handling path (bnc#1012628).
- netfilter: nf_tables: fix nat hook table deletion (bnc#1012628).
- dpaa2-eth: check fsl_mc_get_endpoint for IS_ERR_OR_NULL()
  (bnc#1012628).
- vsock/virtio: annotate 'the_virtio_vsock' RCU pointer
  (bnc#1012628).
- ax88172a: fix ax88172a_unbind() failures (bnc#1012628).
- RDMA/mlx5: Use xa_lock_irq when access to SRQ table
  (bnc#1012628).
- RDMA/core: Fix race in rdma_alloc_commit_uobject()
  (bnc#1012628).
- RDMA/cm: Protect access to remote_sidr_table (bnc#1012628).
- net: fec: fix hardware time stamping by external devices
  (bnc#1012628).
- ASoC: Intel: bytcht_es8316: Add missed put_device()
  (bnc#1012628).
- net: dp83640: fix SIOCSHWTSTAMP to update the struct with
  actual configuration (bnc#1012628).
- ieee802154: fix one possible memleak in adf7242_probe
  (bnc#1012628).
- drm: sun4i: hdmi: Fix inverted HPD result (bnc#1012628).
- net: smc91x: Fix possible memory leak in smc_drv_probe()
  (bnc#1012628).
- mlxsw: core: Fix wrong SFP EEPROM reading for upper pages 1-3
  (bnc#1012628).
- net: dsa: mv88e6xxx: fix in-band AN link establishment
  (bnc#1012628).
- arm64: dts: clearfog-gt-8k: fix switch link configuration
  (bnc#1012628).
- bonding: check error value of register_netdevice() immediately
  (bnc#1012628).
- iwlwifi: Make some Killer Wireless-AC 1550 cards work again
  (bnc#1012628).
- net: bcmgenet: fix error returns in bcmgenet_probe()
  (bnc#1012628).
- dpaa_eth: Fix one possible memleak in dpaa_eth_probe
  (bnc#1012628).
- mlxsw: destroy workqueue when trap_register in mlxsw_emad_init
  (bnc#1012628).
- ionic: use offset for ethtool regs data (bnc#1012628).
- ionic: fix up filter locks and debug msgs (bnc#1012628).
- ionic: update filter id after replay (bnc#1012628).
- ionic: keep rss hash after fw update (bnc#1012628).
- ionic: use mutex to protect queue operations (bnc#1012628).
- crypto/chtls: fix tls alert messages corrupted by tls data
  (bnc#1012628).
- net: ag71xx: add missed clk_disable_unprepare in error path
  of probe (bnc#1012628).
- RDMA/mlx5: Prevent prefetch from racing with implicit
  destruction (bnc#1012628).
- net: hns3: fix for not calculating TX BD send size correctly
  (bnc#1012628).
- net: hns3: fix error handling for desc filling (bnc#1012628).
- net: hns3: fix return value error when query MAC link status
  fail (bnc#1012628).
- net: dsa: microchip: call phy_remove_link_mode during probe
  (bnc#1012628).
- netdevsim: fix unbalaced locking in nsim_create() (bnc#1012628).
- qed: suppress "don't support RoCE & iWARP" flooding on HW init
  (bnc#1012628).
- qed: suppress false-positives interrupt error messages on HW
  init (bnc#1012628).
- ipvs: fix the connection sync failed in some cases
  (bnc#1012628).
- net: ethernet: ave: Fix error returns in ave_init (bnc#1012628).
- iommu/qcom: Use domain rather than dev as tlb cookie
  (bnc#1012628).
- Revert "PCI/PM: Assume ports without DLL Link Active train
  links in 100 ms" (bnc#1012628).
- nfsd4: fix NULL dereference in nfsd/clients display code
  (bnc#1012628).
- enetc: Remove the mdio bus on PF probe bailout (bnc#1012628).
- i2c: rcar: always clear ICSAR to avoid side effects
  (bnc#1012628).
- i2c: i2c-qcom-geni: Fix DMA transfer race (bnc#1012628).
- bonding: check return value of register_netdevice() in
  bond_newlink() (bnc#1012628).
- geneve: fix an uninitialized value in geneve_changelink()
  (bnc#1012628).
- serial: exar: Fix GPIO configuration for Sealevel cards based
  on XR17V35X (bnc#1012628).
- scripts/decode_stacktrace: strip basepath from all paths
  (bnc#1012628).
- scripts/gdb: fix lx-symbols 'gdb.error' while loading modules
  (bnc#1012628).
- RISC-V: Do not rely on initrd_start/end computed during early
  dt parsing (bnc#1012628).
- kbuild: fix single target builds for external modules
  (bnc#1012628).
- HID: i2c-hid: add Mediacom FlexBook edge13 to descriptor
  override (bnc#1012628).
- HID: alps: support devices with report id 2 (bnc#1012628).
- dmaengine: ti: k3-udma: Fix cleanup code for
  alloc_chan_resources (bnc#1012628).
- dmaengine: ti: k3-udma: Fix the running channel handling in
  alloc_chan_resources (bnc#1012628).
- HID: steam: fixes race in handling device list (bnc#1012628).
- dmaengine: ti: k3-udma: add missing put_device() call in
  of_xudma_dev_get() (bnc#1012628).
- dmaengine: idxd: fix hw descriptor fields for delta record
  (bnc#1012628).
- HID: apple: Disable Fn-key key-re-mapping on clone keyboards
  (bnc#1012628).
- dmaengine: tegra210-adma: Fix runtime PM imbalance on error
  (bnc#1012628).
- soc: amlogic: meson-gx-socinfo: Fix S905X3 and S905D3 ID's
  (bnc#1012628).
- Input: add `SW_MACHINE_COVER` (bnc#1012628).
- ARM: dts: n900: remove mmc1 card detect gpio (bnc#1012628).
- spi: mediatek: use correct SPI_CFG2_REG MACRO (bnc#1012628).
- regmap: dev_get_regmap_match(): fix string comparison
  (bnc#1012628).
- hwmon: (aspeed-pwm-tacho) Avoid possible buffer overflow
  (bnc#1012628).
- dmaengine: fsl-edma: fix wrong tcd endianness for big-endian
  cpu (bnc#1012628).
- dmaengine: ioat setting ioat timeout as module parameter
  (bnc#1012628).
- Input: synaptics - enable InterTouch for ThinkPad X1E 1st gen
  (bnc#1012628).
- Input: elan_i2c - only increment wakeup count on touch
  (bnc#1012628).
- usb: dwc3: pci: add support for the Intel Tiger Lake PCH -H
  variant (bnc#1012628).
- usb: dwc3: pci: add support for the Intel Jasper Lake
  (bnc#1012628).
- usb: gadget: udc: gr_udc: fix memleak on error handling path
  in gr_ep_init() (bnc#1012628).
- usb: cdns3: ep0: fix some endian issues (bnc#1012628).
- usb: cdns3: trace: fix some endian issues (bnc#1012628).
- hwmon: (adm1275) Make sure we are reading enough data for
  different chips (bnc#1012628).
- drm/amdgpu/gfx10: fix race condition for kiq (bnc#1012628).
- drm/amdgpu: fix preemption unit test (bnc#1012628).
- hwmon: (nct6775) Accept PECI Calibration as temperature source
  for NCT6798D (bnc#1012628).
- platform/x86: ISST: Add new PCI device ids (bnc#1012628).
- platform/x86: asus-wmi: allow BAT1 battery name (bnc#1012628).
- hwmon: (scmi) Fix potential buffer overflow in
  scmi_hwmon_probe() (bnc#1012628).
- ALSA: hda/realtek - fixup for yet another Intel reference board
  (bnc#1012628).
- drivers/perf: Fix kernel panic when rmmod PMU modules during
  perf sampling (bnc#1012628).
- arm64: Use test_tsk_thread_flag() for checking TIF_SINGLESTEP
  (bnc#1012628).
- x86: math-emu: Fix up 'cmp' insn for clang ias (bnc#1012628).
- asm-generic/mmiowb: Allow mmiowb_set_pending() when
  preemptible() (bnc#1012628).
- drivers/perf: Prevent forced unbinding of PMU drivers
  (bnc#1012628).
- RISC-V: Upgrade smp_mb__after_spinlock() to iorw,iorw
  (bnc#1012628).
- x86/boot: Don't add the EFI stub to targets (bnc#1012628).
- binder: Don't use mmput() from shrinker function (bnc#1012628).
- usb: xhci-mtk: fix the failure of bandwidth allocation
  (bnc#1012628).
- usb: tegra: Fix allocation for the FPCI context (bnc#1012628).
- usb: xhci: Fix ASM2142/ASM3142 DMA addressing (bnc#1012628).
- Revert "cifs: Fix the target file was deleted when rename
  failed." (bnc#1012628).
- iwlwifi: mvm: don't call iwl_mvm_free_inactive_queue() under
  RCU (bnc#1012628).
- tty: xilinx_uartps: Really fix id assignment (bnc#1012628).
- staging: wlan-ng: properly check endpoint types (bnc#1012628).
- staging: comedi: addi_apci_1032: check INSN_CONFIG_DIGITAL_TRIG
  shift (bnc#1012628).
- staging: comedi: ni_6527: fix INSN_CONFIG_DIGITAL_TRIG support
  (bnc#1012628).
- staging: comedi: addi_apci_1500: check INSN_CONFIG_DIGITAL_TRIG
  shift (bnc#1012628).
- staging: comedi: addi_apci_1564: check INSN_CONFIG_DIGITAL_TRIG
  shift (bnc#1012628).
- serial: tegra: fix CREAD handling for PIO (bnc#1012628).
- serial: 8250: fix null-ptr-deref in serial8250_start_tx()
  (bnc#1012628).
- serial: 8250_mtk: Fix high-speed baud rates clamping
  (bnc#1012628).
- interconnect: msm8916: Fix buswidth of pcnoc_s nodes
  (bnc#1012628).
- /dev/mem: Add missing memory barriers for devmem_inode
  (bnc#1012628).
- fbdev: Detect integer underflow at "struct
  fbcon_ops"->clear_margins (bnc#1012628).
- vt: Reject zero-sized screen buffer size (bnc#1012628).
- Makefile: Fix GCC_TOOLCHAIN_DIR prefix for Clang cross
  compilation (bnc#1012628).
- mm/mmap.c: close race between munmap() and
  expand_upwards()/downwards() (bnc#1012628).
- vfs/xattr: mm/shmem: kernfs: release simple xattr entry in a
  right way (bnc#1012628).
- mm/memcg: fix refcount error while moving and swapping
  (bnc#1012628).
- mm: memcg/slab: fix memory leak at non-root kmem_cache destroy
  (bnc#1012628).
- mm/hugetlb: avoid hardcoding while checking if cma is enabled
  (bnc#1012628).
- khugepaged: fix null-pointer dereference due to race
  (bnc#1012628).
- io-mapping: indicate mapping failure (bnc#1012628).
- mmc: sdhci-of-aspeed: Fix clock divider calculation
  (bnc#1012628).
- drm/amdgpu: Fix NULL dereference in dpm sysfs handlers
  (bnc#1012628).
- drm/amd/powerplay: fix a crash when overclocking Vega M
  (bnc#1012628).
- arm64: vdso32: Fix '--prefix=' value for newer versions of clang
  (bnc#1012628).
- parisc: Add atomic64_set_release() define to avoid CPU soft
  lockups (bnc#1012628).
- x86, vmlinux.lds: Page-align end of ..page_aligned sections
  (bnc#1012628).
- ASoC: rt5670: Add new gpio1_is_ext_spk_en quirk and enable it
  on the Lenovo Miix 2 10 (bnc#1012628).
- ASoC: qcom: Drop HAS_DMA dependency to fix link failure
  (bnc#1012628).
- ASoC: topology: fix kernel oops on route addition error
  (bnc#1012628).
- ASoC: topology: fix tlvs in error handling for widget_dmixer
  (bnc#1012628).
- ASoC: Intel: bdw-rt5677: fix non BE conversion (bnc#1012628).
- dm integrity: fix integrity recalculation that is improperly
  skipped (bnc#1012628).
- ath9k: Fix general protection fault in ath9k_hif_usb_rx_cb
  (bnc#1012628).
- ath9k: Fix regression with Atheros 9271 (bnc#1012628).
- Refresh
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch.
- commit 6157a8d
* Tue Jul 28 2020 acho@suse.com
- Bluetooth: Disconnect if E0 is used for Level 4 (bsc#1171988
  CVE-2020-10135).
- commit 86181ec
* Tue Jul 28 2020 acho@suse.com
- Bluetooth: Disconnect if E0 is used for Level 4 (bsc#1171988
  CVE-2020-10135).
- Bluetooth: Consolidate encryption handling in hci_encrypt_cfm
  (bsc#1171988 CVE-2020-10135).
- commit d1148b9
* Tue Jul 28 2020 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: Enable overlayfs
  Overlayfs is needed for podman or docker builds when no more specific
  driver can be used (like lvm or btrfs). As the default build fs is ext4
  currently, we need overlayfs kernel modules to be available.
- commit 29474aa
* Tue Jul 28 2020 jslaby@suse.cz
- vgacon: fix out of bounds write to the scrollback buffer
  (bsc#1174205 CVE-2020-14331).
- commit 62bfb93
* Mon Jul 27 2020 mkubecek@suse.cz
- Update to 5.8-rc7
- eliminated 2 patches
- commit 786d3ff
* Wed Jul 22 2020 jslaby@suse.cz
- soc: qcom: rpmh: Dirt can only make you dirtier, not cleaner
  (git-fixes).
- commit 6a1b5cf
* Wed Jul 22 2020 jslaby@suse.cz
- Linux 5.7.10 (bnc#1012628).
- bridge: mcast: Fix MLD2 Report IPv6 payload length check
  (bnc#1012628).
- genetlink: remove genl_bind (bnc#1012628).
- ipv4: fill fl4_icmp_{type,code} in ping_v4_sendmsg
  (bnc#1012628).
- ipv6: fib6_select_path can not use out path for nexthop objects
  (bnc#1012628).
- ipv6: Fix use of anycast address with loopback (bnc#1012628).
- l2tp: remove skb_dst_set() from l2tp_xmit_skb() (bnc#1012628).
- llc: make sure applications use ARPHRD_ETHER (bnc#1012628).
- net: Added pointer check for dst->ops->neigh_lookup in
  dst_neigh_lookup_skb (bnc#1012628).
- net: dsa: microchip: set the correct number of ports
  (bnc#1012628).
- net: qrtr: free flow in __qrtr_node_release (bnc#1012628).
- net_sched: fix a memory leak in atm_tc_init() (bnc#1012628).
- net: usb: qmi_wwan: add support for Quectel EG95 LTE modem
  (bnc#1012628).
- sched: consistently handle layer3 header accesses in the
  presence of VLANs (bnc#1012628).
- tcp: fix SO_RCVLOWAT possible hangs under high mem pressure
  (bnc#1012628).
- tcp: make sure listeners don't initialize congestion-control
  state (bnc#1012628).
- tcp: md5: add missing memory barriers in
  tcp_md5_do_add()/tcp_md5_hash_key() (bnc#1012628).
- tcp: md5: do not send silly options in SYNCOOKIES (bnc#1012628).
- vlan: consolidate VLAN parsing code and limit max parsing depth
  (bnc#1012628).
- tcp: md5: refine tcp_md5_do_add()/tcp_md5_hash_key() barriers
  (bnc#1012628).
- tcp: md5: allow changing MD5 keys in all socket states
  (bnc#1012628).
- cgroup: fix cgroup_sk_alloc() for sk_clone_lock() (bnc#1012628).
- cgroup: Fix sock_cgroup_data on big-endian (bnc#1012628).
- net: ipa: always check for stopped channel (bnc#1012628).
- net: ipa: introduce ipa_cmd_tag_process() (bnc#1012628).
- ip: Fix SO_MARK in RST, ACK and ICMP packets (bnc#1012628).
- genetlink: get rid of family->attrbuf (bnc#1012628).
- net: ipv4: Fix wrong type conversion from hint to rt in
  ip_route_use_hint() (bnc#1012628).
- ethtool: fix genlmsg_put() failure handling in
  ethnl_default_dumpit() (bnc#1012628).
- mptcp: fix DSS map generation on fin retransmission
  (bnc#1012628).
- net: rmnet: do not allow to add multiple bridge interfaces
  (bnc#1012628).
- hsr: fix interface leak in error path of hsr_dev_finalize()
  (bnc#1012628).
- drm/msm: fix potential memleak in error branch (bnc#1012628).
- drm/msm/dpu: allow initialization of encoder locks during
  encoder init (bnc#1012628).
- drm/exynos: Properly propagate return value in
  drm_iommu_attach_device() (bnc#1012628).
- drm/exynos: fix ref count leak in mic_pre_enable (bnc#1012628).
- x86/fpu: Reset MXCSR to default in kernel_fpu_begin()
  (bnc#1012628).
- thermal/drivers: imx: Fix missing of_node_put() at probe time
  (bnc#1012628).
- ACPI: DPTF: Add battery participant for TigerLake (bnc#1012628).
- blk-mq-debugfs: update blk_queue_flag_name[] accordingly for
  new flags (bnc#1012628).
- m68k: nommu: register start of the memory with memblock
  (bnc#1012628).
- m68k: mm: fix node memblock init (bnc#1012628).
- dt-bindings: bus: uniphier-system-bus: fix warning in example
  (bnc#1012628).
- dt-bindings: mailbox: zynqmp_ipi: fix unit address
  (bnc#1012628).
- dt-bindings: fix error in 'make clean' after 'make
  dt_binding_check' (bnc#1012628).
- cifs: prevent truncation from long to int in
  wait_for_free_credits (bnc#1012628).
- arm64/alternatives: use subsections for replacement sequences
  (bnc#1012628).
- tpm_tis: extra chip->ops check on error path in
  tpm_tis_core_init (bnc#1012628).
- xen/xenbus: avoid large structs and arrays on the stack
  (bnc#1012628).
- xen/xenbus: let xenbus_map_ring_valloc() return errno values
  only (bnc#1012628).
- gfs2: eliminate GIF_ORDERED in favor of list_empty
  (bnc#1012628).
- gfs2: freeze should work on read-only mounts (bnc#1012628).
- gfs2: read-only mounts should grab the sd_freeze_gl glock
  (bnc#1012628).
- gfs2: When freezing gfs2, use GL_EXACT and not GL_NOCACHE
  (bnc#1012628).
- gfs2: The freeze glock should never be frozen (bnc#1012628).
- arm64: Add MIDR value for KRYO4XX gold CPU cores (bnc#1012628).
- arm64: Add KRYO4XX gold CPU cores to erratum list 1463225 and
  1418040 (bnc#1012628).
- arm64: Add KRYO4XX silver CPU cores to erratum list 1530923
  and 1024718 (bnc#1012628).
- i2c: eg20t: Load module automatically if ID matches
  (bnc#1012628).
- arm64/alternatives: don't patch up internal branches
  (bnc#1012628).
- iio:magnetometer:ak8974: Fix alignment and data leak issues
  (bnc#1012628).
- iio:humidity:hdc100x Fix alignment and data leak issues
  (bnc#1012628).
- iio: magnetometer: ak8974: Fix runtime PM imbalance on error
  (bnc#1012628).
- iio: core: add missing IIO_MOD_H2/ETHANOL string identifiers
  (bnc#1012628).
- iio: mma8452: Add missed iio_device_unregister() call in
  mma8452_probe() (bnc#1012628).
- iio: pressure: zpa2326: handle pm_runtime_get_sync failure
  (bnc#1012628).
- iio:humidity:hts221 Fix alignment and data leak issues
  (bnc#1012628).
- iio:pressure:ms5611 Fix buffer element alignment (bnc#1012628).
- iio:health:afe4403 Fix timestamp alignment and prevent data leak
  (bnc#1012628).
- arm64: Add missing sentinel to erratum_1463225 (bnc#1012628).
- xen/xenbus: Fix a double free in xenbus_map_ring_pv()
  (bnc#1012628).
- io_uring: fix recvmsg memory leak with buffer selection
  (bnc#1012628).
- Input: mms114 - add extra compatible for mms345l (bnc#1012628).
- iio:health:afe4404 Fix timestamp alignment and prevent data leak
  (bnc#1012628).
- counter: 104-quad-8: Add lock guards - differential encoder
  (bnc#1012628).
- counter: 104-quad-8: Add lock guards - filter clock prescaler
  (bnc#1012628).
- dmaengine: ti: k3-udma: Use correct node to read "ti,udma-atype"
  (bnc#1012628).
- soundwire: intel: fix memory leak with devm_kasprintf
  (bnc#1012628).
- dmaengine: idxd: fix cdev locking for open and release
  (bnc#1012628).
- dmaengine: ti: k3-udma: Fix delayed_work usage for tx drain
  workaround (bnc#1012628).
- dmaengine: sh: usb-dmac: set tx_result parameters (bnc#1012628).
- phy: rockchip: Fix return value of inno_dsidphy_probe()
  (bnc#1012628).
- phy: sun4i-usb: fix dereference of pointer phy0 before it is
  null checked (bnc#1012628).
- arm64: dts: meson: add missing gxl rng clock (bnc#1012628).
- arm64: dts: meson-gxl-s805x: reduce initial Mali450 core
  frequency (bnc#1012628).
- dmaengine: idxd: cleanup workqueue config after disabling
  (bnc#1012628).
- dmaengine: idxd: fix misc interrupt handler thread unmasking
  (bnc#1012628).
- bus: ti-sysc: Fix wakeirq sleeping function called from invalid
  context (bnc#1012628).
- bus: ti-sysc: Fix sleeping function called from invalid context
  for RTC quirk (bnc#1012628).
- bus: ti-sysc: Do not disable on suspend for no-idle
  (bnc#1012628).
- iio: adc: ad7780: Fix a resource handling path in
  'ad7780_probe()' (bnc#1012628).
- dmaengine: dw: Initialize channel before each transfer
  (bnc#1012628).
- dmaengine: dmatest: stop completed threads when running without
  set channel (bnc#1012628).
- spi: spi-sun6i: sun6i_spi_transfer_one(): fix setting of clock
  rate (bnc#1012628).
- usb: gadget: udc: atmel: fix uninitialized read in debug printk
  (bnc#1012628).
- staging: comedi: verify array index is correct before using it
  (bnc#1012628).
- serial: core: Initialise spin lock before use in
  uart_configure_port() (bnc#1012628).
- clk: mvebu: ARMADA_AP_CPU_CLK needs to select
  ARMADA_AP_CP_HELPER (bnc#1012628).
- clk: AST2600: Add mux for EMMC clock (bnc#1012628).
- xprtrdma: Fix double-free in rpcrdma_ep_create() (bnc#1012628).
- xprtrdma: Fix recursion into rpcrdma_xprt_disconnect()
  (bnc#1012628).
- xprtrdma: Fix return code from rpcrdma_xprt_connect()
  (bnc#1012628).
- xprtrdma: Fix handling of connect errors (bnc#1012628).
- NFS: Fix interrupted slots by sending a solo SEQUENCE operation
  (bnc#1012628).
- fuse: don't ignore errors from fuse_writepages_fill()
  (bnc#1012628).
- ARM: dts: Fix dcan driver probe failed on am437x platform
  (bnc#1012628).
- Revert "thermal: mediatek: fix register index error"
  (bnc#1012628).
- xprtrdma: fix incorrect header size calculations (bnc#1012628).
- ARM: dts: socfpga: Align L2 cache-controller nodename with
  dtschema (bnc#1012628).
- arm64: dts: spcfpga: Align GIC, NAND and UART nodenames with
  dtschema (bnc#1012628).
- keys: asymmetric: fix error return code in software_key_query()
  (bnc#1012628).
- nvme: explicitly update mpath disk capacity on revalidation
  (bnc#1012628).
- regmap: debugfs: Don't sleep while atomic for fast_io regmaps
  (bnc#1012628).
- copy_xstate_to_kernel: Fix typo which caused GDB regression
  (bnc#1012628).
- arm: dts: mt7623: add phy-mode property for gmac2 (bnc#1012628).
- soc: qcom: socinfo: add missing soc_id sysfs entry
  (bnc#1012628).
- dmaengine: ti: k3-udma: Disable memcopy via MCU NAVSS on am654
  (bnc#1012628).
- apparmor: ensure that dfa state tables have entries
  (bnc#1012628).
- habanalabs: Align protection bits configuration of all TPCs
  (bnc#1012628).
- RDMA/rxe: Set default vendor ID (bnc#1012628).
- PCI/PM: Call .bridge_d3() hook only if non-NULL (bnc#1012628).
- perf stat: Zero all the 'ena' and 'run' array slot stats for
  interval mode (bnc#1012628).
- soc: qcom: rpmh: Update dirty flag only when data changes
  (bnc#1012628).
- soc: qcom: rpmh: Invalidate SLEEP and WAKE TCSes before flushing
  new data (bnc#1012628).
- soc: qcom: rpmh-rsc: Clear active mode configuration for wake
  TCS (bnc#1012628).
- soc: qcom: rpmh-rsc: Allow using free WAKE TCS for active
  request (bnc#1012628).
- RDMA/mlx5: Verify that QP is created with RQ or SQ
  (bnc#1012628).
- clk: qcom: Add missing msm8998 ufs_unipro_core_clk_src
  (bnc#1012628).
- mtd: spi-nor: winbond: Fix 4-byte opcode support for w25q256
  (bnc#1012628).
- mtd: spi-nor: spansion: fix writes on S25FS512S (bnc#1012628).
- mtd: rawnand: marvell: Fix the condition on a return code
  (bnc#1012628).
- mtd: rawnand: marvell: Use nand_cleanup() when the device is
  not yet registered (bnc#1012628).
- mtd: rawnand: marvell: Fix probe error path (bnc#1012628).
- mtd: rawnand: timings: Fix default tR_max and tCCS_min timings
  (bnc#1012628).
- mtd: rawnand: brcmnand: correctly verify erased pages
  (bnc#1012628).
- mtd: rawnand: brcmnand: fix CS0 layout (bnc#1012628).
- mtd: rawnand: oxnas: Keep track of registered devices
  (bnc#1012628).
- mtd: rawnand: oxnas: Unregister all devices on error
  (bnc#1012628).
- mtd: rawnand: oxnas: Release all devices in the _remove() path
  (bnc#1012628).
- clk: qcom: gcc: Add GPU and NPU clocks for SM8150 (bnc#1012628).
- clk: qcom: gcc: Add missing UFS clocks for SM8150 (bnc#1012628).
- clk: qcom: gcc: Add support for a new frequency for SC7180
  (bnc#1012628).
- slimbus: core: Fix mismatch in of_node_get/put (bnc#1012628).
- HID: logitech-hidpp: avoid repeated "multiplier = " log messages
  (bnc#1012628).
- HID: magicmouse: do not set up autorepeat (bnc#1012628).
- HID: quirks: Always poll Obins Anne Pro 2 keyboard
  (bnc#1012628).
- HID: quirks: Ignore Simply Automated UPB PIM (bnc#1012628).
- ALSA: line6: Perform sanity check for each URB creation
  (bnc#1012628).
- ALSA: line6: Sync the pending work cancel at disconnection
  (bnc#1012628).
- ALSA: usb-audio: Fix race against the error recovery URB
  submission (bnc#1012628).
- ALSA: hda/realtek - change to suitable link model for ASUS
  platform (bnc#1012628).
- ALSA: hda/realtek: enable headset mic of ASUS ROG Zephyrus
  G14(G401) series with ALC289 (bnc#1012628).
- ALSA: hda/realtek: Enable headset mic of Acer TravelMate
  B311R-31 with ALC256 (bnc#1012628).
- ALSA: hda/realtek - Enable Speaker for ASUS UX533 and UX534
  (bnc#1012628).
- ALSA: hda/realtek - Enable Speaker for ASUS UX563 (bnc#1012628).
- thunderbolt: Fix path indices used in USB3 tunnel discovery
  (bnc#1012628).
- USB: c67x00: fix use after free in c67x00_giveback_urb
  (bnc#1012628).
- usb: dwc2: Fix shutdown callback in platform (bnc#1012628).
- usb: chipidea: core: add wakeup support for extcon
  (bnc#1012628).
- usb: gadget: function: fix missing spinlock in f_uac1_legacy
  (bnc#1012628).
- USB: serial: iuu_phoenix: fix memory corruption (bnc#1012628).
- USB: serial: cypress_m8: enable Simply Automated UPB PIM
  (bnc#1012628).
- USB: serial: ch341: add new Product ID for CH340 (bnc#1012628).
- USB: serial: option: add GosunCn GM500 series (bnc#1012628).
- USB: serial: option: add Quectel EG95 LTE modem (bnc#1012628).
- virt: vbox: Fix VBGL_IOCTL_VMMDEV_REQUEST_BIG and _LOG req
  numbers to match upstream (bnc#1012628).
- virt: vbox: Fix guest capabilities mask check (bnc#1012628).
- Revert "tty: xilinx_uartps: Fix missing id assignment to the
  console" (bnc#1012628).
- tty: serial: cpm_uart: Fix behaviour for non existing GPIOs
  (bnc#1012628).
- virtio: virtio_console: add missing MODULE_DEVICE_TABLE()
  for rproc serial (bnc#1012628).
- serial: sh-sci: Initialize spinlock for uart console
  (bnc#1012628).
- serial: mxs-auart: add missed iounmap() in probe failure and
  remove (bnc#1012628).
- Revert "serial: core: Refactor uart_unlock_and_check_sysrq()"
  (bnc#1012628).
- serial: core: fix sysrq overhead regression (bnc#1012628).
- ovl: fix regression with re-formatted lower squashfs
  (bnc#1012628).
- ovl: inode reference leak in ovl_is_inuse true case
  (bnc#1012628).
- ovl: relax WARN_ON() when decoding lower directory file handle
  (bnc#1012628).
- ovl: fix unneeded call to ovl_change_flags() (bnc#1012628).
- fuse: ignore 'data' argument of mount(..., MS_REMOUNT)
  (bnc#1012628).
- fuse: use ->reconfigure() instead of ->remount_fs()
  (bnc#1012628).
- fuse: Fix parameter for FS_IOC_{GET,SET}FLAGS (bnc#1012628).
- Revert "zram: convert remaining CLASS_ATTR() to CLASS_ATTR_RO()"
  (bnc#1012628).
- mei: bus: don't clean driver pointer (bnc#1012628).
- Revert "Input: elants_i2c - report resolution information for
  touch major" (bnc#1012628).
- Input: i8042 - add Lenovo XiaoXin Air 12 to i8042 nomux list
  (bnc#1012628).
- Input: elan_i2c - add more hardware ID for Lenovo laptops
  (bnc#1012628).
- coresight: etmv4: Fix CPU power management setup in probe()
  function (bnc#1012628).
- uio_pdrv_genirq: Remove warning when irq is not specified
  (bnc#1012628).
- uio_pdrv_genirq: fix use without device tree and no interrupt
  (bnc#1012628).
- scsi: megaraid_sas: Remove undefined ENABLE_IRQ_POLL macro
  (bnc#1012628).
- timer: Prevent base->clk from moving backward (bnc#1012628).
- timer: Fix wheel index calculation on last level (bnc#1012628).
- riscv: use 16KB kernel stack on 64-bit (bnc#1012628).
- hwmon: (emc2103) fix unable to change fan pwm1_enable attribute
  (bnc#1012628).
- hwmon: (drivetemp) Avoid SCT usage on Toshiba DT01ACA family
  drives (bnc#1012628).
- powerpc/book3s64/pkeys: Fix pkey_access_permitted() for execute
  disable pkey (bnc#1012628).
- powerpc/pseries/svm: Fix incorrect check for shared_lppaca_size
  (bnc#1012628).
- intel_th: pci: Add Jasper Lake CPU support (bnc#1012628).
- intel_th: pci: Add Tiger Lake PCH-H support (bnc#1012628).
- intel_th: pci: Add Emmitsburg PCH support (bnc#1012628).
- intel_th: Fix a NULL dereference when hub driver is not loaded
  (bnc#1012628).
- opp: Increase parsed_static_opps in _of_add_opp_table_v1()
  (bnc#1012628).
- dmaengine: fsl-edma: Fix NULL pointer exception in
  fsl_edma_tx_handler (bnc#1012628).
- dmaengine: mcf-edma: Fix NULL pointer exception in
  mcf_edma_tx_handler (bnc#1012628).
- dmaengine: fsl-edma-common: correct DSIZE_32BYTE (bnc#1012628).
- misc: atmel-ssc: lock with mutex instead of spinlock
  (bnc#1012628).
- dmabuf: use spinlock to access dmabuf->name (bnc#1012628).
- thermal: int3403_thermal: Downgrade error message (bnc#1012628).
- ARM: dts: imx6qdl-gw551x: fix audio SSI (bnc#1012628).
- arm64: dts: agilex: add status to qspi dts node (bnc#1012628).
- arm64: dts: stratix10: add status to qspi dts node
  (bnc#1012628).
- arm64: dts: stratix10: increase QSPI reg address in nand dts
  file (bnc#1012628).
- arm64: ptrace: Override SPSR.SS when single-stepping is enabled
  (bnc#1012628).
- arm64: ptrace: Consistently use pseudo-singlestep exceptions
  (bnc#1012628).
- arm64: compat: Ensure upper 32 bits of x0 are zero on syscall
  return (bnc#1012628).
- sched: Fix unreliable rseq cpu_id for new tasks (bnc#1012628).
- sched/fair: handle case of task_h_load() returning 0
  (bnc#1012628).
- x86/ioperm: Fix io bitmap invalidation on Xen PV (bnc#1012628).
- genirq/affinity: Handle affinity setting on inactive interrupts
  correctly (bnc#1012628).
- drm/vmwgfx: fix update of display surface when resolution
  changes (bnc#1012628).
- drm/amdgpu/powerplay: Modify SMC message name for setting
  power profile mode (bnc#1012628).
- drm/amdgpu/sdma5: fix wptr overwritten in ->get_wptr()
  (bnc#1012628).
- drm/amd/display: handle failed allocation during stream
  construction (bnc#1012628).
- drm/amd/display: OLED panel backlight adjust not work with
  external display connected (bnc#1012628).
- drm/amdgpu/display: create fake mst encoders ahead of time (v4)
  (bnc#1012628).
- drm/i915: Move cec_notifier to intel_hdmi_connector_unregister,
  v2 (bnc#1012628).
- drm/i915/gt: Ignore irq enabling on the virtual engines
  (bnc#1012628).
- drm/i915/gt: Only swap to a random sibling once upon creation
  (bnc#1012628).
- libceph: don't omit recovery_deletes in target_copy()
  (bnc#1012628).
- rxrpc: Fix trace string (bnc#1012628).
- spi: sprd: switch the sequence of setting WDG_LOAD_LOW and _HIGH
  (bnc#1012628).
- ionic: no link check while resetting queues (bnc#1012628).
- ionic: export features for vlans to use (bnc#1012628).
- iommu/vt-d: Make Intel SVM code 64-bit only (bnc#1012628).
- mm/memory.c: properly pte_offset_map_lock/unlock in
  vm_insert_pages() (bnc#1012628).
- drm/i915/gvt: Fix two CFL MMIO handling caused by regression
  (bnc#1012628).
- gpio: pca953x: disable regmap locking for automatic address
  incrementing (bnc#1012628).
- bpf: sockmap: Check value of unused args to BPF_PROG_ATTACH
  (bnc#1012628).
- bpf: sockmap: Require attach_bpf_fd when detaching a program
  (bnc#1012628).
- drm/i915/perf: Use GTT when saving/restoring engine GPR
  (bnc#1012628).
- commit dcedc15
* Tue Jul 21 2020 mkubecek@suse.cz
- sched: Fix race against ptrace_freeze_trace() (bsc#1174345).
- commit 007dcf0
* Mon Jul 20 2020 mkubecek@suse.cz
- Update to 5.8-rc6
- eliminated 2 patches
- refresh config files
- commit 25ae237
* Fri Jul 17 2020 mkubecek@suse.cz
- config: restore PHYLIB=m
  This essentially reverts kernel-source commit fcc47b444be6 ("config:
  enable PHYLIB=y and ETHTOOL_NETLINK=y") which responded to upstream
  change not allowing ETHTOOL_NETLINK=y with PHYLIB=m. There are two
  exceptions:
  - vanilla flavors keep PHYLIB=y as patches fixing the dependency are
    not applied to */vanilla (will be fixed with 5.9-rc1 update)
  - we preserve ETHTOOL_NETLINK=y which was previously lost in 5.8-rc1
    update
- commit 4756d9e
* Fri Jul 17 2020 mkubecek@suse.cz
- net: ethtool: Remove PHYLIB direct dependency
  (http://lkml.kernel.org/r/0353ce74-ffc6-4d40-bf0f-d2a7ad640b30@gmail.com).
- net: phy: Register ethtool PHY operations
  (http://lkml.kernel.org/r/0353ce74-ffc6-4d40-bf0f-d2a7ad640b30@gmail.com).
- net: ethtool: Introduce ethtool_phy_ops
  (http://lkml.kernel.org/r/0353ce74-ffc6-4d40-bf0f-d2a7ad640b30@gmail.com).
- commit bcc2825
* Fri Jul 17 2020 mkubecek@suse.cz
- bpf: Use dedicated bpf_trace_printk event instead of
  trace_printk().
- commit a2c9fc2
* Thu Jul 16 2020 jslaby@suse.cz
- net: ethernet: mvneta: Do not error out in non serdes modes
  (git-fixes).
- spi: spi-fsl-dspi: Fix lockup if device is shutdown during
  SPI transfer (git-fixes).
- scsi: qla2xxx: make 1-bit bit-fields unsigned int (git-fixes).
- scsi: qla2xxx: Simplify the functions for dumping firmware
  (git-fixes).
- net: ethernet: mvneta: Add back interface mode validation
  (git-fixes).
- commit a010166
* Thu Jul 16 2020 jslaby@suse.cz
- Linux 5.7.9 (bnc#1012628).
- KVM: s390: reduce number of IO pins to 1 (bnc#1012628).
- spi: spi-fsl-dspi: Adding shutdown hook (bnc#1012628).
- spi: spi-fsl-dspi: Fix lockup if device is removed during SPI
  transfer (bnc#1012628).
- regmap: fix alignment issue (bnc#1012628).
- perf/x86/rapl: Move RAPL support to common x86 code
  (bnc#1012628).
- perf/x86/rapl: Fix RAPL config variable bug (bnc#1012628).
- ARM: dts: omap4-droid4: Fix spi configuration and increase rate
  (bnc#1012628).
- drm/ttm: Fix dma_fence refcnt leak in ttm_bo_vm_fault_reserved
  (bnc#1012628).
- drm/ttm: Fix dma_fence refcnt leak when adding move fence
  (bnc#1012628).
- gpu: host1x: Clean up debugfs in error handling path
  (bnc#1012628).
- drm/tegra: hub: Do not enable orphaned window group
  (bnc#1012628).
- gpu: host1x: Detach driver on unregister (bnc#1012628).
- staging: wfx: fix coherency of hif_scan() prototype
  (bnc#1012628).
- drm: mcde: Fix display initialization problem (bnc#1012628).
- ASoC: SOF: Intel: add PCI ID for CometLake-S (bnc#1012628).
- ASoC: hdac_hda: fix memleak with regmap not freed on remove
  (bnc#1012628).
- ALSA: hda: Intel: add missing PCI IDs for ICL-H, TGL-H and EKL
  (bnc#1012628).
- spi: spidev: fix a race between spidev_release and spidev_remove
  (bnc#1012628).
- spi: spidev: fix a potential use-after-free in spidev_release()
  (bnc#1012628).
- net: ethernet: mvneta: Fix Serdes configuration for SoCs
  without comphy (bnc#1012628).
- net: ethernet: mvneta: Add 2500BaseX support for SoCs without
  comphy (bnc#1012628).
- ixgbe: protect ring accesses with READ- and WRITE_ONCE
  (bnc#1012628).
- i40e: protect ring accesses with READ- and WRITE_ONCE
  (bnc#1012628).
- ice: protect ring accesses with WRITE_ONCE (bnc#1012628).
- ibmvnic: continue to init in CRQ reset returns H_CLOSED
  (bnc#1012628).
- powerpc/kvm/book3s64: Fix kernel crash with nested kvm &
  DEBUG_VIRTUAL (bnc#1012628).
- xprtrdma: Prevent dereferencing r_xprt->rx_ep after it is freed
  (bnc#1012628).
- iommu/vt-d: Don't apply gfx quirks to untrusted devices
  (bnc#1012628).
- drm: panel-orientation-quirks: Add quirk for Asus T101HA panel
  (bnc#1012628).
- drm: panel-orientation-quirks: Use generic orientation-data
  for Acer S1003 (bnc#1012628).
- s390/kasan: fix early pgm check handler execution (bnc#1012628).
- cifs: update ctime and mtime during truncate (bnc#1012628).
- ARM: imx6: add missing put_device() call in imx6q_suspend_init()
  (bnc#1012628).
- scsi: qla2xxx: Fix MPI failure AEN (8200) handling
  (bnc#1012628).
- scsi: mptscsih: Fix read sense data size (bnc#1012628).
- usb: dwc3: pci: Fix reference count leak in dwc3_pci_resume_work
  (bnc#1012628).
- arm64: kpti: Add KRYO{3, 4}XX silver CPU cores to kpti safelist
  (bnc#1012628).
- block: release bip in a right way in error path (bnc#1012628).
- nvme-rdma: assign completion vector correctly (bnc#1012628).
- x86/entry: Increase entry_stack size to a full page
  (bnc#1012628).
- arm64: Add KRYO{3,4}XX silver CPU cores to SSB safelist
  (bnc#1012628).
- nfs: Fix memory leak of export_path (bnc#1012628).
- sched/core: Check cpus_mask, not cpus_ptr in
  __set_cpus_allowed_ptr(), to fix mask corruption (bnc#1012628).
- net: qrtr: Fix an out of bounds read qrtr_endpoint_post()
  (bnc#1012628).
- mtd: set master partition panic write flag (bnc#1012628).
- gpio: pca953x: Synchronize interrupt handler properly
  (bnc#1012628).
- gpio: pca953x: Override IRQ for one of the expanders on Galileo
  Gen 2 (bnc#1012628).
- gpio: pca953x: Fix direction setting when configure an IRQ
  (bnc#1012628).
- gpio: pca953x: Fix GPIO resource leak on Intel Galileo Gen 2
  (bnc#1012628).
- ASoC: fsl_mqs: Don't check clock is NULL before calling clk API
  (bnc#1012628).
- ASoC: fsl_mqs: Fix unchecked return value for clk_prepare_enable
  (bnc#1012628).
- KVM: arm64: vgic-v4: Plug race between non-residency and v4.1
  doorbell (bnc#1012628).
- mac80211: Fix dropping broadcast packets in 802.11 encap
  (bnc#1012628).
- bpf: Do not allow btf_ctx_access with __int128 types
  (bnc#1012628).
- nl80211: don't return err unconditionally in nl80211_start_ap()
  (bnc#1012628).
- nl80211: fix memory leak when parsing NL80211_ATTR_HE_BSS_COLOR
  (bnc#1012628).
- drm/mediatek: Check plane visibility in atomic_update
  (bnc#1012628).
- bpf, sockmap: RCU splat with redirect and strparser error or
  TLS (bnc#1012628).
- bpf, sockmap: RCU dereferenced psock may be used outside RCU
  block (bnc#1012628).
- netfilter: ipset: call ip_set_free() instead of kfree()
  (bnc#1012628).
- net: mvneta: fix use of state->speed (bnc#1012628).
- net: ipa: no checksum offload for SDM845 LAN RX (bnc#1012628).
- net: cxgb4: fix return error value in t4_prep_fw (bnc#1012628).
- btrfs: fix reclaim_size counter leak after stealing from global
  reserve (bnc#1012628).
- drm/meson: viu: fix setting the OSD burst length in
  VIU_OSD1_FIFO_CTRL_STAT (bnc#1012628).
- IB/sa: Resolv use-after-free in ib_nl_make_request()
  (bnc#1012628).
- net: dsa: microchip: set the correct number of ports
  (bnc#1012628).
- netfilter: conntrack: refetch conntrack after
  nf_conntrack_update() (bnc#1012628).
- net: rmnet: fix lower interface leak (bnc#1012628).
- net: rmnet: do not allow to add multiple bridge interfaces
  (bnc#1012628).
- perf report TUI: Fix segmentation fault in
  perf_evsel__hists_browse() (bnc#1012628).
- perf intel-pt: Fix recording PEBS-via-PT with registers
  (bnc#1012628).
- perf intel-pt: Fix PEBS sample for XMM registers (bnc#1012628).
- smsc95xx: check return value of smsc95xx_reset (bnc#1012628).
- smsc95xx: avoid memory leak in smsc95xx_bind (bnc#1012628).
- net: hns3: check reset pending after FLR prepare (bnc#1012628).
- net: hns3: fix for mishandle of asserting VF reset fail
  (bnc#1012628).
- net: hns3: add a missing uninit debugfs when unload driver
  (bnc#1012628).
- net: hns3: fix use-after-free when doing self test
  (bnc#1012628).
- ALSA: compress: fix partial_drain completion state
  (bnc#1012628).
- net: ipa: fix QMI structure definition bugs (bnc#1012628).
- net: qed: fix buffer overflow on ethtool -d (bnc#1012628).
- ionic: centralize queue reset code (bnc#1012628).
- powerpc/64s/exception: Fix 0x1500 interrupt handler crash
  (bnc#1012628).
- RDMA/siw: Fix reporting vendor_part_id (bnc#1012628).
- net: atlantic: fix ip dst and ipv6 address filters
  (bnc#1012628).
- arm64: kgdb: Fix single-step exception handling oops
  (bnc#1012628).
- nbd: Fix memory leak in nbd_add_socket (bnc#1012628).
- IB/mlx5: Fix 50G per lane indication (bnc#1012628).
- qed: Populate nvm-file attributes while reading nvm config
  partition (bnc#1012628).
- selftests: bpf: Fix detach from sockmap tests (bnc#1012628).
- net/mlx5: Fix eeprom support for SFP module (bnc#1012628).
- net/mlx5e: Fix VXLAN configuration restore after function reload
  (bnc#1012628).
- net/mlx5e: Fix CPU mapping after function reload to avoid aRFS
  RX crash (bnc#1012628).
- net/mlx5e: Fix 50G per lane indication (bnc#1012628).
- net/mlx5e: CT: Fix memory leak in cleanup (bnc#1012628).
- bnxt_en: fix NULL dereference in case SR-IOV configuration fails
  (bnc#1012628).
- net: macb: fix wakeup test in runtime suspend/resume routines
  (bnc#1012628).
- net: macb: mark device wake capable when "magic-packet"
  property present (bnc#1012628).
- net: macb: fix macb_get/set_wol() when moving to phylink
  (bnc#1012628).
- net: macb: fix macb_suspend() by removing call to
  netif_carrier_off() (bnc#1012628).
- net: macb: fix call to pm_runtime in the suspend/resume
  functions (bnc#1012628).
- mlxsw: spectrum_router: Remove inappropriate usage of WARN_ON()
  (bnc#1012628).
- mlxsw: pci: Fix use-after-free in case of failed devlink reload
  (bnc#1012628).
- IB/hfi1: Do not destroy hfi1_wq when the device is shut down
  (bnc#1012628).
- IB/hfi1: Do not destroy link_wq when the device is shut down
  (bnc#1012628).
- ALSA: opl3: fix infoleak in opl3 (bnc#1012628).
- ALSA: hda - let hs_mic be picked ahead of hp_mic (bnc#1012628).
- ALSA: usb-audio: add quirk for MacroSilicon MS2109
  (bnc#1012628).
- ALSA: usb-audio: Add implicit feedback quirk for RTX6001
  (bnc#1012628).
- ALSA: hda/realtek - Fix Lenovo Thinkpad X1 Carbon 7th quirk
  subdevice id (bnc#1012628).
- ALSA: hda/realtek - Enable audio jacks of Acer vCopperbox with
  ALC269VC (bnc#1012628).
- ALSA: hda/realtek: Enable headset mic of Acer C20-820 with
  ALC269VC (bnc#1012628).
- ALSA: hda/realtek: Enable headset mic of Acer Veriton N4660G
  with ALC269VC (bnc#1012628).
- KVM: arm64: Fix definition of PAGE_HYP_DEVICE (bnc#1012628).
- KVM: arm64: Stop clobbering x0 for HVC_SOFT_RESTART
  (bnc#1012628).
- KVM: arm64: Annotate hyp NMI-related functions as
  __always_inline (bnc#1012628).
- KVM: x86: bit 8 of non-leaf PDPEs is not reserved (bnc#1012628).
- KVM: x86: Inject #GP if guest attempts to toggle CR4.LA57 in
  64-bit mode (bnc#1012628).
- KVM: x86: Mark CR4.TSD as being possibly owned by the guest
  (bnc#1012628).
- KVM: arm64: Fix kvm_reset_vcpu() return code being incorrect
  with SVE (bnc#1012628).
- io_uring: fix memleak in __io_sqe_files_update() (bnc#1012628).
- io_uring: account user memory freed when exit has been queued
  (bnc#1012628).
- io_uring: fix memleak in io_sqe_files_register() (bnc#1012628).
- io_uring: fix missing msg_name assignment (bnc#1012628).
- kallsyms: Refactor kallsyms_show_value() to take cred
  (bnc#1012628).
- module: Refactor section attr into bin attribute (bnc#1012628).
- module: Do not expose section addresses to non-CAP_SYSLOG
  (bnc#1012628).
- kprobes: Do not expose probe addresses to non-CAP_SYSLOG
  (bnc#1012628).
- bpf: Check correct cred for CAP_SYSLOG in bpf_dump_raw_ok()
  (bnc#1012628).
- btrfs: fix fatal extent_buffer readahead vs releasepage race
  (bnc#1012628).
- btrfs: reset tree root pointer after error in init_tree_roots
  (bnc#1012628).
- btrfs: discard: add missing put when grabbing block group from
  unused list (bnc#1012628).
- btrfs: fix double put of block group with nocow (bnc#1012628).
- drm/radeon: fix double free (bnc#1012628).
- drm/i915/gt: Pin the rings before marking active (bnc#1012628).
- drm/i915: Skip stale object handle for debugfs per-file-stats
  (bnc#1012628).
- drm/amdgpu: don't do soft recovery if gpu_recovery=0
  (bnc#1012628).
- drm/amdgpu: add TMR destory function for psp (bnc#1012628).
- drm/amdgpu: asd function needs to be unloaded in suspend phase
  (bnc#1012628).
- drm/i915: Drop vm.ref for duplicate vma on construction
  (bnc#1012628).
- drm/i915: Also drop vm.ref along error paths for vma
  construction (bnc#1012628).
- cifs: fix reference leak for tlink (bnc#1012628).
- smb3: fix access denied on change notify request to some servers
  (bnc#1012628).
- smb3: fix unneeded error message on change notify (bnc#1012628).
- dm: use noio when sending kobject event (bnc#1012628).
- mmc: meson-gx: limit segments to 1 when dram-access-quirk is
  needed (bnc#1012628).
- mmc: owl-mmc: Get rid of of_match_ptr() macro (bnc#1012628).
- pinctrl: baytrail: Fix pin being driven low for a while on
  gpiod_get(..., GPIOD_OUT_HIGH) (bnc#1012628).
- ARC: entry: fix potential EFA clobber when TIF_SYSCALL_TRACE
  (bnc#1012628).
- ARC: elf: use right ELF_ARCH (bnc#1012628).
- s390/setup: init jump labels before command line parsing
  (bnc#1012628).
- s390/mm: fix huge pte soft dirty copying (bnc#1012628).
- arm64: Introduce a way to disable the 32bit vdso (bnc#1012628).
- arm64: arch_timer: Allow an workaround descriptor to disable
  compat vdso (bnc#1012628).
- arm64: arch_timer: Disable the compat vdso for cores affected
  by ARM64_WORKAROUND_1418040 (bnc#1012628).
- blk-mq: consider non-idle request as "inflight" in
  blk_mq_rq_inflight() (bnc#1012628).
- dm writecache: reject asynchronous pmem devices (bnc#1012628).
- perf scripts python: export-to-postgresql.py: Fix struct.pack()
  int argument (bnc#1012628).
- perf scripts python: exported-sql-viewer.py: Fix zero id in
  call graph 'Find' result (bnc#1012628).
- perf scripts python: exported-sql-viewer.py: Fix zero id in
  call tree 'Find' result (bnc#1012628).
- perf scripts python: exported-sql-viewer.py: Fix unexpanded
  'Find' result (bnc#1012628).
- perf scripts python: exported-sql-viewer.py: Fix time chart
  call tree (bnc#1012628).
- s390: Change s390_kernel_write() return type to match memcpy()
  (bnc#1012628).
- s390/maccess: add no DAT mode to kernel_write (bnc#1012628).
- commit 7237b79
* Wed Jul 15 2020 mbrugger@suse.com
- brcmfmac: Transform compatible string for FW loading
  (bsc#1169771).
- commit 0f57628
* Tue Jul 14 2020 afaerber@suse.com
- config: arm64: Update to 5.8-rc5
- commit b4e494e
* Mon Jul 13 2020 jslaby@suse.cz
- cxgb4: fix all-mask IP address comparison (git-fixes).
- commit 8f507a0
* Mon Jul 13 2020 mkubecek@suse.cz
- Update to 5.8-rc5
- refresh riscv64 configs
- commit 9f5e5ef
* Fri Jul 10 2020 mkubecek@suse.cz
- sched: Fix loadavg accounting race
  (http://lkml.kernel.org/r/20200702171548.GA11813@codemonkey.org.uk).
- commit 2cd7849
* Thu Jul  9 2020 jslaby@suse.cz
- Linux 5.7.8 (bnc#1012628).
- efi: Make it possible to disable efivar_ssdt entirely
  (bnc#1012628).
- Update config files.
- dm zoned: assign max_io_len correctly (bnc#1012628).
- mm/cma.c: use exact_nid true to fix possible per-numa cma leak
  (bnc#1012628).
- mm/hugetlb.c: fix pages per hugetlb calculation (bnc#1012628).
- irqchip/gic: Atomically update affinity (bnc#1012628).
- dma-buf: Move dma_buf_release() from fops to dentry_ops
  (bnc#1012628).
- drm/amdgpu/atomfirmware: fix vram_info fetching for renoir
  (bnc#1012628).
- drm/amdgpu: use %%u rather than %%d for sclk/mclk (bnc#1012628).
- drm/amd/display: Only revalidate bandwidth on medium and fast
  updates (bnc#1012628).
- drm/amd/powerplay: Fix NULL dereference in lock_bus() on Vega20
  w/o RAS (bnc#1012628).
- drm/i915: Include asm sources for {ivb, hsw}_clear_kernel.c
  (bnc#1012628).
- MIPS: Add missing EHB in mtc0 -> mfc0 sequence for DSPen
  (bnc#1012628).
- MIPS: lantiq: xway: sysctrl: fix the GPHY clock alias names
  (bnc#1012628).
- x86/split_lock: Don't write MSR_TEST_CTRL on CPUs that aren't
  whitelisted (bnc#1012628).
- gfs2: fix trans slab error when withdraw occurs inside log_flush
  (bnc#1012628).
- ACPI: fan: Fix Tiger Lake ACPI device ID (bnc#1012628).
- thermal/drivers/cpufreq_cooling: Fix wrong frequency converted
  from power (bnc#1012628).
- hwmon: (pmbus) Fix page vs. register when accessing fans
  (bnc#1012628).
- Drivers: hv: Change flag to write log level in panic msg to
  false (bnc#1012628).
- cifs: Fix the target file was deleted when rename failed
  (bnc#1012628).
- SMB3: Honor 'handletimeout' flag for multiuser mounts
  (bnc#1012628).
- SMB3: Honor lease disabling for multiuser mounts (bnc#1012628).
- SMB3: Honor persistent/resilient handle flags for multiuser
  mounts (bnc#1012628).
- SMB3: Honor 'seal' flag for multiuser mounts (bnc#1012628).
- padata: upgrade smp_mb__after_atomic to smp_mb in
  padata_do_serial (bnc#1012628).
- Revert "ALSA: usb-audio: Improve frames size computation"
  (bnc#1012628).
- nfsd: apply umask on fs without ACL support (bnc#1012628).
- spi: spi-fsl-dspi: Fix external abort on interrupt in resume
  or exit paths (bnc#1012628).
- io_uring: fix regression with always ignoring signals in
  io_cqring_wait() (bnc#1012628).
- i2c: mlxcpld: check correct size of maximum RECV_LEN packet
  (bnc#1012628).
- i2c: designware: platdrv: Set class based on DMI (bnc#1012628).
- i2c: algo-pca: Add 0x78 as SCL stuck low status for PCA9665
  (bnc#1012628).
- samples/vfs: avoid warning in statx override (bnc#1012628).
- tpm: ibmvtpm: Wait for ready buffer before probing for TPM2
  attributes (bnc#1012628).
- nvme: fix a crash in nvme_mpath_add_disk (bnc#1012628).
- nvme: fix identify error status silent ignore (bnc#1012628).
- SMB3: Honor 'posix' flag for multiuser mounts (bnc#1012628).
- virtio-blk: free vblk-vqs in error path of virtblk_probe()
  (bnc#1012628).
- drm: sun4i: hdmi: Remove extra HPD polling (bnc#1012628).
- nfsd: fix nfsdfs inode reference count leak (bnc#1012628).
- nfsd4: fix nfsdfs reference count loop (bnc#1012628).
- thermal/drivers/rcar_gen3: Fix undefined temperature if negative
  (bnc#1012628).
- thermal/drivers/sprd: Fix return value of sprd_thm_probe()
  (bnc#1012628).
- thermal/drivers/mediatek: Fix bank number settings on mt8183
  (bnc#1012628).
- scsi: qla2xxx: Fix a condition in qla2x00_find_all_fabric_devs()
  (bnc#1012628).
- hwmon: (acpi_power_meter) Fix potential memory leak in
  acpi_power_meter_add() (bnc#1012628).
- hwmon: (max6697) Make sure the OVERT mask is set correctly
  (bnc#1012628).
- security: Fix hook iteration and default value for
  inode_copy_up_xattr (bnc#1012628).
- cxgb4: fix SGE queue dump destination buffer context
  (bnc#1012628).
- cxgb4: use correct type for all-mask IP address comparison
  (bnc#1012628).
- cxgb4: fix endian conversions for L4 ports in filters
  (bnc#1012628).
- cxgb4: parse TC-U32 key values and masks natively (bnc#1012628).
- cxgb4: use unaligned conversion for fetching timestamp
  (bnc#1012628).
- hsr: avoid to create proc file after unregister (bnc#1012628).
- hsr: remove hsr interface if all slaves are removed
  (bnc#1012628).
- xfs: fix use-after-free on CIL context on shutdown
  (bnc#1012628).
- RDMA/counter: Query a counter before release (bnc#1012628).
- irqchip/gic-v4.1: Use readx_poll_timeout_atomic() to fix sleep
  in atomic (bnc#1012628).
- enetc: Fix HW_VLAN_CTAG_TX|RX toggling (bnc#1012628).
- net: enetc: add hw tc hw offload features for PSPF capability
  (bnc#1012628).
- mptcp: drop MP_JOIN request sock on syn cookies (bnc#1012628).
- rxrpc: Fix afs large storage transmission performance drop
  (bnc#1012628).
- btrfs: fix RWF_NOWAIT writes blocking on extent locks and
  waiting for IO (bnc#1012628).
- drm/msm/dpu: fix error return code in dpu_encoder_init
  (bnc#1012628).
- io_uring: use signal based task_work running (bnc#1012628).
- task_work: teach task_work_add() to do signal_wake_up()
  (bnc#1012628).
- crypto: af_alg - fix use-after-free in af_alg_accept() due to
  bh_lock_sock() (bnc#1012628).
- tpm: Fix TIS locality timeout problems (bnc#1012628).
- selftests: tpm: Use /bin/sh instead of /bin/bash (bnc#1012628).
- Revert "tpm: selftest: cleanup after unseal with wrong
  auth/policy test" (bnc#1012628).
- kgdb: Avoid suspicious RCU usage warning (bnc#1012628).
- io_uring: fix current->mm NULL dereference on exit
  (bnc#1012628).
- nvme-multipath: fix bogus request queue reference put
  (bnc#1012628).
- nvme-multipath: fix deadlock due to head->lock (bnc#1012628).
- nvme-multipath: fix deadlock between ana_work and scan_work
  (bnc#1012628).
- nvme: fix possible deadlock when I/O is blocked (bnc#1012628).
- nvme-multipath: set bdi capabilities once (bnc#1012628).
- io_uring: fix io_sq_thread no schedule when busy (bnc#1012628).
- s390/debug: avoid kernel warning on too large number of pages
  (bnc#1012628).
- tools lib traceevent: Handle __attribute__((user)) in field
  names (bnc#1012628).
- tools lib traceevent: Add append() function helper for appending
  strings (bnc#1012628).
- usb: usbtest: fix missing kfree(dev->buf) in usbtest_disconnect
  (bnc#1012628).
- rxrpc: Fix race between incoming ACK parser and retransmitter
  (bnc#1012628).
- io_uring: fix {SQ,IO}POLL with unsupported opcodes
  (bnc#1012628).
- mm, dump_page(): do not crash with invalid mapping pointer
  (bnc#1012628).
- mm/slub: fix stack overruns with SLUB_STATS (bnc#1012628).
- mm/slub.c: fix corrupted freechain in deactivate_slab()
  (bnc#1012628).
- powerpc/book3s64/kvm: Fix secondary page table walk warning
  during migration (bnc#1012628).
- powerpc/kvm/book3s: Add helper to walk partition scoped linux
  page table (bnc#1012628).
- soc: ti: omap-prm: use atomic iopoll instead of sleeping one
  (bnc#1012628).
- sched/debug: Make sd->flags sysctl read-only (bnc#1012628).
- drm/amdgpu: fix kernel page fault issue by ras recovery on sGPU
  (bnc#1012628).
- drm/amdgpu: fix non-pointer dereference for non-RAS supported
  (bnc#1012628).
- drm/amdgpu: disable ras query and iject during gpu reset
  (bnc#1012628).
- drm/i915/gt: Mark timeline->cacheline as destroyed after rcu
  grace period (bnc#1012628).
- tipc: Fix NULL pointer dereference in __tipc_sendstream()
  (bnc#1012628).
- usbnet: smsc95xx: Fix use-after-free after removal
  (bnc#1012628).
- tipc: fix kernel WARNING in tipc_msg_append() (bnc#1012628).
- tipc: add test for Nagle algorithm effectiveness (bnc#1012628).
- seg6: fix seg6_validate_srh() to avoid slab-out-of-bounds
  (bnc#1012628).
- drm/amd/display: Fix ineffective setting of max bpc property
  (bnc#1012628).
- drm/amd/display: Fix incorrectly pruned modes with deep color
  (bnc#1012628).
- mm: fix swap cache node allocation mask (bnc#1012628).
- btrfs: fix race between block group removal and block group
  creation (bnc#1012628).
- btrfs: block-group: refactor how we delete one block group item
  (bnc#1012628).
- exfat: flush dirty metadata in fsync (bnc#1012628).
- exfat: move setting VOL_DIRTY over exfat_remove_entries()
  (bnc#1012628).
- exfat: call sync_filesystem for read-only remount (bnc#1012628).
- exfat: add missing brelse() calls on error paths (bnc#1012628).
- exfat: Set the unused characters of FileName field to the
  value 0000h (bnc#1012628).
- commit 15d9076
* Wed Jul  8 2020 jslaby@suse.cz
- pinctrl: cherryview: Ensure _REG(ACPI_ADR_SPACE_GPIO, 1)
  gets called (UMAX).
- pinctrl: cherryview: Enable glitch filter for GPIOs used as
  interrupts (UMAX).
- commit 3647f4a
* Tue Jul  7 2020 tiwai@suse.de
- ALSA: usb-audio: Fix packet size calculation (bsc#1173847).
- commit d62e41f
* Mon Jul  6 2020 mkubecek@suse.cz
- x86/entry/32: Fix XEN_PV build dependency
  (https://lkml.kernel.org/r/20200706084155.ndltt24ipognh67e@lion.mk-sys.cz).
- commit 006adcb
* Mon Jul  6 2020 mkubecek@suse.cz
- Update to 5.8-rc4
- eliminated 1 patch
- refresh
  patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch
- commit 6584126
* Thu Jul  2 2020 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: do not run klp-symbols for configs with no modules
  Starting with 5.8-rc1, s390x/zfcpdump builds fail because rpm/klp-symbols
  script does not find .tmp_versions directory. This is missing because
  s390x/zfcpdump is built without modules (CONFIG_MODULES disabled).
  As livepatching cannot work without modules, the cleanest solution is
  setting %%klp_symbols to 0 if CONFIG_MODULES is disabled. (We cannot simply
  add another condition to the place where %%klp_symbols is set as it can be
  already set to 1 from prjconf.)
- commit a048c4b
* Thu Jul  2 2020 mkubecek@suse.cz
- Revert "rpm/kernel-binary.spec.in: do not run klp-symbols for configs with no modules"
  This reverts commit b5e55f7584b89b6e17d91451bc47c5c0f732e730.
  This approach doesn't work correctly if %%klp_symbols is set to 1 in
  prjconf and correct solution is simpler.
- commit 708b64e
* Thu Jul  2 2020 mkubecek@suse.cz
- config: refresh riscv64/default
- commit 6b56aca
* Wed Jul  1 2020 jslaby@suse.cz
- Linux 5.7.7 (bnc#1012628).
- spi: spi-fsl-dspi: Free DMA memory with matching function
  (bnc#1012628).
- block/bio-integrity: don't free 'buf' if
  bio_integrity_add_page() failed (bnc#1012628).
- enetc: Fix tx rings bitmap iteration range, irq handling
  (bnc#1012628).
- ethtool: Fix check in ethtool_rx_flow_rule_create (bnc#1012628).
- geneve: allow changing DF behavior after creation (bnc#1012628).
- ibmveth: Fix max MTU limit (bnc#1012628).
- mld: fix memory leak in ipv6_mc_destroy_dev() (bnc#1012628).
- mlxsw: spectrum: Do not rely on machine endianness
  (bnc#1012628).
- mvpp2: ethtool rxtx stats fix (bnc#1012628).
- net: bridge: enfore alignment for ethernet address
  (bnc#1012628).
- net: core: reduce recursion limit value (bnc#1012628).
- net: Do not clear the sock TX queue in sk_set_socket()
  (bnc#1012628).
- net: ethtool: add missing string for NETIF_F_GSO_TUNNEL_REMCSUM
  (bnc#1012628).
- net: fix memleak in register_netdevice() (bnc#1012628).
- net: Fix the arp error in some cases (bnc#1012628).
- net: increment xmit_recursion level in dev_direct_xmit()
  (bnc#1012628).
- net: usb: ax88179_178a: fix packet alignment padding
  (bnc#1012628).
- openvswitch: take into account de-fragmentation/gso_size in
  execute_check_pkt_len (bnc#1012628).
- rocker: fix incorrect error handling in dma_rings_init
  (bnc#1012628).
- rxrpc: Fix notification call on completion of discarded calls
  (bnc#1012628).
- sctp: Don't advertise IPv4 addresses if ipv6only is set on
  the socket (bnc#1012628).
- tcp: don't ignore ECN CWR on pure ACK (bnc#1012628).
- tcp: grow window for OOO packets only for SACK flows
  (bnc#1012628).
- tg3: driver sleeps indefinitely when EEH errors exceed
  eeh_max_freezes (bnc#1012628).
- ip6_gre: fix use-after-free in ip6gre_tunnel_lookup()
  (bnc#1012628).
- net: phy: Check harder for errors in get_phy_id() (bnc#1012628).
- ip_tunnel: fix use-after-free in ip_tunnel_lookup()
  (bnc#1012628).
- bnxt_en: Store the running firmware version code (bnc#1012628).
- bnxt_en: Do not enable legacy TX push on older firmware
  (bnc#1012628).
- bnxt_en: Fix statistics counters issue during ifdown with
  older firmware (bnc#1012628).
- bnxt_en: Read VPD info only for PFs (bnc#1012628).
- net: phylink: fix ethtool -A with attached PHYs (bnc#1012628).
- net: phylink: ensure manual pause mode configuration takes
  effect (bnc#1012628).
- sch_cake: don't try to reallocate or unshare skb unconditionally
  (bnc#1012628).
- sch_cake: don't call diffserv parsing code when it is not needed
  (bnc#1012628).
- sch_cake: fix a few style nits (bnc#1012628).
- tcp_cubic: fix spurious HYSTART_DELAY exit upon drop in min RTT
  (bnc#1012628).
- bpf: tcp: bpf_cubic: fix spurious HYSTART_DELAY exit upon drop
  in min RTT (bnc#1012628).
- net: macb: undo operations in case of failure (bnc#1012628).
- r8169: fix firmware not resetting tp->ocp_base (bnc#1012628).
- mptcp: drop sndr_key in mptcp_syn_options (bnc#1012628).
- mptcp: fix memory leak in mptcp_subflow_create_socket()
  (bnc#1012628).
- net: ethtool: add missing NETIF_F_GSO_FRAGLIST feature string
  (bnc#1012628).
- net: macb: call pm_runtime_put_sync on failure path
  (bnc#1012628).
- net: phy: mscc: avoid skcipher API for single block AES
  encryption (bnc#1012628).
- of: of_mdio: Correct loop scanning logic (bnc#1012628).
- wireguard: device: avoid circular netns references
  (bnc#1012628).
- bareudp: Fixed multiproto mode configuration (bnc#1012628).
- ionic: update the queue count on open (bnc#1012628).
- net: dsa: bcm_sf2: Fix node reference count (bnc#1012628).
- net: phy: smsc: fix printing too many logs (bnc#1012628).
- nvmet: cleanups the loop in nvmet_async_events_process
  (bnc#1012628).
- ALSA: usb-audio: Fix potential use-after-free of streams
  (bnc#1012628).
- Revert "i2c: tegra: Fix suspending in active runtime PM state"
  (bnc#1012628).
- btrfs: fix a block group ref counter leak after failure to
  remove block group (bnc#1012628).
- binder: fix null deref of proc->context (bnc#1012628).
- mei: me: disable mei interface on Mehlow server platforms
  (bnc#1012628).
- mei: me: add tiger lake point device ids for H platforms
  (bnc#1012628).
- Revert "usb: dwc3: exynos: Add support for Exynos5422 suspend
  clk" (bnc#1012628).
- USB: ohci-sm501: Add missed iounmap() in remove (bnc#1012628).
- usb: dwc2: Postponed gadget registration to the udc class driver
  (bnc#1012628).
- usb: add USB_QUIRK_DELAY_INIT for Logitech C922 (bnc#1012628).
- USB: ehci: reopen solution for Synopsys HC bug (bnc#1012628).
- usb: host: xhci-mtk: avoid runtime suspend when removing hcd
  (bnc#1012628).
- xhci: Poll for U0 after disabling USB2 LPM (bnc#1012628).
- usb: host: ehci-exynos: Fix error check in exynos_ehci_probe()
  (bnc#1012628).
- usb: typec: tcpci_rt1711h: avoid screaming irq causing boot
  hangs (bnc#1012628).
- usb: typec: mux: intel_pmc_mux: Fix DP alternate mode entry
  (bnc#1012628).
- ALSA: usb-audio: Add implicit feedback quirk for SSL2+
  (bnc#1012628).
- ALSA: usb-audio: add quirk for Denon DCD-1500RE (bnc#1012628).
- ALSA: usb-audio: Set 48 kHz rate for Rodecaster (bnc#1012628).
- ALSA: usb-audio: Add registration quirk for Kingston HyperX
  Cloud Flight S (bnc#1012628).
- ALSA: usb-audio: add quirk for Samsung USBC Headset (AKG)
  (bnc#1012628).
- ALSA: usb-audio: Fix OOB access of mixer element list
  (bnc#1012628).
- usb: cdns3: trace: using correct dir value (bnc#1012628).
- usb: cdns3: ep0: fix the test mode set incorrectly
  (bnc#1012628).
- usb: cdns3: ep0: add spinlock for cdns3_check_new_setup
  (bnc#1012628).
- scsi: qla2xxx: Keep initiator ports after RSCN (bnc#1012628).
- scsi: zfcp: Fix panic on ERP timeout for previously dismissed
  ERP action (bnc#1012628).
- cifs: Fix cached_fid refcnt leak in open_shroot (bnc#1012628).
- cifs/smb3: Fix data inconsistent when punch hole (bnc#1012628).
- cifs/smb3: Fix data inconsistent when zero file range
  (bnc#1012628).
- xhci: Fix incorrect EP_STATE_MASK (bnc#1012628).
- xhci: Fix enumeration issue when setting max packet size for
  FS devices (bnc#1012628).
- xhci: Return if xHCI doesn't support LPM (bnc#1012628).
- cdc-acm: Add DISABLE_ECHO quirk for Microchip/SMSC chip
  (bnc#1012628).
- loop: replace kill_bdev with invalidate_bdev (bnc#1012628).
- IB/mad: Fix use after free when destroying MAD agent
  (bnc#1012628).
- IB/hfi1: Fix module use count flaw due to leftover module put
  calls (bnc#1012628).
- bus: ti-sysc: Flush posted write on enable and disable
  (bnc#1012628).
- bus: ti-sysc: Use optional clocks on for enable and wait for
  softreset bit (bnc#1012628).
- bus: ti-sysc: Ignore clockactivity unless specified as a quirk
  (bnc#1012628).
- bus: ti-sysc: Fix uninitialized framedonetv_irq (bnc#1012628).
- ARM: OMAP2+: Fix legacy mode dss_reset (bnc#1012628).
- xfrm: Fix double ESP trailer insertion in IPsec crypto offload
  (bnc#1012628).
- ARM: dts: Fix am33xx.dtsi USB ranges length (bnc#1012628).
- ARM: dts: Fix am33xx.dtsi ti,sysc-mask wrong softreset flag
  (bnc#1012628).
- ASoC: q6asm: handle EOS correctly (bnc#1012628).
- regulator: da9063: fix LDO9 suspend and warning (bnc#1012628).
- ARM: dts: BCM5301X: Add missing memory "device_type" for Luxul
  XWC-2000 (bnc#1012628).
- ARM: bcm: Select ARM_TIMER_SP804 for ARCH_BCM_NSP (bnc#1012628).
- x86/cpu: Move resctrl CPUID code to resctrl/ (bnc#1012628).
- x86/resctrl: Support CPUID enumeration of MBM counter width
  (bnc#1012628).
- x86/resctrl: Fix memory bandwidth counter width for AMD
  (bnc#1012628).
- efi/esrt: Fix reference count leak in esre_create_sysfs_entry
  (bnc#1012628).
- ASoC: soc-pcm: fix checks for multi-cpu FE dailinks
  (bnc#1012628).
- ASoc: q6afe: add support to get port direction (bnc#1012628).
- ASoC: qcom: common: set correct directions for dailinks
  (bnc#1012628).
- regualtor: pfuze100: correct sw1a/sw2 on pfuze3000
  (bnc#1012628).
- efi/libstub: Fix path separator regression (bnc#1012628).
- RDMA/siw: Fix pointer-to-int-cast warning in siw_rx_pbl()
  (bnc#1012628).
- ARM: dts: NSP: Disable PL330 by default, add dma-coherent
  property (bnc#1012628).
- ASoC: fsl_ssi: Fix bclk calculation for mono channel
  (bnc#1012628).
- samples/bpf: xdp_redirect_cpu: Set MAX_CPUS according to NR_CPUS
  (bnc#1012628).
- bpf, xdp, samples: Fix null pointer dereference in *_user code
  (bnc#1012628).
- ARM: dts: am335x-pocketbeagle: Fix mmc0 Write Protect
  (bnc#1012628).
- ARM: dts: Fix duovero smsc interrupt for suspend (bnc#1012628).
- dma-direct: re-encrypt memory if dma_direct_alloc_pages()
  fails (bnc#1012628).
- dma-direct: check return value when encrypting or decrypting
  memory (bnc#1012628).
- x86/resctrl: Fix a NULL vs IS_ERR() static checker warning in
  rdt_cdp_peer_get() (bnc#1012628).
- efi/x86: Setup stack correctly for efi_pe_entry (bnc#1012628).
- regmap: Fix memory leak from regmap_register_patch
  (bnc#1012628).
- devmap: Use bpf_map_area_alloc() for allocating hash buckets
  (bnc#1012628).
- bpf: Don't return EINVAL from {get,set}sockopt when optlen >
  PAGE_SIZE (bnc#1012628).
- ARM: dts: NSP: Correct FA2 mailbox node (bnc#1012628).
- rxrpc: Fix handling of rwind from an ACK packet (bnc#1012628).
- RDMA/rvt: Fix potential memory leak caused by rvt_alloc_rq
  (bnc#1012628).
- RDMA/efa: Set maximum pkeys device attribute (bnc#1012628).
- RDMA/qedr: Fix KASAN: use-after-free in ucma_event_handler+0x532
  (bnc#1012628).
- RDMA/cma: Protect bind_list and listen_list while finding
  matching cm id (bnc#1012628).
- RDMA/core: Check that type_attrs is not NULL prior access
  (bnc#1012628).
- ASoC: rockchip: Fix a reference count leak (bnc#1012628).
- s390/qeth: fix error handling for isolation mode cmds
  (bnc#1012628).
- RDMA/mad: Fix possible memory leak in ib_mad_post_receive_mads()
  (bnc#1012628).
- selftests/net: report etf errors correctly (bnc#1012628).
- ionic: tame the watchdog timer on reconfig (bnc#1012628).
- Revert "KVM: VMX: Micro-optimize vmexit time when not exposing
  PMU" (bnc#1012628).
- iommu/vt-d: Set U/S bit in first level page table by default
  (bnc#1012628).
- iommu/vt-d: Enable PCI ACS for platform opt in hint
  (bnc#1012628).
- iommu/vt-d: Update scalable mode paging structure coherency
  (bnc#1012628).
- soc: imx8m: Correct i.MX8MP UID fuse offset (bnc#1012628).
- dma-direct: add missing set_memory_decrypted() for coherent
  mapping (bnc#1012628).
- net: qed: fix left elements count calculation (bnc#1012628).
- net: qed: fix async event callbacks unregistering (bnc#1012628).
- net: qede: stop adding events on an already destroyed workqueue
  (bnc#1012628).
- net: qed: fix NVMe login fails over VFs (bnc#1012628).
- net: qed: fix excessive QM ILT lines consumption (bnc#1012628).
- net: qede: fix PTP initialization on recovery (bnc#1012628).
- net: qede: fix use-after-free on recovery and AER handling
  (bnc#1012628).
- net: qed: reset ILT block sizes before recomputing to fix
  crashes (bnc#1012628).
- cxgb4: move handling L2T ARP failures to caller (bnc#1012628).
- cxgb4: move PTP lock and unlock to caller in Tx path
  (bnc#1012628).
- ARM: imx5: add missing put_device() call in
  imx_suspend_alloc_ocram() (bnc#1012628).
- scsi: lpfc: Avoid another null dereference in
  lpfc_sli4_hba_unset() (bnc#1012628).
- usb: gadget: udc: Potential Oops in error handling code
  (bnc#1012628).
- usb: renesas_usbhs: getting residue from callback_result
  (bnc#1012628).
- nvme: don't protect ns mutation with ns->head->lock
  (bnc#1012628).
- qed: add missing error test for
  DBG_STATUS_NO_MATCHING_FRAMING_MODE (bnc#1012628).
- netfilter: ipset: fix unaligned atomic access (bnc#1012628).
- net: bcmgenet: use hardware padding of runt frames
  (bnc#1012628).
- io_uring: fix hanging iopoll in case of -EAGAIN (bnc#1012628).
- clk: sifive: allocate sufficient memory for struct __prci_data
  (bnc#1012628).
- i2c: fsi: Fix the port number field in status register
  (bnc#1012628).
- net: macb: free resources on failure path of at91ether_open()
  (bnc#1012628).
- wireguard: receive: account for napi_gro_receive never returning
  GRO_DROP (bnc#1012628).
- socionext: account for napi_gro_receive never returning GRO_DROP
  (bnc#1012628).
- wil6210: account for napi_gro_receive never returning GRO_DROP
  (bnc#1012628).
- selftests/powerpc: Fix build failure in ebb tests (bnc#1012628).
- i2c: core: check returned size of emulated smbus block read
  (bnc#1012628).
- afs: Fix storage of cell names (bnc#1012628).
- sched/deadline: Initialize ->dl_boosted (bnc#1012628).
- sched/core: Fix PI boosting between RT and DEADLINE tasks
  (bnc#1012628).
- sched/cfs: change initial value of runnable_avg (bnc#1012628).
- sata_rcar: handle pm_runtime_get_sync failure cases
  (bnc#1012628).
- ata/libata: Fix usage of page address by page_address in
  ata_scsi_mode_select_xlat function (bnc#1012628).
- drm/amd/display: Use kfree() to free rgb_user in
  calculate_user_regamma_ramp() (bnc#1012628).
- riscv/atomic: Fix sign extension for RV64I (bnc#1012628).
- bcache: check and adjust logical block size for backing devices
  (bnc#1012628).
- hwrng: ks-sa - Fix runtime PM imbalance on error (bnc#1012628).
- ibmvnic: Harden device login requests (bnc#1012628).
- net: alx: fix race condition in alx_remove (bnc#1012628).
- test_objagg: Fix potential memory leak in error handling
  (bnc#1012628).
- pinctrl: qcom: spmi-gpio: fix warning about irq chip reusage
  (bnc#1012628).
- pinctrl: tegra: Use noirq suspend/resume callbacks
  (bnc#1012628).
- s390/seccomp: pass syscall arguments via seccomp_data
  (bnc#1012628).
- s390/ptrace: return -ENOSYS when invalid syscall is supplied
  (bnc#1012628).
- s390/ptrace: pass invalid syscall numbers to tracing
  (bnc#1012628).
- s390/ptrace: fix setting syscall number (bnc#1012628).
- s390/vdso: Use $(LD) instead of $(CC) to link vDSO
  (bnc#1012628).
- s390/vdso: fix vDSO clock_getres() (bnc#1012628).
- arm64: sve: Fix build failure when ARM64_SVE=y and SYSCTL=n
  (bnc#1012628).
- kbuild: improve cc-option to clean up all temporary files
  (bnc#1012628).
- recordmcount: support >64k sections (bnc#1012628).
- kprobes: Suppress the suspicious RCU warning on kprobes
  (bnc#1012628).
- blktrace: break out of blktrace setup on concurrent calls
  (bnc#1012628).
- nvdimm/region: always show the 'align' attribute (bnc#1012628).
- block: update hctx map when use multiple maps (bnc#1012628).
- RISC-V: Don't allow write+exec only page mapping request in mmap
  (bnc#1012628).
- syscalls: Fix offset type of ksys_ftruncate() (bnc#1012628
  bsc#1172699).
- ALSA: hda: Add NVIDIA codec IDs 9a & 9d through a0 to patch
  table (bnc#1012628).
- ALSA: hda/realtek - Add quirk for MSI GE63 laptop (bnc#1012628).
- ALSA: hda/realtek: Add mute LED and micmute LED support for
  HP systems (bnc#1012628).
- ACPI: sysfs: Fix pm_profile_attr type (bnc#1012628).
- ACPI: configfs: Disallow loading ACPI tables when locked down
  (bnc#1012628).
- erofs: fix partially uninitialized misuse in
  z_erofs_onlinepage_fixup (bnc#1012628).
- KVM: X86: Fix MSR range of APIC registers in X2APIC mode
  (bnc#1012628).
- kvm: lapic: fix broken vcpu hotplug (bnc#1012628).
- KVM: nVMX: Plumb L2 GPA through to PML emulation (bnc#1012628).
- KVM: VMX: Stop context switching MSR_IA32_UMWAIT_CONTROL
  (bnc#1012628).
- x86/cpu: Use pinning mask for CR4 bits needing to be 0
  (bnc#1012628).
- x86/cpu: Reinitialize IA32_FEAT_CTL MSR on BSP during wakeup
  (bnc#1012628).
- x86/asm/64: Align start of __clear_user() loop to 16-bytes
  (bnc#1012628).
- btrfs: fix bytes_may_use underflow when running balance and
  scrub in parallel (bnc#1012628).
- btrfs: fix data block group relocation failure due to concurrent
  scrub (bnc#1012628).
- btrfs: check if a log root exists before locking the log_mutex
  on unlink (bnc#1012628).
- btrfs: fix hang on snapshot creation after RWF_NOWAIT write
  (bnc#1012628).
- btrfs: fix failure of RWF_NOWAIT write into prealloc extent
  beyond eof (bnc#1012628).
- btrfs: fix RWF_NOWAIT write not failling when we need to cow
  (bnc#1012628).
- mm, compaction: make capture control handling safe wrt
  interrupts (bnc#1012628).
- mm, slab: fix sign conversion problem in memcg_uncharge_slab()
  (bnc#1012628).
- mm/slab: use memzero_explicit() in kzfree() (bnc#1012628).
- ocfs2: avoid inode removal while nfsd is accessing it
  (bnc#1012628).
- ocfs2: load global_inode_alloc (bnc#1012628).
- ocfs2: fix value of OCFS2_INVALID_SLOT (bnc#1012628).
- ocfs2: fix panic on nfs server over ocfs2 (bnc#1012628).
- mm: memcontrol: handle div0 crash race condition in memory.low
  (bnc#1012628).
- mm/memcontrol.c: add missed css_put() (bnc#1012628).
- mm/memory_hotplug.c: fix false softlockup during pfn range
  removal (bnc#1012628).
- arm64: perf: Report the PC value in REGS_ABI_32 mode
  (bnc#1012628).
- arm64: dts: imx8mm-evk: correct ldo1/ldo2 voltage range
  (bnc#1012628).
- arm64: dts: imx8mn-ddr4-evk: correct ldo1/ldo2 voltage range
  (bnc#1012628).
- tracing/boottime: Fix kprobe multiple events (bnc#1012628).
- tracing: Fix event trigger to accept redundant spaces
  (bnc#1012628).
- ring-buffer: Zero out time extend if it is nested and not
  absolute (bnc#1012628).
- drm/amd/display: Enable output_bpc property on all outputs
  (bnc#1012628).
- drm/amd: fix potential memleak in err branch (bnc#1012628).
- drm: rcar-du: Fix build error (bnc#1012628).
- drm/radeon: fix fb_div check in ni_init_smc_spll_table()
  (bnc#1012628).
- drm/fb-helper: Fix vt restore (bnc#1012628).
- drm/amdgpu: add fw release for sdma v5_0 (bnc#1012628).
- drm/amdgpu/display: Unlock mutex on error (bnc#1012628).
- drm/panel-simple: fix connector type for
  newhaven_nhd_43_480272ef_atxl (bnc#1012628).
- drm/panel-simple: fix connector type for LogicPD Type28 Display
  (bnc#1012628).
- ARM: dts: imx6ul-kontron: Move watchdog from Kontron i.MX6UL/ULL
  board to SoM (bnc#1012628).
- ARM: dts: imx6ul-kontron: Change WDOG_ANY signal from push-pull
  to open-drain (bnc#1012628).
- Staging: rtl8723bs: prevent buffer overflow in
  update_sta_support_rate() (bnc#1012628).
- powerpc/fsl_booke/32: Fix build with CONFIG_RANDOMIZE_BASE
  (bnc#1012628).
- sunrpc: fixed rollback in rpc_gssd_dummy_populate()
  (bnc#1012628).
- SUNRPC: Properly set the @subbuf parameter of
  xdr_buf_subsegment() (bnc#1012628).
- pNFS/flexfiles: Fix list corruption if the mirror count changes
  (bnc#1012628).
- NFSv4 fix CLOSE not waiting for direct IO compeletion
  (bnc#1012628).
- EDAC/amd64: Read back the scrub rate PCI register on F15h
  (bnc#1012628).
- xprtrdma: Fix handling of RDMA_ERROR replies (bnc#1012628).
- dm writecache: correct uncommitted_block when discarding
  uncommitted entry (bnc#1012628).
- dm writecache: add cond_resched to loop in
  persistent_memory_claim() (bnc#1012628).
- Delete
  patches.suse/syscalls-fix-offset-type-of-ksys_ftruncate.patch.
- commit cba119b
* Wed Jul  1 2020 rgoldwyn@suse.com
- Re-enable F2FS (boo#1173546)
  Since the changes of blacklisting landed)boo#1109665), we can re-enable
  F2FS for opensuse kernels. For SLE, it will land in
  kernel-default-extra
- commit 33443b2
* Wed Jul  1 2020 mkubecek@suse.cz
- Update
  patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch.
- we faked also CC_CAN_LINK_STATIC temporarily to work around the
  bpfilter_umh build breakage but that is no longer needed so we no longer
  need to pretend we can do static linkage on build
- refresh config files to reflect the change
- commit c06a44f
* Wed Jul  1 2020 mkubecek@suse.cz
- bpfilter: allow to build bpfilter_umh
  as a module without static library
  (http://lkml.kernel.org/r/20200608115628.osizkpo76cgn2ci7@lion.mk-sys.cz).
- Delete
  patches.rpmify/bpfilter-only-build-bpfilter_umh-as-static-when-BPFI.patch.
  Replace temporary version of the build fix with upstream submitted patch.
- commit 75906a0
* Wed Jul  1 2020 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: do not run klp-symbols for configs with no modules
  Starting with 5.8-rc1, s390x/zfcpdump builds fail because rpm/klp-symbols
  script does not find .tmp_versions directory. This is missing because
  s390x/zfcpdump is built without modules (CONFIG_MODULES disabled).
  As livepatching cannot work without modules, the cleanest solution is not
  setting %%klp_symbols if CONFIG_MODULES is disabled. To implement that, we
  need to move the block where %%klp_symbols is defined after the place where
  we set macros for config options.
- commit b5e55f7
* Wed Jul  1 2020 mkubecek@suse.cz
- Revert "fs: Do not check if there is
  a fsnotify watcher on pseudo inodes"
  (http://lkml.kernel.org/r/7b4aa1e985007c6d582fffe5e8435f8153e28e0f.camel@redhat.com).
- commit 45231d0
* Mon Jun 29 2020 jslaby@suse.cz
- Revert "ath9k: Fix general protection fault in
  ath9k_hif_usb_rx_cb" (bko#208251).
- commit 6ff0af7
* Mon Jun 29 2020 mkubecek@suse.cz
- Update to 5.8-rc3
- eliminated 2 patches
- refresh
  patches.suse/suse-hv-guest-os-id.patch
- update configs
  - EFI_CUSTOM_SSDT_OVERLAYS=y
- commit 162848a
* Fri Jun 26 2020 jslaby@suse.cz
- blacklist.conf: add one
- commit 1549350
* Fri Jun 26 2020 jslaby@suse.cz
- ALSA: usb-audio: Fixing usage of plain int instead of NULL
  (git-fixes).
- commit 9fcb4e6
* Fri Jun 26 2020 jslaby@suse.cz
- Revert "tty: hvc: Fix data abort due to race in hvc_open"
  (git-fixes).
- commit d5acd88
* Thu Jun 25 2020 jslaby@suse.cz
- Linux 5.7.6 (bnc#1012628).
- staging: wfx: fix potential deadlock in wfx_tx_flush()
  (bnc#1012628).
- power: supply: bq24257_charger: Replace depends on REGMAP_I2C
  with select (bnc#1012628).
- clk: sunxi: Fix incorrect usage of round_down() (bnc#1012628).
- ASoC: tegra: tegra_wm8903: Support nvidia, headset property
  (bnc#1012628).
- rtc: rc5t619: Fix an ERR_PTR vs NULL check (bnc#1012628).
- i2c: piix4: Detect secondary SMBus controller on AMD AM4
  chipsets (bnc#1012628).
- ASoC: SOF: imx8: Fix randbuild error (bnc#1012628).
- iio: pressure: bmp280: Tolerate IRQ before registering
  (bnc#1012628).
- remoteproc: Fix IDR initialisation in rproc_alloc()
  (bnc#1012628).
- clk: qcom: msm8916: Fix the address location of pll->config_reg
  (bnc#1012628).
- staging: wfx: check ssidlen and prevent an array overflow
  (bnc#1012628).
- ASoC: fsl_esai: Disable exception interrupt before scheduling
  tasklet (bnc#1012628).
- backlight: lp855x: Ensure regulators are disabled on probe
  failure (bnc#1012628).
- ARM: dts: renesas: Fix IOMMU device node names (bnc#1012628).
- ASoC: davinci-mcasp: Fix dma_chan refcnt leak when getting
  dma type (bnc#1012628).
- ARM: integrator: Add some Kconfig selections (bnc#1012628).
- ARM: dts: stm32: Add missing ethernet PHY reset on AV96
  (bnc#1012628).
- arm64: dts: renesas: Fix IOMMU device node names (bnc#1012628).
- ASoC: codecs: wm97xx: fix ac97 dependency (bnc#1012628).
- arm64: dts: meson-gxbb-kii-pro: fix board compatible
  (bnc#1012628).
- scsi: core: free sgtables in case command setup fails
  (bnc#1012628).
- scsi: qedi: Check for buffer overflow in qedi_set_path()
  (bnc#1012628).
- arm64: dts: meson: fixup SCP sram nodes (bnc#1012628).
- ALSA: hda/realtek - Introduce polarity for micmute LED GPIO
  (bnc#1012628).
- ALSA: isa/wavefront: prevent out of bounds write in ioctl
  (bnc#1012628).
- PCI: Allow pci_resize_resource() for devices on root bus
  (bnc#1012628).
- PCI: endpoint: functions/pci-epf-test: Fix DMA channel release
  (bnc#1012628).
- scsi: qla2xxx: Fix issue with adapter's stopping state
  (bnc#1012628).
- Input: edt-ft5x06 - fix get_default register write access
  (bnc#1012628).
- PCI: brcmstb: Fix window register offset from 4 to 8
  (bnc#1012628).
- powerpc/kasan: Fix stack overflow by increasing THREAD_SHIFT
  (bnc#1012628).
- rtc: mc13xxx: fix a double-unlock issue (bnc#1012628).
- iio: bmp280: fix compensation of humidity (bnc#1012628).
- f2fs: compress: let lz4 compressor handle output buffer budget
  properly (bnc#1012628).
- f2fs: report delalloc reserve as non-free in statfs for project
  quota (bnc#1012628).
- i2c: pxa: clear all master action bits in i2c_pxa_stop_message()
  (bnc#1012628).
- remoteproc: qcom_q6v5_mss: map/unmap mpss segments before/after
  use (bnc#1012628).
- clk: samsung: Mark top ISP and CAM clocks on Exynos542x as
  critical (bnc#1012628).
- staging: wfx: fix output of rx_stats on big endian hosts
  (bnc#1012628).
- usblp: poison URBs upon disconnect (bnc#1012628).
- usb: roles: Switch on role-switch uevent reporting
  (bnc#1012628).
- serial: 8250: Fix max baud limit in generic 8250 port
  (bnc#1012628).
- nvmem: ensure sysfs writes handle write-protect pin
  (bnc#1012628).
- misc: fastrpc: Fix an incomplete memory release in
  fastrpc_rpmsg_probe() (bnc#1012628).
- misc: fastrpc: fix potential fastrpc_invoke_ctx leak
  (bnc#1012628).
- dm mpath: switch paths in dm_blk_ioctl() code path
  (bnc#1012628).
- arm64: dts: armada-3720-turris-mox: forbid SDR104 on SDIO for
  FCC purposes (bnc#1012628).
- arm64: dts: armada-3720-turris-mox: fix SFP binding
  (bnc#1012628).
- arm64: dts: juno: Fix GIC child nodes (bnc#1012628).
- RDMA/uverbs: Fix create WQ to use the given user handle
  (bnc#1012628).
- RDMA/srpt: Fix disabling device management (bnc#1012628).
- pinctrl: ocelot: Fix GPIO interrupt decoding on Jaguar2
  (bnc#1012628).
- clk: renesas: cpg-mssr: Fix STBCR suspend/resume handling
  (bnc#1012628).
- ASoC: SOF: Do nothing when DSP PM callbacks are not set
  (bnc#1012628).
- arm64: dts: fvp: Fix GIC child nodes (bnc#1012628).
- PCI: aardvark: Don't blindly enable ASPM L0s and don't write
  to read-only register (bnc#1012628).
- ps3disk: use the default segment boundary (bnc#1012628).
- arm64: dts: fvp/juno: Fix node address fields (bnc#1012628).
- vfio/pci: fix memory leaks in alloc_perm_bits() (bnc#1012628).
- arm64: dts: qcom: sc7180: Correct the pdc interrupt ranges
  (bnc#1012628).
- coresight: tmc: Fix TMC mode read in tmc_read_prepare_etb()
  (bnc#1012628).
- RDMA/mlx5: Add init2init as a modify command (bnc#1012628).
- scsi: hisi_sas: Do not reset phy timer to wait for stray phy up
  (bnc#1012628).
- powerpc/book3s64/radix/tlb: Determine hugepage flush correctly
  (bnc#1012628).
- PCI: pci-bridge-emul: Fix PCIe bit conflicts (bnc#1012628).
- m68k/PCI: Fix a memory leak in an error handling path
  (bnc#1012628).
- habanalabs: don't allow hard reset with open processes
  (bnc#1012628).
- usb: cdns3: Fix runtime PM imbalance on error (bnc#1012628).
- gpio: dwapb: Call acpi_gpiochip_free_interrupts() on GPIO chip
  de-registration (bnc#1012628).
- usb: gadget: core: sync interrupt before unbind the udc
  (bnc#1012628).
- powerpc/ptdump: Add _PAGE_COHERENT flag (bnc#1012628).
- mfd: wm8994: Fix driver operation if loaded as modules
  (bnc#1012628).
- scsi: cxgb3i: Fix some leaks in init_act_open() (bnc#1012628).
- clk: zynqmp: fix memory leak in zynqmp_register_clocks
  (bnc#1012628).
- scsi: lpfc: Fix lpfc_nodelist leak when processing unsolicited
  event (bnc#1012628).
- scsi: vhost: Notify TCM about the maximum sg entries supported
  per command (bnc#1012628).
- clk: clk-flexgen: fix clock-critical handling (bnc#1012628).
- IB/mlx5: Fix DEVX support for MLX5_CMD_OP_INIT2INIT_QP command
  (bnc#1012628).
- powerpc/perf/hv-24x7: Fix inconsistent output values incase
  multiple hv-24x7 events run (bnc#1012628).
- nfsd: Fix svc_xprt refcnt leak when setup callback client failed
  (bnc#1012628).
- PCI: vmd: Filter resource type bits from shadow register
  (bnc#1012628).
- RDMA/core: Fix several reference count leaks (bnc#1012628).
- cifs: set up next DFS target before generic_ip_connect()
  (bnc#1012628).
- ASoC: qcom: q6asm-dai: kCFI fix (bnc#1012628).
- powerpc/crashkernel: Take "mem=" option into account
  (bnc#1012628).
- pwm: img: Call pm_runtime_put() in pm_runtime_get_sync()
  failed case (bnc#1012628).
- sparc32: mm: Don't try to free page-table pages if ctor()
  fails (bnc#1012628).
- clk: sprd: fix compile-testing (bnc#1012628).
- drm/nouveau: gr/gk20a: Use firmware version 0 (bnc#1012628).
- crypto: omap-sham - huge buffer access fixes (bnc#1012628).
- yam: fix possible memory leak in yam_init_driver (bnc#1012628).
- net: mdiobus: Disable preemption upon u64_stats update
  (bnc#1012628).
- ASoC: meson: fix memory leak of links if allocation of ldata
  fails (bnc#1012628).
- NTB: ntb_pingpong: Choose doorbells based on port number
  (bnc#1012628).
- NTB: Fix the default port and peer numbers for legacy drivers
  (bnc#1012628).
- mksysmap: Fix the mismatch of '.L' symbols in System.map
  (bnc#1012628).
- apparmor: fix introspection of of task mode for unconfined tasks
  (bnc#1012628).
- net: dsa: lantiq_gswip: fix and improve the unsupported
  interface error (bnc#1012628).
- apparmor: check/put label on apparmor_sk_clone_security()
  (bnc#1012628).
- f2fs: handle readonly filesystem in f2fs_ioc_shutdown()
  (bnc#1012628).
- xfs: Add the missed xfs_perag_put() for xfs_ifree_cluster()
  (bnc#1012628).
- ASoC: meson: add missing free_irq() in error path (bnc#1012628).
- bpf, sockhash: Fix memory leak when unlinking sockets in
  sock_hash_free (bnc#1012628).
- scsi: sr: Fix sr_probe() missing mutex_destroy (bnc#1012628).
- scsi: sr: Fix sr_probe() missing deallocate of device minor
  (bnc#1012628).
- scsi: ibmvscsi: Don't send host info in adapter info MAD after
  LPM (bnc#1012628).
- media: s5p-mfc: Properly handle dma_parms for the allocated
  devices (bnc#1012628).
- media: v4l2-ctrls: Unset correct HEVC loop filter flag
  (bnc#1012628).
- ibmvnic: Flush existing work items before device removal
  (bnc#1012628).
- bpf: tcp: Recv() should return 0 when the peer socket is closed
  (bnc#1012628).
- apparmor: fix nnp subset test for unconfined (bnc#1012628).
- x86/purgatory: Disable various profiling and sanitizing options
  (bnc#1012628).
- ARM: dts: bcm283x: Use firmware PM driver for V3D (bnc#1012628).
- arm64: dts: realtek: rtd129x: Fix GIC CPU masks for RTD1293
  (bnc#1012628).
- staging: greybus: fix a missing-check bug in
  gb_lights_light_config() (bnc#1012628).
- staging: mt7621-pci: fix PCIe interrupt mapping (bnc#1012628).
- arm64: dts: mt8173: fix unit name warnings (bnc#1012628).
- scsi: qedi: Do not flush offload work if ARP not resolved
  (bnc#1012628).
- arm64: dts: qcom: msm8916: remove unit name for thermal trip
  points (bnc#1012628).
- ARM: dts: sun8i-h2-plus-bananapi-m2-zero: Fix led polarity
  (bnc#1012628).
- RDMA/mlx5: Fix udata response upon SRQ creation (bnc#1012628).
- ALSA: usb-audio: RME Babyface Pro mixer patch (bnc#1012628).
- gpio: dwapb: Append MODULE_ALIAS for platform driver
  (bnc#1012628).
- scsi: qedf: Fix crash when MFW calls for protocol stats while
  function is still probing (bnc#1012628).
- iio: buffer-dmaengine: use %%zu specifier for sprintf(align)
  (bnc#1012628).
- pinctrl: rza1: Fix wrong array assignment of rza1l_swio_entries
  (bnc#1012628).
- virtiofs: schedule blocking async replies in separate worker
  (bnc#1012628).
- fuse: BUG_ON correction in fuse_dev_splice_write()
  (bnc#1012628).
- arm64: dts: qcom: fix pm8150 gpio interrupts (bnc#1012628).
- firmware: qcom_scm: fix bogous abuse of dma-direct internals
  (bnc#1012628).
- arm64: dts: qcom: sm8250: Fix PDC compatible and reg
  (bnc#1012628).
- staging: gasket: Fix mapping refcnt leak when put attribute
  fails (bnc#1012628).
- staging: gasket: Fix mapping refcnt leak when register/store
  fails (bnc#1012628).
- ALSA: usb-audio: Improve frames size computation (bnc#1012628).
- ALSA: usb-audio: Fix racy list management in output queue
  (bnc#1012628).
- s390/qdio: consistently restore the IRQ handler (bnc#1012628).
- s390/qdio: tear down thinint indicator after early error
  (bnc#1012628).
- s390/qdio: put thinint indicator after early error
  (bnc#1012628).
- staging: wfx: fix overflow in frame counters (bnc#1012628).
- staging: wfx: fix double init of tx_policy_upload_work
  (bnc#1012628).
- tty: hvc: Fix data abort due to race in hvc_open (bnc#1012628).
- slimbus: ngd: get drvdata from correct device (bnc#1012628).
- gpio: mlxbf2: fix return value check in
  mlxbf2_gpio_get_lock_res() (bnc#1012628).
- of: property: Fix create device links for all child-supplier
  dependencies (bnc#1012628).
- of: property: Do not link to disabled devices (bnc#1012628).
- clk: meson: meson8b: Fix the first parent of vid_pll_in_sel
  (bnc#1012628).
- clk: meson: meson8b: Fix the polarity of the RESET_N lines
  (bnc#1012628).
- clk: meson: meson8b: Fix the vclk_div{1, 2, 4, 6, 12}_en gate
  bits (bnc#1012628).
- gpio: pca953x: fix handling of automatic address incrementing
  (bnc#1012628).
- ASoC: component: suppress uninitialized-variable warning
  (bnc#1012628).
- thermal/drivers/ti-soc-thermal: Avoid dereferencing ERR_PTR
  (bnc#1012628).
- ASoC: rt5682: fix I2C/Soundwire dependencies (bnc#1012628).
- arm64: dts: meson-g12b-ugoos-am6: fix board compatible
  (bnc#1012628).
- arm64: dts: meson: fix leds subnodes name (bnc#1012628).
- ASoC: SOF: Update correct LED status at the first time usage
  of update_mute_led() (bnc#1012628).
- clk: meson: meson8b: Don't rely on u-boot to init all GP_PLL
  registers (bnc#1012628).
- ASoC: max98373: reorder max98373_reset() in resume
  (bnc#1012628).
- soundwire: slave: don't init debugfs on device registration
  error (bnc#1012628).
- ARM: dts: aspeed: ast2600: Set arch timer always-on
  (bnc#1012628).
- ARM: dts: aspeed: Change KCS nodes to v2 binding (bnc#1012628).
- HID: intel-ish-hid: avoid bogus uninitialized-variable warning
  (bnc#1012628).
- usb: dwc3: gadget: Properly handle ClearFeature(halt)
  (bnc#1012628).
- usb: dwc3: meson-g12a: check return of dwc3_meson_g12a_usb_init
  (bnc#1012628).
- usb: dwc3: gadget: Properly handle failed kick_transfer
  (bnc#1012628).
- staging: wilc1000: Increase the size of wid_list array
  (bnc#1012628).
- staging: sm750fb: add missing case while setting FB_VISUAL
  (bnc#1012628).
- staging: wfx: avoid compiler warning on empty array
  (bnc#1012628).
- PCI: v3-semi: Fix a memory leak in v3_pci_probe() error handling
  paths (bnc#1012628).
- i2c: pxa: fix i2c_pxa_scream_blue_murder() debug output
  (bnc#1012628).
- drivers: base: Fix NULL pointer exception in
  __platform_driver_probe() if a driver developer is foolish
  (bnc#1012628).
- PCI: rcar: Fix incorrect programming of OB windows
  (bnc#1012628).
- PCI/ASPM: Allow ASPM on links to PCIe-to-PCI/PCI-X Bridges
  (bnc#1012628).
- scsi: qla2xxx: Fix warning after FC target reset (bnc#1012628).
- ALSA: firewire-lib: fix invalid assignment to union data for
  directional parameter (bnc#1012628).
- power: supply: lp8788: Fix an error handling path in
  'lp8788_charger_probe()' (bnc#1012628).
- power: supply: smb347-charger: IRQSTAT_D is volatile
  (bnc#1012628).
- PCI: brcmstb: Assert fundamental reset on initialization
  (bnc#1012628).
- ASoC: SOF: core: fix error return code in sof_probe_continue()
  (bnc#1012628).
- remoteproc/mediatek: fix invalid use of sizeof in scp_ipi_init()
  (bnc#1012628).
- arm64: dts: msm8996: Fix CSI IRQ types (bnc#1012628).
- scsi: target: loopback: Fix READ with data and sensebytes
  (bnc#1012628).
- scsi: mpt3sas: Fix double free warnings (bnc#1012628).
- f2fs: Fix wrong stub helper update_sit_info (bnc#1012628).
- f2fs: fix potential use-after-free issue (bnc#1012628).
- f2fs: compress: fix zstd data corruption (bnc#1012628).
- um: do not evaluate compiler's library path when cleaning
  (bnc#1012628).
- unicore32: do not evaluate compiler's library path when cleaning
  (bnc#1012628).
- SoC: rsnd: add interrupt support for SSI BUSIF buffer
  (bnc#1012628).
- ASoC: ux500: mop500: Fix some refcounted resources issues
  (bnc#1012628).
- ASoC: ti: omap-mcbsp: Fix an error handling path in
  'asoc_mcbsp_probe()' (bnc#1012628).
- pinctrl: rockchip: fix memleak in rockchip_dt_node_to_map
  (bnc#1012628).
- remoteproc: qcom_q6v5_mss: Drop accesses to MPSS PERPH register
  space (bnc#1012628).
- dlm: remove BUG() before panic() (bnc#1012628).
- phy: ti: j721e-wiz: Fix some error return code in wiz_probe()
  (bnc#1012628).
- USB: ohci-sm501: fix error return code in
  ohci_hcd_sm501_drv_probe() (bnc#1012628).
- arm64: dts: qcom: db820c: Fix invalid pm8994 supplies
  (bnc#1012628).
- arm64: dts: qcom: c630: Add WiFi node (bnc#1012628).
- clk: ti: composite: fix memory leak (bnc#1012628).
- PCI: Fix pci_register_host_bridge() device_register() error
  handling (bnc#1012628).
- powerpc/64: Don't initialise init_task->thread.regs
  (bnc#1012628).
- tty: n_gsm: Fix SOF skipping (bnc#1012628).
- tty: n_gsm: Fix waking up upper tty layer when room available
  (bnc#1012628).
- staging: wfx: fix value of scan timeout (bnc#1012628).
- ALSA: usb-audio: fixing upper volume limit for RME Babyface
  Pro routing crosspoints (bnc#1012628).
- ALSA: usb-audio: Add duplex sound support for USB devices
  using implicit feedback (bnc#1012628).
- HID: Add quirks for Trust Panora Graphic Tablet (bnc#1012628).
- PCI/PM: Assume ports without DLL Link Active train links in
  100 ms (bnc#1012628).
- habanalabs: increase timeout during reset (bnc#1012628).
- arm64: dts: marvell: armada-37xx: Set pcie_reset_pin to gpio
  function (bnc#1012628).
- pinctrl: ocelot: Always register GPIO driver (bnc#1012628).
- ipmi: use vzalloc instead of kmalloc for user creation
  (bnc#1012628).
- ASoC: codecs: rt*-sdw: fix memory leak in set_sdw_stream()
  (bnc#1012628).
- powerpc/64s/exception: Fix machine check no-loss idle wakeup
  (bnc#1012628).
- powerpc/64s/exceptions: Machine check reconcile irq state
  (bnc#1012628).
- powerpc/pseries/ras: Fix FWNMI_VALID off by one (bnc#1012628).
- PCI: aardvark: Train link immediately after enabling training
  (bnc#1012628).
- PCI: aardvark: Improve link training (bnc#1012628).
- PCI: aardvark: Issue PERST via GPIO (bnc#1012628).
- drivers: phy: sr-usb: do not use internal fsm for USB2 phy init
  (bnc#1012628).
- phy: cadence: sierra: Fix for USB3 U1/U2 state (bnc#1012628).
- powerpc/ps3: Fix kexec shutdown hang (bnc#1012628).
- iommu/arm-smmu-v3: Don't reserve implementation defined register
  space (bnc#1012628).
- vfio-pci: Mask cap zero (bnc#1012628).
- usb/ohci-platform: Fix a warning when hibernating (bnc#1012628).
- drm/msm: Fix undefined "rd_full" link error (bnc#1012628).
- drm/msm/mdp5: Fix mdp5_init error path for failed mdp5_kms
  allocation (bnc#1012628).
- ASoC: Intel: bytcr_rt5640: Add quirk for Toshiba Encore WT8-A
  tablet (bnc#1012628).
- USB: host: ehci-mxc: Add error handling in ehci_mxc_drv_probe()
  (bnc#1012628).
- tty: n_gsm: Fix bogus i++ in gsm_data_kick (bnc#1012628).
- coresight: Fix support for sparsely populated ports
  (bnc#1012628).
- coresight: etm4x: Fix use-after-free of per-cpu etm drvdata
  (bnc#1012628).
- fpga: dfl: afu: Corrected error handling levels (bnc#1012628).
- clk: samsung: exynos5433: Add IGNORE_UNUSED flag to sclk_i2s1
  (bnc#1012628).
- RDMA/hns: Bugfix for querying qkey (bnc#1012628).
- RDMA/hns: Fix cmdq parameter of querying pf timer resource
  (bnc#1012628).
- scsi: target: tcmu: Userspace must not complete queued commands
  (bnc#1012628).
- scsi: core: Fix incorrect usage of shost_for_each_device
  (bnc#1012628).
- firmware: imx: scu: Fix possible memory leak in imx_scu_probe()
  (bnc#1012628).
- fuse: fix copy_file_range cache issues (bnc#1012628).
- fuse: copy_file_range should truncate cache (bnc#1012628).
- arm64: tegra: Fix ethernet phy-mode for Jetson Xavier
  (bnc#1012628).
- arm64: tegra: Fix flag for 64-bit resources in 'ranges' property
  (bnc#1012628).
- powerpc/powernv: add NULL check after kzalloc (bnc#1012628).
- powerpc/64s/pgtable: fix an undefined behaviour (bnc#1012628).
- powerpc/kasan: Fix error detection on memory allocation
  (bnc#1012628).
- dm zoned: return NULL if dmz_get_zone_for_reclaim() fails to
  find a zone (bnc#1012628).
- RDMA/efa: Fix setting of wrong bit in get/set_feature commands
  (bnc#1012628).
- xen/cpuhotplug: Fix initial CPU offlining for PV(H) guests
  (bnc#1012628).
- PCI/PTM: Inherit Switch Downstream Port PTM settings from
  Upstream Port (bnc#1012628).
- bus: mhi: core: Read transfer length from an event properly
  (bnc#1012628).
- PCI: dwc: pci-dra7xx: Use
  devm_platform_ioremap_resource_byname() (bnc#1012628).
- PCI: dwc: Fix inner MSI IRQ domain registration (bnc#1012628).
- PCI: amlogic: meson: Don't use FAST_LINK_MODE to set up link
  (bnc#1012628).
- iio: light: gp2ap002: Take runtime PM reference on light read
  (bnc#1012628).
- IB/cma: Fix ports memory leak in cma_configfs (bnc#1012628).
- selftests/timens: handle a case when alarm clocks are not
  supported (bnc#1012628).
- watchdog: da9062: No need to ping manually before setting
  timeout (bnc#1012628).
- usb: dwc2: gadget: move gadget resume after the core is in L0
  state (bnc#1012628).
- USB: gadget: udc: s3c2410_udc: Remove pointless NULL check in
  s3c2410_udc_nuke (bnc#1012628).
- usb: gadget: lpc32xx_udc: don't dereference ep pointer before
  null check (bnc#1012628).
- usb: gadget: fix potential double-free in m66592_probe
  (bnc#1012628).
- usb: gadget: Fix issue with config_ep_by_speed function
  (bnc#1012628).
- pinctrl: Fix return value about devm_platform_ioremap_resource()
  (bnc#1012628).
- scripts: headers_install: Exit with error on config leak
  (bnc#1012628).
- RDMA/iw_cxgb4: cleanup device debugfs entries on ULD remove
  (bnc#1012628).
- x86/apic: Make TSC deadline timer detection message visible
  (bnc#1012628).
- mfd: stmfx: Reset chip on resume as supply was disabled
  (bnc#1012628).
- mfd: stmfx: Fix stmfx_irq_init error path (bnc#1012628).
- mfd: stmfx: Disable IRQ in suspend to avoid spurious interrupt
  (bnc#1012628).
- mfd: wcd934x: Drop kfree for memory allocated with devm_kzalloc
  (bnc#1012628).
- powerpc/32s: Don't warn when mapping RO data ROX (bnc#1012628).
- powerpc/8xx: Drop CONFIG_8xx_COPYBACK option (bnc#1012628).
- ASoC: fix incomplete error-handling in img_i2s_in_probe
  (bnc#1012628).
- scsi: target: tcmu: Fix a use after free in
  tcmu_check_expired_queue_cmd() (bnc#1012628).
- clk: bcm2835: Fix return type of bcm2835_register_gate
  (bnc#1012628).
- scsi: ufs-qcom: Fix scheduling while atomic issue (bnc#1012628).
- clk: zynqmp: Fix divider2 calculation (bnc#1012628).
- scsi: iscsi: Fix deadlock on recovery path during GFP_IO reclaim
  (bnc#1012628).
- scsi: ufs: ti-j721e-ufs: Fix unwinding of pm_runtime changes
  (bnc#1012628).
- KVM: PPC: Book3S HV: Ignore kmemleak false positives
  (bnc#1012628).
- KVM: PPC: Book3S: Fix some RCU-list locks (bnc#1012628).
- KVM: PPC: Book3S HV: Relax check on H_SVM_INIT_ABORT
  (bnc#1012628).
- clk: sprd: return correct type of value for
  _sprd_pll_recalc_rate (bnc#1012628).
- clk: ast2600: Fix AHB clock divider for A1 (bnc#1012628).
- misc: xilinx-sdfec: improve get_user_pages_fast() error handling
  (bnc#1012628).
- /dev/mem: Revoke mappings when a driver claims the region
  (bnc#1012628).
- ASoC: dapm: Move dai_link widgets to runtime to fix use after
  free (bnc#1012628).
- net: sunrpc: Fix off-by-one issues in 'rpc_ntop6' (bnc#1012628).
- NFSv4.1 fix rpc_call_done assignment for BIND_CONN_TO_SESSION
  (bnc#1012628).
- of: Fix a refcounting bug in __of_attach_node_sysfs()
  (bnc#1012628).
- ARM: davinci: fix build failure without I2C (bnc#1012628).
- input: i8042 - Remove special PowerPC handling (bnc#1012628).
- powerpc/4xx: Don't unmap NULL mbase (bnc#1012628).
- powerpc/64s/kuap: Add missing isync to KUAP restore paths
  (bnc#1012628).
- extcon: adc-jack: Fix an error handling path in
  'adc_jack_probe()' (bnc#1012628).
- usb: dwc3: meson-g12a: fix error path when fetching the reset
  line fails (bnc#1012628).
- ASoC: fsl_asrc_dma: Fix dma_chan leak when config DMA channel
  failed (bnc#1012628).
- ASoC: SOF: Intel: hda: fix generic hda codec support
  (bnc#1012628).
- vfio/mdev: Fix reference count leak in add_mdev_supported_type
  (bnc#1012628).
- rtc: rv3028: Add missed check for devm_regmap_init_i2c()
  (bnc#1012628).
- mailbox: imx: Fix return in imx_mu_scu_xlate() (bnc#1012628).
- mailbox: zynqmp-ipi: Fix NULL vs IS_ERR() check in
  zynqmp_ipi_mbox_probe() (bnc#1012628).
- rxrpc: Adjust /proc/net/rxrpc/calls to display call->debug_id
  not user_ID (bnc#1012628).
- openrisc: Fix issue with argument clobbering for clone/fork
  (bnc#1012628).
- drm/nouveau/disp/gm200-: fix NV_PDISP_SOR_HDMI2_CTRL(n)
  selection (bnc#1012628).
- ceph: don't return -ESTALE if there's still an open file
  (bnc#1012628).
- nfsd4: make drc_slab global, not per-net (bnc#1012628).
- pwm: imx27: Fix rounding behavior (bnc#1012628).
- gfs2: Allow lock_nolock mount to specify jid=X (bnc#1012628).
- scsi: iscsi: Fix reference count leak in iscsi_boot_create_kobj
  (bnc#1012628).
- scsi: ufs: Don't update urgent bkops level when toggling auto
  bkops (bnc#1012628).
- modpost: fix -i (--ignore-errors) MAKEFLAGS detection
  (bnc#1012628).
- pinctrl: imxl: Fix an error handling path in
  'imx1_pinctrl_core_probe()' (bnc#1012628).
- pinctrl: sirf: add missing put_device() call in
  sirfsoc_gpio_probe() (bnc#1012628).
- pinctrl: freescale: imx: Fix an error handling path in
  'imx_pinctrl_probe()' (bnc#1012628).
- nfsd: safer handling of corrupted c_type (bnc#1012628).
- RDMA/cm: Spurious WARNING triggered in cm_destroy_id()
  (bnc#1012628).
- drm/amd/display: Revalidate bandwidth before commiting DC
  updates (bnc#1012628).
- ext4: handle ext4_mark_inode_dirty errors (bnc#1012628).
- ext4: don't block for O_DIRECT if IOCB_NOWAIT is set
  (bnc#1012628).
- crypto: omap-sham - add proper load balancing support for
  multicore (bnc#1012628).
- pwm: Add missing "CONFIG_" prefix (bnc#1012628).
- bpf: Fix an error code in check_btf_func() (bnc#1012628).
- geneve: change from tx_error to tx_dropped on missing metadata
  (bnc#1012628).
- lib/zlib: remove outdated and incorrect pre-increment
  optimization (bnc#1012628).
- include/linux/bitops.h: avoid clang shift-count-overflow
  warnings (bnc#1012628).
- selftests/vm/pkeys: fix alloc_random_pkey() to make it really
  random (bnc#1012628).
- blktrace: use errno instead of bi_status (bnc#1012628).
- blktrace: fix endianness in get_pdu_int() (bnc#1012628).
- blktrace: fix endianness for blk_log_remap() (bnc#1012628).
- KVM: selftests: Fix build with "make ARCH=x86_64" (bnc#1012628).
- gfs2: fix use-after-free on transaction ail lists (bnc#1012628).
- net: dp83867: Fix OF_MDIO config check (bnc#1012628).
- net: marvell: Fix OF_MDIO config check (bnc#1012628).
- net: mscc: Fix OF_MDIO config check (bnc#1012628).
- ntb_perf: pass correct struct device to dma_alloc_coherent
  (bnc#1012628).
- ntb_tool: pass correct struct device to dma_alloc_coherent
  (bnc#1012628).
- NTB: ntb_tool: reading the link file should not end in a NULL
  byte (bnc#1012628).
- NTB: Revert the change to use the NTB device dev for DMA
  allocations (bnc#1012628).
- NTB: perf: Don't require one more memory window than number
  of peers (bnc#1012628).
- NTB: perf: Fix support for hardware that doesn't have port
  numbers (bnc#1012628).
- NTB: perf: Fix race condition when run with ntb_test
  (bnc#1012628).
- NTB: ntb_test: Fix bug when counting remote files (bnc#1012628).
- i2c: icy: Fix build with CONFIG_AMIGA_PCMCIA=n (bnc#1012628).
- mailbox: imx: Add context save/restore for suspend/resume
  (bnc#1012628).
- arm64: ftrace: Change CONFIG_FTRACE_WITH_REGS to
  CONFIG_DYNAMIC_FTRACE_WITH_REGS (bnc#1012628).
- drivers/perf: hisi: Fix wrong value for all counters enable
  (bnc#1012628).
- selftests/net: in timestamping, strncpy needs to preserve null
  byte (bnc#1012628).
- f2fs: don't return vmalloc() memory from f2fs_kmalloc()
  (bnc#1012628).
- afs: Fix memory leak in afs_put_sysnames() (bnc#1012628).
- ASoC: soc-pcm: dpcm: fix playback/capture checks (bnc#1012628).
- ASoC: core: only convert non DPCM link to DPCM link
  (bnc#1012628).
- ASoC: SOF: nocodec: conditionally set dpcm_capture/dpcm_playback
  flags (bnc#1012628).
- ASoC: Intel: bytcr_rt5640: Add quirk for Toshiba Encore WT10-A
  tablet (bnc#1012628).
- ASoC: rt5645: Add platform-data for Asus T101HA (bnc#1012628).
- bpf/sockmap: Fix kernel panic at __tcp_bpf_recvmsg
  (bnc#1012628).
- bpf, sockhash: Synchronize delete from bucket list on map free
  (bnc#1012628).
- tracing/probe: Fix bpf_task_fd_query() for kprobes and uprobes
  (bnc#1012628).
- drm/sun4i: hdmi ddc clk: Fix size of m divider (bnc#1012628).
- libbpf: Handle GCC noreturn-turned-volatile quirk (bnc#1012628).
- scsi: acornscsi: Fix an error handling path in acornscsi_probe()
  (bnc#1012628).
- drm/ast: fix missing break in switch statement for
  format->cpp[0] case 4 (bnc#1012628).
- x86/idt: Keep spurious entries unset in system_vectors
  (bnc#1012628).
- x86/mce/dev-mcelog: Fix -Wstringop-truncation warning about
  strncpy() (bnc#1012628).
- net/filter: Permit reading NET in load_bytes_relative when
  MAC not set (bnc#1012628).
- tools, bpftool: Fix memory leak in codegen error cases
  (bnc#1012628).
- nvme-fc: don't call nvme_cleanup_cmd() for AENs (bnc#1012628).
- nvme-pci: use simple suspend when a HMB is enabled
  (bnc#1012628).
- nfs: set invalid blocks after NFSv4 writes (bnc#1012628).
- NFS: Fix direct WRITE throughput regression (bnc#1012628).
- xdp: Fix xsk_generic_xmit errno (bnc#1012628).
- iavf: fix speed reporting over virtchnl (bnc#1012628).
- net: ipa: program upper nibbles of sequencer type (bnc#1012628).
- bpf: sockmap: Don't attach programs to UDP sockets
  (bnc#1012628).
- bpf: Fix memlock accounting for sock_hash (bnc#1012628).
- libbpf: Support pre-initializing .bss global variables
  (bnc#1012628).
- bpf: Undo internal BPF_PROBE_MEM in BPF insns dump
  (bnc#1012628).
- usb/xhci-plat: Set PM runtime as active on resume (bnc#1012628).
- usb/ehci-platform: Set PM runtime as active on resume
  (bnc#1012628).
- perf report: Fix NULL pointer dereference in
  hists__fprintf_nr_sample_events() (bnc#1012628).
- perf stat: Fix NULL pointer dereference (bnc#1012628).
- perf probe: Fix user attribute access in kprobes (bnc#1012628).
- perf parse-events: Fix an incompatible pointer (bnc#1012628).
- ext4: stop overwrite the errcode in ext4_setup_super
  (bnc#1012628).
- bcache: fix potential deadlock problem in btree_gc_coalesce
  (bnc#1012628).
- crypto: hisilicon - Cap block size at 2^31 (bnc#1012628).
- crypto: marvell/octeontx - Fix a potential NULL dereference
  (bnc#1012628).
- powerpc: Fix kernel crash in show_instructions() w/DEBUG_VIRTUAL
  (bnc#1012628).
- afs: Fix non-setting of mtime when writing into mmap
  (bnc#1012628).
- afs: afs_write_end() should change i_size under the right lock
  (bnc#1012628).
- afs: Fix EOF corruption (bnc#1012628).
- afs: Always include dir in bulk status fetch from
  afs_do_lookup() (bnc#1012628).
- afs: Set error flag rather than return error from file status
  decode (bnc#1012628).
- afs: Remove the error argument from afs_protocol_error()
  (bnc#1012628).
- afs: Fix the mapping of the UAEOVERFLOW abort code
  (bnc#1012628).
- bnxt_en: Simplify bnxt_resume() (bnc#1012628).
- bnxt_en: Re-enable SRIOV during resume (bnc#1012628).
- bnxt_en: Fix AER reset logic on 57500 chips (bnc#1012628).
- bnxt_en: Return from timer if interface is not in open state
  (bnc#1012628).
- net: dsa: sja1105: fix PTP timestamping with large tc-taprio
  cycles (bnc#1012628).
- scsi: ufs-bsg: Fix runtime PM imbalance on error (bnc#1012628).
- s390/numa: let NODES_SHIFT depend on NEED_MULTIPLE_NODES
  (bnc#1012628).
- block: Fix use-after-free in blkdev_get() (bnc#1012628).
- mvpp2: remove module bugfix (bnc#1012628).
- bareudp: Fixed configuration to avoid having garbage values
  (bnc#1012628).
- mlxsw: spectrum: Adjust headroom buffers for 8x ports
  (bnc#1012628).
- arm64: mm: reserve hugetlb CMA after numa_init (bnc#1012628).
- arm64: hw_breakpoint: Don't invoke overflow handler on uaccess
  watchpoints (bnc#1012628).
- libata: Use per port sync for detach (bnc#1012628).
- drm: encoder_slave: fix refcouting error for modules
  (bnc#1012628).
- pinctrl: qcom: ipq6018 Add missing pins in qpic pin group
  (bnc#1012628).
- ext4: fix partial cluster initialization when splitting extent
  (bnc#1012628).
- ext4: avoid utf8_strncasecmp() with unstable name (bnc#1012628).
- ext4, jbd2: ensure panic by fix a race between jbd2 abort and
  ext4 error handlers (bnc#1012628).
- arm64: dts: realtek: rtd129x: Use reserved-memory for RPC
  regions (bnc#1012628).
- arm64: dts: realtek: rtd129x: Carve out boot ROM from memory
  (bnc#1012628).
- sh: Convert iounmap() macros to inline functions (bnc#1012628).
- drm/dp_mst: Reformat drm_dp_check_act_status() a bit
  (bnc#1012628).
- drm/qxl: Use correct notify port address when creating cursor
  ring (bnc#1012628).
- drm/amdgpu/display: use blanked rather than plane state for
  sync groups (bnc#1012628).
- drm/amdgpu: Replace invalid device ID with a valid device ID
  (bnc#1012628).
- selinux: fix double free (bnc#1012628).
- selinux: fix a double free in cond_read_node()/cond_read_list()
  (bnc#1012628).
- selinux: fix undefined return of cond_evaluate_expr
  (bnc#1012628).
- drm/ast: Don't check new mode if CRTC is being disabled
  (bnc#1012628).
- io_uring: fix io_kiocb.flags modification race in IOPOLL mode
  (bnc#1012628).
- io_uring: don't fail links for EAGAIN error in IOPOLL mode
  (bnc#1012628).
- io_uring: add memory barrier to synchronize io_kiocb's result
  and iopoll_completed (bnc#1012628).
- io_uring: acquire 'mm' for task_work for SQPOLL (bnc#1012628).
- io_uring: reap poll completions while waiting for refs to drop
  on exit (bnc#1012628).
- io_uring: fix possible race condition against REQ_F_NEED_CLEANUP
  (bnc#1012628).
- ext4: avoid race conditions when remounting with options that
  change dax (bnc#1012628).
- drm/dp_mst: Increase ACT retry timeout to 3s (bnc#1012628).
- net/mlx5: DR, Fix freeing in dr_create_rc_qp() (bnc#1012628).
- f2fs: split f2fs_d_compare() from f2fs_match_name()
  (bnc#1012628).
- f2fs: avoid utf8_strncasecmp() with unstable name (bnc#1012628).
- s390: fix syscall_get_error for compat processes (bnc#1012628).
- drm/i915: Fix AUX power domain toggling across TypeC mode resets
  (bnc#1012628).
- drm/msm: Check for powered down HW in the devfreq callbacks
  (bnc#1012628).
- drm/i915/gem: Avoid iterating an empty list (bnc#1012628).
- drm/i915: Whitelist context-local timestamp in the gen9
  cmdparser (bnc#1012628).
- drm/connector: notify userspace on hotplug after register
  complete (bnc#1012628).
- drm/amdkfd: Use correct major in devcgroup check (bnc#1012628).
- drm/amd/display: Use kvfree() to free coeff in build_regamma()
  (bnc#1012628).
- drm/i915/icl+: Fix hotplug interrupt disabling after storm
  detection (bnc#1012628).
- drm/i915/tc: fix the reset of ln0 (bnc#1012628).
- drm/i915/gt: Incrementally check for rewinding (bnc#1012628).
- drm/i915/gt: Move hsw GT workarounds from init_clock_gating
  to workarounds (bnc#1012628).
- drm/i915/gt: Move ivb GT workarounds from init_clock_gating
  to workarounds (bnc#1012628).
- drm/i915/gt: Move snb GT workarounds from init_clock_gating
  to workarounds (bnc#1012628).
- drm/i915/gt: Move ilk GT workarounds from init_clock_gating
  to workarounds (bnc#1012628).
- drm/i915/gt: Move vlv GT workarounds from init_clock_gating
  to workarounds (bnc#1012628).
- drm/i915/gt: Move gen4 GT workarounds from init_clock_gating
  to workarounds (bnc#1012628).
- Revert "drm/amd/display: disable dcn20 abm feature for bring up"
  (bnc#1012628).
- drm/i915/tgl: Make Wa_14010229206 permanent (bnc#1012628).
- crypto: algif_skcipher - Cap recv SG list at ctx->used
  (bnc#1012628).
- crypto: algboss - don't wait during notifier callback
  (bnc#1012628).
- tracing: Make ftrace packed events have align of 1
  (bnc#1012628).
- tracing/probe: Fix memleak in fetch_op_data operations
  (bnc#1012628).
- proc/bootconfig: Fix to use correct quotes for value
  (bnc#1012628).
- tools/bootconfig: Fix to use correct quotes for value
  (bnc#1012628).
- tools/bootconfig: Fix to return 0 if succeeded to show the
  bootconfig (bnc#1012628).
- sample-trace-array: Remove trace_array 'sample-instance'
  (bnc#1012628).
- sample-trace-array: Fix sleeping function called from invalid
  context (bnc#1012628).
- netfilter: nft_set_rbtree: Don't account for expired elements
  on insertion (bnc#1012628).
- netfilter: nft_set_pipapo: Disable preemption before getting
  per-CPU pointer (bnc#1012628).
- kprobes: Fix to protect kick_kprobe_optimizer() by kprobe_mutex
  (bnc#1012628).
- kretprobe: Prevent triggering kretprobe from within
  kprobe_flush_task (bnc#1012628).
- powerpc/64s: Fix KVM interrupt using wrong save area
  (bnc#1012628).
- e1000e: Do not wake up the system via WOL if device wakeup is
  disabled (bnc#1012628).
- net: octeon: mgmt: Repair filling of RX ring (bnc#1012628).
- net: core: device_rename: Use rwsem instead of a seqcount
  (bnc#1012628).
- iommu/vt-d: Remove real DMA lookup in find_domain (bnc#1012628).
- commit d68b6c3
* Tue Jun 23 2020 jslaby@suse.cz
- Refresh
  patches.suse/iwl-fix-crash-in-iwl_dbg_tlv_alloc_trigger.patch.
- Refresh
  patches.suse/syscalls-fix-offset-type-of-ksys_ftruncate.patch.
  Update upstream status.
- commit f3d2ea3
* Tue Jun 23 2020 jslaby@suse.cz
- fix a braino in "sparc32: fix register window handling in
  genregs32_et()" (git-fixes).
- nvmet: fail outstanding host posted AEN req (git-fixes).
- commit a1775d0
* Tue Jun 23 2020 jslaby@suse.cz
- blacklist.conf: add one coccinelle warning
- commit 0dd0fe7
* Mon Jun 22 2020 jslaby@suse.cz
- Linux 5.7.5 (bnc#1012628).
- drm/amdgpu: fix and cleanup amdgpu_gem_object_close v4
  (bnc#1012628).
- ath10k: Fix the race condition in firmware dump work queue
  (bnc#1012628).
- drm: bridge: adv7511: Extend list of audio sample rates
  (bnc#1012628).
- media: staging: imgu: do not hold spinlock during freeing mmu
  page table (bnc#1012628).
- media: imx: imx7-mipi-csis: Cleanup and fix subdev pad format
  handling (bnc#1012628).
- crypto: ccp -- don't "select" CONFIG_DMADEVICES (bnc#1012628).
- igc: Fix default MAC address filter override (bnc#1012628).
- scripts: sphinx-pre-install: address some issues with Gentoo
  (bnc#1012628).
- media: vicodec: Fix error codes in probe function (bnc#1012628).
- media: si2157: Better check for running tuner in init
  (bnc#1012628).
- media: v4l2-ctrls: v4l2_ctrl_g/s_ctrl*(): don't continue when
  WARN_ON (bnc#1012628).
- objtool: Ignore empty alternatives (bnc#1012628).
- drm/amd/display: Force watermark value propagation
  (bnc#1012628).
- drm/amd/display: fix virtual signal dsc setup (bnc#1012628).
- spi: spi-mem: Fix Dual/Quad modes on Octal-capable devices
  (bnc#1012628).
- drm/amdgpu: Init data to avoid oops while reading pp_num_states
  (bnc#1012628).
- drm/bridge: panel: Return always an error pointer in
  drm_panel_bridge_add() (bnc#1012628).
- net: ethernet: ti: fix return value check in
  k3_cppi_desc_pool_create_name() (bnc#1012628).
- arm64/kernel: Fix range on invalidating dcache for boot page
  tables (bnc#1012628).
- selftests/bpf: Copy runqslower to OUTPUT directory
  (bnc#1012628).
- libbpf: Fix memory leak and possible double-free in
  hashmap__clear (bnc#1012628).
- spi: pxa2xx: Apply CS clk quirk to BXT (bnc#1012628).
- x86,smap: Fix smap_{save,restore}() alternatives (bnc#1012628).
- sched/fair: Refill bandwidth before scaling (bnc#1012628).
- net: atlantic: make hw_get_regs optional (bnc#1012628).
- net: ena: fix error returning in ena_com_get_hash_function()
  (bnc#1012628).
- efi/libstub/x86: Work around LLVM ELF quirk build regression
  (bnc#1012628).
- ath10k: remove the max_sched_scan_reqs value (bnc#1012628).
- arm64: cacheflush: Fix KGDB trap detection (bnc#1012628).
- media: staging: ipu3: Fix stale list entries on parameter
  queue failure (bnc#1012628).
- libperf evlist: Fix a refcount leak (bnc#1012628).
- rtw88: fix an issue about leak system resources (bnc#1012628).
- spi: dw: Zero DMA Tx and Rx configurations on stack
  (bnc#1012628).
- soc: fsl: dpio: properly compute the consumer index
  (bnc#1012628).
- ACPICA: Dispatcher: add status checks (bnc#1012628).
- block: alloc map and request for new hardware queue
  (bnc#1012628).
- arm64: insn: Fix two bugs in encoding 32-bit logical immediates
  (bnc#1012628).
- tools/power/x86/intel-speed-select: Fix CLX-N package
  information output (bnc#1012628).
- mt76: mt7615: fix aid configuration in
  mt7615_mcu_wtbl_generic_tlv (bnc#1012628).
- block: reset mapping if failed to update hardware queue count
  (bnc#1012628).
- drm: rcar-du: Set primary plane zpos immutably at initializing
  (bnc#1012628).
- lockdown: Allow unprivileged users to see lockdown status
  (bnc#1012628).
- ixgbe: Fix XDP redirect on archs with PAGE_SIZE above 4K
  (bnc#1012628).
- platform/x86: dell-laptop: don't register micmute LED if there
  is no token (bnc#1012628).
- cpuidle: psci: Fixup execution order when entering a domain
  idle state (bnc#1012628).
- MIPS: Loongson: Build ATI Radeon GPU driver as module
  (bnc#1012628).
- io_uring: cleanup io_poll_remove_one() logic (bnc#1012628).
- media: i2c: imx219: Fix a bug in imx219_enum_frame_size
  (bnc#1012628).
- Bluetooth: Add SCO fallback for invalid LMP parameters error
  (bnc#1012628).
- kgdb: Disable WARN_CONSOLE_UNLOCKED for all kgdb (bnc#1012628).
- kgdb: Prevent infinite recursive entries to the debugger
  (bnc#1012628).
- pmu/smmuv3: Clear IRQ affinity hint on device removal
  (bnc#1012628).
- ath11k: Fix some resource leaks in error path in
  'ath11k_thermal_register()' (bnc#1012628).
- ACPI/IORT: Fix PMCG node single ID mapping handling
  (bnc#1012628).
- drm/dp: Lenovo X13 Yoga OLED panel brightness fix (bnc#1012628).
- mips: Fix cpu_has_mips64r1/2 activation for MIPS32 CPUs
  (bnc#1012628).
- spi: dw: Enable interrupts in accordance with DMA xfer mode
  (bnc#1012628).
- clocksource/drivers/timer-versatile: Clear OF_POPULATED flag
  (bnc#1012628).
- clocksource: dw_apb_timer: Make CPU-affiliation being optional
  (bnc#1012628).
- clocksource: dw_apb_timer_of: Fix missing clockevent timers
  (bnc#1012628).
- btrfs: account for trans_block_rsv in may_commit_transaction
  (bnc#1012628).
- btrfs: do not ignore error from btrfs_next_leaf() when inserting
  checksums (bnc#1012628).
- spi: mux: repair mux usage (bnc#1012628).
- ARM: 8978/1: mm: make act_mm() respect THREAD_SIZE
  (bnc#1012628).
- batman-adv: Revert "disable ethtool link speed detection when
  auto negotiation off" (bnc#1012628).
- xfs: more lockdep whackamole with kmem_alloc* (bnc#1012628).
- ice: Fix memory leak (bnc#1012628).
- ice: Fix for memory leaks and modify ICE_FREE_CQ_BUFS
  (bnc#1012628).
- ice: Change number of XDP TxQ to 0 when destroying rings
  (bnc#1012628).
- mmc: mmci_sdmmc: fix power on issue due to pwr_reg
  initialization (bnc#1012628).
- mmc: meson-mx-sdio: trigger a soft reset after a timeout or
  CRC error (bnc#1012628).
- Bluetooth: btmtkuart: Improve exception handling in
  btmtuart_probe() (bnc#1012628).
- Bluetooth: hci_qca: Fix suspend/resume functionality failure
  (bnc#1012628).
- spi: dw: Fix Rx-only DMA transfers (bnc#1012628).
- ice: fix PCI device serial number to be lowercase values
  (bnc#1012628).
- x86/kvm/hyper-v: Explicitly align hcall param for
  kvm_hyperv_exit (bnc#1012628).
- net: vmxnet3: fix possible buffer overflow caused by bad DMA
  value in vmxnet3_get_rss() (bnc#1012628).
- Crypto/chcr: Fixes a coccinile check error (bnc#1012628).
- x86: fix vmap arguments in map_irq_stack (bnc#1012628).
- staging: android: ion: use vmap instead of vm_map_ram
  (bnc#1012628).
- ubsan: entirely disable alignment checks under UBSAN_TRAP
  (bnc#1012628).
- ath11k: fix error message to correctly report the command that
  failed (bnc#1012628).
- drm/hisilicon: Enforce 128-byte stride alignment to fix the
  hardware limitation (bnc#1012628).
- ath11k: Avoid mgmt tx count underflow (bnc#1012628).
- ath10k: fix kernel null pointer dereference (bnc#1012628).
- drm/amd/display: Revert to old formula in set_vtg_params
  (bnc#1012628).
- media: staging/intel-ipu3: Implement lock for stream on/off
  operations (bnc#1012628).
- media: venus: core: remove CNOC voting while device suspend
  (bnc#1012628).
- spi: Respect DataBitLength field of SpiSerialBusV2() ACPI
  resource (bnc#1012628).
- brcmfmac: fix wrong location to get firmware feature
  (bnc#1012628).
- regulator: qcom-rpmh: Fix typos in pm8150 and pm8150l
  (bnc#1012628).
- tools api fs: Make xxx__mountpoint() more scalable
  (bnc#1012628).
- e1000: Distribute switch variables for initialization
  (bnc#1012628).
- net: mscc: ocelot: deal with problematic MAC_ETYPE VCAP IS2
  rules (bnc#1012628).
- drm/ast: Allocate initial CRTC state of the correct size
  (bnc#1012628).
- dt-bindings: display: mediatek: control dpi pins mode to avoid
  leakage (bnc#1012628).
- drm/mediatek: set dpi pin mode to gpio low to avoid leakage
  current (bnc#1012628).
- audit: fix a net reference leak in audit_send_reply()
  (bnc#1012628).
- media: dvb: return -EREMOTEIO on i2c transfer failure
  (bnc#1012628).
- media: imx: utils: fix and simplify pixel format enumeration
  (bnc#1012628).
- media: imx: utils: fix media bus format enumeration
  (bnc#1012628).
- media: platform: fcp: Set appropriate DMA parameters
  (bnc#1012628).
- MIPS: Make sparse_init() using top-down allocation
  (bnc#1012628).
- ath10k: add flush tx packets for SDIO chip (bnc#1012628).
- Bluetooth: btbcm: Add 2 missing models to subver tables
  (bnc#1012628).
- audit: fix a net reference leak in audit_list_rules_send()
  (bnc#1012628).
- drm/amd/display: Correct updating logic of dcn21's pipe VM flags
  (bnc#1012628).
- drm/amd/display: dmcu wait loop calculation is incorrect in RV
  (bnc#1012628).
- Drivers: hv: vmbus: Always handle the VMBus messages on CPU0
  (bnc#1012628).
- efi/libstub/random: Align allocate size to EFI_ALLOC_ALIGN
  (bnc#1012628).
- dpaa2-eth: fix return codes used in ndo_setup_tc (bnc#1012628).
- bcache: remove a duplicate ->make_request_fn assignment
  (bnc#1012628).
- net/mlx4_core: Add missing iounmap() in error path
  (bnc#1012628).
- bpf, riscv: Fix tail call count off by one in RV32 BPF JIT
  (bnc#1012628).
- netfilter: nft_nat: return EOPNOTSUPP if type or flags are
  not supported (bnc#1012628).
- ath11k: use GFP_ATOMIC under spin lock (bnc#1012628).
- Bluetooth: Adding driver and quirk defs for multi-role LE
  (bnc#1012628).
- drm/amd/display: Do not disable pipe split if mode is not
  supported (bnc#1012628).
- libbpf: Refactor map creation logic and fix cleanup leak
  (bnc#1012628).
- selftests/bpf: Ensure test flavors use correct skeletons
  (bnc#1012628).
- selftests/bpf: Fix memory leak in test selector (bnc#1012628).
- selftests/bpf: Fix memory leak in extract_build_id()
  (bnc#1012628).
- selftests/bpf: Fix invalid memory reads in core_relo selftest
  (bnc#1012628).
- libbpf: Fix huge memory leak in libbpf_find_vmlinux_btf_id()
  (bnc#1012628).
- selftests/bpf: Fix bpf_link leak in ns_current_pid_tgid selftest
  (bnc#1012628).
- selftests/bpf: Add runqslower binary to .gitignore
  (bnc#1012628).
- media: m88ds3103: error in set_frontend is swallowed and not
  reported (bnc#1012628).
- ARM: 8969/1: decompressor: simplify libfdt builds (bnc#1012628).
- drm/bridge: fix stack usage warning on old gcc (bnc#1012628).
- net: bcmgenet: set Rx mode before starting netif (bnc#1012628).
- net: bcmgenet: Fix WoL with password after deep sleep
  (bnc#1012628).
- lib/mpi: Fix 64-bit MIPS build with Clang (bnc#1012628).
- net/mlx5e: CT: Avoid false warning about rule may be used
  uninitialized (bnc#1012628).
- exit: Move preemption fixup up, move blocking operations down
  (bnc#1012628).
- sched/core: Fix illegal RCU from offline CPUs (bnc#1012628).
- stmmac: intel: Fix clock handling on error and remove paths
  (bnc#1012628).
- arm64: kexec_file: print appropriate variable (bnc#1012628).
- drivers/perf: hisi: Fix typo in events attribute array
  (bnc#1012628).
- iocost_monitor: drop string wrap around numbers when outputting
  json (bnc#1012628).
- octeontx2-pf: Fix error return code in otx2_probe()
  (bnc#1012628).
- ice: Fix error return code in ice_add_prof() (bnc#1012628).
- net: lpc-enet: fix error return code in lpc_mii_init()
  (bnc#1012628).
- selinux: fix error return code in policydb_read() (bnc#1012628).
- drivers: net: davinci_mdio: fix potential NULL dereference in
  davinci_mdio_probe() (bnc#1012628).
- cpufreq: qcom: fix wrong compatible binding (bnc#1012628).
- ath10k: fix possible memory leak in ath10k_bmi_lz_data_large()
  (bnc#1012628).
- ath11k: fix error return code in ath11k_dp_alloc()
  (bnc#1012628).
- media: sun8i: Fix an error handling path in
  'deinterlace_runtime_resume()' (bnc#1012628).
- media: cec: silence shift wrapping warning in
  __cec_s_log_addrs() (bnc#1012628).
- net: allwinner: Fix use correct return type for ndo_start_xmit()
  (bnc#1012628).
- powerpc/spufs: fix copy_to_user while atomic (bnc#1012628).
- ath11k: fix kernel panic by freeing the msdu received with
  invalid length (bnc#1012628).
- libertas_tf: avoid a null dereference in pointer priv
  (bnc#1012628).
- xfs: clean up the error handling in xfs_swap_extents
  (bnc#1012628).
- Crypto/chcr: fix ctr, cbc, xts and rfc3686-ctr failed tests
  (bnc#1012628).
- Crypto/chcr: fix for ccm(aes) failed test (bnc#1012628).
- dsa: sja1105: dynamically allocate stats structure
  (bnc#1012628).
- MIPS: Truncate link address into 32bit for 32bit kernel
  (bnc#1012628).
- mips: cm: Fix an invalid error code of INTVN_*_ERR
  (bnc#1012628).
- kgdb: Fix spurious true from in_dbg_master() (bnc#1012628).
- xfs: reset buffer write failure state on successful completion
  (bnc#1012628).
- xfs: fix duplicate verification from xfs_qm_dqflush()
  (bnc#1012628).
- platform/x86: intel-vbtn: Use acpi_evaluate_integer()
  (bnc#1012628).
- platform/x86: intel-vbtn: Split keymap into buttons and switches
  parts (bnc#1012628).
- platform/x86: intel-vbtn: Do not advertise switches to userspace
  if they are not there (bnc#1012628).
- platform/x86: intel-vbtn: Also handle tablet-mode switch on
  "Detachable" and "Portable" chassis-types (bnc#1012628).
- iwlwifi: avoid debug max amsdu config overwriting itself
  (bnc#1012628).
- nvme: refine the Qemu Identify CNS quirk (bnc#1012628).
- nvme-fc: avoid gcc-10 zero-length-bounds warning (bnc#1012628).
- nvme-pci: align io queue count with allocted nvme_queue in
  nvme_probe (bnc#1012628).
- nvme-tcp: use bh_lock in data_ready (bnc#1012628).
- ath10k: Skip handling del_server during driver exit
  (bnc#1012628).
- ath10k: Remove msdu from idr when management pkt send fails
  (bnc#1012628).
- wcn36xx: Fix error handling path in 'wcn36xx_probe()'
  (bnc#1012628).
- net: qed*: Reduce RX and TX default ring count when running
  inside kdump kernel (bnc#1012628).
- drm/mcde: dsi: Fix return value check in mcde_dsi_bind()
  (bnc#1012628).
- mt76: mt7663: fix mt7615_mac_cca_stats_reset routine
  (bnc#1012628).
- mt76: mt7615: do not always reset the dfs state setting the
  channel (bnc#1012628).
- mt76: mt7622: fix DMA unmap length (bnc#1012628).
- mt76: mt7663: fix DMA unmap length (bnc#1012628).
- mt76: mt7615: fix mt7615_firmware_own for mt7663e (bnc#1012628).
- mt76: mt7615: fix mt7615_driver_own routine (bnc#1012628).
- mt76: avoid rx reorder buffer overflow (bnc#1012628).
- selftests/bpf: Install generated test progs (bnc#1012628).
- brcmfmac: fix WPA/WPA2-PSK 4-way handshake offload and SAE
  offload failures (bnc#1012628).
- md: don't flush workqueue unconditionally in md_open
  (bnc#1012628).
- raid5: remove gfp flags from scribble_alloc() (bnc#1012628).
- iocost: don't let vrate run wild while there's no saturation
  signal (bnc#1012628).
- veth: Adjust hard_start offset on redirect XDP frames
  (bnc#1012628).
- crypto: blake2b - Fix clang optimization for ARMv7-M
  (bnc#1012628).
- io_uring: allow POLL_ADD with double poll_wait() users
  (bnc#1012628).
- net/mlx5e: IPoIB, Drop multicast packets that this interface
  sent (bnc#1012628).
- selftests/bpf: Fix test_align verifier log patterns
  (bnc#1012628).
- net: ipa: do not clear interrupt in gsi_channel_start()
  (bnc#1012628).
- rtlwifi: Fix a double free in _rtl_usb_tx_urb_setup()
  (bnc#1012628).
- mwifiex: Fix memory corruption in dump_station (bnc#1012628).
- kgdboc: Use a platform device to handle tty drivers showing
  up late (bnc#1012628).
- x86/boot: Correct relocation destination on old linkers
  (bnc#1012628).
- xfs: don't fail verifier on empty attr3 leaf block
  (bnc#1012628).
- sched: Defend cfs and rt bandwidth quota against overflow
  (bnc#1012628).
- mips: MAAR: Use more precise address mask (bnc#1012628).
- ice: cleanup vf_id signedness (bnc#1012628).
- ice: Fix resource leak on early exit from function
  (bnc#1012628).
- mips: Add udelay lpj numbers adjustment (bnc#1012628).
- crypto: stm32/crc32 - fix ext4 chksum BUG_ON() (bnc#1012628).
- crypto: stm32/crc32 - fix run-time self test issue
  (bnc#1012628).
- crypto: stm32/crc32 - fix multi-instance (bnc#1012628).
- drm/amd/powerpay: Disable gfxoff when setting manual mode on
  picasso and raven (bnc#1012628).
- drm/amdgpu: Sync with VM root BO when switching VM to CPU
  update mode (bnc#1012628).
- selftests/bpf: CONFIG_IPV6_SEG6_BPF required for
  test_seg6_loop.o (bnc#1012628).
- selftests/bpf: CONFIG_LIRC required for test_lirc_mode2.sh
  (bnc#1012628).
- ice: Fix Tx timeout when link is toggled on a VF's interface
  (bnc#1012628).
- x86/mm: Stop printing BRK addresses (bnc#1012628).
- MIPS: Fix exception handler memcpy() (bnc#1012628).
- MIPS: tools: Fix resource leak in elf-entry.c (bnc#1012628).
- m68k: mac: Don't call via_flush_cache() on Mac IIfx
  (bnc#1012628).
- btrfs: improve global reserve stealing logic (bnc#1012628).
- btrfs: qgroup: mark qgroup inconsistent if we're inherting
  snapshot to a new qgroup (bnc#1012628).
- ACPI: video: Use native backlight on Acer TravelMate 5735Z
  (bnc#1012628).
- nvme-pci: make sure write/poll_queues less or equal then cpu
  count (bnc#1012628).
- nvmet: fix memory leak when removing namespaces and controllers
  concurrently (bnc#1012628).
- macvlan: Skip loopback packets in RX handler (bnc#1012628).
- PCI: Don't disable decoding when mmio_always_on is set
  (bnc#1012628).
- MIPS: Fix IRQ tracing when call handle_fpe() and
  handle_msa_fpe() (bnc#1012628).
- bcache: fix refcount underflow in bcache_device_free()
  (bnc#1012628).
- mmc: mmci: Switch to mmc_regulator_set_vqmmc() (bnc#1012628).
- mmc: sdhci-msm: Set SDHCI_QUIRK_MULTIBLOCK_READ_ACMD12 quirk
  (bnc#1012628).
- staging: greybus: sdio: Respect the cmd->busy_timeout from
  the mmc core (bnc#1012628).
- mmc: owl-mmc: Respect the cmd->busy_timeout from the mmc core
  (bnc#1012628).
- mmc: via-sdmmc: Respect the cmd->busy_timeout from the mmc core
  (bnc#1012628).
- mmc: sdhci: add quirks for be to le byte swapping (bnc#1012628).
- ice: fix potential double free in probe unrolling (bnc#1012628).
- ixgbe: fix signed-integer-overflow warning (bnc#1012628).
- iwlwifi: mvm: fix aux station leak (bnc#1012628).
- mmc: sdhci-esdhc-imx: fix the mask for tuning start point
  (bnc#1012628).
- spi: dw: Return any value retrieved from the dma_transfer
  callback (bnc#1012628).
- cpuidle: Fix three reference count leaks (bnc#1012628).
- spi: spi-fsl-dspi: fix native data copy (bnc#1012628).
- io_uring: fix overflowed reqs cancellation (bnc#1012628).
- platform/x86: hp-wmi: Convert simple_strtoul() to kstrtou32()
  (bnc#1012628).
- ice: Fix inability to set channels when down (bnc#1012628).
- platform/x86: intel-hid: Add a quirk to support HP Spectre X2
  (2015) (bnc#1012628).
- platform/x86: intel-vbtn: Only blacklist SW_TABLET_MODE on
  the 9 / "Laptop" chasis-type (bnc#1012628).
- platform/x86: asus_wmi: Reserve more space for struct bias_args
  (bnc#1012628).
- libbpf: Fix perf_buffer__free() API for sparse allocs
  (bnc#1012628).
- bpf: Fix map permissions check (bnc#1012628).
- bpf: Refactor sockmap redirect code so its easy to reuse
  (bnc#1012628).
- bpf: Fix running sk_skb program types with ktls (bnc#1012628).
- selftests/bpf, flow_dissector: Close TAP device FD after the
  test (bnc#1012628).
- bpf: Fix up bpf_skb_adjust_room helper's skb csum setting
  (bnc#1012628).
- s390/bpf: Maintain 8-byte stack alignment (bnc#1012628).
- kasan: stop tests being eliminated as dead code with
  FORTIFY_SOURCE (bnc#1012628).
- string.h: fix incompatibility between FORTIFY_SOURCE and KASAN
  (bnc#1012628).
- btrfs: free alien device after device add (bnc#1012628).
- btrfs: include non-missing as a qualifier for the latest_bdev
  (bnc#1012628).
- btrfs: fix a race between scrub and block group
  removal/allocation (bnc#1012628).
- btrfs: send: emit file capabilities after chown (bnc#1012628).
- btrfs: force chunk allocation if our global rsv is larger than
  metadata (bnc#1012628).
- btrfs: reloc: fix reloc root leak and NULL pointer dereference
  (bnc#1012628).
- btrfs: fix error handling when submitting direct I/O bio
  (bnc#1012628).
- btrfs: fix corrupt log due to concurrent fsync of inodes with
  shared extents (bnc#1012628).
- btrfs: fix wrong file range cleanup after an error filling
  dealloc range (bnc#1012628).
- btrfs: fix space_info bytes_may_use underflow after nocow
  buffered write (bnc#1012628).
- btrfs: fix space_info bytes_may_use underflow during space
  cache writeout (bnc#1012628).
- powerpc/mm: Fix conditions to perform MMU specific management
  by blocks on PPC32 (bnc#1012628).
- mm: thp: make the THP mapcount atomic against
  __split_huge_pmd_locked() (bnc#1012628).
- mm: initialize deferred pages with interrupts enabled
  (bnc#1012628).
- MIPS: CPU_LOONGSON2EF need software to maintain cache
  consistency (bnc#1012628).
- mm/pagealloc.c: call touch_nmi_watchdog() on max order
  boundaries in deferred init (bnc#1012628).
- mm: call cond_resched() from deferred_init_memmap()
  (bnc#1012628).
- ima: Fix ima digest hash table key calculation (bnc#1012628).
- ima: Switch to ima_hash_algo for boot aggregate (bnc#1012628).
- ima: Evaluate error in init_ima() (bnc#1012628).
- ima: Directly assign the ima_default_policy pointer to ima_rules
  (bnc#1012628).
- ima: Call ima_calc_boot_aggregate() in ima_eventdigest_init()
  (bnc#1012628).
- ima: Remove __init annotation from ima_pcrread() (bnc#1012628).
- evm: Fix possible memory leak in evm_calc_hmac_or_hash()
  (bnc#1012628).
- ext4: fix EXT_MAX_EXTENT/INDEX to check for zeroed eh_max
  (bnc#1012628).
- ext4: fix buffer_head refcnt leak when ext4_iget() fails
  (bnc#1012628).
- ext4: fix error pointer dereference (bnc#1012628).
- ext4: fix race between ext4_sync_parent() and rename()
  (bnc#1012628).
- PCI: Avoid Pericom USB controller OHCI/EHCI PME# defect
  (bnc#1012628).
- PCI: Avoid FLR for AMD Matisse HD Audio & USB 3.0 (bnc#1012628).
- PCI: Avoid FLR for AMD Starship USB 3.0 (bnc#1012628).
- PCI: Add ACS quirk for Intel Root Complex Integrated Endpoints
  (bnc#1012628).
- serial: 8250_pci: Move Pericom IDs to pci_ids.h (bnc#1012628).
- x86/amd_nb: Add AMD family 17h model 60h PCI IDs (bnc#1012628).
- ima: Remove redundant policy rule set in add_rules()
  (bnc#1012628).
- ima: Set again build_ima_appraise variable (bnc#1012628).
- PCI: Program MPS for RCiEP devices (bnc#1012628).
- e1000e: Disable TSO for buffer overrun workaround (bnc#1012628).
- e1000e: Relax condition to trigger reset for ME workaround
  (bnc#1012628).
- irqchip/sifive-plic: Set default irq affinity in
  plic_irqdomain_map() (bnc#1012628).
- irqchip/sifive-plic: Setup cpuhp once after boot CPU handler
  is present (bnc#1012628).
- carl9170: remove P2P_GO support (bnc#1012628).
- clocksource: Remove obsolete ifdef (bnc#1012628).
- clocksource/drivers/timer-microchip-pit64b: Select
  CONFIG_TIMER_OF (bnc#1012628).
- media: cedrus: Program output format during each run
  (bnc#1012628).
- serial: 8250: Avoid error message on reprobe (bnc#1012628).
- Bluetooth: hci_bcm: respect IRQ polarity from DT (bnc#1012628).
- Bluetooth: hci_bcm: fix freeing not-requested IRQ (bnc#1012628).
- b43legacy: Fix case where channel status is corrupted
  (bnc#1012628).
- b43: Fix connection problem with WPA3 (bnc#1012628).
- b43_legacy: Fix connection problem with WPA3 (bnc#1012628).
- media: ov5640: fix use of destroyed mutex (bnc#1012628).
- usb: musb: mediatek: add reset FADDR to zero in reset interrupt
  handle (bnc#1012628).
- clk: mediatek: assign the initial value to clk_init_data of
  mtk_mux (bnc#1012628).
- igb: Report speed and duplex as unknown when device is runtime
  suspended (bnc#1012628).
- hwmon: (k10temp) Add AMD family 17h model 60h PCI match
  (bnc#1012628).
- EDAC/amd64: Add AMD family 17h model 60h PCI IDs (bnc#1012628).
- iommu/vt-d: Only clear real DMA device's context entries
  (bnc#1012628).
- iommu/vt-d: Allocate domain info for real DMA sub-devices
  (bnc#1012628).
- power: vexpress: add suppress_bind_attrs to true (bnc#1012628).
- power: supply: core: fix HWMON temperature labels (bnc#1012628).
- power: supply: core: fix memory leak in HWMON error path
  (bnc#1012628).
- pinctrl: samsung: Correct setting of eint wakeup mask on s5pv210
  (bnc#1012628).
- pinctrl: samsung: Save/restore eint_mask over suspend for
  EINT_TYPE GPIOs (bnc#1012628).
- gnss: sirf: fix error return code in sirf_probe() (bnc#1012628).
- sparc32: fix register window handling in genregs32_[gs]et()
  (bnc#1012628).
- sparc64: fix misuses of access_process_vm() in
  genregs32_[sg]et() (bnc#1012628).
- software node: implement software_node_unregister()
  (bnc#1012628).
- dm crypt: avoid truncating the logical block size (bnc#1012628).
- alpha: fix memory barriers so that they conform to the
  specification (bnc#1012628).
- memory: samsung: exynos5422-dmc: Fix tFAW timings alignment
  (bnc#1012628).
- powerpc/fadump: use static allocation for reserved memory ranges
  (bnc#1012628).
- powerpc/fadump: consider reserved ranges while reserving memory
  (bnc#1012628).
- powerpc/fadump: Account for memory_limit while reserving memory
  (bnc#1012628).
- kernel/cpu_pm: Fix uninitted local in cpu_pm (bnc#1012628).
- ARM: tegra: Correct PL310 Auxiliary Control Register
  initialization (bnc#1012628).
- soc/tegra: pmc: Select GENERIC_PINCONF (bnc#1012628).
- ARM: dts: exynos: Fix GPIO polarity for thr GalaxyS3 CM36651
  sensor's bus (bnc#1012628).
- ARM: dts: at91: sama5d2_ptc_ek: fix vbus pin (bnc#1012628).
- ARM: dts: s5pv210: Set keep-power-in-suspend for SDHCI1 on Aries
  (bnc#1012628).
- drivers/macintosh: Fix memleak in windfarm_pm112 driver
  (bnc#1012628).
- powerpc/32s: Fix another build failure with
  CONFIG_PPC_KUAP_DEBUG (bnc#1012628).
- powerpc/kasan: Fix issues by lowering KASAN_SHADOW_END
  (bnc#1012628).
- powerpc/kasan: Fix shadow pages allocation failure
  (bnc#1012628).
- powerpc/32: Disable KASAN with pages bigger than 16k
  (bnc#1012628).
- powerpc/64s: Don't let DT CPU features set FSCR_DSCR
  (bnc#1012628).
- powerpc/64s: Save FSCR to init_task.thread.fscr after feature
  init (bnc#1012628).
- kbuild: force to build vmlinux if CONFIG_MODVERSION=y
  (bnc#1012628).
- virtio-balloon: Disable free page reporting if page poison
  reporting is not enabled (bnc#1012628).
- sunrpc: svcauth_gss_register_pseudoflavor must reject duplicate
  registrations (bnc#1012628).
- sunrpc: clean up properly in gss_mech_unregister()
  (bnc#1012628).
- block: nr_sects_write(): Disable preemption on seqcount write
  (bnc#1012628).
- RISC-V: Don't mark init section as non-executable (bnc#1012628).
- pwm: lpss: Fix get_state runtime-pm reference handling
  (bnc#1012628).
- pwm: jz4740: Enhance precision in calculation of duty cycle
  (bnc#1012628).
- mtd: rawnand: Fix nand_gpio_waitrdy() (bnc#1012628).
- mtd: rawnand: onfi: Fix redundancy detection check
  (bnc#1012628).
- mtd: rawnand: brcmnand: fix hamming oob layout (bnc#1012628).
- mtd: rawnand: diskonchip: Fix the probe error path
  (bnc#1012628).
- mtd: rawnand: sharpsl: Fix the probe error path (bnc#1012628).
- mtd: rawnand: ingenic: Fix the probe error path (bnc#1012628).
- mtd: rawnand: xway: Fix the probe error path (bnc#1012628).
- mtd: rawnand: orion: Fix the probe error path (bnc#1012628).
- mtd: rawnand: socrates: Fix the probe error path (bnc#1012628).
- mtd: rawnand: oxnas: Fix the probe error path (bnc#1012628).
- mtd: rawnand: sunxi: Fix the probe error path (bnc#1012628).
- mtd: rawnand: plat_nand: Fix the probe error path (bnc#1012628).
- mtd: rawnand: pasemi: Fix the probe error path (bnc#1012628).
- mtd: rawnand: mtk: Fix the probe error path (bnc#1012628).
- mtd: rawnand: tmio: Fix the probe error path (bnc#1012628).
- w1: omap-hdq: cleanup to add missing newline for some dev_dbg
  (bnc#1012628).
- w1: omap-hdq: fix return value to be -1 if there is a timeout
  (bnc#1012628).
- w1: omap-hdq: fix interrupt handling which did show spurious
  timeouts (bnc#1012628).
- f2fs: don't leak filename in f2fs_try_convert_inline_dir()
  (bnc#1012628).
- f2fs: fix checkpoint=disable:%%u%%%% (bnc#1012628).
- perf probe: Do not show the skipped events (bnc#1012628).
- perf probe: Fix to check blacklist address correctly
  (bnc#1012628).
- perf probe: Check address correctness by map instead of _etext
  (bnc#1012628).
- perf symbols: Fix debuginfo search for Ubuntu (bnc#1012628).
- perf symbols: Fix kernel maps for kcore and eBPF (bnc#1012628).
- Update config files.
- commit 33d4749
* Mon Jun 22 2020 mkubecek@suse.cz
- Update to 5.8-rc2
- refresh configs
- commit f76a148
* Thu Jun 18 2020 jeyu@suse.de
- panic: do not print uninitialized taint_flags (bsc#1172814).
- commit ed3a673
* Thu Jun 18 2020 jslaby@suse.cz
- Linux 5.7.4 (bnc#1012628).
- lib/vdso: Provide sanity check for cycles (again) (bnc#1012628).
- commit 23bad63
* Thu Jun 18 2020 jslaby@suse.cz
- blacklist.conf: add one cleanup
- commit 44c4af0
* Thu Jun 18 2020 jslaby@suse.cz
- genetlink: clean up family attributes allocations (git-fixes).
- ACPI: GED: use correct trigger type field in _Exx / _Lxx
  handling (git-fixes).
- commit 8a9985c
* Wed Jun 17 2020 jslaby@suse.cz
- Linux 5.7.3 (bnc#1012628).
- ipv6: fix IPV6_ADDRFORM operation logic (bnc#1012628).
- mlxsw: core: Use different get_trend() callbacks for different
  thermal zones (bnc#1012628).
- net_failover: fixed rollback in net_failover_open()
  (bnc#1012628).
- tun: correct header offsets in napi frags mode (bnc#1012628).
- bridge: Avoid infinite loop when suppressing NS messages with
  invalid options (bnc#1012628).
- vxlan: Avoid infinite loop when suppressing NS messages with
  invalid options (bnc#1012628).
- net: ena: xdp: XDP_TX: fix memory leak (bnc#1012628).
- net: ena: xdp: update napi budget for DROP and ABORTED
  (bnc#1012628).
- mptcp: bugfix for RM_ADDR option parsing (bnc#1012628).
- genetlink: fix memory leaks in genl_family_rcv_msg_dumpit()
  (bnc#1012628).
- net: dsa: qca8k: Fix "Unexpected gfp" kernel exception
  (bnc#1012628).
- tipc: fix NULL pointer dereference in streaming (bnc#1012628).
- elfnote: mark all .note sections SHF_ALLOC (bnc#1012628).
- staging: mt7621-pci: properly power off dual-ported pcie phy
  (bnc#1012628).
- staging: wfx: fix double free (bnc#1012628).
- selftests: fix flower parent qdisc (bnc#1012628).
- mm: add kvfree_sensitive() for freeing sensitive data objects
  (bnc#1012628).
- perf probe: Accept the instance number of kretprobe event
  (bnc#1012628).
- driver core: Update device link status correctly for
  SYNC_STATE_ONLY links (bnc#1012628).
- fanotify: fix ignore mask logic for events on child and on dir
  (bnc#1012628).
- powerpc/xive: Clear the page tables for the ESB IO mapping
  (bnc#1012628).
- spi: dw: Fix native CS being unset (bnc#1012628).
- ath9k_htc: Silence undersized packet warnings (bnc#1012628).
- smack: avoid unused 'sip' variable warning (bnc#1012628).
- s390/pci: Log new handle in clp_disable_fh() (bnc#1012628).
- x86/cpu/amd: Make erratum #1054 a legacy erratum (bnc#1012628).
- RDMA/uverbs: Make the event_queue fds return POLLERR when
  disassociated (bnc#1012628).
- padata: add separate cpuhp node for CPUHP_PADATA_DEAD
  (bnc#1012628).
- PCI/PM: Adjust pcie_wait_for_link_delay() for caller delay
  (bnc#1012628).
- aio: fix async fsync creds (bnc#1012628).
- x86_64: Fix jiffies ODR violation (bnc#1012628).
- x86: mm: ptdump: calculate effective permissions correctly
  (bnc#1012628).
- x86/PCI: Mark Intel C620 MROMs as having non-compliant BARs
  (bnc#1012628).
- x86/reboot/quirks: Add MacBook6,1 reboot quirk (bnc#1012628).
- x86/vdso: Unbreak paravirt VDSO clocks (bnc#1012628).
- perf/x86/intel: Add more available bits for OFFCORE_RESPONSE
  of Intel Tremont (bnc#1012628).
- KVM: x86: don't expose MSR_IA32_UMWAIT_CONTROL unconditionally
  (bnc#1012628).
- KVM: x86: allow KVM_STATE_NESTED_MTF_PENDING in kvm_state flags
  (bnc#1012628).
- KVM: VMX: enable X86_FEATURE_WAITPKG in KVM capabilities
  (bnc#1012628).
- KVM: x86: respect singlestep when emulating instruction
  (bnc#1012628).
- KVM: x86: Fix APIC page invalidation race (bnc#1012628).
- powerpc/ptdump: Properly handle non standard page size
  (bnc#1012628).
- ASoC: tlv320adcx140: Fix mic gain registers (bnc#1012628).
- ASoC: max9867: fix volume controls (bnc#1012628).
- io_uring: fix flush req->refs underflow (bnc#1012628).
- io_uring: re-set iov base/len for buffer select retry
  (bnc#1012628).
- io_uring: use kvfree() in io_sqe_buffer_register()
  (bnc#1012628).
- io_uring: allow O_NONBLOCK async retry (bnc#1012628).
- efi/efivars: Add missing kobject_put() in sysfs entry creation
  error path (bnc#1012628).
- smb3: fix incorrect number of credits when ioctl
  MaxOutputResponse > 64K (bnc#1012628).
- smb3: add indatalen that can be a non-zero value to calculation
  of credit charge in smb2 ioctl (bnc#1012628).
- smb3: fix typo in mount options displayed in /proc/mounts
  (bnc#1012628).
- serial: imx: Initialize lock for non-registered console
  (bnc#1012628).
- watchdog: imx_sc_wdt: Fix reboot on crash (bnc#1012628).
- ALSA: es1688: Add the missed snd_card_free() (bnc#1012628).
- ALSA: hda: add sienna_cichlid audio asic id for sienna_cichlid
  up (bnc#1012628).
- ALSA: fireface: fix configuration error for nominal sampling
  transfer frequency (bnc#1012628).
- ALSA: fireface: start IR context immediately (bnc#1012628).
- ALSA: hda/realtek - add a pintbl quirk for several Lenovo
  machines (bnc#1012628).
- ALSA: pcm: disallow linking stream to itself (bnc#1012628).
- ALSA: pcm: fix snd_pcm_link() lockdep splat (bnc#1012628).
- ALSA: usb-audio: Fix inconsistent card PM state after resume
  (bnc#1012628).
- ALSA: usb-audio: Add vendor, product and profile name for HP
  Thunderbolt Dock (bnc#1012628).
- ACPI: sysfs: Fix reference count leak in
  acpi_sysfs_add_hotplug_profile() (bnc#1012628).
- ACPI: CPPC: Fix reference count leak in
  acpi_cppc_processor_probe() (bnc#1012628).
- ACPI: GED: add support for _Exx / _Lxx handler methods
  (bnc#1012628).
- ACPI: PM: Avoid using power resources if there are none for D0
  (bnc#1012628).
- arm64: acpi: fix UBSAN warning (bnc#1012628).
- lib/lzo: fix ambiguous encoding bug in lzo-rle (bnc#1012628).
- nilfs2: fix null pointer dereference at
  nilfs_segctor_do_construct() (bnc#1012628).
- lib: fix bitmap_parse() on 64-bit big endian archs
  (bnc#1012628).
- spi: dw: Fix controller unregister order (bnc#1012628).
- spi: Fix controller unregister order (bnc#1012628).
- spi: pxa2xx: Fix controller unregister order (bnc#1012628).
- spi: pxa2xx: Fix runtime PM ref imbalance on probe error
  (bnc#1012628).
- spi: bcm2835: Fix controller unregister order (bnc#1012628).
- spi: bcm2835aux: Fix controller unregister order (bnc#1012628).
- spi: bcm-qspi: Handle clock probe deferral (bnc#1012628).
- spi: bcm-qspi: when tx/rx buffer is NULL set to 0 (bnc#1012628).
- PM: runtime: clk: Fix clk_pm_runtime_get() error path
  (bnc#1012628).
- gup: document and work around "COW can break either way" issue
  (bnc#1012628).
- crypto: cavium/nitrox - Fix 'nitrox_get_first_device()' when
  ndevlist is fully iterated (bnc#1012628).
- crypto: algapi - Avoid spurious modprobe on LOADED
  (bnc#1012628).
- crypto: drbg - fix error return code in drbg_alloc_state()
  (bnc#1012628).
- crypto: virtio: Fix dest length calculation in
  __virtio_crypto_skcipher_do_req() (bnc#1012628).
- crypto: virtio: Fix use-after-free in
  virtio_crypto_skcipher_finalize_req() (bnc#1012628).
- crypto: virtio: Fix src/dst scatterlist calculation in
  __virtio_crypto_skcipher_do_req() (bnc#1012628).
- x86/{mce,mm}: Unmap the entire page if the whole page is
  affected and poisoned (bnc#1012628).
- firmware: imx-scu: Support one TX and one RX (bnc#1012628).
- firmware: imx: scu: Fix corruption of header (bnc#1012628).
- dccp: Fix possible memleak in dccp_init and dccp_fini
  (bnc#1012628).
- net: mvneta: do not redirect frames during reconfiguration
  (bnc#1012628).
- selftests/net: in rxtimestamp getopt_long needs terminating
  null entry (bnc#1012628).
- net/mlx5: drain health workqueue in case of driver load error
  (bnc#1012628).
- net/mlx5: Fix fatal error handling during device load
  (bnc#1012628).
- net/mlx5e: Fix repeated XSK usage on one channel (bnc#1012628).
- net: cadence: macb: disable NAPI on error (bnc#1012628).
- net: macb: Only disable NAPI on the actual error path
  (bnc#1012628).
- net/mlx5: Disable reload while removing the device
  (bnc#1012628).
- mptcp: don't leak msk in token container (bnc#1012628).
- ionic: wait on queue start until after IFF_UP (bnc#1012628).
- mptcp: fix races between shutdown and recvmsg (bnc#1012628).
- net: ethernet: ti: ale: fix allmulti for nu type ale
  (bnc#1012628).
- net: ethernet: ti: am65-cpsw-nuss: fix ale parameters init
  (bnc#1012628).
- net: sched: export __netdev_watchdog_up() (bnc#1012628).
- net/mlx5e: CT: Fix ipv6 nat header rewrite actions
  (bnc#1012628).
- ovl: fix out of bounds access warning in ovl_check_fb_len()
  (bnc#1012628).
- ovl: initialize error in ovl_copy_xattr (bnc#1012628).
- exfat: fix memory leak in exfat_parse_param() (bnc#1012628).
- exfat: fix incorrect update of stream entry in
  __exfat_truncate() (bnc#1012628).
- proc: Use new_inode not new_inode_pseudo (bnc#1012628).
- remoteproc: Fall back to using parent memory pool if no
  dedicated available (bnc#1012628).
- remoteproc: Fix and restore the parenting hierarchy for vdev
  (bnc#1012628).
- cpufreq: Fix up cpufreq_boost_set_sw() (bnc#1012628).
- EDAC/skx: Use the mcmtr register to retrieve
  close_pg/bank_xor_enable (bnc#1012628).
- video: vt8500lcdfb: fix fallthrough warning (bnc#1012628).
- video: fbdev: w100fb: Fix a potential double free (bnc#1012628).
- media: videobuf2-dma-contig: fix bad kfree in
  vb2_dma_contig_clear_max_seg_size (bnc#1012628).
- KVM: nVMX: Skip IBPB when switching between vmcs01 and vmcs02
  (bnc#1012628).
- KVM: nSVM: fix condition for filtering async PF (bnc#1012628).
- KVM: nSVM: leave ASID aside in copy_vmcb_control_area
  (bnc#1012628).
- KVM: nVMX: Consult only the "basic" exit reason when routing
  nested exit (bnc#1012628).
- KVM: MIPS: Define KVM_ENTRYHI_ASID to
  cpu_asid_mask(&boot_cpu_data) (bnc#1012628).
- KVM: MIPS: Fix VPN2_MASK definition for variable cpu_vmbits
  (bnc#1012628).
- KVM: arm64: Stop writing aarch32's CSSELR into ACTLR
  (bnc#1012628).
- KVM: arm64: Make vcpu_cp1x() work on Big Endian hosts
  (bnc#1012628).
- scsi: megaraid_sas: TM command refire leads to controller
  firmware crash (bnc#1012628).
- scsi: lpfc: Fix negation of else clause in
  lpfc_prep_node_fc4type (bnc#1012628).
- scsi: megaraid_sas: Replace undefined MFI_BIG_ENDIAN macro
  with __BIG_ENDIAN_BITFIELD macro (bnc#1012628).
- selftests/ftrace: Return unsupported if no error_log file
  (bnc#1012628).
- ath9k: Fix use-after-free Read in htc_connect_service
  (bnc#1012628).
- ath9k: Fix use-after-free Read in ath9k_wmi_ctrl_rx
  (bnc#1012628).
- ath9k: Fix use-after-free Write in ath9k_htc_rx_msg
  (bnc#1012628).
- ath9x: Fix stack-out-of-bounds Write in ath9k_hif_usb_rx_cb
  (bnc#1012628).
- ath9k: Fix general protection fault in ath9k_hif_usb_rx_cb
  (bnc#1012628).
- Smack: slab-out-of-bounds in vsscanf (bnc#1012628).
- drm/vkms: Hold gem object while still in-use (bnc#1012628).
- mm/slub: fix a memory leak in sysfs_slab_add() (bnc#1012628).
- fat: don't allow to mount if the FAT length == 0 (bnc#1012628).
- perf: Add cond_resched() to task_function_call() (bnc#1012628).
- agp/intel: Reinforce the barrier after GTT updates
  (bnc#1012628).
- mmc: sdhci-msm: Clear tuning done flag while hs400 tuning
  (bnc#1012628).
- mmc: sdhci-of-at91: fix CALCR register being rewritten
  (bnc#1012628).
- mmc: mmci_sdmmc: fix DMA API warning overlapping mappings
  (bnc#1012628).
- mmc: tmio: Further fixup runtime PM management at remove
  (bnc#1012628).
- mmc: uniphier-sd: call devm_request_irq() after
  tmio_mmc_host_probe() (bnc#1012628).
- ARM: dts: at91: sama5d2_ptc_ek: fix sdmmc0 node description
  (bnc#1012628).
- mmc: sdio: Fix potential NULL pointer error in
  mmc_sdio_init_card() (bnc#1012628).
- mmc: sdio: Fix several potential memory leaks in
  mmc_sdio_init_card() (bnc#1012628).
- block/floppy: fix contended case in floppy_queue_rq()
  (bnc#1012628).
- xen/pvcalls-back: test for errors when calling backend_connect()
  (bnc#1012628).
- platform/x86: sony-laptop: SNC calls should handle BUFFER types
  (bnc#1012628).
- platform/x86: sony-laptop: Make resuming thermal profile safer
  (bnc#1012628).
- KVM: arm64: Save the host's PtrAuth keys in non-preemptible
  context (bnc#1012628).
- KVM: arm64: Synchronize sysreg state on injecting an AArch32
  exception (bnc#1012628).
- serial: amba-pl011: Make sure we initialize the port.lock
  spinlock (bnc#1012628).
- commit af36e48
* Wed Jun 17 2020 duwe@suse.de
- rpm/modules.fips:
  * add aes-ce-ccm and des3_ede-x86_64 (boo#173030)
  * add aes_ti and aes_neon_bs (boo#1172956)
- commit 08a1655
* Tue Jun 16 2020 jslaby@suse.cz
- efi/tpm: Verify event log header before parsing (bnc#1165773).
- commit fb5dacf
* Tue Jun 16 2020 jslaby@suse.cz
- Update
  patches.suse/iwl-fix-crash-in-iwl_dbg_tlv_alloc_trigger.patch
  (bsc#1172905).
  Add a bsc as a reference.
- commit 096f443
* Mon Jun 15 2020 mkubecek@suse.cz
- config: disable BPFILTER_UMH on i386
  It does not build currently.
- commit 72fbe18
* Mon Jun 15 2020 mkubecek@suse.cz
- config: enable PHYLIB=y and ETHTOOL_NETLINK=y
  As an unfortunate side effect of ethtool cable diagnostic support,
  ETHTOOL_NETLINK now depends on PHYLIB and the dependency is implemented in
  a way making "make oldconfig" drops ETHTOOL_NETLINK if PHYLIB=m.
  Until this issue is resolved in upstream, set PHYLIB=y so that
  ETHTOOL_NETLINK can be enabled again.
- commit fcc47b4
* Mon Jun 15 2020 mkubecek@suse.cz
- rpm: drop execute permissions on source files
  Sometimes a source file with execute permission appears in upstream
  repository and makes it into our kernel-source packages. This is caught by
  OBS build checks and may even result in build failures.
  Sanitize the source tree by removing execute permissions from all C source
  and header files.
- commit 771e293
* Mon Jun 15 2020 mkubecek@suse.cz
- Update to 5.8-rc1
- eliminated 48 patches (40 stable, 8 other)
- disable ARM architectures (need config update)
- refresh
  patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch
  patches.suse/apparmor-compatibility-with-v2.x-net.patch
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch
  patches.suse/dm-mpath-leastpending-path-update
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  patches.suse/pstore_disable_efi_backend_by_default.patch
  patches.suse/readahead-request-tunables.patch
  patches.suse/supported-flag
  patches.suse/supported-flag-external
  patches.suse/supported-flag-modverdir
  patches.suse/suse-hv-guest-os-id.patch
- fix build with BPFILTER_UMH=m
  patches.rpmify/bpfilter-only-build-bpfilter_umh-as-static-when-BPFI.patch
- new config options:
  - General setup
  - CONFIG_DEFAULT_INIT=""
  - CONFIG_WATCH_QUEUE=y
  - Power management and ACPI options
  - CONFIG_HIBERNATION_SNAPSHOT_DEV=y
  - Enable the block layer
  - CONFIG_BLK_INLINE_ENCRYPTION=y
  - CONFIG_BLK_INLINE_ENCRYPTION_FALLBACK=y
  - CONFIG_BLK_DEV_RNBD_CLIENT=m
  - CONFIG_BLK_DEV_RNBD_SERVER=m
  - Memory Management options
  - CONFIG_ZSMALLOC_PGTABLE_MAPPING=n
  - Networking support
  - CONFIG_INET6_ESPINTCP=y
  - CONFIG_BRIDGE_MRP=y
  - CONFIG_NET_ACT_GATE=m
  - CONFIG_QRTR=m
  - CONFIG_QRTR_SMD=m
  - CONFIG_QRTR_TUN=m
  - CONFIG_QRTR_MHI=m
  - CONFIG_BT_MSFTEXT=n
  - File systems
  - CONFIG_PSTORE_BLK=m
  - Library routines
  - CONFIG_PRIME_NUMBERS=n
  - CONFIG_DEBUG_INFO_COMPRESSED=n
  - CONFIG_DEBUG_VM_PGTABLE=n
  - CONFIG_HIST_TRIGGERS_DEBUG=n
  - CONFIG_TEST_BITOPS=n
  - CONFIG_TEST_HMM=n
  - Multiple devices driver support (RAID and LVM)
  - CONFIG_BCACHE_ASYNC_REGISTRAION=n
  - CONFIG_DM_EBS=m
  - CONFIG_DM_MULTIPATH_HST=m
  - Network device support
  - CONFIG_NET_DSA_SJA1105_VL=y
  - CONFIG_MLX5_CLS_ACT=y
  - CONFIG_BCM54140_PHY=m
  - CONFIG_MT7663U=m
  - CONFIG_MT7915E=m
  - CONFIG_RTW88_8723DE=m
  - Input device support
  - CONFIG_TOUCHSCREEN_CY8CTMA140=m
  - CONFIG_INPUT_IQS269A=m
  - Character devices
  - CONFIG_SERIAL_LANTIQ=m
  - Multifunction device drivers
  - CONFIG_MFD_MP2629=n
  - CONFIG_MFD_INTEL_PMC_BXT=m
  - CONFIG_INTEL_SOC_PMIC_MRFLD=m
  - CONFIG_INTEL_MRFLD_PWRBTN=m
  - CONFIG_EXTCON_INTEL_MRFLD=m
  - CONFIG_INTEL_MRFLD_ADC=n
  - CONFIG_MFD_INTEL_MSIC=n
  - CONFIG_MFD_MT6360=n
  - Multimedia support
  - CONFIG_MEDIA_SUPPORT_FILTER=y
  - CONFIG_MEDIA_PLATFORM_SUPPORT=n
  - CONFIG_MEDIA_TEST_SUPPORT=n
  - CONFIG_VIDEO_OV2740=m
  - CONFIG_INTEL_ATOMISP=y
  - CONFIG_VIDEO_ATOMISP=m
  - CONFIG_VIDEO_ATOMISP_ISP2401=y
  - CONFIG_VIDEO_ATOMISP_OV5693=m
  - CONFIG_VIDEO_ATOMISP_OV2722=m
  - CONFIG_VIDEO_ATOMISP_GC2235=m
  - CONFIG_VIDEO_ATOMISP_MSRLIST_HELPER=m
  - CONFIG_VIDEO_ATOMISP_MT9M114=m
  - CONFIG_VIDEO_ATOMISP_GC0310=m
  - CONFIG_VIDEO_ATOMISP_OV2680=m
  - CONFIG_VIDEO_ATOMISP_LM3554=m
  - CONFIG_CEC_CROS_EC=m
  - CONFIG_CEC_SECO=m
  - CONFIG_CEC_SECO_RC=n
  - Graphics support
  - CONFIG_DRM_I915_FENCE_TIMEOUT=10000
  - Sound card support
  - CONFIG_SND_SOC_AMD_RENOIR=m
  - CONFIG_SND_SOC_AMD_RENOIR_MACH=m
  - CONFIG_SND_SOC_INTEL_SOF_WM8804_MACH=m
  - CONFIG_SND_SOC_INTEL_EHL_RT5660_MACH=m
  - CONFIG_SND_SOC_MAX98390=m
  - CONFIG_SND_SOC_ZL38060=n
  - USB support
  - CONFIG_USB_XHCI_PCI_RENESAS=m
  - InfiniBand support
  - CONFIG_INFINIBAND_RTRS_CLIENT=m
  - CONFIG_INFINIBAND_RTRS_SERVER=m
  - Virtio drivers
  - CONFIG_VIRTIO_MEM=m
  - X86 Platform Specific Device Drivers
  - CONFIG_INTEL_WMI_SBL_FW_UPDATE=m
  - CONFIG_INTEL_SCU_PCI=y
  - CONFIG_INTEL_SCU_PLATFORM=m
  - CONFIG_INTEL_MID_POWER_BUTTON=m
  - CONFIG_INTEL_SCU_IPC_UTIL=m
  - Industrial I/O support
  - CONFIG_AD9467=n
  - CONFIG_ADI_AXI_ADC=n
  - CONFIG_MAX1241=n
  - CONFIG_ATLAS_EZO_SENSOR=n
  - CONFIG_ADIS16475=n
  - CONFIG_SX9310=n
  - CONFIG_VCNL3020=n
  - Misc drivers
  - CONFIG_MTD_NAND_ARASAN=m
  - CONFIG_MTD_PSTORE=m
  - CONFIG_INTERCONNECT=n
  - CONFIG_SPI_AMD=n
  - CONFIG_PINCTRL_JASPERLAKE=m
  - CONFIG_GPIO_PCA953X_IRQ=y
  - CONFIG_GPIO_AGGREGATOR=m
  - CONFIG_BATTERY_CW2015=m
  - CONFIG_CHARGER_BD99954=m
  - CONFIG_SENSORS_AMD_ENERGY=m
  - CONFIG_SENSORS_MAX16601=m
  - ACPI INT340X thermal drivers
  - CONFIG_REGULATOR_MAX77826=m
  - CONFIG_LEDS_SGM3140=m
  - CONFIG_PWM_IQS620A=m
  - i386 / ppc64 / ppc64le
  - MDIO_IPQ4019=m
  - HW_RANDOM_CCTRNG=n
  - MFD_GATEWORKS_GSC=m
  - DRM_PANEL_ASUS_Z00T_TM5P5_NT35596=n
  - DRM_PANEL_LEADTEK_LTK050H3146W=n
  - DRM_PANEL_VISIONOX_RM69299=n
  - DRM_CHRONTEL_CH7033=n
  - DRM_NWL_MIPI_DSI=n
  - LEDS_AW2013=m
  - CLK_LGM_CGU=y
  - PHY_CADENCE_SALVO=m
  - PHY_INTEL_COMBO=y
  - PHY_OCELOT_SERDES=m
  - MTD_PHYSMAP_VERSATILE=y
  - MTD_PHYSMAP_GEMINI=y
  - MDIO_IPQ8064=m
  - SERIAL_8250_ASPEED_VUART=n
  - GPIO_LOGICVC=n
  - GPIO_SAMA5D2_PIOBU=n
  - GPIO_SYSCON=n
  - SENSORS_GSC=m
  - DRM_PANEL_ARM_VERSATILE=n
  - LEDS_SYSCON=y
- commit 8874901
* Fri Jun 12 2020 bp@suse.de
- x86/speculation: PR_SPEC_FORCE_DISABLE enforcement for indirect
  branches (bsc#1172783 CVE-2020-10768).
- commit 3bb02b8
* Fri Jun 12 2020 bp@suse.de
- x86/speculation: Prevent rogue cross-process SSBD shutdown
  (bsc#1172781 CVE-2020-10766).
- commit 765c970
* Fri Jun 12 2020 jslaby@suse.cz
- iwl: fix crash in iwl_dbg_tlv_alloc_trigger (iwlwifi crash).
- commit 6645a57
* Thu Jun 11 2020 bp@suse.de
- x86/speculation: Avoid force-disabling IBPB based on STIBP
  and enhanced IBRS (bsc#1172782 CVE-2020-10767).
- commit 5c5774f
* Thu Jun 11 2020 jslaby@suse.cz
- Linux 5.7.2 (bnc#1012628).
- uprobes: ensure that uprobe->offset and ->ref_ctr_offset are
  properly aligned (bnc#1012628).
- x86/speculation: Add Ivy Bridge to affected list (bnc#1012628).
- x86/speculation: Add SRBDS vulnerability and mitigation
  documentation (bnc#1012628).
- x86/speculation: Add Special Register Buffer Data Sampling
  (SRBDS) mitigation (bnc#1012628).
- x86/cpu: Add 'table' argument to cpu_matches() (bnc#1012628).
- x86/cpu: Add a steppings field to struct x86_cpu_id
  (bnc#1012628).
- nvmem: qfprom: remove incorrect write support (bnc#1012628).
- CDC-ACM: heed quirk also in error handling (bnc#1012628).
- staging: rtl8712: Fix IEEE80211_ADDBA_PARAM_BUF_SIZE_MASK
  (bnc#1012628).
- tty: hvc_console, fix crashes on parallel open/close
  (bnc#1012628).
- vt: keyboard: avoid signed integer overflow in k_ascii
  (bnc#1012628).
- serial: 8250: Enable 16550A variants by default on non-x86
  (bnc#1012628).
- usb: musb: jz4740: Prevent lockup when CONFIG_SMP is set
  (bnc#1012628).
- usb: musb: Fix runtime PM imbalance on error (bnc#1012628).
- usb: musb: start session in resume for host port (bnc#1012628).
- iio: adc: stm32-adc: fix a wrong error message when probing
  interrupts (bnc#1012628).
- iio:chemical:pms7003: Fix timestamp alignment and prevent data
  leak (bnc#1012628).
- iio: vcnl4000: Fix i2c swapped word reading (bnc#1012628).
- iio:chemical:sps30: Fix timestamp alignment (bnc#1012628).
- USB: serial: ch341: fix lockup of devices with limited prescaler
  (bnc#1012628).
- USB: serial: ch341: add basis for quirk detection (bnc#1012628).
- USB: serial: option: add Telit LE910C1-EUX compositions
  (bnc#1012628).
- USB: serial: usb_wwan: do not resubmit rx urb on fatal errors
  (bnc#1012628).
- USB: serial: qcserial: add DW5816e QDL support (bnc#1012628).
- commit 936fe4f
* Wed Jun 10 2020 jslaby@suse.cz
- syscalls: fix offset type of ksys_ftruncate (bsc#1172699).
- commit 8d4977c
* Tue Jun  9 2020 dmueller@suse.com
- armv7/ararch64: Update config files.
  Enable IOMMU_DEFAULT_PASSTHROUGH; per jsc#SLE-5568 this should be on by
  default, like on x86_64.
- commit bb34387
* Mon Jun  8 2020 jslaby@suse.cz
- Refresh
  patches.suse/jbd2-avoid-leaking-transaction-credits-when-unreserv.patch.
  Update upstream status.
- commit c3ae43f
* Mon Jun  8 2020 jslaby@suse.cz
- KVM: x86/mmu: Set mmio_value to '0' if reserved #PF can't be
  generated (bsc#1171904).
- KVM: x86: only do L1TF workaround on affected processors
  (bsc#1171904).
- commit 16721c7
* Mon Jun  8 2020 jslaby@suse.cz
- Linux 5.7.1 (bnc#1012628).
- airo: Fix read overflows sending packets (bnc#1012628).
- net: dsa: mt7530: set CPU port to fallback mode (bnc#1012628).
- media: staging: ipu3-imgu: Move alignment attribute to field
  (bnc#1012628).
- media: Revert "staging: imgu: Address a compiler warning on
  alignment" (bnc#1012628).
- mmc: fix compilation of user API (bnc#1012628).
- kernel/relay.c: handle alloc_percpu returning NULL in relay_open
  (bnc#1012628).
- crypto: api - Fix use-after-free and race in crypto_spawn_alg
  (bnc#1012628).
- mt76: mt76x02u: Add support for newer versions of the XBox
  One wifi adapter (bnc#1012628).
- p54usb: add AirVasT USB stick device-id (bnc#1012628).
- HID: i2c-hid: add Schneider SCL142ALM to descriptor override
  (bnc#1012628).
- HID: multitouch: enable multi-input as a quirk for some devices
  (bnc#1012628).
- HID: sony: Fix for broken buttons on DS3 USB dongles
  (bnc#1012628).
- mm: Fix mremap not considering huge pmd devmap (bnc#1012628).
- media: dvbdev: Fix tuner->demod media controller link
  (bnc#1012628).
- commit cc2f849
* Thu Jun  4 2020 mkubecek@suse.cz
- config: refresh with gcc10
  gcc10 is default in Tumbleweed now.
- commit 0b1e86b
* Wed Jun  3 2020 jslaby@suse.cz
- Revert "Update config files."
  This reverts commit 34be040b91701c047e592935bc2dbb46a3947a56. We now
  have a fix (previous commit) in place, so change the configuration back
  (bsc#1156053).
- commit f4546fe
* Wed Jun  3 2020 jslaby@suse.cz
- usercopy: mark dma-kmalloc caches as usercopy caches
  (bsc#1156053).
- commit d3b5ce7
* Tue Jun  2 2020 jslaby@suse.cz
- jbd2: avoid leaking transaction credits when unreserving handle
  (bnc#1169774).
- commit 8599ef4
* Tue Jun  2 2020 jslaby@suse.cz
- jbd2: avoid leaking transaction credits when unreserving handle
  (bnc#1169774).
- Delete
  patches.suse/Revert-ext4-make-dioread_nolock-the-default.patch.
  Replace revert by the upstream fix.
- commit bfa465b
* Tue Jun  2 2020 jslaby@suse.cz
- Refresh
  patches.suse/drm-nouveau-Fix-regression-by-audio-component-transition.patch.
  Update upstream status.
- commit 3000ce5
* Mon Jun  1 2020 mkubecek@suse.cz
- config: enable DEBUG_INFO_BTF
  This was disabled when the option was introduced in 5.2-rc1 but it turned
  out there are interesting use cases for having it enabled.
  Add pahole to build time dependencies as it is used to extracth the BTF
  data. Once we figure out how to make it conditional (only if DEBUG_INFO_BTF
  exists and is enabled), it should be done in packaging branch.
- commit 9ddab66
* Mon Jun  1 2020 mkubecek@suse.cz
- Updated to 5.7 final
- refresh configs
- commit 7cd0da5
* Thu May 28 2020 jslaby@suse.cz
- Update config files.
- commit 6dba057
* Thu May 28 2020 jslaby@suse.cz
- Revert "virtio-balloon: Revert "virtio-balloon: Switch back to
  OOM handler for VIRTIO_BALLOON_F_DEFLATE_ON_OOM"" (virtio fix).
- commit fe7831e
* Thu May 28 2020 jslaby@suse.cz
- Linux 5.6.15 (bnc#1012628).
- blacklist.conf: remove one entry
- sched/fair: Fix enqueue_task_fair() warning some more
  (bnc#1012628).
- sched/fair: Fix reordering of enqueue/dequeue_task_fair()
  (bnc#1012628).
- sched/fair: Reorder enqueue/dequeue_task_fair path
  (bnc#1012628).
- bpf: Prevent mmap()'ing read-only maps as writable
  (bnc#1012628).
- rxrpc: Fix ack discard (bnc#1012628).
- rxrpc: Trace discarded ACKs (bnc#1012628).
- x86/unwind/orc: Fix unwind_get_return_address_ptr() for inactive
  tasks (bnc#1012628).
- flow_dissector: Drop BPF flow dissector prog ref on netns
  cleanup (bnc#1012628).
- s390/kexec_file: fix initrd location for kdump kernel
  (bnc#1012628).
- tpm: check event log version before reading final events
  (bnc#1012628).
- rxrpc: Fix a memory leak in rxkad_verify_response()
  (bnc#1012628).
- rxrpc: Fix the excessive initial retransmission timeout
  (bnc#1012628).
- iio: imu: st_lsm6dsx: unlock on error in
  st_lsm6dsx_shub_write_raw() (bnc#1012628).
- z3fold: fix use-after-free when freeing handles (bnc#1012628).
- sparc32: fix page table traversal in srmmu_nocache_init()
  (bnc#1012628).
- sparc32: use PUD rather than PGD to get PMD in
  srmmu_nocache_init() (bnc#1012628).
- sh: include linux/time_types.h for sockios (bnc#1012628).
- kasan: disable branch tracing for core runtime (bnc#1012628).
- rapidio: fix an error in get_user_pages_fast() error handling
  (bnc#1012628).
- device-dax: don't leak kernel memory to user space after
  unloading kmem (bnc#1012628).
- s390/kaslr: add support for R_390_JMP_SLOT relocation type
  (bnc#1012628).
- s390/pci: Fix s390_mmio_read/write with MIO (bnc#1012628).
- ipack: tpci200: fix error return code in tpci200_register()
  (bnc#1012628).
- mei: release me_cl object reference (bnc#1012628).
- tty: serial: add missing spin_lock_init for SiFive serial
  console (bnc#1012628).
- misc: rtsx: Add short delay after exit from ASPM (bnc#1012628).
- driver core: Fix handling of SYNC_STATE_ONLY + STATELESS device
  links (bnc#1012628).
- driver core: Fix SYNC_STATE_ONLY device link implementation
  (bnc#1012628).
- iio: adc: ti-ads8344: Fix channel selection (bnc#1012628).
- iio: dac: vf610: Fix an error handling path in
  'vf610_dac_probe()' (bnc#1012628).
- iio: sca3000: Remove an erroneous 'get_device()' (bnc#1012628).
- iio: adc: stm32-dfsdm: fix device used to request dma
  (bnc#1012628).
- iio: adc: stm32-adc: fix device used to request dma
  (bnc#1012628).
- staging: greybus: Fix uninitialized scalar variable
  (bnc#1012628).
- staging: kpc2000: fix error return code in kp2000_pcie_probe()
  (bnc#1012628).
- staging: wfx: unlock on error path (bnc#1012628).
- staging: iio: ad2s1210: Fix SPI reading (bnc#1012628).
- kbuild: Remove debug info from kallsyms linking (bnc#1012628).
- tools/bootconfig: Fix apply_xbc() to return zero on success
  (bnc#1012628).
- Revert "driver core: platform: Initialize dma_parms for platform
  devices" (bnc#1012628).
- virtio-balloon: Revert "virtio-balloon: Switch back to OOM
  handler for VIRTIO_BALLOON_F_DEFLATE_ON_OOM" (bnc#1012628).
- Revert "gfs2: Don't demote a glock until its revokes are
  written" (bnc#1012628).
- drm/i915: Propagate error from completed fences (bnc#1012628).
- drm/i915/gvt: Init DPLL/DDI vreg for virtual display instead
  of inheritance (bnc#1012628).
- vsprintf: don't obfuscate NULL and error pointers (bnc#1012628).
- dmaengine: owl: Use correct lock in owl_dma_get_pchan()
  (bnc#1012628).
- dmaengine: idxd: fix interrupt completion after unmasking
  (bnc#1012628).
- dmaengine: dmatest: Restore default for channel (bnc#1012628).
- drm/etnaviv: Fix a leak in submit_pin_objects() (bnc#1012628).
- dmaengine: tegra210-adma: Fix an error handling path in
  'tegra_adma_probe()' (bnc#1012628).
- apparmor: Fix aa_label refcnt leak in policy_update
  (bnc#1012628).
- apparmor: fix potential label refcnt leak in aa_change_profile
  (bnc#1012628).
- apparmor: Fix use-after-free in aa_audit_rule_init
  (bnc#1012628).
- pinctrl: qcom: Add affinity callbacks to msmgpio IRQ chip
  (bnc#1012628).
- drm/etnaviv: fix perfmon domain interation (bnc#1012628).
- powerpc/64s: Disable STRICT_KERNEL_RWX (bnc#1012628).
- arm64: Fix PTRACE_SYSEMU semantics (bnc#1012628).
- scsi: target: Put lun_ref at end of tmr processing
  (bnc#1012628).
- scsi: qla2xxx: Do not log message when reading port speed via
  sysfs (bnc#1012628).
- ALSA: hda/realtek - Add more fixup entries for Clevo machines
  (bnc#1012628).
- ALSA: hda/realtek - Fix silent output on Gigabyte X570 Aorus
  Xtreme (bnc#1012628).
- ALSA: pcm: fix incorrect hw_base increase (bnc#1012628).
- ALSA: iec1712: Initialize STDSP24 properly when using the
  model=staudio option (bnc#1012628).
- bpf: Add bpf_probe_read_{user, kernel}_str() to
  do_refine_retval_range (bnc#1012628).
- bpf: Restrict bpf_probe_read{, str}() only to archs where they
  work (bnc#1012628).
- Update config files.
- ALSA: hda/realtek: Enable headset mic of ASUS UX581LV with
  ALC295 (bnc#1012628).
- ALSA: hda/realtek - Enable headset mic of ASUS UX550GE with
  ALC295 (bnc#1012628).
- ALSA: hda/realtek - Enable headset mic of ASUS GL503VM with
  ALC295 (bnc#1012628).
- ALSA: hda/realtek: Add quirk for Samsung Notebook (bnc#1012628).
- ALSA: hda/realtek - Add HP new mute led supported for ALC236
  (bnc#1012628).
- ALSA: hda/realtek - Add supported new mute Led for HP
  (bnc#1012628).
- scripts/gdb: repair rb_first() and rb_last() (bnc#1012628).
- tools/bootconfig: Fix resource leak in apply_xbc()
  (bnc#1012628).
- ARM: futex: Address build warning (bnc#1012628).
- KVM: selftests: Fix build for evmcs.h (bnc#1012628).
- drm/amd/display: Prevent dpcd reads with passive dongles
  (bnc#1012628).
- drm/amd/display: fix counter in wait_for_no_pipes_pending
  (bnc#1012628).
- iommu/amd: Call domain_flush_complete() in update_domain()
  (bnc#1012628).
- iommu/amd: Do not loop forever when trying to increase address
  space (bnc#1012628).
- platform/x86: asus-nb-wmi: Do not load on Asus T100TA and T200TA
  (bnc#1012628).
- USB: core: Fix misleading driver bug report (bnc#1012628).
- stmmac: fix pointer check after utilization in stmmac_interrupt
  (bnc#1012628).
- ceph: fix double unlock in handle_cap_export() (bnc#1012628).
- HID: quirks: Add HID_QUIRK_NO_INIT_REPORTS quirk for Dell K12A
  keyboard-dock (bnc#1012628).
- gtp: set NLM_F_MULTI flag in gtp_genl_dump_pdp() (bnc#1012628).
- x86/apic: Move TSC deadline timer debug printk (bnc#1012628).
- selftests: fix kvm relocatable native/cross builds and installs
  (bnc#1012628).
- ftrace/selftest: make unresolved cases cause failure if
  - -fail-unresolved set (bnc#1012628).
- ibmvnic: Skip fatal error reset after passive init
  (bnc#1012628).
- HID: i2c-hid: reset Synaptics SYNA2393 on resume (bnc#1012628).
- scsi: ibmvscsi: Fix WARN_ON during event pool release
  (bnc#1012628).
- net/ena: Fix build warning in ena_xdp_set() (bnc#1012628).
- component: Silence bind error on -EPROBE_DEFER (bnc#1012628).
- aquantia: Fix the media type of AQC100 ethernet controller in
  the driver (bnc#1012628).
- vhost/vsock: fix packet delivery order to monitoring devices
  (bnc#1012628).
- configfs: fix config_item refcnt leak in configfs_rmdir()
  (bnc#1012628).
- scsi: qla2xxx: Delete all sessions before unregister local
  nvme port (bnc#1012628).
- scsi: qla2xxx: Fix hang when issuing nvme disconnect-all in NPIV
  (bnc#1012628).
- HID: alps: ALPS_1657 is too specific; use U1_UNICORN_LEGACY
  instead (bnc#1012628).
- HID: alps: Add AUI1657 device ID (bnc#1012628).
- HID: logitech: Add support for Logitech G11 extra keys
  (bnc#1012628).
- HID: multitouch: add eGalaxTouch P80H84 support (bnc#1012628).
- gcc-common.h: Update for GCC 10 (bnc#1012628).
- net: drop_monitor: use IS_REACHABLE() to guard
  net_dm_hw_report() (bnc#1012628).
- kbuild: avoid concurrency issue in parallel building dtbs and
  dtbs_check (bnc#1012628).
- iommu: Fix deferred domain attachment (bnc#1012628).
- mtd: Fix mtd not registered due to nvmem name collision
  (bnc#1012628).
- afs: Don't unlock fetched data pages until the op completes
  successfully (bnc#1012628).
- ubi: Fix seq_file usage in detailed_erase_block_info debugfs
  file (bnc#1012628).
- i2c: mux: demux-pinctrl: Fix an error handling path in
  'i2c_demux_pinctrl_probe()' (bnc#1012628).
- evm: Fix a small race in init_desc() (bnc#1012628).
- iommu/amd: Fix get_acpihid_device_id() (bnc#1012628).
- iommu/amd: Fix over-read of ACPI UID from IVRS table
  (bnc#1012628).
- i2c: fix missing pm_runtime_put_sync in i2c_device_probe
  (bnc#1012628).
- ubifs: remove broken lazytime support (bnc#1012628).
- pipe: Fix pipe_full() test in opipe_prep() (bnc#1012628).
- fix multiplication overflow in copy_fdtable() (bnc#1012628).
- mtd: spinand: Propagate ECC information to the MTD structure
  (bnc#1012628).
- ACPI: EC: PM: Avoid flushing EC work when EC GPE is inactive
  (bnc#1012628).
- ubifs: fix wrong use of crypto_shash_descsize() (bnc#1012628).
- ovl: potential crash in ovl_fid_to_fh() (bnc#1012628).
- ima: Fix return value of ima_write_policy() (bnc#1012628).
- evm: Check also if *tfm is an error pointer in init_desc()
  (bnc#1012628).
- ima: Set file->f_mode instead of file->f_flags in
  ima_calc_file_hash() (bnc#1012628).
- ARC: [plat-hsdk]: fix USB regression (bnc#1012628).
- i2c: dev: Fix the race between the release of i2c_dev and cdev
  (bnc#1012628).
- commit 5afc154
* Tue May 26 2020 trenn@suse.com
- Update config files.
  Remove ACPI_PROCFS_POWER
  This should all be in sysfs nowadays. If this is in Tumbleweed for a while,
  a patch to totally remove this code will be sent mainline.
  Related to bsc#1160977
- commit 96731f2
* Tue May 26 2020 msuchanek@suse.de
- rpm/kernel-source.spec.in: Add obsolete_rebuilds (boo#1172073).
- commit 6524463
* Mon May 25 2020 mkubecek@suse.cz
- Update to 5.7-rc7
- refresh configs (ARCH_HAS_STRICT_KERNEL_RWX=n on ppc64/ppc64le)
- commit 67f7fb5
* Wed May 20 2020 jslaby@suse.cz
- Linux 5.6.14 (bnc#1012628).
- KVM: nVMX: Consolidate nested MTF checks to helper function
  (bnc#1012628).
- kvm: nVMX: reflect MTF VM-exits if injected by L1 (bnc#1012628).
- xprtrdma: Clean up the post_send path (bnc#1012628).
- xprtrdma: Fix trace point use-after-free race (bnc#1012628).
- drm/i915/tgl: Add Wa_14010477008:tgl (bnc#1012628).
- drm/i915/tgl: TBT AUX should use TC power well ops
  (bnc#1012628).
- drm/i915/display: Load DP_TP_CTL/STATUS offset before use it
  (bnc#1012628).
- shmem: fix possible deadlocks on shmlock_user_lock
  (bnc#1012628).
- net: phy: microchip_t1: add lan87xx_phy_init to initialize
  the lan87xx phy (bnc#1012628).
- KVM: arm: vgic: Synchronize the whole guest on
  GIC{D,R}_I{S,C}ACTIVER read (bnc#1012628).
- KVM: arm: vgic-v2: Only use the virtual state when userspace
  accesses pending bits (bnc#1012628).
- gpio: pca953x: Fix pca953x_gpio_set_config (bnc#1012628).
- SUNRPC: Add "@len" parameter to gss_unwrap() (bnc#1012628).
- SUNRPC: Fix GSS privacy computation of auth->au_ralign
  (bnc#1012628).
- net/sonic: Fix a resource leak in an error handling path in
  'jazz_sonic_probe()' (bnc#1012628).
- net: moxa: Fix a potential double 'free_irq()' (bnc#1012628).
- ftrace/selftests: workaround cgroup RT scheduling issues
  (bnc#1012628).
- hv_netvsc: Fix netvsc_start_xmit's return type (bnc#1012628).
- drop_monitor: work around gcc-10 stringop-overflow warning
  (bnc#1012628).
- virtio-blk: handle block_device_operations callbacks after
  hot unplug (bnc#1012628).
- sun6i: dsi: fix gcc-4.8 (bnc#1012628).
- net_sched: fix tcm_parent in tc filter dump (bnc#1012628).
- net: stmmac: gmac5+: fix potential integer overflow on 32 bit
  multiply (bnc#1012628).
- iommu/amd: Fix race in increase_address_space()/fetch_pte()
  (bnc#1012628).
- iommu/amd: Update Device Table in increase_address_space()
  (bnc#1012628).
- net: dsa: ocelot: the MAC table on Felix is twice as large
  (bnc#1012628).
- net: mscc: ocelot: ANA_AUTOAGE_AGE_PERIOD holds a value in
  seconds, not ms (bnc#1012628).
- mmc: sdhci-acpi: Add SDHCI_QUIRK2_BROKEN_64_BIT_DMA for AMDI0040
  (bnc#1012628).
- dpaa2-eth: properly handle buffer size restrictions
  (bnc#1012628).
- mptcp: set correct vfs info for subflows (bnc#1012628).
- net: fix a potential recursive NETDEV_FEAT_CHANGE (bnc#1012628).
- netlabel: cope with NULL catmap (bnc#1012628).
- net: phy: fix aneg restart in phy_ethtool_set_eee (bnc#1012628).
- net: stmmac: fix num_por initialization (bnc#1012628).
- pppoe: only process PADT targeted at local interfaces
  (bnc#1012628).
- Revert "ipv6: add mtu lock check in __ip6_rt_update_pmtu"
  (bnc#1012628).
- tcp: fix error recovery in tcp_zerocopy_receive() (bnc#1012628).
- tcp: fix SO_RCVLOWAT hangs with fat skbs (bnc#1012628).
- virtio_net: fix lockdep warning on 32 bit (bnc#1012628).
- dpaa2-eth: prevent array underflow in update_cls_rule()
  (bnc#1012628).
- hinic: fix a bug of ndo_stop (bnc#1012628).
- net: dsa: loop: Add module soft dependency (bnc#1012628).
- net: ipv4: really enforce backoff for redirects (bnc#1012628).
- netprio_cgroup: Fix unlimited memory leak of v2 cgroups
  (bnc#1012628).
- net: tcp: fix rx timestamp behavior for tcp_recvmsg
  (bnc#1012628).
- nfp: abm: fix error return code in nfp_abm_vnic_alloc()
  (bnc#1012628).
- r8169: re-establish support for RTL8401 chip version
  (bnc#1012628).
- umh: fix memory leak on execve failure (bnc#1012628).
- net: broadcom: Select BROADCOM_PHY for BCMGENET (bnc#1012628).
- dmaengine: xilinx_dma: Add missing check for empty list
  (bnc#1012628).
- riscv: fix vdso build with lld (bnc#1012628).
- dmaengine: pch_dma.c: Avoid data race between probe and irq
  handler (bnc#1012628).
- dmaengine: mmp_tdma: Do not ignore slave config validation
  errors (bnc#1012628).
- dmaengine: mmp_tdma: Reset channel error on release
  (bnc#1012628).
- drm/amd/display: blank dp stream before re-train the link
  (bnc#1012628).
- selftests/ftrace: Check the first record for kprobe_args_type.tc
  (bnc#1012628).
- cpufreq: intel_pstate: Only mention the BIOS disabling turbo
  mode once (bnc#1012628).
- ALSA: hda/hdmi: fix race in monitor detection during probe
  (bnc#1012628).
- drm/amd/powerplay: avoid using pm_en before it is initialized
  revised (bnc#1012628).
- drm/amd/display: check if REFCLK_CNTL register is present
  (bnc#1012628).
- drm/amd/display: Defer cursor update around VUPDATE for all ASIC
  (bnc#1012628).
- drm/amd/display: Update downspread percent to match spreadsheet
  for DCN2.1 (bnc#1012628).
- drm/qxl: lost qxl_bo_kunmap_atomic_page in
  qxl_image_init_helper() (bnc#1012628).
- fibmap: Warn and return an error in case of block > INT_MAX
  (bnc#1012628).
- io_uring: use cond_resched() in io_ring_ctx_wait_and_kill()
  (bnc#1012628).
- io_uring: check non-sync defer_list carefully (bnc#1012628).
- ALSA: hda/realtek - Fix S3 pop noise on Dell Wyse (bnc#1012628).
- gfs2: Another gfs2_walk_metadata fix (bnc#1012628).
- mmc: sdhci-pci-gli: Fix no irq handler from suspend
  (bnc#1012628).
- IB/hfi1: Fix another case where pq is left on waitlist
  (bnc#1012628).
- ACPI: EC: PM: Avoid premature returns from acpi_s2idle_wake()
  (bnc#1012628).
- pinctrl: sunrisepoint: Fix PAD lock register offset for SPT-H
  (bnc#1012628).
- pinctrl: baytrail: Enable pin configuration setting for GPIO
  chip (bnc#1012628).
- pinctrl: qcom: fix wrong write in update_dual_edge
  (bnc#1012628).
- pinctrl: cherryview: Add missing spinlock usage in
  chv_gpio_irq_handler (bnc#1012628).
- drm/tegra: Fix SMMU support on Tegra124 and Tegra210
  (bnc#1012628).
- bpf: Fix error return code in map_lookup_and_delete_elem()
  (bnc#1012628).
- ALSA: firewire-lib: fix 'function sizeof not defined' error
  of tracepoints format (bnc#1012628).
- cachefiles: Fix corruption of the return value in
  cachefiles_read_or_alloc_pages() (bnc#1012628 boo#1168841).
- i40iw: Fix error handling in i40iw_manage_arp_cache()
  (bnc#1012628).
- drm/i915/gt: Make timeslicing an explicit engine property
  (bnc#1012628).
- drm/i915: Don't enable WaIncreaseLatencyIPCEnabled when IPC
  is disabled (bnc#1012628).
- bpf, sockmap: msg_pop_data can incorrecty set an sge length
  (bnc#1012628).
- bpf, sockmap: bpf_tcp_ingress needs to subtract bytes from
  sg.size (bnc#1012628).
- drm/i915/gem: Remove object_is_locked assertion from
  unpin_from_display_plane (bnc#1012628).
- mmc: alcor: Fix a resource leak in the error path for ->probe()
  (bnc#1012628).
- mmc: sdhci-pci-gli: Fix can not access GL9750 after reboot
  from Windows 10 (bnc#1012628).
- mmc: core: Check request type before completing the request
  (bnc#1012628).
- mmc: core: Fix recursive locking issue in CQE recovery path
  (bnc#1012628).
- mmc: block: Fix request completion in the CQE timeout path
  (bnc#1012628).
- gfs2: More gfs2_find_jhead fixes (bnc#1012628).
- fork: prevent accidental access to clone3 features
  (bnc#1012628).
- drm/amdgpu: force fbdev into vram (bnc#1012628).
- NFS: Fix fscache super_cookie index_key from changing after
  umount (bnc#1012628).
- NFS: Fix fscache super_cookie allocation (bnc#1012628).
- NFSv4: Fix fscache cookie aux_data to ensure change_attr is
  included (bnc#1012628).
- hwmon: (drivetemp) Fix SCT support if SCT data tables are not
  supported (bnc#1012628).
- netfilter: conntrack: avoid gcc-10 zero-length-bounds warning
  (bnc#1012628).
- drm/i915/gvt: Fix kernel oops for 3-level ppgtt guest
  (bnc#1012628).
- arm64: fix the flush_icache_range arguments in machine_kexec
  (bnc#1012628).
- netfilter: conntrack: fix infinite loop on rmmod (bnc#1012628).
- drm/i915: Mark concurrent submissions with a weak-dependency
  (bnc#1012628).
- nfs: fix NULL deference in nfs4_get_valid_delegation
  (bnc#1012628).
- SUNRPC: Signalled ASYNC tasks need to exit (bnc#1012628).
- netfilter: flowtable: set NF_FLOW_TEARDOWN flag on entry
  expiration (bnc#1012628).
- netfilter: nft_set_rbtree: Add missing expired checks
  (bnc#1012628).
- RDMA/rxe: Always return ERR_PTR from rxe_create_mmap_info()
  (bnc#1012628).
- IB/mlx4: Test return value of calls to ib_get_cached_pkey
  (bnc#1012628).
- IB/core: Fix potential NULL pointer dereference in pkey cache
  (bnc#1012628).
- RDMA/core: Fix double put of resource (bnc#1012628).
- RDMA/iw_cxgb4: Fix incorrect function parameters (bnc#1012628).
- x86/ftrace: Have ftrace trampolines turn read-only at the end
  of system boot up (bnc#1012628).
- hwmon: (da9052) Synchronize access with mfd (bnc#1012628).
- s390/ism: fix error return code in ism_probe() (bnc#1012628).
- drm/i915: Handle idling during i915_gem_evict_something busy
  loops (bnc#1012628).
- mm, memcg: fix inconsistent oom event behavior (bnc#1012628).
- epoll: call final ep_events_available() check under the lock
  (bnc#1012628).
- bpf: Fix bug in mmap() implementation for BPF array map
  (bnc#1012628).
- NFSv3: fix rpc receive buffer size for MOUNT call (bnc#1012628).
- pnp: Use list_for_each_entry() instead of open coding
  (bnc#1012628).
- net/rds: Use ERR_PTR for rds_message_alloc_sgs() (bnc#1012628).
- Stop the ad-hoc games with -Wno-maybe-initialized (bnc#1012628).
- gcc-10: disable 'zero-length-bounds' warning for now
  (bnc#1012628).
- gcc-10: disable 'array-bounds' warning for now (bnc#1012628).
- gcc-10: disable 'stringop-overflow' warning for now
  (bnc#1012628).
- gcc-10: disable 'restrict' warning for now (bnc#1012628).
- gcc-10 warnings: fix low-hanging fruit (bnc#1012628).
- gcc-10: mark more functions __init to avoid section mismatch
  warnings (bnc#1012628).
- gcc-10: avoid shadowing standard library 'free()' in crypto
  (bnc#1012628).
- bootconfig: Fix to remove bootconfig data from initrd while boot
  (bnc#1012628).
- bootconfig: Fix to prevent warning message if no bootconfig
  option (bnc#1012628).
- usb: usbfs: correct kernel->user page attribute mismatch
  (bnc#1012628).
- USB: usbfs: fix mmap dma mismatch (bnc#1012628).
- ALSA: hda/realtek - Add COEF workaround for ASUS ZenBook UX431DA
  (bnc#1012628).
- ALSA: rawmidi: Fix racy buffer resize under concurrent accesses
  (bnc#1012628).
- ALSA: usb-audio: Add control message quirk delay for Kingston
  HyperX headset (bnc#1012628).
- usb: core: hub: limit HUB_QUIRK_DISABLE_AUTOSUSPEND to USB5534B
  (bnc#1012628).
- usb: host: xhci-plat: keep runtime active when removing host
  (bnc#1012628).
- usb: cdns3: gadget: prev_req->trb is NULL for ep0 (bnc#1012628).
- USB: gadget: fix illegal array access in binding with UDC
  (bnc#1012628).
- usb: xhci: Fix NULL pointer dereference when enqueuing trbs
  from urb sg list (bnc#1012628).
- ARM: dts: dra7: Fix bus_dma_limit for PCIe (bnc#1012628).
- ARM: dts: imx27-phytec-phycard-s-rdk: Fix the I2C1 pinctrl
  entries (bnc#1012628).
- ARM: dts: imx6dl-yapp4: Fix Ursa board Ethernet connection
  (bnc#1012628).
- drm/amd/display: add basic atomic check for cursor plane
  (bnc#1012628).
- drm/amd/amdgpu: add raven1 part to the gfxoff quirk list
  (bnc#1012628).
- drm/i915/tgl+: Fix interrupt handling for DP AUX transactions
  (bnc#1012628).
- powerpc/vdso32: Fallback on getres syscall when clock is unknown
  (bnc#1012628).
- powerpc/32s: Fix build failure with CONFIG_PPC_KUAP_DEBUG
  (bnc#1012628).
- cifs: fix leaked reference on requeued write (bnc#1012628).
- KVM: x86: Fix pkru save/restore when guest CR4.PKE=0, move it
  to x86.c (bnc#1012628).
- x86/unwind/orc: Fix error handling in __unwind_start()
  (bnc#1012628).
- exec: Move would_dump into flush_old_exec (bnc#1012628).
- clk: rockchip: fix incorrect configuration of rk3228 aclk_gpu*
  clocks (bnc#1012628).
- dwc3: Remove check for HWO flag in
  dwc3_gadget_ep_reclaim_trb_sg() (bnc#1012628).
- fanotify: fix merging marks masks with FAN_ONDIR (bnc#1012628).
- arm64: dts: meson-g12b-ugoos-am6: fix usb vbus-supply
  (bnc#1012628).
- usb: gadget: tegra-xudc: Fix idle suspend/resume (bnc#1012628).
- usb: gadget: net2272: Fix a memory leak in an error handling
  path in 'net2272_plat_probe()' (bnc#1012628).
- usb: gadget: audio: Fix a missing error return value in
  audio_bind() (bnc#1012628).
- usb: gadget: legacy: fix error return code in gncm_bind()
  (bnc#1012628).
- usb: gadget: legacy: fix error return code in cdc_bind()
  (bnc#1012628).
- Revert "ALSA: hda/realtek: Fix pop noise on ALC225"
  (bnc#1012628).
- clk: ti: clkctrl: Fix Bad of_node_put within clkctrl_get_name
  (bnc#1012628).
- clk: Unlink clock if failed to prepare or enable (bnc#1012628).
- arm64: dts: meson-g12b-khadas-vim3: add missing frddr_a status
  property (bnc#1012628).
- arm64: dts: qcom: msm8996: Reduce vdd_apc voltage (bnc#1012628).
- arm64: dts: meson-g12-common: fix dwc2 clock names
  (bnc#1012628).
- arm64: dts: rockchip: Replace RK805 PMIC node name with "pmic"
  on rk3328 boards (bnc#1012628).
- arm64: dts: rockchip: Rename dwc3 device nodes on rk3399 to
  make dtc happy (bnc#1012628).
- arm64: dts: imx8mn: Change SDMA1 ahb clock for imx8mn
  (bnc#1012628).
- ARM: dts: r8a73a4: Add missing CMT1 interrupts (bnc#1012628).
- arm64: dts: renesas: r8a77980: Fix IPMMU VIP[01] nodes
  (bnc#1012628).
- ARM: dts: r8a7740: Add missing extal2 to CPG node (bnc#1012628).
- dt-bindings: dma: fsl-edma: fix ls1028a-edma compatible
  (bnc#1012628).
- SUNRPC: Revert 241b1f419f0e ("SUNRPC: Remove xdr_buf_trim()")
  (bnc#1012628).
- bpf: Fix sk_psock refcnt leak when receiving message
  (bnc#1012628).
- powerpc/uaccess: Evaluate macro arguments once, before user
  access is allowed (bnc#1012628).
- powerpc/ima: Fix secure boot rules in ima arch policy
  (bnc#1012628).
- RDMA/uverbs: Do not discard the IB_EVENT_DEVICE_FATAL event
  (bnc#1012628).
- RDMA/uverbs: Move IB_EVENT_DEVICE_FATAL to destroy_uobj
  (bnc#1012628).
- riscv: perf: RISCV_BASE_PMU should be independent (bnc#1012628).
- KVM: x86: Fix off-by-one error in kvm_vcpu_ioctl_x86_setup_mce
  (bnc#1012628).
- bpf: Enforce returning 0 for fentry/fexit progs (bnc#1012628).
- selftests/bpf: Enforce returning 0 for fentry/fexit programs
  (bnc#1012628).
- bpf: Restrict bpf_trace_printk()'s %%s usage and add %%pks,
  %%pus specifier (bnc#1012628).
- Delete patches.suse/cachefiles-fix.patch.
- commit b0ab48a
* Tue May 19 2020 jslaby@suse.cz
- Makefile: disallow data races on gcc-10 as well (gcc 10).
- commit 3c26bf7
* Tue May 19 2020 afaerber@suse.com
- config: armv7hl: Update to 5.7-rc6
- commit 8e7f5b8
* Mon May 18 2020 bp@suse.de
- Replace gcc10 fix with the upstream one
- commit 1adb363
* Mon May 18 2020 jslaby@suse.cz
- Refresh
  patches.suse/ipc-util.c-sysvipc_find_ipc-incorrectly-updates-posi.patch.
  Update upstream status.
- commit f322baa
* Mon May 18 2020 mkubecek@suse.cz
- Update to 5.7-rc6
- eliminated 2 patches
- refresh configs
- commit 3603fcd
* Sun May 17 2020 afaerber@suse.com
- config: armv6hl: Update to 5.7-rc5
- commit 2a4b8c3
* Thu May 14 2020 tiwai@suse.de
- ALSA: hda/realtek - Limit int mic boost for Thinkpad T530
  (bsc#1171293).
- commit 60a84bf
* Thu May 14 2020 jslaby@suse.cz
- tracing: Wait for preempt irq delay thread to execute
  (git-fixes).
- commit 5f84268
* Thu May 14 2020 jslaby@suse.cz
- Linux 5.6.13 (bnc#1012628).
- thunderbolt: Check return value of tb_sw_read() in
  usb4_switch_op() (bnc#1012628).
- USB: serial: qcserial: Add DW5816e support (bnc#1012628).
- drm/amdgpu: move kfd suspend after ip_suspend_phase1
  (bnc#1012628).
- drm/amdgpu: drop redundant cg/pg ungate on runpm enter
  (bnc#1012628).
- vt: fix unicode console freeing with a common interface
  (bnc#1012628).
- tty: xilinx_uartps: Fix missing id assignment to the console
  (bnc#1012628).
- ext4: don't set dioread_nolock by default for blocksize <
  pagesize (bnc#1012628).
- ext4: disable dioread_nolock whenever delayed allocation is
  disabled (bnc#1012628).
- nvme: refactor nvme_identify_ns_descs error handling
  (bnc#1012628).
- nvme: fix possible hang when ns scanning fails during error
  recovery (bnc#1012628).
- tracing/kprobes: Fix a double initialization typo (bnc#1012628).
- net: macb: Fix runtime PM refcounting (bnc#1012628).
- cxgb4: fix EOTID leak when disabling TC-MQPRIO offload
  (bnc#1012628).
- devlink: Fix reporter's recovery condition (bnc#1012628).
- devlink: fix return value after hitting end in region read
  (bnc#1012628).
- dp83640: reverse arguments to list_add_tail (bnc#1012628).
- fq_codel: fix TCA_FQ_CODEL_DROP_BATCH_SIZE sanity checks
  (bnc#1012628).
- ipv6: Use global sernum for dst validation with nexthop objects
  (bnc#1012628).
- mlxsw: spectrum_acl_tcam: Position vchunk in a vregion list
  properly (bnc#1012628).
- neigh: send protocol value in neighbor create notification
  (bnc#1012628).
- net: bridge: vlan: Add a schedule point during VLAN processing
  (bnc#1012628).
- net: dsa: Do not leave DSA master with NULL netdev_ops
  (bnc#1012628).
- net: dsa: Do not make user port errors fatal (bnc#1012628).
- net: macb: fix an issue about leak related system resources
  (bnc#1012628).
- net: macsec: preserve ingress frame ordering (bnc#1012628).
- net/mlx4_core: Fix use of ENOSPC around mlx4_counter_alloc()
  (bnc#1012628).
- net: phy: marvell10g: fix temperature sensor on 2110
  (bnc#1012628).
- net_sched: sch_skbprio: add message validation to
  skbprio_change() (bnc#1012628).
- net: stricter validation of untrusted gso packets (bnc#1012628).
- net: tc35815: Fix phydev supported/advertising mask
  (bnc#1012628).
- net/tls: Fix sk_psock refcnt leak in bpf_exec_tx_verdict()
  (bnc#1012628).
- net/tls: Fix sk_psock refcnt leak when in tls_data_ready()
  (bnc#1012628).
- net: usb: qmi_wwan: add support for DW5816e (bnc#1012628).
- nfp: abm: fix a memory leak bug (bnc#1012628).
- sch_choke: avoid potential panic in choke_reset() (bnc#1012628).
- sch_sfq: validate silly quantum values (bnc#1012628).
- selftests: net: tcp_mmap: clear whole tcp_zerocopy_receive
  struct (bnc#1012628).
- selftests: net: tcp_mmap: fix SO_RCVLOWAT setting (bnc#1012628).
- tipc: fix partial topology connection closure (bnc#1012628).
- tunnel: Propagate ECT(1) when decapsulating as recommended by
  RFC6040 (bnc#1012628).
- bnxt_en: Fix VF anti-spoof filter setup (bnc#1012628).
- bnxt_en: Reduce BNXT_MSIX_VEC_MAX value to supported CQs per PF
  (bnc#1012628).
- bnxt_en: Improve AER slot reset (bnc#1012628).
- bnxt_en: Return error when allocating zero size context memory
  (bnc#1012628).
- bnxt_en: Fix VLAN acceleration handling in bnxt_fix_features()
  (bnc#1012628).
- net/mlx5: DR, On creation set CQ's arm_db member to right value
  (bnc#1012628).
- net/mlx5: Fix forced completion access non initialized command
  entry (bnc#1012628).
- net/mlx5: Fix command entry leak in Internal Error State
  (bnc#1012628).
- net/mlx5e: Fix q counters on uplink representors (bnc#1012628).
- net: mvpp2: prevent buffer overflow in mvpp22_rss_ctx()
  (bnc#1012628).
- net: mvpp2: cls: Prevent buffer overflow in
  mvpp2_ethtool_cls_rule_del() (bnc#1012628).
- wireguard: queueing: cleanup ptr_ring in error path of
  packet_queue_init (bnc#1012628).
- wireguard: receive: use tunnel helpers for decapsulating ECN
  markings (bnc#1012628).
- net: enetc: fix an issue about leak system resources
  (bnc#1012628).
- wireguard: socket: remove errant restriction on looping to self
  (bnc#1012628).
- wireguard: send/receive: cond_resched() when processing worker
  ringbuffers (bnc#1012628).
- HID: wacom: Read HID_DG_CONTACTMAX directly for non-generic
  devices (bnc#1012628).
- sctp: Fix bundling of SHUTDOWN with COOKIE-ACK (bnc#1012628).
- Revert "HID: wacom: generic: read the number of expected
  touches on a per collection basis" (bnc#1012628).
- HID: usbhid: Fix race between usbhid_close() and usbhid_stop()
  (bnc#1012628).
- HID: wacom: Report 2nd-gen Intuos Pro S center button status
  over BT (bnc#1012628).
- USB: uas: add quirk for LaCie 2Big Quadra (bnc#1012628).
- usb: chipidea: msm: Ensure proper controller reset using role
  switch API (bnc#1012628).
- USB: serial: garmin_gps: add sanity checking for data length
  (bnc#1012628).
- tracing/boottime: Fix kprobe event API usage (bnc#1012628).
- tracing/kprobes: Reject new event if loc is NULL (bnc#1012628).
- tracing: Wait for preempt irq delay thread to finish
  (bnc#1012628).
- tracing: Add a vmalloc_sync_mappings() for safe measure
  (bnc#1012628).
- crypto: arch/nhpoly1305 - process in explicit 4k chunks
  (bnc#1012628).
- crypto: arch/lib - limit simd usage to 4k chunks (bnc#1012628).
- KVM: s390: Remove false WARN_ON_ONCE for the PQAP instruction
  (bnc#1012628).
- KVM: VMX: Explicitly clear RFLAGS.CF and RFLAGS.ZF in VM-Exit
  RSB path (bnc#1012628).
- KVM: arm: vgic: Fix limit condition when writing to
  GICD_I[CS]ACTIVER (bnc#1012628).
- KVM: arm64: Fix 32bit PC wrap-around (bnc#1012628).
- arm64: hugetlb: avoid potential NULL dereference (bnc#1012628).
- driver core: platform: Initialize dma_parms for platform devices
  (bnc#1012628).
- amba: Initialize dma_parms for amba devices (bnc#1012628).
- mei: me: disable mei interface on LBG servers (bnc#1012628).
- drm: ingenic-drm: add MODULE_DEVICE_TABLE (bnc#1012628).
- drm/amd/display: work around fp code being emitted outside of
  DC_FP_START/END (bnc#1012628).
- ipc/mqueue.c: change __do_notify() to bypass
  check_kill_permission() (bnc#1012628).
- epoll: atomically remove wait entry on wake up (bnc#1012628).
- eventpoll: fix missing wakeup for ovflist in ep_poll_callback
  (bnc#1012628).
- mm/page_alloc: fix watchdog soft lockups during
  set_zone_contiguous() (bnc#1012628).
- mm: limit boost_watermark on small zones (bnc#1012628).
- ceph: fix endianness bug when handling MDS session feature bits
  (bnc#1012628).
- ceph: demote quotarealm lookup warning to a debug message
  (bnc#1012628).
- staging: gasket: Check the return value of
  gasket_get_bar_index() (bnc#1012628).
- coredump: fix crash when umh is disabled (bnc#1012628).
- riscv: set max_pfn to the PFN of the last page (bnc#1012628).
- iocost: protect iocg->abs_vdebt with iocg->waitq.lock
  (bnc#1012628).
- batman-adv: fix batadv_nc_random_weight_tq (bnc#1012628).
- batman-adv: Fix refcnt leak in batadv_show_throughput_override
  (bnc#1012628).
- batman-adv: Fix refcnt leak in batadv_store_throughput_override
  (bnc#1012628).
- batman-adv: Fix refcnt leak in batadv_v_ogm_process
  (bnc#1012628).
- x86/mm/cpa: Flush direct map alias during cpa (bnc#1012628).
- x86/entry/64: Fix unwind hints in register clearing code
  (bnc#1012628).
- x86/entry/64: Fix unwind hints in kernel exit path
  (bnc#1012628).
- x86/entry/64: Fix unwind hints in __switch_to_asm()
  (bnc#1012628).
- x86/entry/64: Fix unwind hints in rewind_stack_do_exit()
  (bnc#1012628).
- x86/unwind/orc: Don't skip the first frame for inactive tasks
  (bnc#1012628).
- x86/unwind/orc: Prevent unwinding before ORC initialization
  (bnc#1012628).
- x86/unwind/orc: Fix error path for bad ORC entry type
  (bnc#1012628).
- x86/unwind/orc: Fix premature unwind stoppage due to IRET frames
  (bnc#1012628).
- KVM: x86: Fixes posted interrupt check for IRQs delivery modes
  (bnc#1012628).
- arch/x86/kvm/svm/sev.c: change flag passed to GUP fast in
  sev_pin_memory() (bnc#1012628).
- netfilter: nat: never update the UDP checksum when it's 0
  (bnc#1012628).
- netfilter: nf_osf: avoid passing pointer to local var
  (bnc#1012628).
- objtool: Fix stack offset tracking for indirect CFAs
  (bnc#1012628).
- iommu/virtio: Reverse arguments to list_add (bnc#1012628).
- scripts/decodecode: fix trapping instruction formatting
  (bnc#1012628).
- mm, memcg: fix error return value of mem_cgroup_css_alloc()
  (bnc#1012628).
- bdi: move bdi_dev_name out of line (bnc#1012628).
- bdi: add a ->dev_name field to struct backing_dev_info
  (bnc#1012628).
- io_uring: don't use 'fd' for openat/openat2/statx (bnc#1012628).
- fsnotify: replace inode pointer with an object id (bnc#1012628).
- fanotify: merge duplicate events on parent and child
  (bnc#1012628).
- Refresh
  patches.suse/Revert-ext4-make-dioread_nolock-the-default.patch.
- commit 77f44b9
* Thu May 14 2020 msuchanek@suse.de
- rpm/check-for-config-changes: Ignore CONFIG_CC_VERSION_TEXT
- commit 8e6b05f
* Tue May 12 2020 bp@suse.de
- x86: Fix early boot crash on gcc-10, next try (bsc#1167632).
- commit 3afa06d
* Tue May 12 2020 jroedel@suse.de
- kvm: ioapic: Restrict lazy EOI update to edge-triggered interrupts (bsc#1171289).
- commit 9f9d75e
* Mon May 11 2020 jslaby@suse.cz
- Linux 5.6.12 (bnc#1012628).
- mm/mremap: Add comment explaining the untagging behaviour of
  mremap() (bnc#1012628).
- cgroup, netclassid: remove double cond_resched (bnc#1012628).
- mac80211: add ieee80211_is_any_nullfunc() (bnc#1012628).
- ACPI: PM: s2idle: Fix comment in acpi_s2idle_prepare_late()
  (bnc#1012628).
- platform/x86: GPD pocket fan: Fix error message when temp-limits
  are out of range (bnc#1012628).
- x86/kvm: fix a missing-prototypes "vmread_error" (bnc#1012628).
- ALSA: hda: Match both PCI ID and SSID for driver blacklist
  (bnc#1012628).
- drm/amdgpu: Fix oops when pp_funcs is unset in ACPI event
  (bnc#1012628).
- sctp: Fix SHUTDOWN CTSN Ack in the peer restart case
  (bnc#1012628).
- tools/runqslower: Ensure own vmlinux.h is picked up first
  (bnc#1012628).
- net: systemport: suppress warnings on failed Rx SKB allocations
  (bnc#1012628).
- net: bcmgenet: suppress warnings on failed Rx SKB allocations
  (bnc#1012628).
- mac80211: sta_info: Add lockdep condition for RCU list usage
  (bnc#1012628).
- lib/mpi: Fix building for powerpc with clang (bnc#1012628).
- net: phy: bcm84881: clear settings on link down (bnc#1012628).
- ftrace: Fix memory leak caused by not freeing entry in
  unregister_ftrace_direct() (bnc#1012628).
- tracing: Fix memory leaks in trace_events_hist.c (bnc#1012628).
- cifs: do not share tcons with DFS (bnc#1012628).
- scripts/config: allow colons in option strings for sed
  (bnc#1012628).
- cifs: protect updating server->dstaddr with a spinlock
  (bnc#1012628).
- ASoC: rsnd: Fix "status check failed" spam for multi-SSI
  (bnc#1012628).
- ASoC: rsnd: Don't treat master SSI in multi SSI setup as parent
  (bnc#1012628).
- net: stmmac: Fix sub-second increment (bnc#1012628).
- net: stmmac: fix enabling socfpga's ptp_ref_clock (bnc#1012628).
- wimax/i2400m: Fix potential urb refcnt leak (bnc#1012628).
- drm/amdgpu: Correctly initialize thermal controller for GPUs
  with Powerplay table v0 (e.g Hawaii) (bnc#1012628).
- drm/amd/powerplay: fix resume failed as smu table initialize
  early exit (bnc#1012628).
- remoteproc: qcom_q6v5_mss: fix a bug in q6v5_probe()
  (bnc#1012628).
- ASoC: codecs: hdac_hdmi: Fix incorrect use of
  list_for_each_entry (bnc#1012628).
- ASoC: rsnd: Fix HDMI channel mapping for multi-SSI mode
  (bnc#1012628).
- ASoC: rsnd: Fix parent SSI start/stop in multi-SSI mode
  (bnc#1012628).
- usb: dwc3: gadget: Properly set maxpacket limit (bnc#1012628).
- ASoC: topology: Fix endianness issue (bnc#1012628).
- ASoC: sgtl5000: Fix VAG power-on handling (bnc#1012628).
- scsi: sg: add sg_remove_request in sg_write (bnc#1012628).
- drm/bridge: anx6345: set correct BPC for display_info of
  connector (bnc#1012628).
- selftests/ipc: Fix test failure seen after initial test run
  (bnc#1012628).
- Revert "Kernel selftests: tpm2: check for tpm support"
  (bnc#1012628).
- selftests: vm: Fix 64-bit test builds for powerpc64le
  (bnc#1012628).
- selftests: vm: Do not override definition of ARCH (bnc#1012628).
- SUNRPC/cache: Fix unsafe traverse caused double-free in
  cache_purge (bnc#1012628).
- ASoC: topology: Check return value of soc_tplg_dai_config
  (bnc#1012628).
- ASoC: topology: Check return value of pcm_new_ver (bnc#1012628).
- ASoC: topology: Check soc_tplg_add_route return value
  (bnc#1012628).
- ASoC: topology: Check return value of soc_tplg_*_create
  (bnc#1012628).
- ASoC: topology: Check return value of soc_tplg_create_tlv
  (bnc#1012628).
- ASoC: topology: Add missing memory checks (bnc#1012628).
- drm/bridge: analogix_dp: Split bind() into probe() and real
  bind() (bnc#1012628).
- vhost: vsock: kick send_pkt worker once device is started
  (bnc#1012628).
- commit 7501758
* Mon May 11 2020 mkubecek@suse.cz
- Update to 5.7-rc5
- refresh configs
- commit 298ea3d
* Thu May  7 2020 afaerber@suse.com
- config: arm64: Update to 5.7-rc4
- commit 47279b9
* Thu May  7 2020 jzerebecki@suse.com
- kernel-docs: Change Requires on python-Sphinx to earlier than version 3
  References: bsc#1166965
  From 3 on the internal API that the build system uses was rewritten in
  an incompatible way.
  See https://github.com/sphinx-doc/sphinx/issues/7421 and
  https://bugzilla.suse.com/show_bug.cgi?id=1166965#c16 for some details.
- commit cf60b5c
* Wed May  6 2020 jslaby@suse.cz
- Linux 5.6.11 (bnc#1012628).
- drm/scheduler: fix drm_sched_get_cleanup_job (bnc#1012628).
- dma-buf: Fix SET_NAME ioctl uapi (bnc#1012628).
- drm/amdgpu: invalidate L2 before SDMA IBs (v2) (bnc#1012628).
- drm/edid: Fix off-by-one in DispID DTD pixel clock
  (bnc#1012628).
- drm/amd/display: Fix green screen issue after suspend
  (bnc#1012628).
- drm/i915/gem: Hold obj->vma.lock over for_each_ggtt_vma()
  (bnc#1012628).
- drm/i915/gt: Check cacheline is valid before acquiring
  (bnc#1012628).
- drm/qxl: qxl_release leak in qxl_draw_dirty_fb() (bnc#1012628).
- drm/qxl: qxl_release leak in qxl_hw_surface_alloc()
  (bnc#1012628).
- drm/qxl: qxl_release use after free (bnc#1012628).
- NFSv4.1: fix handling of backchannel binding in
  BIND_CONN_TO_SESSION (bnc#1012628).
- btrfs: fix transaction leak in btrfs_recover_relocation
  (bnc#1012628).
- btrfs: fix block group leak when removing fails (bnc#1012628).
- btrfs: fix partial loss of prealloc extent past i_size after
  fsync (bnc#1012628).
- btrfs: transaction: Avoid deadlock due to bad initialization
  timing of fs_info::journal_info (bnc#1012628).
- mmc: cqhci: Avoid false "cqhci: CQE stuck on" by not open-coding
  timeout loop (bnc#1012628).
- mmc: sdhci-xenon: fix annoying 1.8V regulator warning
  (bnc#1012628).
- mmc: sdhci-pci: Fix eMMC driver strength for BYT-based
  controllers (bnc#1012628).
- mmc: sdhci-msm: Enable host capabilities pertains to R1b
  response (bnc#1012628).
- mmc: meson-mx-sdio: Set MMC_CAP_WAIT_WHILE_BUSY (bnc#1012628).
- mmc: meson-mx-sdio: remove the broken ->card_busy() op
  (bnc#1012628).
- crypto: caam - fix the address of the last entry of S/G
  (bnc#1012628).
- ALSA: hda/realtek - Two front mics on a Lenovo ThinkCenter
  (bnc#1012628).
- ALSA: usb-audio: Correct a typo of NuPrime DAC-10 USB ID
  (bnc#1012628).
- ALSA: hda/hdmi: fix without unlocked before return
  (bnc#1012628).
- ALSA: line6: Fix POD HD500 audio playback (bnc#1012628).
- i2c: amd-mp2-pci: Fix Oops in amd_mp2_pci_init() error handling
  (bnc#1012628).
- x86/hyperv: Suspend/resume the VP assist page for hibernation
  (bnc#1012628).
- Drivers: hv: vmbus: Fix Suspend-to-Idle for Generation-2 VM
  (bnc#1012628).
- dlmfs_file_write(): fix the bogosity in handling non-zero *ppos
  (bnc#1012628).
- selinux: properly handle multiple messages in
  selinux_netlink_send() (bnc#1012628).
- IB/rdmavt: Always return ERR_PTR from rvt_create_mmap_info()
  (bnc#1012628).
- PM: ACPI: Output correct message on target power state
  (bnc#1012628).
- PM: hibernate: Freeze kernel threads in software_resume()
  (bnc#1012628).
- dm verity fec: fix hash block number in verity_fec_decode
  (bnc#1012628).
- dm writecache: fix data corruption when reloading the target
  (bnc#1012628).
- dm multipath: use updated MPATHF_QUEUE_IO on mapping for
  bio-based mpath (bnc#1012628).
- ARM: dts: imx6qdl-sr-som-ti: indicate powering off wifi is safe
  (bnc#1012628).
- block: remove the bd_openers checks in blk_drop_partitions
  (bnc#1012628).
- scsi: qla2xxx: set UNLOADING before waiting for session deletion
  (bnc#1012628).
- scsi: qla2xxx: check UNLOADING before posting async work
  (bnc#1012628).
- RDMA/mlx5: Set GRH fields in query QP on RoCE (bnc#1012628).
- RDMA/uverbs: Fix a race with disassociate and exit_mmap()
  (bnc#1012628).
- RDMA/mlx4: Initialize ib_spec on the stack (bnc#1012628).
- RDMA/siw: Fix potential siw_mem refcnt leak in siw_fastreg_mr()
  (bnc#1012628).
- RDMA/core: Prevent mixed use of FDs between shared ufiles
  (bnc#1012628).
- RDMA/core: Fix overwriting of uobj in case of error
  (bnc#1012628).
- RDMA/core: Fix race between destroy and release FD object
  (bnc#1012628).
- RDMA/cm: Fix ordering of xa_alloc_cyclic() in ib_create_cm_id()
  (bnc#1012628).
- RDMA/cm: Fix an error check in cm_alloc_id_priv() (bnc#1012628).
- i2c: iproc: generate stop event for slave writes (bnc#1012628).
- dmaengine: hisilicon: Fix build error without PCI_MSI
  (bnc#1012628).
- vfio: avoid possible overflow in vfio_iommu_type1_pin_pages
  (bnc#1012628).
- vfio/type1: Fix VA->PA translation for PFNMAP VMAs in
  vaddr_get_pfn() (bnc#1012628).
- iommu/qcom: Fix local_base status check (bnc#1012628).
- dmaengine: ti: k3-psil: fix deadlock on error path
  (bnc#1012628).
- dmaengine: fix channel index enumeration (bnc#1012628).
- scsi: target/iblock: fix WRITE SAME zeroing (bnc#1012628).
- iommu: Properly export iommu_group_get_for_dev() (bnc#1012628).
- iommu/vt-d: Use right Kconfig option name (bnc#1012628).
- iommu/amd: Fix legacy interrupt remapping for x2APIC-enabled
  system (bnc#1012628).
- i2c: aspeed: Avoid i2c interrupt status clear race condition
  (bnc#1012628).
- ALSA: opti9xx: shut up gcc-10 range warning (bnc#1012628).
- Fix use after free in get_tree_bdev() (bnc#1012628).
- nvme: prevent double free in nvme_alloc_ns() error handling
  (bnc#1012628).
- drm/i915/selftests: Fix i915_address_space refcnt leak
  (bnc#1012628).
- nfs: Fix potential posix_acl refcnt leak in nfs3_set_acl
  (bnc#1012628).
- dmaengine: dmatest: Fix iteration non-stop logic (bnc#1012628).
- drm/i915: Use proper fault mask in interrupt postinstall too
  (bnc#1012628).
- dmaengine: dmatest: Fix process hang when reading 'wait'
  parameter (bnc#1012628).
- arm64: vdso: Add -fasynchronous-unwind-tables to cflags
  (bnc#1012628).
- io_uring: statx must grab the file table for valid fd
  (bnc#1012628).
- commit 91c024a
* Wed May  6 2020 jslaby@suse.cz
- ipc/util.c: sysvipc_find_ipc() incorrectly updates position
  index (bnc#1171211).
- commit 31ea4f6
* Mon May  4 2020 mkubecek@suse.cz
- Update to 5.7-rc4
- commit 9761f3e
* Sat May  2 2020 jslaby@suse.cz
- Linux 5.6.10 (bnc#1012628).
- Revert "ASoC: meson: axg-card: fix codec-to-codec link setup"
  (bnc#1012628).
- commit de48f93
* Sat May  2 2020 jslaby@suse.cz
- Linux 5.6.9 (bnc#1012628).
- ubifs: Fix ubifs_tnc_lookup() usage in do_kill_orphans()
  (bnc#1012628).
- printk: queue wake_up_klogd irq_work only if per-CPU areas
  are ready (bnc#1012628).
- ASoC: stm32: sai: fix sai probe (bnc#1012628).
- usb: dwc3: gadget: Do link recovery for SS and SSP
  (bnc#1012628).
- ARM: dts: bcm283x: Add cells encoding format to firmware bus
  (bnc#1012628).
- kbuild: fix DT binding schema rule again to avoid needless
  rebuilds (bnc#1012628).
- usb: gadget: udc: bdc: Remove unnecessary NULL checks in
  bdc_req_complete (bnc#1012628).
- usb: gadget: udc: atmel: Fix vbus disconnect handling
  (bnc#1012628).
- afs: Make record checking use TASK_UNINTERRUPTIBLE when
  appropriate (bnc#1012628).
- afs: Fix to actually set AFS_SERVER_FL_HAVE_EPOCH (bnc#1012628).
- iio:ad7797: Use correct attribute_group (bnc#1012628).
- iio: imu: st_lsm6dsx: fix read misalignment on untagged FIFO
  (bnc#1012628).
- iio: imu: st_lsm6dsx: specify slave odr in slv_odr
  (bnc#1012628).
- propagate_one(): mnt_set_mountpoint() needs mount_lock
  (bnc#1012628).
- counter: 104-quad-8: Add lock guards - generic interface
  (bnc#1012628).
- s390/ftrace: fix potential crashes when switching tracers
  (bnc#1012628).
- ASoC: q6dsp6: q6afe-dai: add missing channels to MI2S DAIs
  (bnc#1012628).
- iwlwifi: actually check allocated conf_tlv pointer
  (bnc#1012628).
- ASoC: samsung: s3c24xx-i2s: Fix build after removal of DAI
  suspend/resume (bnc#1012628).
- ASoC: tas571x: disable regulators on failed probe (bnc#1012628).
- ASoC: meson: axg-card: fix codec-to-codec link setup
  (bnc#1012628).
- ASoC: wm8960: Fix wrong clock after suspend & resume
  (bnc#1012628).
- drivers: soc: xilinx: fix firmware driver Kconfig dependency
  (bnc#1012628).
- nfsd: memory corruption in nfsd4_lock() (bnc#1012628).
- ARM: dts: OMAP3: disable RNG on N950/N9 (bnc#1012628).
- bpf: Forbid XADD on spilled pointers for unprivileged users
  (bnc#1012628).
- brcmfmac: add stub for monitor interface xmit (bnc#1012628).
- i2c: altera: use proper variable to hold errno (bnc#1012628).
- hwmon: (drivetemp) Use drivetemp's true module name in Kconfig
  section (bnc#1012628).
- clk: asm9260: fix __clk_hw_register_fixed_rate_with_accuracy
  typo (bnc#1012628).
- rtw88: avoid unused function warnings (bnc#1012628).
- hwmon: (drivetemp) Return -ENODATA for invalid temperatures
  (bnc#1012628).
- rxrpc: Fix DATA Tx to disable nofrag for UDP on AF_INET6 socket
  (bnc#1012628).
- netfilter: nf_tables: reintroduce the NFT_SET_CONCAT flag
  (bnc#1012628).
- net/cxgb4: Check the return from t4_query_params properly
  (bnc#1012628).
- tipc: fix incorrect increasing of link window (bnc#1012628).
- xfs: acquire superblock freeze protection on eofblocks scans
  (bnc#1012628).
- svcrdma: Fix trace point use-after-free race (bnc#1012628).
- svcrdma: Fix leak of svc_rdma_recv_ctxt objects (bnc#1012628).
- net/mlx5e: Don't trigger IRQ multiple times on XSK wakeup to
  avoid WQ overruns (bnc#1012628).
- net/mlx5e: Get the latest values from counters in switchdev mode
  (bnc#1012628).
- PCI: Avoid ASMedia XHCI USB PME# from D0 defect (bnc#1012628).
- PCI: Add Zhaoxin Vendor ID (bnc#1012628).
- PCI: Add ACS quirk for Zhaoxin multi-function devices
  (bnc#1012628).
- PCI: Add ACS quirk for Zhaoxin Root/Downstream Ports
  (bnc#1012628).
- PCI: Move Apex Edge TPU class quirk to fix BAR assignment
  (bnc#1012628).
- ARM: dts: bcm283x: Disable dsi0 node (bnc#1012628).
- cpumap: Avoid warning when CONFIG_DEBUG_PER_CPU_MAPS is enabled
  (bnc#1012628).
- s390/pci: do not set affinity for floating irqs (bnc#1012628).
- remoteproc: mtk_scp: use dma_addr_t for DMA API (bnc#1012628).
- net/mlx5: Fix failing fw tracer allocation on s390
  (bnc#1012628).
- sched/core: Fix reset-on-fork from RT with uclamp (bnc#1012628).
- perf/core: fix parent pid/tid in task exit events (bnc#1012628).
- netfilter: nat: fix error handling upon registering inet hook
  (bnc#1012628).
- PM: sleep: core: Switch back to async_schedule_dev()
  (bnc#1012628).
- blk-iocost: Fix error on iocost_ioc_vrate_adj (bnc#1012628).
- um: ensure `make ARCH=um mrproper` removes
  arch/$(SUBARCH)/include/generated/ (bnc#1012628).
- bpf: Fix handling of XADD on BTF memory (bnc#1012628).
- bpf, x86: Fix encoding for lower 8-bit registers in BPF_STX
  BPF_B (bnc#1012628).
- bpf, x86_32: Fix incorrect encoding in BPF_LDX zero-extension
  (bnc#1012628).
- bpf, x86_32: Fix clobbering of dst for BPF_JSET (bnc#1012628).
- bpf, x86_32: Fix logic error in BPF_LDX zero-extension
  (bnc#1012628).
- bpf: Propagate expected_attach_type when verifying freplace
  programs (bnc#1012628).
- selftests/bpf: Fix a couple of broken test_btf cases
  (bnc#1012628).
- mm: shmem: disable interrupt when acquiring info->lock in
  userfaultfd_copy path (bnc#1012628).
- xfs: clear PF_MEMALLOC before exiting xfsaild thread
  (bnc#1012628).
- libbpf: Initialize *nl_pid so gcc 10 is happy (bnc#1012628).
- net: fec: set GPR bit on suspend by DT configuration
  (bnc#1012628).
- x86: hyperv: report value of misc_features (bnc#1012628).
- signal: check sig before setting info in kill_pid_usb_asyncio
  (bnc#1012628).
- afs: Fix length of dump of bad YFSFetchStatus record
  (bnc#1012628).
- xfs: fix partially uninitialized structure in
  xfs_reflink_remap_extent (bnc#1012628).
- ALSA: hda: Release resources at error in delayed probe
  (bnc#1012628).
- ALSA: hda: Keep the controller initialization even if no codecs
  found (bnc#1012628).
- ALSA: hda: Explicitly permit using autosuspend if runtime PM
  is supported (bnc#1012628).
- drm/amdgpu: fix wrong vram lost counter increment V2
  (bnc#1012628).
- scsi: target: fix PR IN / READ FULL STATUS for FC (bnc#1012628).
- scsi: target: tcmu: reset_ring should reset TCMU_DEV_BIT_BROKEN
  (bnc#1012628).
- objtool: Fix CONFIG_UBSAN_TRAP unreachable warnings
  (bnc#1012628).
- objtool: Support Clang non-section symbols in ORC dump
  (bnc#1012628).
- xen/xenbus: ensure xenbus_map_ring_valloc() returns proper
  grant status (bnc#1012628).
- ALSA: hda: call runtime_allow() for all hda controllers
  (bnc#1012628).
- net: stmmac: socfpga: Allow all RGMII modes (bnc#1012628).
- mac80211: fix channel switch trigger from unknown mesh peer
  (bnc#1012628).
- sched/isolation: Allow "isolcpus=" to skip unknown
  sub-parameters (bnc#1012628).
- sched/vtime: Work around an unitialized variable warning
  (bnc#1012628).
- arm64: Delete the space separator in __emit_inst (bnc#1012628).
- ext4: use matching invalidatepage in ext4_writepage
  (bnc#1012628).
- ext4: increase wait time needed before reuse of deleted inode
  numbers (bnc#1012628).
- ext4: convert BUG_ON's to WARN_ON's in mballoc.c (bnc#1012628).
- irqchip/gic-v4.1: Add support for VPENDBASER's Dirty+Valid
  signaling (bnc#1012628).
- blk-mq: Put driver tag in blk_mq_dispatch_rq_list() when no
  budget (bnc#1012628).
- irqchip/meson-gpio: Fix HARDIRQ-safe -> HARDIRQ-unsafe lock
  order (bnc#1012628).
- hwmon: (jc42) Fix name to have no illegal characters
  (bnc#1012628).
- sfc: fix XDP-redirect in this driver (bnc#1012628).
- taprio: do not use BIT() in TCA_TAPRIO_ATTR_FLAG_* definitions
  (bnc#1012628).
- tipc: Add a missing case of TIPC_DIRECT_MSG type (bnc#1012628).
- qed: Fix race condition between scheduling and destroying the
  slowpath workqueue (bnc#1012628).
- Crypto: chelsio - Fixes a hang issue during driver registration
  (bnc#1012628).
- net: use indirect call wrappers for skb_copy_datagram_iter()
  (bnc#1012628).
- qed: Fix use after free in qed_chain_free (bnc#1012628).
- ext4: check for non-zero journal inum in ext4_calculate_overhead
  (bnc#1012628).
- ASoC: soc-pcm: fix regression in soc_new_pcm() (bnc#1012628).
- ASoC: soc-core: disable route checks for legacy devices
  (bnc#1012628).
- ASoC: stm32: spdifrx: fix regmap status check (bnc#1012628).
- commit 46be1cc
* Thu Apr 30 2020 tiwai@suse.de
- drm/nouveau: Fix regression by audio component transition
  (bsc#1170951).
- commit 779158b
* Thu Apr 30 2020 jslaby@suse.cz
- Revert "ext4: make dioread_nolock the default" (bnc#1169774).
- commit 63116ab
* Wed Apr 29 2020 jslaby@suse.cz
- Linux 5.6.8 (bnc#1012628).
- mm: check that mm is still valid in madvise() (bnc#1012628).
- tools/testing/nvdimm: Fix compilation failure without
  CONFIG_DEV_DAX_PMEM_COMPAT (bnc#1012628).
- watchdog: reset last_hw_keepalive time at start (bnc#1012628).
- scsi: lpfc: Fix kasan slab-out-of-bounds error in
  lpfc_unreg_login (bnc#1012628).
- xfs: correctly acount for reclaimable slabs (bnc#1012628).
- scsi: lpfc: Fix crash after handling a pci error (bnc#1012628).
- scsi: lpfc: Fix crash in target side cable pulls hitting
  WAIT_FOR_UNREG (bnc#1012628).
- scsi: libfc: If PRLI rejected, move rport to PLOGI state
  (bnc#1012628).
- ceph: return ceph_mdsc_do_request() errors from __get_parent()
  (bnc#1012628).
- ceph: don't skip updating wanted caps when cap is stale
  (bnc#1012628).
- pwm: imx27: Fix clock handling in pwm_imx27_apply()
  (bnc#1012628).
- pwm: rcar: Fix late Runtime PM enablement (bnc#1012628).
- nvme-tcp: fix possible crash in write_zeroes processing
  (bnc#1012628).
- ASoC: qcom: q6asm-dai: Add SNDRV_PCM_INFO_BATCH flag
  (bnc#1012628).
- scsi: iscsi: Report unbind session event when the target has
  been removed (bnc#1012628).
- tools/test/nvdimm: Fix out of tree build (bnc#1012628).
- ASoC: Intel: atom: Take the drv->lock mutex before calling
  sst_send_slot_map() (bnc#1012628).
- nvme: fix deadlock caused by ANA update wrong locking
  (bnc#1012628).
- drm/amd/display: Update stream adjust in
  dc_stream_adjust_vmin_vmax (bnc#1012628).
- dma-direct: fix data truncation in
  dma_direct_get_required_mask() (bnc#1012628).
- kernel/gcov/fs.c: gcov_seq_next() should increase position index
  (bnc#1012628).
- selftests: kmod: fix handling test numbers above 9
  (bnc#1012628).
- ipc/util.c: sysvipc_find_ipc() should increase position index
  (bnc#1012628).
- kconfig: qconf: Fix a few alignment issues (bnc#1012628).
- lib/raid6/test: fix build on distros whose /bin/sh is not bash
  (bnc#1012628).
- block: fix busy device checking in blk_drop_partitions
  (bnc#1012628).
- s390/cio: generate delayed uevent for vfio-ccw subchannels
  (bnc#1012628).
- s390/cio: avoid duplicated 'ADD' uevents (bnc#1012628).
- loop: Better discard support for block devices (bnc#1012628).
- Revert "powerpc/64: irq_work avoid interrupt when called with
  hardware irqs enabled" (bnc#1012628).
- powerpc/pseries: Fix MCE handling on pseries (bnc#1012628).
- nvme: fix compat address handling in several ioctls
  (bnc#1012628).
- pwm: renesas-tpu: Fix late Runtime PM enablement (bnc#1012628).
- pwm: bcm2835: Dynamically allocate base (bnc#1012628).
- scsi: lpfc: Fix erroneous cpu limit of 128 on I/O statistics
  (bnc#1012628).
- scsi: lpfc: Fix lockdep error - register non-static key
  (bnc#1012628).
- perf/core: Disable page faults when getting phys address
  (bnc#1012628).
- drm/amd/display: Calculate scaling ratios on every medium/full
  update (bnc#1012628).
- ASoC: Intel: bytcr_rt5640: Add quirk for MPMAN MPWIN895CL tablet
  (bnc#1012628).
- ALSA: usb-audio: Add Pioneer DJ DJM-250MK2 quirk (bnc#1012628).
- xhci: Ensure link state is U3 after setting USB_SS_PORT_LS_U3
  (bnc#1012628).
- xhci: Wait until link state trainsits to U0 after setting
  USB_SS_PORT_LS_U0 (bnc#1012628).
- xhci: Finetune host initiated USB3 rootport link suspend and
  resume (bnc#1012628).
- block: fix busy device checking in blk_drop_partitions again
  (bnc#1012628).
- cxgb4: fix adapter crash due to wrong MC size (bnc#1012628).
- cxgb4: fix large delays in PTP synchronization (bnc#1012628).
- ipv4: Update fib_select_default to handle nexthop objects
  (bnc#1012628).
- ipv6: fix restrict IPV6_ADDRFORM operation (bnc#1012628).
- macsec: avoid to set wrong mtu (bnc#1012628).
- macvlan: fix null dereference in macvlan_device_event()
  (bnc#1012628).
- mlxsw: Fix some IS_ERR() vs NULL bugs (bnc#1012628).
- net: bcmgenet: correct per TX/RX ring statistics (bnc#1012628).
- net/mlx4_en: avoid indirect call in TX completion (bnc#1012628).
- net: netrom: Fix potential nr_neigh refcnt leak in nr_add_node
  (bnc#1012628).
- net: openvswitch: ovs_ct_exit to be done under ovs_lock
  (bnc#1012628).
- net: stmmac: dwmac-meson8b: Add missing boundary to RGMII TX
  clock array (bnc#1012628).
- net/x25: Fix x25_neigh refcnt leak when receiving frame
  (bnc#1012628).
- sched: etf: do not assume all sockets are full blown
  (bnc#1012628).
- selftests: Fix suppress test in fib_tests.sh (bnc#1012628).
- tcp: cache line align MAX_TCP_HEADER (bnc#1012628).
- team: fix hang in team_mode_get() (bnc#1012628).
- tipc: Fix potential tipc_aead refcnt leak in tipc_crypto_rcv
  (bnc#1012628).
- tipc: Fix potential tipc_node refcnt leak in tipc_rcv
  (bnc#1012628).
- vrf: Fix IPv6 with qdisc and xfrm (bnc#1012628).
- net: dsa: b53: Lookup VID in ARL searches when VLAN is enabled
  (bnc#1012628).
- net: dsa: b53: Fix valid setting for MDB entries (bnc#1012628).
- net: dsa: b53: Fix ARL register definitions (bnc#1012628).
- net: dsa: b53: Rework ARL bin logic (bnc#1012628).
- net: dsa: b53: b53_arl_rw_op() needs to select IVL or SVL
  (bnc#1012628).
- vxlan: use the correct nlattr array in NL_SET_ERR_MSG_ATTR
  (bnc#1012628).
- geneve: use the correct nlattr array in NL_SET_ERR_MSG_ATTR
  (bnc#1012628).
- xfrm: Always set XFRM_TRANSFORMED in xfrm{4,6}_output_finish
  (bnc#1012628).
- vrf: Check skb for XFRM_TRANSFORMED flag (bnc#1012628).
- net: ethernet: ixp4xx: Add error handling in ixp4xx_eth_probe()
  (bnc#1012628).
- KEYS: Avoid false positive ENOMEM error on key read
  (bnc#1012628).
- ALSA: hda: Remove ASUS ROG Zenith from the blacklist
  (bnc#1012628).
- ALSA: usb-audio: Add static mapping table for ALC1220-VB-based
  mobos (bnc#1012628).
- ALSA: usb-audio: Add connector notifier delegation
  (bnc#1012628).
- mac80211: populate debugfs only after cfg80211 init
  (bnc#1012628).
- iio: core: remove extra semi-colon from
  devm_iio_device_register() macro (bnc#1012628).
- iio: imu: st_lsm6dsx: flush hw FIFO before resetting the device
  (bnc#1012628).
- iio: st_sensors: rely on odr mask to know if odr can be set
  (bnc#1012628).
- iio: adc: stm32-adc: fix sleep in atomic context (bnc#1012628).
- iio: adc: ti-ads8344: properly byte swap value (bnc#1012628).
- iio: xilinx-xadc: Fix ADC-B powerdown (bnc#1012628).
- iio: xilinx-xadc: Fix clearing interrupt when enabling trigger
  (bnc#1012628).
- iio: xilinx-xadc: Fix sequencer configuration for aux channels
  in simultaneous mode (bnc#1012628).
- iio: xilinx-xadc: Make sure not exceed maximum samplerate
  (bnc#1012628).
- USB: sisusbvga: Change port variable from signed to unsigned
  (bnc#1012628).
- USB: Add USB_QUIRK_DELAY_CTRL_MSG and USB_QUIRK_DELAY_INIT
  for Corsair K70 RGB RAPIDFIRE (bnc#1012628).
- USB: early: Handle AMD's spec-compliant identifiers, too
  (bnc#1012628).
- USB: core: Fix free-while-in-use bug in the USB S-Glibrary
  (bnc#1012628).
- USB: hub: Fix handling of connect changes during sleep
  (bnc#1012628).
- USB: hub: Revert commit bd0e6c9614b9 ("usb: hub: try old
  enumeration scheme first for high speed devices") (bnc#1012628).
- tty: serial: owl: add "much needed" clk_prepare_enable()
  (bnc#1012628).
- vmalloc: fix remap_vmalloc_range() bounds checks (bnc#1012628).
- staging: gasket: Fix incongruency in handling of sysfs entries
  creation (bnc#1012628).
- coredump: fix null pointer dereference on coredump
  (bnc#1012628).
- mm/hugetlb: fix a addressing exception caused by huge_pte_offset
  (bnc#1012628).
- mm/ksm: fix NULL pointer dereference when KSM zero page is
  enabled (bnc#1012628).
- tools/vm: fix cross-compile build (bnc#1012628).
- ALSA: usx2y: Fix potential NULL dereference (bnc#1012628).
- ALSA: hda/realtek - Fix unexpected init_amp override
  (bnc#1012628).
- ALSA: hda/realtek - Add new codec supported for ALC245
  (bnc#1012628).
- ALSA: hda/hdmi: Add module option to disable audio component
  binding (bnc#1012628).
- ALSA: usb-audio: Fix usb audio refcnt leak when getting spdif
  (bnc#1012628).
- ALSA: usb-audio: Filter out unsupported sample rates on
  Focusrite devices (bnc#1012628).
- tpm/tpm_tis: Free IRQ if probing fails (bnc#1012628).
- tpm: fix wrong return value in tpm_pcr_extend (bnc#1012628).
- tpm: ibmvtpm: retry on H_CLOSED in tpm_ibmvtpm_send()
  (bnc#1012628).
- KVM: s390: Return last valid slot if approx index is
  out-of-bounds (bnc#1012628).
- KVM: Check validity of resolved slot when searching memslots
  (bnc#1012628).
- KVM: VMX: Enable machine check support for 32bit targets
  (bnc#1012628).
- tty: hvc: fix buffer overflow during hvc_alloc() (bnc#1012628).
- tty: rocket, avoid OOB access (bnc#1012628).
- usb-storage: Add unusual_devs entry for JMicron JMS566
  (bnc#1012628).
- signal: Avoid corrupting si_pid and si_uid in do_notify_parent
  (bnc#1012628).
- drm/dp_mst: Zero assigned PBN when releasing VCPI slots
  (bnc#1012628).
- audit: check the length of userspace generated audit records
  (bnc#1012628).
- ASoC: dapm: fixup dapm kcontrol widget (bnc#1012628).
- SUNRPC: Fix backchannel RPC soft lockups (bnc#1012628).
- iwlwifi: pcie: actually release queue memory in TVQM
  (bnc#1012628).
- iwlwifi: mvm: beacon statistics shouldn't go backwards
  (bnc#1012628).
- iwlwifi: pcie: indicate correct RB size to device (bnc#1012628).
- iwlwifi: mvm: limit maximum queue appropriately (bnc#1012628).
- iwlwifi: mvm: Do not declare support for ACK Enabled Aggregation
  (bnc#1012628).
- iwlwifi: mvm: fix inactive TID removal return value usage
  (bnc#1012628).
- iwlwifi: fix WGDS check when WRDS is disabled (bnc#1012628).
- cifs: fix uninitialised lease_key in open_shroot()
  (bnc#1012628).
- ARM: imx: provide v7_cpu_resume() only on ARM_CPU_SUSPEND=y
  (bnc#1012628).
- powerpc/8xx: Fix STRICT_KERNEL_RWX startup test failure
  (bnc#1012628).
- powerpc/setup_64: Set cache-line-size based on cache-block-size
  (bnc#1012628).
- staging: comedi: dt2815: fix writing hi byte of analog output
  (bnc#1012628).
- staging: comedi: Fix comedi_device refcnt leak in comedi_open
  (bnc#1012628).
- vt: don't hardcode the mem allocation upper bound (bnc#1012628).
- vt: don't use kmalloc() for the unicode screen buffer
  (bnc#1012628).
- staging: vt6656: Don't set RCR_MULTICAST or RCR_BROADCAST by
  default (bnc#1012628).
- staging: vt6656: Fix calling conditions of vnt_set_bss_mode
  (bnc#1012628).
- staging: vt6656: Fix drivers TBTT timing counter (bnc#1012628).
- staging: vt6656: Fix pairwise key entry save (bnc#1012628).
- staging: vt6656: Power save stop wake_up_count wrap around
  (bnc#1012628).
- mei: me: fix irq number stored in hw struct (bnc#1012628).
- cdc-acm: close race betrween suspend() and acm_softint
  (bnc#1012628).
- cdc-acm: introduce a cool down (bnc#1012628).
- UAS: no use logging any details in case of ENODEV (bnc#1012628).
- UAS: fix deadlock in error handling and PM flushing work
  (bnc#1012628).
- fpga: dfl: pci: fix return value of cci_pci_sriov_configure
  (bnc#1012628).
- usb: dwc3: gadget: Fix request completion check (bnc#1012628).
- usb: f_fs: Clear OS Extended descriptor counts to zero in
  ffs_data_reset() (bnc#1012628).
- usb: typec: tcpm: Ignore CC and vbus changes in PORT_RESET
  change (bnc#1012628).
- usb: typec: altmode: Fix typec_altmode_get_partner sometimes
  returning an invalid pointer (bnc#1012628).
- xhci: Fix handling halted endpoint even if endpoint ring
  appears empty (bnc#1012628).
- xhci: prevent bus suspend if a roothub port detected a
  over-current condition (bnc#1012628).
- xhci: Don't clear hub TT buffer on ep0 protocol stall
  (bnc#1012628).
- serial: sh-sci: Make sure status register SCxSR is read in
  correct sequence (bnc#1012628).
- Revert "serial: uartps: Fix uartps_major handling"
  (bnc#1012628).
- Revert "serial: uartps: Use the same dynamic major number for
  all ports" (bnc#1012628).
- Revert "serial: uartps: Fix error path when alloc failed"
  (bnc#1012628).
- Revert "serial: uartps: Do not allow use aliases >=
  MAX_UART_INSTANCES" (bnc#1012628).
- Revert "serial: uartps: Change uart ID port allocation"
  (bnc#1012628).
- Revert "serial: uartps: Move Port ID to device data structure"
  (bnc#1012628).
- Revert "serial: uartps: Register own uart console and driver
  structures" (bnc#1012628).
- drm/i915/gt: Update PMINTRMSK holding fw (bnc#1012628).
- powerpc/kuap: PPC_KUAP_DEBUG should depend on PPC_KUAP
  (bnc#1012628).
- powerpc/mm: Fix CONFIG_PPC_KUAP_DEBUG on PPC32 (bnc#1012628).
- s390/mm: fix page table upgrade vs 2ndary address mode accesses
  (bnc#1012628).
- commit 58238cd
* Wed Apr 29 2020 ykaukab@suse.de
- config: arm64: enable coresight support
  Coresight is already enabled in armv7hl
- commit f6f465c
* Wed Apr 29 2020 tiwai@suse.de
- Make the "Reducing compressed framebufer size" message be
  DRM_INFO_ONCE() (bsc#1168776).
- commit a7947d7
* Mon Apr 27 2020 tiwai@suse.de
- ALSA: pcm: oss: Place the plugin buffer overflow checks
  correctly (bsc#1170522).
- commit 00d8515
* Mon Apr 27 2020 mkubecek@suse.cz
- Update to 5.7-rc3
- eliminated 1 patch
- refresh configs
- commit 888b015
* Sun Apr 26 2020 jslaby@suse.cz
- blacklist.conf: add one revert
- commit 2ef52fd
* Sun Apr 26 2020 jslaby@suse.cz
- libbpf: Only check mode flags in get_xdp_id (git-fixes).
- commit 4535732
* Sat Apr 25 2020 jslaby@suse.cz
- Linux 5.6.7 (bnc#1012628).
- x86/xen: fix booting 32-bit pv guest (bnc#1012628).
- bpf, test_verifier: switch bpf_get_stack's 0 s> r8 test
  (bnc#1012628).
- bpf: Test_progs, add test to catch retval refine error handling
  (bnc#1012628).
- bpf: Test_verifier, bpf_get_stack return value add <0
  (bnc#1012628).
- bpf: fix buggy r0 retval refinement for tracing helpers
  (bnc#1012628).
- KEYS: Don't write out to userspace while holding key semaphore
  (bnc#1012628).
- mtd: phram: fix a double free issue in error path (bnc#1012628).
- mtd: lpddr: Fix a double free in probe() (bnc#1012628).
- docs: Fix path to MTD command line partition parser
  (bnc#1012628).
- mtd: spinand: Explicitly use MTD_OPS_RAW to write the bad
  block marker to OOB (bnc#1012628).
- mtd: rawnand: free the nand_device object (bnc#1012628).
- locktorture: Print ratio of acquisitions, not failures
  (bnc#1012628).
- iio: st_sensors: handle memory allocation failure to fix null
  pointer dereference (bnc#1012628).
- tty: evh_bytechan: Fix out of bounds accesses (bnc#1012628).
- fbmem: Adjust indentation in fb_prepare_logo and fb_blank
  (bnc#1012628).
- iio: si1133: read 24-bit signed integer for measurement
  (bnc#1012628).
- ARM: dts: sunxi: Fix DE2 clocks register range (bnc#1012628).
- fbdev: potential information leak in do_fb_ioctl()
  (bnc#1012628).
- dma-debug: fix displaying of dma allocation type (bnc#1012628).
- cifs: ignore cached share root handle closing errors
  (bnc#1012628).
- net: dsa: bcm_sf2: Fix overflow checks (bnc#1012628).
- drm/nouveau/gr/gp107,gp108: implement workaround for HW hanging
  during init (bnc#1012628).
- platform/chrome: cros_ec: Query EC protocol version if EC
  transitions between RO/RW (bnc#1012628).
- f2fs: fix to wait all node page writeback (bnc#1012628).
- f2fs: fix leaking uninitialized memory in compressed clusters
  (bnc#1012628).
- iommu/amd: Fix the configuration of GCR3 table root pointer
  (bnc#1012628).
- libnvdimm: Out of bounds read in __nd_ioctl() (bnc#1012628).
- power: supply: axp288_fuel_gauge: Broaden vendor check for
  Intel Compute Sticks (bnc#1012628).
- csky: Fixup init_fpu compile warning with __init (bnc#1012628).
- thermal: qoriq: Fix a compiling issue (bnc#1012628).
- sunrpc: Fix gss_unwrap_resp_integ() again (bnc#1012628).
- ext2: fix debug reference to ext2_xattr_cache (bnc#1012628).
- iommu/vt-d: Fix page request descriptor size (bnc#1012628).
- iommu/vt-d: Silence RCU-list debugging warning in
  dmar_find_atsr() (bnc#1012628).
- f2fs: skip GC when section is full (bnc#1012628).
- f2fs: fix to account compressed blocks in
  f2fs_compressed_blocks() (bnc#1012628).
- ext2: fix empty body warnings when -Wextra is used
  (bnc#1012628).
- virtio-balloon: Switch back to OOM handler for
  VIRTIO_BALLOON_F_DEFLATE_ON_OOM (bnc#1012628).
- SUNRPC: fix krb5p mount to provide large enough buffer in
  rq_rcvsize (bnc#1012628).
- iommu/vt-d: Fix mm reference leak (bnc#1012628).
- iommu/vt-d: Add build dependency on IOASID (bnc#1012628).
- iommu/virtio: Fix freeing of incomplete domains (bnc#1012628).
- drm/vc4: Fix HDMI mode validation (bnc#1012628).
- um: falloc.h needs to be directly included for older libc
  (bnc#1012628).
- mfd: cros_ec: Check DT node for usbpd-notify add (bnc#1012628).
- ceph: re-org copy_file_range and fix some error paths
  (bnc#1012628).
- ACPICA: Fixes for acpiExec namespace init file (bnc#1012628).
- f2fs: fix potential deadlock on compressed quota file
  (bnc#1012628).
- f2fs: fix NULL pointer dereference in f2fs_write_begin()
  (bnc#1012628).
- f2fs: fix NULL pointer dereference in f2fs_verity_work()
  (bnc#1012628).
- f2fs: fix potential .flags overflow on 32bit architecture
  (bnc#1012628).
- f2fs: compress: fix to call missing destroy_compress_ctx()
  (bnc#1012628).
- csky: Fixup get wrong psr value from phyical reg (bnc#1012628).
- ACPI: Update Tiger Lake ACPI device IDs (bnc#1012628).
- NFS: Fix memory leaks in nfs_pageio_stop_mirroring()
  (bnc#1012628).
- drm/amdkfd: kfree the wrong pointer (bnc#1012628).
- csky: Fixup cpu speculative execution to IO area (bnc#1012628).
- x86: ACPI: fix CPU hotplug deadlock (bnc#1012628).
- leds: core: Fix warning message when init_data (bnc#1012628).
- drm/nouveau: workaround runpm fail by disabling PCI power
  management on certain intel bridges (bnc#1012628).
- KVM: s390: vsie: Fix possible race when shadowing region 3
  tables (bnc#1012628).
- compiler.h: fix error in BUILD_BUG_ON() reporting (bnc#1012628).
- percpu_counter: fix a data race at vm_committed_as
  (bnc#1012628).
- include/linux/swapops.h: correct guards for non_swap_entry()
  (bnc#1012628).
- drm/nouveau/svm: fix vma range check for migration
  (bnc#1012628).
- drm/nouveau/svm: check for SVM initialized before migrating
  (bnc#1012628).
- macsec: fix NULL dereference in macsec_upd_offload()
  (bnc#1012628).
- mm/hugetlb: fix build failure with HUGETLB_PAGE but not
  HUGEBTLBFS (bnc#1012628).
- platform/x86: intel-hid: fix: Update Tiger Lake ACPI device ID
  (bnc#1012628).
- dt-bindings: thermal: tsens: Fix nvmem-cell-names schema
  (bnc#1012628).
- drm/amd/display: Don't try hdcp1.4 when content_type is set
  to type1 (bnc#1012628).
- x86/xen: Make the boot CPU idle task reliable (bnc#1012628).
- cifs: Allocate encryption header through kmalloc (bnc#1012628).
- um: ubd: Prevent buffer overrun on command completion
  (bnc#1012628).
- ext4: do not commit super on read-only bdev (bnc#1012628).
- nfsroot: set tcp as the default transport protocol
  (bnc#1012628).
- s390/cpum_sf: Fix wrong page count in error message
  (bnc#1012628).
- powerpc/maple: Fix declaration made after definition
  (bnc#1012628).
- powerpc/prom_init: Pass the "os-term" message to hypervisor
  (bnc#1012628).
- btrfs: add RCU locks around block group initialization
  (bnc#1012628).
- hibernate: Allow uswsusp to write to swap (bnc#1012628).
- thermal/drivers/cpufreq_cooling: Fix return of
  cpufreq_set_cur_state (bnc#1012628).
- MIPS: DTS: CI20: add DT node for IR sensor (bnc#1012628).
- s390/cpuinfo: fix wrong output when CPU0 is offline
  (bnc#1012628).
- f2fs: Add a new CP flag to help fsck fix resize SPO issues
  (bnc#1012628).
- f2fs: Fix mount failure due to SPO after a successful online
  resize FS (bnc#1012628).
- f2fs: fix to update f2fs_super_block fields under sb_lock
  (bnc#1012628).
- NFS: direct.c: Fix memory leak of dreq when nfs_get_lock_context
  fails (bnc#1012628).
- phy: uniphier-usb3ss: Add Pro5 support (bnc#1012628).
- drivers: thermal: tsens: Release device in success path
  (bnc#1012628).
- f2fs: fix to show norecovery mount option (bnc#1012628).
- KVM: PPC: Book3S HV: Fix H_CEDE return code for nested guests
  (bnc#1012628).
- xfs: fix incorrect test in xfs_alloc_ag_vextent_lastblock
  (bnc#1012628).
- ARM: dts: rockchip: fix lvds-encoder ports subnode for
  rk3188-bqedison2qc (bnc#1012628).
- NFSv4.2: error out when relink swapfile (bnc#1012628).
- NFSv4/pnfs: Return valid stateids in
  nfs_layout_find_inode_by_stateid() (bnc#1012628).
- NFS: alloc_nfs_open_context() must use the file cred when
  available (bnc#1012628).
- rtc: 88pm860x: fix possible race condition (bnc#1012628).
- dma-coherent: fix integer overflow in the reserved-memory dma
  allocation (bnc#1012628).
- soc: imx: gpc: fix power up sequencing (bnc#1012628).
- arm64: dts: marvell: Fix cpu compatible for AP807-quad
  (bnc#1012628).
- arm64: dts: clearfog-gt-8k: set gigabit PHY reset deassert delay
  (bnc#1012628).
- arm64: dts: marvell: espressobin: add ethernet alias
  (bnc#1012628).
- xfs: fix regression in "cleanup xfs_dir2_block_getdents"
  (bnc#1012628).
- xfs: fix use-after-free when aborting corrupt attr inactivation
  (bnc#1012628).
- arm64: tegra: Fix Tegra194 PCIe compatible string (bnc#1012628).
- arm64: tegra: Add PCIe endpoint controllers nodes for Tegra194
  (bnc#1012628).
- clk: tegra: Fix Tegra PMC clock out parents (bnc#1012628).
- power: supply: bq27xxx_battery: Silence deferred-probe error
  (bnc#1012628).
- arm64: dts: allwinner: a64: Fix display clock register range
  (bnc#1012628).
- memory: tegra: Correct debugfs clk rate-range on Tegra124
  (bnc#1012628).
- memory: tegra: Correct debugfs clk rate-range on Tegra30
  (bnc#1012628).
- memory: tegra: Correct debugfs clk rate-range on Tegra20
  (bnc#1012628).
- dmaengine: idxd: reflect shadow copy of traffic class
  programming (bnc#1012628).
- ARM: dts: rockchip: fix vqmmc-supply property name for
  rk3188-bqedison2qc (bnc#1012628).
- f2fs: fix to avoid use-after-free in f2fs_write_multi_pages()
  (bnc#1012628).
- f2fs: fix wrong check on F2FS_IOC_FSSETXATTR (bnc#1012628).
- xfs: fix iclog release error check race with shutdown
  (bnc#1012628).
- bpf: Reliably preserve btf_trace_xxx types (bnc#1012628).
- f2fs: fix the panic in do_checkpoint() (bnc#1012628).
- f2fs: fix to avoid potential deadlock (bnc#1012628).
- s390/crypto: explicitly memzero stack key material in aes_s390.c
  (bnc#1012628).
- net/mlx5e: Enforce setting of a single FEC mode (bnc#1012628).
- crypto: qce - use cryptlen when adding extra sgl (bnc#1012628).
- clk: imx: pll14xx: Add new frequency entries for pll1443x table
  (bnc#1012628).
- clk: at91: usb: continue if clk_hw_round_rate() return zero
  (bnc#1012628).
- clk: Don't cache errors from clk_ops::get_phase() (bnc#1012628).
- gfs2: clear ail1 list when gfs2 withdraws (bnc#1012628).
- drm/ttm: flush the fence on the bo after we individualize the
  reservation object (bnc#1012628).
- block, bfq: invoke flush_idle_tree after reparent_active_queues
  in pd_offline (bnc#1012628).
- block, bfq: make reparent_leaf_entity actually work only on
  leaf entities (bnc#1012628).
- block, bfq: turn put_queue into release_process_ref in
  __bfq_bic_change_cgroup (bnc#1012628).
- afs: Fix race between post-modification dir edit and
  readdir/d_revalidate (bnc#1012628).
- afs: Fix afs_d_validate() to set the right directory version
  (bnc#1012628).
- afs: Fix rename operation status delivery (bnc#1012628).
- afs: Fix decoding of inline abort codes from version 1 status
  records (bnc#1012628).
- afs: Fix missing XDR advance in
  xdr_decode_{AFS,YFS}FSFetchStatus() (bnc#1012628).
- x86/Hyper-V: Report crash data in die() when panic_on_oops is
  set (bnc#1012628).
- x86/Hyper-V: Report crash register data when
  sysctl_record_panic_msg is not set (bnc#1012628).
- x86/Hyper-V: Report crash register data or kmsg before running
  crash kernel (bnc#1012628).
- x86/Hyper-V: Trigger crash enlightenment only once during
  system crash (bnc#1012628).
- x86/Hyper-V: Free hv_panic_page when fail to register kmsg dump
  (bnc#1012628).
- x86/Hyper-V: Unload vmbus channel in hv panic callback
  (bnc#1012628).
- of: overlay: kmemleak in dup_and_fixup_symbol_prop()
  (bnc#1012628).
- of: unittest: kmemleak in of_unittest_overlay_high_level()
  (bnc#1012628).
- of: unittest: kmemleak in of_unittest_platform_populate()
  (bnc#1012628).
- of: unittest: kmemleak on changeset destroy (bnc#1012628).
- xsk: Add missing check on user supplied headroom size
  (bnc#1012628).
- ALSA: hda: Don't release card at firmware loading error
  (bnc#1012628).
- rbd: don't test rbd_dev->opts in rbd_dev_image_release()
  (bnc#1012628).
- rbd: call rbd_dev_unprobe() after unwatching and flushing
  notifies (bnc#1012628).
- rbd: avoid a deadlock on header_rwsem when flushing notifies
  (bnc#1012628).
- irqchip/mbigen: Free msi_desc on device teardown (bnc#1012628).
- netfilter: nf_tables: report EOPNOTSUPP on unsupported
  flags/object type (bnc#1012628).
- kbuild, btf: Fix dependencies for DEBUG_INFO_BTF (bnc#1012628).
- ARM: dts: imx6: Use gpc for FEC interrupt controller to fix
  wake on LAN (bnc#1012628).
- bpf: Prevent re-mmap()'ing BPF map as writable for initially
  r/o mapping (bnc#1012628).
- arm, bpf: Fix bugs with ALU64 {RSH, ARSH} BPF_K shift by 0
  (bnc#1012628).
- libbpf: Fix bpf_get_link_xdp_id flags handling (bnc#1012628).
- xsk: Fix out of boundary write in __xsk_rcv_memcpy
  (bnc#1012628).
- watchdog: sp805: fix restart handler (bnc#1012628).
- ext4: use non-movable memory for superblock readahead
  (bnc#1012628).
- ALSA: hda: Honor PM disablement in PM freeze and thaw_noirq ops
  (bnc#1012628).
- scsi: sg: add sg_remove_request in sg_common_write
  (bnc#1012628).
- objtool: Fix switch table detection in .text.unlikely
  (bnc#1012628).
- arm, bpf: Fix offset overflow for BPF_MEM BPF_DW (bnc#1012628).
- netfilter: nft_set_rbtree: Drop spurious condition for overlap
  detection on insertion (bnc#1012628).
- commit 94f4e94
* Wed Apr 22 2020 mkubecek@suse.cz
- config.conf: fix order of i386 flavors
  Unlike on other architectures, i386/pae is the basic config and others,
  including i386/default are diffs against it. With i386/default listed
  first, it is also processed first by run_oldconfig.sh so that if there
  is a new config option, it is added to i386/default (as it's not present
  in i386/pae yet) even if the value is going to be the same as in
  i386/pae. To get stable result, one needs to run run_oldconfig.sh twice.
  Swat the two entries so that i386/pae is updated first and i386/default
  is created as a diff against already updated i386/pae.
- commit 17dfd53
* Wed Apr 22 2020 jslaby@suse.cz
- Linux 5.6.6 (bnc#1012628).
- amd-xgbe: Use __napi_schedule() in BH context (bnc#1012628).
- hsr: check protocol version in hsr_newlink() (bnc#1012628).
- l2tp: Allow management of tunnels and session in user namespace
  (bnc#1012628).
- net: dsa: mt7530: fix tagged frames pass-through in VLAN-unaware
  mode (bnc#1012628).
- net: ipv4: devinet: Fix crash when add/del multicast IP with
  autojoin (bnc#1012628).
- net: ipv6: do not consider routes via gateways for anycast
  address check (bnc#1012628).
- net: macsec: fix using wrong structure in macsec_changelink()
  (bnc#1012628).
- net: phy: micrel: use genphy_read_status for KSZ9131
  (bnc#1012628).
- net: qrtr: send msgs from local of same id as broadcast
  (bnc#1012628).
- net: revert default NAPI poll timeout to 2 jiffies
  (bnc#1012628).
- net: tun: record RX queue in skb before do_xdp_generic()
  (bnc#1012628).
- net: dsa: mt7530: move mt7623 settings out off the mt7530
  (bnc#1012628).
- net: ethernet: mediatek: move mt7623 settings out off the mt7530
  (bnc#1012628).
- net/mlx5: Fix frequent ioread PCI access during recovery
  (bnc#1012628).
- net/mlx5e: Add missing release firmware call (bnc#1012628).
- net/mlx5e: Fix nest_level for vlan pop action (bnc#1012628).
- net/mlx5e: Fix pfnum in devlink port attribute (bnc#1012628).
- net: icmp6: do not select saddr from iif when route has prefsrc
  set (bnc#1012628).
- net: mscc: ocelot: fix untagged packet drops when enslaving
  to vlan aware bridge (bnc#1012628).
- net: stmmac: dwmac-sunxi: Provide TX and RX fifo sizes
  (bnc#1012628).
- net: phy: marvell: Fix pause frame negotiation (bnc#1012628).
- Revert "ACPI: EC: Do not clear boot_ec_is_ecdt in acpi_ec_add()"
  (bnc#1012628).
- ovl: fix value of i_ino for lower hardlink corner case
  (bnc#1012628).
- scsi: ufs: Fix ufshcd_hold() caused scheduling while atomic
  (bnc#1012628).
- platform/chrome: cros_ec_rpmsg: Fix race with host event
  (bnc#1012628).
- jbd2: improve comments about freeing data buffers whose page
  mapping is NULL (bnc#1012628).
- acpi/nfit: improve bounds checking for 'func' (bnc#1012628).
- perf report: Fix no branch type statistics report issue
  (bnc#1012628).
- pwm: pca9685: Fix PWM/GPIO inter-operation (bnc#1012628).
- net: stmmac: xgmac: Fix VLAN register handling (bnc#1012628).
- ext4: fix incorrect group count in ext4_fill_super error message
  (bnc#1012628).
- ext4: fix incorrect inodes per group in error message
  (bnc#1012628).
- HID: lg-g15: Do not fail the probe when we fail to disable F#
  emulation (bnc#1012628).
- clk: at91: sam9x60: fix usb clock parents (bnc#1012628).
- clk: at91: usb: use proper usbs_mask (bnc#1012628).
- ARM: dts: imx7-colibri: fix muxing of usbc_det pin
  (bnc#1012628).
- arm64: dts: librem5-devkit: add a vbus supply to usb0
  (bnc#1012628).
- usb: dwc3: gadget: Don't clear flags before transfer ended
  (bnc#1012628).
- ASoC: Intel: mrfld: fix incorrect check on p->sink
  (bnc#1012628).
- ASoC: Intel: mrfld: return error codes when an error occurs
  (bnc#1012628).
- ALSA: hda/realtek - Enable the headset mic on Asus FX505DT
  (bnc#1012628).
- ALSA: usb-audio: Filter error from connector kctl ops, too
  (bnc#1012628).
- ALSA: usb-audio: Don't override ignore_ctl_error value from
  the map (bnc#1012628).
- ALSA: usb-audio: Don't create jack controls for PCM terminals
  (bnc#1012628).
- ALSA: usb-audio: Check mapping at creating connector controls,
  too (bnc#1012628).
- arm64: vdso: don't free unallocated pages (bnc#1012628).
- keys: Fix proc_keys_next to increase position index
  (bnc#1012628).
- tracing: Fix the race between registering 'snapshot' event
  trigger and triggering 'snapshot' operation (bnc#1012628).
- btrfs: check commit root generation in should_ignore_root
  (bnc#1012628).
- nl80211: fix NL80211_ATTR_FTM_RESPONDER policy (bnc#1012628).
- mac80211: fix race in ieee80211_register_hw() (bnc#1012628).
- mac80211_hwsim: Use kstrndup() in place of kasprintf()
  (bnc#1012628).
- net/mlx5e: Encapsulate updating netdev queues into a function
  (bnc#1012628).
- net/mlx5e: Rename hw_modify to preactivate (bnc#1012628).
- net/mlx5e: Use preactivate hook to set the indirection table
  (bnc#1012628).
- drm/amd/powerplay: force the trim of the mclk dpm_levels if
  OD is enabled (bnc#1012628).
- drm/amdgpu/gfx9: add gfxoff quirk (bnc#1012628).
- drm/amdgpu: fix the hw hang during perform system reboot and
  reset (bnc#1012628).
- i2c: designware: platdrv: Remove DPM_FLAG_SMART_SUSPEND flag
  on BYT and CHT (bnc#1012628).
- drm/nouveau/sec2/gv100-: add missing MODULE_FIRMWARE()
  (bnc#1012628).
- drm/i915/perf: Do not clear pollin for small user read buffers
  (bnc#1012628).
- rcu: Don't acquire lock in NMI handler in rcu_nmi_enter_common()
  (bnc#1012628).
- ext4: do not zeroout extents beyond i_disksize (bnc#1012628).
- irqchip/ti-sci-inta: Fix processing of masked irqs
  (bnc#1012628).
- proc, time/namespace: Show clock symbolic names in
  /proc/pid/timens_offsets (bnc#1012628).
- x86/resctrl: Preserve CDP enable over CPU hotplug (bnc#1012628).
- x86/resctrl: Fix invalid attempt at removing the default
  resource group (bnc#1012628).
- x86/microcode/AMD: Increase microcode PATCH_MAX_SIZE
  (bnc#1012628).
- scsi: target: iscsi: calling iscsit_stop_session() inside
  iscsit_close_session() has no effect (bnc#1012628).
- Delete
  patches.suse/Revert-ACPI-EC-Do-not-clear-boot_ec_is_ecdt-in-acpi_.patch.
- commit c11f000
* Tue Apr 21 2020 schwab@suse.de
- config: riscv64: enable left out config options
  Enable some config options to reduce difference with x86 config
- commit ffb4ebb
* Tue Apr 21 2020 mkubecek@suse.cz
- series.conf: cleanup
- fix Patch-mainline and move to more appropriate place:
  patches.suse/s390-export-symbols-for-crash-kmp.patch
- commit d3c6449
* Mon Apr 20 2020 tiwai@suse.de
- Update config files: revert CONFIG_SND_HDA_PREALLOC_SIZE changes (bsc#1169471)
- commit 438882a
* Mon Apr 20 2020 jslaby@suse.cz
- Revert "ACPI: EC: Do not clear boot_ec_is_ecdt in acpi_ec_add()"
  (5.6.5 regression).
- commit 1bdcfdf
* Mon Apr 20 2020 mkubecek@suse.cz
- config: enable PCIE_EDR (bsc#1169263)
  (x86 only)
- commit e781722
* Mon Apr 20 2020 mkubecek@suse.cz
- Update to 5.7-rc2
- eliminated 2 patches
- commit 487485c
* Mon Apr 20 2020 mbrugger@suse.com
- armv7hl: Update config files.
  Build MediaTek watchdog as built-in.
- commit dfe578b
* Fri Apr 17 2020 jslaby@suse.cz
- Linux 5.6.5 (bnc#1012628).
- media: rc: add keymap for Videostrong KII Pro (bnc#1012628).
- cpufreq: imx6q: Fixes unwanted cpu overclocking on i.MX6ULL
  (bnc#1012628).
- EDAC/mc: Report "unknown memory" on too many DIMM labels found
  (bnc#1012628).
- usb: ucsi: ccg: disable runtime pm during fw flashing
  (bnc#1012628).
- staging: wilc1000: avoid double unlocking of 'wilc->hif_cs'
  mutex (bnc#1012628).
- media: vimc: streamer: fix memory leak in vimc subdevs if
  kthread_run fails (bnc#1012628).
- media: hantro: fix extra MV/MC sync space calculation
  (bnc#1012628).
- media: staging: rkisp1: use consistent bus_info string for
  media_dev (bnc#1012628).
- media: staging: rkisp1: isp: do not set invalid mbus code for
  pad (bnc#1012628).
- media: venus: hfi_parser: Ignore HEVC encoding for V1
  (bnc#1012628).
- firmware: arm_sdei: fix double-lock on hibernate with shared
  events (bnc#1012628).
- media: arm64: dts: amlogic: add rc-videostrong-kii-pro keymap
  (bnc#1012628).
- usb: phy: tegra: Include proper GPIO consumer header to fix
  compile testing (bnc#1012628).
- arm64/mm: Hold memory hotplug lock while walking for kernel
  page table dump (bnc#1012628).
- sched/vtime: Prevent unstable evaluation of WARN(vtime->state)
  (bnc#1012628).
- iio: imu: st_lsm6dsx: check return value from
  st_lsm6dsx_sensor_set_enable (bnc#1012628).
- null_blk: Fix the null_add_dev() error path (bnc#1012628).
- blk-mq: Fix a recently introduced regression in
  blk_mq_realloc_hw_ctxs() (bnc#1012628).
- null_blk: Handle null_add_dev() failures properly (bnc#1012628).
- null_blk: Suppress an UBSAN complaint triggered when setting
  'memory_backed' (bnc#1012628).
- null_blk: fix spurious IO errors after failed past-wp access
  (bnc#1012628).
- media: imx: imx7_mipi_csis: Power off the source when stopping
  streaming (bnc#1012628).
- media: imx: imx7-media-csi: Fix video field handling
  (bnc#1012628).
- xhci: bail out early if driver can't accress host in resume
  (bnc#1012628).
- ACPI: EC: Do not clear boot_ec_is_ecdt in acpi_ec_add()
  (bnc#1012628).
- clocksource/drivers/timer-microchip-pit64b: Fix rate for gck
  (bnc#1012628).
- x86: Don't let pgprot_modify() change the page encryption bit
  (bnc#1012628).
- dma-mapping: Fix dma_pgprot() for unencrypted coherent pages
  (bnc#1012628).
- block: keep bdi->io_pages in sync with max_sectors_kb for
  stacked devices (bnc#1012628).
- debugfs: Check module state before warning in
  {full/open}_proxy_open() (bnc#1012628).
- spi: spi-fsl-dspi: Avoid NULL pointer in dspi_slave_abort for
  non-DMA mode (bnc#1012628).
- irqchip/versatile-fpga: Handle chained IRQs properly
  (bnc#1012628).
- time/sched_clock: Expire timer in hardirq context (bnc#1012628).
- irqchip/gic-v4.1: Skip absent CPUs while iterating over
  redistributors (bnc#1012628).
- media: allegro: fix type of gop_length in channel_create message
  (bnc#1012628).
- sched: Avoid scale real weight down to zero (bnc#1012628).
- sched/fair: Fix condition of avg_load calculation (bnc#1012628).
- selftests/x86/ptrace_syscall_32: Fix no-vDSO segfault
  (bnc#1012628).
- PCI/switchtec: Fix init_completion race condition with
  poll_wait() (bnc#1012628).
- block, bfq: move forward the getting of an extra ref in
  bfq_bfqq_move (bnc#1012628).
- media: i2c: video-i2c: fix build errors due to 'imply hwmon'
  (bnc#1012628).
- libata: Remove extra scsi_host_put() in ata_scsi_add_hosts()
  (bnc#1012628).
- pstore/platform: fix potential mem leak if pstore_init_fs failed
  (bnc#1012628).
- gfs2: Do log_flush in gfs2_ail_empty_gl even if ail list is
  empty (bnc#1012628).
- gfs2: Don't demote a glock until its revokes are written
  (bnc#1012628).
- cpufreq: imx6q: fix error handling (bnc#1012628).
- x86/boot: Use unsigned comparison for addresses (bnc#1012628).
- efi/x86: Ignore the memory attributes table on i386
  (bnc#1012628).
- genirq/irqdomain: Check pointer in
  irq_domain_alloc_irqs_hierarchy() (bnc#1012628).
- block: Fix use-after-free issue accessing struct io_cq
  (bnc#1012628).
- block, zoned: fix integer overflow with BLKRESETZONE et al
  (bnc#1012628).
- media: mtk-vpu: avoid unaligned access to DTCM buffer
  (bnc#1012628).
- media: i2c: ov5695: Fix power on and off sequences
  (bnc#1012628).
- usb: dwc3: core: add support for disabling SS instances in
  park mode (bnc#1012628).
- irqchip/gic-v4: Provide irq_retrigger to avoid circular locking
  dependency (bnc#1012628).
- md: check arrays is suspended in mddev_detach before call
  quiesce operations (bnc#1012628).
- firmware: fix a double abort case with fw_load_sysfs_fallback
  (bnc#1012628).
- spi: spi-fsl-dspi: Replace interruptible wait queue with a
  simple completion (bnc#1012628).
- locking/lockdep: Avoid recursion in
  lockdep_count_{for,back}ward_deps() (bnc#1012628).
- staging: mt7621-pci: avoid to poweroff the phy for slot one
  (bnc#1012628).
- block, bfq: fix use-after-free in bfq_idle_slice_timer_body
  (bnc#1012628).
- btrfs: qgroup: ensure qgroup_rescan_running is only set when
  the worker is at least queued (bnc#1012628).
- btrfs: remove a BUG_ON() from merge_reloc_roots() (bnc#1012628).
- btrfs: restart relocate_tree_blocks properly (bnc#1012628).
- btrfs: track reloc roots based on their commit root bytenr
  (bnc#1012628).
- ASoC: fix regwmask (bnc#1012628).
- ASoC: dapm: connect virtual mux with default value
  (bnc#1012628).
- ASoC: dpcm: allow start or stop during pause for backend
  (bnc#1012628).
- ASoC: topology: use name_prefix for new kcontrol (bnc#1012628).
- usb: gadget: f_fs: Fix use after free issue as part of queue
  failure (bnc#1012628).
- usb: gadget: composite: Inform controller driver of self-powered
  (bnc#1012628).
- ALSA: usb-audio: Add mixer workaround for TRX40 and co
  (bnc#1012628).
- ALSA: hda: Add driver blacklist (bnc#1012628).
- ALSA: hda: Fix potential access overflow in beep helper
  (bnc#1012628).
- ALSA: ice1724: Fix invalid access for enumerated ctl items
  (bnc#1012628).
- ALSA: pcm: oss: Fix regression by buffer overflow fix
  (bnc#1012628).
- ALSA: hda/realtek: Enable mute LED on an HP system
  (bnc#1012628).
- ALSA: hda/realtek - a fake key event is triggered by running
  shutup (bnc#1012628).
- ALSA: doc: Document PC Beep Hidden Register on Realtek ALC256
  (bnc#1012628).
- ALSA: hda/realtek - Set principled PC Beep configuration for
  ALC256 (bnc#1012628).
- ALSA: hda/realtek - Remove now-unnecessary XPS 13 headphone
  noise fixups (bnc#1012628).
- ALSA: hda/realtek - Add quirk for Lenovo Carbon X1 8th gen
  (bnc#1012628).
- ALSA: hda/realtek - Add quirk for MSI GL63 (bnc#1012628).
- media: venus: cache vb payload to be used by clock scaling
  (bnc#1012628).
- media: venus: firmware: Ignore secure call error on first resume
  (bnc#1012628).
- media: hantro: Read be32 words starting at every fourth byte
  (bnc#1012628).
- media: ti-vpe: cal: fix disable_irqs to only the intended target
  (bnc#1012628).
- media: ti-vpe: cal: fix a kernel oops when unloading module
  (bnc#1012628).
- seccomp: Add missing compat_ioctl for notify (bnc#1012628).
- ACPI: EC: Avoid printing confusing messages in acpi_ec_setup()
  (bnc#1012628).
- acpi/x86: ignore unspecified bit positions in the ACPI global
  lock field (bnc#1012628).
- ACPICA: Allow acpi_any_gpe_status_set() to skip one GPE
  (bnc#1012628).
- ACPI: PM: s2idle: Refine active GPEs check (bnc#1012628).
- thermal: int340x_thermal: fix: Update Tiger Lake ACPI device
  IDs (bnc#1012628).
- thermal: devfreq_cooling: inline all stubs for
  CONFIG_DEVFREQ_THERMAL=n (bnc#1012628).
- nvmet-tcp: fix maxh2cdata icresp parameter (bnc#1012628).
- nvme-fc: Revert "add module to ops template to allow module
  references" (bnc#1012628).
- efi/x86: Add TPM related EFI tables to unencrypted mapping
  checks (bnc#1012628).
- PCI: pciehp: Fix indefinite wait on sysfs requests
  (bnc#1012628).
- PCI/ASPM: Clear the correct bits when enabling L1 substates
  (bnc#1012628).
- PCI: Add boot interrupt quirk mechanism for Xeon chipsets
  (bnc#1012628).
- PCI: qcom: Fix the fixup of PCI_VENDOR_ID_QCOM (bnc#1012628).
- PCI: endpoint: Fix for concurrent memory allocation in OB
  address region (bnc#1012628).
- erofs: correct the remaining shrink objects (bnc#1012628).
- sched/fair: Fix enqueue_task_fair warning (bnc#1012628).
- tpm: Don't make log failures fatal (bnc#1012628).
- tpm: tpm1_bios_measurements_next should increase position index
  (bnc#1012628).
- tpm: tpm2_bios_measurements_next should increase position index
  (bnc#1012628).
- KEYS: reaching the keys quotas correctly (bnc#1012628).
- mmc: mmci_sdmmc: Fix clear busyd0end irq flag (bnc#1012628).
- rcu: Make rcu_barrier() account for offline no-CBs CPUs
  (bnc#1012628).
- cpu/hotplug: Ignore pm_wakeup_pending() for
  disable_nonboot_cpus() (bnc#1012628).
- genirq/debugfs: Add missing sanity checks to interrupt injection
  (bnc#1012628).
- irqchip/versatile-fpga: Apply clear-mask earlier (bnc#1012628).
- io_uring: ensure openat sets O_LARGEFILE if needed
  (bnc#1012628).
- io_uring: remove bogus RLIMIT_NOFILE check in file registration
  (bnc#1012628).
- io_uring: fix ctx refcounting in io_submit_sqes() (bnc#1012628).
- pstore: pstore_ftrace_seq_next should increase position index
  (bnc#1012628).
- MIPS/tlbex: Fix LDDIR usage in setup_pw() for Loongson-3
  (bnc#1012628).
- MIPS: OCTEON: irq: Fix potential NULL pointer dereference
  (bnc#1012628).
- PM / Domains: Allow no domain-idle-states DT property in genpd
  when parsing (bnc#1012628).
- PM: sleep: wakeup: Skip wakeup_source_sysfs_remove() if device
  is not there (bnc#1012628).
- ath9k: Handle txpower changes even when TPC is disabled
  (bnc#1012628).
- signal: Extend exec_id to 64bits (bnc#1012628).
- x86/tsc_msr: Use named struct initializers (bnc#1012628).
- x86/tsc_msr: Fix MSR_FSB_FREQ mask for Cherry Trail devices
  (bnc#1012628).
- x86/tsc_msr: Make MSR derived TSC frequency more accurate
  (bnc#1012628).
- x86/entry/32: Add missing ASM_CLAC to general_protection entry
  (bnc#1012628).
- platform/x86: asus-wmi: Support laptops where the first battery
  is named BATT (bnc#1012628).
- KVM: PPC: Book3S HV: Skip kvmppc_uvmem_free if Ultravisor is
  not supported (bnc#1012628).
- KVM: nVMX: Properly handle userspace interrupt window request
  (bnc#1012628).
- KVM: s390: vsie: Fix region 1 ASCE sanity shadow address checks
  (bnc#1012628).
- KVM: s390: vsie: Fix delivery of addressing exceptions
  (bnc#1012628).
- KVM: x86: Allocate new rmap and large page tracking when moving
  memslot (bnc#1012628).
- KVM: VMX: Always VMCLEAR in-use VMCSes during crash with kexec
  support (bnc#1012628).
- KVM: x86: Gracefully handle __vmalloc() failure during VM
  allocation (bnc#1012628).
- KVM: VMX: Add a trampoline to fix VMREAD error handling
  (bnc#1012628).
- KVM: VMX: fix crash cleanup when KVM wasn't used (bnc#1012628).
- smb3: fix performance regression with setting mtime
  (bnc#1012628).
- CIFS: Fix bug which the return value by asynchronous read is
  error (bnc#1012628).
- CIFS: check new file size when extending file by fallocate
  (bnc#1012628).
- mtd: spinand: Stop using spinand->oobbuf for buffering bad
  block markers (bnc#1012628).
- mtd: spinand: Do not erase the block before writing a bad
  block marker (bnc#1012628).
- mtd: rawnand: cadence: fix the calculation of the avaialble
  OOB size (bnc#1012628).
- mtd: rawnand: cadence: change bad block marker size
  (bnc#1012628).
- mtd: rawnand: cadence: reinit completion before executing a
  new command (bnc#1012628).
- drm/i915/gen12: Disable preemption timeout (bnc#1012628).
- btrfs: Don't submit any btree write bio if the fs has errors
  (bnc#1012628).
- btrfs: fix btrfs_calc_reclaim_metadata_size calculation
  (bnc#1012628).
- Btrfs: fix crash during unmount due to race with delayed inode
  workers (bnc#1012628).
- btrfs: reloc: clean dirty subvols if we fail to start a
  transaction (bnc#1012628).
- btrfs: set update the uuid generation as soon as possible
  (bnc#1012628).
- btrfs: drop block from cache on error in relocation
  (bnc#1012628).
- btrfs: fix missing file extent item for hole after ranged fsync
  (bnc#1012628).
- btrfs: unset reloc control if we fail to recover (bnc#1012628).
- btrfs: fix missing semaphore unlock in btrfs_sync_file
  (bnc#1012628).
- btrfs: use nofs allocations for running delayed items
  (bnc#1012628).
- remoteproc: qcom_q6v5_mss: Don't reassign mpss region on
  shutdown (bnc#1012628).
- remoteproc: qcom_q6v5_mss: Reload the mba region on coredump
  (bnc#1012628).
- remoteproc: Fix NULL pointer dereference in rproc_virtio_notify
  (bnc#1012628).
- time/namespace: Fix time_for_children symlink (bnc#1012628).
- time/namespace: Add max_time_namespaces ucount (bnc#1012628).
- crypto: rng - Fix a refcounting bug in crypto_rng_reset()
  (bnc#1012628).
- crypto: mxs-dcp - fix scatterlist linearization for hash
  (bnc#1012628).
- io_uring: honor original task RLIMIT_FSIZE (bnc#1012628).
- scsi: mpt3sas: Fix kernel panic observed on soft HBA unplug
  (bnc#1012628).
- tools: gpio: Fix out-of-tree build regression (bnc#1012628).
- net: qualcomm: rmnet: Allow configuration updates to existing
  devices (bnc#1012628).
- arm64: dts: allwinner: h6: Fix PMU compatible (bnc#1012628).
- sched/core: Remove duplicate assignment in sched_tick_remote()
  (bnc#1012628).
- arm64: dts: allwinner: h5: Fix PMU compatible (bnc#1012628).
- mm, memcg: do not high throttle allocators based on wraparound
  (bnc#1012628).
- dm writecache: add cond_resched to avoid CPU hangs
  (bnc#1012628).
- dm integrity: fix a crash with unusually large tag size
  (bnc#1012628).
- dm verity fec: fix memory leak in verity_fec_dtr (bnc#1012628).
- dm zoned: remove duplicate nr_rnd_zones increase in
  dmz_init_zone() (bnc#1012628).
- dm clone: Fix handling of partial region discards (bnc#1012628).
- dm clone: Add overflow check for number of regions
  (bnc#1012628).
- dm clone: Add missing casts to prevent overflows and data
  corruption (bnc#1012628).
- dm clone metadata: Fix return type of
  dm_clone_nr_of_hydrated_regions() (bnc#1012628).
- XArray: Fix xas_pause for large multi-index entries
  (bnc#1012628).
- xarray: Fix early termination of xas_for_each_marked
  (bnc#1012628).
- crypto: caam/qi2 - fix chacha20 data size error (bnc#1012628).
- crypto: caam - update xts sector size for large input length
  (bnc#1012628).
- crypto: ccree - protect against empty or NULL scatterlists
  (bnc#1012628).
- crypto: ccree - only try to map auth tag if needed
  (bnc#1012628).
- crypto: ccree - dec auth tag size from cryptlen map
  (bnc#1012628).
- scsi: zfcp: fix missing erp_lock in port recovery trigger for
  point-to-point (bnc#1012628).
- scsi: ufs: fix Auto-Hibern8 error detection (bnc#1012628).
- scsi: lpfc: Fix lpfc_io_buf resource leak in
  lpfc_get_scsi_buf_s4 error path (bnc#1012628).
- scsi: lpfc: Fix broken Credit Recovery after driver load
  (bnc#1012628).
- ARM: dts: exynos: Fix polarity of the LCD SPI bus on
  UniversalC210 board (bnc#1012628).
- arm64: dts: ti: k3-am65: Add clocks to dwc3 nodes (bnc#1012628).
- arm64: armv8_deprecated: Fix undef_hook mask for thumb setend
  (bnc#1012628).
- selftests: vm: drop dependencies on page flags from mlock2 tests
  (bnc#1012628).
- selftests/vm: fix map_hugetlb length used for testing read
  and write (bnc#1012628).
- selftests/powerpc: Add tlbie_test in .gitignore (bnc#1012628).
- selftests/powerpc: Fix try-run when source tree is not writable
  (bnc#1012628).
- vfio: platform: Switch to platform_get_irq_optional()
  (bnc#1012628).
- drm/i915/gem: Flush all the reloc_gpu batch (bnc#1012628).
- drm/bridge: analogix-anx78xx: Fix drm_dp_link helper removal
  (bnc#1012628).
- drm/etnaviv: rework perfmon query infrastructure (bnc#1012628).
- drm: Remove PageReserved manipulation from drm_pci_alloc
  (bnc#1012628).
- drm/amdgpu/powerplay: using the FCLK DPM table to set the MCLK
  (bnc#1012628).
- drm/amd/powerplay: implement the is_dpm_running() (bnc#1012628).
- drm/amdgpu: unify fw_write_wait for new gfx9 asics
  (bnc#1012628).
- drm/amd/display: Check for null fclk voltage when parsing
  clock table (bnc#1012628).
- drm/prime: fix extracting of the DMA addresses from a
  scatterlist (bnc#1012628).
- drm/i915/icl+: Don't enable DDI IO power on a TypeC port in
  TBT mode (bnc#1012628).
- powerpc/pseries: Avoid NULL pointer dereference when drmem is
  unavailable (bnc#1012628).
- drm/vboxvideo: Add missing remove_conflicting_pci_framebuffers
  call, v2 (bnc#1012628).
- nfsd: fsnotify on rmdir under nfsd/clients/ (bnc#1012628).
- NFS: Fix use-after-free issues in nfs_pageio_add_request()
  (bnc#1012628).
- NFS: Fix a page leak in nfs_destroy_unlinked_subrequests()
  (bnc#1012628).
- NFS: finish_automount() requires us to hold 2 refs to the
  mount record (bnc#1012628).
- NFS: Fix a few constant_table array definitions (bnc#1012628).
- ext4: fix a data race at inode->i_blocks (bnc#1012628).
- drm/i915/gt: Treat idling as a RPS downclock event
  (bnc#1012628).
- ASoC: cs4270: pull reset GPIO low then high (bnc#1012628).
- fs/filesystems.c: downgrade user-reachable WARN_ONCE() to
  pr_warn_once() (bnc#1012628).
- ocfs2: no need try to truncate file beyond i_size (bnc#1012628).
- perf tools: Support Python 3.8+ in Makefile (bnc#1012628).
- s390/diag: fix display of diagnose call statistics
  (bnc#1012628).
- Input: i8042 - add Acer Aspire 5738z to nomux list
  (bnc#1012628).
- ftrace/kprobe: Show the maxactive number on kprobe_events
  (bnc#1012628).
- clk: ingenic/jz4770: Exit with error if CGU init failed
  (bnc#1012628).
- clk: ingenic/TCU: Fix round_rate returning error (bnc#1012628).
- kmod: make request_module() return an error when autoloading
  is disabled (bnc#1012628).
- cpufreq: powernv: Fix use-after-free (bnc#1012628).
- hfsplus: fix crash and filesystem corruption when deleting files
  (bnc#1012628).
- libata: Return correct status in sata_pmp_eh_recover_pm()
  when ATA_DFLAG_DETACH is set (bnc#1012628).
- ipmi: fix hung processes in __get_guid() (bnc#1012628).
- xen/blkfront: fix memory allocation flags in
  blkfront_setup_indirect() (bnc#1012628).
- scsi: sr: get rid of sr global mutex (bnc#1012628).
- scsi: sr: Fix sr_block_release() (bnc#1012628).
- powerpc: Make setjmp/longjmp signature standard (bnc#1012628).
- powerpc/64/tm: Don't let userspace set regs->trap via sigreturn
  (bnc#1012628).
- powerpc/fsl_booke: Avoid creating duplicate tlb1 entry
  (bnc#1012628).
- powerpc/hash64/devmap: Use H_PAGE_THP_HUGE when setting up
  huge devmap PTE entries (bnc#1012628).
- powerpc/xive: Use XIVE_BAD_IRQ instead of zero to catch non
  configured IPIs (bnc#1012628).
- powerpc/64: Setup a paca before parsing device tree etc
  (bnc#1012628).
- powerpc/xive: Fix xmon support on the PowerNV platform
  (bnc#1012628).
- powerpc/kprobes: Ignore traps that happened in real mode
  (bnc#1012628).
- powerpc/64: Prevent stack protection in early boot
  (bnc#1012628).
- arm64: Always force a branch protection mode when the compiler
  has one (bnc#1012628).
- Revert "drm/dp_mst: Remove VCPI while disabling topology mgr"
  (bnc#1012628).
- drm/dp_mst: Fix clearing payload state on topology disable
  (bnc#1012628).
- drm/amdgpu: fix gfx hang during suspend with video playback (v2)
  (bnc#1012628).
- drm/i915/ggtt: do not set bits 1-11 in gen12 ptes (bnc#1012628).
- drm/i915/gt: Fill all the unused space in the GGTT
  (bnc#1012628).
- perf/core: Unify {pinned,flexible}_sched_in() (bnc#1012628).
- perf/core: Fix event cgroup tracking (bnc#1012628).
- perf/core: Remove 'struct sched_in_data' (bnc#1012628).
- powerpc/kasan: Fix kasan_remap_early_shadow_ro() (bnc#1012628).
- bpf: Fix tnum constraints for 32-bit comparisons (bnc#1012628).
- mfd: dln2: Fix sanity checking for endpoints (bnc#1012628).
- ASoC: stm32: sai: Add missing cleanup (bnc#1012628).
- commit 6656dc4
* Wed Apr 15 2020 tiwai@suse.de
- Update config files: fix vanilla config for CONFIG_SND_HDA_PREALLOC_SIZE
  Those have to removed from vanilla config once after the fix went into
  5.6.y stable tree and backported.
- commit 902100b
* Wed Apr 15 2020 msuchanek@suse.de
- rpm/check-for-config-changes: Ignore CONFIG_LD_VERSION
- commit e60242e
* Wed Apr 15 2020 tiwai@suse.de
- ALSA: hda: Allow setting preallocation again for x86
  (bsc#1169471).
- Update config files: revert CONFIG_SND_HDA_PREALLOC_SIZE changes
- commit 2cd7ffd
* Tue Apr 14 2020 schwab@suse.de
- Add config files for riscv64
- commit b85c09e
* Mon Apr 13 2020 jslaby@suse.cz
- Linux 5.6.4 (bnc#1012628).
- driver core: Reevaluate dev->links.need_for_probe as suppliers
  are added (bnc#1012628).
- io-uring: drop completion when removing file (bnc#1012628).
- fbcon: fix null-ptr-deref in fbcon_switch (bnc#1012628).
- blk-mq: Keep set->nr_hw_queues and set->map[].nr_queues in sync
  (bnc#1012628).
- RDMA/cm: Update num_paths in cma_resolve_iboe_route error flow
  (bnc#1012628).
- Bluetooth: RFCOMM: fix ODEBUG bug in rfcomm_dev_ioctl
  (bnc#1012628).
- RDMA/siw: Fix passive connection establishment (bnc#1012628).
- RDMA/cma: Teach lockdep about the order of rtnl and lock
  (bnc#1012628).
- RDMA/ucma: Put a lock around every call to the rdma_cm layer
  (bnc#1012628).
- ubi: fastmap: Free unused fastmap anchor peb during detach
  (bnc#1012628).
- IB/mlx5: Replace tunnel mpls capability bits for tunnel_offloads
  (bnc#1012628).
- IB/hfi1: Fix memory leaks in sysfs registration and
  unregistration (bnc#1012628).
- IB/hfi1: Call kobject_put() when kobject_init_and_add() fails
  (bnc#1012628).
- ASoC: jz4740-i2s: Fix divider written at incorrect offset in
  register (bnc#1012628).
- ASoC: tas2562: Fixed incorrect amp_level setting (bnc#1012628).
- platform/x86: intel_int0002_vgpio: Use
  acpi_register_wakeup_handler() (bnc#1012628).
- ACPI: PM: Add acpi_[un]register_wakeup_handler() (bnc#1012628).
- hwrng: imx-rngc - fix an error path (bnc#1012628).
- tools/accounting/getdelays.c: fix netlink attribute length
  (bnc#1012628).
- slub: improve bit diffusion for freelist ptr obfuscation
  (bnc#1012628).
- usb: dwc3: gadget: Wrap around when skip TRBs (bnc#1012628).
- random: always use batched entropy for get_random_u{32,64}
  (bnc#1012628).
- s390: prevent leaking kernel address in BEAR (bnc#1012628).
- net: phy: at803x: fix clock sink configuration on ATH8030 and
  ATH8035 (bnc#1012628).
- cxgb4: free MQPRIO resources in shutdown path (bnc#1012628).
- r8169: change back SG and TSO to be disabled by default
  (bnc#1012628).
- mlxsw: spectrum_flower: Do not stop at FLOW_ACTION_VLAN_MANGLE
  (bnc#1012628).
- tun: Don't put_page() for all negative return values from XDP
  program (bnc#1012628).
- slcan: Don't transmit uninitialized stack data in padding
  (bnc#1012628).
- net: stmmac: dwmac1000: fix out-of-bounds mac address reg
  setting (bnc#1012628).
- net_sched: fix a missing refcnt in tcindex_init() (bnc#1012628).
- net_sched: add a temporary refcnt for struct tcindex_data
  (bnc#1012628).
- net: phy: micrel: kszphy_resume(): add delay after
  genphy_resume() before accessing PHY registers (bnc#1012628).
- net: dsa: mt7530: fix null pointer dereferencing in port5 setup
  (bnc#1012628).
- net: dsa: bcm_sf2: Ensure correct sub-node is parsed
  (bnc#1012628).
- net: dsa: bcm_sf2: Do not register slave MDIO bus with OF
  (bnc#1012628).
- ipv6: don't auto-add link-local address to lag ports
  (bnc#1012628).
- cxgb4: fix MPS index overwrite when setting MAC address
  (bnc#1012628).
- commit e42da4f
* Mon Apr 13 2020 mkubecek@suse.cz
- Update to 5.7-rc1
- eliminated 70 patches (66 stable, 4 other)
- disable ARM architectures (need config update)
- refresh
  - patches.suse/supported-flag
  - patches.suse/supported-flag-external
  - patches.suse/supported-flag-modverdir
  - patches.suse/vfs-add-super_operations-get_inode_dev
  - patches.suse/acpi_thinkpad_introduce_acpi_root_table_boot_param.patch
  - patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch
- fix s390x build:
  patches.suse/tty-sysrq-Export-sysrq_mask.patch
- new config options:
- General setup
  - CONFIG_SCHED_THERMAL_PRESSURE=y
  - CONFIG_BPF_LSM=y
- Power management and ACPI options
  - CONFIG_ACPI_TINY_POWER_BUTTON=m
  - CONFIG_ACPI_TINY_POWER_BUTTON_SIGNAL=38
- Memory Management options
  - CONFIG_ZSWAP_COMPRESSOR_DEFAULT_LZO=y
  - CONFIG_ZSWAP_ZPOOL_DEFAULT_ZBUD=y
  - CONFIG_ZSWAP_DEFAULT_ON=n
- Networking support
  - CONFIG_IPV6_RPL_LWTUNNEL=y
- File systems
  - CONFIG_EXFAT_FS=m
  - CONFIG_EXFAT_DEFAULT_IOCHARSET="utf8"
- Cryptographic API
  - CONFIG_CHELSIO_TLS_DEVICE=y
- Kernel hacking
  - CONFIG_MAGIC_SYSRQ_SERIAL_SEQUENCE=""
  - CONFIG_TEST_LOCKUP=n
  - CONFIG_TEST_MIN_HEAP=n
- PCI
  - CONFIG_PCIE_EDR=n
- Network device drivers
  - CONFIG_BAREUDP=m
  - CONFIG_MLX5_TC_CT=y
  - CONFIG_DWMAC_INTEL=m
  - CONFIG_MDIO_MVUSB=m
  - CONFIG_BCM84881_PHY=m
  - PHY_CADENCE_TORRENT=m (i386, ppc64(le))
- PTP clock support
  - CONFIG_PTP_1588_CLOCK_IDT82P33=m
  - CONFIG_PTP_1588_CLOCK_VMW=m
- Graphics
  - CONFIG_DRM_I915_MAX_REQUEST_BUSYWAIT=8000
  - CONFIG_TINYDRM_ILI9486=n
  - DRM_PANEL_BOE_TV101WUM_NL6=n
  - DRM_PANEL_ELIDA_KD35T133=n
  - DRM_PANEL_FEIXIN_K101_IM2BA02=n
  - DRM_PANEL_NOVATEK_NT35510=n
  - DRM_PANEL_SAMSUNG_S6E88A0_AMS452EF01=n
  - DRM_DISPLAY_CONNECTOR=n
  - DRM_PARADE_PS8640=n
  - DRM_SIMPLE_BRIDGE=n
  - DRM_TOSHIBA_TC358768=n
  - DRM_TI_TPD12S015=n
- Sound
  - CONFIG_SND_SOC_AMD_RV_RT5682_MACH=m
  - CONFIG_SND_BCM63XX_I2S_WHISTLER=n
  - CONFIG_SND_SOC_INTEL_SOF_PCM512x_MACH=m
  - CONFIG_SND_SOC_SOF_DEBUG_PROBES=n
  - CONFIG_SND_SOC_RT5682_SDW=n
  - CONFIG_SND_SOC_TLV320ADCX140=n
- Input
  - CONFIG_HID_GLORIOUS=m
  - CONFIG_HID_MCP2221=m
  - CONFIG_KEYBOARD_IQS62X=m
- USB
  - CONFIG_APPLE_MFI_FASTCHARGE=m
  - CONFIG_TYPEC_MUX_INTEL_PMC=m
- Virtio drivers
  - CONFIG_VIRTIO_VDPA=m
  - CONFIG_VDPA_MENU=y
  - CONFIG_VDPA_SIM=m
  - CONFIG_IFCVF=m
  - CONFIG_VHOST_MENU=y
  - CONFIG_VHOST_VDPA=m
- Platform drivers
  - CONFIG_SURFACE_3_POWER_OPREGION=m
  - CONFIG_CROS_EC_TYPEC=m
  - CONFIG_CROS_USBPD_NOTIFY=m
- Industrial I/O
  - CONFIG_HMC425=n
  - CONFIG_AD5770R=n
  - CONFIG_AL3010=n
  - CONFIG_GP2AP002=n
  - CONFIG_ICP10100=n
  - CONFIG_IQS621_ALS=n
  - CONFIG_IQS624_POS=n
  - CONFIG_IQS620AT_TEMP=n
- Misc drivers
  - CONFIG_MHI_BUS=m
  - CONFIG_UACCE=m
  - CONFIG_ATA_FORCE=y
  - CONFIG_SERIAL_SPRD=m
  - CONFIG_SPI_MUX=m
  - CONFIG_PINCTRL_DA9062=m
  - CONFIG_SENSORS_AXI_FAN_CONTROL=m
  - CONFIG_MFD_IQS62X=m
  - CONFIG_VIDEO_IMX219=m
  - CONFIG_MMC_HSQ=m
  - CONFIG_DMABUF_MOVE_NOTIFY=n
  - CONFIG_PWM_DEBUG=n
  - CONFIG_MUX_ADG792A=n
  - CONFIG_MUX_ADGS1408=n
  - CONFIG_MUX_GPIO=n
- i386
  - REGULATOR_MP541=m
  - REGULATOR_MP886X=m
- ppc64
  - PMU_SYSFS=y
  - FSL_ENETC=m
  - FSL_ENETC_VF=m
  - FSL_ENETC_PTP_CLOCK=m
  - FSL_ENETC_QOS=y
  - SPI_FSI=m
  - REGULATOR_MP5416=m
  - REGULATOR_MP886X=m
- s390x
  - XILINX_LL_TEMAC=m
  - MDIO_XPCS=m
  - QETH_OSN=y
  - QETH_OSX=y
- commit 84ddad4
* Sun Apr 12 2020 mkubecek@suse.cz
- constrants: fix malformed XML
  Closing tag of an element is "</foo>", not "<foo/>".
  Fixes: 8b37de2eb835 ("rpm/constraints.in: Increase memory for kernel-docs")
- commit 4a8ca28
* Thu Apr  9 2020 jslaby@suse.cz
- Refresh
  patches.suse/efi-x86-Don-t-remap-text-rodata-gap-read-only-for-mi.patch.
  Update upstream status.
- commit 5b340fd
* Thu Apr  9 2020 jslaby@suse.cz
- efi/x86: Fix the deletion of variables in mixed mode
  (bnc#1167933).
- commit 61c9284
* Thu Apr  9 2020 jslaby@suse.cz
- efi/x86: Don't remap text<->rodata gap read-only for mixed mode
  (bnc#1168645).
- commit fd9c360
* Thu Apr  9 2020 mgorman@suse.de
- Update config files to disable CONFIG_TRACE_IRQFLAGS (bsc#1169078).
- commit d379575
* Thu Apr  9 2020 msuchanek@suse.de
- rpm/constraints.in: Increase memory for kernel-docs
  References: https://build.opensuse.org/request/show/792664
- commit 8b37de2
* Thu Apr  9 2020 neilb@suse.de
- cachefiles: fix corruption of 'ret' (boo#1168841).
- commit 0a79cdc
* Wed Apr  8 2020 jslaby@suse.cz
- Linux 5.6.3 (bnc#1012628).
- ipv4: fix a RCU-list lock in fib_triestat_seq_show
  (bnc#1012628).
- net: dsa: ksz: Select KSZ protocol tag (bnc#1012628).
- net, ip_tunnel: fix interface lookup with no key (bnc#1012628).
- sctp: fix possibly using a bad saddr with a given dst
  (bnc#1012628).
- sctp: fix refcount bug in sctp_wfree (bnc#1012628).
- net: macb: Fix handling of fixed-link node (bnc#1012628).
- net: fix fraglist segmentation reference count leak
  (bnc#1012628).
- udp: initialize is_flist with 0 in udp_gro_receive
  (bnc#1012628).
- padata: fix uninitialized return value in padata_replace()
  (bnc#1012628).
- brcmfmac: abort and release host after error (bnc#1012628).
- XArray: Fix xa_find_next for large multi-index entries
  (bnc#1012628).
- drm/bridge: analogix-anx6345: Avoid duplicate -supply suffix
  (bnc#1012628).
- misc: rtsx: set correct pcr_ops for rts522A (bnc#1012628).
- misc: pci_endpoint_test: Fix to support > 10 pci-endpoint-test
  devices (bnc#1012628).
- misc: pci_endpoint_test: Avoid using module parameter to
  determine irqtype (bnc#1012628).
- PCI: sysfs: Revert "rescan" file renames (bnc#1012628).
- coresight: do not use the BIT() macro in the UAPI header
  (bnc#1012628).
- mei: me: add cedar fork device ids (bnc#1012628).
- nvmem: release the write-protect pin (bnc#1012628).
- nvmem: check for NULL reg_read and reg_write before
  dereferencing (bnc#1012628).
- nvmem: sprd: Fix the block lock operation (bnc#1012628).
- extcon: axp288: Add wakeup support (bnc#1012628).
- power: supply: axp288_charger: Add special handling for HP
  Pavilion x2 10 (bnc#1012628).
- Revert "ALSA: uapi: Drop asound.h inclusion from asoc.h"
  (bnc#1012628).
- Revert "dm: always call blk_queue_split() in dm_process_bio()"
  (bnc#1012628).
- ALSA: hda/ca0132 - Add Recon3Di quirk to handle integrated
  sound on EVGA X99 Classified motherboard (bnc#1012628).
- soc: mediatek: knows_txdone needs to be set in Mediatek CMDQ
  helper (bnc#1012628).
- perf python: Fix clang detection to strip out options passed
  in $CC (bnc#1012628).
- mm: mempolicy: require at least one nodeid for MPOL_PREFERRED
  (bnc#1012628).
- commit 97c6e99
* Tue Apr  7 2020 msuchanek@suse.de
- s390x: zfcpdump: disable CONFIG_RELOCATABLE (bsc#1168847).
- commit c824449
* Tue Apr  7 2020 mgorman@suse.de
- Update config files to disable CONFIG_UCLAMP_TASK (bsc#1168888).
- commit 025835f
* Mon Apr  6 2020 jslaby@suse.cz
- net/bpfilter: remove superfluous testing message (bnc#1168664).
- commit 7d8cfa8
* Fri Apr  3 2020 msuchanek@suse.de
- Delete patches.rpmify/powerpc-Blacklist-GCC-5.4-6.1-and-6.2.patch.
- commit daf9f5a
* Fri Apr  3 2020 yousaf.kaukab@suse.com
- config: arm64: enable cpufreq driver for Jetson Nano and Jetson TX1
- commit 3187813
* Thu Apr  2 2020 tiwai@suse.de
- drm/i915/display: Fix mode private_flags comparison at
  atomic_check (bsc#1168383).
- commit a83dd8f
* Thu Apr  2 2020 jslaby@suse.cz
- bpf: update jmp32 test cases to fix range bound deduction
  (bnc#1012628).
- serial: sprd: Fix a dereference warning (bnc#1012628).
- vt: selection, introduce vc_is_sel (bnc#1012628).
- vt: ioctl, switch VT_IS_IN_USE and VT_BUSY to inlines
  (bnc#1012628).
- vt: switch vt_dont_switch to bool (bnc#1012628).
- vt: vt_ioctl: remove unnecessary console allocation checks
  (bnc#1012628).
- vt: vt_ioctl: fix VT_DISALLOCATE freeing in-use virtual console
  (bnc#1012628).
- vt: vt_ioctl: fix use-after-free in vt_in_use() (bnc#1012628).
- platform/x86: pmc_atom: Add Lex 2I385SW to critclk_systems
  DMI table (bnc#1012628).
- Linux 5.6.2 (bnc#1012628).
- commit 8dfb75b
* Wed Apr  1 2020 jslaby@suse.cz
- Linux 5.6.1 (bnc#1012628).
- media: v4l2-core: fix a use-after-free bug of sd->devnode
  (bnc#1012628).
- media: xirlink_cit: add missing descriptor sanity checks
  (bnc#1012628).
- media: stv06xx: add missing descriptor sanity checks
  (bnc#1012628).
- media: dib0700: fix rc endpoint lookup (bnc#1012628).
- media: ov519: add missing endpoint sanity checks (bnc#1012628).
- libfs: fix infoleak in simple_attr_read() (bnc#1012628).
- ahci: Add Intel Comet Lake H RAID PCI ID (bnc#1012628).
- staging: wfx: annotate nested gc_list vs tx queue locking
  (bnc#1012628).
- staging: wfx: fix init/remove vs IRQ race (bnc#1012628).
- staging: wfx: add proper "compatible" string (bnc#1012628).
- staging: wlan-ng: fix use-after-free Read in
  hfa384x_usbin_callback (bnc#1012628).
- staging: wlan-ng: fix ODEBUG bug in prism2sta_disconnect_usb
  (bnc#1012628).
- staging: rtl8188eu: Add ASUS USB-N10 Nano B1 to device table
  (bnc#1012628).
- staging: kpc2000: prevent underflow in cpld_reconfigure()
  (bnc#1012628).
- media: usbtv: fix control-message timeouts (bnc#1012628).
- media: flexcop-usb: fix endpoint sanity check (bnc#1012628).
- usb: musb: fix crash with highmen PIO and usbmon (bnc#1012628).
- USB: serial: io_edgeport: fix slab-out-of-bounds read in
  edge_interrupt_callback (bnc#1012628).
- USB: cdc-acm: restore capability check order (bnc#1012628).
- USB: serial: option: add Wistron Neweb D19Q1 (bnc#1012628).
- USB: serial: option: add BroadMobi BM806U (bnc#1012628).
- USB: serial: option: add support for ASKEY WWHC050
  (bnc#1012628).
- bpf: Undo incorrect __reg_bound_offset32 handling (bnc#1012628).
- commit 1675c56
* Wed Apr  1 2020 jslaby@suse.cz
- Refresh
  patches.suse/media-go7007-Fix-URB-type-for-interrupt-handling.patch.
  Update upstream status.
- commit 96043ad
* Wed Apr  1 2020 jslaby@suse.cz
- Refresh
  patches.suse/mac80211-fix-authentication-with-iwlwifi-mvm.patch.
  Update upstream status -- merged.
- commit 26b6c02
* Mon Mar 30 2020 jslaby@suse.cz
- Refresh
  patches.suse/media-go7007-Fix-URB-type-for-interrupt-handling.patch.
  Update upstream status.
- commit 46fab61
* Mon Mar 30 2020 mkubecek@suse.cz
- mac80211: fix authentication with iwlwifi/mvm
  (https://lkml.kernel.org/r/20200329.212136.273575061630425724.davem@davemloft.net).
- commit 5032681
* Mon Mar 30 2020 mkubecek@suse.cz
- Revert "sign also s390x kernel images (bsc#1163524)"
  This reverts commit b38b61155f0a2c3ebca06d4bb0c2e11a19a87f1f.
  The pesign-obs-integration changes needed for s390x image signing are
  still missing in Factory so that this change breaks s390x builds.
- commit 9544af9
* Mon Mar 30 2020 mkubecek@suse.cz
- Update to 5.6 final
- refresh configs
- commit da616f7
* Thu Mar 26 2020 jslaby@suse.cz
- Linux 5.5.13 (bnc#1012628).
- commit 0af205d
* Wed Mar 25 2020 jslaby@suse.cz
- driver core: Add dev_has_sync_state() (bnc#1167245).
- commit 9fa62a7
* Wed Mar 25 2020 jslaby@suse.cz
- driver core: Skip unnecessary work when device doesn't have
  sync_state() (bnc#1167245).
- commit 2d483bd
* Wed Mar 25 2020 jslaby@suse.cz
- Linux 5.5.12 (bnc#1012628).
- locks: fix a potential use-after-free problem when wakeup a
  waiter (bnc#1012628).
- locks: reinstate locks_delete_block optimization (bnc#1012628).
- spi: spi-omap2-mcspi: Support probe deferral for DMA channels
  (bnc#1012628).
- drm/mediatek: Find the cursor plane instead of hard coding it
  (bnc#1012628).
- drm/mediatek: Ensure the cursor plane is on top of other
  overlays (bnc#1012628).
- phy: ti: gmii-sel: fix set of copy-paste errors (bnc#1012628).
- phy: ti: gmii-sel: do not fail in case of gmii (bnc#1012628).
- ARM: dts: dra7-l4: mark timer13-16 as pwm capable (bnc#1012628).
- spi: qup: call spi_qup_pm_resume_runtime before suspending
  (bnc#1012628).
- powerpc: Include .BTF section (bnc#1012628).
- cifs: fix potential mismatch of UNC paths (bnc#1012628).
- cifs: add missing mount option to /proc/mounts (bnc#1012628).
- ARM: dts: dra7: Add "dma-ranges" property to PCIe RC DT nodes
  (bnc#1012628).
- spi: pxa2xx: Add CS control clock quirk (bnc#1012628).
- spi/zynqmp: remove entry that causes a cs glitch (bnc#1012628).
- ARM: dts: bcm283x: Add missing properties to the PWR LED
  (bnc#1012628).
- drm/exynos: dsi: propagate error value and silence meaningless
  warning (bnc#1012628).
- drm/exynos: dsi: fix workaround for the legacy clock name
  (bnc#1012628).
- drm/exynos: hdmi: don't leak enable HDMI_EN regulator if probe
  fails (bnc#1012628).
- drivers/perf: fsl_imx8_ddr: Correct the CLEAR bit definition
  (bnc#1012628).
- drivers/perf: arm_pmu_acpi: Fix incorrect checking of gicc
  pointer (bnc#1012628).
- io-wq: fix IO_WQ_WORK_NO_CANCEL cancellation (bnc#1012628).
- ARM: bcm2835_defconfig: Explicitly restore CONFIG_DEBUG_FS
  (bnc#1012628).
- altera-stapl: altera_get_note: prevent write beyond end of 'key'
  (bnc#1012628).
- dm bio record: save/restore bi_end_io and bi_integrity
  (bnc#1012628).
- dm integrity: use dm_bio_record and dm_bio_restore
  (bnc#1012628).
- riscv: avoid the PIC offset of static percpu data in module
  beyond 2G limits (bnc#1012628).
- ASoC: stm32: sai: manage rebind issue (bnc#1012628).
- spi: spi_register_controller(): free bus id on error paths
  (bnc#1012628).
- riscv: Force flat memory model with no-mmu (bnc#1012628).
- riscv: Fix range looking for kernel image memblock
  (bnc#1012628).
- drm/amdgpu: clean wptr on wb when gpu recovery (bnc#1012628).
- drm/amd/display: Clear link settings on MST disable connector
  (bnc#1012628).
- drm/amd/display: fix dcc swath size calculations on dcn1
  (bnc#1012628).
- xenbus: req->body should be updated before req->state
  (bnc#1012628).
- xenbus: req->err should be updated before req->state
  (bnc#1012628).
- riscv: fix seccomp reject syscall code path (bnc#1012628).
- parse-maintainers: Mark as executable (bnc#1012628).
- io_uring: fix lockup with timeouts (bnc#1012628).
- binderfs: use refcount for binder control devices too
  (bnc#1012628).
- USB: Disable LPM on WD19's Realtek Hub (bnc#1012628).
- usb: quirks: add NO_LPM quirk for RTL8153 based ethernet
  adapters (bnc#1012628).
- USB: serial: option: add ME910G1 ECM composition 0x110b
  (bnc#1012628).
- usb: chipidea: udc: fix sleeping function called from invalid
  context (bnc#1012628).
- usb: host: xhci-plat: add a shutdown (bnc#1012628).
- USB: serial: pl2303: add device-id for HP LD381 (bnc#1012628).
- usb: xhci: apply XHCI_SUSPEND_DELAY to AMD XHCI controller
  1022:145c (bnc#1012628).
- usb: typec: ucsi: displayport: Fix NULL pointer dereference
  (bnc#1012628).
- usb: typec: ucsi: displayport: Fix a potential race during
  registration (bnc#1012628).
- USB: cdc-acm: fix close_delay and closing_wait units in
  TIOCSSERIAL (bnc#1012628).
- USB: cdc-acm: fix rounding error in TIOCSSERIAL (bnc#1012628).
- ALSA: line6: Fix endless MIDI read loop (bnc#1012628).
- ALSA: hda/realtek - Enable headset mic of Acer X2660G with
  ALC662 (bnc#1012628).
- ALSA: hda/realtek - Enable the headset of Acer N50-600 with
  ALC662 (bnc#1012628).
- ALSA: seq: virmidi: Fix running status after receiving sysex
  (bnc#1012628).
- ALSA: seq: oss: Fix running status after receiving sysex
  (bnc#1012628).
- ALSA: pcm: oss: Avoid plugin buffer overflow (bnc#1012628).
- ALSA: pcm: oss: Remove WARNING from snd_pcm_plug_alloc() checks
  (bnc#1012628).
- tty: fix compat TIOCGSERIAL leaking uninitialized memory
  (bnc#1012628).
- tty: fix compat TIOCGSERIAL checking wrong function ptr
  (bnc#1012628).
- iio: chemical: sps30: fix missing triggered buffer dependency
  (bnc#1012628).
- iio: st_sensors: remap SMO8840 to LIS2DH12 (bnc#1012628).
- iio: trigger: stm32-timer: disable master mode when stopping
  (bnc#1012628).
- iio: accel: adxl372: Set iio_chan BE (bnc#1012628).
- iio: magnetometer: ak8974: Fix negative raw values in sysfs
  (bnc#1012628).
- iio: adc: stm32-dfsdm: fix sleep in atomic context
  (bnc#1012628).
- iio: adc: at91-sama5d2_adc: fix differential channels in
  triggered mode (bnc#1012628).
- iio: light: vcnl4000: update sampling periods for vcnl4200
  (bnc#1012628).
- iio: light: vcnl4000: update sampling periods for vcnl4040
  (bnc#1012628).
- mmc: rtsx_pci: Fix support for speed-modes that relies on tuning
  (bnc#1012628).
- mmc: sdhci-of-at91: fix cd-gpios for SAMA5D2 (bnc#1012628).
- mmc: sdhci-cadence: set SDHCI_QUIRK2_PRESET_VALUE_BROKEN for
  UniPhier (bnc#1012628).
- mmc: sdhci-acpi: Switch signal voltage back to 3.3V on suspend
  on external microSD on Lenovo Miix 320 (bnc#1012628).
- mmc: sdhci-acpi: Disable write protect detection on Acer Aspire
  Switch 10 (SW5-012) (bnc#1012628).
- CIFS: fiemap: do not return EINVAL if get nothing (bnc#1012628).
- kbuild: Disable -Wpointer-to-enum-cast (bnc#1012628).
- staging: rtl8188eu: Add device id for MERCUSYS MW150US v2
  (bnc#1012628).
- staging: greybus: loopback_test: fix poll-mask build breakage
  (bnc#1012628).
- staging/speakup: fix get_word non-space look-ahead
  (bnc#1012628).
- intel_th: msu: Fix the unexpected state warning (bnc#1012628).
- intel_th: Fix user-visible error codes (bnc#1012628).
- intel_th: pci: Add Elkhart Lake CPU support (bnc#1012628).
- modpost: move the namespace field in Module.symvers last
  (bnc#1012628).
- rtc: max8907: add missing select REGMAP_IRQ (bnc#1012628).
- arm64: compat: Fix syscall number of compat_clock_getres
  (bnc#1012628).
- xhci: Do not open code __print_symbolic() in xhci trace events
  (bnc#1012628).
- btrfs: fix log context list corruption after rename whiteout
  error (bnc#1012628).
- drm/amd/amdgpu: Fix GPR read from debugfs (v2) (bnc#1012628).
- drm/lease: fix WARNING in idr_destroy (bnc#1012628).
- stm class: sys-t: Fix the use of time_after() (bnc#1012628).
- memcg: fix NULL pointer dereference in
  __mem_cgroup_usage_unregister_event (bnc#1012628).
- mm, memcg: fix corruption on 64-bit divisor in memory.high
  throttling (bnc#1012628).
- mm, memcg: throttle allocators based on ancestral memory.high
  (bnc#1012628).
- mm/hotplug: fix hot remove failure in SPARSEMEM|!VMEMMAP case
  (bnc#1012628).
- mm: do not allow MADV_PAGEOUT for CoW pages (bnc#1012628).
- epoll: fix possible lost wakeup on epoll_ctl() path
  (bnc#1012628).
- mm: slub: be more careful about the double cmpxchg of freelist
  (bnc#1012628).
- mm, slub: prevent kmalloc_node crashes and memory leaks
  (bnc#1012628).
- page-flags: fix a crash at SetPageError(THP_SWAP) (bnc#1012628).
- x86/mm: split vmalloc_sync_all() (bnc#1012628).
- io_uring: NULL-deref for IOSQE_{ASYNC,DRAIN} (bnc#1012628).
- futex: Fix inode life-time issue (bnc#1012628).
- futex: Unbreak futex hashing (bnc#1012628).
- ALSA: hda/realtek: Fix pop noise on ALC225 (bnc#1012628).
- thunderbolt: Fix error code in tb_port_is_width_supported()
  (bnc#1012628).
- arm64: smp: fix smp_send_stop() behaviour (bnc#1012628).
- arm64: smp: fix crash_smp_send_stop() behaviour (bnc#1012628).
- nvmet-tcp: set MSG_MORE only if we actually have more to send
  (bnc#1012628).
- modpost: Get proper section index by get_secindex() instead
  of st_shndx (bnc#1012628).
- btrfs: fix removal of raid[56|1c34} incompat flags after
  removing block group (bnc#1012628).
- Revert "drm/i915/tgl: Add extra hdc flush workaround"
  (bnc#1012628).
- drm/bridge: dw-hdmi: fix AVI frame colorimetry (bnc#1012628).
- drm/i915/execlists: Track active elements during dequeue
  (bnc#1012628).
- drm/i915: Handle all MCR ranges (bnc#1012628).
- staging: greybus: loopback_test: fix potential path truncation
  (bnc#1012628).
- staging: greybus: loopback_test: fix potential path truncations
  (bnc#1012628).
- kconfig: introduce m32-flag and m64-flag (bnc#1012628).
- int128: fix __uint128_t compiler test in Kconfig (bnc#1012628).
- Refresh patches.suse/supported-flag.
- Update config files.
- commit 19257da
* Mon Mar 23 2020 mkubecek@suse.cz
- Update to 5.6-rc7
- refresh
  patches.suse/supported-flag
- refresh config files:
  - CC_HAS_INT128=n on 32-bit architectures (was =y on i386)
- commit 0801cd7
* Sat Mar 21 2020 jslaby@suse.cz
- Linux 5.5.11 (bnc#1012628).
- ipv4: ensure rcu_read_lock() in cipso_v4_error() (bnc#1012628).
- ARM: 8961/2: Fix Kbuild issue caused by per-task stack protector
  GCC plugin (bnc#1012628).
- HID: add ALWAYS_POLL quirk to lenovo pixart mouse (bnc#1012628).
- HID: google: add moonball USB id (bnc#1012628).
- mm: slub: add missing TID bump in kmem_cache_alloc_bulk()
  (bnc#1012628).
- ARM: 8958/1: rename missed uaccess .fixup section (bnc#1012628).
- ARM: 8957/1: VDSO: Match ARMv8 timer in cntvct_functional()
  (bnc#1012628).
- blk-mq: insert flush request to the front of dispatch queue
  (bnc#1012628).
- jbd2: fix data races at struct journal_head (bnc#1012628).
- net: dsa: mv88e6xxx: Fix masking of egress port (bnc#1012628).
- mlxsw: pci: Wait longer before accessing the device after reset
  (bnc#1012628).
- sfc: fix timestamp reconstruction at 16-bit rollover points
  (bnc#1012628).
- net: rmnet: fix packet forwarding in rmnet bridge mode
  (bnc#1012628).
- net: rmnet: fix bridge mode bugs (bnc#1012628).
- net: rmnet: use upper/lower device infrastructure (bnc#1012628).
- net: rmnet: do not allow to change mux id if mux id is
  duplicated (bnc#1012628).
- net: rmnet: remove rcu_read_lock in
  rmnet_force_unassociate_device() (bnc#1012628).
- net: rmnet: fix suspicious RCU usage (bnc#1012628).
- net: rmnet: fix NULL pointer dereference in rmnet_changelink()
  (bnc#1012628).
- net: rmnet: fix NULL pointer dereference in rmnet_newlink()
  (bnc#1012628).
- hinic: fix a bug of rss configuration (bnc#1012628).
- hinic: fix a bug of setting hw_ioctxt (bnc#1012628).
- hinic: fix a irq affinity bug (bnc#1012628).
- net: phy: mscc: fix firmware paths (bnc#1012628).
- slip: not call free_netdev before rtnl_unlock in slip_open
  (bnc#1012628).
- net: bcmgenet: Clear ID_MODE_DIS in EXT_RGMII_OOB_CTRL when
  not needed (bnc#1012628).
- signal: avoid double atomic counter increments for user
  accounting (bnc#1012628).
- kbuild: add dt_binding_check to PHONY in a correct place
  (bnc#1012628).
- kbuild: add dtbs_check to PHONY (bnc#1012628).
- io_uring: pick up link work on submit reference drop
  (bnc#1012628).
- drm/amdgpu: fix memory leak during TDR test(v2) (bnc#1012628).
- io_uring: fix poll_list race for SETUP_IOPOLL|SETUP_SQPOLL
  (bnc#1012628).
- blk-mq: insert passthrough request into hctx->dispatch directly
  (bnc#1012628).
- net: ll_temac: Handle DMA halt condition caused by buffer
  underrun (bnc#1012628).
- net: ll_temac: Fix RX buffer descriptor handling on GFP_ATOMIC
  pressure (bnc#1012628).
- net: ll_temac: Add more error handling of dma_map_single()
  calls (bnc#1012628).
- net: ll_temac: Fix race condition causing TX hang (bnc#1012628).
- mac80211: rx: avoid RCU list traversal under mutex
  (bnc#1012628).
- net: ks8851-ml: Fix IRQ handling and locking (bnc#1012628).
- net: usb: qmi_wwan: restore mtu min/max values after raw_ip
  switch (bnc#1012628).
- scsi: libfc: free response frame from GPN_ID (bnc#1012628).
- cfg80211: check reg_rule for NULL in handle_channel_custom()
  (bnc#1012628).
- tracing: Fix number printing bug in print_synth_event()
  (bnc#1012628).
- selftests/rseq: Fix out-of-tree compilation (bnc#1012628).
- kunit: run kunit_tool from any directory (bnc#1012628).
- riscv: set pmp configuration if kernel is running in M-mode
  (bnc#1012628).
- HID: hid-bigbenff: fix race condition for scheduled work during
  removal (bnc#1012628).
- HID: hid-bigbenff: call hid_hw_stop() in case of error
  (bnc#1012628).
- HID: hid-bigbenff: fix general protection fault caused by
  double kfree (bnc#1012628).
- HID: i2c-hid: add Trekstor Surfbook E11B to descriptor override
  (bnc#1012628).
- ACPI: watchdog: Set default timeout in probe (bnc#1012628).
- HID: apple: Add support for recent firmware on Magic Keyboards
  (bnc#1012628).
- ACPI: watchdog: Allow disabling WDAT at boot (bnc#1012628).
- pinctrl: qcom: ssbi-gpio: Fix fwspec parsing bug (bnc#1012628).
- commit 794b2e9
* Thu Mar 19 2020 yousaf.kaukab@suse.com
- config: arm64: enable CONFIG_MTD_PHYSMAP_OF
  Get rid of CONFIG_MTD_PHYSMAP_COMPAT and enable CONFIG_MTD_PHYSMAP_OF.
  Compat maps of zero length (CONFIG_MTD_PHYSMAP_LEN=0x0) doesn't make
  sense and driver initialization is bound to fail. So use device-tree
  based initialization.
- commit 2205109
* Wed Mar 18 2020 jslaby@suse.cz
- Linux 5.5.10 (bnc#1012628).
- virtio_balloon: Adjust label in virtballoon_probe (bnc#1012628).
- ALSA: hda/realtek - More constifications (bnc#1012628).
- ALSA: hda/realtek - Add Headset Mic supported for HP cPC
  (bnc#1012628).
- ALSA: hda/realtek - Fixed one of HP ALC671 platform Headset
  Mic supported (bnc#1012628).
- cgroup, netclassid: periodically release file_lock on classid
  updating (bnc#1012628).
- cxgb4: fix checks for max queues to allocate (bnc#1012628).
- gre: fix uninit-value in __iptunnel_pull_header (bnc#1012628).
- inet_diag: return classid for all socket types (bnc#1012628).
- ipv6/addrconf: call ipv6_mc_up() for non-Ethernet interface
  (bnc#1012628).
- ipvlan: add cond_resched_rcu() while processing muticast backlog
  (bnc#1012628).
- ipvlan: do not add hardware address of master to its unicast
  filter list (bnc#1012628).
- ipvlan: do not use cond_resched_rcu() in
  ipvlan_process_multicast() (bnc#1012628).
- ipvlan: don't deref eth hdr before checking it's set
  (bnc#1012628).
- macvlan: add cond_resched() during multicast processing
  (bnc#1012628).
- net: dsa: fix phylink_start()/phylink_stop() calls
  (bnc#1012628).
- net: dsa: mv88e6xxx: fix lockup on warm boot (bnc#1012628).
- net: fec: validate the new settings in fec_enet_set_coalesce()
  (bnc#1012628).
- net: hns3: fix a not link up issue when fibre port supports
  autoneg (bnc#1012628).
- net/ipv6: use configured metric when add peer route
  (bnc#1012628).
- netlink: Use netlink header as base to calculate bad attribute
  offset (bnc#1012628).
- net: macsec: update SCI upon MAC address change (bnc#1012628).
- net: mscc: ocelot: properly account for VLAN header length
  when setting MRU (bnc#1012628).
- net: nfc: fix bounds checking bugs on "pipe" (bnc#1012628).
- net/packet: tpacket_rcv: do not increment ring index on drop
  (bnc#1012628).
- net: phy: bcm63xx: fix OOPS due to missing driver name
  (bnc#1012628).
- net/smc: cancel event worker during device removal
  (bnc#1012628).
- net: stmmac: dwmac1000: Disable ACS if enhanced descs are not
  used (bnc#1012628).
- net: systemport: fix index check to avoid an array out of
  bounds access (bnc#1012628).
- r8152: check disconnect status after long sleep (bnc#1012628).
- sfc: detach from cb_page in efx_copy_channel() (bnc#1012628).
- slip: make slhc_compress() more robust against malicious packets
  (bnc#1012628).
- taprio: Fix sending packets without dequeueing them
  (bnc#1012628).
- bonding/alb: make sure arp header is pulled before accessing it
  (bnc#1012628).
- bnxt_en: reinitialize IRQs when MTU is modified (bnc#1012628).
- bnxt_en: fix error handling when flashing from file
  (bnc#1012628).
- cgroup: memcg: net: do not associate sock with unrelated cgroup
  (bnc#1012628).
- net: memcg: late association of sock to memcg (bnc#1012628).
- net: memcg: fix lockdep splat in inet_csk_accept()
  (bnc#1012628).
- dt-bindings: net: FMan erratum A050385 (bnc#1012628).
- arm64: dts: ls1043a: FMan erratum A050385 (bnc#1012628).
- fsl/fman: detect FMan erratum A050385 (bnc#1012628).
- dpaa_eth: FMan erratum A050385 workaround (bnc#1012628).
- net: hns3: fix "tc qdisc del" failed issue (bnc#1012628).
- net: hns3: fix RMW issue for VLAN filter switch (bnc#1012628).
- net: hns3: clear port base VLAN when unload PF (bnc#1012628).
- devlink: validate length of param values (bnc#1012628).
- devlink: validate length of region addr/len (bnc#1012628).
- fib: add missing attribute validation for tun_id (bnc#1012628).
- nl802154: add missing attribute validation (bnc#1012628).
- nl802154: add missing attribute validation for dev_type
  (bnc#1012628).
- can: add missing attribute validation for termination
  (bnc#1012628).
- macsec: add missing attribute validation for port (bnc#1012628).
- openvswitch: add missing attribute validation for hash
  (bnc#1012628).
- net: fq: add missing attribute validation for orphan mask
  (bnc#1012628).
- net: taprio: add missing attribute validation for txtime delay
  (bnc#1012628).
- team: add missing attribute validation for port ifindex
  (bnc#1012628).
- team: add missing attribute validation for array index
  (bnc#1012628).
- tipc: add missing attribute validation for MTU property
  (bnc#1012628).
- nfc: add missing attribute validation for SE API (bnc#1012628).
- nfc: add missing attribute validation for deactivate target
  (bnc#1012628).
- nfc: add missing attribute validation for vendor subcommand
  (bnc#1012628).
- net: phy: avoid clearing PHY interrupts twice in irq handler
  (bnc#1012628).
- net: phy: fix MDIO bus PM PHY resuming (bnc#1012628).
- net/ipv6: need update peer route when modify metric
  (bnc#1012628).
- net/ipv6: remove the old peer route if change it to a new one
  (bnc#1012628).
- selftests/net/fib_tests: update addr_metric_test for peer
  route testing (bnc#1012628).
- s390/qeth: don't reset default_out_queue (bnc#1012628).
- s390/qeth: handle error when backing RX buffer (bnc#1012628).
- net: dsa: Don't instantiate phylink for CPU/DSA ports unless
  needed (bnc#1012628).
- net: dsa: mv88e6xxx: Add missing mask of ATU occupancy register
  (bnc#1012628).
- net: phy: Avoid multiple suspends (bnc#1012628).
- cgroup: fix psi_show() crash on 32bit ino archs (bnc#1012628).
- cgroup: cgroup_procs_next should increase position index
  (bnc#1012628).
- cgroup: Iterate tasks that did not finish do_exit()
  (bnc#1012628).
- netfilter: nf_tables: fix infinite loop when expr is not
  available (bnc#1012628).
- virtio-blk: fix hw_queue stopped on arbitrary error
  (bnc#1012628).
- iommu/vt-d: quirk_ioat_snb_local_iommu: replace WARN_TAINT
  with pr_warn + add_taint (bnc#1012628).
- netfilter: nf_conntrack: ct_cpu_seq_next should increase
  position index (bnc#1012628).
- netfilter: synproxy: synproxy_cpu_seq_next should increase
  position index (bnc#1012628).
- netfilter: xt_recent: recent_seq_next should increase position
  index (bnc#1012628).
- netfilter: x_tables: xt_mttg_seq_next should increase position
  index (bnc#1012628).
- workqueue: don't use wq_select_unbound_cpu() for bound works
  (bnc#1012628).
- drm/amd/display: remove duplicated assignment to grph_obj_type
  (bnc#1012628).
- drm/i915: Actually emit the await_start (bnc#1012628).
- drm/i915: Return early for await_start on same timeline
  (bnc#1012628).
- drm/i915: be more solid in checking the alignment (bnc#1012628).
- drm/i915: Defer semaphore priority bumping to a workqueue
  (bnc#1012628).
- drm/i915/gt: Close race between cacheline_retire and free
  (bnc#1012628).
- drm/i915/execlists: Enable timeslice on partial virtual engine
  dequeue (bnc#1012628).
- mmc: sdhci-pci-gli: Enable MSI interrupt for GL975x
  (bnc#1012628).
- pinctrl: falcon: fix syntax error (bnc#1012628).
- pinctrl: qcom: Assign irq_eoi conditionally (bnc#1012628).
- ktest: Add timeout for ssh sync testing (bnc#1012628).
- block: Fix partition support for host aware zoned block devices
  (bnc#1012628).
- cifs_atomic_open(): fix double-put on late allocation failure
  (bnc#1012628).
- gfs2_atomic_open(): fix O_EXCL|O_CREAT handling on cold dcache
  (bnc#1012628).
- KVM: x86: clear stale x86_emulate_ctxt->intercept value
  (bnc#1012628).
- KVM: nVMX: avoid NULL pointer dereference with incorrect EVMCS
  GPAs (bnc#1012628).
- ARC: define __ALIGN_STR and __ALIGN symbols for ARC
  (bnc#1012628).
- fuse: fix stack use after return (bnc#1012628).
- MIPS: DTS: CI20: fix PMU definitions for ACT8600 (bnc#1012628).
- MIPS: DTS: CI20: fix interrupt for pcf8563 RTC (bnc#1012628).
- MIPS: Fix CONFIG_MIPS_CMDLINE_DTB_EXTEND handling (bnc#1012628).
- s390/dasd: fix data corruption for thin provisioned devices
  (bnc#1012628).
- ftrace: Return the first found result in lookup_rec()
  (bnc#1012628).
- blk-iocost: fix incorrect vtime comparison in iocg_is_idle()
  (bnc#1012628).
- fscrypt: don't evict dirty inodes after removing key
  (bnc#1012628).
- pid: Fix error return value in some cases (bnc#1012628).
- macintosh: windfarm: fix MODINFO regression (bnc#1012628).
- x86/ioremap: Map EFI runtime services data as encrypted for SEV
  (bnc#1012628).
- efi: Fix a race and a buffer overflow while reading efivars
  via sysfs (bnc#1012628).
- efi: Add a sanity check to efivar_store_raw() (bnc#1012628).
- i2c: designware-pci: Fix BUG_ON during device removal
  (bnc#1012628).
- mt76: fix array overflow on receiving too many fragments for
  a packet (bnc#1012628).
- perf/amd/uncore: Replace manual sampling check with
  CAP_NO_INTERRUPT flag (bnc#1012628).
- x86/mce: Fix logic and comments around MSR_PPIN_CTL
  (bnc#1012628).
- iommu/dma: Fix MSI reservation allocation (bnc#1012628).
- iommu/vt-d: dmar: replace WARN_TAINT with pr_warn + add_taint
  (bnc#1012628).
- iommu/vt-d: dmar_parse_one_rmrr: replace WARN_TAINT with
  pr_warn + add_taint (bnc#1012628).
- iommu/vt-d: Fix RCU list debugging warnings (bnc#1012628).
- iommu/vt-d: Fix a bug in intel_iommu_iova_to_phys() for huge
  page (bnc#1012628).
- batman-adv: Don't schedule OGM for disabled interface
  (bnc#1012628).
- clk: imx8mn: Fix incorrect clock defines (bnc#1012628).
- pinctrl: meson-gxl: fix GPIOX sdio pins (bnc#1012628).
- pinctrl: imx: scu: Align imx sc msg structs to 4 (bnc#1012628).
- virtio_ring: Fix mem leak with vring_new_virtqueue()
  (bnc#1012628).
- x86/mce/therm_throt: Undo thermal polling properly on CPU
  offline (bnc#1012628).
- drm/i915/gvt: Fix dma-buf display blur issue on CFL
  (bnc#1012628).
- pinctrl: core: Remove extra kref_get which blocks hogs being
  freed (bnc#1012628).
- drm/i915/gvt: Fix unnecessary schedule timer when no vGPU exits
  (bnc#1012628).
- driver code: clarify and fix platform device DMA mask allocation
  (bnc#1012628).
- iommu/vt-d: Fix RCU-list bugs in intel_iommu_init()
  (bnc#1012628).
- i2c: gpio: suppress error on probe defer (bnc#1012628).
- nl80211: add missing attribute validation for critical protocol
  indication (bnc#1012628).
- nl80211: add missing attribute validation for beacon report
  scanning (bnc#1012628).
- nl80211: add missing attribute validation for channel switch
  (bnc#1012628).
- perf bench futex-wake: Restore thread count default to online
  CPU count (bnc#1012628).
- netfilter: nf_tables: free flowtable hooks on hook register
  error (bnc#1012628).
- netfilter: cthelper: add missing attribute validation for
  cthelper (bnc#1012628).
- netfilter: nft_payload: add missing attribute validation for
  payload csum flags (bnc#1012628).
- netfilter: nft_tunnel: add missing attribute validation for
  tunnels (bnc#1012628).
- netfilter: nf_tables: dump NFTA_CHAIN_FLAGS attribute
  (bnc#1012628).
- netfilter: nft_chain_nat: inet family is missing module
  ownership (bnc#1012628).
- iommu/vt-d: Fix the wrong printing in RHSA parsing
  (bnc#1012628).
- iommu/vt-d: Ignore devices with out-of-spec domain number
  (bnc#1012628).
- i2c: acpi: put device when verifying client fails (bnc#1012628).
- iommu/amd: Fix IOMMU AVIC not properly update the is_run bit
  in IRTE (bnc#1012628).
- ipv6: restrict IPV6_ADDRFORM operation (bnc#1012628).
- net/smc: check for valid ib_client_data (bnc#1012628).
- Update config files.
- commit 3925fb5
* Mon Mar 16 2020 mkubecek@suse.cz
- Update to 5.6-rc6
- refresh config files
- commit 5c2f002
* Fri Mar 13 2020 nsaenzjulienne@suse.de
- mmc: sdhci: iproc: Add custom set_power() callback for bcm2711
  (bsc#1165954).
- mmc: sdhci: Introduce sdhci_set_power_and_bus_voltage()
  (bsc#1165954).
- mmc: sdhci: iproc: Add custom set_power() callback for bcm2711
  (bsc#1165954).
- mmc: sdhci: Introduce sdhci_set_power_and_bus_voltage()
  (bsc#1165954).
- commit e9e359d
* Fri Mar 13 2020 nsaenzjulienne@suse.de
- Delete patches.suse/linux-log2-h-add-roundup-rounddown_pow_two64-family-of-functions.patch.
  The patch was initially introduced to support RPi4's PCIe controller.
  The now available upstream driver isn't using this roundup
  functionality.
- commit ea370a5
* Thu Mar 12 2020 tiwai@suse.de
- Update config files: disable CONFIG_OABI_COMPAT for 32bit Arm (bsc#1165462)
  It enables CONFIG_SECCOMP_FILTER.
- commit e9e55d0
* Thu Mar 12 2020 tiwai@suse.de
- Update config files: enable CONFIG_EROFS_FS_ZIP=y
  Requested for supporting EROFS compressed files:
  https://lists.opensuse.org/opensuse-kernel/2020-02/msg00007.html
- commit 2b67ee5
* Thu Mar 12 2020 jslaby@suse.cz
- Linux 5.5.9 (bnc#1012628).
- ASoC: intel/skl/hda - export number of digital microphones
  via control components (bnc#1012628).
- block, bfq: get a ref to a group when adding it to a service
  tree (bnc#1012628).
- block, bfq: get extra ref to prevent a queue from being freed
  during a group move (bnc#1012628).
- block, bfq: do not insert oom queue into position tree
  (bnc#1012628).
- dm thin metadata: fix lockdep complaint (bnc#1012628).
- net: dsa: bcm_sf2: Forcibly configure IMP port for 1Gb/sec
  (bnc#1012628).
- RDMA/core: Fix pkey and port assignment in get_new_pps
  (bnc#1012628).
- RDMA/core: Fix use of logical OR in get_new_pps (bnc#1012628).
- blktrace: fix dereference after null check (bnc#1012628).
- netfilter: hashlimit: do not use indirect calls during gc
  (bnc#1012628).
- ALSA: hda: do not override bus codec_mask in link_get()
  (bnc#1012628).
- serial: ar933x_uart: set UART_CS_{RX,TX}_READY_ORIDE
  (bnc#1012628).
- Kernel selftests: tpm2: check for tpm support (bnc#1012628).
- selftests: fix too long argument (bnc#1012628).
- usb: gadget: composite: Support more than 500mA MaxPower
  (bnc#1012628).
- usb: gadget: ffs: ffs_aio_cancel(): Save/restore IRQ flags
  (bnc#1012628).
- usb: gadget: serial: fix Tx stall after buffer overflow
  (bnc#1012628).
- habanalabs: halt the engines before hard-reset (bnc#1012628).
- habanalabs: do not halt CoreSight during hard reset
  (bnc#1012628).
- habanalabs: patched cb equals user cb in device memset
  (bnc#1012628).
- drm/msm/mdp5: rate limit pp done timeout warnings (bnc#1012628).
- drm: msm: Fix return type of dsi_mgr_connector_mode_valid for
  kCFI (bnc#1012628).
- drm/modes: Make sure to parse valid rotation value from cmdline
  (bnc#1012628).
- drm/modes: Allow DRM_MODE_ROTATE_0 when applying video mode
  parameters (bnc#1012628).
- scsi: megaraid_sas: silence a warning (bnc#1012628).
- drm/msm/dsi: save pll state before dsi host is powered off
  (bnc#1012628).
- drm/msm/dsi/pll: call vco set rate explicitly (bnc#1012628).
- selftests: forwarding: use proto icmp for {gretap,
  ip6gretap}_mac testing (bnc#1012628).
- selftests: forwarding: vxlan_bridge_1d: fix tos value
  (bnc#1012628).
- net: atlantic: check rpc result and wait for rpc address
  (bnc#1012628).
- net: atlantic: ptp gpio adjustments (bnc#1012628).
- net: ks8851-ml: Remove 8-bit bus accessors (bnc#1012628).
- net: ks8851-ml: Fix 16-bit data access (bnc#1012628).
- net: ks8851-ml: Fix 16-bit IO operation (bnc#1012628).
- net: ethernet: dm9000: Handle -EPROBE_DEFER in dm9000_parse_dt()
  (bnc#1012628).
- watchdog: da9062: do not ping the hw during stop()
  (bnc#1012628).
- s390/cio: cio_ignore_proc_seq_next should increase position
  index (bnc#1012628).
- s390: make 'install' not depend on vmlinux (bnc#1012628).
- efi: Only print errors about failing to get certs if EFI vars
  are found (bnc#1012628).
- net/mlx5: DR, Fix matching on vport gvmi (bnc#1012628).
- iommu/amd: Disable IOMMU on Stoney Ridge systems (bnc#1012628).
- nvme/pci: Add sleep quirk for Samsung and Toshiba drives
  (bnc#1012628).
- nvme-pci: Use single IRQ vector for old Apple models
  (bnc#1012628).
- x86/boot/compressed: Don't declare __force_order in kaslr_64.c
  (bnc#1012628).
- s390/qdio: fill SL with absolute addresses (bnc#1012628).
- nvme: Fix uninitialized-variable warning (bnc#1012628).
- ice: Don't tell the OS that link is going down (bnc#1012628).
- x86/xen: Distribute switch variables for initialization
  (bnc#1012628).
- net: thunderx: workaround BGX TX Underflow issue (bnc#1012628).
- csky/mm: Fixup export invalid_pte_table symbol (bnc#1012628).
- csky: Set regs->usp to kernel sp, when the exception is from
  kernel (bnc#1012628).
- csky/smp: Fixup boot failed when CONFIG_SMP (bnc#1012628).
- csky: Fixup ftrace modify panic (bnc#1012628).
- csky: Fixup compile warning for three unimplemented syscalls
  (bnc#1012628).
- arch/csky: fix some Kconfig typos (bnc#1012628).
- selftests: forwarding: vxlan_bridge_1d: use more proper tos
  value (bnc#1012628).
- firmware: imx: scu: Ensure sequential TX (bnc#1012628).
- binder: prevent UAF for binderfs devices (bnc#1012628).
- binder: prevent UAF for binderfs devices II (bnc#1012628).
- ALSA: hda/realtek - Add Headset Mic supported (bnc#1012628).
- ALSA: hda/realtek - Add Headset Button supported for ThinkPad X1
  (bnc#1012628).
- ALSA: hda/realtek - Fix a regression for mute led on Lenovo
  Carbon X1 (bnc#1012628).
- ALSA: hda/realtek - Fix silent output on Gigabyte X570 Aorus
  Master (bnc#1012628).
- ALSA: hda/realtek - Enable the headset of ASUS B9450FA with
  ALC294 (bnc#1012628).
- driver core: Call sync_state() even if supplier has no consumers
  (bnc#1012628).
- cifs: don't leak -EAGAIN for stat() during reconnect
  (bnc#1012628).
- cifs: fix rename() by ensuring source handle opened with DELETE
  bit (bnc#1012628).
- usb: storage: Add quirk for Samsung Fit flash (bnc#1012628).
- usb: usb251xb: fix regulator probe and error handling
  (bnc#1012628).
- usb: quirks: add NO_LPM quirk for Logitech Screen Share
  (bnc#1012628).
- usb: dwc3: gadget: Update chain bit correctly when using sg list
  (bnc#1012628).
- usb: cdns3: gadget: link trb should point to next request
  (bnc#1012628).
- usb: cdns3: gadget: toggle cycle bit before reset endpoint
  (bnc#1012628).
- usb: core: hub: fix unhandled return by employing a void
  function (bnc#1012628).
- usb: core: hub: do error out if usb_autopm_get_interface()
  fails (bnc#1012628).
- usb: core: port: do error out if usb_autopm_get_interface()
  fails (bnc#1012628).
- vgacon: Fix a UAF in vgacon_invert_region (bnc#1012628).
- mm, numa: fix bad pmd by atomically check for pmd_trans_huge
  when marking page tables prot_numa (bnc#1012628).
- mm: fix possible PMD dirty bit lost in set_pmd_migration_entry()
  (bnc#1012628).
- mm: avoid data corruption on CoW fault into PFN-mapped VMA
  (bnc#1012628).
- mm, hotplug: fix page online with DEBUG_PAGEALLOC compiled
  but not enabled (bnc#1012628).
- fat: fix uninit-memory access for partial initialized inode
  (bnc#1012628).
- btrfs: fix RAID direct I/O reads with alternate csums
  (bnc#1012628).
- arm64: dts: socfpga: agilex: Fix gmac compatible (bnc#1012628).
- arm: dts: dra76x: Fix mmc3 max-frequency (bnc#1012628).
- phy: allwinner: Fix GENMASK misuse (bnc#1012628).
- tty:serial:mvebu-uart:fix a wrong return (bnc#1012628).
- tty: serial: fsl_lpuart: free IDs allocated by IDA
  (bnc#1012628).
- serial: 8250_exar: add support for ACCES cards (bnc#1012628).
- serdev: Fix detection of UART devices on Apple machines
  (bnc#1012628).
- media: hantro: Fix broken media controller links (bnc#1012628).
- media: mc-entity.c: use & to check pad flags, not ==
  (bnc#1012628).
- media: vicodec: process all 4 components for RGB32 formats
  (bnc#1012628).
- media: v4l2-mem2mem.c: fix broken links (bnc#1012628).
- perf intel-pt: Fix endless record after being terminated
  (bnc#1012628).
- perf intel-bts: Fix endless record after being terminated
  (bnc#1012628).
- perf cs-etm: Fix endless record after being terminated
  (bnc#1012628).
- perf arm-spe: Fix endless record after being terminated
  (bnc#1012628).
- spi: spidev: Fix CS polarity if GPIO descriptors are used
  (bnc#1012628).
- x86/ioperm: Add new paravirt function update_io_bitmap()
  (bnc#1012628).
- x86/pkeys: Manually set X86_FEATURE_OSPKE to preserve existing
  changes (bnc#1012628).
- s390/pci: Fix unexpected write combine on resource
  (bnc#1012628).
- s390/mm: fix panic in gup_fast on large pud (bnc#1012628).
- selftests: pidfd: Add pidfd_fdinfo_test in .gitignore
  (bnc#1012628).
- powerpc/mm: Fix missing KUAP disable in flush_coherent_icache()
  (bnc#1012628).
- drm/amdgpu: disable 3D pipe 1 on Navi1x (bnc#1012628).
- drm/amd/powerplay: fix pre-check condition for setting clock
  range (bnc#1012628).
- dmaengine: imx-sdma: fix context cache (bnc#1012628).
- dmaengine: imx-sdma: Fix the event id check to include RX
  event for UART6 (bnc#1012628).
- dmaengine: tegra-apb: Fix use-after-free (bnc#1012628).
- dmaengine: tegra-apb: Prevent race conditions of tasklet vs
  free list (bnc#1012628).
- dm integrity: fix recalculation when moving from journal mode
  to bitmap mode (bnc#1012628).
- dm integrity: fix a deadlock due to offloading to an incorrect
  workqueue (bnc#1012628).
- dm integrity: fix invalid table returned due to argument count
  mismatch (bnc#1012628).
- dm cache: fix a crash due to incorrect work item cancelling
  (bnc#1012628).
- dm: report suspended device during destroy (bnc#1012628).
- dm writecache: verify watermark during resume (bnc#1012628).
- dm zoned: Fix reference counter initial value of chunk works
  (bnc#1012628).
- dm: fix congested_fn for request-based device (bnc#1012628).
- arm64: dts: meson-sm1-sei610: add missing interrupt-names
  (bnc#1012628).
- ARM: dts: ls1021a: Restore MDIO compatible to gianfar
  (bnc#1012628).
- spi: bcm63xx-hsspi: Really keep pll clk enabled (bnc#1012628).
- drm/virtio: fix resource id creation race (bnc#1012628).
- ASoC: topology: Fix memleak in soc_tplg_link_elems_load()
  (bnc#1012628).
- ASoC: topology: Fix memleak in soc_tplg_manifest_load()
  (bnc#1012628).
- ASoC: SOF: Fix snd_sof_ipc_stream_posn() (bnc#1012628).
- ASoC: intel: skl: Fix pin debug prints (bnc#1012628).
- ASoC: intel: skl: Fix possible buffer overflow in debug outputs
  (bnc#1012628).
- ASoC: pcm: Fix possible buffer overflow in dpcm state sysfs
  output (bnc#1012628).
- ASoC: pcm512x: Fix unbalanced regulator enable call in probe
  error path (bnc#1012628).
- ASoC: Intel: Skylake: Fix available clock counter incrementation
  (bnc#1012628).
- ASoC: dapm: Correct DAPM handling of active widgets during
  shutdown (bnc#1012628).
- ASoC: soc-component: tidyup snd_soc_pcm_component_sync_stop()
  (bnc#1012628).
- spi: atmel-quadspi: fix possible MMIO window size overrun
  (bnc#1012628).
- drm/panfrost: Don't try to map on error faults (bnc#1012628).
- drm/mediatek: Handle component type MTK_DISP_OVL_2L correctly
  (bnc#1012628).
- drm/ttm: fix leaking fences via ttm_buffer_object_transfer
  (bnc#1012628).
- drm: kirin: Revert "Fix for hikey620 display offset problem"
  (bnc#1012628).
- drm/sun4i: Add separate DE3 VI layer formats (bnc#1012628).
- drm/sun4i: Fix DE2 VI layer format support (bnc#1012628).
- drm/sun4i: de2/de3: Remove unsupported VI layer formats
  (bnc#1012628).
- drm/i915: Program MBUS with rmw during initialization
  (bnc#1012628).
- drm/i915/selftests: Fix return in assert_mmap_offset()
  (bnc#1012628).
- drm/i915/perf: Reintroduce wait on OA configuration completion
  (bnc#1012628).
- phy: mapphone-mdm6600: Fix timeouts by adding wake-up handling
  (bnc#1012628).
- phy: mapphone-mdm6600: Fix write timeouts with shorter GPIO
  toggle interval (bnc#1012628).
- ARM: dts: imx6: phycore-som: fix emmc supply (bnc#1012628).
- arm64: dts: imx8qxp-mek: Remove unexisting Ethernet PHY
  (bnc#1012628).
- firmware: imx: misc: Align imx sc msg structs to 4
  (bnc#1012628).
- firmware: imx: scu-pd: Align imx sc msg structs to 4
  (bnc#1012628).
- firmware: imx: Align imx_sc_msg_req_cpu_start to 4
  (bnc#1012628).
- soc: imx-scu: Align imx sc msg structs to 4 (bnc#1012628).
- Revert "RDMA/cma: Simplify rdma_resolve_addr() error flow"
  (bnc#1012628).
- RDMA/rw: Fix error flow during RDMA context initialization
  (bnc#1012628).
- RDMA/odp: Ensure the mm is still alive before creating an
  implicit child (bnc#1012628).
- RDMA/nldev: Fix crash when set a QP to a new counter but QPN
  is missing (bnc#1012628).
- RDMA/siw: Fix failure handling during device creation
  (bnc#1012628).
- RDMA/iwcm: Fix iwcm work deallocation (bnc#1012628).
- RDMA/core: Fix protection fault in ib_mr_pool_destroy
  (bnc#1012628).
- regulator: stm32-vrefbuf: fix a possible overshoot when
  re-enabling (bnc#1012628).
- regulator: qcom_spmi: Fix docs for PM8004 (bnc#1012628).
- RMDA/cm: Fix missing ib_cm_destroy_id() in ib_cm_insert_listen()
  (bnc#1012628).
- IB/mlx5: Fix implicit ODP race (bnc#1012628).
- IB/hfi1, qib: Ensure RCU is locked when accessing list
  (bnc#1012628).
- ARM: imx: build v7_cpu_resume() unconditionally (bnc#1012628).
- ARM: dts: imx7d: fix opp-supported-hw (bnc#1012628).
- ARM: dts: am437x-idk-evm: Fix incorrect OPP node names
  (bnc#1012628).
- ARM: dts: dra7xx-clocks: Fixup IPU1 mux clock parent source
  (bnc#1012628).
- ARM: dts: imx7-colibri: Fix frequency for sd/mmc (bnc#1012628).
- hwmon: (adt7462) Fix an error return in ADT7462_REG_VOLT()
  (bnc#1012628).
- dma-buf: free dmabuf->name in dma_buf_release() (bnc#1012628).
- dmaengine: coh901318: Fix a double lock bug in dma_tc_handle()
  (bnc#1012628).
- sched/fair: Fix statistics for find_idlest_group()
  (bnc#1012628).
- arm64: dts: meson: fix gxm-khadas-vim2 wifi (bnc#1012628).
- bus: ti-sysc: Fix 1-wire reset quirk (bnc#1012628).
- dt-bindings: arm: fsl: fix APF6Dev compatible (bnc#1012628).
- EDAC/synopsys: Do not print an error with back-to-back
  snprintf() calls (bnc#1012628).
- powerpc: fix hardware PMU exception bug on PowerVM compatibility
  mode systems (bnc#1012628).
- efi/x86: Align GUIDs to their size in the mixed mode runtime
  wrapper (bnc#1012628).
- efi/x86: Handle by-ref arguments covering multiple pages in
  mixed mode (bnc#1012628).
- efi: READ_ONCE rng seed size before munmap (bnc#1012628).
- net: stmmac: fix notifier registration (bnc#1012628).
- block, bfq: remove ifdefs from around gets/puts of bfq groups
  (bnc#1012628).
- csky: Implement copy_thread_tls (bnc#1012628).
- commit 70a6377
* Wed Mar 11 2020 jslaby@suse.cz
- vt: selection, push sel_lock up (bnc#1162928 CVE-2020-8648).
- vt: selection, push console lock down (bnc#1162928
  CVE-2020-8648).
- commit 1538c30
* Wed Mar 11 2020 jslaby@suse.cz
- Refresh patches.suse/vt-selection-close-sel_buffer-race.patch.
  Update upstream status.
- commit e2b9350
* Tue Mar 10 2020 dmueller@suse.com
- drm/virtio: fix mmap page attributes (bsc#1163720).
- drm/shmem: add support for per object caching flags
  (bsc#1163720).
- commit 1e5a090
* Mon Mar  9 2020 jeyu@suse.de
- rpm/kabi.pl: account for namespace field being moved last
  Upstream is moving the namespace field in Module.symvers last in order to
  preserve backwards compatibility with kmod tools (depmod, etc). Fix the kabi.pl
  script to expect the namespace field last. Since split() ignores trailing empty
  fields and delimeters, switch to using tr to count how many fields/tabs are in
  a line. Also, in load_symvers(), pass LIMIT of -1 to split() so it does not
  strip trailing empty fields, as namespace is an optional field.
- commit a3bb253
* Mon Mar  9 2020 mkubecek@suse.cz
- Update to 5.6-rc5
- new config options:
  - BACKLIGHT_LED=m
- commit ff29e08
* Fri Mar  6 2020 jslaby@suse.cz
- netfilter: xt_hashlimit: unregister proc file before releasing
  mutex (git-fixes).
- commit fb4c60d
* Fri Mar  6 2020 jslaby@suse.cz
- Linux 5.5.8 (bnc#1012628).
- kvm: nVMX: VMWRITE checks unsupported field before read-only
  field (bnc#1012628).
- kvm: nVMX: VMWRITE checks VMCS-link pointer before VMCS field
  (bnc#1012628).
- mm, thp: fix defrag setting if newline is not used
  (bnc#1012628).
- mm/huge_memory.c: use head to check huge zero page
  (bnc#1012628).
- mm/gup: allow FOLL_FORCE for get_user_pages_fast()
  (bnc#1012628).
- mm/debug.c: always print flags in dump_page() (bnc#1012628).
- locking/lockdep: Fix lockdep_stats indentation problem
  (bnc#1012628).
- xfs: clear kernel only flags in XFS_IOC_ATTRMULTI_BY_HANDLE
  (bnc#1012628).
- clk: qcom: rpmh: Sort OF match table (bnc#1012628).
- bus: tegra-aconnect: Remove PM_CLK dependency (bnc#1012628).
- netfilter: nf_flowtable: fix documentation (bnc#1012628).
- netfilter: nft_tunnel: no need to call htons() when dumping
  ports (bnc#1012628).
- thermal: brcmstb_thermal: Do not use DT coefficients
  (bnc#1012628).
- thermal: db8500: Depromote debug print (bnc#1012628).
- ubifs: Fix ino_t format warnings in orphan_delete()
  (bnc#1012628).
- rcu: Allow only one expedited GP to run concurrently with
  wakeups (bnc#1012628).
- KVM: x86: Remove spurious clearing of async #PF MSR
  (bnc#1012628).
- KVM: x86: Remove spurious kvm_mmu_unload() from vcpu destruction
  path (bnc#1012628).
- KVM: X86: Fix kvm_bitmap_or_dest_vcpus() to use irq shorthand
  (bnc#1012628).
- x86/resctrl: Check monitoring static key in the MBM overflow
  handler (bnc#1012628).
- perf maps: Add missing unlock to maps__insert() error case
  (bnc#1012628).
- perf ui gtk: Add missing zalloc object (bnc#1012628).
- perf hists browser: Restore ESC as "Zoom out" of DSO/thread/etc
  (bnc#1012628).
- pwm: omap-dmtimer: put_device() after of_find_device_by_node()
  (bnc#1012628).
- lib/vdso: Update coarse timekeeper unconditionally
  (bnc#1012628).
- lib/vdso: Make __arch_update_vdso_data() logic understandable
  (bnc#1012628).
- kprobes: Set unoptimized flag after unoptimizing code
  (bnc#1012628).
- ima: ima/lsm policy rule loading logic bug fixes (bnc#1012628).
- drivers: net: xgene: Fix the order of the arguments of
  'alloc_etherdev_mqs()' (bnc#1012628).
- RDMA/hns: Bugfix for posting a wqe with sge (bnc#1012628).
- RDMA/hns: Simplify the calculation and usage of wqe idx for
  post verbs (bnc#1012628).
- f2fs: fix to add swap extent correctly (bnc#1012628).
- sched/fair: Optimize select_idle_cpu (bnc#1012628).
- KVM: Check for a bad hva before dropping into the ghc slow path
  (bnc#1012628).
- KVM: SVM: Override default MMIO mask if memory encryption is
  enabled (bnc#1012628).
- perf report: Fix no libunwind compiled warning break s390 issue
  (bnc#1012628).
- mwifiex: delete unused mwifiex_get_intf_num() (bnc#1012628).
- mwifiex: drop most magic numbers from
  mwifiex_process_tdls_action_frame() (bnc#1012628).
- namei: only return -ECHILD from follow_dotdot_rcu()
  (bnc#1012628).
- tipc: fix successful connect() but timed out (bnc#1012628).
- net: ena: make ena rxfh support ETH_RSS_HASH_NO_CHANGE
  (bnc#1012628).
- net/smc: no peer ID in CLC decline for SMCD (bnc#1012628).
- selftests: Install settings files to fix TIMEOUT failures
  (bnc#1012628).
- net: atlantic: fix out of range usage of active_vlans array
  (bnc#1012628).
- net: atlantic: possible fault in transition to hibernation
  (bnc#1012628).
- net: atlantic: fix potential error handling (bnc#1012628).
- net: atlantic: fix use after free kasan warn (bnc#1012628).
- net: atlantic: better loopback mode handling (bnc#1012628).
- net: atlantic: checksum compat issue (bnc#1012628).
- net: netlink: cap max groups which will be considered in
  netlink_bind() (bnc#1012628).
- s390/qeth: fix off-by-one in RX copybreak check (bnc#1012628).
- s390/qeth: vnicc Fix EOPNOTSUPP precedence (bnc#1012628).
- nvme-pci: Hold cq_poll_lock while completing CQEs (bnc#1012628).
- usb: charger: assign specific number for enum value
  (bnc#1012628).
- hv_netvsc: Fix unwanted wakeup in netvsc_attach() (bnc#1012628).
- kbuild: fix DT binding schema rule to detect command line
  changes (bnc#1012628).
- mac80211: Remove a redundant mutex unlock (bnc#1012628).
- nl80211: fix potential leak in AP start (bnc#1012628).
- drm/i915/gvt: Separate display reset from ALL_ENGINES reset
  (bnc#1012628).
- drm/i915: Avoid recursing onto active vma from the shrinker
  (bnc#1012628).
- drm/i915/gvt: Fix orphan vgpu dmabuf_objs' lifetime
  (bnc#1012628).
- MIPS: cavium_octeon: Fix syncw generation (bnc#1012628).
- i2c: jz4780: silence log flood on txabrt (bnc#1012628).
- i2c: altera: Fix potential integer overflow (bnc#1012628).
- MIPS: VPE: Fix a double free and a memory leak in
  'release_vpe()' (bnc#1012628).
- RISC-V: Don't enable all interrupts in trap_init()
  (bnc#1012628).
- HID: hiddev: Fix race in in hiddev_disconnect() (bnc#1012628).
- HID: alps: Fix an error handling path in
  'alps_input_configured()' (bnc#1012628).
- netfilter: xt_hashlimit: reduce hashlimit_mutex scope for
  htable_put() (bnc#1012628).
- netfilter: ipset: Fix forceadd evaluation path (bnc#1012628).
- vhost: Check docket sk_family instead of call getname
  (bnc#1012628).
- net/smc: transfer fasync_list in case of fallback (bnc#1012628).
- netfilter: ipset: Fix "INFO: rcu detected stall in hash_xxx"
  reports (bnc#1012628).
- io_uring: fix 32-bit compatability with sendmsg/recvmsg
  (bnc#1012628).
- cpufreq: Fix policy initialization for internal governor drivers
  (bnc#1012628).
- amdgpu/gmc_v9: save/restore sdpif regs during S3 (bnc#1012628).
- Revert "PM / devfreq: Modify the device name as devfreq(X)
  for sysfs" (bnc#1012628).
- tracing: Disable trace_printk() on post poned tests
  (bnc#1012628).
- blktrace: Protect q->blk_trace with RCU (bnc#1012628).
- macintosh: therm_windtunnel: fix regression when instantiating
  devices (bnc#1012628).
- drm/radeon: Inline drm_get_pci_dev (bnc#1012628).
- drm/amdgpu: Drop DRIVER_USE_AGP (bnc#1012628).
- HID: core: increase HID report buffer size to 8KiB
  (bnc#1012628).
- HID: core: fix off-by-one memset in hid_report_raw_event()
  (bnc#1012628).
- HID: ite: Only bind to keyboard USB interface on Acer SW5-012
  keyboard dock (bnc#1012628).
- KVM: VMX: check descriptor table exits on instruction emulation
  (bnc#1012628).
- ACPI: watchdog: Fix gas->access_width usage (bnc#1012628).
- ACPICA: Introduce ACPI_ACCESS_BYTE_WIDTH() macro (bnc#1012628).
- audit: always check the netlink payload length in
  audit_receive_msg() (bnc#1012628).
- audit: fix error handling in audit_data_to_entry()
  (bnc#1012628).
- ext4: potential crash on allocation error in
  ext4_alloc_flex_bg_array() (bnc#1012628).
- docs: Fix empty parallelism argument (bnc#1012628).
- scsi: zfcp: fix wrong data and display format of SFP+
  temperature (bnc#1012628).
- scsi: sd_sbc: Fix sd_zbc_report_zones() (bnc#1012628).
- nvme/pci: move cqe check after device shutdown (bnc#1012628).
- nvme: prevent warning triggered by nvme_stop_keep_alive
  (bnc#1012628).
- nvme/tcp: fix bug on double requeue when send fails
  (bnc#1012628).
- net: hns3: fix a copying IPv6 address error in
  hclge_fd_get_flow_tuples() (bnc#1012628).
- net: hns3: fix VF bandwidth does not take effect in some case
  (bnc#1012628).
- net: hns3: add management table after IMP reset (bnc#1012628).
- mac80211: fix wrong 160/80+80 MHz setting (bnc#1012628).
- cfg80211: add missing policy for NL80211_ATTR_STATUS_CODE
  (bnc#1012628).
- cifs: Fix mode output in debugging statements (bnc#1012628).
- io-wq: don't call kXalloc_node() with non-online node
  (bnc#1012628).
- ice: Use correct netif error function (bnc#1012628).
- ice: Use ice_pf_to_dev (bnc#1012628).
- ice: update Unit Load Status bitmask to check after reset
  (bnc#1012628).
- ice: fix and consolidate logging of NVM/firmware version
  information (bnc#1012628).
- ice: Don't allow same value for Rx tail to be written twice
  (bnc#1012628).
- ice: Fix switch between FW and SW LLDP (bnc#1012628).
- net: ena: ena-com.c: prevent NULL pointer dereference
  (bnc#1012628).
- net: ena: ethtool: use correct value for crc32 hash
  (bnc#1012628).
- net: ena: fix corruption of dev_idx_to_host_tbl (bnc#1012628).
- net: ena: fix incorrectly saving queue numbers when setting
  RSS indirection table (bnc#1012628).
- net: ena: rss: store hash function as values and not bits
  (bnc#1012628).
- net: ena: rss: fix failure to get indirection table
  (bnc#1012628).
- net: ena: rss: do not allocate key when not supported
  (bnc#1012628).
- net: ena: fix incorrect default RSS key (bnc#1012628).
- net: ena: add missing ethtool TX timestamping indication
  (bnc#1012628).
- net: ena: fix uses of round_jiffies() (bnc#1012628).
- net: ena: fix potential crash when rxfh key is NULL
  (bnc#1012628).
- i40e: Fix the conditional for i40e_vc_validate_vqs_bitmaps
  (bnc#1012628).
- soc/tegra: fuse: Fix build with Tegra194 configuration
  (bnc#1012628).
- amdgpu: Prevent build errors regarding soft/hard-float FP ABI
  tags (bnc#1012628).
- drm/amd/display: Add initialitions for PLL2 clock source
  (bnc#1012628).
- drm/amd/display: Limit minimum DPPCLK to 100MHz (bnc#1012628).
- drm/amd/display: Check engine is not NULL before acquiring
  (bnc#1012628).
- RDMA/siw: Remove unwanted WARN_ON in siw_cm_llp_data_ready()
  (bnc#1012628).
- drm/amd/display: Do not set optimized_require to false after
  plane disable (bnc#1012628).
- ARM: dts: sti: fixup sound frame-inversion for
  stihxxx-b2120.dtsi (bnc#1012628).
- ceph: do not execute direct write in parallel if O_APPEND is
  specified (bnc#1012628).
- perf/x86/msr: Add Tremont support (bnc#1012628).
- perf/x86/cstate: Add Tremont support (bnc#1012628).
- perf/x86/intel: Add Elkhart Lake support (bnc#1012628).
- perf/smmuv3: Use platform_get_irq_optional() for wired interrupt
  (bnc#1012628).
- NFSv4: Fix races between open and dentry revalidation
  (bnc#1012628).
- qmi_wwan: unconditionally reject 2 ep interfaces (bnc#1012628).
- qmi_wwan: re-add DW5821e pre-production variant (bnc#1012628).
- s390/zcrypt: fix card and queue total counter wrap
  (bnc#1012628).
- io_uring: flush overflowed CQ events in the io_uring_poll()
  (bnc#1012628).
- cfg80211: check wiphy driver existence for drvinfo report
  (bnc#1012628).
- mac80211: consider more elements in parsing CRC (bnc#1012628).
- dax: pass NOWAIT flag to iomap_apply (bnc#1012628).
- sched/fair: Prevent unlimited runtime on throttled group
  (bnc#1012628).
- timers/nohz: Update NOHZ load in remote tick (bnc#1012628).
- sched/core: Don't skip remote tick for idle CPUs (bnc#1012628).
- drm/msm: Set dma maximum segment size for mdss (bnc#1012628).
- ipmi:ssif: Handle a possible NULL pointer reference
  (bnc#1012628).
- net: rtnetlink: fix bugs in rtnl_alt_ifname() (bnc#1012628).
- net: macb: Properly handle phylink on at91rm9200 (bnc#1012628).
- net: add strict checks in netdev_name_node_alt_destroy()
  (bnc#1012628).
- ionic: fix fw_status read (bnc#1012628).
- ipv6: Fix nlmsg_flags when splitting a multipath route
  (bnc#1012628).
- ipv6: Fix route replacement with dev-only route (bnc#1012628).
- bonding: fix lockdep warning in bond_get_stats() (bnc#1012628).
- net: export netdev_next_lower_dev_rcu() (bnc#1012628).
- bonding: add missing netdev_update_lockdep_key() (bnc#1012628).
- bnxt_en: Issue PCIe FLR in kdump kernel to cleanup pending DMAs
  (bnc#1012628).
- bnxt_en: Improve device shutdown method (bnc#1012628).
- sctp: move the format error check out of __sctp_sf_do_9_1_abort
  (bnc#1012628).
- udp: rehash on disconnect (bnc#1012628).
- Revert "net: dev: introduce support for sch BYPASS for lockless
  qdisc" (bnc#1012628).
- qede: Fix race between rdma destroy workqueue and link change
  event (bnc#1012628).
- nfc: pn544: Fix occasional HW initialization failure
  (bnc#1012628).
- net/tls: Fix to avoid gettig invalid tls record (bnc#1012628).
- net: sched: correct flower port blocking (bnc#1012628).
- net: phy: restore mdio regs in the iproc mdio driver
  (bnc#1012628).
- net: mscc: fix in frame extraction (bnc#1012628).
- net: macb: ensure interface is not suspended on at91rm9200
  (bnc#1012628).
- net: fib_rules: Correctly set table field when table number
  exceeds 8 bits (bnc#1012628).
- net: dsa: b53: Ensure the default VID is untagged (bnc#1012628).
- EDAC: skx_common: downgrade message importance on missing PCI
  device (bnc#1012628).
- commit 3727848
* Wed Mar  4 2020 jeffm@suse.com
- config: re-enable NLS_ISO8859_1 for kvmsmall
  The EFI partition wants NLS_ISO8859_1 and will fail to mount without it.
- commit 666974e
* Mon Mar  2 2020 mkubecek@suse.cz
- Update to 5.6-rc4
- eliminated 3 patches
- new config options:
  - KVM_WERROR=n (x86)
- commit 8a04afc
* Sun Mar  1 2020 jslaby@suse.cz
- Linux 5.5.7 (bnc#1012628).
- iommu/qcom: Fix bogus detach logic (bnc#1012628).
- iommu/vt-d: Add attach_deferred() helper (bnc#1012628).
- iommu/vt-d: Move deferred device attachment into helper function
  (bnc#1012628).
- iommu/vt-d: Do deferred attachment in iommu_need_mapping()
  (bnc#1012628).
- iommu/vt-d: Remove deferred_attach_domain() (bnc#1012628).
- iommu/vt-d: Simplify check in identity_mapping() (bnc#1012628).
- ALSA: hda: Use scnprintf() for printing texts for sysfs/procfs
  (bnc#1012628).
- ALSA: hda/realtek - Apply quirk for MSI GP63, too (bnc#1012628).
- ALSA: hda/realtek - Apply quirk for yet another MSI laptop
  (bnc#1012628).
- ASoC: codec2codec: avoid invalid/double-free of pcm runtime
  (bnc#1012628).
- ASoC: sun8i-codec: Fix setting DAI data format (bnc#1012628).
- tpm: Revert tpm_tis_spi_mod.ko to tpm_tis_spi.ko (bnc#1012628).
- tpm: Initialize crypto_id of allocated_banks to HASH_ALGO__LAST
  (bnc#1012628).
- ecryptfs: fix a memory leak bug in parse_tag_1_packet()
  (bnc#1012628).
- ecryptfs: fix a memory leak bug in ecryptfs_init_messaging()
  (bnc#1012628).
- Btrfs: fix race between shrinking truncate and fiemap
  (bnc#1012628).
- btrfs: don't set path->leave_spinning for truncate
  (bnc#1012628).
- btrfs: handle logged extent failure properly (bnc#1012628).
- thunderbolt: Prevent crash if non-active NVMem file is read
  (bnc#1012628).
- USB: misc: iowarrior: add support for 2 OEMed devices
  (bnc#1012628).
- USB: misc: iowarrior: add support for the 28 and 28L devices
  (bnc#1012628).
- USB: misc: iowarrior: add support for the 100 device
  (bnc#1012628).
- floppy: check FDC index for errors before assigning it
  (bnc#1012628).
- USB: serial: ch341: fix receiver regression (bnc#1012628).
- vt: fix scrollback flushing on background consoles
  (bnc#1012628).
- vt: vt_ioctl: fix race in VT_RESIZEX (bnc#1012628).
- staging: android: ashmem: Disallow ashmem memory from being
  remapped (bnc#1012628).
- staging: vt6656: fix sign of rx_dbm to bb_pre_ed_rssi
  (bnc#1012628).
- xhci: Force Maximum Packet size for Full-speed bulk devices
  to valid range (bnc#1012628).
- xhci: fix runtime pm enabling for quirky Intel hosts
  (bnc#1012628).
- xhci: apply XHCI_PME_STUCK_QUIRK to Intel Comet Lake platforms
  (bnc#1012628).
- xhci: Fix memory leak when caching protocol extended capability
  PSI tables - take 2 (bnc#1012628).
- USB: core: add endpoint-blacklist quirk (bnc#1012628).
- USB: quirks: blacklist duplicate ep on Sound Devices USBPre2
  (bnc#1012628).
- usb: uas: fix a plug & unplug racing (bnc#1012628).
- USB: Fix novation SourceControl XL after suspend (bnc#1012628).
- USB: hub: Don't record a connect-change event during
  reset-resume (bnc#1012628).
- USB: hub: Fix the broken detection of USB3 device in SMSC hub
  (bnc#1012628).
- usb: dwc2: Fix SET/CLEAR_FEATURE and GET_STATUS flows
  (bnc#1012628).
- usb: dwc3: gadget: Check for IOC/LST bit in TRB->ctrl fields
  (bnc#1012628).
- usb: dwc3: debug: fix string position formatting mixup with
  ret and len (bnc#1012628).
- scsi: Revert "target/core: Inline transport_lun_remove_cmd()"
  (bnc#1012628).
- staging: rtl8188eu: Fix potential security hole (bnc#1012628).
- staging: rtl8188eu: Fix potential overuse of kernel memory
  (bnc#1012628).
- staging: rtl8723bs: Fix potential security hole (bnc#1012628).
- staging: rtl8723bs: Fix potential overuse of kernel memory
  (bnc#1012628).
- hwmon: (acpi_power_meter) Fix lockdep splat (bnc#1012628).
- drm/panfrost: perfcnt: Reserve/use the AS attached to the
  perfcnt MMU context (bnc#1012628).
- powerpc/8xx: Fix clearing of bits 20-23 in ITLB miss
  (bnc#1012628).
- powerpc/eeh: Fix deadlock handling dead PHB (bnc#1012628).
- powerpc/tm: Fix clearing MSR[TS] in current when reclaiming
  on signal delivery (bnc#1012628).
- powerpc/entry: Fix an #if which should be an #ifdef in
  entry_32.S (bnc#1012628).
- powerpc/hugetlb: Fix 512k hugepages on 8xx with 16k page size
  (bnc#1012628).
- powerpc/hugetlb: Fix 8M hugepages on 8xx (bnc#1012628).
- arm64: memory: Add missing brackets to untagged_addr() macro
  (bnc#1012628).
- jbd2: fix ocfs2 corrupt when clearing block group bits
  (bnc#1012628).
- x86/ima: use correct identifier for SetupMode variable
  (bnc#1012628).
- x86/mce/amd: Publish the bank pointer only after setup has
  succeeded (bnc#1012628).
- x86/mce/amd: Fix kobject lifetime (bnc#1012628).
- x86/cpu/amd: Enable the fixed Instructions Retired counter
  IRPERF (bnc#1012628).
- MIPS: ingenic: DTS: Fix watchdog nodes (bnc#1012628).
- serial: 8250: Check UPF_IRQ_SHARED in advance (bnc#1012628).
- tty/serial: atmel: manage shutdown in case of RS485 or ISO7816
  mode (bnc#1012628).
- tty: serial: imx: setup the correct sg entry for tx dma
  (bnc#1012628).
- tty: serial: qcom_geni_serial: Fix RX cancel command failure
  (bnc#1012628).
- serdev: ttyport: restore client ops on deregistration
  (bnc#1012628).
- MAINTAINERS: Update drm/i915 bug filing URL (bnc#1012628).
- fsi: aspeed: add unspecified HAS_IOMEM dependency (bnc#1012628).
- ACPI: PM: s2idle: Check fixed wakeup events in
  acpi_s2idle_wake() (bnc#1012628).
- Revert "ipc,sem: remove uneeded sem_undo_list lock usage in
  exit_sem()" (bnc#1012628).
- mm/memcontrol.c: lost css_put in memcg_expand_shrinker_maps()
  (bnc#1012628).
- nvme-multipath: Fix memory leak with ana_log_buf (bnc#1012628).
- genirq/irqdomain: Make sure all irq domain flags are distinct
  (bnc#1012628).
- mm/vmscan.c: don't round up scan size for online memory cgroup
  (bnc#1012628).
- mm/sparsemem: pfn_to_page is not valid yet on SPARSEMEM
  (bnc#1012628).
- lib/stackdepot.c: fix global out-of-bounds in stack_slabs
  (bnc#1012628).
- mm: Avoid creating virtual address aliases in
  brk()/mmap()/mremap() (bnc#1012628).
- drm/amdgpu/soc15: fix xclk for raven (bnc#1012628).
- drm/amdgpu/gfx9: disable gfxoff when reading rlc clock
  (bnc#1012628).
- drm/amdgpu/gfx10: disable gfxoff when reading rlc clock
  (bnc#1012628).
- drm/nouveau/kms/gv100-: Re-set LUT after clearing for modesets
  (bnc#1012628).
- drm/i915: Wean off drm_pci_alloc/drm_pci_free (bnc#1012628).
- drm/i915: Update drm/i915 bug filing URL (bnc#1012628).
- sched/psi: Fix OOB write when writing 0 bytes to PSI files
  (bnc#1012628).
- KVM: x86: don't notify userspace IOAPIC on edge-triggered
  interrupt EOI (bnc#1012628).
- ext4: fix a data race in EXT4_I(inode)->i_disksize
  (bnc#1012628).
- ext4: add cond_resched() to __ext4_find_entry() (bnc#1012628).
- ext4: fix potential race between online resizing and write
  operations (bnc#1012628).
- ext4: fix potential race between s_group_info online resizing
  and access (bnc#1012628).
- ext4: fix potential race between s_flex_groups online resizing
  and access (bnc#1012628).
- ext4: fix mount failure with quota configured as module
  (bnc#1012628).
- ext4: rename s_journal_flag_rwsem to s_writepages_rwsem
  (bnc#1012628).
- ext4: fix race between writepages and enabling EXT4_EXTENTS_FL
  (bnc#1012628).
- drm/i915/execlists: Always force a context reload when rewinding
  RING_TAIL (bnc#1012628).
- KVM: nVMX: clear PIN_BASED_POSTED_INTR from nested pinbased_ctls
  only when apicv is globally disabled (bnc#1012628).
- KVM: nVMX: handle nested posted interrupts when apicv is
  disabled for L1 (bnc#1012628).
- KVM: apic: avoid calculating pending eoi from an uninitialized
  val (bnc#1012628).
- crypto: chacha20poly1305 - prevent integer overflow on large
  input (bnc#1012628).
- btrfs: destroy qgroup extent records on transaction abort
  (bnc#1012628).
- btrfs: fix bytes_may_use underflow in prealloc error condtition
  (bnc#1012628).
- btrfs: reset fs_root to NULL on error in open_ctree
  (bnc#1012628).
- btrfs: do not check delayed items are empty for single
  transaction cleanup (bnc#1012628).
- Btrfs: fix btrfs_wait_ordered_range() so that it waits for
  all ordered extents (bnc#1012628).
- Btrfs: fix deadlock during fast fsync when logging prealloc
  extents beyond eof (bnc#1012628).
- Revert "dmaengine: imx-sdma: Fix memory leak" (bnc#1012628).
- drm/i915/selftests: Add a mock i915_vma to the mock_ring
  (bnc#1012628).
- drm/i915/gvt: more locking for ppgtt mm LRU list (bnc#1012628).
- drm/bridge: tc358767: fix poll timeouts (bnc#1012628).
- drm/i915/gem: Require per-engine reset support for
  non-persistent contexts (bnc#1012628).
- drm/i915/gt: Protect defer_request() from new waiters
  (bnc#1012628).
- drm/i915/ehl: Update port clock voltage level requirements
  (bnc#1012628).
- drm/msm/dpu: fix BGR565 vs RGB565 confusion (bnc#1012628).
- scsi: Revert "RDMA/isert: Fix a recently introduced regression
  related to logout" (bnc#1012628).
- scsi: Revert "target: iscsi: Wait for all commands to finish
  before freeing a session" (bnc#1012628).
- usb: gadget: composite: Fix bMaxPower for SuperSpeedPlus
  (bnc#1012628).
- usb: dwc2: Fix in ISOC request length checking (bnc#1012628).
- staging: rtl8723bs: fix copy of overlapping memory
  (bnc#1012628).
- staging: greybus: use after free in
  gb_audio_manager_remove_all() (bnc#1012628).
- ASoC: atmel: fix atmel_ssc_set_audio link failure (bnc#1012628).
- ASoC: fsl_sai: Fix exiting path on probing failure
  (bnc#1012628).
- ecryptfs: replace BUG_ON with error handling code (bnc#1012628).
- iommu/vt-d: Fix compile warning from intel-svm.h (bnc#1012628).
- crypto: rename sm3-256 to sm3 in hash_algo_name (bnc#1012628).
- genirq/proc: Reject invalid affinity masks (again)
  (bnc#1012628).
- bpf, offload: Replace bitwise AND by logical AND in
  bpf_prog_offload_info_fill (bnc#1012628).
- scripts/get_maintainer.pl: deprioritize old Fixes: addresses
  (bnc#1012628).
- io_uring: prevent sq_thread from spinning when it should stop
  (bnc#1012628).
- io_uring: fix __io_iopoll_check deadlock in io_sq_thread
  (bnc#1012628).
- dma-direct: relax addressability checks in dma_direct_supported
  (bnc#1012628).
- ALSA: rawmidi: Avoid bit fields for state flags (bnc#1012628).
- ALSA: seq: Avoid concurrent access to queue flags (bnc#1012628).
- ALSA: seq: Fix concurrent access to queue current tick/time
  (bnc#1012628).
- netfilter: xt_hashlimit: limit the max size of hashtable
  (bnc#1012628).
- rxrpc: Fix call RCU cleanup using non-bh-safe locks
  (bnc#1012628).
- ata: ahci: Add shutdown to freeze hardware resources of ahci
  (bnc#1012628).
- xen: Enable interrupts when calling _cond_resched()
  (bnc#1012628).
- net/mlx5e: Reset RQ doorbell counter before moving RQ state
  from RST to RDY (bnc#1012628).
- net/mlx5: Fix sleep while atomic in mlx5_eswitch_get_vepa
  (bnc#1012628).
- net/mlx5e: Don't clear the whole vf config when switching modes
  (bnc#1012628).
- net/mlx5e: Fix crash in recovery flow without devlink reporter
  (bnc#1012628).
- s390/kaslr: Fix casts in get_random (bnc#1012628).
- s390/mm: Explicitly compare PAGE_DEFAULT_KEY against zero in
  storage_key_init_range (bnc#1012628).
- bpf: Selftests build error in sockmap_basic.c (bnc#1012628).
- ASoC: SOF: Intel: hda: Add iDisp4 DAI (bnc#1012628).
- commit 1004bce
* Thu Feb 27 2020 jslaby@suse.cz
- Revert "sign also s390x kernel images (bsc#1163524)"
  This reverts commit b38b61155f0a2c3ebca06d4bb0c2e11a19a87f1f.
  It breaks s390x build as we need pesign-obs-integration package updated
  first.
  Let's enable this later when everything is ready.
- commit eca1eba
* Wed Feb 26 2020 msuchanek@suse.de
- rpm/package-descriptions: garbege collection
  remove old ARM and Xen flavors.
- commit bda0360
* Wed Feb 26 2020 mhocko@suse.com
- Created new preempt kernel flavor (jsc#SLE-11309)
  Configs are cloned from the respective $arch/default configs. All
  changed configs appart from CONFIG_PREEMPT->y are a result of
  dependencies, namely many lock/unlock primitives are no longer
  inlined in the preempt kernel. TREE_RCU has been also changed to
  PREEMPT_RCU which is the default implementation for PREEMPT kernel.
- commit f994874
* Tue Feb 25 2020 meissner@suse.de
- sign also s390x kernel images (bsc#1163524)
- commit fd52e6c
* Tue Feb 25 2020 jroedel@suse.de
- KVM: nVMX: Check IO instruction VM-exit conditions
  (CVE-2020-2732 bsc#1163971).
- KVM: nVMX: Refactor IO bitmap checks into helper function
  (CVE-2020-2732 bsc#1163971).
- KVM: nVMX: Don't emulate instructions in guest mode
  (CVE-2020-2732 bsc#1163971).
- commit 9a155f2
* Tue Feb 25 2020 jroedel@suse.de
- KVM: nVMX: Check IO instruction VM-exit conditions
  (CVE-2020-2732 bsc#1163971).
- KVM: nVMX: Refactor IO bitmap checks into helper function
  (CVE-2020-2732 bsc#1163971).
- KVM: nVMX: Don't emulate instructions in guest mode
  (CVE-2020-2732 bsc#1163971).
- commit c225901
* Mon Feb 24 2020 msuchanek@suse.de
- Enable CONFIG_BLK_DEV_SR_VENDOR (boo#1164632).
- commit 517bced
* Mon Feb 24 2020 jslaby@suse.cz
- arm64: lse: Fix LSE atomics with LLVM (git-fixes).
- Revert "drm/fbdev: Fallback to non tiled mode if all tiles
  not present" (git-fixes).
- ice: Remove possible null dereference (git-fixes).
- commit 4a830b1
* Mon Feb 24 2020 jslaby@suse.cz
- Linux 5.5.6 (bnc#1012628).
- core: Don't skip generic XDP program execution for cloned SKBs
  (bnc#1012628).
- enic: prevent waking up stopped tx queues over watchdog reset
  (bnc#1012628).
- net/smc: fix leak of kernel memory to user space (bnc#1012628).
- net: dsa: tag_qca: Make sure there is headroom for tag
  (bnc#1012628).
- net/sched: matchall: add missing validation of
  TCA_MATCHALL_FLAGS (bnc#1012628).
- net/sched: flower: add missing validation of TCA_FLOWER_FLAGS
  (bnc#1012628).
- drm/gma500: Fixup fbdev stolen size usage evaluation
  (bnc#1012628).
- drm/dp_mst: fix multiple frees of tx->bytes (bnc#1012628).
- ath10k: Fix qmi init error handling (bnc#1012628).
- wil6210: fix break that is never reached because of zero'ing
  of a retry counter (bnc#1012628).
- drm/virtio: fix byteorder handling in
  virtio_gpu_cmd_transfer_{from, to}_host_3d functions
  (bnc#1012628).
- drm/qxl: Complete exception handling in qxl_device_init()
  (bnc#1012628).
- rcu/nocb: Fix dump_tree hierarchy print always active
  (bnc#1012628).
- rcu: Fix missed wakeup of exp_wq waiters (bnc#1012628).
- rcu: Fix data-race due to atomic_t copy-by-value (bnc#1012628).
- dmaengine: ti: edma: add missed operations (bnc#1012628).
- f2fs: preallocate DIO blocks when forcing buffered_io
  (bnc#1012628).
- f2fs: call f2fs_balance_fs outside of locked page (bnc#1012628).
- media: meson: add missing allocation failure check on new_buf
  (bnc#1012628).
- clk: meson: pll: Fix by 0 division in __pll_params_to_rate()
  (bnc#1012628).
- cpu/hotplug, stop_machine: Fix stop_machine vs hotplug order
  (bnc#1012628).
- drm: rcar-du: Recognize "renesas,vsps" in addition to "vsps"
  (bnc#1012628).
- dmaengine: ti: edma: Fix error return code in edma_probe()
  (bnc#1012628).
- brcmfmac: Fix memory leak in brcmf_p2p_create_p2pdev()
  (bnc#1012628).
- brcmfmac: Fix use after free in brcmf_sdio_readframes()
  (bnc#1012628).
- PCI: Fix pci_add_dma_alias() bitmask size (bnc#1012628).
- drm/amd/display: Map ODM memory correctly when doing ODM combine
  (bnc#1012628).
- leds: pca963x: Fix open-drain initialization (bnc#1012628).
- ext4: fix ext4_dax_read/write inode locking sequence for
  IOCB_NOWAIT (bnc#1012628).
- ALSA: ctl: allow TLV read operation for callback type of
  element in locked case (bnc#1012628).
- gianfar: Fix TX timestamping with a stacked DSA driver
  (bnc#1012628).
- pinctrl: sh-pfc: sh7264: Fix CAN function GPIOs (bnc#1012628).
- printk: fix exclusive_console replaying (bnc#1012628).
- drm/mipi_dbi: Fix off-by-one bugs in mipi_dbi_blank()
  (bnc#1012628).
- drm/msm/adreno: fix zap vs no-zap handling (bnc#1012628).
- pxa168fb: Fix the function used to release some memory in an
  error handling path (bnc#1012628).
- media: ov5640: Fix check for PLL1 exceeding max allowed rate
  (bnc#1012628).
- media: i2c: mt9v032: fix enum mbus codes and frame sizes
  (bnc#1012628).
- media: sun4i-csi: Deal with DRAM offset (bnc#1012628).
- media: sun4i-csi: Fix data sampling polarity handling
  (bnc#1012628).
- media: sun4i-csi: Fix [HV]sync polarity handling (bnc#1012628).
- clk: at91: sam9x60: fix programmable clock prescaler
  (bnc#1012628).
- powerpc/powernv/iov: Ensure the pdn for VFs always contains
  a valid PE number (bnc#1012628).
- clk: meson: meson8b: make the CCF use the glitch-free mali mux
  (bnc#1012628).
- gpio: gpio-grgpio: fix possible sleep-in-atomic-context bugs
  in grgpio_irq_map/unmap() (bnc#1012628).
- iommu/vt-d: Fix off-by-one in PASID allocation (bnc#1012628).
- x86/fpu: Deactivate FPU state after failure during state load
  (bnc#1012628).
- dm raid: table line rebuild status fixes (bnc#1012628).
- char/random: silence a lockdep splat with printk()
  (bnc#1012628).
- media: sti: bdisp: fix a possible sleep-in-atomic-context bug
  in bdisp_device_run() (bnc#1012628).
- kernel/module: Fix memleak in module_add_modinfo_attrs()
  (bnc#1012628).
- IB/core: Let IB core distribute cache update events
  (bnc#1012628).
- pinctrl: baytrail: Do not clear IRQ flags on direct-irq enabled
  pins (bnc#1012628).
- kprobes: Fix optimize_kprobe()/unoptimize_kprobe() cancellation
  logic (bnc#1012628).
- efi/x86: Map the entire EFI vendor string before copying it
  (bnc#1012628).
- sparc: Add .exit.data section (bnc#1012628).
- net: ethernet: ixp4xx: Standard module init (bnc#1012628).
- raid6/test: fix a compilation error (bnc#1012628).
- iio: imu: st_lsm6dsx: check return value from
  st_lsm6dsx_sensor_set_enable (bnc#1012628).
- uio: fix a sleep-in-atomic-context bug in
  uio_dmem_genirq_irqcontrol() (bnc#1012628).
- drm/amdgpu/sriov: workaround on rev_id for Navi12 under sriov
  (bnc#1012628).
- spi: fsl-lpspi: fix only one cs-gpio working (bnc#1012628).
- drm/nouveau/nouveau: fix incorrect sizeof on args.src an
  args.dst (bnc#1012628).
- usb: gadget: udc: fix possible sleep-in-atomic-context bugs
  in gr_probe() (bnc#1012628).
- usb: dwc2: Fix IN FIFO allocation (bnc#1012628).
- clocksource/drivers/bcm2835_timer: Fix memory leak of timer
  (bnc#1012628).
- drm/amd/display: Clear state after exiting fixed active VRR
  state (bnc#1012628).
- kselftest: Minimise dependency of get_size on C library
  interfaces (bnc#1012628).
- jbd2: clear JBD2_ABORT flag before journal_reset to update
  log tail info when load journal (bnc#1012628).
- ext4: fix deadlock allocating bio_post_read_ctx from mempool
  (bnc#1012628).
- clk: ti: dra7: fix parent for gmac_clkctrl (bnc#1012628).
- x86/sysfb: Fix check for bad VRAM size (bnc#1012628).
- pwm: omap-dmtimer: Simplify error handling (bnc#1012628).
- udf: Allow writing to 'Rewritable' partitions (bnc#1012628).
- dmaengine: fsl-qdma: fix duplicated argument to &&
  (bnc#1012628).
- wan/hdlc_x25: fix skb handling (bnc#1012628).
- irqchip/gic-v3-its: Fix get_vlpi_map() breakage with doorbells
  (bnc#1012628).
- s390/pci: Fix possible deadlock in recover_store()
  (bnc#1012628).
- backlight: qcom-wled: Fix unsigned comparison to zero
  (bnc#1012628).
- powerpc/iov: Move VF pdev fixup into pcibios_fixup_iov()
  (bnc#1012628).
- tracing: Fix tracing_stat return values in error handling paths
  (bnc#1012628).
- tracing: Fix very unlikely race of registering two stat tracers
  (bnc#1012628).
- ARM: 8952/1: Disable kmemleak on XIP kernels (bnc#1012628).
- ext4, jbd2: ensure panic when aborting with zero errno
  (bnc#1012628).
- ath10k: Correct the DMA direction for management tx buffers
  (bnc#1012628).
- rtw88: fix rate mask for 1SS chip (bnc#1012628).
- brcmfmac: sdio: Fix OOB interrupt initialization on brcm43362
  (bnc#1012628).
- selftests: settings: tests can be in subsubdirs (bnc#1012628).
- rtc: i2c/spi: Avoid inclusion of REGMAP support when not needed
  (bnc#1012628).
- drm/amd/display: Retrain dongles when SINK_COUNT becomes
  non-zero (bnc#1012628).
- tracing: Simplify assignment parsing for hist triggers
  (bnc#1012628).
- nbd: add a flush_workqueue in nbd_start_device (bnc#1012628).
- KVM: s390: ENOTSUPP -> EOPNOTSUPP fixups (bnc#1012628).
- Btrfs: keep pages dirty when using btrfs_writepage_fixup_worker
  (bnc#1012628).
- drivers/block/zram/zram_drv.c: fix error return codes not
  being returned in writeback_store (bnc#1012628).
- block, bfq: do not plug I/O for bfq_queues with no proc refs
  (bnc#1012628).
- kconfig: fix broken dependency in randconfig-generated .config
  (bnc#1012628).
- clk: qcom: Don't overwrite 'cfg' in clk_rcg2_dfs_populate_freq()
  (bnc#1012628).
- clk: qcom: rcg2: Don't crash if our parent can't be found;
  return an error (bnc#1012628).
- drm/amdkfd: Fix a bug in SDMA RLC queue counting under HWS mode
  (bnc#1012628).
- bpf, sockhash: Synchronize_rcu before free'ing map
  (bnc#1012628).
- drm/amd/display: Renoir chroma viewport WA (bnc#1012628).
- drm/amdgpu: remove 4 set but not used variable in
  amdgpu_atombios_get_connector_info_from_object_table
  (bnc#1012628).
- drm/amdgpu/dm: Do not throw an error for a display with no audio
  (bnc#1012628).
- ath10k: correct the tlv len of
  ath10k_wmi_tlv_op_gen_config_pno_start (bnc#1012628).
- drm/amdgpu: Ensure ret is always initialized when using
  SOC15_WAIT_ON_RREG (bnc#1012628).
- drm/panel: simple: Add Logic PD Type 28 display support
  (bnc#1012628).
- arm64: dts: rockchip: Fix NanoPC-T4 cooling maps (bnc#1012628).
- modules: lockdep: Suppress suspicious RCU usage warning
  (bnc#1012628).
- ASoC: intel: sof_rt5682: Add quirk for number of HDMI DAI's
  (bnc#1012628).
- ASoC: intel: sof_rt5682: Add support for tgl-max98357a-rt5682
  (bnc#1012628).
- ASoC: SOF: Intel: hda: solve MSI issues by merging ipc and
  stream irq handlers (bnc#1012628).
- regulator: rk808: Lower log level on optional GPIOs being not
  available (bnc#1012628).
- net/wan/fsl_ucc_hdlc: reject muram offsets above 64K
  (bnc#1012628).
- Revert "drm/amdgpu: enable VCN DPG on Raven and Raven2"
  (bnc#1012628).
- NFC: port100: Convert cpu_to_le16(le16_to_cpu(E1) + E2) to
  use le16_add_cpu() (bnc#1012628).
- arm64: dts: allwinner: H6: Add PMU mode (bnc#1012628).
- arm64: dts: allwinner: H5: Add PMU node (bnc#1012628).
- arm: dts: allwinner: H3: Add PMU node (bnc#1012628).
- opp: Free static OPPs on errors while adding them (bnc#1012628).
- selinux: ensure we cleanup the internal AVC counters on error
  in avc_insert() (bnc#1012628).
- enetc: remove variable 'tc_max_sized_frame' set but not used
  (bnc#1012628).
- arm64: dts: qcom: msm8996: Disable USB2 PHY suspend by core
  (bnc#1012628).
- padata: validate cpumask without removed CPU during offline
  (bnc#1012628).
- clk: imx: Add correct failure handling for clk based helpers
  (bnc#1012628).
- ARM: exynos_defconfig: Bring back explicitly wanted options
  (bnc#1012628).
- ARM: dts: imx6: rdu2: Disable WP for USDHC2 and USDHC3
  (bnc#1012628).
- ARM: dts: imx6: rdu2: Limit USBH1 to Full Speed (bnc#1012628).
- IMA: Check IMA policy flag (bnc#1012628).
- bus: ti-sysc: Implement quirk handling for CLKDM_NOAUTO
  (bnc#1012628).
- PCI: iproc: Apply quirk_paxc_bridge() for module as well as
  built-in (bnc#1012628).
- media: cx23885: Add support for AVerMedia CE310B (bnc#1012628).
- PCI: Add generic quirk for increasing D3hot delay (bnc#1012628).
- PCI: Increase D3 delay for AMD Ryzen5/7 XHCI controllers
  (bnc#1012628).
- Revert "nfp: abm: fix memory leak in nfp_abm_u32_knode_replace"
  (bnc#1012628).
- gpu/drm: ingenic: Avoid null pointer deference in plane atomic
  update (bnc#1012628).
- selftests/net: make so_txtime more robust to timer variance
  (bnc#1012628).
- media: v4l2-device.h: Explicitly compare grp{id,mask} to zero
  in v4l2_device macros (bnc#1012628).
- reiserfs: Fix spurious unlock in reiserfs_fill_super() error
  handling (bnc#1012628).
- samples/bpf: Set -fno-stack-protector when building BPF programs
  (bnc#1012628).
- r8169: check that Realtek PHY driver module is loaded
  (bnc#1012628).
- fore200e: Fix incorrect checks of NULL pointer dereference
  (bnc#1012628).
- x86/mce/therm_throt: Mark throttle_active_work() as
  __maybe_unused (bnc#1012628).
- netfilter: nft_tunnel: add the missing ERSPAN_VERSION nla_policy
  (bnc#1012628).
- ALSA: usx2y: Adjust indentation in snd_usX2Y_hwdep_dsp_status
  (bnc#1012628).
- nfs: fix timstamp debug prints (bnc#1012628).
- PCI: Add nr_devfns parameter to pci_add_dma_alias()
  (bnc#1012628).
- PCI: Add DMA alias quirk for PLX PEX NTB (bnc#1012628).
- b43legacy: Fix -Wcast-function-type (bnc#1012628).
- ipw2x00: Fix -Wcast-function-type (bnc#1012628).
- iwlegacy: Fix -Wcast-function-type (bnc#1012628).
- rtlwifi: rtl_pci: Fix -Wcast-function-type (bnc#1012628).
- orinoco: avoid assertion in case of NULL pointer (bnc#1012628).
- drm/amd/display: Fix update_bw_bounding_box Calcs (bnc#1012628).
- drm/amd/display: Lower DPP DTO only when safe (bnc#1012628).
- drm/amdgpu: fix double gpu_recovery for NV of SRIOV
  (bnc#1012628).
- drm/amdgpu: fix KIQ ring test fail in TDR of SRIOV
  (bnc#1012628).
- clk: qcom: smd: Add missing bimc clock (bnc#1012628).
- ACPICA: Disassembler: create buffer fields in
  ACPI_PARSE_LOAD_PASS1 (bnc#1012628).
- nfsd: Clone should commit src file metadata too (bnc#1012628).
- scsi: ufs: Complete pending requests in host reset and restore
  path (bnc#1012628).
- scsi: aic7xxx: Adjust indentation in ahc_find_syncrate
  (bnc#1012628).
- crypto: inside-secure - add unspecified HAS_IOMEM dependency
  (bnc#1012628).
- crypto: amlogic - add unspecified HAS_IOMEM dependency
  (bnc#1012628).
- drm/mediatek: handle events when enabling/disabling crtc
  (bnc#1012628).
- clk: renesas: rcar-gen3: Allow changing the RPC[D2] clocks
  (bnc#1012628).
- ARM: dts: r8a7779: Add device node for ARM global timer
  (bnc#1012628).
- remoteproc: q6v5-mss: Remove mem clk from the active pool
  (bnc#1012628).
- selinux: ensure we cleanup the internal AVC counters on error
  in avc_update() (bnc#1012628).
- scsi: lpfc: Fix: Rework setting of fdmi symbolic node name
  registration (bnc#1012628).
- arm64: dts: qcom: db845c: Enable ath10k 8bit host-cap quirk
  (bnc#1012628).
- PCI/ATS: Restore EXPORT_SYMBOL_GPL() for
  pci_{enable,disable}_ats() (bnc#1012628).
- iommu/amd: Check feature support bit before accessing MSI
  capability registers (bnc#1012628).
- iommu/amd: Only support x2APIC with IVHD type 11h/40h
  (bnc#1012628).
- iommu/iova: Silence warnings under memory pressure
  (bnc#1012628).
- clk: qcom: Add missing msm8998 gcc_bimc_gfx_clk (bnc#1012628).
- clk: actually call the clock init before any other callback
  of the clock (bnc#1012628).
- dmaengine: Store module owner in dma_device struct
  (bnc#1012628).
- clk: bm1800: Remove set but not used variable 'fref'
  (bnc#1012628).
- dmaengine: imx-sdma: Fix memory leak (bnc#1012628).
- bpf: Print error message for bpftool cgroup show (bnc#1012628).
- net: phy: realtek: add logging for the RGMII TX delay
  configuration (bnc#1012628).
- crypto: chtls - Fixed memory leak (bnc#1012628).
- x86/vdso: Provide missing include file (bnc#1012628).
- PM / devfreq: exynos-ppmu: Fix excessive stack usage
  (bnc#1012628).
- PM / devfreq: Change time stats to 64-bit (bnc#1012628).
- PM / devfreq: rk3399_dmc: Add COMPILE_TEST and HAVE_ARM_SMCCC
  dependency (bnc#1012628).
- drm/fbdev: Fallback to non tiled mode if all tiles not present
  (bnc#1012628).
- pinctrl: sh-pfc: sh7269: Fix CAN function GPIOs (bnc#1012628).
- reset: uniphier: Add SCSSI reset control for each channel
  (bnc#1012628).
- ASoC: soc-topology: fix endianness issues (bnc#1012628).
- fbdev: fix numbering of fbcon options (bnc#1012628).
- RDMA/rxe: Fix error type of mmap_offset (bnc#1012628).
- ice: add extra check for null Rx descriptor (bnc#1012628).
- clk: sunxi-ng: add mux and pll notifiers for A64 CPU clock
  (bnc#1012628).
- ALSA: sh: Fix unused variable warnings (bnc#1012628).
- clk: Use parent node pointer during registration if necessary
  (bnc#1012628).
- clk: uniphier: Add SCSSI clock gate for each channel
  (bnc#1012628).
- ALSA: hda/realtek - Apply mic mute LED quirk for Dell E7xx
  laptops, too (bnc#1012628).
- ALSA: sh: Fix compile warning wrt const (bnc#1012628).
- net: phy: fixed_phy: fix use-after-free when checking link GPIO
  (bnc#1012628).
- tools lib api fs: Fix gcc9 stringop-truncation compilation error
  (bnc#1012628).
- vfio/spapr/nvlink2: Skip unpinning pages on error exit
  (bnc#1012628).
- ASoC: Intel: sof_rt5682: Ignore the speaker amp when there
  isn't one (bnc#1012628).
- ACPI: button: Add DMI quirk for Razer Blade Stealth 13 late
  2019 lid switch (bnc#1012628).
- iommu/vt-d: Match CPU and IOMMU paging mode (bnc#1012628).
- iommu/vt-d: Avoid sending invalid page response (bnc#1012628).
- drm/amdkfd: Fix permissions of hang_hws (bnc#1012628).
- mlx5: work around high stack usage with gcc (bnc#1012628).
- RDMA/hns: Avoid printing address of mtt page (bnc#1012628).
- drm: remove the newline for CRC source name (bnc#1012628).
- usb: dwc3: use proper initializers for property entries
  (bnc#1012628).
- ARM: dts: stm32: Add power-supply for DSI panel on
  stm32f469-disco (bnc#1012628).
- usbip: Fix unsafe unaligned pointer usage (bnc#1012628).
- udf: Fix free space reporting for metadata and virtual
  partitions (bnc#1012628).
- selftests: Uninitialized variable in
  test_cgcore_proc_migration() (bnc#1012628).
- kunit: remove timeout dependence on
  sysctl_hung_task_timeout_seconds (bnc#1012628).
- drm/mediatek: Add gamma property according to hardware
  capability (bnc#1012628).
- staging: rtl8188: avoid excessive stack usage (bnc#1012628).
- IB/hfi1: Add software counter for ctxt0 seq drop (bnc#1012628).
- IB/hfi1: Add RcvShortLengthErrCnt to hfi1stats (bnc#1012628).
- soc/tegra: fuse: Correct straps' address for older Tegra124
  device trees (bnc#1012628).
- efi/x86: Don't panic or BUG() on non-critical error conditions
  (bnc#1012628).
- rcu: Use WRITE_ONCE() for assignments to ->pprev for hlist_nulls
  (bnc#1012628).
- Input: edt-ft5x06 - work around first register access error
  (bnc#1012628).
- bnxt: Detach page from page pool before sending up the stack
  (bnc#1012628).
- x86/nmi: Remove irq_work from the long duration NMI handler
  (bnc#1012628).
- wan: ixp4xx_hss: fix compile-testing on 64-bit (bnc#1012628).
- clocksource: davinci: only enable clockevents once tim34 is
  initialized (bnc#1012628).
- arm64: dts: rockchip: fix dwmmc clock name for px30
  (bnc#1012628).
- arm64: dts: rockchip: fix dwmmc clock name for rk3308
  (bnc#1012628).
- arm64: dts: rockchip: add reg property to brcmf sub-nodes
  (bnc#1012628).
- ARM: dts: rockchip: add reg property to brcmf sub node for
  rk3188-bqedison2qc (bnc#1012628).
- ALSA: usb-audio: Add boot quirk for MOTU M Series (bnc#1012628).
- ASoC: txx9: Remove unused rtd variable (bnc#1012628).
- ASoC: atmel: fix build error with CONFIG_SND_ATMEL_SOC_DMA=m
  (bnc#1012628).
- raid6/test: fix a compilation warning (bnc#1012628).
- tty: synclinkmp: Adjust indentation in several functions
  (bnc#1012628).
- tty: synclink_gt: Adjust indentation in several functions
  (bnc#1012628).
- bus: fsl-mc: properly empty-initialize structure (bnc#1012628).
- misc: xilinx_sdfec: fix xsdfec_poll()'s return type
  (bnc#1012628).
- visorbus: fix uninitialized variable access (bnc#1012628).
- driver core: platform: Prevent resouce overflow from causing
  infinite loops (bnc#1012628).
- driver core: Print device when resources present in
  really_probe() (bnc#1012628).
- ASoC: SOF: Intel: hda-dai: fix compilation warning in
  pcm_prepare (bnc#1012628).
- bpf: Return -EBADRQC for invalid map type in __bpf_tx_xdp_map
  (bnc#1012628).
- vme: bridges: reduce stack usage (bnc#1012628).
- MIPS: ralink: dts: gardena_smart_gateway_mt7688: Limit UART1
  (bnc#1012628).
- drm/nouveau/secboot/gm20b: initialize pointer in
  gm20b_secboot_new() (bnc#1012628).
- drm/nouveau/gr/gk20a,gm200-: add terminators to method lists
  read from fw (bnc#1012628).
- drm/nouveau: Fix copy-paste error in
  nouveau_fence_wait_uevent_handler (bnc#1012628).
- drm/nouveau/drm/ttm: Remove set but not used variable 'mem'
  (bnc#1012628).
- drm/nouveau/fault/gv100-: fix memory leak on module unload
  (bnc#1012628).
- dm thin: don't allow changing data device during thin-pool
  reload (bnc#1012628).
- gpiolib: Set lockdep class for hierarchical irq domains
  (bnc#1012628).
- drm/vmwgfx: prevent memory leak in vmw_cmdbuf_res_add
  (bnc#1012628).
- perf/imx_ddr: Fix cpu hotplug state cleanup (bnc#1012628).
- usb: musb: omap2430: Get rid of musb .set_vbus for omap2430 glue
  (bnc#1012628).
- kbuild: remove *.tmp file when filechk fails (bnc#1012628).
- iommu/arm-smmu-v3: Use WRITE_ONCE() when changing validity of
  an STE (bnc#1012628).
- ALSA: usb-audio: unlock on error in probe (bnc#1012628).
- f2fs: set I_LINKABLE early to avoid wrong access by vfs
  (bnc#1012628).
- f2fs: free sysfs kobject (bnc#1012628).
- scsi: ufs: pass device information to apply_dev_quirks
  (bnc#1012628).
- scsi: ufs-mediatek: add apply_dev_quirks variant operation
  (bnc#1012628).
- scsi: iscsi: Don't destroy session if there are outstanding
  connections (bnc#1012628).
- crypto: hisilicon - Update debugfs usage of SEC V2
  (bnc#1012628).
- crypto: hisilicon - Bugfixed tfm leak (bnc#1012628).
- crypto: essiv - fix AEAD capitalization and preposition use
  in help text (bnc#1012628).
- ALSA: usb-audio: add implicit fb quirk for MOTU M Series
  (bnc#1012628).
- PM / devfreq: Add debugfs support with devfreq_summary file
  (bnc#1012628).
- pinctrl: tigerlake: Tiger Lake uses _HID enumeration
  (bnc#1012628).
- RDMA/mlx5: Don't fake udata for kernel path (bnc#1012628).
- arm64: lse: fix LSE atomics with LLVM's integrated assembler
  (bnc#1012628).
- arm64: fix alternatives with LLVM's integrated assembler
  (bnc#1012628).
- drm/amd/display: fixup DML dependencies (bnc#1012628).
- staging: wfx: fix possible overflow on jiffies comparaison
  (bnc#1012628).
- EDAC/sifive: Fix return value check in ecc_register()
  (bnc#1012628).
- KVM: PPC: Remove set but not used variable 'ra', 'rs', 'rt'
  (bnc#1012628).
- arm64: dts: ti: k3-j721e-main: Add missing power-domains for
  smmu (bnc#1012628).
- sched/core: Fix size of rq::uclamp initialization (bnc#1012628).
- sched/topology: Assert non-NUMA topology masks don't (partially)
  overlap (bnc#1012628).
- perf/x86/amd: Constrain Large Increment per Cycle events
  (bnc#1012628).
- watchdog/softlockup: Enforce that timestamp is valid on boot
  (bnc#1012628).
- enetc: Don't print from enetc_sched_speed_set when link goes
  down (bnc#1012628).
- x86/apic/uv: Avoid unused variable warning (bnc#1012628).
- debugobjects: Fix various data races (bnc#1012628).
- ASoC: wm_adsp: Correct cache handling of new kernel control API
  (bnc#1012628).
- ASoC: SOF: Intel: hda: Fix SKL dai count (bnc#1012628).
- regulator: vctrl-regulator: Avoid deadlock getting and setting
  the voltage (bnc#1012628).
- f2fs: fix memleak of kobject (bnc#1012628).
- x86/mm: Fix NX bit clearing issue in kernel_map_pages_in_pgd
  (bnc#1012628).
- efi/arm: Defer probe of PCIe backed efifb on DT systems
  (bnc#1012628).
- x86/boot/compressed: Relax sed symbol type regex for LLVM ld.lld
  (bnc#1012628).
- pwm: omap-dmtimer: Remove PWM chip in .remove before making
  it unfunctional (bnc#1012628).
- cmd64x: potential buffer overflow in cmd64x_program_timings()
  (bnc#1012628).
- ide: serverworks: potential overflow in svwks_set_pio_mode()
  (bnc#1012628).
- pwm: Remove set but not set variable 'pwm' (bnc#1012628).
- btrfs: fix possible NULL-pointer dereference in integrity checks
  (bnc#1012628).
- btrfs: safely advance counter when looking up bio csums
  (bnc#1012628).
- btrfs: device stats, log when stats are zeroed (bnc#1012628).
- module: avoid setting info->name early in case we can fall
  back to info->mod->name (bnc#1012628).
- remoteproc: Initialize rproc_class before use (bnc#1012628).
- regulator: core: Fix exported symbols to the exported GPL
  version (bnc#1012628).
- irqchip/mbigen: Set driver .suppress_bind_attrs to avoid remove
  problems (bnc#1012628).
- ALSA: hda/hdmi - add retry logic to parse_intel_hdmi()
  (bnc#1012628).
- spi: spi-fsl-qspi: Ensure width is respected in spi-mem
  operations (bnc#1012628).
- kbuild: use -S instead of -E for precise cc-option test in
  Kconfig (bnc#1012628).
- objtool: Fix ARCH=x86_64 build error (bnc#1012628).
- x86/decoder: Add TEST opcode to Group3-2 (bnc#1012628).
- s390: adjust -mpacked-stack support check for clang 10
  (bnc#1012628).
- s390/ftrace: generate traced function stack frame (bnc#1012628).
- s390: fix __EMIT_BUG() macro (bnc#1012628).
- driver core: platform: fix u32 greater or equal to zero
  comparison (bnc#1012628).
- bpf, btf: Always output invariant hit in pahole DWARF to BTF
  transform (bnc#1012628).
- ALSA: hda - Add docking station support for Lenovo Thinkpad
  T420s (bnc#1012628).
- sunrpc: Fix potential leaks in sunrpc_cache_unhash()
  (bnc#1012628).
- drm/nouveau/mmu: fix comptag memory leak (bnc#1012628).
- net/mlx5e: Fix printk format warning (bnc#1012628).
- powerpc/sriov: Remove VF eeh_dev state when disabling SR-IOV
  (bnc#1012628).
- media: uvcvideo: Add a quirk to force GEO GC6500 Camera
  bits-per-pixel value (bnc#1012628).
- btrfs: separate definition of assertion failure handlers
  (bnc#1012628).
- btrfs: Fix split-brain handling when changing FSID to metadata
  uuid (bnc#1012628).
- bcache: cached_dev_free needs to put the sb page (bnc#1012628).
- bcache: rework error unwinding in register_bcache (bnc#1012628).
- bcache: fix use-after-free in register_bcache() (bnc#1012628).
- iommu/vt-d: Mark firmware tainted if RMRR fails sanity check
  (bnc#1012628).
- iommu/vt-d: Remove unnecessary WARN_ON_ONCE() (bnc#1012628).
- alarmtimer: Make alarmtimer platform device child of RTC device
  (bnc#1012628).
- selftests: bpf: Reset global state between reuseport test runs
  (bnc#1012628).
- jbd2: switch to use jbd2_journal_abort() when failed to submit
  the commit record (bnc#1012628).
- jbd2: make sure ESHUTDOWN to be recorded in the journal
  superblock (bnc#1012628).
- powerpc/pseries/lparcfg: Fix display of Maximum Memory
  (bnc#1012628).
- selftests/eeh: Bump EEH wait time to 60s (bnc#1012628).
- ARM: 8941/1: decompressor: enable CP15 barrier instructions
  in v7 cache setup code (bnc#1012628).
- ARM: 8951/1: Fix Kexec compilation issue (bnc#1012628).
- ALSA: usb-audio: add quirks for Line6 Helix devices fw>=2.82
  (bnc#1012628).
- hostap: Adjust indentation in prism2_hostapd_add_sta
  (bnc#1012628).
- iwlegacy: ensure loop counter addr does not wrap and cause an
  infinite loop (bnc#1012628).
- cifs: fix unitialized variable poential problem with network
  I/O cache lock patch (bnc#1012628).
- cifs: Fix mount options set in automount (bnc#1012628).
- cifs: fix NULL dereference in match_prepath (bnc#1012628).
- video: hyperv: hyperv_fb: Use physical memory for fb on HyperV
  Gen 1 VMs (bnc#1012628).
- bpf: map_seq_next should always increase position index
  (bnc#1012628).
- powerpc/mm: Don't log user reads to 0xffffffff (bnc#1012628).
- ceph: check availability of mds cluster on mount after wait
  timeout (bnc#1012628).
- rbd: work around -Wuninitialized warning (bnc#1012628).
- ASoC: Intel: consistent HDMI codec probing code (bnc#1012628).
- drm/amd/display: do not allocate display_mode_lib unnecessarily
  (bnc#1012628).
- irqchip/gic-v3: Only provision redistributors that are enabled
  in ACPI (bnc#1012628).
- KVM: PPC: Book3S HV: Release lock on page-out failure path
  (bnc#1012628).
- drm/nouveau/disp/nv50-: prevent oops when no channel method
  map provided (bnc#1012628).
- char: hpet: Fix out-of-bounds read bug (bnc#1012628).
- ftrace: fpid_next() should increase position index
  (bnc#1012628).
- trigger_next should increase position index (bnc#1012628).
- radeon: insert 10ms sleep in dce5_crtc_load_lut (bnc#1012628).
- powerpc: Do not consider weak unresolved symbol relocations
  as bad (bnc#1012628).
- btrfs: do not do delalloc reservation under page lock
  (bnc#1012628).
- tracing: Fix now invalid var_ref_vals assumption in trace action
  (bnc#1012628).
- ocfs2: make local header paths relative to C files
  (bnc#1012628).
- ocfs2: fix a NULL pointer dereference when call
  ocfs2_update_inode_fsync_trans() (bnc#1012628).
- lib/scatterlist.c: adjust indentation in __sg_alloc_table
  (bnc#1012628).
- reiserfs: prevent NULL pointer dereference in
  reiserfs_insert_item() (bnc#1012628).
- bcache: fix memory corruption in bch_cache_accounting_clear()
  (bnc#1012628).
- bcache: explicity type cast in bset_bkey_last() (bnc#1012628).
- irqchip/gic-v3-its: Reference to its_invall_cmd descriptor
  when building INVALL (bnc#1012628).
- nvmet: Pass lockdep expression to RCU lists (bnc#1012628).
- nvmet: fix dsm failure when payload does not match sgl
  descriptor (bnc#1012628).
- nvme-pci: remove nvmeq->tags (bnc#1012628).
- iwlwifi: mvm: Fix thermal zone registration (bnc#1012628).
- iwlwifi: mvm: Check the sta is not NULL in iwl_mvm_cfg_he_sta()
  (bnc#1012628).
- asm-generic/tlb: add missing CONFIG symbol (bnc#1012628).
- tc-testing: add missing 'nsPlugin' to basic.json (bnc#1012628).
- microblaze: Prevent the overflow of the start (bnc#1012628).
- brd: check and limit max_part par (bnc#1012628).
- drm/amdgpu/smu10: fix smu10_get_clock_by_type_with_latency
  (bnc#1012628).
- drm/amdgpu/smu10: fix smu10_get_clock_by_type_with_voltage
  (bnc#1012628).
- NFS: Fix memory leaks (bnc#1012628).
- help_next should increase position index (bnc#1012628).
- i40e: Relax i40e_xsk_wakeup's return value when PF is busy
  (bnc#1012628).
- kbuild: make multiple directory targets work (bnc#1012628).
- cifs: log warning message (once) if out of disk space
  (bnc#1012628).
- virtio_balloon: prevent pfn array overflow (bnc#1012628).
- fuse: don't overflow LLONG_MAX with end offset (bnc#1012628).
- mlxsw: core: Add validation of hardware device types for MGPIR
  register (bnc#1012628).
- mlxsw: spectrum_dpipe: Add missing error path (bnc#1012628).
- s390/pci: Recover handle in clp_set_pci_fn() (bnc#1012628).
- drm/amdgpu/display: handle multiple numbers of fclks in
  dcn_calcs.c (v2) (bnc#1012628).
- bcache: properly initialize 'path' and 'err' in
  register_bcache() (bnc#1012628).
- rtc: Kconfig: select REGMAP_I2C when necessary (bnc#1012628).
- Update config files.
- commit 6e54038
* Mon Feb 24 2020 mkubecek@suse.cz
- Update to 5.6-rc3
- eliminated 3 patches
- commit 8f8ffe7
* Fri Feb 21 2020 mkubecek@suse.cz
- config: fix config options added with 5.5-rc1
  Due to a mistake on my side, some config options introduced in 5.5-rc1 got
  different values than the commit message claimed (and, more important, than
  intended). Thanks to Jean Delvare for catching this.
- restored config option values:
  - BACKLIGHT_QCOM_WLED=m
  - BYTCRC_PMIC_OPREGION=y
  - CAIF_DRIVERS=y
  - CHTCRC_PMIC_OPREGION=y
  - CRYPTO_BLAKE2S=m
  - CRYPTO_CURVE25519=m
  - CRYPTO_DEV_AMLOGIC_GXL=m
  - DP83869_PHY=m
  - DRM_AMD_DC_HDCP=y
  - NET_DSA_MSCC_FELIX=m
  - NET_DSA_TAG_OCELOT=m
  - NFC_PN532_UART=m
  - PINCTRL_EQUILIBRIUM=m
  - PINCTRL_TIGERLAKE=m
  - PTP_1588_CLOCK_IDTCM=m
  - SENSORS_BEL_PFE=m
  - SENSORS_LTC2947_I2C=m
  - SENSORS_LTC2947_SPI=m
  - SENSORS_TMP513=m
  - SF_PDMA=m
  - SYSTEM76_ACPI=m
  - TCG_TIS_SPI_CR50=y
  - TYPEC_HD3SS3220=m
  - VIDEO_HI556=m
  - VIDEO_IMX290=m
  - W1_SLAVE_DS2430=m
  - WFX=m
- new config options visible after the changes above:
  - CAIF_TTY=m
  - CAIF_SPI_SLAVE=m
  - CAIF_SPI_SYNC=n
  - CAIF_HSI=m
  - CAIF_VIRTIO=m
  - CRYPTO_DEV_AMLOGIC_GXL_DEBUG=n
  - CRYPTO_LIB_BLAKE2S=m
  - CRYPTO_LIB_CURVE25519=m
- config: fix config options added with 5.5-rc1
  Due to a mistake on my side, some config options introduced in 5.5-rc1 got
  different values than the commit message claimed (and, more important, than
  intended). Thanks to Jean Delvare for catching this.
- restored config option values:
  - BACKLIGHT_QCOM_WLED=m
  - BYTCRC_PMIC_OPREGION=y
  - CAIF_DRIVERS=y
  - CHTCRC_PMIC_OPREGION=y
  - CRYPTO_BLAKE2S=m
  - CRYPTO_CURVE25519=m
  - CRYPTO_DEV_AMLOGIC_GXL=m
  - DP83869_PHY=m
  - DRM_AMD_DC_HDCP=y
  - NET_DSA_MSCC_FELIX=m
  - NET_DSA_TAG_OCELOT=m
  - NFC_PN532_UART=m
  - PINCTRL_EQUILIBRIUM=m
  - PINCTRL_TIGERLAKE=m
  - PTP_1588_CLOCK_IDTCM=m
  - SENSORS_BEL_PFE=m
  - SENSORS_LTC2947_I2C=m
  - SENSORS_LTC2947_SPI=m
  - SENSORS_TMP513=m
  - SF_PDMA=m
  - SYSTEM76_ACPI=m
  - TCG_TIS_SPI_CR50=y
  - TYPEC_HD3SS3220=m
  - VIDEO_HI556=m
  - VIDEO_IMX290=m
  - W1_SLAVE_DS2430=m
  - WFX=m
- new config options visible after the changes above:
  - CAIF_TTY=m
  - CAIF_SPI_SLAVE=m
  - CAIF_SPI_SYNC=n
  - CAIF_HSI=m
  - CAIF_VIRTIO=m
  - CRYPTO_DEV_AMLOGIC_GXL_DEBUG=n
- commit bfcbf21
* Fri Feb 21 2020 jslaby@suse.cz
- Update config files (bnc#1163396).
  Disable CONFIG_RESET_ATTACK_MITIGATION as we don't have the userspace
  part and it causes problems during reboot. The config description
  states:
  This should only be enabled when userland is configured to clear the
  MemoryOverwriteRequest flag on clean shutdown after secrets have been
  evicted, since otherwise it will trigger even on clean reboots.
- commit 32035c7
* Thu Feb 20 2020 jslaby@suse.cz
- Linux 5.5.5 (bnc#1012628).
- io_uring: fix deferred req iovec leak (bnc#1012628).
- io_uring: retry raw bdev writes if we hit -EOPNOTSUPP
  (bnc#1012628).
- Input: synaptics - switch T470s to RMI4 by default
  (bnc#1012628).
- Input: synaptics - enable SMBus on ThinkPad L470 (bnc#1012628).
- Input: synaptics - remove the LEN0049 dmi id from topbuttonpad
  list (bnc#1012628).
- ALSA: usb-audio: Add clock validity quirk for Denon
  MC7000/MCX8000 (bnc#1012628).
- ALSA: usb-audio: Fix UAC2/3 effect unit parsing (bnc#1012628).
- ALSA: pcm: Fix double hw_free calls (bnc#1012628).
- ALSA: hda/realtek - Add more codec supported Headset Button
  (bnc#1012628).
- ALSA: hda/realtek - Fix silent output on MSI-GL73 (bnc#1012628).
- ALSA: usb-audio: Apply sample rate quirk for Audioengine D1
  (bnc#1012628).
- ACPI: EC: Fix flushing of pending work (bnc#1012628).
- ACPI: PM: s2idle: Avoid possible race related to the EC GPE
  (bnc#1012628).
- ACPICA: Introduce acpi_any_gpe_status_set() (bnc#1012628).
- ACPI: PM: s2idle: Prevent spurious SCIs from waking up the
  system (bnc#1012628).
- ext4: don't assume that mmp_nodename/bdevname have NUL
  (bnc#1012628).
- ext4: fix support for inode sizes > 1024 bytes (bnc#1012628).
- ext4: fix checksum errors with indexed dirs (bnc#1012628).
- ext4: add cond_resched() to ext4_protect_reserved_inode
  (bnc#1012628).
- ext4: improve explanation of a mount failure caused by a
  misconfigured kernel (bnc#1012628).
- Btrfs: fix race between using extent maps and merging them
  (bnc#1012628).
- btrfs: ref-verify: fix memory leaks (bnc#1012628).
- btrfs: print message when tree-log replay starts (bnc#1012628).
- btrfs: log message when rw remount is attempted with unclean
  tree-log (bnc#1012628).
- ARM: npcm: Bring back GPIOLIB support (bnc#1012628).
- gpio: xilinx: Fix bug where the wrong GPIO register is written
  to (bnc#1012628).
- arm64: ssbs: Fix context-switch when SSBS is present on all CPUs
  (bnc#1012628).
- xprtrdma: Fix DMA scatter-gather list mapping imbalance
  (bnc#1012628).
- cifs: make sure we do not overflow the max EA buffer size
  (bnc#1012628).
- jbd2: move the clearing of b_modified flag to the
  journal_unmap_buffer() (bnc#1012628).
- jbd2: do not clear the BH_Mapped flag when forgetting a metadata
  buffer (bnc#1012628).
- EDAC/sysfs: Remove csrow objects on errors (bnc#1012628).
- EDAC/mc: Fix use-after-free and memleaks during device removal
  (bnc#1012628).
- KVM: nVMX: Use correct root level for nested EPT shadow page
  tables (bnc#1012628).
- KVM: x86/mmu: Fix struct guest_walker arrays for 5-level paging
  (bnc#1012628).
- perf/x86/amd: Add missing L2 misses event spec to AMD Family
  17h's event map (bnc#1012628).
- s390/pkey: fix missing length of protected key on return
  (bnc#1012628).
- s390/uv: Fix handling of length extensions (bnc#1012628).
- drm/vgem: Close use-after-free race in vgem_gem_create
  (bnc#1012628).
- drm/mst: Fix possible NULL pointer dereference in
  drm_dp_mst_process_up_req() (bnc#1012628).
- drm/panfrost: Make sure the shrinker does not reclaim referenced
  BOs (bnc#1012628).
- drm/amdgpu: update smu_v11_0_pptable.h (bnc#1012628).
- drm/amdgpu:/navi10: use the ODCAP enum to index the caps array
  (bnc#1012628).
- bus: moxtet: fix potential stack buffer overflow (bnc#1012628).
- nvme: fix the parameter order for nvme_get_log in
  nvme_get_fw_slot_info (bnc#1012628).
- drivers: ipmi: fix off-by-one bounds check that leads to a
  out-of-bounds write (bnc#1012628).
- IB/mlx5: Return failure when rts2rts_qp_counters_set_id is
  not supported (bnc#1012628).
- IB/hfi1: Acquire lock to release TID entries when user file
  is closed (bnc#1012628).
- IB/hfi1: Close window for pq and request coliding (bnc#1012628).
- IB/rdmavt: Reset all QPs when the device is shut down
  (bnc#1012628).
- IB/umad: Fix kernel crash while unloading ib_umad (bnc#1012628).
- RDMA/core: Fix invalid memory access in spec_filter_size
  (bnc#1012628).
- RDMA/iw_cxgb4: initiate CLOSE when entering TERM (bnc#1012628).
- RDMA/hfi1: Fix memory leak in _dev_comp_vect_mappings_create
  (bnc#1012628).
- RDMA/rxe: Fix soft lockup problem due to using tasklets in
  softirq (bnc#1012628).
- RDMA/core: Fix protection fault in get_pkey_idx_qp_list
  (bnc#1012628).
- s390/time: Fix clk type in get_tod_clock (bnc#1012628).
- Input: ili210x - fix return value of is_visible function
  (bnc#1012628).
- sched/uclamp: Reject negative values in cpu_uclamp_write()
  (bnc#1012628).
- mac80211: use more bits for ack_frame_id (bnc#1012628).
- spmi: pmic-arb: Set lockdep class for hierarchical irq domains
  (bnc#1012628).
- perf/x86/intel: Fix inaccurate period in context switch for
  auto-reload (bnc#1012628).
- hwmon: (pmbus/ltc2978) Fix PMBus polling of MFR_COMMON
  definitions (bnc#1012628).
- mac80211: fix quiet mode activation in action frames
  (bnc#1012628).
- cifs: fix mount option display for sec=krb5i (bnc#1012628).
- ceph: noacl mount option is effectively ignored (bnc#1012628).
- arm64: dts: fast models: Fix FVP PCI interrupt-map property
  (bnc#1012628).
- KVM: x86: Mask off reserved bit from #DB exception payload
  (bnc#1012628).
- KVM: nVMX: Handle pending #DB when injecting INIT VM-exit
  (bnc#1012628).
- perf stat: Don't report a null stalled cycles per insn metric
  (bnc#1012628).
- NFSv4.1 make cachethis=no for writes (bnc#1012628).
- NFSv4: Ensure the delegation cred is pinned when we call
  delegreturn (bnc#1012628).
- Revert "drm/sun4i: drv: Allow framebuffer modifiers in mode
  config" (bnc#1012628).
- drm/i915/pmu: Correct the rc6 offset upon enabling
  (bnc#1012628).
- ext4: choose hardlimit when softlimit is larger than hardlimit
  in ext4_statfs_project() (bnc#1012628).
- io-wq: add support for inheriting ->fs (bnc#1012628).
- NFSv4: Add accounting for the number of active delegations held
  (bnc#1012628).
- gpio: add gpiod_toggle_active_low() (bnc#1012628).
- mmc: core: Rework wp-gpio handling (bnc#1012628).
- commit 5157fff
* Wed Feb 19 2020 jslaby@suse.cz
- Update config files (bnc#1161832).
  Disable CONFIG_MODULE_SIG on i386. We don't run pesign on i386 builds,
  hence the modules are not signed at all. This results in module
  verification failures and warnings.
  CONFIG_SECURITY_LOCKDOWN_LSM depends on (selects) CONFIG_MODULE_SIG, so
  we have to disable it too. But it makes no sense to lockdown without
  module signature anyway.
- commit 599e3c2
* Tue Feb 18 2020 msuchanek@suse.de
- Delete patches.rpmify/powerpc-boot-Fix-missing-crc32poly.h-when-building-w.patch.
- commit 3083c73
* Mon Feb 17 2020 jslaby@suse.cz
- vt: selection, close sel_buffer race (bnc#1162928
  CVE-2020-8648).
- vt: selection, handle pending signals in paste_selection
  (bnc#1162928 CVE-2020-8648).
- vt: selection, close sel_buffer race (bnc#1162928
  CVE-2020-8648).
- vt: selection, handle pending signals in paste_selection
  (bnc#1162928 CVE-2020-8648).
- commit 813d10d
* Mon Feb 17 2020 mkubecek@suse.cz
- Update to 5.6-rc2
- refresh configs (drop LIBXBC)
- commit 327abc9
* Mon Feb 17 2020 mkubecek@suse.cz
- ethtool: fix application of verbose no_mask bitset.
- commit 7b26eb4
* Sat Feb 15 2020 jslaby@suse.cz
- bcache: fix incorrect data type usage in btree_flush_write()
  (git-fixes).
- commit 119f9ca
* Sat Feb 15 2020 jslaby@suse.cz
- Linux 5.5.4 (bnc#1012628).
- selinux: fall back to ref-walk if audit is required
  (bnc#1012628).
- libertas: make lbs_ibss_join_existing() return error code on
  rates overflow (bnc#1012628).
- libertas: don't exit from lbs_ibss_join_existing() with RCU
  read lock held (bnc#1012628).
- mwifiex: Fix possible buffer overflows in
  mwifiex_cmd_append_vsie_tlv() (bnc#1012628).
- mwifiex: Fix possible buffer overflows in
  mwifiex_ret_wmm_get_status() (bnc#1012628).
- dmaengine: axi-dmac: add a check for devm_regmap_init_mmio
  (bnc#1012628).
- clk: meson: g12a: fix missing uart2 in regmap table
  (bnc#1012628).
- mfd: max77650: Select REGMAP_IRQ in Kconfig (bnc#1012628).
- regmap: fix writes to non incrementing registers (bnc#1012628).
- pinctrl: qcom: Don't lock around irq_set_irq_wake()
  (bnc#1012628).
- pinctrl: sh-pfc: r8a7778: Fix duplicate SDSELF_B and SD1_CLK_B
  (bnc#1012628).
- pinctrl: sh-pfc: r8a77965: Fix DU_DOTCLKIN3 drive/bias control
  (bnc#1012628).
- pinctrl: baytrail: Allocate IRQ chip dynamic (bnc#1012628).
- selinux: fix regression introduced by move_mount(2) syscall
  (bnc#1012628).
- selinux: revert "stop passing MAY_NOT_BLOCK to the AVC upon
  follow_link" (bnc#1012628).
- x86/alternatives: add missing insn.h include (bnc#1012628).
- bcache: avoid unnecessary btree nodes flushing in
  btree_flush_write() (bnc#1012628).
- ASoC: soc-generic-dmaengine-pcm: Fix error handling
  (bnc#1012628).
- dt-bindings: iio: adc: ad7606: Fix wrong maxItems value
  (bnc#1012628).
- i2c: cros-ec-tunnel: Fix ACPI identifier (bnc#1012628).
- i2c: cros-ec-tunnel: Fix slave device enumeration (bnc#1012628).
- media: i2c: adv748x: Fix unsafe macros (bnc#1012628).
- drivers: watchdog: stm32_iwdg: set WDOG_HW_RUNNING at probe
  (bnc#1012628).
- crypto: caam/qi2 - fix typo in algorithm's driver name
  (bnc#1012628).
- crypto: atmel-sha - fix error handling when setting hmac key
  (bnc#1012628).
- crypto: artpec6 - return correct error code for failed setkey()
  (bnc#1012628).
- crypto: testmgr - don't try to decrypt uninitialized buffers
  (bnc#1012628).
- mtd: sharpslpart: Fix unsigned comparison to zero (bnc#1012628).
- mtd: onenand_base: Adjust indentation in onenand_read_ops_nolock
  (bnc#1012628).
- arm64: kvm: Fix IDMAP overlap with HYP VA (bnc#1012628).
- arm64: nofpsmid: Handle TIF_FOREIGN_FPSTATE flag cleanly
  (bnc#1012628).
- KVM: arm64: Treat emulated TVAL TimerValue as a signed 32-bit
  integer (bnc#1012628).
- KVM: arm64: pmu: Fix chained SW_INCR counters (bnc#1012628).
- KVM: arm64: pmu: Don't increment SW_INCR if PMCR.E is unset
  (bnc#1012628).
- KVM: arm: Make inject_abt32() inject an external abort instead
  (bnc#1012628).
- KVM: arm: Fix DFSR setting for non-LPAE aarch32 guests
  (bnc#1012628).
- KVM: arm/arm64: Fix young bit from mmu notifier (bnc#1012628).
- crypto: arm/chacha - fix build failured when kernel mode NEON
  is disabled (bnc#1012628).
- arm64: ptrace: nofpsimd: Fail FP/SIMD regset operations
  (bnc#1012628).
- arm64: cpufeature: Set the FP/SIMD compat HWCAP bits properly
  (bnc#1012628).
- arm64: cpufeature: Fix the type of no FP/SIMD capability
  (bnc#1012628).
- arm64: kernel: Correct annotation of end of el0_sync
  (bnc#1012628).
- sched/uclamp: Fix a bug in propagating uclamp value in new
  cgroups (bnc#1012628).
- ARM: 8949/1: mm: mark free_memmap as __init (bnc#1012628).
- KVM: arm/arm64: vgic-its: Fix restoration of unmapped
  collections (bnc#1012628).
- ARM: at91: pm: use of_device_id array to find the proper shdwc
  node (bnc#1012628).
- ARM: at91: pm: use SAM9X60 PMC's compatible (bnc#1012628).
- iommu/arm-smmu-v3: Populate VMID field for CMDQ_OP_TLBI_NH_VA
  (bnc#1012628).
- powerpc/pseries: Allow not having ibm,
  hypertas-functions::hcall-multi-tce for DDW (bnc#1012628).
- powerpc/pseries/vio: Fix iommu_table use-after-free refcount
  warning (bnc#1012628).
- powerpc/papr_scm: Fix leaking 'bus_desc.provider_name' in some
  paths (bnc#1012628).
- powerpc/ptdump: Only enable PPC_CHECK_WX with STRICT_KERNEL_RWX
  (bnc#1012628).
- powerpc/ptdump: Fix W+X verification call in mark_rodata_ro()
  (bnc#1012628).
- Revert "powerpc/pseries/iommu: Don't use dma_iommu_ops on
  secure guests" (bnc#1012628).
- soc: qcom: rpmhpd: Set 'active_only' for active only power
  domains (bnc#1012628).
- tools/power/acpi: fix compilation error (bnc#1012628).
- ARM: dts: at91: sama5d3: define clock rate range for tcb1
  (bnc#1012628).
- ARM: dts: at91: sama5d3: fix maximum peripheral clock rates
  (bnc#1012628).
- ARM: dts: meson8b: use the actual frequency for the GPU's
  364MHz OPP (bnc#1012628).
- ARM: dts: meson8: use the actual frequency for the GPU's
  182.1MHz OPP (bnc#1012628).
- arm64: dts: marvell: clearfog-gt-8k: fix switch cpu port node
  (bnc#1012628).
- arm64: dts: renesas: r8a77990: ebisu: Remove
  clkout-lr-synchronous from sound (bnc#1012628).
- ARM: dts: am43xx: add support for clkout1 clock (bnc#1012628).
- ARM: dts: at91: Reenable UART TX pull-ups (bnc#1012628).
- arm64: dts: qcom: msm8998-mtp: Add alias for blsp1_uart3
  (bnc#1012628).
- arm64: dts: uDPU: fix broken ethernet (bnc#1012628).
- arm64: dts: qcom: msm8998: Fix tcsr syscon size (bnc#1012628).
- platform/x86: intel_mid_powerbtn: Take a copy of ddata
  (bnc#1012628).
- ARC: [plat-axs10x]: Add missing multicast filter number to
  GMAC node (bnc#1012628).
- MIPS: Loongson: Fix potential NULL dereference in
  loongson3_platform_init() (bnc#1012628).
- watchdog: qcom: Use platform_get_irq_optional() for bark irq
  (bnc#1012628).
- rtc: cmos: Stop using shared IRQ (bnc#1012628).
- rtc: hym8563: Return -EINVAL if the time is known to be invalid
  (bnc#1012628).
- rtc: mt6397: drop free_irq of devm_ allocated irq (bnc#1012628).
- netdevsim: use __GFP_NOWARN to avoid memalloc warning
  (bnc#1012628).
- netdevsim: fix panic in nsim_dev_take_snapshot_write()
  (bnc#1012628).
- netdevsim: disable devlink reload when resources are being used
  (bnc#1012628).
- netdevsim: fix using uninitialized resources (bnc#1012628).
- mt76: mt7615: fix max_nss in mt7615_eeprom_parse_hw_cap
  (bnc#1012628).
- bpf, sockmap: Check update requirements after locking
  (bnc#1012628).
- bpf: Improve bucket_log calculation logic (bnc#1012628).
- selftests/bpf: Test freeing sockmap/sockhash with a socket in it
  (bnc#1012628).
- bpf, sockhash: Synchronize_rcu before free'ing map
  (bnc#1012628).
- bpf, sockmap: Don't sleep while holding RCU lock on tear-down
  (bnc#1012628).
- bpftool: Don't crash on missing xlated program instructions
  (bnc#1012628).
- x86/boot: Handle malformed SRAT tables during early ACPI parsing
  (bnc#1012628).
- NFSv4.0: nfs4_do_fsinfo() should not do implicit lease renewals
  (bnc#1012628).
- NFSv4: try lease recovery on NFS4ERR_EXPIRED (bnc#1012628).
- NFSv4: pnfs_roc() must use cred_fscmp() to compare creds
  (bnc#1012628).
- NFS: Fix fix of show_nfs_errors (bnc#1012628).
- NFS/pnfs: Fix pnfs_generic_prepare_to_resend_writes()
  (bnc#1012628).
- NFS: Revalidate the file size on a fatal write error
  (bnc#1012628).
- nfs: NFS_SWAP should depend on SWAP (bnc#1012628).
- NFSv4.x recover from pre-mature loss of openstateid
  (bnc#1012628).
- netfilter: flowtable: Fix missing flush hardware on table free
  (bnc#1012628).
- netfilter: flowtable: Fix hardware flush order on
  nf_flow_table_cleanup (bnc#1012628).
- netfilter: flowtable: restrict flow dissector match on meta
  ingress device (bnc#1012628).
- netfilter: flowtable: fetch stats only if flow is still alive
  (bnc#1012628).
- iwlwifi: mvm: fix TDLS discovery with the new firmware API
  (bnc#1012628).
- iwlwifi: mvm: avoid use after free for pmsr request
  (bnc#1012628).
- PCI/AER: Initialize aer_fifo (bnc#1012628).
- PCI: Don't disable bridge BARs when assigning bus resources
  (bnc#1012628).
- PCI: tegra: Fix afi_pex2_ctrl reg offset for Tegra30
  (bnc#1012628).
- PCI/switchtec: Fix vep_vector_number ioread width (bnc#1012628).
- PCI/switchtec: Use dma_set_mask_and_coherent() (bnc#1012628).
- ath10k: pci: Only dump ATH10K_MEM_REGION_TYPE_IOREG when safe
  (bnc#1012628).
- PCI/IOV: Fix memory leak in pci_iov_add_virtfn() (bnc#1012628).
- scsi: ufs: Fix ufshcd_probe_hba() reture value in case
  ufshcd_scsi_add_wlus() fails (bnc#1012628).
- RDMA/umem: Fix ib_umem_find_best_pgsz() (bnc#1012628).
- RDMA/cma: Fix unbalanced cm_id reference count during address
  resolve (bnc#1012628).
- RDMA/core: Ensure that rdma_user_mmap_entry_remove() is a fence
  (bnc#1012628).
- RDMA/mlx5: Fix handling of IOVA != user_va in ODP paths
  (bnc#1012628).
- RDMA/uverbs: Verify MR access flags (bnc#1012628).
- RDMA/core: Fix locking in ib_uverbs_event_read (bnc#1012628).
- RDMA/i40iw: fix a potential NULL pointer dereference
  (bnc#1012628).
- RDMA/netlink: Do not always generate an ACK for some netlink
  operations (bnc#1012628).
- IB/mlx4: Fix leak in id_map_find_del (bnc#1012628).
- IB/mlx5: Return the administrative GUID if exists (bnc#1012628).
- IB/srp: Never use immediate data if it is disabled by a user
  (bnc#1012628).
- IB/mlx4: Fix memory leak in add_gid error flow (bnc#1012628).
- commit 271ee1b
* Thu Feb 13 2020 tiwai@suse.de
- Update config files: enable CONFIG_FW_CFG_SYSFS for arm64 (bsc#1163521)
- commit d888576
* Wed Feb 12 2020 jdelvare@suse.de
- Update config files: CONFIG_NVME_HWMON=y
  When the config files were updated for kernel v5.5, the commit
  message claimed CONFIG_NVME_HWMON was to be enabled, however the
  configuration files themselves had the option disabled. We definitely
  want hardware monitoring enabled on NVME devices, so fix the
  configuration files to match the original intent.
- commit d654690
* Wed Feb 12 2020 jslaby@suse.cz
- Linux 5.5.3 (bnc#1012628).
- sparc32: fix struct ipc64_perm type definition (bnc#1012628).
- bnxt_en: Move devlink_register before registering netdev
  (bnc#1012628).
- gtp: use __GFP_NOWARN to avoid memalloc warning (bnc#1012628).
- l2tp: Allow duplicate session creation with UDP (bnc#1012628).
- net: hsr: fix possible NULL deref in hsr_handle_frame()
  (bnc#1012628).
- net_sched: fix an OOB access in cls_tcindex (bnc#1012628).
- net/core: Do not clear VF index for node/port GUIDs query
  (bnc#1012628).
- net: mvneta: fix XDP support if sw bm is used as fallback
  (bnc#1012628).
- bnxt_en: Fix TC queue mapping (bnc#1012628).
- net: stmmac: Delete txtimer in suspend() (bnc#1012628).
- tcp: clear tp->total_retrans in tcp_disconnect() (bnc#1012628).
- tcp: clear tp->delivered in tcp_disconnect() (bnc#1012628).
- tcp: clear tp->data_segs{in|out} in tcp_disconnect()
  (bnc#1012628).
- tcp: clear tp->segs_{in|out} in tcp_disconnect() (bnc#1012628).
- cls_rsvp: fix rsvp_policy (bnc#1012628).
- rxrpc: Fix use-after-free in rxrpc_put_local() (bnc#1012628).
- rxrpc: Fix insufficient receive notification generation
  (bnc#1012628).
- rxrpc: Fix missing active use pinning of rxrpc_local object
  (bnc#1012628).
- rxrpc: Fix NULL pointer deref due to call->conn being cleared
  on disconnect (bnc#1012628).
- bnxt_en: Refactor logic to re-enable SRIOV after firmware
  reset detected (bnc#1012628).
- net: phy: at803x: disable vddio regulator (bnc#1012628).
- bnxt_en: Fix RDMA driver failure with SRIOV after firmware reset
  (bnc#1012628).
- ionic: fix rxq comp packet type mask (bnc#1012628).
- MAINTAINERS: correct entries for ISDN/mISDN section
  (bnc#1012628).
- netdevsim: fix stack-out-of-bounds in nsim_dev_debugfs_init()
  (bnc#1012628).
- bnxt_en: Fix logic that disables Bus Master during firmware
  reset (bnc#1012628).
- media: uvcvideo: Avoid cyclic entity chains due to malformed
  USB descriptors (bnc#1012628).
- mfd: dln2: More sanity checking for endpoints (bnc#1012628).
- netfilter: ipset: fix suspicious RCU usage in find_set_and_id
  (bnc#1012628).
- ALSA: pcm: Fix memory leak at closing a stream without hw_free
  (bnc#1012628).
- ipc/msg.c: consolidate all xxxctl_down() functions
  (bnc#1012628).
- tracing/kprobes: Have uname use __get_str() in print_fmt
  (bnc#1012628).
- tracing: Fix sched switch start/stop refcount racy updates
  (bnc#1012628).
- rcu: Use *_ONCE() to protect lockless ->expmask accesses
  (bnc#1012628).
- rcu: Avoid data-race in rcu_gp_fqs_check_wake() (bnc#1012628).
- srcu: Apply *_ONCE() to ->srcu_last_gp_end (bnc#1012628).
- rcu: Use READ_ONCE() for ->expmask in rcu_read_unlock_special()
  (bnc#1012628).
- nvmet: Fix error print message at nvmet_install_queue function
  (bnc#1012628).
- nvmet: Fix controller use after free (bnc#1012628).
- Bluetooth: btusb: fix memory leak on fw (bnc#1012628).
- Bluetooth: btusb: Disable runtime suspend on Realtek devices
  (bnc#1012628).
- brcmfmac: Fix memory leak in brcmf_usbdev_qinit (bnc#1012628).
- usb: dwc3: gadget: Check END_TRANSFER completion (bnc#1012628).
- usb: dwc3: gadget: Delay starting transfer (bnc#1012628).
- usb: typec: tcpci: mask event interrupts when remove driver
  (bnc#1012628).
- objtool: Silence build output (bnc#1012628).
- usb: gadget: f_fs: set req->num_sgs as 0 for non-sg transfer
  (bnc#1012628).
- usb: gadget: legacy: set max_speed to super-speed (bnc#1012628).
- usb: gadget: f_ncm: Use atomic_t to track in-flight request
  (bnc#1012628).
- usb: gadget: f_ecm: Use atomic_t to track in-flight request
  (bnc#1012628).
- ALSA: usb-audio: Fix endianess in descriptor validation
  (bnc#1012628).
- ALSA: usb-audio: Annotate endianess in Scarlett gen2 quirk
  (bnc#1012628).
- ALSA: dummy: Fix PCM format loop in proc output (bnc#1012628).
- memcg: fix a crash in wb_workfn when a device disappears
  (bnc#1012628).
- mm/sparse.c: reset section's mem_map when fully deactivated
  (bnc#1012628).
- utimes: Clamp the timestamps in notify_change() (bnc#1012628).
- mm/migrate.c: also overwrite error when it is bigger than zero
  (bnc#1012628).
- mm/memory_hotplug: fix remove_memory() lockdep splat
  (bnc#1012628).
- mm: thp: don't need care deferred split queue in memcg charge
  move path (bnc#1012628).
- mm: move_pages: report the number of non-attempted pages
  (bnc#1012628).
- media/v4l2-core: set pages dirty upon releasing DMA buffers
  (bnc#1012628).
- media: v4l2-core: compat: ignore native command codes
  (bnc#1012628).
- media: v4l2-rect.h: fix v4l2_rect_map_inside() top/left
  adjustments (bnc#1012628).
- lib/test_kasan.c: fix memory leak in kmalloc_oob_krealloc_more()
  (bnc#1012628).
- irqdomain: Fix a memory leak in irq_domain_push_irq()
  (bnc#1012628).
- x86/cpu: Update cached HLE state on write to
  TSX_CTRL_CPUID_CLEAR (bnc#1012628).
- platform/x86: intel_scu_ipc: Fix interrupt support
  (bnc#1012628).
- ALSA: hda: Add Clevo W65_67SB the power_save blacklist
  (bnc#1012628).
- ALSA: hda: Add JasperLake PCI ID and codec vid (bnc#1012628).
- ALSA: hda - Fix DP-MST support for NVIDIA codecs (bnc#1012628).
- arm64: acpi: fix DAIF manipulation with pNMI (bnc#1012628).
- KVM: arm64: Correct PSTATE on exception entry (bnc#1012628).
- KVM: arm/arm64: Correct CPSR on exception entry (bnc#1012628).
- KVM: arm/arm64: Correct AArch32 SPSR on exception entry
  (bnc#1012628).
- KVM: arm64: Only sign-extend MMIO up to register width
  (bnc#1012628).
- MIPS: syscalls: fix indentation of the 'SYSNR' message
  (bnc#1012628).
- MIPS: fix indentation of the 'RELOCS' message (bnc#1012628).
- MIPS: boot: fix typo in 'vmlinux.lzma.its' target (bnc#1012628).
- MIPS: SGI-IP30: Check for valid pointer before using it
  (bnc#1012628).
- MIPS: asm: local: add barriers for Loongson (bnc#1012628).
- s390/mm: fix dynamic pagetable upgrade for hugetlbfs
  (bnc#1012628).
- powerpc/mmu_gather: enable RCU_TABLE_FREE even for !SMP case
  (bnc#1012628).
- powerpc/ptdump: Fix W+X verification (bnc#1012628).
- powerpc/xmon: don't access ASDR in VMs (bnc#1012628).
- powerpc/pseries: Advance pfn if section is not present in
  lmb_is_removable() (bnc#1012628).
- powerpc/32s: Fix bad_kuap_fault() (bnc#1012628).
- powerpc/32s: Fix CPU wake-up from sleep mode (bnc#1012628).
- PCI/ATS: Use PF PASID for VFs (bnc#1012628).
- PCI: tegra: Fix return value check of pm_runtime_get_sync()
  (bnc#1012628).
- PCI: keystone: Fix outbound region mapping (bnc#1012628).
- PCI: keystone: Fix link training retries initiation
  (bnc#1012628).
- PCI: keystone: Fix error handling when "num-viewport" DT
  property is not populated (bnc#1012628).
- mmc: spi: Toggle SPI polarity, do not hardcode it (bnc#1012628).
- ACPI: video: Do not export a non working backlight interface
  on MSI MS-7721 boards (bnc#1012628).
- ACPI / battery: Deal with design or full capacity being reported
  as -1 (bnc#1012628).
- ACPI / battery: Use design-cap for capacity calculations if
  full-cap is not available (bnc#1012628).
- ACPI / battery: Deal better with neither design nor full
  capacity not being reported (bnc#1012628).
- smb3: fix default permissions on new files when mounting with
  modefromsid (bnc#1012628).
- alarmtimer: Unregister wakeup source when module get fails
  (bnc#1012628).
- fscrypt: don't print name of busy file when removing key
  (bnc#1012628).
- ubifs: don't trigger assertion on invalid no-key filename
  (bnc#1012628).
- ubifs: Fix wrong memory allocation (bnc#1012628).
- ubifs: Fix FS_IOC_SETFLAGS unexpectedly clearing encrypt flag
  (bnc#1012628).
- ubifs: Fix deadlock in concurrent bulk-read and writepage
  (bnc#1012628).
- mmc: sdhci-of-at91: fix memleak on clk_get failure
  (bnc#1012628).
- ASoC: tegra: Revert 24 and 32 bit support (bnc#1012628).
- ASoC: topology: fix soc_tplg_fe_link_create() - link->dobj
  initialization order (bnc#1012628).
- hv_balloon: Balloon up according to request page number
  (bnc#1012628).
- mfd: axp20x: Mark AXP20X_VBUS_IPSOUT_MGMT as volatile
  (bnc#1012628).
- nvmem: imx: scu: fix write SIP (bnc#1012628).
- nvmem: core: fix memory abort in cleanup path (bnc#1012628).
- crypto: api - Check spawn->alg under lock in crypto_drop_spawn
  (bnc#1012628).
- crypto: ccree - fix backlog memory leak (bnc#1012628).
- crypto: ccree - fix AEAD decrypt auth fail (bnc#1012628).
- crypto: ccree - fix pm wrongful error reporting (bnc#1012628).
- crypto: ccree - fix FDE descriptor sequence (bnc#1012628).
- crypto: ccree - fix PM race condition (bnc#1012628).
- padata: Remove broken queue flushing (bnc#1012628).
- fs: allow deduplication of eof block into the end of the
  destination file (bnc#1012628).
- scripts/find-unused-docs: Fix massive false positives
  (bnc#1012628).
- erofs: fix out-of-bound read for shifted uncompressed block
  (bnc#1012628).
- scsi: megaraid_sas: Do not initiate OCR if controller is not
  in ready state (bnc#1012628).
- scsi: qla2xxx: Fix stuck login session using prli_pend_timer
  (bnc#1012628).
- scsi: qla2xxx: Fix mtcp dump collection failure (bnc#1012628).
- cpupower: Revert library ABI changes from commit
  ae2917093fb60bdc1ed3e (bnc#1012628).
- power: supply: axp20x_ac_power: Fix reporting online status
  (bnc#1012628).
- power: supply: ltc2941-battery-gauge: fix use-after-free
  (bnc#1012628).
- ovl: fix wrong WARN_ON() in ovl_cache_update_ino()
  (bnc#1012628).
- ovl: fix lseek overflow on 32bit (bnc#1012628).
- f2fs: fix miscounted block limit in f2fs_statfs_project()
  (bnc#1012628).
- f2fs: code cleanup for f2fs_statfs_project() (bnc#1012628).
- f2fs: fix dcache lookup of !casefolded directories
  (bnc#1012628).
- f2fs: fix race conditions in ->d_compare() and ->d_hash()
  (bnc#1012628).
- PM: core: Fix handling of devices deleted during system-wide
  resume (bnc#1012628).
- cpufreq: Avoid creating excessively large stack frames
  (bnc#1012628).
- of: Add OF_DMA_DEFAULT_COHERENT & select it on powerpc
  (bnc#1012628).
- ARM: dma-api: fix max_pfn off-by-one error in __dma_supported()
  (bnc#1012628).
- dm zoned: support zone sizes smaller than 128MiB (bnc#1012628).
- dm space map common: fix to ensure new block isn't already in
  use (bnc#1012628).
- dm writecache: fix incorrect flush sequence when doing SSD
  mode commit (bnc#1012628).
- dm crypt: fix GFP flags passed to skcipher_request_alloc()
  (bnc#1012628).
- dm crypt: fix benbi IV constructor crash if used in
  authenticated mode (bnc#1012628).
- dm thin metadata: use pool locking at end of
  dm_pool_metadata_close (bnc#1012628).
- dm thin: fix use-after-free in metadata_pre_commit_callback
  (bnc#1012628).
- dm: fix potential for q->make_request_fn NULL pointer
  (bnc#1012628).
- tracing: Annotate ftrace_graph_hash pointer with __rcu
  (bnc#1012628).
- tracing: Annotate ftrace_graph_notrace_hash pointer with __rcu
  (bnc#1012628).
- ftrace: Add comment to why rcu_dereference_sched() is open coded
  (bnc#1012628).
- ftrace: Protect ftrace_graph_hash with ftrace_sync
  (bnc#1012628).
- crypto: pcrypt - Avoid deadlock by using per-instance padata
  queues (bnc#1012628).
- btrfs: fix improper setting of scanned for range cyclic write
  cache pages (bnc#1012628).
- btrfs: Handle another split brain scenario with metadata uuid
  feature (bnc#1012628).
- riscv, bpf: Fix broken BPF tail calls (bnc#1012628).
- libbpf: Fix readelf output parsing for Fedora (bnc#1012628).
- libbpf: Fix printf compilation warnings on ppc64le arch
  (bnc#1012628).
- libbpf: Don't attach perf_buffer to offline/missing CPUs
  (bnc#1012628).
- selftests/bpf: Fix perf_buffer test on systems w/ offline CPUs
  (bnc#1012628).
- flow_dissector: Fix to use new variables for port ranges in
  bpf hook (bnc#1012628).
- bpf, devmap: Pass lockdep expression to RCU lists (bnc#1012628).
- libbpf: Add missing newline in opts validation macro
  (bnc#1012628).
- libbpf: Fix realloc usage in bpf_core_find_cands (bnc#1012628).
- tc-testing: fix eBPF tests failure on linux fresh clones
  (bnc#1012628).
- samples/bpf: Don't try to remove user's homedir on clean
  (bnc#1012628).
- samples/bpf: Xdp_redirect_cpu fix missing tracepoint attach
  (bnc#1012628).
- samples/bpf: Reintroduce missed build targets (bnc#1012628).
- selftests/bpf: Fix test_attach_probe (bnc#1012628).
- selftests/bpf: Skip perf hw events test if the setup disabled it
  (bnc#1012628).
- selftests: bpf: Use a temporary file in test_sockmap
  (bnc#1012628).
- selftests: bpf: Ignore FIN packets for reuseport tests
  (bnc#1012628).
- crypto: sun8i-ss - fix removal of module (bnc#1012628).
- crypto: amlogic - fix removal of module (bnc#1012628).
- crypto: sun8i-ce - fix removal of module (bnc#1012628).
- crypto: api - fix unexpectedly getting generic implementation
  (bnc#1012628).
- crypto: hisilicon - Fix issue with wrong number of sg elements
  after dma map (bnc#1012628).
- crypto: hisilicon - Use the offset fields in sqe to avoid need
  to split scatterlists (bnc#1012628).
- crypto: ccp - set max RSA modulus size for v3 platform devices
  as well (bnc#1012628).
- crypto: arm64/ghash-neon - bump priority to 150 (bnc#1012628).
- crypto: pcrypt - Do not clear MAY_SLEEP flag in original request
  (bnc#1012628).
- crypto: hisilicon - select CRYPTO_SKCIPHER, not CRYPTO_BLKCIPHER
  (bnc#1012628).
- crypto: atmel-aes - Fix counter overflow in CTR mode
  (bnc#1012628).
- crypto: api - Fix race condition in crypto_spawn_alg
  (bnc#1012628).
- crypto: picoxcell - adjust the position of tasklet_init and
  fix missed tasklet_kill (bnc#1012628).
- powerpc/futex: Fix incorrect user access blocking (bnc#1012628).
- scsi: qla2xxx: Fix unbound NVME response length (bnc#1012628).
- NFS: Fix memory leaks and corruption in readdir (bnc#1012628).
- NFS: Directory page cache pages need to be locked when read
  (bnc#1012628).
- nfsd: fix filecache lookup (bnc#1012628).
- jbd2_seq_info_next should increase position index (bnc#1012628).
- ext4: fix deadlock allocating crypto bounce page from mempool
  (bnc#1012628).
- ext4: fix race conditions in ->d_compare() and ->d_hash()
  (bnc#1012628).
- Btrfs: fix missing hole after hole punching and fsync when
  using NO_HOLES (bnc#1012628).
- Btrfs: make deduplication with range including the last block
  work (bnc#1012628).
- Btrfs: fix infinite loop during fsync after rename operations
  (bnc#1012628).
- btrfs: set trans->drity in btrfs_commit_transaction
  (bnc#1012628).
- btrfs: drop log root for dropped roots (bnc#1012628).
- btrfs: free block groups after free'ing fs trees (bnc#1012628).
- Btrfs: fix race between adding and putting tree mod seq elements
  and nodes (bnc#1012628).
- btrfs: flush write bio if we loop in extent_write_cache_pages
  (bnc#1012628).
- btrfs: Correctly handle empty trees in
  find_first_clear_extent_bit (bnc#1012628).
- Btrfs: send, fix emission of invalid clone operations within
  the same file (bnc#1012628).
- ARM: tegra: Enable PLLP bypass during Tegra124 LP1
  (bnc#1012628).
- iwlwifi: don't throw error when trying to remove IGTK
  (bnc#1012628).
- mwifiex: fix unbalanced locking in mwifiex_process_country_ie()
  (bnc#1012628).
- sunrpc: expiry_time should be seconds not timeval (bnc#1012628).
- gfs2: fix gfs2_find_jhead that returns uninitialized jhead
  with seq 0 (bnc#1012628).
- gfs2: move setting current->backing_dev_info (bnc#1012628).
- gfs2: fix O_SYNC write handling (bnc#1012628).
- drm: atmel-hlcdc: use double rate for pixel clock only if
  supported (bnc#1012628).
- drm: atmel-hlcdc: enable clock before configuring timing engine
  (bnc#1012628).
- drm: atmel-hlcdc: prefer a lower pixel-clock than requested
  (bnc#1012628).
- drm/rect: Avoid division by zero (bnc#1012628).
- media: iguanair: fix endpoint sanity check (bnc#1012628).
- media: rc: ensure lirc is initialized before registering input
  device (bnc#1012628).
- tools/kvm_stat: Fix kvm_exit filter name (bnc#1012628).
- xen/balloon: Support xend-based toolstack take two
  (bnc#1012628).
- xen/gntdev: Do not use mm notifiers with autotranslating guests
  (bnc#1012628).
- watchdog: fix UAF in reboot notifier handling in watchdog core
  code (bnc#1012628).
- bcache: add readahead cache policy options via sysfs interface
  (bnc#1012628).
- io_uring: don't map read/write iovec potentially twice
  (bnc#1012628).
- io_uring: spin for sq thread to idle on shutdown (bnc#1012628).
- eventfd: track eventfd_signal() recursion depth (bnc#1012628).
- aio: prevent potential eventfd recursion on poll (bnc#1012628).
- KVM: x86: Refactor picdev_write() to prevent Spectre-v1/L1TF
  attacks (bnc#1012628).
- KVM: x86: Refactor prefix decoding to prevent Spectre-v1/L1TF
  attacks (bnc#1012628).
- KVM: x86: Protect pmu_intel.c from Spectre-v1/L1TF attacks
  (bnc#1012628).
- KVM: x86: Protect DR-based index computations from
  Spectre-v1/L1TF attacks (bnc#1012628).
- KVM: x86: Protect kvm_lapic_reg_write() from Spectre-v1/L1TF
  attacks (bnc#1012628).
- KVM: x86: Protect kvm_hv_msr_[get|set]_crash_data() from
  Spectre-v1/L1TF attacks (bnc#1012628).
- KVM: x86: Protect ioapic_write_indirect() from Spectre-v1/L1TF
  attacks (bnc#1012628).
- KVM: x86: Protect MSR-based index computations in pmu.h from
  Spectre-v1/L1TF attacks (bnc#1012628).
- KVM: x86: Protect ioapic_read_indirect() from Spectre-v1/L1TF
  attacks (bnc#1012628).
- KVM: x86: Protect MSR-based index computations from
  Spectre-v1/L1TF attacks in x86.c (bnc#1012628).
- KVM: x86: Protect x86_decode_insn from Spectre-v1/L1TF attacks
  (bnc#1012628).
- KVM: x86: Protect MSR-based index computations in
  fixed_msr_to_seg_unit() from Spectre-v1/L1TF attacks
  (bnc#1012628).
- KVM: x86: Fix potential put_fpu() w/o load_fpu() on MPX platform
  (bnc#1012628).
- KVM: PPC: Book3S HV: Uninit vCPU if vcore creation fails
  (bnc#1012628).
- KVM: PPC: Book3S PR: Free shared page if mmu initialization
  fails (bnc#1012628).
- kvm/svm: PKU not currently supported (bnc#1012628).
- KVM: x86/mmu: Apply max PA check for MMIO sptes to 32-bit KVM
  (bnc#1012628).
- KVM: x86: use CPUID to locate host page table reserved bits
  (bnc#1012628).
- KVM: x86: Use gpa_t for cr2/gpa to fix TDP support on 32-bit
  KVM (bnc#1012628).
- KVM: VMX: Add non-canonical check on writes to RTIT address MSRs
  (bnc#1012628).
- KVM: x86: Don't let userspace set host-reserved cr4 bits
  (bnc#1012628).
- KVM: x86: Free wbinvd_dirty_mask if vCPU creation fails
  (bnc#1012628).
- KVM: x86: fix overlap between SPTE_MMIO_MASK and generation
  (bnc#1012628).
- KVM: x86: Handle TIF_NEED_FPU_LOAD in kvm_{load,put}_guest_fpu()
  (bnc#1012628).
- KVM: x86: Ensure guest's FPU state is loaded when accessing
  for emulation (bnc#1012628).
- KVM: x86: Revert "KVM: X86: Fix fpu state crash in kvm guest"
  (bnc#1012628).
- KVM: s390: do not clobber registers during guest reset/store
  status (bnc#1012628).
- KVM: x86: reorganize pvclock_gtod_data members (bnc#1012628).
- KVM: x86: use raw clock values consistently (bnc#1012628).
- ocfs2: fix oops when writing cloned file (bnc#1012628).
- mm/page_alloc.c: fix uninitialized memmaps on a partially
  populated last section (bnc#1012628).
- arm64: dts: qcom: qcs404-evb: Set vdd_apc regulator in high
  power mode (bnc#1012628).
- mm/mmu_gather: invalidate TLB correctly on batch allocation
  failure and flush (bnc#1012628).
- clk: tegra: Mark fuse clock as critical (bnc#1012628).
- drm/amdgpu/navi: fix index for OD MCLK (bnc#1012628).
- drm/tegra: Relax IOMMU usage criteria on old Tegra
  (bnc#1012628).
- drm/tegra: Reuse IOVA mapping where possible (bnc#1012628).
- drm/amd/powerplay: fix navi10 system intermittent reboot issue
  V2 (bnc#1012628).
- drm/amd/dm/mst: Ignore payload update failures (bnc#1012628).
- drm/amdgpu: fetch default VDDC curve voltages (v2)
  (bnc#1012628).
- drm/amdgpu/navi10: add OD_RANGE for navi overclocking
  (bnc#1012628).
- drm/amdgpu/smu_v11_0: Correct behavior of restoring default
  tables (v2) (bnc#1012628).
- virtio-balloon: initialize all vq callbacks (bnc#1012628).
- virtio-pci: check name when counting MSI-X vectors
  (bnc#1012628).
- fix up iter on short count in fuse_direct_io() (bnc#1012628).
- broken ping to ipv6 linklocal addresses on debian buster
  (bnc#1012628).
- percpu: Separate decrypted varaibles anytime encryption can
  be enabled (bnc#1012628).
- ASoC: meson: axg-fifo: fix fifo threshold setup (bnc#1012628).
- scsi: qla2xxx: Fix the endianness of the qla82xx_get_fw_size()
  return type (bnc#1012628).
- scsi: csiostor: Adjust indentation in csio_device_reset
  (bnc#1012628).
- scsi: qla4xxx: Adjust indentation in qla4xxx_mem_free
  (bnc#1012628).
- scsi: ufs: Recheck bkops level if bkops is disabled
  (bnc#1012628).
- compat: scsi: sg: fix v3 compat read/write interface
  (bnc#1012628).
- mtd: spi-nor: Split mt25qu512a (n25q512a) entry into two
  (bnc#1012628).
- phy: qualcomm: Adjust indentation in read_poll_timeout
  (bnc#1012628).
- ext2: Adjust indentation in ext2_fill_super (bnc#1012628).
- powerpc/44x: Adjust indentation in ibm4xx_denali_fixup_memsize
  (bnc#1012628).
- drm: msm: mdp4: Adjust indentation in mdp4_dsi_encoder_enable
  (bnc#1012628).
- NFC: pn544: Adjust indentation in pn544_hci_check_presence
  (bnc#1012628).
- ppp: Adjust indentation into ppp_async_input (bnc#1012628).
- net: smc911x: Adjust indentation in smc911x_phy_configure
  (bnc#1012628).
- net: tulip: Adjust indentation in {dmfe, uli526x}_init_module
  (bnc#1012628).
- IB/mlx5: Fix outstanding_pi index for GSI qps (bnc#1012628).
- IB/core: Fix ODP get user pages flow (bnc#1012628).
- IB/core: Fix ODP with IB_ACCESS_HUGETLB handling (bnc#1012628).
- staging: wfx: revert unexpected change in debugfs output
  (bnc#1012628).
- nfsd: fix delay timer on 32-bit architectures (bnc#1012628).
- nfsd: fix jiffies/time_t mixup in LRU list (bnc#1012628).
- nfsd: Return the correct number of bytes written to the file
  (bnc#1012628).
- virtio-balloon: Fix memory leak when unloading while hinting
  is in progress (bnc#1012628).
- virtio_balloon: Fix memory leaks on errors in
  virtballoon_probe() (bnc#1012628).
- ubi: fastmap: Fix inverted logic in seen selfcheck
  (bnc#1012628).
- ubi: Fix an error pointer dereference in error handling code
  (bnc#1012628).
- ubifs: Fix memory leak from c->sup_node (bnc#1012628).
- regulator: core: Add regulator_is_equal() helper (bnc#1012628).
- ASoC: sgtl5000: Fix VDDA and VDDIO comparison (bnc#1012628).
- ASoC: Intel: skl_hda_dsp_common: Fix global-out-of-bounds bug
  (bnc#1012628).
- mfd: da9062: Fix watchdog compatible string (bnc#1012628).
- mfd: rn5t618: Mark ADC control register volatile (bnc#1012628).
- mfd: bd70528: Fix hour register mask (bnc#1012628).
- mfd: ab8500: Fix ab8500-clk typo (bnc#1012628).
- bpf: Fix trampoline usage in preempt (bnc#1012628).
- libbpf: Extract and generalize CPU mask parsing logic
  (bnc#1012628).
- x86/timer: Don't skip PIT setup when APIC is disabled or in
  legacy mode (bnc#1012628).
- bonding/alb: properly access headers in bond_alb_xmit()
  (bnc#1012628).
- devlink: report 0 after hitting end in region read
  (bnc#1012628).
- dpaa_eth: support all modes with rate adapting PHYs
  (bnc#1012628).
- net: dsa: b53: Always use dev->vlan_enabled in
  b53_configure_vlan() (bnc#1012628).
- net: dsa: bcm_sf2: Only 7278 supports 2Gb/sec IMP port
  (bnc#1012628).
- net: dsa: microchip: enable module autoprobe (bnc#1012628).
- net: mvneta: move rx_dropped and rx_errors in per-cpu stats
  (bnc#1012628).
- net_sched: fix a resource leak in tcindex_set_parms()
  (bnc#1012628).
- net: stmmac: fix a possible endless loop (bnc#1012628).
- net: systemport: Avoid RBUF stuck in Wake-on-LAN mode
  (bnc#1012628).
- net/mlx5: IPsec, Fix esp modify function attribute
  (bnc#1012628).
- net/mlx5: IPsec, fix memory leak at
  mlx5_fpga_ipsec_delete_sa_ctx (bnc#1012628).
- net: macb: Remove unnecessary alignment check for TSO
  (bnc#1012628).
- net: macb: Limit maximum GEM TX length in TSO (bnc#1012628).
- net: stmmac: fix incorrect GMAC_VLAN_TAG register writting in
  GMAC4+ (bnc#1012628).
- net: stmmac: xgmac: fix incorrect XGMAC_VLAN_TAG register
  writting (bnc#1012628).
- net: stmmac: fix missing IFF_MULTICAST check in
  dwmac4_set_filter (bnc#1012628).
- net: stmmac: xgmac: fix missing IFF_MULTICAST checki in
  dwxgmac2_set_filter (bnc#1012628).
- net: stmmac: update pci platform data to use phy_interface
  (bnc#1012628).
- taprio: Fix enabling offload with wrong number of traffic
  classes (bnc#1012628).
- taprio: Fix still allowing changing the flags during runtime
  (bnc#1012628).
- taprio: Add missing policy validation for flags (bnc#1012628).
- taprio: Use taprio_reset_tc() to reset Traffic Classes
  configuration (bnc#1012628).
- taprio: Fix dropping packets when using taprio + ETF offloading
  (bnc#1012628).
- ipv6/addrconf: fix potential NULL deref in inet6_set_link_af()
  (bnc#1012628).
- qed: Fix timestamping issue for L2 unicast ptp packets
  (bnc#1012628).
- drop_monitor: Do not cancel uninitialized work item
  (bnc#1012628).
- net/mlx5: Fix deadlock in fs_core (bnc#1012628).
- net/mlx5: Deprecate usage of generic TLS HW capability bit
  (bnc#1012628).
- r8169: fix performance regression related to PCIe max read
  request size (bnc#1012628).
- net/mlx5e: TX, Error completion is for last WQE in batch
  (bnc#1012628).
- cifs: fail i/o on soft mounts if sessionsetup errors out
  (bnc#1012628).
- cifs: fix mode bits from dir listing when mounted with
  modefromsid (bnc#1012628).
- x86/apic/msi: Plug non-maskable MSI affinity race (bnc#1012628).
- clocksource: Prevent double add_timer_on() for watchdog_timer
  (bnc#1012628).
- perf/core: Fix mlock accounting in perf_mmap() (bnc#1012628).
- perf/cgroups: Install cgroup events to correct cpuctx
  (bnc#1012628).
- drm/dp_mst: Remove VCPI while disabling topology mgr
  (bnc#1012628).
- io_uring: enable option to only trigger eventfd for async
  completions (bnc#1012628).
- io_uring: prevent potential eventfd recursion on poll
  (bnc#1012628).
- KVM: x86: Protect exit_reason from being used in Spectre-v1/L1TF
  attacks (bnc#1012628).
- KVM: nVMX: vmread should not set rflags to specify success in
  case of #PF (bnc#1012628).
- KVM: Use vcpu-specific gva->hva translation when querying host
  page size (bnc#1012628).
- KVM: Play nice with read-only memslots when querying host page
  size (bnc#1012628).
- rxrpc: Fix service call disconnection (bnc#1012628).
- IB/core: Fix build failure without hugepages (bnc#1012628).
- crypto: atmel-{aes,tdes} - Do not save IV for ECB mode
  (bnc#1012628).
- crypto: atmel-aes - Fix saving of IV for CTR mode (bnc#1012628).
- crypto: atmel-aes - Fix CTR counter overflow when multiple
  fragments (bnc#1012628).
- crypto: atmel-tdes - Map driver data flags to Mode Register
  (bnc#1012628).
- regulator fix for "regulator: core: Add regulator_is_equal()
  helper" (bnc#1012628).
- powerpc/kuap: Fix set direction in allow/prevent_user_access()
  (bnc#1012628).
- compat: ARM64: always include asm-generic/compat.h
  (bnc#1012628).
- Update config files.
- commit ffbbfe8
* Tue Feb 11 2020 afaerber@suse.com
- config: armv7hl: Update to 5.6-rc1
- commit b09045a
* Tue Feb 11 2020 afaerber@suse.com
- config: armv6hl: Update to 5.6-rc1
- commit e68a306
* Tue Feb 11 2020 afaerber@suse.com
- config: arm64: Update to 5.6-rc1
- commit 0ae2ac2
* Tue Feb 11 2020 tiwai@suse.de
- cgroup: init_tasks shouldn't be linked to the root cgroup
  (bsc#1163370).
- commit 00b4c73
* Mon Feb 10 2020 tiwai@suse.de
- ipmi_si: Avoid spurious errors for optional IRQs (bsc#1161943).
- commit 481e5b9
* Mon Feb 10 2020 tiwai@suse.de
- media: go7007: Fix URB type for interrupt handling
  (bsc#1162583).
- commit 23d5616
* Mon Feb 10 2020 tiwai@suse.de
- iwlwifi: mvm: Do not require PHY_SKU NVM section for 3168
  devices (bsc#1163213).
- commit f4b8e5e
* Mon Feb 10 2020 mkubecek@suse.cz
- Update to 5.6-rc1
- eliminated 95 patches (70 stable, 25 other)
- disable ARM architectures (need config update)
- refresh
  - patches.rpmify/Add-ksym-provides-tool.patch
  - patches.suse/acpi_thermal_passive_blacklist.patch
- new config options :
  - General setup
  - TIME_NS=y
  - BOOT_CONFIG=y
  - Firmware Drivers
  - EFI_DISABLE_PCI_DMA=n
  - Networking core
  - INET_ESPINTCP=y
  - MPTCP=y
  - MPTCP_IPV6=y
  - MPTCP_HMAC_TEST=n
  - NET_DSA_TAG_AR9331=m
  - NET_SCH_FQ_PIE=m
  - NET_SCH_ETS=m
  - VSOCKETS_LOOPBACK=m
  - ETHTOOL_NETLINK=y
  - WIREGUARD=m
  - WIREGUARD_DEBUG=n
  - File systems
  - ZONEFS_FS=m
  - VBOXSF_FS=m
  - NFS_DISABLE_UDP_SUPPORT=n
  - NFSD_V4_2_INTER_SSC=y
  - Security options
  - SECURITY_SELINUX_SIDTAB_HASH_BITS=9
  - SECURITY_SELINUX_SID2STR_CACHE_SIZE=256
  - TEE=m
  - AMDTEE=m
  - Kernel hacking
  - PTDUMP_DEBUGFS=n
  - BOOTTIME_TRACING=y
  - SYNTH_EVENT_GEN_TEST=n
  - KPROBE_EVENT_GEN_TEST=n
  - Networking drivers
  - NET_DSA_AR9331=m
  - NET_DSA_VITESSE_VSC73XX_SPI=m
  - NET_DSA_VITESSE_VSC73XX_PLATFORM=m
  - PHY_INTEL_EMMC=m
  - Hardware Monitoring support
  - SENSORS_ADM1177=m
  - SENSORS_DRIVETEMP=m
  - SENSORS_MAX31730=m
  - SENSORS_MAX20730=m
  - SENSORS_XDPE122=m
  - Sound
  - SND_CTL_VALIDATION=n
  - SND_SOC_INTEL_USER_FRIENDLY_LONG_NAMES=n
  - SND_SOC_INTEL_BDW_RT5650_MACH=m
  - SND_SOC_INTEL_SOF_DA7219_MAX98373_MACH=m
  - SND_SOC_RT1308_SDW=n
  - SND_SOC_RT700_SDW=n
  - SND_SOC_RT711_SDW=n
  - SND_SOC_RT715_SDW=n
  - SND_SOC_WSA881X=n
  - SND_SOC_MT6660=n
  - Graphics
  - DRM_PANEL_BOE_HIMAX8279D=n
  - DRM_PANEL_LEADTEK_LTK500HD1829=n
  - DRM_PANEL_SONY_ACX424AKP=n
  - DRM_PANEL_XINPENG_XPP055C272=n
  - DRM_LVDS_CODEC=m
  - DRM_ANALOGIX_ANX6345=n
  - Industrial I/O support
  - BMA400=n
  - AD7091R5=n
  - LTC2496=n
  - DLHL60D=n
  - PING=n
  - USB
  - USB4_NET=m
  - USB4=m
  - Misc drivers
  - SERIAL_8250_16550A_VARIANTS=n
  - PINCTRL_LYNXPOINT=m
  - INTEL_IDXD=m
  - PLX_DMA=m
  - QCOM_CPR=m
  - REGULATOR_MP8859=m
  - MFD_ROHM_BD71828=n
  - MEDIA_CEC_RC=y
  - NVMEM_SPMI_SDAM=m
  - DMABUF_HEAPS=n
  - RESET_BRCMSTB_RESCAL=n
  - INTEL_IOMMU_SCALABLE_MODE_DEFAULT_ON=n
  - GPIO_SIFIVE=n
  - x86
  - INTEL_UNCORE_FREQ_CONTROL=m
  - i386
  - PCIE_INTEL_GW=n
  - CPU_FREQ_THERMAL=y
  - CPU_IDLE_THERMAL=y
  - MICROCHIP_PIT64B=y
  - RESET_INTEL_GW=n
  - powerpc
  - STRICT_KERNEL_RWX=y
  - CPU_FREQ_THERMAL=y
  - MICROCHIP_PIT64B=y
  - RESET_INTEL_GW=n
  - DEBUG_RODATA_TEST=n
  - QUICC_ENGINE=y
  - QE_GPIO=y
  - FSL_PQ_MDIO=m
  - FSL_XGMAC_MDIO=m
  - GIANFAR=m
  - SERIAL_QE=m
  - PTP_1588_CLOCK_QORIQ=m
  - USB_FHCI_HCD=m
  - FHCI_DEBUG=n
  - s390x
  - ZLIB_DFLTCC=y
  - KPROBE_EVENTS_ON_NOTRACE=n
- commit 00fe0a9
* Fri Feb  7 2020 ykaukab@suse.de
- config.conf: enable armv6 and armv7 configs
- commit d355d69
* Thu Feb  6 2020 chrubis@suse.cz
- rpm/kernel-binary.spec.in: Replace Novell with SUSE
- commit 8719d69
* Wed Feb  5 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference (in mainline now) and move to "almost mainline" section:
  patches.suse/btrfs-do-not-zero-f_bavail-if-we-have-available-spac.patch
- commit d386a7a
* Wed Feb  5 2020 jslaby@suse.cz
- Linux 5.5.2 (bnc#1012628).
- vfs: fix do_last() regression (bnc#1012628).
- cifs: fix soft mounts hanging in the reconnect code
  (bnc#1012628).
- x86/resctrl: Fix a deadlock due to inaccurate reference
  (bnc#1012628).
- x86/resctrl: Fix use-after-free when deleting resource groups
  (bnc#1012628).
- x86/resctrl: Fix use-after-free due to inaccurate refcount of
  rdtgroup (bnc#1012628).
- KVM: PPC: Book3S PR: Fix -Werror=return-type build failure
  (bnc#1012628).
- gfs2: Another gfs2_find_jhead fix (bnc#1012628).
- lib/test_bitmap: correct test data offsets for 32-bit
  (bnc#1012628).
- perf c2c: Fix return type for histogram sorting comparision
  functions (bnc#1012628).
- PM / devfreq: Add new name attribute for sysfs (bnc#1012628).
- tools lib: Fix builds when glibc contains strlcpy()
  (bnc#1012628).
- arm64: kbuild: remove compressed images on 'make ARCH=arm64
  (dist)clean' (bnc#1012628).
- mm/mempolicy.c: fix out of bounds write in mpol_parse_str()
  (bnc#1012628).
- reiserfs: Fix memory leak of journal device string
  (bnc#1012628).
- media: digitv: don't continue if remote control state can't
  be read (bnc#1012628).
- media: af9005: uninitialized variable printked (bnc#1012628).
- media: vp7045: do not read uninitialized values if usb transfer
  fails (bnc#1012628).
- media: gspca: zero usb_buf (bnc#1012628).
- media: dvb-usb/dvb-usb-urb.c: initialize actlen to 0
  (bnc#1012628).
- tomoyo: Use atomic_t for statistics counter (bnc#1012628).
- ttyprintk: fix a potential deadlock in interrupt context issue
  (bnc#1012628).
- Bluetooth: Fix race condition in hci_release_sock()
  (bnc#1012628).
- cgroup: Prevent double killing of css when enabling threaded
  cgroup (bnc#1012628).
- commit c2619d7
* Tue Feb  4 2020 duwe@suse.de
- rpm/modules.fips: add keywrap (bsc#1160561)
- commit 719d9e1
* Tue Feb  4 2020 jslaby@suse.cz
- btrfs: do not zero f_bavail if we have available space
  (bnc#1162471).
- commit efe8ca5
* Mon Feb  3 2020 dsterba@suse.com
- btrfs: do not zero f_bavail if we have available space (bsc#1162471)
- commit edaa5de
* Mon Feb  3 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into "almost mainline" section:
  patches.suse/0001-x86-kvm-Be-careful-not-to-clear-KVM_VCPU_FLUSH_TLB-b.patch
  patches.suse/0002-x86-kvm-Introduce-kvm_-un-map_gfn.patch
  patches.suse/0003-x86-kvm-Cache-gfn-to-pfn-translation.patch
  patches.suse/0004-x86-KVM-Make-sure-KVM_VCPU_FLUSH_TLB-flag-is-not-mis.patch
  patches.suse/0005-x86-KVM-Clean-up-host-s-steal-time-structure.patch
  patches.suse/pci-brcmstb-add-broadcom-stb-pcie-host-controller-driver.patch
  patches.suse/pci-brcmstb-add-msi-capability.patch
- move into "almost mainline" section
  patches.suse/ASoC-SOF-Introduce-state-machine-for-FW-boot.patch
- commit 9b0f74c
* Sat Feb  1 2020 jslaby@suse.cz
- Linux 5.5.1 (bnc#1012628).
- power/supply: ingenic-battery: Don't change scale if there's
  only one (bnc#1012628).
- Revert "um: Enable CONFIG_CONSTRUCTORS" (bnc#1012628).
- KVM: arm64: Write arch.mdcr_el2 changes since last vcpu_load
  on VHE (bnc#1012628).
- crypto: pcrypt - Fix user-after-free on module unload
  (bnc#1012628).
- crypto: caam - do not reset pointer size from MCFGR register
  (bnc#1012628).
- crypto: vmx - reject xts inputs that are too short
  (bnc#1012628).
- crypto: af_alg - Use bh_lock_sock in sk_destruct (bnc#1012628).
- rsi: fix non-atomic allocation in completion handler
  (bnc#1012628).
- rsi: fix memory leak on failed URB submission (bnc#1012628).
- rsi: fix use-after-free on probe errors (bnc#1012628).
- rsi: fix use-after-free on failed probe and unbind
  (bnc#1012628).
- rxrpc: Fix use-after-free in rxrpc_receive_data() (bnc#1012628).
- net: include struct nhmsg size in nh nlmsg size (bnc#1012628).
- mlxsw: minimal: Fix an error handling path in
  'mlxsw_m_port_create()' (bnc#1012628).
- udp: segment looped gso packets correctly (bnc#1012628).
- net: socionext: fix xdp_result initialization in
  netsec_process_rx (bnc#1012628).
- net: socionext: fix possible user-after-free in
  netsec_process_rx (bnc#1012628).
- net_sched: walk through all child classes in tc_bind_tclass()
  (bnc#1012628).
- net_sched: fix ops->bind_class() implementations (bnc#1012628).
- net_sched: ematch: reject invalid TCF_EM_SIMPLE (bnc#1012628).
- mvneta driver disallow XDP program on hardware buffer management
  (bnc#1012628).
- zd1211rw: fix storage endpoint lookup (bnc#1012628).
- rtl8xxxu: fix interface sanity check (bnc#1012628).
- brcmfmac: fix interface sanity check (bnc#1012628).
- ath9k: fix storage endpoint lookup (bnc#1012628).
- cifs: Fix memory allocation in __smb2_handle_cancelled_cmd()
  (bnc#1012628).
- cifs: set correct max-buffer-size for smb2_ioctl_init()
  (bnc#1012628).
- CIFS: Fix task struct use-after-free on reconnect (bnc#1012628).
- crypto: chelsio - fix writing tfm flags to wrong place
  (bnc#1012628).
- driver core: Fix test_async_driver_probe if NUMA is disabled
  (bnc#1012628).
- iio: st_gyro: Correct data for LSM9DS0 gyro (bnc#1012628).
- iio: adc: stm32-dfsdm: fix single conversion (bnc#1012628).
- mei: me: add jasper point DID (bnc#1012628).
- mei: me: add comet point (lake) H device ids (bnc#1012628).
- mei: hdcp: bind only with i915 on the same PCH (bnc#1012628).
- binder: fix log spam for existing debugfs file creation
  (bnc#1012628).
- component: do not dereference opaque pointer in debugfs
  (bnc#1012628).
- debugfs: Return -EPERM when locked down (bnc#1012628).
- serial: imx: fix a race condition in receive path (bnc#1012628).
- serial: 8250_bcm2835aux: Fix line mismatch on driver unbind
  (bnc#1012628).
- staging: vt6656: Fix false Tx excessive retries reporting
  (bnc#1012628).
- staging: vt6656: use NULLFUCTION stack on mac80211
  (bnc#1012628).
- staging: vt6656: correct packet types for CTS protect, mode
  (bnc#1012628).
- staging: wlan-ng: ensure error return is actually returned
  (bnc#1012628).
- staging: most: net: fix buffer overflow (bnc#1012628).
- usb: typec: fusb302: fix "op-sink-microwatt" default that was
  in mW (bnc#1012628).
- usb: typec: wcove: fix "op-sink-microwatt" default that was
  in mW (bnc#1012628).
- usb: dwc3: turn off VBUS when leaving host mode (bnc#1012628).
- USB: serial: ir-usb: fix IrLAP framing (bnc#1012628).
- USB: serial: ir-usb: fix link-speed handling (bnc#1012628).
- USB: serial: ir-usb: add missing endpoint sanity check
  (bnc#1012628).
- usb: host: xhci-tegra: set MODULE_FIRMWARE for tegra186
  (bnc#1012628).
- usb: dwc3: pci: add ID for the Intel Comet Lake -V variant
  (bnc#1012628).
- rsi_91x_usb: fix interface sanity check (bnc#1012628).
- orinoco_usb: fix interface sanity check (bnc#1012628).
- Bluetooth: btusb: fix non-atomic allocation in completion
  handler (bnc#1012628).
- commit d3e7b7d
* Fri Jan 31 2020 yousaf.kaukab@suse.com
- config: armv7lpae: Update to 5.5
- commit 74459b2
* Fri Jan 31 2020 yousaf.kaukab@suse.com
- config: armv7hl: Update to 5.5
- commit ae8d01e
* Fri Jan 31 2020 yousaf.kaukab@suse.com
- config: armv6hl: Update to 5.5
- commit edbc4d9
* Fri Jan 31 2020 jroedel@suse.de
- x86/KVM: Clean up host's steal time structure (bcs#1161154,
  CVE-2019-3016).
- x86/KVM: Make sure KVM_VCPU_FLUSH_TLB flag is not missed
  (bcs#1161154, CVE-2019-3016).
- x86/kvm: Cache gfn to pfn translation (bcs#1161154,
  CVE-2019-3016).
- x86/kvm: Introduce kvm_(un)map_gfn() (bcs#1161154,
  CVE-2019-3016).
- x86/kvm: Be careful not to clear KVM_VCPU_FLUSH_TLB bit
  (bcs#1161154, CVE-2019-3016).
- commit 77cf1f3
* Fri Jan 31 2020 jroedel@suse.de
- x86/KVM: Clean up host's steal time structure (bcs#1161154,
  CVE-2019-3016).
- x86/KVM: Make sure KVM_VCPU_FLUSH_TLB flag is not missed
  (bcs#1161154, CVE-2019-3016).
- x86/kvm: Cache gfn to pfn translation (bcs#1161154,
  CVE-2019-3016).
- x86/kvm: Introduce kvm_(un)map_gfn() (bcs#1161154,
  CVE-2019-3016).
- x86/kvm: Be careful not to clear KVM_VCPU_FLUSH_TLB bit
  (bcs#1161154, CVE-2019-3016).
- commit 7e57096
* Thu Jan 30 2020 mkubecek@suse.cz
- update upstream references
- update upstream status (in mainline now):
  patches.suse/ALSA-hda-Apply-aligned-MMIO-access-only-conditionall.patch
  patches.suse/hwrng-iproc-rng200-add-support-for-bcm2711.patch
- commit f202425
* Thu Jan 30 2020 mkubecek@suse.cz
- update upstream reference
- update upstream status (in mainline now):
  patches.suse/ASoC-SOF-Introduce-state-machine-for-FW-boot.patch
- commit 86483c3
* Wed Jan 29 2020 tiwai@suse.de
- Update patch tag for upstreamed rtw88 patch
- commit 1507410
* Mon Jan 27 2020 tiwai@suse.de
- ASoC: SOF: core: release resources on errors in probe_continue
  (bsc#1161246).
- ASoC: SOF: core: free trace on errors (bsc#1161246).
- ASoC: SOF: Introduce state machine for FW boot (bsc#1161246).
- commit ef0a514
* Mon Jan 27 2020 jeyu@suse.de
- rpm/kabi.pl: support new (>=5.4) Module.symvers format (new symbol namespace field)
- commit eecbd97
* Mon Jan 27 2020 mkubecek@suse.cz
- Update to 5.5 final
- refresh configs
- commit 002fd1a
* Fri Jan 24 2020 mkubecek@suse.cz
- config: refresh
  Only update headers.
- commit 7193c66
* Thu Jan 23 2020 tiwai@suse.de
- drm/i915/gt: Detect if we miss WaIdleLiteRestore (bsc#1161720).
- commit 170524c
* Thu Jan 23 2020 jslaby@suse.cz
- Linux 5.4.14 (bnc#1012628).
- scsi: lpfc: use hdwq assigned cpu for allocation (bnc#1012628).
- perf script: Fix --reltime with --time (bnc#1012628).
- hwmon: (pmbus/ibm-cffps) Fix LED blink behavior (bnc#1012628).
- hwmon: (pmbus/ibm-cffps) Switch LEDs to blocking brightness call
  (bnc#1012628).
- regulator: ab8500: Remove SYSCLKREQ from enum
  ab8505_regulator_id (bnc#1012628).
- clk: imx7ulp: Correct DDR clock mux options (bnc#1012628).
- clk: imx7ulp: Correct system clock source option #7
  (bnc#1012628).
- clk: sprd: Use IS_ERR() to validate the return value of
  syscon_regmap_lookup_by_phandle() (bnc#1012628).
- perf script: Allow --time with --reltime (bnc#1012628).
- perf probe: Fix wrong address verification (bnc#1012628).
- rtw88: fix potential read outside array boundary (bnc#1012628).
- scsi: lpfc: Fix a kernel warning triggered by
  lpfc_get_sgl_per_hdwq() (bnc#1012628).
- scsi: lpfc: Fix hdwq sgl locks and irq handling (bnc#1012628).
- scsi: lpfc: Fix list corruption detected in
  lpfc_put_sgl_per_hdwq (bnc#1012628).
- scsi: core: scsi_trace: Use get_unaligned_be*() (bnc#1012628).
- scsi: qla2xxx: fix rports not being mark as lost in sync fabric
  scan (bnc#1012628).
- scsi: qla2xxx: Fix qla2x00_request_irqs() for MSI (bnc#1012628).
- scsi: scsi_transport_sas: Fix memory leak when removing devices
  (bnc#1012628).
- scsi: hisi_sas: Return directly if init hardware failed
  (bnc#1012628).
- scsi: lpfc: fix: Coverity: lpfc_get_scsi_buf_s3(): Null pointer
  dereferences (bnc#1012628).
- scsi: target: core: Fix a pr_debug() argument (bnc#1012628).
- scsi: bnx2i: fix potential use after free (bnc#1012628).
- scsi: qla4xxx: fix double free bug (bnc#1012628).
- scsi: hisi_sas: Set the BIST init value before enabling BIST
  (bnc#1012628).
- scsi: hisi_sas: Don't create debugfs dump folder twice
  (bnc#1012628).
- scsi: esas2r: unlock on error in esas2r_nvram_read_direct()
  (bnc#1012628).
- reiserfs: fix handling of -EOPNOTSUPP in reiserfs_for_each_xattr
  (bnc#1012628).
- um: virtio_uml: Disallow modular build (bnc#1012628).
- um: Don't trace irqflags during shutdown (bnc#1012628).
- mtd: cfi_cmdset_0002: fix delayed error detection on HyperFlash
  (bnc#1012628).
- mtd: cfi_cmdset_0002: only check errors when ready in
  cfi_check_err_status() (bnc#1012628).
- mtd: devices: fix mchp23k256 read and write (bnc#1012628).
- Revert "arm64: dts: juno: add dma-ranges property"
  (bnc#1012628).
- ARM: dts: Fix sgx sysconfig register for omap4 (bnc#1012628).
- arm64: dts: juno: Fix UART frequency (bnc#1012628).
- ARM: dts: dra7: fix cpsw mdio fck clock (bnc#1012628).
- arm64: dts: allwinner: a64: Re-add PMU node (bnc#1012628).
- ARM: dts: imx6ul-kontron-n6310-s: Disable the snvs-poweroff
  driver (bnc#1012628).
- arm64: dts: qcom: sdm845-cheza: delete zap-shader (bnc#1012628).
- arm64: dts: imx8mm-evk: Assigned clocks for audio plls
  (bnc#1012628).
- arm64: dts: renesas: r8a774a1: Remove audio port node
  (bnc#1012628).
- arm64: dts: marvell: Fix CP110 NAND controller node multi-line
  comment alignment (bnc#1012628).
- tick/sched: Annotate lockless access to last_jiffies_update
  (bnc#1012628).
- cfg80211: check for set_wiphy_params (bnc#1012628).
- arm64: dts: marvell: Add AP806-dual missing CPU clocks
  (bnc#1012628).
- arm64: dts: renesas: r8a77970: Fix PWM3 (bnc#1012628).
- arm64: dts: meson-gxl-s905x-khadas-vim: fix gpio-keys-polled
  node (bnc#1012628).
- arm64: dts: meson: g12: fix audio fifo reg size (bnc#1012628).
- arm64: dts: meson: axg: fix audio fifo reg size (bnc#1012628).
- cw1200: Fix a signedness bug in cw1200_load_firmware()
  (bnc#1012628).
- arm64: dts: qcom: msm8998: Disable coresight by default
  (bnc#1012628).
- irqchip: Place CONFIG_SIFIVE_PLIC into the menu (bnc#1012628).
- tcp: refine rule to allow EPOLLOUT generation under mem pressure
  (bnc#1012628).
- dt-bindings: Add missing 'properties' keyword enclosing
  'snps,tso' (bnc#1012628).
- xen/blkfront: Adjust indentation in xlvbd_alloc_gendisk
  (bnc#1012628).
- devlink: Wait longer before warning about unset port type
  (bnc#1012628).
- net: stmmac: tc: Do not setup flower filtering if RSS is enabled
  (bnc#1012628).
- net: stmmac: selftests: Update status when disabling RSS
  (bnc#1012628).
- selftests: mlxsw: qos_mc_aware: Fix mausezahn invocation
  (bnc#1012628).
- net: stmmac: selftests: Mark as fail when received VLAN ID !=
  expected (bnc#1012628).
- net: stmmac: selftests: Make it work in Synopsys AXS101 boards
  (bnc#1012628).
- mlxsw: spectrum_qdisc: Include MC TCs in Qdisc counters
  (bnc#1012628).
- mlxsw: spectrum: Wipe xstats.backlog of down ports
  (bnc#1012628).
- mlxsw: spectrum: Do not modify cloned SKBs during xmit
  (bnc#1012628).
- sh_eth: check sh_eth_cpu_data::dual_port when dumping registers
  (bnc#1012628).
- drm/amdgpu: allow direct upload save restore list for raven2
  (bnc#1012628).
- i40e: prevent memory leak in i40e_setup_macvlans (bnc#1012628).
- net: dsa: bcm_sf2: Configure IMP port for 2Gb/sec (bnc#1012628).
- net: sched: act_ctinfo: fix memory leak (bnc#1012628).
- net: dsa: tag_gswip: fix typo in tagger name (bnc#1012628).
- net: dsa: sja1105: Don't error out on disabled ports with no
  phy-mode (bnc#1012628).
- net: systemport: Fixed queue mapping in internal ring map
  (bnc#1012628).
- net: ethernet: ave: Avoid lockdep warning (bnc#1012628).
- bnxt_en: Do not treat DSN (Digital Serial Number) read failure
  as fatal (bnc#1012628).
- bnxt_en: Fix ipv6 RFS filter matching logic (bnc#1012628).
- bnxt_en: Fix NTUPLE firmware command failures (bnc#1012628).
- tcp: fix marked lost packets not being retransmitted
  (bnc#1012628).
- r8152: add missing endpoint sanity check (bnc#1012628).
- ptp: free ptp device pin descriptors properly (bnc#1012628).
- net/wan/fsl_ucc_hdlc: fix out of bounds write on array utdm_info
  (bnc#1012628).
- net: usb: lan78xx: limit size of local TSO packets
  (bnc#1012628).
- net/sched: act_ife: initalize ife->metalist earlier
  (bnc#1012628).
- net: phy: dp83867: Set FORCE_LINK_GOOD to default after reset
  (bnc#1012628).
- net: hns: fix soft lockup when there is not enough memory
  (bnc#1012628).
- net: hns3: pad the short frame before sending to the hardware
  (bnc#1012628).
- net: dsa: tag_qca: fix doubled Tx statistics (bnc#1012628).
- net: avoid updating qdisc_xmit_lock_key in
  netdev_update_lockdep_key() (bnc#1012628).
- hv_netvsc: Fix memory leak when removing rndis device
  (bnc#1012628).
- macvlan: use skb_reset_mac_header() in macvlan_queue_xmit()
  (bnc#1012628).
- batman-adv: Fix DAT candidate selection on little endian systems
  (bnc#1012628).
- bpftool: Fix printing incorrect pointer in btf_dump_ptr
  (bnc#1012628).
- net: bpf: Don't leak time wait and request sockets
  (bnc#1012628).
- NFC: pn533: fix bulk-message timeout (bnc#1012628).
- netfilter: nf_tables: fix flowtable list del corruption
  (bnc#1012628).
- netfilter: nf_tables: store transaction list locally while
  requesting module (bnc#1012628).
- netfilter: nf_tables: remove WARN and add NLA_STRING upper
  limits (bnc#1012628).
- netfilter: nft_tunnel: ERSPAN_VERSION must not be null
  (bnc#1012628).
- netfilter: nft_tunnel: fix null-attribute check (bnc#1012628).
- netfilter: nat: fix ICMP header corruption on ICMP errors
  (bnc#1012628).
- netfilter: arp_tables: init netns pointer in xt_tgdtor_param
  struct (bnc#1012628).
- netfilter: fix a use-after-free in mtype_destroy()
  (bnc#1012628).
- i2c: iop3xx: Fix memory leak in probe error path (bnc#1012628).
- bpf/sockmap: Read psock ingress_msg before sk_receive_queue
  (bnc#1012628).
- cfg80211: fix page refcount issue in A-MSDU decap (bnc#1012628).
- cfg80211: fix memory leak in cfg80211_cqm_rssi_update
  (bnc#1012628).
- cfg80211: fix memory leak in nl80211_probe_mesh_link
  (bnc#1012628).
- cfg80211: fix deadlocks in autodisconnect work (bnc#1012628).
- i2c: tegra: Properly disable runtime PM on driver's probe error
  (bnc#1012628).
- i2c: tegra: Fix suspending in active runtime PM state
  (bnc#1012628).
- bpf: Sockmap/tls, fix pop data with SK_DROP return code
  (bnc#1012628).
- bpf: Sockmap/tls, skmsg can have wrapped skmsg that needs
  extra chaining (bnc#1012628).
- bpf: Sockmap/tls, tls_sw can create a plaintext buf > encrypt
  buf (bnc#1012628).
- bpf: Sockmap/tls, msg_push_data may leave end mark in place
  (bnc#1012628).
- bpf: Sockmap, skmsg helper overestimates push, pull, and pop
  bounds (bnc#1012628).
- bpf: Sockmap/tls, push write_space updates through ulp updates
  (bnc#1012628).
- bpf: Sockmap, ensure sock lock held during tear down
  (bnc#1012628).
- bpf: Sockmap/tls, during free we may call tcp_bpf_unhash()
  in loop (bnc#1012628).
- bpf: Fix incorrect verifier simulation of ARSH under ALU32
  (bnc#1012628).
- drm/amd/display: Reorder detect_edp_sink_caps before link
  settings read (bnc#1012628).
- block: Fix the type of 'sts' in bsg_queue_rq() (bnc#1012628).
- net: fix kernel-doc warning in <linux/netdevice.h>
  (bnc#1012628).
- tipc: fix retrans failure due to wrong destination
  (bnc#1012628).
- tipc: fix potential hanging after b/rcast changing
  (bnc#1012628).
- reset: Fix {of,devm}_reset_control_array_get kerneldoc return
  types (bnc#1012628).
- net: stmmac: Enable 16KB buffer size (bnc#1012628).
- net: stmmac: 16KB buffer must be 16 byte aligned (bnc#1012628).
- ARM: dts: imx7: Fix Toradex Colibri iMX7S 256MB NAND flash
  support (bnc#1012628).
- ARM: dts: imx6q-icore-mipi: Use 1.5 version of i.Core MX6DL
  (bnc#1012628).
- ARM: dts: imx6sll-evk: Remove incorrect power supply assignment
  (bnc#1012628).
- ARM: dts: imx6sl-evk: Remove incorrect power supply assignment
  (bnc#1012628).
- ARM: dts: imx6sx-sdb: Remove incorrect power supply assignment
  (bnc#1012628).
- ARM: dts: imx6qdl-sabresd: Remove incorrect power supply
  assignment (bnc#1012628).
- mm: khugepaged: add trace status description for
  SCAN_PAGE_HAS_PRIVATE (bnc#1012628).
- mm/page-writeback.c: avoid potential division by zero in
  wb_min_max_ratio() (bnc#1012628).
- mm/memory_hotplug: don't free usage map when removing a re-added
  early section (bnc#1012628).
- Btrfs: always copy scrub arguments back to user space
  (bnc#1012628).
- btrfs: check rw_devices, not num_devices for balance
  (bnc#1012628).
- btrfs: fix memory leak in qgroup accounting (bnc#1012628).
- btrfs: relocation: fix reloc_root lifespan and access
  (bnc#1012628).
- btrfs: do not delete mismatched root refs (bnc#1012628).
- btrfs: fix invalid removal of root ref (bnc#1012628).
- btrfs: rework arguments of btrfs_unlink_subvol (bnc#1012628).
- mm, debug_pagealloc: don't rely on static keys too early
  (bnc#1012628).
- mm: memcg/slab: call flush_memcg_workqueue() only if memcg
  workqueue is valid (bnc#1012628).
- mm: memcg/slab: fix percpu slab vmstats flushing (bnc#1012628).
- mm/huge_memory.c: thp: fix conflict of above-47bit hint address
  and PMD alignment (bnc#1012628).
- mm/shmem.c: thp, shmem: fix conflict of above-47bit hint
  address and PMD alignment (bnc#1012628).
- perf report: Fix incorrectly added dimensions as switch perf
  data file (bnc#1012628).
- locking/lockdep: Fix buffer overrun problem in stack_trace[]
  (bnc#1012628).
- perf hists: Fix variable name's inconsistency in
  hists__for_each() macro (bnc#1012628).
- clk: samsung: exynos5420: Keep top G3D clocks enabled
  (bnc#1012628).
- s390/setup: Fix secure ipl message (bnc#1012628).
- efi/earlycon: Fix write-combine mapping on x86 (bnc#1012628).
- x86/resctrl: Fix potential memory leak (bnc#1012628).
- drm/i915: Add missing include file <linux/math64.h>
  (bnc#1012628).
- mtd: spi-nor: Fix selection of 4-byte addressing opcodes on
  Spansion (bnc#1012628).
- scsi: storvsc: Correctly set number of hardware queues for
  IDE disk (bnc#1012628).
- s390/zcrypt: Fix CCA cipher key gen with clear key value
  function (bnc#1012628).
- x86/efistub: Disable paging at mixed mode entry (bnc#1012628).
- perf/x86/intel/uncore: Fix missing marker for
  snr_uncore_imc_freerunning_events (bnc#1012628).
- locking/rwsem: Fix kernel crash when spinning on
  RWSEM_OWNER_UNKNOWN (bnc#1012628).
- x86/CPU/AMD: Ensure clearing of SME/SEV features is maintained
  (bnc#1012628).
- x86/resctrl: Fix an imbalance in domain_remove_cpu()
  (bnc#1012628).
- cpu/SMT: Fix x86 link error without CONFIG_SYSFS (bnc#1012628).
- usb: core: hub: Improved device recognition on remote wakeup
  (bnc#1012628).
- mtd: rawnand: gpmi: Restore nfc timing setup after
  suspend/resume (bnc#1012628).
- mtd: rawnand: gpmi: Fix suspend/resume problem (bnc#1012628).
- ptrace: reintroduce usage of subjective credentials in
  ptrace_has_cap() (bnc#1012628).
- scsi: mptfusion: Fix double fetch bug in ioctl (bnc#1012628).
- scsi: fnic: fix invalid stack access (bnc#1012628).
- staging: comedi: ni_routes: allow partial routing information
  (bnc#1012628).
- staging: comedi: ni_routes: fix null dereference in
  ni_find_route_source() (bnc#1012628).
- USB: serial: quatech2: handle unbound ports (bnc#1012628).
- USB: serial: keyspan: handle unbound ports (bnc#1012628).
- USB: serial: io_edgeport: add missing active-port sanity check
  (bnc#1012628).
- USB: serial: io_edgeport: handle unbound ports on URB completion
  (bnc#1012628).
- USB: serial: ch341: handle unbound port at reset_resume
  (bnc#1012628).
- USB: serial: suppress driver bind attributes (bnc#1012628).
- USB: serial: option: add support for Quectel RM500Q in QDL mode
  (bnc#1012628).
- USB: serial: opticon: fix control-message timeouts
  (bnc#1012628).
- USB: serial: option: Add support for Quectel RM500Q
  (bnc#1012628).
- USB: serial: simple: Add Motorola Solutions TETRA MTP3xxx and
  MTP85xx (bnc#1012628).
- iio: buffer: align the size of scan bytes to size of the
  largest element (bnc#1012628).
- iio: chemical: pms7003: fix unmet triggered buffer dependency
  (bnc#1012628).
- iio: light: vcnl4000: Fix scale for vcnl4040 (bnc#1012628).
- iio: imu: st_lsm6dsx: Fix selection of ST_LSM6DS3_ID
  (bnc#1012628).
- iio: adc: ad7124: Fix DT channel configuration (bnc#1012628).
- perf: Correctly handle failed perf_get_aux_event()
  (bnc#1012628).
- ARM: davinci: select CONFIG_RESET_CONTROLLER (bnc#1012628).
- ARM: dts: am571x-idk: Fix gpios property to have the correct
  gpio number (bnc#1012628).
- cpuidle: teo: Fix intervals[] array indexing bug (bnc#1012628).
- io_uring: only allow submit from owning task (bnc#1012628).
- fuse: fix fuse_send_readpages() in the syncronous read case
  (bnc#1012628).
- block: fix an integer overflow in logical block size
  (bnc#1012628).
- clk: sunxi-ng: r40: Allow setting parent rate for external
  clock outputs (bnc#1012628).
- Fix built-in early-load Intel microcode alignment (bnc#1012628).
- arm64: dts: agilex/stratix10: fix pmu interrupt numbers
  (bnc#1012628).
- arm64: dts: allwinner: a64: olinuxino: Fix eMMC supply regulator
  (bnc#1012628).
- arm64: dts: allwinner: a64: olinuxino: Fix SDIO supply regulator
  (bnc#1012628).
- ALSA: usb-audio: fix sync-ep altsetting sanity check
  (bnc#1012628).
- ALSA: firewire-tascam: fix corruption due to spin lock without
  restoration in SoftIRQ context (bnc#1012628).
- ALSA: seq: Fix racy access for queue timer in proc read
  (bnc#1012628).
- ALSA: dice: fix fallback from protocol extension into limited
  functionality (bnc#1012628).
- ASoC: Intel: bytcht_es8316: Fix Irbis NB41 netbook quirk
  (bnc#1012628).
- ARM: dts: imx6q-dhcom: Fix SGTL5000 VDDIO regulator connection
  (bnc#1012628).
- ARM: dts: imx7ulp: fix reg of cpu node (bnc#1012628).
- ARM: OMAP2+: Fix ti_sysc_find_one_clockdomain to check for
  to_clk_hw_omap (bnc#1012628).
- ASoC: msm8916-wcd-analog: Fix MIC BIAS Internal1 (bnc#1012628).
- ASoC: msm8916-wcd-analog: Fix selected events for MIC BIAS
  External1 (bnc#1012628).
- ASoC: stm32: dfsdm: fix 16 bits record (bnc#1012628).
- ASoC: stm32: sai: fix possible circular locking (bnc#1012628).
- ASoC: msm8916-wcd-digital: Reset RX interpolation path after
  use (bnc#1012628).
- arm64: dts: imx8mq-librem5-devkit: use correct interrupt for
  the magnetometer (bnc#1012628).
- Revert "gpio: thunderx: Switch to GPIOLIB_IRQCHIP"
  (bnc#1012628).
- clk: Don't try to enable critical clocks if prepare failed
  (bnc#1012628).
- bus: ti-sysc: Fix iterating over clocks (bnc#1012628).
- arm64: dts: imx8mm: Change SDMA1 ahb clock for imx8mm
  (bnc#1012628).
- arm64: dts: ls1028a: fix endian setting for dcfg (bnc#1012628).
- ARM: dts: imx6q-dhcom: fix rtc compatible (bnc#1012628).
- dt-bindings: reset: meson8b: fix duplicate reset IDs
  (bnc#1012628).
- soc: amlogic: meson-ee-pwrc: propagate errors from
  pm_genpd_init() (bnc#1012628).
- soc: amlogic: meson-ee-pwrc: propagate PD provider registration
  errors (bnc#1012628).
- clk: qcom: gcc-sdm845: Add missing flag to votable GDSCs
  (bnc#1012628).
- ARM: dts: meson8: fix the size of the PMU registers
  (bnc#1012628).
- commit fc4ea7a
* Wed Jan 22 2020 afaerber@suse.com
- config: arm64: Update to 5.5-rc7
- commit 4e17086
* Tue Jan 21 2020 tiwai@suse.de
- Update config files: Update config files: adjust Intel ASoC audio items (bsc#1161463)
  Adjust the Kconfigs for Intel ASoC SOF/SST drivers more appropriately.
  Disable unrecommended items:
  CONFIG_SND_SOC_INTEL_SKYLAKE_HDAUDIO_CODEC=n
  CONFIG_SND_SST_ATOM_HIFI2_PLATFORM_PCI=n
  CONFIG_SND_SOC_SOF_MERRIFIELD_SUPPORT=n
  CONFIG_SND_SOC_INTEL_BYT_CHT_NOCODEC_MACH=n
  Enable the other ones:
  CONFIG_SND_SOC_INTEL_SKL_RT286_MACH=m
  CONFIG_SND_SOC_INTEL_SKL_NAU88L25_SSM4567_MACH=m
  CONFIG_SND_SOC_INTEL_SKL_NAU88L25_MAX98357A_MACH=m
  CONFIG_SND_SOC_INTEL_BXT_DA7219_MAX98357A_MACH=m
  CONFIG_SND_SOC_INTEL_BXT_RT298_MACH=m
  CONFIG_SND_SOC_INTEL_GLK_DA7219_MAX98357A_MACH=m
  CONFIG_SND_SOC_INTEL_SOF_CML_RT1011_RT5682_MACH=m
- commit 1da7ef3
* Tue Jan 21 2020 tiwai@suse.de
- Update config files: adjust Intel ASoC audio items (bsc#1161463)
  Adjust the Kconfigs for Intel ASoC SOF/SST drivers more appropriately.
  Disable unrecommended items:
  CONFIG_SND_SOC_INTEL_SKYLAKE_HDAUDIO_CODEC=n
  CONFIG_SND_SST_ATOM_HIFI2_PLATFORM_PCI=n
  CONFIG_SND_SOC_SOF_MERRIFIELD_SUPPORT=n
  CONFIG_SND_SOC_INTEL_BYT_CHT_NOCODEC_MACH=n
  Enable the other ones:
  CONFIG_SND_SOC_INTEL_SKL_RT286_MACH=m
  CONFIG_SND_SOC_INTEL_SKL_NAU88L25_SSM4567_MACH=m
  CONFIG_SND_SOC_INTEL_SKL_NAU88L25_MAX98357A_MACH=m
  CONFIG_SND_SOC_INTEL_BXT_DA7219_MAX98357A_MACH=m
  CONFIG_SND_SOC_INTEL_BXT_RT298_MACH=m
- commit 69c6063
* Mon Jan 20 2020 msuchanek@suse.de
- kernel-binary.spec.in: do not recommend firmware for kvmsmall and azure
  flavor (boo#1161360).
- commit dbe7b27
* Mon Jan 20 2020 msuchanek@suse.de
- config/x86_64/kvmsmall: Enable UINPUT (boo#1161305).
- commit f406189
* Mon Jan 20 2020 tiwai@suse.de
- ALSA: hda: Apply aligned MMIO access only conditionally
  (bsc#1161152).
- commit e1a66d4
* Mon Jan 20 2020 mkubecek@suse.cz
- Update to 5.5-rc7
- commit 3dbb847
* Sat Jan 18 2020 jslaby@suse.cz
- drm/amdgpu: remove redundant variable r and redundant return
  statement (git-fixes).
- Revert "rsi: fix potential null dereference in rsi_probe()"
  (git-fixes).
- bpf: Force .BTF section start to zero when dumping from vmlinux
  (git-fixes).
- commit 9294bb2
* Sat Jan 18 2020 jslaby@suse.cz
- Linux 5.4.13 (bnc#1012628).
- rtc: mt6397: fix alarm register overwrite (bnc#1012628).
- phy: mapphone-mdm6600: Fix uninitialized status value regression
  (bnc#1012628).
- RDMA/bnxt_re: Avoid freeing MR resources if dereg fails
  (bnc#1012628).
- RDMA/bnxt_re: Fix Send Work Entry state check while polling
  completions (bnc#1012628).
- IB/hfi1: Don't cancel unused work item (bnc#1012628).
- mtd: rawnand: stm32_fmc2: avoid to lock the CPU bus
  (bnc#1012628).
- i2c: bcm2835: Store pointer to bus clock (bnc#1012628).
- ASoC: SOF: imx8: fix memory allocation failure check on
  priv->pd_dev (bnc#1012628).
- ASoC: soc-core: Set dpcm_playback / dpcm_capture (bnc#1012628).
- ASoC: stm32: spdifrx: fix inconsistent lock state (bnc#1012628).
- ASoC: stm32: spdifrx: fix race condition in irq handler
  (bnc#1012628).
- ASoC: stm32: spdifrx: fix input pin state management
  (bnc#1012628).
- pinctrl: lochnagar: select GPIOLIB (bnc#1012628).
- netfilter: nft_flow_offload: fix underflow in flowtable
  reference counter (bnc#1012628).
- ASoC: SOF: imx8: Fix dsp_box offset (bnc#1012628).
- mtd: onenand: omap2: Pass correct flags for prep_dma_memcpy
  (bnc#1012628).
- gpio: zynq: Fix for bug in zynq_gpio_restore_context API
  (bnc#1012628).
- pinctrl: meson: Fix wrong shift value when get drive-strength
  (bnc#1012628).
- selftests: loopback.sh: skip this test if the driver does not
  support (bnc#1012628).
- iommu/vt-d: Unlink device if failed to add to group
  (bnc#1012628).
- iommu: Remove device link to group on failure (bnc#1012628).
- bpf: cgroup: prevent out-of-order release of cgroup bpf
  (bnc#1012628).
- fs: move guard_bio_eod() after bio_set_op_attrs (bnc#1012628).
- scsi: mpt3sas: Fix double free in attach error handling
  (bnc#1012628).
- gpio: Fix error message on out-of-range GPIO in lookup table
  (bnc#1012628).
- PM / devfreq: tegra: Add COMMON_CLK dependency (bnc#1012628).
- PCI: amlogic: Fix probed clock names (bnc#1012628).
- drm/tegra: Fix ordering of cleanup code (bnc#1012628).
- hsr: add hsr root debugfs directory (bnc#1012628).
- hsr: rename debugfs file when interface name is changed
  (bnc#1012628).
- hsr: reset network header when supervision frame is created
  (bnc#1012628).
- s390/qeth: fix qdio teardown after early init error
  (bnc#1012628).
- s390/qeth: fix false reporting of VNIC CHAR config failure
  (bnc#1012628).
- s390/qeth: Fix vnicc_is_in_use if rx_bcast not set
  (bnc#1012628).
- s390/qeth: vnicc Fix init to default (bnc#1012628).
- s390/qeth: fix initialization on old HW (bnc#1012628).
- cifs: Adjust indentation in smb2_open_file (bnc#1012628).
- scsi: smartpqi: Update attribute name to `driver_version`
  (bnc#1012628).
- MAINTAINERS: Append missed file to the database (bnc#1012628).
- ath9k: use iowrite32 over __raw_writel (bnc#1012628).
- can: j1939: fix address claim code example (bnc#1012628).
- dt-bindings: reset: Fix brcmstb-reset example (bnc#1012628).
- reset: brcmstb: Remove resource checks (bnc#1012628).
- afs: Fix missing cell comparison in afs_test_super()
  (bnc#1012628).
- perf vendor events s390: Remove name from L1D_RO_EXCL_WRITES
  description (bnc#1012628).
- syscalls/x86: Wire up COMPAT_SYSCALL_DEFINE0 (bnc#1012628).
- syscalls/x86: Use COMPAT_SYSCALL_DEFINE0 for IA32 (rt_)sigreturn
  (bnc#1012628).
- syscalls/x86: Use the correct function type for sys_ni_syscall
  (bnc#1012628).
- syscalls/x86: Fix function types in COND_SYSCALL (bnc#1012628).
- hsr: fix slab-out-of-bounds Read in hsr_debugfs_rename()
  (bnc#1012628).
- btrfs: simplify inode locking for RWF_NOWAIT (bnc#1012628).
- netfilter: nf_tables_offload: release flow_rule on error from
  commit path (bnc#1012628).
- netfilter: nft_meta: use 64-bit time arithmetic (bnc#1012628).
- ASoC: dt-bindings: mt8183: add missing update (bnc#1012628).
- ASoC: simple_card_utils.h: Add missing include (bnc#1012628).
- ASoC: fsl_esai: Add spin lock to protect reset, stop and start
  (bnc#1012628).
- ASoC: SOF: Intel: Broadwell: clarify mutual exclusion with
  legacy driver (bnc#1012628).
- ASoC: core: Fix compile warning with CONFIG_DEBUG_FS=n
  (bnc#1012628).
- ASoC: rsnd: fix DALIGN register for SSIU (bnc#1012628).
- RDMA/hns: Prevent undefined behavior in
  hns_roce_set_user_sq_size() (bnc#1012628).
- RDMA/hns: remove a redundant le16_to_cpu (bnc#1012628).
- RDMA/hns: Modify return value of restrack functions
  (bnc#1012628).
- RDMA/counter: Prevent QP counter manual binding in auto mode
  (bnc#1012628).
- RDMA/siw: Fix port number endianness in a debug message
  (bnc#1012628).
- RDMA/hns: Fix build error again (bnc#1012628).
- RDMA/hns: Release qp resources when failed to destroy qp
  (bnc#1012628).
- xprtrdma: Add unique trace points for posting Local Invalidate
  WRs (bnc#1012628).
- xprtrdma: Connection becomes unstable after a reconnect
  (bnc#1012628).
- xprtrdma: Fix MR list handling (bnc#1012628).
- xprtrdma: Close window between waking RPC senders and posting
  Receives (bnc#1012628).
- RDMA/hns: Fix to support 64K page for srq (bnc#1012628).
- RDMA/hns: Bugfix for qpc/cqc timer configuration (bnc#1012628).
- rdma: Remove nes ABI header (bnc#1012628).
- RDMA/mlx5: Return proper error value (bnc#1012628).
- RDMA/srpt: Report the SCSI residual to the initiator
  (bnc#1012628).
- uaccess: Add non-pagefault user-space write function
  (bnc#1012628).
- bpf: Make use of probe_user_write in probe write helper
  (bnc#1012628).
- bpf: skmsg, fix potential psock NULL pointer dereference
  (bnc#1012628).
- bpf: Support pre-2.25-binutils objcopy for vmlinux BTF
  (bnc#1012628).
- libbpf: Fix Makefile' libbpf symbol mismatch diagnostic
  (bnc#1012628).
- afs: Fix use-after-loss-of-ref (bnc#1012628).
- afs: Fix afs_lookup() to not clobber the version on a new dentry
  (bnc#1012628).
- keys: Fix request_key() cache (bnc#1012628).
- scsi: enclosure: Fix stale device oops with hot replug
  (bnc#1012628).
- scsi: sd: Clear sdkp->protection_type if disk is reformatted
  without PI (bnc#1012628).
- platform/mellanox: fix potential deadlock in the tmfifo driver
  (bnc#1012628).
- platform/x86: asus-wmi: Fix keyboard brightness cannot be set
  to 0 (bnc#1012628).
- platform/x86: GPD pocket fan: Use default values when wrong
  modparams are given (bnc#1012628).
- asm-generic/nds32: don't redefine cacheflush primitives
  (bnc#1012628).
- Documentation/ABI: Fix documentation inconsistency for mlxreg-io
  sysfs interfaces (bnc#1012628).
- Documentation/ABI: Add missed attribute for mlxreg-io sysfs
  interfaces (bnc#1012628).
- xprtrdma: Fix create_qp crash on device unload (bnc#1012628).
- xprtrdma: Fix completion wait during device removal
  (bnc#1012628).
- xprtrdma: Fix oops in Receive handler after device removal
  (bnc#1012628).
- dm: add dm-clone to the documentation index (bnc#1012628).
- scsi: ufs: Give an unique ID to each ufs-bsg (bnc#1012628).
- crypto: cavium/nitrox - fix firmware assignment to AE cores
  (bnc#1012628).
- crypto: hisilicon - select NEED_SG_DMA_LENGTH in qm Kconfig
  (bnc#1012628).
- crypto: arm64/aes-neonbs - add return value of
  skcipher_walk_done() in __xts_crypt() (bnc#1012628).
- crypto: virtio - implement missing support for output IVs
  (bnc#1012628).
- crypto: algif_skcipher - Use chunksize instead of blocksize
  (bnc#1012628).
- crypto: geode-aes - convert to skcipher API and make thread-safe
  (bnc#1012628).
- NFSv2: Fix a typo in encode_sattr() (bnc#1012628).
- nfsd: Fix cld_net->cn_tfm initialization (bnc#1012628).
- nfsd: v4 support requires CRYPTO_SHA256 (bnc#1012628).
- NFSv4.x: Handle bad/dead sessions correctly in
  nfs41_sequence_process() (bnc#1012628).
- NFSv4.x: Drop the slot if nfs4_delegreturn_prepare waits for
  layoutreturn (bnc#1012628).
- iio: imu: st_lsm6dsx: fix gyro gain definitions for LSM9DS1
  (bnc#1012628).
- iio: imu: adis16480: assign bias value only if operation
  succeeded (bnc#1012628).
- mei: fix modalias documentation (bnc#1012628).
- clk: meson: axg-audio: fix regmap last register (bnc#1012628).
- clk: samsung: exynos5420: Preserve CPU clocks configuration
  during suspend/resume (bnc#1012628).
- clk: Fix memory leak in clk_unregister() (bnc#1012628).
- dmaengine: dw: platform: Mark 'hclk' clock optional
  (bnc#1012628).
- clk: imx: pll14xx: Fix quick switch of S/K parameter
  (bnc#1012628).
- rsi: fix potential null dereference in rsi_probe()
  (bnc#1012628).
- affs: fix a memory leak in affs_remount (bnc#1012628).
- pinctl: ti: iodelay: fix error checking on
  pinctrl_count_index_with_args call (bnc#1012628).
- pinctrl: sh-pfc: Fix PINMUX_IPSR_PHYS() to set GPSR
  (bnc#1012628).
- pinctrl: sh-pfc: Do not use platform_get_irq() to count
  interrupts (bnc#1012628).
- pinctrl: lewisburg: Update pin list according to v1.1v6
  (bnc#1012628).
- PCI: pciehp: Do not disable interrupt twice on suspend
  (bnc#1012628).
- Revert "drm/virtio: switch virtio_gpu_wait_ioctl() to gem
  helper." (bnc#1012628).
- drm/amdgpu: cleanup creating BOs at fixed location (v2)
  (bnc#1012628).
- drm/amdgpu/discovery: reserve discovery data at the top of VRAM
  (bnc#1012628).
- scsi: sd: enable compat ioctls for sed-opal (bnc#1012628).
- arm64: dts: apq8096-db820c: Increase load on l21 for SDCARD
  (bnc#1012628).
- gfs2: add compat_ioctl support (bnc#1012628).
- af_unix: add compat_ioctl support (bnc#1012628).
- compat_ioctl: handle SIOCOUTQNSD (bnc#1012628).
- PCI: aardvark: Use LTSSM state to build link training flag
  (bnc#1012628).
- PCI: aardvark: Fix PCI_EXP_RTCTL register configuration
  (bnc#1012628).
- PCI: dwc: Fix find_next_bit() usage (bnc#1012628).
- PCI: Fix missing bridge dma_ranges resource list cleanup
  (bnc#1012628).
- PCI/PM: Clear PCIe PME Status even for legacy power management
  (bnc#1012628).
- tools: PCI: Fix fd leakage (bnc#1012628).
- PCI/PTM: Remove spurious "d" from granularity message
  (bnc#1012628).
- powerpc/powernv: Disable native PCIe port management
  (bnc#1012628).
- MIPS: PCI: remember nasid changed by set interrupt affinity
  (bnc#1012628).
- MIPS: Loongson: Fix return value of loongson_hwmon_init
  (bnc#1012628).
- MIPS: SGI-IP27: Fix crash, when CPUs are disabled via nr_cpus
  parameter (bnc#1012628).
- tty: serial: imx: use the sg count from dma_map_sg
  (bnc#1012628).
- tty: serial: pch_uart: correct usage of dma_unmap_sg
  (bnc#1012628).
- ARM: 8943/1: Fix topology setup in case of CPU hotplug for
  CONFIG_SCHED_MC (bnc#1012628).
- media: ov6650: Fix incorrect use of JPEG colorspace
  (bnc#1012628).
- media: ov6650: Fix some format attributes not under control
  (bnc#1012628).
- media: ov6650: Fix .get_fmt() V4L2_SUBDEV_FORMAT_TRY support
  (bnc#1012628).
- media: ov6650: Fix default format not applied on device probe
  (bnc#1012628).
- media: rcar-vin: Fix incorrect return statement in
  rvin_try_format() (bnc#1012628).
- media: hantro: h264: Fix the frame_num wraparound case
  (bnc#1012628).
- media: v4l: cadence: Fix how unsued lanes are handled in
  'csi2rx_start()' (bnc#1012628).
- media: exynos4-is: Fix recursive locking in isp_video_release()
  (bnc#1012628).
- media: coda: fix deadlock between decoder picture run and
  start command (bnc#1012628).
- media: cedrus: Use correct H264 8x8 scaling list (bnc#1012628).
- media: hantro: Do not reorder H264 scaling list (bnc#1012628).
- media: aspeed-video: Fix memory leaks in aspeed_video_probe
  (bnc#1012628).
- media: hantro: Set H264 FIELDPIC_FLAG_E flag correctly
  (bnc#1012628).
- iommu/mediatek: Correct the flush_iotlb_all callback
  (bnc#1012628).
- iommu/mediatek: Add a new tlb_lock for tlb_flush (bnc#1012628).
- memory: mtk-smi: Add PM suspend and resume ops (bnc#1012628).
- Revert "ubifs: Fix memory leak bug in alloc_ubifs_info()
  error path" (bnc#1012628).
- ubifs: Fixed missed le64_to_cpu() in journal (bnc#1012628).
- ubifs: do_kill_orphans: Fix a memory leak bug (bnc#1012628).
- spi: sprd: Fix the incorrect SPI register (bnc#1012628).
- mtd: spi-nor: fix silent truncation in spi_nor_read()
  (bnc#1012628).
- mtd: spi-nor: fix silent truncation in spi_nor_read_raw()
  (bnc#1012628).
- spi: pxa2xx: Set controller->max_transfer_size in dma mode
  (bnc#1012628).
- spi: atmel: fix handling of cs_change set on non-last xfer
  (bnc#1012628).
- spi: rspi: Use platform_get_irq_byname_optional() for optional
  irqs (bnc#1012628).
- spi: lpspi: fix memory leak in fsl_lpspi_probe (bnc#1012628).
- iwlwifi: mvm: consider ieee80211 station max amsdu value
  (bnc#1012628).
- rtlwifi: Remove unnecessary NULL check in rtl_regd_init
  (bnc#1012628).
- iwlwifi: mvm: fix support for single antenna diversity
  (bnc#1012628).
- sch_cake: Add missing NLA policy entry TCA_CAKE_SPLIT_GSO
  (bnc#1012628).
- f2fs: fix potential overflow (bnc#1012628).
- NFSD fixing possible null pointer derefering in copy offload
  (bnc#1012628).
- rtc: msm6242: Fix reading of 10-hour digit (bnc#1012628).
- rtc: brcmstb-waketimer: add missed clk_disable_unprepare
  (bnc#1012628).
- rtc: bd70528: Add MODULE ALIAS to autoload module (bnc#1012628).
- gpio: mpc8xxx: Add platform device to gpiochip->parent
  (bnc#1012628).
- scsi: libcxgbi: fix NULL pointer dereference in
  cxgbi_device_destroy() (bnc#1012628).
- scsi: target/iblock: Fix protection error with blocks greater
  than 512B (bnc#1012628).
- selftests: firmware: Fix it to do root uid check and skip
  (bnc#1012628).
- rseq/selftests: Turn off timeout setting (bnc#1012628).
- riscv: export flush_icache_all to modules (bnc#1012628).
- mips: cacheinfo: report shared CPU map (bnc#1012628).
- mips: Fix gettimeofday() in the vdso library (bnc#1012628).
- tomoyo: Suppress RCU warning at list_for_each_entry_rcu()
  (bnc#1012628).
- MIPS: Prevent link failure with kcov instrumentation
  (bnc#1012628).
- drm/arm/mali: make malidp_mw_connector_helper_funcs static
  (bnc#1012628).
- rxrpc: Unlock new call in rxrpc_new_incoming_call() rather
  than the caller (bnc#1012628).
- rxrpc: Don't take call->user_mutex in rxrpc_new_incoming_call()
  (bnc#1012628).
- rxrpc: Fix missing security check on incoming calls
  (bnc#1012628).
- dmaengine: k3dma: Avoid null pointer traversal (bnc#1012628).
- s390/qeth: lock the card while changing its hsuid (bnc#1012628).
- ioat: ioat_alloc_ring() failure handling (bnc#1012628).
- drm/amdgpu: enable gfxoff for raven1 refresh (bnc#1012628).
- media: intel-ipu3: Align struct ipu3_uapi_awb_fr_config_s to
  32 bytes (bnc#1012628).
- kbuild/deb-pkg: annotate libelf-dev dependency as :native
  (bnc#1012628).
- hexagon: parenthesize registers in asm predicates (bnc#1012628).
- hexagon: work around compiler crash (bnc#1012628).
- ocfs2: call journal flush to mark journal as empty after
  journal recovery when mount (bnc#1012628).
- Update config files.
- commit 5fa871d
* Wed Jan 15 2020 tiwai@suse.de
- Update config files: disable CONFIG_SND_HDA_INTEL_DETECT_DMIC (bsc#1160914)
  SOF driver still doesn't work properly for most of HD-audio devices on
  5.4.y without the current firmware, so better to disable it to make
  the driver behavior compatible with older kernels.
- commit 4c4d6ee
* Wed Jan 15 2020 tiwai@suse.de
- rtw88: fix potential NULL skb access in TX ISR (bsc#1160730).
- commit f123aae
* Wed Jan 15 2020 jslaby@suse.cz
- HID: hidraw, uhid: Always report EPOLLOUT (git-fixes).
- commit 7f4459b
* Wed Jan 15 2020 jslaby@suse.cz
- Linux 5.4.12 (bnc#1012628).
- chardev: Avoid potential use-after-free in 'chrdev_open()'
  (bnc#1012628).
- i2c: fix bus recovery stop mode timing (bnc#1012628).
- powercap: intel_rapl: add NULL pointer check to
  rapl_mmio_cpu_online() (bnc#1012628).
- usb: chipidea: host: Disable port power only if previously
  enabled (bnc#1012628).
- ALSA: usb-audio: Apply the sample rate quirk for Bose Companion
  5 (bnc#1012628).
- ALSA: hda/realtek - Add new codec supported for ALCS1200A
  (bnc#1012628).
- ALSA: hda/realtek - Set EAPD control to default for ALC222
  (bnc#1012628).
- ALSA: hda/realtek - Add quirk for the bass speaker on Lenovo
  Yoga X1 7th gen (bnc#1012628).
- tpm: Handle negative priv->response_len in tpm_common_read()
  (bnc#1012628).
- rtc: sun6i: Add support for RTC clocks on R40 (bnc#1012628).
- kernel/trace: Fix do not unregister tracepoints when register
  sched_migrate_task fail (bnc#1012628).
- tracing: Have stack tracer compile when MCOUNT_INSN_SIZE is
  not defined (bnc#1012628).
- tracing: Change offset type to s32 in preempt/irq tracepoints
  (bnc#1012628).
- HID: Fix slab-out-of-bounds read in hid_field_extract
  (bnc#1012628).
- HID: uhid: Fix returning EPOLLOUT from uhid_char_poll
  (bnc#1012628).
- HID: hidraw: Fix returning EPOLLOUT from hidraw_poll
  (bnc#1012628).
- HID: hid-input: clear unmapped usages (bnc#1012628).
- Input: add safety guards to input_set_keycode() (bnc#1012628).
- Input: input_event - fix struct padding on sparc64
  (bnc#1012628).
- drm/i915: Add Wa_1408615072 and Wa_1407596294 to icl,ehl
  (bnc#1012628).
- Revert "drm/amdgpu: Set no-retry as default." (bnc#1012628).
- drm/sun4i: tcon: Set RGB DCLK min. divider based on hardware
  model (bnc#1012628).
- drm/fb-helper: Round up bits_per_pixel if possible
  (bnc#1012628).
- drm/dp_mst: correct the shifting in DP_REMOTE_I2C_READ
  (bnc#1012628).
- drm/i915: Add Wa_1407352427:icl,ehl (bnc#1012628).
- drm/i915/gt: Mark up virtual engine uabi_instance (bnc#1012628).
- IB/hfi1: Adjust flow PSN with the correct resync_psn
  (bnc#1012628).
- can: kvaser_usb: fix interface sanity check (bnc#1012628).
- can: gs_usb: gs_usb_probe(): use descriptors of current
  altsetting (bnc#1012628).
- can: tcan4x5x: tcan4x5x_can_probe(): get the device out of
  standby before register access (bnc#1012628).
- can: mscan: mscan_rx_poll(): fix rx path lockup when returning
  from polling to irq mode (bnc#1012628).
- can: can_dropped_invalid_skb(): ensure an initialized headroom
  in outgoing CAN sk_buffs (bnc#1012628).
- gpiolib: acpi: Turn dmi_system_id table into a generic quirk
  table (bnc#1012628).
- gpiolib: acpi: Add honor_wakeup module-option + quirk mechanism
  (bnc#1012628).
- pstore/ram: Regularize prz label allocation lifetime
  (bnc#1012628).
- staging: vt6656: set usb_set_intfdata on driver fail
  (bnc#1012628).
- staging: vt6656: Fix non zero logical return of, usb_control_msg
  (bnc#1012628).
- usb: cdns3: should not use the same dev_id for shared interrupt
  handler (bnc#1012628).
- usb: ohci-da8xx: ensure error return on variable error is set
  (bnc#1012628).
- USB-PD tcpm: bad warning+size, PPS adapters (bnc#1012628).
- USB: serial: option: add ZLP support for 0x1bc7/0x9010
  (bnc#1012628).
- usb: musb: fix idling for suspend after disconnect interrupt
  (bnc#1012628).
- usb: musb: Disable pullup at init (bnc#1012628).
- usb: musb: dma: Correct parameter passed to IRQ handler
  (bnc#1012628).
- staging: comedi: adv_pci1710: fix AI channels 16-31 for PCI-1713
  (bnc#1012628).
- staging: vt6656: correct return of vnt_init_registers
  (bnc#1012628).
- staging: vt6656: limit reg output to block size (bnc#1012628).
- staging: rtl8188eu: Add device code for TP-Link TL-WN727N v5.21
  (bnc#1012628).
- serdev: Don't claim unsupported ACPI serial devices
  (bnc#1012628).
- iommu/vt-d: Fix adding non-PCI devices to Intel IOMMU
  (bnc#1012628).
- tty: link tty and port before configuring it as console
  (bnc#1012628).
- tty: always relink the port (bnc#1012628).
- arm64: Move __ARCH_WANT_SYS_CLONE3 definition to uapi headers
  (bnc#1012628).
- arm64: Implement copy_thread_tls (bnc#1012628).
- arm: Implement copy_thread_tls (bnc#1012628).
- parisc: Implement copy_thread_tls (bnc#1012628).
- riscv: Implement copy_thread_tls (bnc#1012628).
- xtensa: Implement copy_thread_tls (bnc#1012628).
- clone3: ensure copy_thread_tls is implemented (bnc#1012628).
- um: Implement copy_thread_tls (bnc#1012628).
- staging: vt6656: remove bool from vnt_radio_power_on ret
  (bnc#1012628).
- mwifiex: fix possible heap overflow in
  mwifiex_process_country_ie() (bnc#1012628).
- mwifiex: pcie: Fix memory leak in mwifiex_pcie_alloc_cmdrsp_buf
  (bnc#1012628).
- rpmsg: char: release allocated memory (bnc#1012628).
- scsi: bfa: release allocated memory in case of error
  (bnc#1012628).
- rtl8xxxu: prevent leaking urb (bnc#1012628).
- ath10k: fix memory leak (bnc#1012628).
- HID: hiddev: fix mess in hiddev_open() (bnc#1012628).
- phy: cpcap-usb: Fix error path when no host driver is loaded
  (bnc#1012628).
- phy: cpcap-usb: Fix flakey host idling and enumerating of
  devices (bnc#1012628).
- netfilter: arp_tables: init netns pointer in xt_tgchk_param
  struct (bnc#1012628).
- netfilter: conntrack: dccp, sctp: handle null timeout argument
  (bnc#1012628).
- netfilter: ipset: avoid null deref when IPSET_ATTR_LINENO is
  present (bnc#1012628).
- Update config files.
- commit 9cfb8de
* Tue Jan 14 2020 tiwai@suse.de
- drm/i915/gen9: Clear residual context state on context switch
  (CVE-2019-14615 bsc#1160195).
- commit 63e6175
* Tue Jan 14 2020 tiwai@suse.de
- Revert "iwlwifi: mvm: fix scan config command size" (bsc#1160717).
- commit cf0d366
* Tue Jan 14 2020 tiwai@suse.de
- Update config files: enable forgotten configs for SOF (bsc#1160819)
  The configs have been forgotten to be enabled:
  CONFIG_SND_SOC_SOF_HDA_COMMON_HDMI_CODEC=y
  CONFIG_SND_SOC_SOF_JASPERLAKE_SUPPORT=y
  CONFIG_SND_SOC_SOF_JASPERLAKE=m
- commit c542b01
* Mon Jan 13 2020 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Do not obsolete KMPs (boo#1126512).
- commit cea1843
* Mon Jan 13 2020 mkubecek@suse.cz
- Update to 5.5-rc6
- commit 6dccaaf
* Mon Jan 13 2020 jslaby@suse.cz
- Linux 5.4.11 (bnc#1012628).
- USB: dummy-hcd: use usb_urb_dir_in instead of usb_pipein
  (bnc#1012628).
- bpf: Fix passing modified ctx to ld/abs/ind instruction
  (bnc#1012628).
- ASoC: rt5682: fix i2c arbitration lost issue (bnc#1012628).
- spi: pxa2xx: Add support for Intel Jasper Lake (bnc#1012628).
- regulator: fix use after free issue (bnc#1012628).
- ASoC: max98090: fix possible race conditions (bnc#1012628).
- spi: fsl: Fix GPIO descriptor support (bnc#1012628).
- gpio: Handle counting of Freescale chipselects (bnc#1012628).
- spi: fsl: Handle the single hardwired chipselect case
  (bnc#1012628).
- locking/spinlock/debug: Fix various data races (bnc#1012628).
- netfilter: ctnetlink: netns exit must wait for callbacks
  (bnc#1012628).
- x86/intel: Disable HPET on Intel Ice Lake platforms
  (bnc#1012628).
- netfilter: nf_tables_offload: Check for the NETDEV_UNREGISTER
  event (bnc#1012628).
- mwifiex: Fix heap overflow in
  mmwifiex_process_tdls_action_frame() (bnc#1012628).
- libtraceevent: Fix lib installation with O= (bnc#1012628).
- libtraceevent: Copy pkg-config file to output folder when
  using O= (bnc#1012628).
- regulator: core: fix regulator_register() error paths to
  properly release rdev (bnc#1012628).
- x86/efi: Update e820 with reserved EFI boot services data to
  fix kexec breakage (bnc#1012628).
- ASoC: Intel: bytcr_rt5640: Update quirk for Teclast X89
  (bnc#1012628).
- selftests: netfilter: use randomized netns names (bnc#1012628).
- efi/gop: Return EFI_NOT_FOUND if there are no usable GOPs
  (bnc#1012628).
- efi/gop: Return EFI_SUCCESS if a usable GOP was found
  (bnc#1012628).
- efi/gop: Fix memory leak in __gop_query32/64() (bnc#1012628).
- efi/earlycon: Remap entire framebuffer after page initialization
  (bnc#1012628).
- ARM: dts: imx6ul: imx6ul-14x14-evk.dtsi: Fix SPI NOR probing
  (bnc#1012628).
- ARM: vexpress: Set-up shared OPP table instead of individual
  for each CPU (bnc#1012628).
- netfilter: uapi: Avoid undefined left-shift in xt_sctp.h
  (bnc#1012628).
- netfilter: nft_set_rbtree: bogus lookup/get on consecutive
  elements in named sets (bnc#1012628).
- netfilter: nf_tables: validate NFT_SET_ELEM_INTERVAL_END
  (bnc#1012628).
- netfilter: nf_tables: validate NFT_DATA_VALUE after
  nft_data_init() (bnc#1012628).
- netfilter: nf_tables: skip module reference count bump on
  object updates (bnc#1012628).
- netfilter: nf_tables_offload: return EOPNOTSUPP if rule
  specifies no actions (bnc#1012628).
- ARM: dts: BCM5301X: Fix MDIO node address/size cells
  (bnc#1012628).
- selftests/ftrace: Fix to check the existence of
  set_ftrace_filter (bnc#1012628).
- selftests/ftrace: Fix ftrace test cases to check unsupported
  (bnc#1012628).
- selftests/ftrace: Do not to use absolute debugfs path
  (bnc#1012628).
- selftests/ftrace: Fix multiple kprobe testcase (bnc#1012628).
- selftests: safesetid: Move link library to LDLIBS (bnc#1012628).
- selftests: safesetid: Check the return value of setuid/setgid
  (bnc#1012628).
- selftests: safesetid: Fix Makefile to set correct test program
  (bnc#1012628).
- ARM: exynos_defconfig: Restore debugfs support (bnc#1012628).
- ARM: dts: Cygnus: Fix MDIO node address/size cells
  (bnc#1012628).
- spi: spi-cavium-thunderx: Add missing pci_release_regions()
  (bnc#1012628).
- reset: Do not register resource data for missing resets
  (bnc#1012628).
- ASoC: topology: Check return value for snd_soc_add_dai_link()
  (bnc#1012628).
- ASoC: topology: Check return value for soc_tplg_pcm_create()
  (bnc#1012628).
- ASoC: SOF: loader: snd_sof_fw_parse_ext_data log warning on
  unknown header (bnc#1012628).
- ASoC: SOF: Intel: split cht and byt debug window sizes
  (bnc#1012628).
- ARM: dts: am335x-sancloud-bbe: fix phy mode (bnc#1012628).
- ARM: omap2plus_defconfig: Add back DEBUG_FS (bnc#1012628).
- ARM: dts: bcm283x: Fix critical trip point (bnc#1012628).
- arm64: dts: ls1028a: fix typo in TMU calibration data
  (bnc#1012628).
- bpf, riscv: Limit to 33 tail calls (bnc#1012628).
- bpf, mips: Limit to 33 tail calls (bnc#1012628).
- bpftool: Don't crash on missing jited insns or ksyms
  (bnc#1012628).
- perf metricgroup: Fix printing event names of metric group
  with multiple events (bnc#1012628).
- perf header: Fix false warning when there are no duplicate
  cache entries (bnc#1012628).
- spi: spi-ti-qspi: Fix a bug when accessing non default CS
  (bnc#1012628).
- ARM: dts: am437x-gp/epos-evm: fix panel compatible
  (bnc#1012628).
- kselftest/runner: Print new line in print of timeout log
  (bnc#1012628).
- kselftest: Support old perl versions (bnc#1012628).
- samples: bpf: Replace symbol compare of trace_event
  (bnc#1012628).
- samples: bpf: fix syscall_tp due to unused syscall
  (bnc#1012628).
- arm64: dts: ls1028a: fix reboot node (bnc#1012628).
- ARM: imx_v6_v7_defconfig: Explicitly restore CONFIG_DEBUG_FS
  (bnc#1012628).
- pinctrl: aspeed-g6: Fix LPC/eSPI mux configuration
  (bnc#1012628).
- bus: ti-sysc: Fix missing reset delay handling (bnc#1012628).
- clk: walk orphan list on clock provider registration
  (bnc#1012628).
- mac80211: fix TID field in monitor mode transmit (bnc#1012628).
- cfg80211: fix double-free after changing network namespace
  (bnc#1012628).
- pinctrl: pinmux: fix a possible null pointer in
  pinmux_can_be_used_for_gpio (bnc#1012628).
- powerpc: Ensure that swiotlb buffer is allocated from low memory
  (bnc#1012628).
- btrfs: Fix error messages in qgroup_rescan_init (bnc#1012628).
- Btrfs: fix cloning range with a hole when using the NO_HOLES
  feature (bnc#1012628).
- powerpc/vcpu: Assume dedicated processors as non-preempt
  (bnc#1012628).
- powerpc/spinlocks: Include correct header for static key
  (bnc#1012628).
- btrfs: handle error in btrfs_cache_block_group (bnc#1012628).
- Btrfs: fix hole extent items with a zero size after range
  cloning (bnc#1012628).
- ocxl: Fix potential memory leak on context creation
  (bnc#1012628).
- bpf: Clear skb->tstamp in bpf_redirect when necessary
  (bnc#1012628).
- habanalabs: rate limit error msg on waiting for CS
  (bnc#1012628).
- habanalabs: remove variable 'val' set but not used
  (bnc#1012628).
- bnx2x: Do not handle requests from VFs after parity
  (bnc#1012628).
- bnx2x: Fix logic to get total no. of PFs per engine
  (bnc#1012628).
- cxgb4: Fix kernel panic while accessing sge_info (bnc#1012628).
- net: usb: lan78xx: Fix error message format specifier
  (bnc#1012628).
- parisc: fix compilation when KEXEC=n and KEXEC_FILE=y
  (bnc#1012628).
- parisc: add missing __init annotation (bnc#1012628).
- rfkill: Fix incorrect check to avoid NULL pointer dereference
  (bnc#1012628).
- ASoC: wm8962: fix lambda value (bnc#1012628).
- regulator: rn5t618: fix module aliases (bnc#1012628).
- spi: nxp-fspi: Ensure width is respected in spi-mem operations
  (bnc#1012628).
- clk: at91: fix possible deadlock (bnc#1012628).
- staging: axis-fifo: add unspecified HAS_IOMEM dependency
  (bnc#1012628).
- iommu/iova: Init the struct iova to fix the possible memleak
  (bnc#1012628).
- kconfig: don't crash on NULL expressions in expr_eq()
  (bnc#1012628).
- scripts: package: mkdebian: add missing rsync dependency
  (bnc#1012628).
- perf/x86: Fix potential out-of-bounds access (bnc#1012628).
- perf/x86/intel: Fix PT PMI handling (bnc#1012628).
- sched/psi: Fix sampling error and rare div0 crashes with
  cgroups and high uptime (bnc#1012628).
- psi: Fix a division error in psi poll() (bnc#1012628).
- usb: typec: fusb302: Fix an undefined reference to
  'extcon_get_state' (bnc#1012628).
- block: end bio with BLK_STS_AGAIN in case of non-mq devs and
  REQ_NOWAIT (bnc#1012628).
- fs: avoid softlockups in s_inodes iterators (bnc#1012628).
- fs: call fsnotify_sb_delete after evict_inodes (bnc#1012628).
- perf/smmuv3: Remove the leftover put_cpu() in error path
  (bnc#1012628).
- iommu/dma: Relax locking in iommu_dma_prepare_msi()
  (bnc#1012628).
- io_uring: don't wait when under-submitting (bnc#1012628).
- clk: Move clk_core_reparent_orphans() under CONFIG_OF
  (bnc#1012628).
- net: stmmac: selftests: Needs to check the number of Multicast
  regs (bnc#1012628).
- net: stmmac: Determine earlier the size of RX buffer
  (bnc#1012628).
- net: stmmac: Do not accept invalid MTU values (bnc#1012628).
- net: stmmac: xgmac: Clear previous RX buffer size (bnc#1012628).
- net: stmmac: RX buffer size must be 16 byte aligned
  (bnc#1012628).
- net: stmmac: Always arm TX Timer at end of transmission start
  (bnc#1012628).
- s390/purgatory: do not build purgatory with kcov, kasan and
  friends (bnc#1012628).
- drm/exynos: gsc: add missed component_del (bnc#1012628).
- tpm/tpm_ftpm_tee: add shutdown call back (bnc#1012628).
- xsk: Add rcu_read_lock around the XSK wakeup (bnc#1012628).
- net/mlx5e: Fix concurrency issues between config flow and XSK
  (bnc#1012628).
- net/i40e: Fix concurrency issues between config flow and XSK
  (bnc#1012628).
- net/ixgbe: Fix concurrency issues between config flow and XSK
  (bnc#1012628).
- platform/x86: pcengines-apuv2: fix simswap GPIO assignment
  (bnc#1012628).
- arm64: cpu_errata: Add Hisilicon TSV110 to spectre-v2 safe list
  (bnc#1012628).
- block: Fix a lockdep complaint triggered by request queue
  flushing (bnc#1012628).
- s390/dasd/cio: Interpret ccw_device_get_mdc return value
  correctly (bnc#1012628).
- s390/dasd: fix memleak in path handling error case
  (bnc#1012628).
- block: fix memleak when __blk_rq_map_user_iov() is failed
  (bnc#1012628).
- parisc: Fix compiler warnings in debug_core.c (bnc#1012628).
- sbitmap: only queue kyber's wait callback if not already active
  (bnc#1012628).
- s390/qeth: handle error due to unsupported transport mode
  (bnc#1012628).
- s390/qeth: fix promiscuous mode after reset (bnc#1012628).
- s390/qeth: don't return -ENOTSUPP to userspace (bnc#1012628).
- llc2: Fix return statement of llc_stat_ev_rx_null_dsap_xid_c
  (and _test_c) (bnc#1012628).
- hv_netvsc: Fix unwanted rx_table reset (bnc#1012628).
- selftests: pmtu: fix init mtu value in description
  (bnc#1012628).
- tracing: Do not create directories if lockdown is in affect
  (bnc#1012628).
- gtp: fix bad unlock balance in gtp_encap_enable_socket
  (bnc#1012628).
- macvlan: do not assume mac_header is set in macvlan_broadcast()
  (bnc#1012628).
- net: dsa: mv88e6xxx: Preserve priority when setting CPU port
  (bnc#1012628).
- net: freescale: fec: Fix ethtool -d runtime PM (bnc#1012628).
- net: stmmac: dwmac-sun8i: Allow all RGMII modes (bnc#1012628).
- net: stmmac: dwmac-sunxi: Allow all RGMII modes (bnc#1012628).
- net: stmmac: Fixed link does not need MDIO Bus (bnc#1012628).
- net: usb: lan78xx: fix possible skb leak (bnc#1012628).
- pkt_sched: fq: do not accept silly TCA_FQ_QUANTUM (bnc#1012628).
- sch_cake: avoid possible divide by zero in cake_enqueue()
  (bnc#1012628).
- sctp: free cmd->obj.chunk for the unprocessed SCTP_CMD_REPLY
  (bnc#1012628).
- tcp: fix "old stuff" D-SACK causing SACK to be treated as D-SACK
  (bnc#1012628).
- vxlan: fix tos value before xmit (bnc#1012628).
- mlxsw: spectrum_qdisc: Ignore grafting of invisible FIFO
  (bnc#1012628).
- net: sch_prio: When ungrafting, replace with FIFO (bnc#1012628).
- vlan: fix memory leak in vlan_dev_set_egress_priority
  (bnc#1012628).
- vlan: vlan_changelink() should propagate errors (bnc#1012628).
- macb: Don't unregister clks unconditionally (bnc#1012628).
- net/mlx5: Move devlink registration before interfaces load
  (bnc#1012628).
- net: dsa: mv88e6xxx: force cmode write on 6141/6341
  (bnc#1012628).
- net/mlx5e: Always print health reporter message to dmesg
  (bnc#1012628).
- net/mlx5: DR, No need for atomic refcount for internal SW
  steering resources (bnc#1012628).
- net/mlx5e: Fix hairpin RSS table size (bnc#1012628).
- net/mlx5: DR, Init lists that are used in rule's member
  (bnc#1012628).
- usb: dwc3: gadget: Fix request complete check (bnc#1012628).
- USB: core: fix check for duplicate endpoints (bnc#1012628).
- USB: serial: option: add Telit ME910G1 0x110a composition
  (bnc#1012628).
- usb: missing parentheses in USE_NEW_SCHEME (bnc#1012628).
- Refresh
  patches.suse/V4-04-10-ARM-dts-bcm283x-Move-BCM2835-6-7-specific-to-bcm2835-common.dtsi.patch.
- commit 2d02eb4
* Fri Jan 10 2020 nsaenzjulienne@suse.de
- supported.conf: Enable mdio-bcm-unimac (bsc#1160310)
  Needed in order for Raspberry Pi 4's ethernet port to work.
- commit b949d3b
* Thu Jan  9 2020 jslaby@suse.cz
- Linux 5.4.10 (bnc#1012628).
- powerpc/pmem: Fix kernel crash due to wrong range value usage
  in flush_dcache_range (bnc#1012628).
- commit 556a6fe
* Thu Jan  9 2020 jslaby@suse.cz
- Linux 5.4.9 (bnc#1012628).
- drm/mcde: dsi: Fix invalid pointer dereference if panel cannot
  be found (bnc#1012628).
- nvme_fc: add module to ops template to allow module references
  (bnc#1012628).
- nvme-fc: fix double-free scenarios on hw queues (bnc#1012628).
- drm/amdgpu: add check before enabling/disabling broadcast mode
  (bnc#1012628).
- drm/amdgpu: add header line for power profile on Arcturus
  (bnc#1012628).
- drm/amdgpu: add cache flush workaround to gfx8 emit_fence
  (bnc#1012628).
- drm/amd/display: Map DSC resources 1-to-1 if numbers of OPPs
  and DSCs are equal (bnc#1012628).
- drm/amd/display: Fixed kernel panic when booting with DP-to-HDMI
  dongle (bnc#1012628).
- drm/amd/display: Change the delay time before enabling FEC
  (bnc#1012628).
- drm/amd/display: Reset steer fifo before unblanking the stream
  (bnc#1012628).
- drm/amd/display: update dispclk and dppclk vco frequency
  (bnc#1012628).
- nvme/pci: Fix write and poll queue types (bnc#1012628).
- nvme/pci: Fix read queue count (bnc#1012628).
- iio: st_accel: Fix unused variable warning (bnc#1012628).
- iio: adc: max9611: Fix too short conversion time delay
  (bnc#1012628).
- PM / devfreq: Fix devfreq_notifier_call returning errno
  (bnc#1012628).
- PM / devfreq: Set scaling_max_freq to max on OPP notifier error
  (bnc#1012628).
- PM / devfreq: Don't fail devfreq_dev_release if not in list
  (bnc#1012628).
- afs: Fix afs_find_server lookups for ipv4 peers (bnc#1012628).
- afs: Fix SELinux setting security label on /afs (bnc#1012628).
- RDMA/cma: add missed unregister_pernet_subsys in init failure
  (bnc#1012628).
- rxe: correctly calculate iCRC for unaligned payloads
  (bnc#1012628).
- scsi: lpfc: Fix memory leak on lpfc_bsg_write_ebuf_set func
  (bnc#1012628).
- scsi: qla2xxx: Use explicit LOGO in target mode (bnc#1012628).
- scsi: qla2xxx: Drop superfluous INIT_WORK of del_work
  (bnc#1012628).
- scsi: qla2xxx: Don't call qlt_async_event twice (bnc#1012628).
- scsi: qla2xxx: Fix PLOGI payload and ELS IOCB dump length
  (bnc#1012628).
- scsi: qla2xxx: Configure local loop for N2N target
  (bnc#1012628).
- scsi: qla2xxx: Send Notify ACK after N2N PLOGI (bnc#1012628).
- scsi: qla2xxx: Don't defer relogin unconditonally (bnc#1012628).
- scsi: qla2xxx: Ignore PORT UPDATE after N2N PLOGI (bnc#1012628).
- scsi: iscsi: qla4xxx: fix double free in probe (bnc#1012628).
- scsi: libsas: stop discovering if oob mode is disconnected
  (bnc#1012628).
- scsi: iscsi: Avoid potential deadlock in iscsi_if_rx func
  (bnc#1012628).
- staging/wlan-ng: add CRC32 dependency in Kconfig (bnc#1012628).
- drm/nouveau: Move the declaration of struct nouveau_conn_atom
  up a bit (bnc#1012628).
- drm/nouveau: Fix drm-core using atomic code-paths on pre-nv50
  hardware (bnc#1012628).
- drm/nouveau/kms/nv50-: fix panel scaling (bnc#1012628).
- usb: gadget: fix wrong endpoint desc (bnc#1012628).
- net: make socket read/write_iter() honor IOCB_NOWAIT
  (bnc#1012628).
- afs: Fix mountpoint parsing (bnc#1012628).
- afs: Fix creation calls in the dynamic root to fail with
  EOPNOTSUPP (bnc#1012628).
- raid5: need to set STRIPE_HANDLE for batch head (bnc#1012628).
- md: raid1: check rdev before reference in raid1_sync_request
  func (bnc#1012628).
- s390/cpum_sf: Adjust sampling interval to avoid hitting sample
  limits (bnc#1012628).
- s390/cpum_sf: Avoid SBD overflow condition in irq handler
  (bnc#1012628).
- RDMA/counter: Prevent auto-binding a QP which are not tracked
  with res (bnc#1012628).
- IB/mlx4: Follow mirror sequence of device add during device
  removal (bnc#1012628).
- IB/mlx5: Fix steering rule of drop and count (bnc#1012628).
- xen-blkback: prevent premature module unload (bnc#1012628).
- xen/balloon: fix ballooned page accounting without hotplug
  enabled (bnc#1012628).
- PM / hibernate: memory_bm_find_bit(): Tighten node optimisation
  (bnc#1012628).
- ALSA: hda/realtek - Add Bass Speaker and fixed dac for bass
  speaker (bnc#1012628).
- ALSA: hda/realtek - Enable the bass speaker of ASUS UX431FLC
  (bnc#1012628).
- PCI: Add a helper to check Power Resource Requirements _PR3
  existence (bnc#1012628).
- ALSA: hda: Allow HDA to be runtime suspended when dGPU is not
  bound to a driver (bnc#1012628).
- PCI: Fix missing inline for pci_pr3_present() (bnc#1012628).
- ALSA: hda - fixup for the bass speaker on Lenovo Carbon X1
  7th gen (bnc#1012628).
- tcp: fix data-race in tcp_recvmsg() (bnc#1012628).
- shmem: pin the file in shmem_fault() if mmap_sem is dropped
  (bnc#1012628).
- taskstats: fix data-race (bnc#1012628).
- ALSA: hda - Downgrade error message for single-cmd fallback
  (bnc#1012628).
- netfilter: nft_tproxy: Fix port selector on Big Endian
  (bnc#1012628).
- block: add bio_truncate to fix guard_bio_eod (bnc#1012628).
- mm: drop mmap_sem before calling balance_dirty_pages() in
  write fault (bnc#1012628).
- ALSA: ice1724: Fix sleep-in-atomic in Infrasonic Quartet
  support code (bnc#1012628).
- ALSA: usb-audio: fix set_format altsetting sanity check
  (bnc#1012628).
- ALSA: usb-audio: set the interface format after resume on Dell
  WD19 (bnc#1012628).
- ALSA: hda - Apply sync-write workaround to old Intel platforms,
  too (bnc#1012628).
- ALSA: hda/realtek - Add headset Mic no shutup for ALC283
  (bnc#1012628).
- drm/sun4i: hdmi: Remove duplicate cleanup calls (bnc#1012628).
- drm/amdgpu/smu: add metrics table lock (bnc#1012628).
- drm/amdgpu/smu: add metrics table lock for arcturus (v2)
  (bnc#1012628).
- drm/amdgpu/smu: add metrics table lock for navi (v2)
  (bnc#1012628).
- drm/amdgpu/smu: add metrics table lock for vega20 (v2)
  (bnc#1012628).
- MIPS: BPF: Disable MIPS32 eBPF JIT (bnc#1012628).
- MIPS: BPF: eBPF JIT: check for MIPS ISA compliance in Kconfig
  (bnc#1012628).
- MIPS: Avoid VDSO ABI breakage due to global register variable
  (bnc#1012628).
- media: pulse8-cec: fix lost cec_transmit_attempt_done() call
  (bnc#1012628).
- media: cec: CEC 2.0-only bcast messages were ignored
  (bnc#1012628).
- media: cec: avoid decrementing transmit_queue_sz if it is 0
  (bnc#1012628).
- media: cec: check 'transmit_in_progress', not 'transmitting'
  (bnc#1012628).
- mm/memory_hotplug: shrink zones when offlining memory
  (bnc#1012628).
- mm/zsmalloc.c: fix the migrated zspage statistics (bnc#1012628).
- memcg: account security cred as well to kmemcg (bnc#1012628).
- mm: move_pages: return valid node id in status if the page is
  already on the target node (bnc#1012628).
- mm/oom: fix pgtables units mismatch in Killed process message
  (bnc#1012628).
- ocfs2: fix the crash due to call ocfs2_get_dlm_debug once less
  (bnc#1012628).
- pstore/ram: Write new dumps to start of recycled zones
  (bnc#1012628).
- pstore/ram: Fix error-path memory leak in persistent_ram_new()
  callers (bnc#1012628).
- gcc-plugins: make it possible to disable CONFIG_GCC_PLUGINS
  again (bnc#1012628).
- locks: print unsigned ino in /proc/locks (bnc#1012628).
- selftests/seccomp: Zero out seccomp_notif (bnc#1012628).
- seccomp: Check that seccomp_notif is zeroed out by the user
  (bnc#1012628).
- samples/seccomp: Zero out members based on seccomp_notif_sizes
  (bnc#1012628).
- selftests/seccomp: Catch garbage on SECCOMP_IOCTL_NOTIF_RECV
  (bnc#1012628).
- dmaengine: Fix access to uninitialized dma_slave_caps
  (bnc#1012628).
- dmaengine: dma-jz4780: Also break descriptor chains on JZ4725B
  (bnc#1012628).
- Btrfs: fix infinite loop during nocow writeback due to race
  (bnc#1012628).
- compat_ioctl: block: handle Persistent Reservations
  (bnc#1012628).
- compat_ioctl: block: handle BLKREPORTZONE/BLKRESETZONE
  (bnc#1012628).
- compat_ioctl: block: handle BLKGETZONESZ/BLKGETNRZONES
  (bnc#1012628).
- bpf: Fix precision tracking for unbounded scalars (bnc#1012628).
- ata: libahci_platform: Export again
  ahci_platform_<en/dis>able_phys() (bnc#1012628).
- ata: ahci_brcm: Fix AHCI resources management (bnc#1012628).
- ata: ahci_brcm: Add missing clock management during recovery
  (bnc#1012628).
- ata: ahci_brcm: BCM7425 AHCI requires AHCI_HFLAG_DELAY_ENGINE
  (bnc#1012628).
- libata: Fix retrieving of active qcs (bnc#1012628).
- gpio: xtensa: fix driver build (bnc#1012628).
- gpiolib: fix up emulated open drain outputs (bnc#1012628).
- clocksource: riscv: add notrace to riscv_sched_clock
  (bnc#1012628).
- riscv: ftrace: correct the condition logic in function graph
  tracer (bnc#1012628).
- rseq/selftests: Fix: Namespace gettid() for compatibility with
  glibc 2.30 (bnc#1012628).
- tracing: Fix lock inversion in trace_event_enable_tgid_record()
  (bnc#1012628).
- tracing: Avoid memory leak in process_system_preds()
  (bnc#1012628).
- tracing: Have the histogram compare functions convert to u64
  first (bnc#1012628).
- tracing: Fix endianness bug in histogram trigger (bnc#1012628).
- samples/trace_printk: Wait for IRQ work to finish (bnc#1012628).
- io_uring: use current task creds instead of allocating a new
  one (bnc#1012628).
- mm/gup: fix memory leak in __gup_benchmark_ioctl (bnc#1012628).
- apparmor: fix aa_xattrs_match() may sleep while holding a RCU
  lock (bnc#1012628).
- dmaengine: virt-dma: Fix access after free in vchan_complete()
  (bnc#1012628).
- gen_initramfs_list.sh: fix 'bad variable name' error
  (bnc#1012628).
- ALSA: cs4236: fix error return comparison of an unsigned integer
  (bnc#1012628).
- ALSA: pcm: Yet another missing check of non-cached buffer type
  (bnc#1012628).
- ALSA: firewire-motu: Correct a typo in the clock proc string
  (bnc#1012628).
- scsi: lpfc: Fix rpi release when deleting vport (bnc#1012628).
- exit: panic before exit_mm() on global init exit (bnc#1012628).
- arm64: Revert support for execute-only user mappings
  (bnc#1012628).
- ftrace: Avoid potential division by zero in function profiler
  (bnc#1012628).
- spi: spi-fsl-dspi: Fix 16-bit word order in 32-bit XSPI mode
  (bnc#1012628).
- drm/msm: include linux/sched/task.h (bnc#1012628).
- PM / devfreq: Check NULL governor in available_governors_show
  (bnc#1012628).
- sunrpc: fix crash when cache_head become valid before update
  (bnc#1012628).
- arm64: dts: qcom: msm8998-clamshell: Remove retention idle state
  (bnc#1012628).
- nfsd4: fix up replay_matches_cache() (bnc#1012628).
- powerpc: Chunk calls to flush_dcache_range in arch_*_memory
  (bnc#1012628).
- HID: i2c-hid: Reset ALPS touchpads on resume (bnc#1012628).
- net/sched: annotate lockless accesses to qdisc->empty
  (bnc#1012628).
- kernel/module.c: wakeup processes in module_wq on module unload
  (bnc#1012628).
- ACPI: sysfs: Change ACPI_MASKABLE_GPE_MAX to 0x100
  (bnc#1012628).
- perf callchain: Fix segfault in
  thread__resolve_callchain_sample() (bnc#1012628).
- iommu/vt-d: Remove incorrect PSI capability check (bnc#1012628).
- of: overlay: add_changeset_property() memory leak (bnc#1012628).
- cifs: Fix potential softlockups while refreshing DFS cache
  (bnc#1012628).
- firmware: arm_scmi: Avoid double free in error flow
  (bnc#1012628).
- xfs: don't check for AG deadlock for realtime files in bunmapi
  (bnc#1012628).
- platform/x86: pmc_atom: Add Siemens CONNECT X300 to
  critclk_systems DMI table (bnc#1012628).
- netfilter: nf_queue: enqueue skbs with NULL dst (bnc#1012628).
- net, sysctl: Fix compiler warning when only cBPF is present
  (bnc#1012628).
- watchdog: tqmx86_wdt: Fix build error (bnc#1012628).
- regulator: axp20x: Fix axp20x_set_ramp_delay (bnc#1012628).
- regulator: bd70528: Remove .set_ramp_delay for bd70528_ldo_ops
  (bnc#1012628).
- spi: uniphier: Fix FIFO threshold (bnc#1012628).
- regulator: axp20x: Fix AXP22x ELDO2 regulator enable bitmask
  (bnc#1012628).
- powerpc/mm: Mark get_slice_psize() & slice_addr_is_low()
  as notrace (bnc#1012628).
- Bluetooth: btusb: fix PM leak in error case of setup
  (bnc#1012628).
- Bluetooth: delete a stray unlock (bnc#1012628).
- Bluetooth: Fix memory leak in hci_connect_le_scan (bnc#1012628).
- arm64: dts: meson-gxl-s905x-khadas-vim: fix uart_A bluetooth
  node (bnc#1012628).
- arm64: dts: meson-gxm-khadas-vim2: fix uart_A bluetooth node
  (bnc#1012628).
- media: flexcop-usb: ensure -EIO is returned on error condition
  (bnc#1012628).
- regulator: ab8500: Remove AB8505 USB regulator (bnc#1012628).
- media: usb: fix memory leak in af9005_identify_state
  (bnc#1012628).
- dt-bindings: clock: renesas: rcar-usb2-clock-sel: Fix typo in
  example (bnc#1012628).
- arm64: dts: meson: odroid-c2: Disable usb_otg bus to avoid
  power failed warning (bnc#1012628).
- phy: renesas: rcar-gen3-usb2: Use platform_get_irq_optional()
  for optional irq (bnc#1012628).
- tty: serial: msm_serial: Fix lockup for sysrq and oops
  (bnc#1012628).
- cifs: Fix lookup of root ses in DFS referral cache
  (bnc#1012628).
- fs: cifs: Fix atime update check vs mtime (bnc#1012628).
- fix compat handling of FICLONERANGE, FIDEDUPERANGE and
  FS_IOC_FIEMAP (bnc#1012628).
- ath9k_htc: Modify byte order for an error message (bnc#1012628).
- ath9k_htc: Discard undersized packets (bnc#1012628).
- drm/i915/execlists: Fix annotation for decoupling virtual
  request (bnc#1012628).
- xfs: periodically yield scrub threads to the scheduler
  (bnc#1012628).
- net: add annotations on hh->hh_len lockless accesses
  (bnc#1012628).
- ubifs: ubifs_tnc_start_commit: Fix OOB in layout_in_gaps
  (bnc#1012628).
- btrfs: get rid of unique workqueue helper functions
  (bnc#1012628).
- Btrfs: only associate the locked page with one async_chunk
  struct (bnc#1012628).
- s390/smp: fix physical to logical CPU map for SMT (bnc#1012628).
- mm/sparse.c: mark populate_section_memmap as __meminit
  (bnc#1012628).
- xen/blkback: Avoid unmapping unmapped grant pages (bnc#1012628).
- lib/ubsan: don't serialize UBSAN report (bnc#1012628).
- efi: Don't attempt to map RCI2 config table if it doesn't exist
  (bnc#1012628).
- perf/x86/intel/bts: Fix the use of page_private() (bnc#1012628).
- net: annotate lockless accesses to sk->sk_pacing_shift
  (bnc#1012628).
- hsr: avoid debugfs warning message when module is remove
  (bnc#1012628).
- hsr: fix error handling routine in hsr_dev_finalize()
  (bnc#1012628).
- hsr: fix a race condition in node list insertion and deletion
  (bnc#1012628).
- mm/hugetlb: defer freeing of huge pages if in non-task context
  (bnc#1012628).
- Refresh patches.suse/vfs-add-super_operations-get_inode_dev.
- commit 605842d
* Thu Jan  9 2020 mkubecek@suse.cz
- supported.conf: sort
  Fix order of entries in supported.conf file.
- commit 581d935
* Wed Jan  8 2020 tiwai@suse.de
- libertas: Fix two buffer overflows at parsing bss descriptor
  (CVE-2019-14896 bsc#1157157 CVE-2019-14897 bsc#1157155).
- commit 434d4ff
* Wed Jan  8 2020 nsaenzjulienne@suse.de
- supported.conf: enable Raspberry Pi cpufreq driver (bsc#1160461).
  These drivers are required in order to enable CPU frequency scaling on
  the Raspberry Pi family of boards.
- commit 224f041
* Wed Jan  8 2020 tiwai@suse.de
- rpm/kernel-docs.spec.in: pass PYTHON=python3 to fix build error (bsc#1160435)
- commit 9b5299f
* Wed Jan  8 2020 mkubecek@suse.cz
- config: fix pstore default compression options on 32-bit ARM
  Previous commit did not update arvm7hl and armv6hl configs properly and
  run_oldconfig.sh did not catch it as these architectures are disabled at
  the moment.
- commit aaf3b6a
* Tue Jan  7 2020 msuchanek@suse.de
- Make lzo the default pstore compression method (bsc#1159986).
  Pstore has compression enabled, pstore is built-in, pstore default
  compression is deflate, deflate is modular -> pstore initialization
  fails on boot. Switch default compression to lzo which is built-in and
  the only built-in method on SLE15.
- commit 4adf9f7
* Tue Jan  7 2020 tiwai@suse.de
- tpm: Revert "tpm_tis_core: Turn on the TPM before probing IRQ's"
  (bsc#1159152).
- tpm: Revert "tpm_tis_core: Set TPM_CHIP_FLAG_IRQ before probing
  for interrupts" (bsc#1159152).
- tpm: Revert "tpm_tis: reserve chip for duration of
  tpm_tis_core_init" (bsc#1159152).
- USB: Fix: Don't skip endpoint descriptors with maxpacket=0
  (bsc#1159811).
- commit 52394e7
* Mon Jan  6 2020 mkubecek@suse.cz
- Update to 5.5-rc5
- commit 288dac0
* Sun Jan  5 2020 jslaby@suse.cz
- Linux 5.4.8 (bnc#1012628).
- Revert "MIPS: futex: Restore \n after sync instructions"
  (bnc#1012628).
- Revert "MIPS: futex: Emit Loongson3 sync workarounds within asm"
  (bnc#1012628).
- scsi: lpfc: Fix spinlock_irq issues in lpfc_els_flush_cmd()
  (bnc#1012628).
- scsi: lpfc: Fix discovery failures when target device
  connectivity bounces (bnc#1012628).
- scsi: mpt3sas: Fix clear pending bit in ioctl status
  (bnc#1012628).
- scsi: lpfc: Fix locking on mailbox command completion
  (bnc#1012628).
- scsi: mpt3sas: Reject NVMe Encap cmnds to unsupported HBA
  (bnc#1012628).
- gpio: mxc: Only get the second IRQ when there is more than
  one IRQ (bnc#1012628).
- scsi: lpfc: Fix list corruption in lpfc_sli_get_iocbq
  (bnc#1012628).
- Input: atmel_mxt_ts - disable IRQ across suspend (bnc#1012628).
- f2fs: fix to update time in lazytime mode (bnc#1012628).
- powerpc/papr_scm: Fix an off-by-one check in papr_scm_meta_{get,
  set} (bnc#1012628).
- tools/power/x86/intel-speed-select: Remove warning for unused
  result (bnc#1012628).
- platform/x86: peaq-wmi: switch to using polled mode of input
  devices (bnc#1012628).
- iommu: rockchip: Free domain on .domain_free (bnc#1012628).
- iommu/tegra-smmu: Fix page tables in > 4 GiB memory
  (bnc#1012628).
- dmaengine: xilinx_dma: Clear desc_pendingcount in
  xilinx_dma_reset (bnc#1012628).
- scsi: target: compare full CHAP_A Algorithm strings
  (bnc#1012628).
- scsi: lpfc: Fix hardlockup in lpfc_abort_handler (bnc#1012628).
- scsi: lpfc: Fix SLI3 hba in loop mode not discovering devices
  (bnc#1012628).
- scsi: csiostor: Don't enable IRQs too early (bnc#1012628).
- scsi: hisi_sas: Replace in_softirq() check in
  hisi_sas_task_exec() (bnc#1012628).
- scsi: hisi_sas: Delete the debugfs folder of hisi_sas when
  the probe fails (bnc#1012628).
- powerpc/pseries: Mark accumulate_stolen_time() as notrace
  (bnc#1012628).
- powerpc/pseries: Don't fail hash page table insert for bolted
  mapping (bnc#1012628).
- Input: st1232 - do not reset the chip too early (bnc#1012628).
- selftests/powerpc: Fixup clobbers for TM tests (bnc#1012628).
- powerpc/tools: Don't quote $objdump in scripts (bnc#1012628).
- dma-debug: add a schedule point in debug_dma_dump_mappings()
  (bnc#1012628).
- dma-mapping: Add vmap checks to dma_map_single() (bnc#1012628).
- dma-mapping: fix handling of dma-ranges for reserved memory
  (again) (bnc#1012628).
- dmaengine: fsl-qdma: Handle invalid qdma-queue0 IRQ
  (bnc#1012628).
- leds: lm3692x: Handle failure to probe the regulator
  (bnc#1012628).
- leds: an30259a: add a check for devm_regmap_init_i2c
  (bnc#1012628).
- leds: trigger: netdev: fix handling on interface rename
  (bnc#1012628).
- clocksource/drivers/asm9260: Add a check for of_clk_get
  (bnc#1012628).
- clocksource/drivers/timer-of: Use unique device name instead
  of timer (bnc#1012628).
- dtc: Use pkg-config to locate libyaml (bnc#1012628).
- selftests/powerpc: Skip tm-signal-sigreturn-nt if TM not
  available (bnc#1012628).
- powerpc/security/book3s64: Report L1TF status in sysfs
  (bnc#1012628).
- powerpc/book3s64/hash: Add cond_resched to avoid soft lockup
  warning (bnc#1012628).
- ext4: update direct I/O read lock pattern for IOCB_NOWAIT
  (bnc#1012628).
- ext4: iomap that extends beyond EOF should be marked dirty
  (bnc#1012628).
- jbd2: Fix statistics for the number of logged blocks
  (bnc#1012628).
- scsi: tracing: Fix handling of TRANSFER LENGTH == 0 for READ(6)
  and WRITE(6) (bnc#1012628).
- scsi: lpfc: Fix unexpected error messages during RSCN handling
  (bnc#1012628).
- scsi: lpfc: Fix duplicate unreg_rpi error in port offline flow
  (bnc#1012628).
- f2fs: fix to update dir's i_pino during cross_rename
  (bnc#1012628).
- clk: qcom: smd: Add missing pnoc clock (bnc#1012628).
- clk: qcom: Allow constant ratio freq tables for rcg
  (bnc#1012628).
- clk: clk-gpio: propagate rate change to parent (bnc#1012628).
- irqchip/irq-bcm7038-l1: Enable parent IRQ if necessary
  (bnc#1012628).
- irqchip: ingenic: Error out if IRQ domain creation failed
  (bnc#1012628).
- fs/quota: handle overflows of sysctl fs.quota.* and report as
  unsigned long (bnc#1012628).
- iommu/arm-smmu-v3: Don't display an error when IRQ lines are
  missing (bnc#1012628).
- i2c: stm32f7: fix & reorder remove & probe error handling
  (bnc#1012628).
- iomap: fix return value of iomap_dio_bio_actor on 32bit systems
  (bnc#1012628).
- Input: ili210x - handle errors from input_mt_init_slots()
  (bnc#1012628).
- scsi: lpfc: fix: Coverity: lpfc_cmpl_els_rsp(): Null pointer
  dereferences (bnc#1012628).
- scsi: zorro_esp: Limit DMA transfers to 65536 bytes (except
  on Fastlane) (bnc#1012628).
- PCI: rpaphp: Fix up pointer to first drc-info entry
  (bnc#1012628).
- scsi: ufs: fix potential bug which ends in system hang
  (bnc#1012628).
- powerpc/pseries/cmm: Implement release() function for sysfs
  device (bnc#1012628).
- PCI: rpaphp: Don't rely on firmware feature to imply drc-info
  support (bnc#1012628).
- PCI: rpaphp: Annotate and correctly byte swap DRC properties
  (bnc#1012628).
- PCI: rpaphp: Correctly match ibm, my-drc-index to drc-name
  when using drc-info (bnc#1012628).
- powerpc/security: Fix wrong message when RFI Flush is disable
  (bnc#1012628).
- powerpc/eeh: differentiate duplicate detection message
  (bnc#1012628).
- powerpc/book3s/mm: Update Oops message to print the correct
  translation in use (bnc#1012628).
- scsi: atari_scsi: sun3_scsi: Set sg_tablesize to 1 instead of
  SG_NONE (bnc#1012628).
- clk: pxa: fix one of the pxa RTC clocks (bnc#1012628).
- bcache: at least try to shrink 1 node in bch_mca_scan()
  (bnc#1012628).
- HID: quirks: Add quirk for HP MSU1465 PIXART OEM mouse
  (bnc#1012628).
- dt-bindings: Improve validation build error handling
  (bnc#1012628).
- HID: logitech-hidpp: Silence intermittent get_battery_capacity
  errors (bnc#1012628).
- HID: i2c-hid: fix no irq after reset on raydium 3118
  (bnc#1012628).
- ARM: 8937/1: spectre-v2: remove Brahma-B53 from hardening
  (bnc#1012628).
- libnvdimm/btt: fix variable 'rc' set but not used (bnc#1012628).
- HID: Improve Windows Precision Touchpad detection (bnc#1012628).
- HID: rmi: Check that the RMI_STARTED bit is set before
  unregistering the RMI transport device (bnc#1012628).
- watchdog: imx7ulp: Fix reboot hang (bnc#1012628).
- watchdog: prevent deferral of watchdogd wakeup on RT
  (bnc#1012628).
- watchdog: Fix the race between the release of watchdog_core_data
  and cdev (bnc#1012628).
- powerpc/fixmap: Use __fix_to_virt() instead of fix_to_virt()
  (bnc#1012628).
- scsi: pm80xx: Fix for SATA device discovery (bnc#1012628).
- scsi: ufs: Fix error handing during hibern8 enter (bnc#1012628).
- scsi: scsi_debug: num_tgts must be >= 0 (bnc#1012628).
- scsi: NCR5380: Add disconnect_mask module parameter
  (bnc#1012628).
- scsi: target: core: Release SPC-2 reservations when closing
  a session (bnc#1012628).
- scsi: ufs: Fix up auto hibern8 enablement (bnc#1012628).
- scsi: iscsi: Don't send data to unbound connection
  (bnc#1012628).
- scsi: target: iscsi: Wait for all commands to finish before
  freeing a session (bnc#1012628).
- f2fs: Fix deadlock in f2fs_gc() context during atomic files
  handling (bnc#1012628).
- habanalabs: skip VA block list update in reset flow
  (bnc#1012628).
- gpio/mpc8xxx: fix qoriq GPIO reading (bnc#1012628).
- platform/x86: intel_pmc_core: Fix the SoC naming inconsistency
  (bnc#1012628).
- platform/x86: intel_pmc_core: Add Comet Lake (CML) platform
  support to intel_pmc_core driver (bnc#1012628).
- gpio: mpc8xxx: Don't overwrite default irq_set_type callback
  (bnc#1012628).
- gpio: lynxpoint: Setup correct IRQ handlers (bnc#1012628).
- tools/power/x86/intel-speed-select: Ignore missing config level
  (bnc#1012628).
- Drivers: hv: vmbus: Fix crash handler reset of Hyper-V synic
  (bnc#1012628).
- apparmor: fix unsigned len comparison with less than zero
  (bnc#1012628).
- drm/amdgpu: Call find_vma under mmap_sem (bnc#1012628).
- scripts/kallsyms: fix definitely-lost memory leak (bnc#1012628).
- powerpc: Don't add -mabi= flags when building with Clang
  (bnc#1012628).
- cifs: Fix use-after-free bug in cifs_reconnect() (bnc#1012628).
- um: virtio: Keep reading on -EAGAIN (bnc#1012628).
- io_uring: io_allocate_scq_urings() should return a sane state
  (bnc#1012628).
- of: unittest: fix memory leak in attach_node_and_children
  (bnc#1012628).
- cdrom: respect device capabilities during opening action
  (bnc#1012628).
- cifs: move cifsFileInfo_put logic into a work-queue
  (bnc#1012628).
- perf diff: Use llabs() with 64-bit values (bnc#1012628).
- perf script: Fix brstackinsn for AUXTRACE (bnc#1012628).
- perf regs: Make perf_reg_name() return "unknown" instead of NULL
  (bnc#1012628).
- s390/zcrypt: handle new reply code FILTERED_BY_HYPERVISOR
  (bnc#1012628).
- mailbox: imx: Clear the right interrupts at shutdown
  (bnc#1012628).
- libfdt: define INT32_MAX and UINT32_MAX in libfdt_env.h
  (bnc#1012628).
- s390/unwind: filter out unreliable bogus %%r14 (bnc#1012628).
- s390/cpum_sf: Check for SDBT and SDB consistency (bnc#1012628).
- ocfs2: fix passing zero to 'PTR_ERR' warning (bnc#1012628).
- mailbox: imx: Fix Tx doorbell shutdown path (bnc#1012628).
- s390: disable preemption when switching to nodat stack with
  CALL_ON_STACK (bnc#1012628).
- selftests: vm: add fragment CONFIG_TEST_VMALLOC (bnc#1012628).
- mm/hugetlbfs: fix error handling when setting up mounts
  (bnc#1012628).
- kernel: sysctl: make drop_caches write-only (bnc#1012628).
- userfaultfd: require CAP_SYS_PTRACE for UFFD_FEATURE_EVENT_FORK
  (bnc#1012628).
- Revert "powerpc/vcpu: Assume dedicated processors as
  non-preempt" (bnc#1012628).
- sctp: fix err handling of stream initialization (bnc#1012628).
- Revert "iwlwifi: assign directly to iwl_trans->cfg in QuZ
  detection" (bnc#1012628).
- netfilter: ebtables: compat: reject all padding in
  matches/watchers (bnc#1012628).
- 6pack,mkiss: fix possible deadlock (bnc#1012628).
- powerpc: Fix __clear_user() with KUAP enabled (bnc#1012628).
- net/smc: add fallback check to connect() (bnc#1012628).
- netfilter: bridge: make sure to pull arp header in
  br_nf_forward_arp() (bnc#1012628).
- inetpeer: fix data-race in inet_putpeer / inet_putpeer
  (bnc#1012628).
- net: add a READ_ONCE() in skb_peek_tail() (bnc#1012628).
- net: icmp: fix data-race in cmp_global_allow() (bnc#1012628).
- hrtimer: Annotate lockless access to timer->state (bnc#1012628).
- tomoyo: Don't use nifty names on sockets (bnc#1012628).
- uaccess: disallow > INT_MAX copy sizes (bnc#1012628).
- drm: limit to INT_MAX in create_blob ioctl (bnc#1012628).
- xfs: fix mount failure crash on invalid iclog memory access
  (bnc#1012628).
- cxgb4/cxgb4vf: fix flow control display for auto negotiation
  (bnc#1012628).
- net: dsa: bcm_sf2: Fix IP fragment location and behavior
  (bnc#1012628).
- net/mlxfw: Fix out-of-memory error in mfa2 flash burning
  (bnc#1012628).
- net: phy: aquantia: add suspend / resume ops for AQR105
  (bnc#1012628).
- net/sched: act_mirred: Pull mac prior redir to non
  mac_header_xmit device (bnc#1012628).
- net/sched: add delete_empty() to filters and use it in
  cls_flower (bnc#1012628).
- net_sched: sch_fq: properly set sk->sk_pacing_status
  (bnc#1012628).
- net: stmmac: dwmac-meson8b: Fix the RGMII TX delay on
  Meson8b/8m2 SoCs (bnc#1012628).
- ptp: fix the race between the release of ptp_clock and cdev
  (bnc#1012628).
- tcp: Fix highest_sack and highest_sack_seq (bnc#1012628).
- udp: fix integer overflow while computing available space in
  sk_rcvbuf (bnc#1012628).
- bnxt_en: Fix MSIX request logic for RDMA driver (bnc#1012628).
- bnxt_en: Free context memory in the open path if firmware has
  been reset (bnc#1012628).
- bnxt_en: Return error if FW returns more data than dump length
  (bnc#1012628).
- bnxt_en: Fix bp->fw_health allocation and free logic
  (bnc#1012628).
- bnxt_en: Remove unnecessary NULL checks for fw_health
  (bnc#1012628).
- bnxt_en: Fix the logic that creates the health reporters
  (bnc#1012628).
- bnxt_en: Add missing devlink health reporters for VFs
  (bnc#1012628).
- mlxsw: spectrum_router: Skip loopback RIFs during MAC validation
  (bnc#1012628).
- mlxsw: spectrum: Use dedicated policer for VRRP packets
  (bnc#1012628).
- net: add bool confirm_neigh parameter for dst_ops.update_pmtu
  (bnc#1012628).
- ip6_gre: do not confirm neighbor when do pmtu update
  (bnc#1012628).
- gtp: do not confirm neighbor when do pmtu update (bnc#1012628).
- net/dst: add new function skb_dst_update_pmtu_no_confirm
  (bnc#1012628).
- tunnel: do not confirm neighbor when do pmtu update
  (bnc#1012628).
- vti: do not confirm neighbor when do pmtu update (bnc#1012628).
- sit: do not confirm neighbor when do pmtu update (bnc#1012628).
- net/dst: do not confirm neighbor for vxlan and geneve pmtu
  update (bnc#1012628).
- net: dsa: sja1105: Reconcile the meaning of TPID and TPID2
  for E/T and P/Q/R/S (bnc#1012628).
- net: marvell: mvpp2: phylink requires the link interrupt
  (bnc#1012628).
- gtp: fix wrong condition in gtp_genl_dump_pdp() (bnc#1012628).
- gtp: avoid zero size hashtable (bnc#1012628).
- bonding: fix active-backup transition after link failure
  (bnc#1012628).
- tcp: do not send empty skb from tcp_write_xmit() (bnc#1012628).
- tcp/dccp: fix possible race __inet_lookup_established()
  (bnc#1012628).
- hv_netvsc: Fix tx_table init in rndis_set_subchannel()
  (bnc#1012628).
- gtp: fix an use-after-free in ipv4_pdp_find() (bnc#1012628).
- gtp: do not allow adding duplicate tid and ms_addr pdp context
  (bnc#1012628).
- bnxt: apply computed clamp value for coalece parameter
  (bnc#1012628).
- ipv6/addrconf: only check invalid header values when
  NETLINK_F_STRICT_CHK is set (bnc#1012628).
- net: phylink: fix interface passed to mac_link_up (bnc#1012628).
- net: ena: fix napi handler misbehavior when the napi budget
  is zero (bnc#1012628).
- vhost/vsock: accept only packets with the right dst_cid
  (bnc#1012628).
- mmc: sdhci-of-esdhc: fix up erratum A-008171 workaround
  (bnc#1012628).
- mmc: sdhci-of-esdhc: re-implement erratum A-009204 workaround
  (bnc#1012628).
- mm/hugetlbfs: fix for_each_hstate() loop in init_hugetlbfs_fs()
  (bnc#1012628).
- commit 582f5cb
* Fri Jan  3 2020 jslaby@suse.cz
- Update config files.
  Turn off CONFIG_HARDENED_USERCOPY as it causes issues on s390
  (bnc#1156053). Until this gets resolved upstream...
- commit 76565ad
* Fri Jan  3 2020 jslaby@suse.cz
- Update
  patches.kernel.org/5.4.3-088-vcs-prevent-write-access-to-vcsu-devices.patch
  (bnc#1012628 CVE-2019-19252 bnc#1157813).
- commit d0d7407
* Wed Jan  1 2020 jslaby@suse.cz
- blacklist.conf: add one
- commit 34ebd00
* Wed Jan  1 2020 jslaby@suse.cz
- md: make sure desc_nr less than MD_SB_DISKS (git-fixes).
- commit 7b09cf8
* Tue Dec 31 2019 jslaby@suse.cz
- Linux 5.4.7 (bnc#1012628).
- af_packet: set defaule value for tmo (bnc#1012628).
- fjes: fix missed check in fjes_acpi_add (bnc#1012628).
- mod_devicetable: fix PHY module format (bnc#1012628).
- net: dst: Force 4-byte alignment of dst_metrics (bnc#1012628).
- net: gemini: Fix memory leak in gmac_setup_txqs (bnc#1012628).
- net: hisilicon: Fix a BUG trigered by wrong bytes_compl
  (bnc#1012628).
- net: nfc: nci: fix a possible sleep-in-atomic-context bug in
  nci_uart_tty_receive() (bnc#1012628).
- net: phy: ensure that phy IDs are correctly typed (bnc#1012628).
- net: qlogic: Fix error paths in ql_alloc_large_buffers()
  (bnc#1012628).
- net-sysfs: Call dev_hold always in rx_queue_add_kobject
  (bnc#1012628).
- net: usb: lan78xx: Fix suspend/resume PHY register access error
  (bnc#1012628).
- nfp: flower: fix stats id allocation (bnc#1012628).
- qede: Disable hardware gro when xdp prog is installed
  (bnc#1012628).
- qede: Fix multicast mac configuration (bnc#1012628).
- sctp: fix memleak on err handling of stream initialization
  (bnc#1012628).
- sctp: fully initialize v4 addr in some functions (bnc#1012628).
- selftests: forwarding: Delete IPv6 address at the end
  (bnc#1012628).
- neighbour: remove neigh_cleanup() method (bnc#1012628).
- bonding: fix bond_neigh_init() (bnc#1012628).
- net: ena: fix default tx interrupt moderation interval
  (bnc#1012628).
- net: ena: fix issues in setting interrupt moderation params
  in ethtool (bnc#1012628).
- dpaa2-ptp: fix double free of the ptp_qoriq IRQ (bnc#1012628).
- mlxsw: spectrum_router: Remove unlikely user-triggerable warning
  (bnc#1012628).
- net: ethernet: ti: davinci_cpdma: fix warning "device driver
  frees DMA memory with different size" (bnc#1012628).
- net: stmmac: platform: Fix MDIO init for platforms without PHY
  (bnc#1012628).
- net: dsa: b53: Fix egress flooding settings (bnc#1012628).
- NFC: nxp-nci: Fix probing without ACPI (bnc#1012628).
- btrfs: don't double lock the subvol_sem for rename exchange
  (bnc#1012628).
- btrfs: do not call synchronize_srcu() in inode_tree_del
  (bnc#1012628).
- Btrfs: make tree checker detect checksum items with overlapping
  ranges (bnc#1012628).
- btrfs: return error pointer from alloc_test_extent_buffer
  (bnc#1012628).
- Btrfs: fix missing data checksums after replaying a log tree
  (bnc#1012628).
- btrfs: send: remove WARN_ON for readonly mount (bnc#1012628).
- btrfs: abort transaction after failed inode updates in
  create_subvol (bnc#1012628).
- btrfs: skip log replay on orphaned roots (bnc#1012628).
- btrfs: do not leak reloc root if we fail to read the fs root
  (bnc#1012628).
- btrfs: handle ENOENT in btrfs_uuid_tree_iterate (bnc#1012628).
- Btrfs: fix removal logic of the tree mod log that leads to
  use-after-free issues (bnc#1012628).
- ALSA: pcm: Avoid possible info leaks from PCM stream buffers
  (bnc#1012628).
- ALSA: hda/ca0132 - Keep power on during processing DSP response
  (bnc#1012628).
- ALSA: hda/ca0132 - Avoid endless loop (bnc#1012628).
- ALSA: hda/ca0132 - Fix work handling in delayed HP detection
  (bnc#1012628).
- drm/vc4/vc4_hdmi: fill in connector info (bnc#1012628).
- drm/virtio: switch virtio_gpu_wait_ioctl() to gem helper
  (bnc#1012628).
- drm: mst: Fix query_payload ack reply struct (bnc#1012628).
- drm/mipi-dbi: fix a loop in debugfs code (bnc#1012628).
- drm/panel: Add missing drm_panel_init() in panel drivers
  (bnc#1012628).
- drm: exynos: exynos_hdmi: use cec_notifier_conn_(un)register
  (bnc#1012628).
- drm: Use EOPNOTSUPP, not ENOTSUPP (bnc#1012628).
- drm/amd/display: verify stream link before link test
  (bnc#1012628).
- drm/bridge: analogix-anx78xx: silence -EPROBE_DEFER warnings
  (bnc#1012628).
- drm/amd/display: OTC underflow fix (bnc#1012628).
- iio: max31856: add missing of_node and parent references to
  iio_dev (bnc#1012628).
- iio: light: bh1750: Resolve compiler warning and make code
  more readable (bnc#1012628).
- drm/amdgpu/sriov: add ring_stop before ring_create in psp v11
  code (bnc#1012628).
- drm/amdgpu: grab the id mgr lock while accessing passid_mapping
  (bnc#1012628).
- drm/ttm: return -EBUSY on pipelining with no_gpu_wait (v2)
  (bnc#1012628).
- drm/amd/display: Rebuild mapped resources after pipe split
  (bnc#1012628).
- ath10k: add cleanup in ath10k_sta_state() (bnc#1012628).
- drm/amd/display: Handle virtual signal type in disable_link()
  (bnc#1012628).
- ath10k: Check if station exists before forwarding tx airtime
  report (bnc#1012628).
- spi: Add call to spi_slave_abort() function when spidev driver
  is released (bnc#1012628).
- drm/meson: vclk: use the correct G12A frac max value
  (bnc#1012628).
- staging: rtl8192u: fix multiple memory leaks on error path
  (bnc#1012628).
- staging: rtl8188eu: fix possible null dereference (bnc#1012628).
- rtlwifi: prevent memory leak in rtl_usb_probe (bnc#1012628).
- Revert "pinctrl: sh-pfc: r8a77990: Fix MOD_SEL1 bit30 when
  using SSI_SCK2 and SSI_WS2" (bnc#1012628).
- Revert "pinctrl: sh-pfc: r8a77990: Fix MOD_SEL1 bit31 when
  using SIM0_D" (bnc#1012628).
- ath10k: fix backtrace on coredump (bnc#1012628).
- IB/iser: bound protection_sg size by data_sg size (bnc#1012628).
- drm/komeda: Workaround for broken FLIP_COMPLETE timestamps
  (bnc#1012628).
- spi: gpio: prevent memory leak in spi_gpio_probe (bnc#1012628).
- media: am437x-vpfe: Setting STD to current value is not an error
  (bnc#1012628).
- media: cedrus: fill in bus_info for media device (bnc#1012628).
- media: seco-cec: Add a missing 'release_region()' in an error
  handling path (bnc#1012628).
- media: vim2m: Fix abort issue (bnc#1012628).
- media: vim2m: Fix BUG_ON in vim2m_device_release()
  (bnc#1012628).
- media: max2175: Fix build error without CONFIG_REGMAP_I2C
  (bnc#1012628).
- media: ov6650: Fix control handler not freed on init error
  (bnc#1012628).
- media: i2c: ov2659: fix s_stream return value (bnc#1012628).
- media: ov6650: Fix crop rectangle alignment not passed back
  (bnc#1012628).
- media: i2c: ov2659: Fix missing 720p register config
  (bnc#1012628).
- media: ov6650: Fix stored frame format not in sync with hardware
  (bnc#1012628).
- media: ov6650: Fix stored crop rectangle not in sync with
  hardware (bnc#1012628).
- tools/power/cpupower: Fix initializer override in
  hsw_ext_cstates (bnc#1012628).
- media: venus: core: Fix msm8996 frequency table (bnc#1012628).
- ath10k: fix offchannel tx failure when no
  ath10k_mac_tx_frm_has_freq (bnc#1012628).
- media: vimc: Fix gpf in rmmod path when stream is active
  (bnc#1012628).
- drm/amd/display: Set number of pipes to 1 if the second pipe
  was disabled (bnc#1012628).
- pinctrl: devicetree: Avoid taking direct reference to device
  name string (bnc#1012628).
- drm/sun4i: dsi: Fix TCON DRQ set bits (bnc#1012628).
- drm/amdkfd: fix a potential NULL pointer dereference (v2)
  (bnc#1012628).
- x86/math-emu: Check __copy_from_user() result (bnc#1012628).
- drm/amd/powerplay: A workaround to GPU RESET on APU
  (bnc#1012628).
- selftests/bpf: Correct path to include msg + path (bnc#1012628).
- drm/amd/display: set minimum abm backlight level (bnc#1012628).
- media: venus: Fix occasionally failures to suspend
  (bnc#1012628).
- rtw88: fix NSS of hw_cap (bnc#1012628).
- drm/amd/display: fix struct init in update_bounding_box
  (bnc#1012628).
- usb: renesas_usbhs: add suspend event support in gadget mode
  (bnc#1012628).
- crypto: aegis128-neon - use Clang compatible cflags for ARM
  (bnc#1012628).
- hwrng: omap3-rom - Call clk_disable_unprepare() on exit only
  if not idled (bnc#1012628).
- regulator: max8907: Fix the usage of uninitialized variable
  in max8907_regulator_probe() (bnc#1012628).
- tools/memory-model: Fix data race detection for unordered
  store and load (bnc#1012628).
- media: flexcop-usb: fix NULL-ptr deref in
  flexcop_usb_transfer_init() (bnc#1012628).
- media: cec-funcs.h: add status_req checks (bnc#1012628).
- media: meson/ao-cec: move cec_notifier_cec_adap_register after
  hw setup (bnc#1012628).
- drm/bridge: dw-hdmi: Refuse DDC/CI transfers on the internal
  I2C controller (bnc#1012628).
- samples: pktgen: fix proc_cmd command result check logic
  (bnc#1012628).
- block: Fix writeback throttling W=1 compiler warnings
  (bnc#1012628).
- drm/amdkfd: Fix MQD size calculation (bnc#1012628).
- MIPS: futex: Emit Loongson3 sync workarounds within asm
  (bnc#1012628).
- mwifiex: pcie: Fix memory leak in mwifiex_pcie_init_evt_ring
  (bnc#1012628).
- drm/drm_vblank: Change EINVAL by the correct errno
  (bnc#1012628).
- selftests/bpf: Fix btf_dump padding test case (bnc#1012628).
- libbpf: Fix struct end padding in btf_dump (bnc#1012628).
- libbpf: Fix passing uninitialized bytes to setsockopt
  (bnc#1012628).
- net/smc: increase device refcount for added link group
  (bnc#1012628).
- team: call RCU read lock when walking the port_list
  (bnc#1012628).
- media: cx88: Fix some error handling path in 'cx8800_initdev()'
  (bnc#1012628).
- crypto: inside-secure - Fix a maybe-uninitialized warning
  (bnc#1012628).
- crypto: aegis128/simd - build 32-bit ARM for v8 architecture
  explicitly (bnc#1012628).
- misc: fastrpc: fix memory leak from miscdev->name (bnc#1012628).
- ASoC: SOF: enable sync_write in hdac_bus (bnc#1012628).
- media: ti-vpe: vpe: Fix Motion Vector vpdma stride
  (bnc#1012628).
- media: ti-vpe: vpe: fix a v4l2-compliance warning about invalid
  pixel format (bnc#1012628).
- media: ti-vpe: vpe: fix a v4l2-compliance failure about frame
  sequence number (bnc#1012628).
- media: ti-vpe: vpe: Make sure YUYV is set as default format
  (bnc#1012628).
- media: ti-vpe: vpe: fix a v4l2-compliance failure causing a
  kernel panic (bnc#1012628).
- media: ti-vpe: vpe: ensure buffers are cleaned up properly in
  abort cases (bnc#1012628).
- drm/amd/display: Properly round nominal frequency for SPD
  (bnc#1012628).
- drm/amd/display: wait for set pipe mcp command completion
  (bnc#1012628).
- media: ti-vpe: vpe: fix a v4l2-compliance failure about invalid
  sizeimage (bnc#1012628).
- drm/amd/display: add new active dongle to existent w/a
  (bnc#1012628).
- syscalls/x86: Use the correct function type in SYSCALL_DEFINE0
  (bnc#1012628).
- drm/amd/display: Fix dongle_caps containing stale information
  (bnc#1012628).
- extcon: sm5502: Reset registers during initialization
  (bnc#1012628).
- drm/amd/display: Program DWB watermarks from correct state
  (bnc#1012628).
- x86/mm: Use the correct function type for native_set_fixmap()
  (bnc#1012628).
- ath10k: Correct error handling of dma_map_single()
  (bnc#1012628).
- rtw88: coex: Set 4 slot mode for A2DP (bnc#1012628).
- drm/bridge: dw-hdmi: Restore audio when setting a mode
  (bnc#1012628).
- perf test: Report failure for mmap events (bnc#1012628).
- perf report: Add warning when libunwind not compiled in
  (bnc#1012628).
- perf test: Avoid infinite loop for task exit case (bnc#1012628).
- perf vendor events arm64: Fix Hisi hip08 DDRC PMU eventname
  (bnc#1012628).
- usb: usbfs: Suppress problematic bind and unbind uevents
  (bnc#1012628).
- drm/amd/powerplay: avoid disabling ECC if RAS is enabled for
  VEGA20 (bnc#1012628).
- iio: adc: max1027: Reset the device at probe time (bnc#1012628).
- Bluetooth: btusb: avoid unused function warning (bnc#1012628).
- Bluetooth: missed cpu_to_le16 conversion in hci_init4_req
  (bnc#1012628).
- Bluetooth: Workaround directed advertising bug in Broadcom
  controllers (bnc#1012628).
- Bluetooth: hci_core: fix init for HCI_USER_CHANNEL
  (bnc#1012628).
- bpf/stackmap: Fix deadlock with rq_lock in bpf_get_stack()
  (bnc#1012628).
- x86/mce: Lower throttling MCE messages' priority to warning
  (bnc#1012628).
- drm/amd/display: enable hostvm based on roimmu active for dcn2.1
  (bnc#1012628).
- drm/amd/display: fix header for RN clk mgr (bnc#1012628).
- drm/amdgpu: fix amdgpu trace event print string format error
  (bnc#1012628).
- staging: iio: ad9834: add a check for devm_clk_get
  (bnc#1012628).
- power: supply: cpcap-battery: Check voltage before
  orderly_poweroff (bnc#1012628).
- perf tests: Disable bp_signal testing for arm64 (bnc#1012628).
- selftests/bpf: Make a copy of subtest name (bnc#1012628).
- net: hns3: log and clear hardware error after reset complete
  (bnc#1012628).
- RDMA/hns: Fix wrong parameters when initial mtt of srq->idx_que
  (bnc#1012628).
- drm/gma500: fix memory disclosures due to uninitialized bytes
  (bnc#1012628).
- ASoC: soc-pcm: fixup dpcm_prune_paths() loop continue
  (bnc#1012628).
- rtl8xxxu: fix RTL8723BU connection failure issue after warm
  reboot (bnc#1012628).
- RDMA/siw: Fix SQ/RQ drain logic (bnc#1012628).
- ipmi: Don't allow device module unload when in use
  (bnc#1012628).
- x86/ioapic: Prevent inconsistent state when moving an interrupt
  (bnc#1012628).
- media: cedrus: Fix undefined shift with a SHIFT_AND_MASK_BITS
  macro (bnc#1012628).
- media: aspeed: set hsync and vsync polarities to normal before
  starting mode detection (bnc#1012628).
- drm/nouveau: Don't grab runtime PM refs for HPD IRQs
  (bnc#1012628).
- media: ov6650: Fix stored frame interval not in sync with
  hardware (bnc#1012628).
- media: ad5820: Define entity function (bnc#1012628).
- media: ov5640: Make 2592x1944 mode only available at 15 fps
  (bnc#1012628).
- media: st-mipid02: add a check for devm_gpiod_get_optional
  (bnc#1012628).
- media: imx7-mipi-csis: Add a check for devm_regulator_get
  (bnc#1012628).
- media: aspeed: clear garbage interrupts (bnc#1012628).
- media: smiapp: Register sensor after enabling runtime PM on
  the device (bnc#1012628).
- md: no longer compare spare disk superblock events in super_load
  (bnc#1012628).
- staging: wilc1000: potential corruption in
  wilc_parse_join_bss_param() (bnc#1012628).
- md/bitmap: avoid race window between md_bitmap_resize and
  bitmap_file_clear_bit (bnc#1012628).
- drm: Don't free jobs in wait_event_interruptible()
  (bnc#1012628).
- EDAC/amd64: Set grain per DIMM (bnc#1012628).
- arm64: psci: Reduce the waiting time for cpu_psci_cpu_kill()
  (bnc#1012628).
- drm/amd/display: setting the DIG_MODE to the correct value
  (bnc#1012628).
- i40e: initialize ITRN registers with correct values
  (bnc#1012628).
- drm/amd/display: correctly populate dpp refclk in fpga
  (bnc#1012628).
- i40e: Wrong 'Advertised FEC modes' after set FEC to AUTO
  (bnc#1012628).
- net: phy: dp83867: enable robust auto-mdix (bnc#1012628).
- drm/tegra: sor: Use correct SOR index on Tegra210 (bnc#1012628).
- regulator: core: Release coupled_rdevs on
  regulator_init_coupling() error (bnc#1012628).
- ubsan, x86: Annotate and allow
  __ubsan_handle_shift_out_of_bounds() in uaccess regions
  (bnc#1012628).
- spi: sprd: adi: Add missing lock protection when rebooting
  (bnc#1012628).
- ACPI: button: Add DMI quirk for Medion Akoya E2215T
  (bnc#1012628).
- RDMA/qedr: Fix memory leak in user qp and mr (bnc#1012628).
- RDMA/hns: Fix memory leak on 'context' on error return path
  (bnc#1012628).
- RDMA/qedr: Fix srqs xarray initialization (bnc#1012628).
- RDMA/core: Set DMA parameters correctly (bnc#1012628).
- staging: wilc1000: check if device is initialzied before
  changing vif (bnc#1012628).
- gpu: host1x: Allocate gather copy for host1x (bnc#1012628).
- net: dsa: LAN9303: select REGMAP when LAN9303 enable
  (bnc#1012628).
- phy: renesas: phy-rcar-gen2: Fix the array off by one warning
  (bnc#1012628).
- phy: qcom-usb-hs: Fix extcon double register after power cycle
  (bnc#1012628).
- s390/time: ensure get_clock_monotonic() returns monotonic values
  (bnc#1012628).
- s390: add error handling to perf_callchain_kernel (bnc#1012628).
- s390/mm: add mm_pxd_folded() checks to pxd_free() (bnc#1012628).
- net: hns3: add struct netdev_queue debug info for TX timeout
  (bnc#1012628).
- libata: Ensure ata_port probe has completed before detach
  (bnc#1012628).
- loop: fix no-unmap write-zeroes request behavior (bnc#1012628).
- net/mlx5e: Verify that rule has at least one fwd/drop action
  (bnc#1012628).
- pinctrl: sh-pfc: sh7734: Fix duplicate TCLK1_B (bnc#1012628).
- ALSA: bebob: expand sleep just after breaking connections for
  protocol version 1 (bnc#1012628).
- iio: dln2-adc: fix iio_triggered_buffer_postenable() position
  (bnc#1012628).
- libbpf: Fix error handling in bpf_map__reuse_fd() (bnc#1012628).
- Bluetooth: Fix advertising duplicated flags (bnc#1012628).
- ALSA: pcm: Fix missing check of the new non-cached buffer type
  (bnc#1012628).
- spi: sifive: disable clk when probe fails and remove
  (bnc#1012628).
- ASoC: SOF: imx: fix reverse CONFIG_SND_SOC_SOF_OF dependency
  (bnc#1012628).
- pinctrl: qcom: sc7180: Add missing tile info in
  SDC_QDSD_PINGROUP/UFS_RESET (bnc#1012628).
- pinctrl: amd: fix __iomem annotation in amd_gpio_irq_handler()
  (bnc#1012628).
- ixgbe: protect TX timestamping from API misuse (bnc#1012628).
- cpufreq: sun50i: Fix CPU speed bin detection (bnc#1012628).
- media: rcar_drif: fix a memory disclosure (bnc#1012628).
- media: v4l2-core: fix touch support in v4l_g_fmt (bnc#1012628).
- nvme: introduce "Command Aborted By host" status code
  (bnc#1012628).
- media: staging/imx: Use a shorter name for driver (bnc#1012628).
- nvmem: imx-ocotp: reset error status on probe (bnc#1012628).
- nvmem: core: fix nvmem_cell_write inline function (bnc#1012628).
- ASoC: SOF: topology: set trigger order for FE DAI link
  (bnc#1012628).
- media: vivid: media_device_cleanup was called too early
  (bnc#1012628).
- spi: dw: Fix Designware SPI loopback (bnc#1012628).
- bnx2x: Fix PF-VF communication over multi-cos queues
  (bnc#1012628).
- spi: img-spfi: fix potential double release (bnc#1012628).
- ALSA: timer: Limit max amount of slave instances (bnc#1012628).
- RDMA/core: Fix return code when modify_port isn't supported
  (bnc#1012628).
- drm: msm: a6xx: fix debug bus register configuration
  (bnc#1012628).
- rtlwifi: fix memory leak in rtl92c_set_fw_rsvdpagepkt()
  (bnc#1012628).
- perf probe: Fix to find range-only function instance
  (bnc#1012628).
- perf cs-etm: Fix definition of macro TO_CS_QUEUE_NR
  (bnc#1012628).
- perf probe: Fix to list probe event with correct line number
  (bnc#1012628).
- perf jevents: Fix resource leak in process_mapfile() and main()
  (bnc#1012628).
- perf probe: Walk function lines in lexical blocks (bnc#1012628).
- perf probe: Fix to probe an inline function which has no entry
  pc (bnc#1012628).
- perf probe: Fix to show ranges of variables in functions
  without entry_pc (bnc#1012628).
- perf probe: Fix to show inlined function callsite without
  entry_pc (bnc#1012628).
- libsubcmd: Use -O0 with DEBUG=1 (bnc#1012628).
- perf probe: Fix to probe a function which has no entry pc
  (bnc#1012628).
- perf tools: Fix cross compile for ARM64 (bnc#1012628).
- perf tools: Splice events onto evlist even on error
  (bnc#1012628).
- drm/amdgpu: disallow direct upload save restore list from gfx
  driver (bnc#1012628).
- drm/amd/powerplay: fix struct init in renoir_print_clk_levels
  (bnc#1012628).
- drm/amdgpu: fix potential double drop fence reference
  (bnc#1012628).
- ice: Check for null pointer dereference when setting rings
  (bnc#1012628).
- xen/gntdev: Use select for DMA_SHARED_BUFFER (bnc#1012628).
- perf parse: If pmu configuration fails free terms (bnc#1012628).
- perf probe: Skip overlapped location on searching variables
  (bnc#1012628).
- net: avoid potential false sharing in neighbor related code
  (bnc#1012628).
- perf probe: Return a better scope DIE if there is no best scope
  (bnc#1012628).
- perf probe: Fix to show calling lines of inlined functions
  (bnc#1012628).
- perf probe: Skip end-of-sequence and non statement lines
  (bnc#1012628).
- perf probe: Filter out instances except for inlined subroutine
  and subprogram (bnc#1012628).
- libbpf: Fix negative FD close() in xsk_setup_xdp_prog()
  (bnc#1012628).
- s390/bpf: Use kvcalloc for addrs array (bnc#1012628).
- cgroup: freezer: don't change task and cgroups status
  unnecessarily (bnc#1012628).
- selftests: proc: Make va_max 1MB (bnc#1012628).
- drm/amdgpu: Avoid accidental thread reactivation (bnc#1012628).
- media: exynos4-is: fix wrong mdev and v4l2 dev order in error
  path (bnc#1012628).
- ath10k: fix get invalid tx rate for Mesh metric (bnc#1012628).
- fsi: core: Fix small accesses and unaligned offsets via sysfs
  (bnc#1012628).
- selftests: net: Fix printf format warnings on arm (bnc#1012628).
- media: pvrusb2: Fix oops on tear-down when radio support is
  not present (bnc#1012628).
- soundwire: intel: fix PDI/stream mapping for Bulk (bnc#1012628).
- crypto: atmel - Fix authenc support when it is set to m
  (bnc#1012628).
- ice: delay less (bnc#1012628).
- media: si470x-i2c: add missed operations in remove
  (bnc#1012628).
- media: cedrus: Use helpers to access capture queue
  (bnc#1012628).
- media: v4l2-ctrl: Lock main_hdl on operations of requests_queued
  (bnc#1012628).
- iio: cros_ec_baro: set info_mask_shared_by_all_available field
  (bnc#1012628).
- EDAC/ghes: Fix grain calculation (bnc#1012628).
- media: vicodec: media_device_cleanup was called too early
  (bnc#1012628).
- media: vim2m: media_device_cleanup was called too early
  (bnc#1012628).
- spi: pxa2xx: Add missed security checks (bnc#1012628).
- ASoC: rt5677: Mark reg RT5677_PWR_ANLG2 as volatile
  (bnc#1012628).
- iio: dac: ad5446: Add support for new AD5600 DAC (bnc#1012628).
- bpf, testing: Workaround a verifier failure for test_progs
  (bnc#1012628).
- ASoC: Intel: kbl_rt5663_rt5514_max98927: Add dmic format
  constraint (bnc#1012628).
- net: dsa: sja1105: Disallow management xmit during switch reset
  (bnc#1012628).
- r8169: respect EEE user setting when restarting network
  (bnc#1012628).
- s390/disassembler: don't hide instruction addresses
  (bnc#1012628).
- net: ethernet: ti: Add dependency for TI_DAVINCI_EMAC
  (bnc#1012628).
- nvme: Discard workaround for non-conformant devices
  (bnc#1012628).
- parport: load lowlevel driver if ports not found (bnc#1012628).
- bcache: fix static checker warning in bcache_device_free()
  (bnc#1012628).
- cpufreq: Register drivers only after CPU devices have been
  registered (bnc#1012628).
- qtnfmac: fix debugfs support for multiple cards (bnc#1012628).
- qtnfmac: fix invalid channel information output (bnc#1012628).
- x86/crash: Add a forward declaration of struct kimage
  (bnc#1012628).
- qtnfmac: fix using skb after free (bnc#1012628).
- RDMA/efa: Clear the admin command buffer prior to its submission
  (bnc#1012628).
- tracing: use kvcalloc for tgid_map array allocation
  (bnc#1012628).
- MIPS: ralink: enable PCI support only if driver for mt7621
  SoC is selected (bnc#1012628).
- tracing/kprobe: Check whether the non-suffixed symbol is notrace
  (bnc#1012628).
- bcache: fix deadlock in bcache_allocator (bnc#1012628).
- iwlwifi: mvm: fix unaligned read of rx_pkt_status (bnc#1012628).
- ASoC: wm8904: fix regcache handling (bnc#1012628).
- regulator: core: Let boot-on regulators be powered off
  (bnc#1012628).
- spi: tegra20-slink: add missed clk_unprepare (bnc#1012628).
- tun: fix data-race in gro_normal_list() (bnc#1012628).
- xhci-pci: Allow host runtime PM as default also for Intel Ice
  Lake xHCI (bnc#1012628).
- crypto: virtio - deal with unsupported input sizes
  (bnc#1012628).
- mmc: tmio: Add MMC_CAP_ERASE to allow erase/discard/trim
  requests (bnc#1012628).
- btrfs: don't prematurely free work in end_workqueue_fn()
  (bnc#1012628).
- btrfs: don't prematurely free work in run_ordered_work()
  (bnc#1012628).
- sched/uclamp: Fix overzealous type replacement (bnc#1012628).
- ASoC: wm2200: add missed operations in remove and probe failure
  (bnc#1012628).
- spi: st-ssc4: add missed pm_runtime_disable (bnc#1012628).
- ASoC: wm5100: add missed pm_runtime_disable (bnc#1012628).
- perf/core: Fix the mlock accounting, again (bnc#1012628).
- selftests, bpf: Fix test_tc_tunnel hanging (bnc#1012628).
- selftests, bpf: Workaround an alu32 sub-register spilling issue
  (bnc#1012628).
- bnxt_en: Return proper error code for non-existent NVM variable
  (bnc#1012628).
- net: phy: avoid matching all-ones clause 45 PHY IDs
  (bnc#1012628).
- firmware_loader: Fix labels with comma for builtin firmware
  (bnc#1012628).
- ASoC: Intel: bytcr_rt5640: Update quirk for Acer Switch 10
  SW5-012 2-in-1 (bnc#1012628).
- x86/insn: Add some Intel instructions to the opcode map
  (bnc#1012628).
- net-af_xdp: Use correct number of channels from ethtool
  (bnc#1012628).
- brcmfmac: remove monitor interface when detaching (bnc#1012628).
- perf session: Fix decompression of PERF_RECORD_COMPRESSED
  records (bnc#1012628).
- perf probe: Fix to show function entry line as probe-able
  (bnc#1012628).
- s390/crypto: Fix unsigned variable compared with zero
  (bnc#1012628).
- s390/kasan: support memcpy_real with TRACE_IRQFLAGS
  (bnc#1012628).
- bnxt_en: Improve RX buffer error handling (bnc#1012628).
- iwlwifi: check kasprintf() return value (bnc#1012628).
- fbtft: Make sure string is NULL terminated (bnc#1012628).
- ASoC: soc-pcm: check symmetry before hw_params (bnc#1012628).
- net: ethernet: ti: ale: clean ale tbl on init and intf restart
  (bnc#1012628).
- mt76: fix possible out-of-bound access in
  mt7615_fill_txs/mt7603_fill_txs (bnc#1012628).
- s390/cpumf: Adjust registration of s390 PMU device drivers
  (bnc#1012628).
- crypto: sun4i-ss - Fix 64-bit size_t warnings (bnc#1012628).
- crypto: sun4i-ss - Fix 64-bit size_t warnings on sun4i-ss-hash.c
  (bnc#1012628).
- mac80211: consider QoS Null frames for STA_NULLFUNC_ACKED
  (bnc#1012628).
- crypto: vmx - Avoid weird build failures (bnc#1012628).
- libtraceevent: Fix memory leakage in copy_filter_type
  (bnc#1012628).
- mips: fix build when "48 bits virtual memory" is enabled
  (bnc#1012628).
- drm/amdgpu: fix bad DMA from INTERRUPT_CNTL2 (bnc#1012628).
- ice: Only disable VF state when freeing each VF resources
  (bnc#1012628).
- ice: Fix setting coalesce to handle DCB configuration
  (bnc#1012628).
- net: phy: initialise phydev speed and duplex sanely
  (bnc#1012628).
- tools, bpf: Fix build for 'make -s tools/bpf O=<dir>'
  (bnc#1012628).
- RDMA/bnxt_re: Fix missing le16_to_cpu (bnc#1012628).
- RDMA/bnxt_re: Fix stat push into dma buffer on gen p5 devices
  (bnc#1012628).
- bpf: Provide better register bounds after jmp32 instructions
  (bnc#1012628).
- RDMA/bnxt_re: Fix chip number validation Broadcom's Gen P5
  series (bnc#1012628).
- ibmvnic: Fix completion structure initialization (bnc#1012628).
- net: wireless: intel: iwlwifi: fix GRO_NORMAL packet stalling
  (bnc#1012628).
- MIPS: futex: Restore \n after sync instructions (bnc#1012628).
- btrfs: don't prematurely free work in
  reada_start_machine_worker() (bnc#1012628).
- btrfs: don't prematurely free work in
  scrub_missing_raid56_worker() (bnc#1012628).
- Revert "mmc: sdhci: Fix incorrect switch to HS mode"
  (bnc#1012628).
- mmc: mediatek: fix CMD_TA to 2 for MT8173 HS200/HS400 mode
  (bnc#1012628).
- tpm_tis: reserve chip for duration of tpm_tis_core_init
  (bnc#1012628).
- tpm: fix invalid locking in NONBLOCKING mode (bnc#1012628).
- iommu: fix KASAN use-after-free in iommu_insert_resv_region
  (bnc#1012628).
- iommu: set group default domain before creating direct mappings
  (bnc#1012628).
- iommu/vt-d: Fix dmar pte read access not set error
  (bnc#1012628).
- iommu/vt-d: Set ISA bridge reserved region as relaxable
  (bnc#1012628).
- iommu/vt-d: Allocate reserved region for ISA with correct
  permission (bnc#1012628).
- can: xilinx_can: Fix missing Rx can packets on CANFD2.0
  (bnc#1012628).
- can: m_can: tcan4x5x: add required delay after reset
  (bnc#1012628).
- can: j1939: j1939_sk_bind(): take priv after lock is held
  (bnc#1012628).
- can: flexcan: fix possible deadlock and out-of-order reception
  after wakeup (bnc#1012628).
- can: flexcan: poll MCR_LPM_ACK instead of GPR ACK for stop
  mode acknowledgment (bnc#1012628).
- can: kvaser_usb: kvaser_usb_leaf: Fix some info-leaks to USB
  devices (bnc#1012628).
- selftests: net: tls: remove recv_rcvbuf test (bnc#1012628).
- spi: dw: Correct handling of native chipselect (bnc#1012628).
- spi: cadence: Correct handling of native chipselect
  (bnc#1012628).
- usb: xhci: Fix build warning seen with CONFIG_PM=n
  (bnc#1012628).
- drm/amdgpu: fix uninitialized variable pasid_mapping_needed
  (bnc#1012628).
- ath10k: Revert "ath10k: add cleanup in ath10k_sta_state()"
  (bnc#1012628).
- RDMA/siw: Fix post_recv QP state locking (bnc#1012628).
- md: avoid invalid memory access for array sb->dev_roles
  (bnc#1012628).
- s390/ftrace: fix endless recursion in function_graph tracer
  (bnc#1012628).
- ARM: dts: Fix vcsi regulator to be always-on for droid4 to
  prevent hangs (bnc#1012628).
- can: flexcan: add low power enter/exit acknowledgment helper
  (bnc#1012628).
- usbip: Fix receive error in vhci-hcd when using scatter-gather
  (bnc#1012628).
- usbip: Fix error path of vhci_recv_ret_submit() (bnc#1012628).
- spi: fsl: don't map irq during probe (bnc#1012628).
- spi: fsl: use platform_get_irq() instead of of_irq_to_resource()
  (bnc#1012628).
- efi/memreserve: Register reservations as 'reserved' in
  /proc/iomem (bnc#1012628).
- cpufreq: Avoid leaving stale IRQ work items during CPU offline
  (bnc#1012628).
- KEYS: asymmetric: return ENOMEM if akcipher_request_alloc()
  fails (bnc#1012628).
- mm: vmscan: protect shrinker idr replace with CONFIG_MEMCG
  (bnc#1012628).
- USB: EHCI: Do not return -EPIPE when hub is disconnected
  (bnc#1012628).
- intel_th: pci: Add Comet Lake PCH-V support (bnc#1012628).
- intel_th: pci: Add Elkhart Lake SOC support (bnc#1012628).
- intel_th: Fix freeing IRQs (bnc#1012628).
- intel_th: msu: Fix window switching without windows
  (bnc#1012628).
- platform/x86: hp-wmi: Make buffer for HPWMI_FEATURE2_QUERY
  128 bytes (bnc#1012628).
- staging: comedi: gsc_hpdi: check dma_alloc_coherent() return
  value (bnc#1012628).
- tty/serial: atmel: fix out of range clock divider handling
  (bnc#1012628).
- serial: sprd: Add clearing break interrupt operation
  (bnc#1012628).
- pinctrl: baytrail: Really serialize all register accesses
  (bnc#1012628).
- clk: imx: clk-imx7ulp: Add missing sentinel of ulp_div_table
  (bnc#1012628).
- clk: imx: clk-composite-8m: add lock to gate/mux (bnc#1012628).
- clk: imx: pll14xx: fix clk_pll14xx_wait_lock (bnc#1012628).
- ext4: fix ext4_empty_dir() for directories with holes
  (bnc#1012628).
- ext4: check for directory entries too close to block end
  (bnc#1012628).
- ext4: unlock on error in ext4_expand_extra_isize()
  (bnc#1012628).
- ext4: validate the debug_want_extra_isize mount option at
  parse time (bnc#1012628).
- iocost: over-budget forced IOs should schedule async delay
  (bnc#1012628).
- KVM: PPC: Book3S HV: Fix regression on big endian hosts
  (bnc#1012628).
- kvm: x86: Host feature SSBD doesn't imply guest feature
  SPEC_CTRL_SSBD (bnc#1012628).
- kvm: x86: Host feature SSBD doesn't imply guest feature AMD_SSBD
  (bnc#1012628).
- KVM: arm/arm64: Properly handle faulting of device mappings
  (bnc#1012628).
- KVM: arm64: Ensure 'params' is initialised when looking up
  sys register (bnc#1012628).
- x86/intel: Disable HPET on Intel Coffee Lake H platforms
  (bnc#1012628).
- x86/MCE/AMD: Do not use rdmsr_safe_on_cpu() in smca_configure()
  (bnc#1012628).
- x86/MCE/AMD: Allow Reserved types to be overwritten in
  smca_banks[] (bnc#1012628).
- x86/mce: Fix possibly incorrect severity calculation on AMD
  (bnc#1012628).
- powerpc/vcpu: Assume dedicated processors as non-preempt
  (bnc#1012628).
- powerpc/irq: fix stack overflow verification (bnc#1012628).
- ocxl: Fix concurrent AFU open and device removal (bnc#1012628).
- mmc: sdhci-msm: Correct the offset and value for DDR_CONFIG
  register (bnc#1012628).
- mmc: sdhci-of-esdhc: Revert "mmc: sdhci-of-esdhc: add erratum
  A-009204 support" (bnc#1012628).
- mmc: sdhci: Update the tuning failed messages to pr_debug level
  (bnc#1012628).
- mmc: sdhci-of-esdhc: fix P2020 errata handling (bnc#1012628).
- mmc: sdhci: Workaround broken command queuing on Intel GLK
  (bnc#1012628).
- mmc: sdhci: Add a quirk for broken command queuing
  (bnc#1012628).
- nbd: fix shutdown and recv work deadlock v2 (bnc#1012628).
- iwlwifi: pcie: move power gating workaround earlier in the flow
  (bnc#1012628).
- Update config files.
  CONFIG_SND_SOC_SOF_IMX8_SUPPORT=y to keep CONFIG_SND_SOC_SOF_IMX8=m.
- commit e7419a3
* Mon Dec 30 2019 mkubecek@suse.cz
- Update to 5.5-rc4
- refresh
  patches.suse/vfs-add-super_operations-get_inode_dev
- commit 7e31c5e
* Sun Dec 29 2019 mkubecek@suse.cz
- config: refresh
  Refresh with a new gcc version.
- commit 2d3adcc
* Sat Dec 28 2019 mbrugger@suse.com
- arm64: Add Allwinner crypto modules to config
  Enabel SUN4I and SUN8I based HW crypto blocks.
- commit b496619
* Mon Dec 23 2019 mkubecek@suse.cz
- Update to 5.5-rc3
- refresh configs
- commit acd0797
* Sat Dec 21 2019 jslaby@suse.cz
- Linux 5.4.6 (bnc#1012628).
- ALSA: hda: Fix regression by strip mask fix (bnc#1012628).
- drm/amdgpu: add invalidate semaphore limit for SRIOV and
  picasso in gmc9 (bnc#1012628).
- drm/amdgpu: avoid using invalidate semaphore for picasso
  (bnc#1012628).
- drm/i915/gvt: Fix cmd length check for MI_ATOMIC (bnc#1012628).
- drm/amdgpu/gfx10: re-init clear state buffer after gpu reset
  (bnc#1012628).
- drm/amdgpu/gfx10: explicitly wait for cp idle after halt/unhalt
  (bnc#1012628).
- drm/amdgpu: invalidate mmhub semaphore workaround in gmc9/gmc10
  (bnc#1012628).
- drm/amdgpu: initialize vm_inv_eng0_sem for gfxhub and mmhub
  (bnc#1012628).
- drm/amd/display: add default clocks if not able to fetch them
  (bnc#1012628).
- drm/amd/display: re-enable wait in pipelock, but add timeout
  (bnc#1012628).
- drm/dp_mst: Correct the bug in drm_dp_update_payload_part1()
  (bnc#1012628).
- drm/radeon: fix r1xx/r2xx register checker for POT textures
  (bnc#1012628).
- drm/i915/fbc: Disable fbc by default on all glk+ (bnc#1012628).
- drm/nouveau/kms/nv50-: Limit MST BPC to 8 (bnc#1012628).
- drm/nouveau/kms/nv50-: Store the bpc we're using in
  nv50_head_atom (bnc#1012628).
- drm/nouveau/kms/nv50-: Call outp_atomic_check_view() before
  handling PBN (bnc#1012628).
- scsi: qla2xxx: Fix incorrect SFUB length used for Secure Flash
  Update MB Cmd (bnc#1012628).
- scsi: qla2xxx: Correctly retrieve and interpret active flash
  region (bnc#1012628).
- scsi: qla2xxx: Change discovery state before PLOGI
  (bnc#1012628).
- scsi: qla2xxx: Added support for MPI and PEP regions for ISP28XX
  (bnc#1012628).
- scsi: qla2xxx: Initialize free_work before flushing it
  (bnc#1012628).
- scsi: qla2xxx: Ignore NULL pointer in tcm_qla2xxx_free_mcmd
  (bnc#1012628).
- scsi: iscsi: Fix a potential deadlock in the timeout handler
  (bnc#1012628).
- scsi: ufs: Disable autohibern8 feature in Cadence UFS
  (bnc#1012628).
- dm thin: Flush data device before committing metadata
  (bnc#1012628).
- dm thin metadata: Add support for a pre-commit callback
  (bnc#1012628).
- dm clone: Flush destination device before committing metadata
  (bnc#1012628).
- dm clone metadata: Use a two phase commit (bnc#1012628).
- dm clone metadata: Track exact changes per transaction
  (bnc#1012628).
- dm btree: increase rebalance threshold in __rebalance2()
  (bnc#1012628).
- dm mpath: remove harmful bio-based optimization (bnc#1012628).
- drm: meson: venc: cvbs: fix CVBS mode matching (bnc#1012628).
- drm/mgag200: Flag all G200 SE A machines as broken wrt
  <startadd> (bnc#1012628).
- drm/mgag200: Add workaround for HW that does not support
  'startadd' (bnc#1012628).
- drm/mgag200: Store flags from PCI driver data in device
  structure (bnc#1012628).
- drm/mgag200: Extract device type from flags (bnc#1012628).
- drm/panfrost: Fix a race in panfrost_gem_free_object()
  (bnc#1012628).
- drm/panfrost: Fix a BO leak in panfrost_ioctl_mmap_bo()
  (bnc#1012628).
- drm/panfrost: Fix a race in panfrost_ioctl_madvise()
  (bnc#1012628).
- dma-buf: Fix memory leak in sync_file_merge() (bnc#1012628).
- vfio/pci: call irq_bypass_unregister_producer() before freeing
  irq (bnc#1012628).
- ARM: tegra: Fix FLOW_CTLR_HALT register clobbering by
  tegra_resume() (bnc#1012628).
- ARM: dts: s3c64xx: Fix init order of clock providers
  (bnc#1012628).
- cifs: Fix retrieval of DFS referrals in cifs_mount()
  (bnc#1012628).
- CIFS: Fix NULL pointer dereference in mid callback
  (bnc#1012628).
- CIFS: Do not miss cancelled OPEN responses (bnc#1012628).
- CIFS: Close open handle after interrupted close (bnc#1012628).
- CIFS: Respect O_SYNC and O_DIRECT flags during reconnect
  (bnc#1012628).
- cifs: Don't display RDMA transport on reconnect (bnc#1012628).
- cifs: smbd: Return -ECONNABORTED when trasnport is not in
  connected state (bnc#1012628).
- cifs: smbd: Return -EINVAL when the number of iovs exceeds
  SMBDIRECT_MAX_SGE (bnc#1012628).
- cifs: smbd: Add messages on RDMA session destroy and
  reconnection (bnc#1012628).
- cifs: smbd: Only queue work for error recovery on memory
  registration (bnc#1012628).
- cifs: smbd: Return -EAGAIN when transport is reconnecting
  (bnc#1012628).
- rpmsg: glink: Free pending deferred work on remove
  (bnc#1012628).
- rpmsg: glink: Don't send pending rx_done during remove
  (bnc#1012628).
- rpmsg: glink: Fix rpmsg_register_device err handling
  (bnc#1012628).
- rpmsg: glink: Put an extra reference during cleanup
  (bnc#1012628).
- rpmsg: glink: Fix use after free in open_ack TIMEOUT case
  (bnc#1012628).
- rpmsg: glink: Fix reuse intents memory leak issue (bnc#1012628).
- rpmsg: glink: Set tail pointer to 0 at end of FIFO
  (bnc#1012628).
- xtensa: fix syscall_set_return_value (bnc#1012628).
- xtensa: fix TLB sanity checker (bnc#1012628).
- gfs2: fix glock reference problem in gfs2_trans_remove_revoke
  (bnc#1012628).
- gfs2: Multi-block allocations in gfs2_page_mkwrite
  (bnc#1012628).
- xtensa: use MEMBLOCK_ALLOC_ANYWHERE for KASAN shadow map
  (bnc#1012628).
- block: fix "check bi_size overflow before merge" (bnc#1012628).
- PM / QoS: Redefine FREQ_QOS_MAX_DEFAULT_VALUE to S32_MAX
  (bnc#1012628).
- PCI: Apply Cavium ACS quirk to ThunderX2 and ThunderX3
  (bnc#1012628).
- PCI: rcar: Fix missing MACCTLR register setting in
  initialization sequence (bnc#1012628).
- PCI: Do not use bus number zero from EA capability
  (bnc#1012628).
- PCI/MSI: Fix incorrect MSI-X masking on resume (bnc#1012628).
- PCI: Fix Intel ACS quirk UPDCR register address (bnc#1012628).
- PCI: pciehp: Avoid returning prematurely from sysfs requests
  (bnc#1012628).
- PCI/PM: Always return devices to D0 when thawing (bnc#1012628).
- PCI/switchtec: Read all 64 bits of part_event_bitmap
  (bnc#1012628).
- mmc: core: Re-work HW reset for SDIO cards (bnc#1012628).
- mmc: core: Drop check for mmc_card_is_removable() in
  mmc_rescan() (bnc#1012628).
- mmc: block: Add CMD13 polling for MMC IOCTLS with R1B response
  (bnc#1012628).
- mmc: block: Make card_busy_detect() a bit more generic
  (bnc#1012628).
- USB: Fix incorrect DMA allocations for local memory pool drivers
  (bnc#1012628).
- commit e5f8301
* Thu Dec 19 2019 mkubecek@suse.cz
- rpm/kernel-subpackage-spec: fix kernel-default-base build
  There were some issues with recent changes to subpackage dependencies handling:
- a typo in %%kernel_base_conflicts macro name
- copy/pasted "Recommends:" instead of "Provides:", "Obsoletes:" and
  "Conflicts:
- missing escaping of backslashes in macro expansions
  Fixes: f3b74b0ae86b ("rpm/kernel-subpackage-spec: Unify dependency handling.")
  Fixes: 3fd22e219f77 ("rpm/kernel-subpackage-spec: Fix empty Recommends tag (bsc#1143959)")
- commit 762fd66
* Wed Dec 18 2019 jslaby@suse.cz
- Linux 5.4.5 (bnc#1012628).
- r8169: add missing RX enabling for WoL on RTL8125 (bnc#1012628).
- net: mscc: ocelot: unregister the PTP clock on deinit
  (bnc#1012628).
- ionic: keep users rss hash across lif reset (bnc#1012628).
- xdp: obtain the mem_id mutex before trying to remove an entry
  (bnc#1012628).
- page_pool: do not release pool until inflight == 0
  (bnc#1012628).
- net/mlx5e: ethtool, Fix analysis of speed setting (bnc#1012628).
- net/mlx5e: Fix translation of link mode into speed
  (bnc#1012628).
- net/mlx5e: Fix freeing flow with kfree() and not kvfree()
  (bnc#1012628).
- net/mlx5e: Fix SFF 8472 eeprom length (bnc#1012628).
- act_ct: support asymmetric conntrack (bnc#1012628).
- net/mlx5e: Fix TXQ indices to be sequential (bnc#1012628).
- net: Fixed updating of ethertype in skb_mpls_push()
  (bnc#1012628).
- hsr: fix a NULL pointer dereference in hsr_dev_xmit()
  (bnc#1012628).
- Fixed updating of ethertype in function skb_mpls_pop
  (bnc#1012628).
- gre: refetch erspan header from skb->data after pskb_may_pull()
  (bnc#1012628).
- cls_flower: Fix the behavior using port ranges with hw-offload
  (bnc#1012628).
- net: sched: allow indirect blocks to bind to clsact in TC
  (bnc#1012628).
- net: core: rename indirect block ingress cb function
  (bnc#1012628).
- tcp: Protect accesses to .ts_recent_stamp with
  {READ,WRITE}_ONCE() (bnc#1012628).
- tcp: tighten acceptance of ACKs not matching a child socket
  (bnc#1012628).
- tcp: fix rejected syncookies due to stale timestamps
  (bnc#1012628).
- net: ipv6_stub: use ip6_dst_lookup_flow instead of
  ip6_dst_lookup (bnc#1012628).
- net: ipv6: add net argument to ip6_dst_lookup_flow
  (bnc#1012628).
- net/mlx5e: Query global pause state before setting prio2buffer
  (bnc#1012628).
- tipc: fix ordering of tipc module init and exit routine
  (bnc#1012628).
- tcp: md5: fix potential overestimation of TCP option space
  (bnc#1012628).
- openvswitch: support asymmetric conntrack (bnc#1012628).
- net/tls: Fix return values to avoid ENOTSUPP (bnc#1012628).
- net: thunderx: start phy before starting autonegotiation
  (bnc#1012628).
- net_sched: validate TCA_KIND attribute in tc_chain_tmplt_add()
  (bnc#1012628).
- net: sched: fix dump qlen for sch_mq/sch_mqprio with NOLOCK
  subqueues (bnc#1012628).
- net: ethernet: ti: cpsw: fix extra rx interrupt (bnc#1012628).
- net: dsa: fix flow dissection on Tx path (bnc#1012628).
- net: bridge: deny dev_set_mac_address() when unregistering
  (bnc#1012628).
- mqprio: Fix out-of-bounds access in mqprio_dump (bnc#1012628).
- inet: protect against too small mtu values (bnc#1012628).
- commit 47eef04
* Wed Dec 18 2019 jslaby@suse.cz
- cpuidle: teo: Avoid using "early hits" incorrectly (git-fixes).
- commit 43b8f65
* Wed Dec 18 2019 msuchanek@suse.de
- rpm/kernel-subpackage-spec: Unify dependency handling.
- commit f3b74b0
* Tue Dec 17 2019 jslaby@suse.cz
- rpm/config.sh: set COMPRESS_VMLINUX to xz (bnc#1155921)
- commit 7fe1f4a
* Tue Dec 17 2019 jslaby@suse.cz
- Linux 5.4.4 (bnc#1012628).
- usb: gadget: configfs: Fix missing spin_lock_init()
  (bnc#1012628).
- usb: gadget: pch_udc: fix use after free (bnc#1012628).
- nvme: Namepace identification descriptor list is optional
  (bnc#1012628).
- Revert "nvme: Add quirk for Kingston NVME SSD running FW
  E8FK11.T" (bnc#1012628).
- scsi: lpfc: Fix bad ndlp ptr in xri aborted handling
  (bnc#1012628).
- scsi: zfcp: trace channel log even for FCP command responses
  (bnc#1012628).
- scsi: qla2xxx: Do command completion on abort timeout
  (bnc#1012628).
- scsi: qla2xxx: Fix driver unload hang (bnc#1012628).
- scsi: qla2xxx: Fix double scsi_done for abort path
  (bnc#1012628).
- scsi: qla2xxx: Fix memory leak when sending I/O fails
  (bnc#1012628).
- compat_ioctl: add compat_ptr_ioctl() (bnc#1012628).
- ceph: fix compat_ioctl for ceph_dir_operations (bnc#1012628).
- media: venus: remove invalid compat_ioctl32 handler
  (bnc#1012628).
- USB: uas: honor flag to avoid CAPACITY16 (bnc#1012628).
- USB: uas: heed CAPACITY_HEURISTICS (bnc#1012628).
- USB: documentation: flags on usb-storage versus UAS
  (bnc#1012628).
- usb: Allow USB device to be warm reset in suspended state
  (bnc#1012628).
- usb: host: xhci-tegra: Correct phy enable sequence
  (bnc#1012628).
- binder: fix incorrect calculation for num_valid (bnc#1012628).
- staging: exfat: fix multiple definition error of `rename_file'
  (bnc#1012628).
- staging: rtl8188eu: fix interface sanity check (bnc#1012628).
- staging: rtl8712: fix interface sanity check (bnc#1012628).
- staging: vchiq: call unregister_chrdev_region() when driver
  registration fails (bnc#1012628).
- staging: gigaset: fix general protection fault on probe
  (bnc#1012628).
- staging: gigaset: fix illegal free on probe errors
  (bnc#1012628).
- staging: gigaset: add endpoint-type sanity check (bnc#1012628).
- usb: xhci: only set D3hot for pci device (bnc#1012628).
- xhci: Fix memory leak in xhci_add_in_port() (bnc#1012628).
- xhci: fix USB3 device initiated resume race with roothub
  autosuspend (bnc#1012628).
- xhci: Increase STS_HALT timeout in xhci_suspend() (bnc#1012628).
- xhci: handle some XHCI_TRUST_TX_LENGTH quirks cases as default
  behaviour (bnc#1012628).
- xhci: make sure interrupts are restored to correct state
  (bnc#1012628).
- interconnect: qcom: sdm845: Walk the list safely on node removal
  (bnc#1012628).
- interconnect: qcom: qcs404: Walk the list safely on node removal
  (bnc#1012628).
- usb: common: usb-conn-gpio: Don't log an error on probe deferral
  (bnc#1012628).
- ARM: dts: pandora-common: define wl1251 as child node of mmc3
  (bnc#1012628).
- iio: adis16480: Add debugfs_reg_access entry (bnc#1012628).
- iio: imu: st_lsm6dsx: fix ODR check in st_lsm6dsx_write_raw
  (bnc#1012628).
- iio: adis16480: Fix scales factors (bnc#1012628).
- iio: humidity: hdc100x: fix IIO_HUMIDITYRELATIVE channel
  reporting (bnc#1012628).
- iio: imu: inv_mpu6050: fix temperature reporting using bad unit
  (bnc#1012628).
- iio: adc: ad7606: fix reading unnecessary data from device
  (bnc#1012628).
- iio: adc: ad7124: Enable internal reference (bnc#1012628).
- USB: atm: ueagle-atm: add missing endpoint check (bnc#1012628).
- USB: idmouse: fix interface sanity checks (bnc#1012628).
- USB: serial: io_edgeport: fix epic endpoint lookup
  (bnc#1012628).
- usb: roles: fix a potential use after free (bnc#1012628).
- USB: adutux: fix interface sanity check (bnc#1012628).
- usb: core: urb: fix URB structure initialization function
  (bnc#1012628).
- usb: mon: Fix a deadlock in usbmon between mmap and read
  (bnc#1012628).
- tpm: add check after commands attribs tab allocation
  (bnc#1012628).
- tpm: Switch to platform_get_irq_optional() (bnc#1012628).
- EDAC/altera: Use fast register IO for S10 IRQs (bnc#1012628).
- brcmfmac: disable PCIe interrupts before bus reset
  (bnc#1012628).
- mtd: spear_smi: Fix Write Burst mode (bnc#1012628).
- mtd: rawnand: Change calculating of position page containing
  BBM (bnc#1012628).
- virt_wifi: fix use-after-free in virt_wifi_newlink()
  (bnc#1012628).
- virtio-balloon: fix managed page counts when migrating pages
  between zones (bnc#1012628).
- usb: dwc3: pci: add ID for the Intel Comet Lake -H variant
  (bnc#1012628).
- usb: dwc3: gadget: Fix logical condition (bnc#1012628).
- usb: dwc3: gadget: Clear started flag for non-IOC (bnc#1012628).
- usb: dwc3: ep0: Clear started flag on completion (bnc#1012628).
- phy: renesas: rcar-gen3-usb2: Fix sysfs interface of "role"
  (bnc#1012628).
- usb: typec: fix use after free in typec_register_port()
  (bnc#1012628).
- iwlwifi: pcie: fix support for transmitting SKBs with fraglist
  (bnc#1012628).
- btrfs: check page->mapping when loading free space cache
  (bnc#1012628).
- btrfs: use btrfs_block_group_cache_done in update_block_group
  (bnc#1012628).
- btrfs: use refcount_inc_not_zero in kill_all_nodes
  (bnc#1012628).
- Btrfs: fix metadata space leak on fixup worker failure to set
  range as delalloc (bnc#1012628).
- Btrfs: fix negative subv_writers counter and data space leak
  after buffered write (bnc#1012628).
- btrfs: Avoid getting stuck during cyclic writebacks
  (bnc#1012628).
- btrfs: Remove btrfs_bio::flags member (bnc#1012628).
- Btrfs: send, skip backreference walking for extents with many
  references (bnc#1012628).
- btrfs: record all roots for rename exchange on a subvol
  (bnc#1012628).
- rtlwifi: rtl8192de: Fix missing code to retrieve RX buffer
  address (bnc#1012628).
- rtlwifi: rtl8192de: Fix missing callback that tests for hw
  release of buffer (bnc#1012628).
- rtlwifi: rtl8192de: Fix missing enable interrupt flag
  (bnc#1012628).
- lib: raid6: fix awk build warnings (bnc#1012628).
- ovl: fix lookup failure on multi lower squashfs (bnc#1012628).
- ovl: fix corner case of non-unique st_dev;st_ino (bnc#1012628).
- ovl: relax WARN_ON() on rename to self (bnc#1012628).
- hwrng: omap - Fix RNG wait loop timeout (bnc#1012628).
- dm writecache: handle REQ_FUA (bnc#1012628).
- dm zoned: reduce overhead of backing device checks
  (bnc#1012628).
- workqueue: Fix spurious sanity check failures in
  destroy_workqueue() (bnc#1012628).
- workqueue: Fix pwq ref leak in rescuer_thread() (bnc#1012628).
- ASoC: rt5645: Fixed buddy jack support (bnc#1012628).
- ASoC: rt5645: Fixed typo for buddy jack support (bnc#1012628).
- ASoC: Jack: Fix NULL pointer dereference in snd_soc_jack_report
  (bnc#1012628).
- ASoC: fsl_audmix: Add spin lock to protect tdms (bnc#1012628).
- md: improve handling of bio with REQ_PREFLUSH in
  md_flush_request() (bnc#1012628).
- blk-mq: avoid sysfs buffer overflow with too many CPU cores
  (bnc#1012628).
- cgroup: pids: use atomic64_t for pids->limit (bnc#1012628).
- wil6210: check len before memcpy() calls (bnc#1012628).
- ar5523: check NULL before memcpy() in ar5523_cmd()
  (bnc#1012628).
- s390/mm: properly clear _PAGE_NOEXEC bit when it is not
  supported (bnc#1012628).
- media: hantro: Fix s_fmt for dynamic resolution changes
  (bnc#1012628).
- media: hantro: Fix motion vectors usage condition (bnc#1012628).
- media: hantro: Fix picture order count table enable
  (bnc#1012628).
- media: vimc: sen: remove unused kthread_sen field (bnc#1012628).
- media: bdisp: fix memleak on release (bnc#1012628).
- media: radio: wl1273: fix interrupt masking on release
  (bnc#1012628).
- media: cec.h: CEC_OP_REC_FLAG_ values were swapped
  (bnc#1012628).
- cpuidle: Do not unset the driver if it is there already
  (bnc#1012628).
- cpuidle: teo: Ignore disabled idle states that are too deep
  (bnc#1012628).
- cpuidle: teo: Rename local variable in teo_select()
  (bnc#1012628).
- cpuidle: teo: Consider hits and misses metrics of disabled
  states (bnc#1012628).
- cpuidle: teo: Fix "early hits" handling for disabled idle states
  (bnc#1012628).
- cpuidle: use first valid target residency as poll time
  (bnc#1012628).
- erofs: zero out when listxattr is called with no xattr
  (bnc#1012628).
- perf tests: Fix out of bounds memory access (bnc#1012628).
- drm/panfrost: Open/close the perfcnt BO (bnc#1012628).
- powerpc/perf: Disable trace_imc pmu (bnc#1012628).
- intel_th: Fix a double put_device() in error path (bnc#1012628).
- intel_th: pci: Add Ice Lake CPU support (bnc#1012628).
- intel_th: pci: Add Tiger Lake CPU support (bnc#1012628).
- PM / devfreq: Lock devfreq in trans_stat_show (bnc#1012628).
- cpufreq: powernv: fix stack bloat and hard limit on number of
  CPUs (bnc#1012628).
- ALSA: fireface: fix return value in error path of isochronous
  resources reservation (bnc#1012628).
- ALSA: oxfw: fix return value in error path of isochronous
  resources reservation (bnc#1012628).
- ALSA: hda/realtek - Line-out jack doesn't work on a Dell AIO
  (bnc#1012628).
- ACPI / utils: Move acpi_dev_get_first_match_dev() under
  CONFIG_ACPI (bnc#1012628).
- ACPI: LPSS: Add LNXVIDEO -> BYT I2C7 to lpss_device_links
  (bnc#1012628).
- ACPI: LPSS: Add LNXVIDEO -> BYT I2C1 to lpss_device_links
  (bnc#1012628).
- ACPI: LPSS: Add dmi quirk for skipping _DEP check for some
  device-links (bnc#1012628).
- ACPI / hotplug / PCI: Allocate resources directly under the
  non-hotplug bridge (bnc#1012628).
- ACPI: OSL: only free map once in osl.c (bnc#1012628).
- ACPI: bus: Fix NULL pointer check in acpi_bus_get_private_data()
  (bnc#1012628).
- ACPI: EC: Rework flushing of pending work (bnc#1012628).
- ACPI: PM: Avoid attaching ACPI PM domain to certain devices
  (bnc#1012628).
- pinctrl: rza2: Fix gpio name typos (bnc#1012628).
- pinctrl: armada-37xx: Fix irq mask access in
  armada_37xx_irq_set_type() (bnc#1012628).
- pinctrl: samsung: Add of_node_put() before return in error path
  (bnc#1012628).
- pinctrl: samsung: Fix device node refcount leaks in Exynos
  wakeup controller init (bnc#1012628).
- pinctrl: samsung: Fix device node refcount leaks in S3C24xx
  wakeup controller init (bnc#1012628).
- pinctrl: samsung: Fix device node refcount leaks in init code
  (bnc#1012628).
- pinctrl: samsung: Fix device node refcount leaks in S3C64xx
  wakeup controller init (bnc#1012628).
- mmc: host: omap_hsmmc: add code for special init of wl1251 to
  get rid of pandora_wl1251_init_card (bnc#1012628).
- ARM: dts: omap3-tao3530: Fix incorrect MMC card detection GPIO
  polarity (bnc#1012628).
- RDMA/core: Fix ib_dma_max_seg_size() (bnc#1012628).
- ppdev: fix PPGETTIME/PPSETTIME ioctls (bnc#1012628).
- stm class: Lose the protocol driver when dropping its reference
  (bnc#1012628).
- coresight: Serialize enabling/disabling a link device
  (bnc#1012628).
- powerpc: Allow 64bit VDSO __kernel_sync_dicache to work across
  ranges >4GB (bnc#1012628).
- powerpc/xive: Prevent page fault issues in the machine crash
  handler (bnc#1012628).
- powerpc: Allow flush_icache_range to work across ranges >4GB
  (bnc#1012628).
- powerpc/xive: Skip ioremap() of ESB pages for LSI interrupts
  (bnc#1012628).
- video/hdmi: Fix AVI bar unpack (bnc#1012628).
- quota: Check that quota is not dirty before release
  (bnc#1012628).
- ext2: check err when partial != NULL (bnc#1012628).
- seccomp: avoid overflow in implicit constant conversion
  (bnc#1012628).
- quota: fix livelock in dquot_writeback_dquots (bnc#1012628).
- ext4: Fix credit estimate for final inode freeing (bnc#1012628).
- reiserfs: fix extended attributes on the root directory
  (bnc#1012628).
- scsi: qla2xxx: Fix SRB leak on switch command timeout
  (bnc#1012628).
- scsi: qla2xxx: Fix a dma_pool_free() call (bnc#1012628).
- Revert "scsi: qla2xxx: Fix memory leak when sending I/O fails"
  (bnc#1012628).
- iio: ad7949: kill pointless "readback"-handling code
  (bnc#1012628).
- iio: ad7949: fix channels mixups (bnc#1012628).
- omap: pdata-quirks: revert pandora specific gpiod additions
  (bnc#1012628).
- omap: pdata-quirks: remove openpandora quirks for mmc3 and
  wl1251 (bnc#1012628).
- powerpc: Avoid clang warnings around setjmp and longjmp
  (bnc#1012628).
- powerpc: Fix vDSO clock_getres() (bnc#1012628).
- mm, memfd: fix COW issue on MAP_PRIVATE and F_SEAL_FUTURE_WRITE
  mappings (bnc#1012628).
- mfd: rk808: Fix RK818 ID template (bnc#1012628).
- mm: memcg/slab: wait for !root kmem_cache refcnt killing on
  root kmem_cache destruction (bnc#1012628).
- ext4: work around deleting a file with i_nlink == 0 safely
  (bnc#1012628).
- firmware: qcom: scm: Ensure 'a0' status code is treated as
  signed (bnc#1012628).
- s390/smp,vdso: fix ASCE handling (bnc#1012628).
- s390/kaslr: store KASLR offset for early dumps (bnc#1012628).
- mm/shmem.c: cast the type of unmap_start to u64 (bnc#1012628).
- powerpc: Define arch_is_kernel_initmem_freed() for lockdep
  (bnc#1012628).
- USB: dummy-hcd: increase max number of devices to 32
  (bnc#1012628).
- rtc: disable uie before setting time and enable after
  (bnc#1012628).
- splice: only read in as much information as there is pipe
  buffer space (bnc#1012628).
- ext4: fix a bug in ext4_wait_for_tail_page_commit (bnc#1012628).
- ext4: fix leak of quota reservations (bnc#1012628).
- blk-mq: make sure that line break can be printed (bnc#1012628).
- workqueue: Fix missing kfree(rescuer) in destroy_workqueue()
  (bnc#1012628).
- r8169: fix rtl_hw_jumbo_disable for RTL8168evl (bnc#1012628).
- commit 286f4fb
* Mon Dec 16 2019 tiwai@suse.de
- rpm/kernel-subpackage-spec: Fix empty Recommends tag (bsc#1143959)
- commit 3fd22e2
* Mon Dec 16 2019 bp@suse.de
- crypto: ccp - Release all allocated memory if sha type is
  invalid (bsc#1156259 CVE-2019-18808).
- commit c8b14a1
* Mon Dec 16 2019 mkubecek@suse.cz
- Update to 5.5-rc2
- update configs
  - CRYPTO_BLAKE2B=m
- commit 5d7acaa
* Fri Dec 13 2019 jslaby@suse.cz
- EDAC/ghes: Do not warn when incrementing refcount on 0
  (git-fixes).
- commit e16f7d4
* Fri Dec 13 2019 jslaby@suse.cz
- Linux 5.4.3 (bnc#1012628).
- rsi: release skb if rsi_prepare_beacon fails (bnc#1012628).
- arm64: tegra: Fix 'active-low' warning for Jetson TX1 regulator
  (bnc#1012628).
- arm64: tegra: Fix 'active-low' warning for Jetson Xavier
  regulator (bnc#1012628).
- perf scripts python: exported-sql-viewer.py: Fix use of TRUE
  with SQLite (bnc#1012628).
- sparc64: implement ioremap_uc (bnc#1012628).
- lp: fix sparc64 LPSETTIMEOUT ioctl (bnc#1012628).
- time: Zero the upper 32-bits in __kernel_timespec on 32-bit
  (bnc#1012628).
- mailbox: tegra: Fix superfluous IRQ error message (bnc#1012628).
- staging/octeon: Use stubs for MIPS && !CAVIUM_OCTEON_SOC
  (bnc#1012628).
- usb: gadget: u_serial: add missing port entry locking
  (bnc#1012628).
- serial: 8250-mtk: Use platform_get_irq_optional() for optional
  irq (bnc#1012628).
- tty: serial: fsl_lpuart: use the sg count from dma_map_sg
  (bnc#1012628).
- tty: serial: msm_serial: Fix flow control (bnc#1012628).
- serial: pl011: Fix DMA ->flush_buffer() (bnc#1012628).
- serial: serial_core: Perform NULL checks for break_ctl ops
  (bnc#1012628).
- serial: stm32: fix clearing interrupt error flags (bnc#1012628).
- serial: 8250_dw: Avoid double error messaging when IRQ absent
  (bnc#1012628).
- serial: ifx6x60: add missed pm_runtime_disable (bnc#1012628).
- mwifiex: Re-work support for SDIO HW reset (bnc#1012628).
- io_uring: fix dead-hung for non-iter fixed rw (bnc#1012628).
- io_uring: transform send/recvmsg() -ERESTARTSYS to -EINTR
  (bnc#1012628).
- fuse: fix leak of fuse_io_priv (bnc#1012628).
- fuse: verify nlink (bnc#1012628).
- fuse: verify write return (bnc#1012628).
- fuse: verify attributes (bnc#1012628).
- io_uring: fix missing kmap() declaration on powerpc
  (bnc#1012628).
- io_uring: ensure req->submit is copied when req is deferred
  (bnc#1012628).
- SUNRPC: Avoid RPC delays when exiting suspend (bnc#1012628).
- ALSA: hda/realtek - Enable internal speaker of ASUS UX431FLC
  (bnc#1012628).
- ALSA: hda/realtek - Enable the headset-mic on a Xiaomi's laptop
  (bnc#1012628).
- ALSA: hda/realtek - Dell headphone has noise on unmute for
  ALC236 (bnc#1012628).
- ALSA: hda/realtek - Fix inverted bass GPIO pin on Acer 8951G
  (bnc#1012628).
- ALSA: pcm: oss: Avoid potential buffer overflows (bnc#1012628).
- ALSA: hda - Add mute led support for HP ProBook 645 G4
  (bnc#1012628).
- ALSA: hda: Modify stream stripe mask only when needed
  (bnc#1012628).
- soc: mediatek: cmdq: fixup wrong input order of write api
  (bnc#1012628).
- Input: synaptics - switch another X1 Carbon 6 to RMI/SMbus
  (bnc#1012628).
- Input: synaptics-rmi4 - re-enable IRQs in f34v7_do_reflash
  (bnc#1012628).
- Input: synaptics-rmi4 - don't increment rmiaddr for SMBus
  transfers (bnc#1012628).
- Input: goodix - add upside-down quirk for Teclast X89 tablet
  (bnc#1012628).
- coresight: etm4x: Fix input validation for sysfs (bnc#1012628).
- Input: Fix memory leak in psxpad_spi_probe (bnc#1012628).
- media: rc: mark input device as pointing stick (bnc#1012628).
- x86/mm/32: Sync only to VMALLOC_END in vmalloc_sync_all()
  (bnc#1012628).
- x86/PCI: Avoid AMD FCH XHCI USB PME# from D0 defect
  (bnc#1012628).
- CIFS: Fix NULL-pointer dereference in smb2_push_mandatory_locks
  (bnc#1012628).
- CIFS: Fix SMB2 oplock break processing (bnc#1012628).
- tty: vt: keyboard: reject invalid keycodes (bnc#1012628).
- can: slcan: Fix use-after-free Read in slcan_open (bnc#1012628).
- nfsd: Ensure CLONE persists data and metadata changes to the
  target file (bnc#1012628).
- nfsd: restore NFSv3 ACL support (bnc#1012628).
- kernfs: fix ino wrap-around detection (bnc#1012628).
- jbd2: Fix possible overflow in jbd2_log_space_left()
  (bnc#1012628).
- drm/msm: fix memleak on release (bnc#1012628).
- drm: damage_helper: Fix race checking plane->state->fb
  (bnc#1012628).
- drm/i810: Prevent underflow in ioctl (bnc#1012628).
- arm64: Validate tagged addresses in access_ok() called from
  kernel threads (bnc#1012628).
- arm64: dts: exynos: Revert "Remove unneeded address space
  mapping for soc node" (bnc#1012628).
- KVM: PPC: Book3S HV: XIVE: Free previous EQ page when setting
  up a new one (bnc#1012628).
- KVM: PPC: Book3S HV: XIVE: Fix potential page leak on error path
  (bnc#1012628).
- KVM: PPC: Book3S HV: XIVE: Set kvm->arch.xive when VPs are
  allocated (bnc#1012628).
- KVM: nVMX: Always write vmcs02.GUEST_CR3 during nested VM-Enter
  (bnc#1012628).
- KVM: arm/arm64: vgic: Don't rely on the wrong pending table
  (bnc#1012628).
- KVM: x86: do not modify masked bits of shared MSRs
  (bnc#1012628).
- KVM: x86: Grab KVM's srcu lock when setting nested state
  (bnc#1012628).
- crypto: crypto4xx - fix double-free in crypto4xx_destroy_sdr
  (bnc#1012628).
- crypto: atmel-aes - Fix IV handling when req->nbytes < ivsize
  (bnc#1012628).
- crypto: af_alg - cast ki_complete ternary op to int
  (bnc#1012628).
- crypto: geode-aes - switch to skcipher for cbc(aes) fallback
  (bnc#1012628).
- crypto: ccp - fix uninitialized list head (bnc#1012628).
- crypto: ecdh - fix big endian bug in ECC library (bnc#1012628).
- crypto: user - fix memory leak in crypto_report (bnc#1012628).
- crypto: user - fix memory leak in crypto_reportstat
  (bnc#1012628).
- spi: spi-fsl-qspi: Clear TDH bits in FLSHCR register
  (bnc#1012628).
- spi: stm32-qspi: Fix kernel oops when unbinding driver
  (bnc#1012628).
- spi: atmel: Fix CS high support (bnc#1012628).
- spi: Fix SPI_CS_HIGH setting when using native and GPIO CS
  (bnc#1012628).
- spi: Fix NULL pointer when setting SPI_CS_HIGH for GPIO CS
  (bnc#1012628).
- can: ucan: fix non-atomic allocation in completion handler
  (bnc#1012628).
- RDMA/qib: Validate ->show()/store() callbacks before calling
  them (bnc#1012628).
- rfkill: allocate static minor (bnc#1012628).
- bdev: Factor out bdev revalidation into a common helper
  (bnc#1012628).
- bdev: Refresh bdev size for disks without partitioning
  (bnc#1012628).
- iomap: Fix pipe page leakage during splicing (bnc#1012628).
- thermal: Fix deadlock in thermal thermal_zone_device_check
  (bnc#1012628).
- vcs: prevent write access to vcsu devices (bnc#1012628).
- Revert "serial/8250: Add support for NI-Serial PXI/PXIe+485
  devices" (bnc#1012628).
- binder: Fix race between mmap() and binder_alloc_print_pages()
  (bnc#1012628).
- binder: Prevent repeated use of ->mmap() via NULL mapping
  (bnc#1012628).
- binder: Handle start==NULL in binder_update_page_range()
  (bnc#1012628).
- ALSA: hda - Fix pending unsol events at shutdown (bnc#1012628).
- cpufreq: imx-cpufreq-dt: Correct i.MX8MN's default speed grade
  value (bnc#1012628).
- md/raid0: Fix an error message in raid0_make_request()
  (bnc#1012628).
- drm/mcde: Fix an error handling path in 'mcde_probe()'
  (bnc#1012628).
- watchdog: aspeed: Fix clock behaviour for ast2600 (bnc#1012628).
- EDAC/ghes: Fix locking and memory barrier issues (bnc#1012628).
- perf script: Fix invalid LBR/binary mismatch error
  (bnc#1012628).
- kselftest: Fix NULL INSTALL_PATH for TARGETS runlist
  (bnc#1012628).
- commit 9f4d3b5
* Thu Dec 12 2019 nsaenzjulienne@suse.de
- hwrng: iproc-rng200 - Add support for BCM2711 (jsc#SLE-7772).
- commit 9e9a23d
* Wed Dec 11 2019 jroedel@suse.de
- KVM: x86: Remove a spurious export of a static function
  (CVE-2019-19338 bsc#1158954).
- KVM: x86: fix presentation of TSX feature in ARCH_CAPABILITIES
  (CVE-2019-19338 bsc#1158954).
- commit e830a48
* Wed Dec 11 2019 jroedel@suse.de
- KVM: x86: fix out-of-bounds write in KVM_GET_EMULATED_CPUID
  (CVE-2019-19332) (CVE-2019-19332 bsc#1158827).
- commit bdbc1dc
* Mon Dec  9 2019 mkubecek@suse.cz
- Update to 5.5-rc1
- eliminated 175 patches (114 stable, 61 other)
- ARM configs need update
- refresh
  patches.suse/0001-usb-Add-Xen-pvUSB-protocol-description.patch
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  patches.suse/linux-log2-h-add-roundup-rounddown_pow_two64-family-of-functions.patch
  patches.suse/setuid-dumpable-wrongdir
  patches.suse/supported-flag
  patches.suse/supported-flag-external
- new config options:
  - Processor type and features
  - X86_IOPL_IOPERM=y
  - X86_UMIP=y
  - Power management
  - BYTCRC_PMIC_OPREGION=y
  - CHTCRC_PMIC_OPREGION=y
  - Networking
  - TLS_TOE=n
  - TIPC_CRYPTO=y
  - NET_DSA_TAG_OCELOT=m
  - NFC_PN532_UART=m
  - Cryptographic API
  - CRYPTO_CURVE25519=m
  - CRYPTO_CURVE25519_X86=m
  - CRYPTO_BLAKE2B=m
  - CRYPTO_BLAKE2S=m
  - CRYPTO_BLAKE2S_X86=m
  - CRYPTO_LIB_BLAKE2S=m
  - CRYPTO_LIB_CHACHA=m
  - CRYPTO_LIB_CURVE25519=m
  - CRYPTO_LIB_POLY1305=m
  - CRYPTO_LIB_CHACHA20POLY1305=m
  - CRYPTO_DEV_AMLOGIC_GXL=m
  - Kernel hacking
  - SYMBOLIC_ERRNAME=y
  - TRACE_EVENT_INJECT=n
  - KUNIT=n
  - Kernel Testing and Coverage
  - HYPERV_TESTING=n
  - Networking drivers
  - CAIF_DRIVERS=y
  - NET_DSA_MSCC_FELIX=m
  - DP83869_PHY=m
  - Hardware Monitoring
  - SENSORS_LTC2947_I2C=m
  - SENSORS_LTC2947_SPI=m
  - SENSORS_BEL_PFE=m
  - SENSORS_TMP513=m
  - Multimedia
  - VIDEO_HI556=m
  - VIDEO_IMX290=m
  - Graphics
  - DRM_DEBUG_DP_MST_TOPOLOGY_REFS=n
  - DRM_AMD_DC_HDCP=y
  - DRM_I915_HEARTBEAT_INTERVAL=2500
  - DRM_I915_PREEMPT_TIMEOUT=640
  - DRM_I915_SPIN_REQUEST=5
  - DRM_I915_STOP_TIMEOUT=100
  - DRM_I915_TIMESLICE_DURATION=1
  - BACKLIGHT_QCOM_WLED=m
  - FB_TFT=n
  - Sound
  - SND_SOC_INTEL_GLK_DA7219_MAX98357A_MACH=m
  - SND_SOC_INTEL_SOF_CML_RT1011_RT5682_MACH=m
  - SND_SOC_SOF_DEVELOPER_SUPPORT=n
  - SND_SOC_SOF_JASPERLAKE_SUPPORT=y
  - SND_SOC_SOF_HDA_COMMON_HDMI_CODEC=y
  - SND_SOC_ADAU7118_HW=n
  - SND_SOC_ADAU7118_I2C=n
  - SND_SOC_TAS2562=n
  - SND_SOC_TAS2770=n
  - USB
  - TYPEC_HD3SS3220=m
  - Industrial I/O
  - AD7292=n
  - FXOS8700_I2C=n
  - FXOS8700_SPI=n
  - ADUX1020=n
  - VEML6030=n
  - LTC2983=n
  - Misc drivers
  - EFI_SOFT_RESERVE=y
  - FW_CACHE=y
  - TCG_TIS_SPI_CR50=y
  - PTP_1588_CLOCK_IDTCM=m
  - PINCTRL_TIGERLAKE=m
  - PINCTRL_EQUILIBRIUM=m
  - W1_SLAVE_DS2430=m
  - SF_PDMA=m
  - NVME_HWMON=y
  - WFX=m
  - SYSTEM76_ACPI=m
  - CROS_EC_SENSORHUB=m
  - DEV_DAX_HMEM=m
  - ppc64(le):
  - PPC_UV=n
  - */debug:
  - TRACE_EVENT_INJECT=y
  - x86_64/debug:
  - HYPERV_TESTING=y
- commit 6af0b1c
* Thu Dec  5 2019 nsaenzjulienne@suse.de
- supported.conf: Support Broadcom's Genet Ethernet driver (bsc#158563)
- commit 5e42d26
* Thu Dec  5 2019 jslaby@suse.cz
- Linux 5.4.2 (bnc#1012628).
- platform/x86: hp-wmi: Fix ACPI errors caused by passing 0 as
  input size (bnc#1012628).
- platform/x86: hp-wmi: Fix ACPI errors caused by too small buffer
  (bnc#1012628).
- HID: core: check whether Usage Page item is after Usage ID items
  (bnc#1012628).
- crypto: talitos - Fix build error by selecting LIB_DES
  (bnc#1012628).
- Revert "jffs2: Fix possible null-pointer dereferences in
  jffs2_add_frag_to_fragtree()" (bnc#1012628).
- ext4: add more paranoia checking in ext4_expand_extra_isize
  handling (bnc#1012628).
- r8169: fix resume on cable plug-in (bnc#1012628).
- r8169: fix jumbo configuration for RTL8168evl (bnc#1012628).
- selftests: pmtu: use -oneline for ip route list cache
  (bnc#1012628).
- tipc: fix link name length check (bnc#1012628).
- selftests: bpf: correct perror strings (bnc#1012628).
- selftests: bpf: test_sockmap: handle file creation failures
  gracefully (bnc#1012628).
- net/tls: use sg_next() to walk sg entries (bnc#1012628).
- net/tls: remove the dead inplace_crypto code (bnc#1012628).
- selftests/tls: add a test for fragmented messages (bnc#1012628).
- net: skmsg: fix TLS 1.3 crash with full sk_msg (bnc#1012628).
- net/tls: free the record on encryption error (bnc#1012628).
- net/tls: take into account that bpf_exec_tx_verdict() may free
  the record (bnc#1012628).
- openvswitch: remove another BUG_ON() (bnc#1012628).
- openvswitch: drop unneeded BUG_ON() in ovs_flow_cmd_build_info()
  (bnc#1012628).
- sctp: cache netns in sctp_ep_common (bnc#1012628).
- slip: Fix use-after-free Read in slip_open (bnc#1012628).
- sctp: Fix memory leak in sctp_sf_do_5_2_4_dupcook (bnc#1012628).
- openvswitch: fix flow command message size (bnc#1012628).
- net: sched: fix `tc -s class show` no bstats on class with
  nolock subqueues (bnc#1012628).
- net: psample: fix skb_over_panic (bnc#1012628).
- net: macb: add missed tasklet_kill (bnc#1012628).
- net: dsa: sja1105: fix sja1105_parse_rgmii_delays()
  (bnc#1012628).
- mdio_bus: don't use managed reset-controller (bnc#1012628).
- macvlan: schedule bc_work even if error (bnc#1012628).
- gve: Fix the queue page list allocated pages count
  (bnc#1012628).
- x86/fpu: Don't cache access to fpu_fpregs_owner_ctx
  (bnc#1012628).
- thunderbolt: Power cycle the router if NVM authentication fails
  (bnc#1012628).
- mei: me: add comet point V device id (bnc#1012628).
- mei: bus: prefix device names on bus with the bus name
  (bnc#1012628).
- USB: serial: ftdi_sio: add device IDs for U-Blox C099-F9P
  (bnc#1012628).
- staging: rtl8723bs: Add 024c:0525 to the list of SDIO device-ids
  (bnc#1012628).
- staging: rtl8723bs: Drop ACPI device ids (bnc#1012628).
- staging: rtl8192e: fix potential use after free (bnc#1012628).
- staging: wilc1000: fix illegal memory access in
  wilc_parse_join_bss_param() (bnc#1012628).
- usb: dwc2: use a longer core rest timeout in dwc2_core_reset()
  (bnc#1012628).
- driver core: platform: use the correct callback type for
  bus_find_device (bnc#1012628).
- crypto: inside-secure - Fix stability issue with Macchiatobin
  (bnc#1012628).
- net: disallow ancillary data for __sys_{send,recv}msg_file()
  (bnc#1012628).
- net: separate out the msghdr copy from ___sys_{send,recv}msg()
  (bnc#1012628).
- io_uring: async workers should inherit the user creds
  (bnc#1012628).
- commit 9df353f
* Wed Dec  4 2019 nsaenzjulienne@suse.de
- supported.conf: support gpio-regulator used by Raspberry Pi 4
  (bsc#1158451)
- commit d0225c2
* Tue Dec  3 2019 mbrugger@suse.com
- arm64: Update config files.
  Bump CONFIG_NODES_SHIFT from 2 to 6
- commit 476eb27
* Tue Dec  3 2019 tiwai@suse.de
- rpm/kernel-subpackage-spec: Exclude kernel-firmware recommends (bsc#1143959)
  For reducing the dependency on kernel-firmware in sub packages
- commit d950271
* Fri Nov 29 2019 msuchanek@suse.de
- Update config files.
  ppc64 is lats architecture without PRINTK_TIME. Align with the rest.
- commit f46c056
* Fri Nov 29 2019 jslaby@suse.cz
- blacklist.conf: add one invalid commit
- commit 4c2d405
* Fri Nov 29 2019 jslaby@suse.cz
- Linux 5.4.1 (bnc#1012628).
- Bluetooth: Fix invalid-free in bcsp_close() (bnc#1012628).
- ath9k_hw: fix uninitialized variable data (bnc#1012628).
- ath10k: Fix HOST capability QMI incompatibility (bnc#1012628).
- ath10k: restore QCA9880-AR1A (v1) detection (bnc#1012628).
- Revert "Bluetooth: hci_ll: set operational frequency earlier"
  (bnc#1012628).
- Revert "dm crypt: use WQ_HIGHPRI for the IO and crypt
  workqueues" (bnc#1012628).
- md/raid10: prevent access of uninitialized resync_pages offset
  (bnc#1012628).
- x86/insn: Fix awk regexp warnings (bnc#1012628).
- x86/speculation: Fix incorrect MDS/TAA mitigation status
  (bnc#1012628).
- x86/speculation: Fix redundant MDS mitigation message
  (bnc#1012628).
- nbd: prevent memory leak (bnc#1012628).
- x86/stackframe/32: Repair 32-bit Xen PV (bnc#1012628).
- x86/xen/32: Make xen_iret_crit_fixup() independent of frame
  layout (bnc#1012628).
- x86/xen/32: Simplify ring check in xen_iret_crit_fixup()
  (bnc#1012628).
- x86/doublefault/32: Fix stack canaries in the double fault
  handler (bnc#1012628).
- x86/pti/32: Size initial_page_table correctly (bnc#1012628).
- x86/cpu_entry_area: Add guard page for entry stack on 32bit
  (bnc#1012628).
- x86/entry/32: Fix IRET exception (bnc#1012628).
- x86/entry/32: Use %%ss segment where required (bnc#1012628).
- x86/entry/32: Move FIXUP_FRAME after pushing %%fs in SAVE_ALL
  (bnc#1012628).
- x86/entry/32: Unwind the ESPFIX stack earlier on exception entry
  (bnc#1012628).
- x86/entry/32: Fix NMI vs ESPFIX (bnc#1012628).
- selftests/x86/mov_ss_trap: Fix the SYSENTER test (bnc#1012628).
- selftests/x86/sigreturn/32: Invalidate DS and ES when abusing
  the kernel (bnc#1012628).
- x86/pti/32: Calculate the various PTI cpu_entry_area sizes
  correctly, make the CPU_ENTRY_AREA_PAGES assert precise
  (bnc#1012628).
- x86/entry/32: Fix FIXUP_ESPFIX_STACK with user CR3
  (bnc#1012628).
- futex: Prevent robust futex exit race (bnc#1012628).
- ALSA: usb-audio: Fix NULL dereference at parsing BADD
  (bnc#1012628).
- ALSA: usb-audio: Fix Scarlett 6i6 Gen 2 port data (bnc#1012628).
- media: vivid: Set vid_cap_streaming and vid_out_streaming to
  true (bnc#1012628).
- media: vivid: Fix wrong locking that causes race conditions
  on streaming stop (bnc#1012628).
- media: usbvision: Fix invalid accesses after device disconnect
  (bnc#1012628).
- media: usbvision: Fix races among open, close, and disconnect
  (bnc#1012628).
- cpufreq: Add NULL checks to show() and store() methods of
  cpufreq (bnc#1012628).
- futex: Move futex exit handling into futex code (bnc#1012628).
- futex: Replace PF_EXITPIDONE with a state (bnc#1012628).
- exit/exec: Seperate mm_release() (bnc#1012628).
- futex: Split futex_mm_release() for exit/exec (bnc#1012628).
- futex: Set task::futex_state to DEAD right after handling
  futex exit (bnc#1012628).
- futex: Mark the begin of futex exit explicitly (bnc#1012628).
- futex: Sanitize exit state handling (bnc#1012628).
- futex: Provide state handling for exec() as well (bnc#1012628).
- futex: Add mutex around futex exit (bnc#1012628).
- futex: Provide distinct return value when owner is exiting
  (bnc#1012628).
- futex: Prevent exit livelock (bnc#1012628).
- media: uvcvideo: Fix error path in control parsing failure
  (bnc#1012628).
- media: b2c2-flexcop-usb: add sanity checking (bnc#1012628).
- media: cxusb: detect cxusb_ctrl_msg error in query
  (bnc#1012628).
- media: imon: invalid dereference in imon_touch_event
  (bnc#1012628).
- media: mceusb: fix out of bounds read in MCE receiver buffer
  (bnc#1012628).
- ALSA: hda - Disable audio component for legacy Nvidia HDMI
  codecs (bnc#1012628).
- USBIP: add config dependency for SGL_ALLOC (bnc#1012628).
- usbip: tools: fix fd leakage in the function of
  read_attr_usbip_status (bnc#1012628).
- usbip: Fix uninitialized symbol 'nents' in
  stub_recv_cmd_submit() (bnc#1012628).
- usb-serial: cp201x: support Mark-10 digital force gauge
  (bnc#1012628).
- USB: chaoskey: fix error case of a timeout (bnc#1012628).
- appledisplay: fix error handling in the scheduled work
  (bnc#1012628).
- USB: serial: mos7840: add USB ID to support Moxa UPort 2210
  (bnc#1012628).
- USB: serial: mos7720: fix remote wakeup (bnc#1012628).
- USB: serial: mos7840: fix remote wakeup (bnc#1012628).
- USB: serial: option: add support for DW5821e with eSIM support
  (bnc#1012628).
- USB: serial: option: add support for Foxconn T77W968 LTE modules
  (bnc#1012628).
- staging: comedi: usbduxfast: usbduxfast_ai_cmdtest rounding
  error (bnc#1012628).
- powerpc/book3s64: Fix link stack flush on context switch
  (bnc#1012628).
- KVM: PPC: Book3S HV: Flush link stack on guest exit to host
  kernel (bnc#1012628).
- commit 694287b
* Fri Nov 29 2019 ptesarik@suse.cz
- Update config files (bsc#1158055 LTC#182629).
- commit 632b250
* Thu Nov 28 2019 mkubecek@suse.cz
- series.conf: cleanup
- update mainline reference:
  patches.suse/net-bcmgenet-Add-BCM2711-support.patch
  patches.suse/net-bcmgenet-Add-RGMII_RXID-support.patch
  patches.suse/net-bcmgenet-Add-a-shutdown-callback.patch
  patches.suse/net-bcmgenet-Avoid-touching-non-existent-interrupt.patch
  patches.suse/net-bcmgenet-Fix-error-handling-on-IRQ-retrieval.patch
  patches.suse/net-bcmgenet-Generate-a-random-MAC-if-none-is-valid.patch
  patches.suse/net-bcmgenet-Refactor-register-access-in-bcmgenet_mi.patch
- commit fd0f02f
* Wed Nov 27 2019 nsaenzjulienne@suse.de
- PCI: brcmstb: add MSI capability (jsc#SLE-7772).
- PCI: brcmstb: add Broadcom STB PCIe host controller driver
  (jsc#SLE-7772).
- supported.conf: Add pcie-brcmstb
- Update config files: build pcie-brcmstb as module
- linux/log2.h: Add roundup/rounddown_pow_two64() family of
  functions (jsc#SLE-7772).
- dma-mapping: treat dev->bus_dma_mask as a DMA limit
  (jsc#SLE-7772).
- dma-direct: exclude dma_direct_map_resource from the min_low_pfn
  check (jsc#SLE-7772).
- dma-direct: avoid a forward declaration for phys_to_dma
  (jsc#SLE-7772).
- dma-direct: unify the dma_capable definitions (jsc#SLE-7772).
- x86/PCI: sta2x11: use default DMA address translation
  (jsc#SLE-7772).
- dma-direct: check for overflows on 32 bit DMA addresses
  (jsc#SLE-7772).
- of: Make of_dma_get_range() work on bus nodes (jsc#SLE-7772).
- of/address: Fix of_pci_range_parser_one translation of DMA
  addresses (jsc#SLE-7772).
- of/address: Translate 'dma-ranges' for parent nodes missing
  'dma-ranges' (jsc#SLE-7772).
- of: Factor out #{addr,size}-cells parsing (jsc#SLE-7772).
- of: address: Follow DMA parent for "dma-coherent"
  (jsc#SLE-7772).
- of/address: Introduce of_get_next_dma_parent() helper
  (jsc#SLE-7772).
- PCI: rcar: Use inbound resources for setup (jsc#SLE-7772).
- PCI: iproc: Use inbound resources for setup (jsc#SLE-7772).
- PCI: xgene: Use inbound resources for setup (jsc#SLE-7772).
- PCI: v3-semi: Use inbound resources for setup (jsc#SLE-7772).
- PCI: ftpci100: Use inbound resources for setup (jsc#SLE-7772).
- PCI: of: Add inbound resource parsing to helpers (jsc#SLE-7772).
- PCI: versatile: Enable COMPILE_TEST (jsc#SLE-7772).
- PCI: versatile: Remove usage of PHYS_OFFSET (jsc#SLE-7772).
- PCI: versatile: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: xilinx-nwl: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: xilinx: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: xgene: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: v3-semi: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: rockchip: Drop storing driver private outbound resource
  data (jsc#SLE-7772).
- PCI: rockchip: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: mobiveil: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: mediatek: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: iproc: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: faraday: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: dwc: Use pci_parse_request_of_pci_ranges() (jsc#SLE-7772).
- PCI: altera: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: aardvark: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: Export pci_parse_request_of_pci_ranges() (jsc#SLE-7772).
- resource: Add a resource_list_first_type helper (jsc#SLE-7772).
- commit 1c7ba00
* Tue Nov 26 2019 mbrugger@suse.com
- net: bcmgenet: Add RGMII_RXID support (jsc#SLE-7772).
- net: bcmgenet: Refactor register access in bcmgenet_mii_config (jsc#SLE-7772).
- net: bcmgenet: Fix error handling on IRQ retrieval (jsc#SLE-7772).
- net: bcmgenet: Avoid touching non-existent interrupt (jsc#SLE-7772).
- net: bcmgenet: Add BCM2711 support (jsc#SLE-7772).
- net: bcmgenet: Add a shutdown callback (jsc#SLE-7772).
- net: bcmgenet: Generate a random MAC if none is valid (jsc#SLE-7772).
- commit 9d632e7
* Mon Nov 25 2019 jslaby@suse.cz
- Refresh patches.suse/net-ath10k-Fix-a-NULL-ptr-deref-bug.patch.
  Update upstream status.
- commit b33144f
* Mon Nov 25 2019 jslaby@suse.cz
- drm/amdgpu: Add DC feature mask to disable fractional pwm
  (bsc#1154010).
- ata: make qc_prep return ata_completion_errors (bnc#1110252).
- ata: define AC_ERR_OK (bnc#1110252).
- ata: sata_mv, avoid trigerrable BUG_ON (bnc#1110252).
- libertas: fix a potential NULL pointer dereference
  (CVE-2019-16232,bsc#1150465).
- commit 42674e2
* Mon Nov 25 2019 jslaby@suse.cz
- mm: refresh ZONE_DMA and ZONE_DMA32 comments in 'enum zone_type'
  (jsc#SLE-7772).
  Port all non-upstream patches from stable to master.
- arm64: use both ZONE_DMA and ZONE_DMA32 (jsc#SLE-7772).
- Update config files.
  Config options taken from commit 4f2941cd44a2.
- arm64: rename variables used to calculate ZONE_DMA32's size
  (jsc#SLE-7772).
- arm64: mm: use arm64_dma_phys_limit instead of calling
  max_zone_dma_phys() (jsc#SLE-7772).
- arm64: dts: broadcom: Add reference to RPi 4 B (jsc#SLE-7772).
- ARM: dts: Add minimal Raspberry Pi 4 support (jsc#SLE-7772).
- ARM: bcm: Add support for BCM2711 SoC (jsc#SLE-7772).
- dt-bindings: arm: bcm2835: Add Raspberry Pi 4 to DT schema
  (jsc#SLE-7772).
- dt-bindings: arm: Convert BCM2835 board/soc bindings to
  json-schema (jsc#SLE-7772).
- ARM: dts: bcm283x: Move BCM2835/6/7 specific to
  bcm2835-common.dtsi (jsc#SLE-7772).
- ARM: dts: bcm283x: Remove brcm, bcm2835-pl011 compatible
  (jsc#SLE-7772).
- ARM: dts: bcm283x: Remove simple-bus from fixed clocks
  (jsc#SLE-7772).
- bluetooth: hci_bcm: Fix RTS handling during startup
  (jsc#SLE-7772).
- commit 19bad9e
* Mon Nov 25 2019 jslaby@suse.cz
- Refresh
  patches.suse/V4-01-10-bluetooth-hci_bcm-Fix-RTS-handling-during-startup.patch.
- Refresh
  patches.suse/V4-02-10-ARM-dts-bcm283x-Remove-simple-bus-from-fixed-clocks.patch.
- Refresh
  patches.suse/V4-03-10-ARM-dts-bcm283x-Remove-brcm-bcm2835-pl011-compatible.patch.
- Refresh
  patches.suse/V4-04-10-ARM-dts-bcm283x-Move-BCM2835-6-7-specific-to-bcm2835-common.dtsi.patch.
- Refresh
  patches.suse/V4-05-10-dt-bindings-arm-Convert-BCM2835-board-soc-bindings-to-json-schema.patch.
- Refresh
  patches.suse/V4-06-10-dt-bindings-arm-bcm2835-Add-Raspberry-Pi-4-to-DT-schema.patch.
- Refresh
  patches.suse/V4-07-10-ARM-bcm-Add-support-for-BCM2711-SoC.patch.
- Refresh
  patches.suse/V4-08-10-ARM-dts-Add-minimal-Raspberry-Pi-4-support.patch.
- Refresh
  patches.suse/V4-09-10-arm64-dts-broadcom-Add-reference-to-RPi-4-B.patch.
- Refresh
  patches.suse/v6-1-4-arm64-mm-use-arm64_dma_phys_limit-instead-of-calling-max_zone_dma_phys.patch.
- Refresh
  patches.suse/v6-2-4-arm64-rename-variables-used-to-calculate-ZONE_DMA32-s-size.patch.
- Refresh
  patches.suse/v6-3-4-arm64-use-both-ZONE_DMA-and-ZONE_DMA32.patch.
- Refresh
  patches.suse/v6-4-4-mm-refresh-ZONE_DMA-and-ZONE_DMA32-comments-in-enum-zone_type.patch.
- Refresh
  patches.suse/drm-amdgpu-Add-DC-feature-mask-to-disable-fractional.patch.
- Refresh patches.suse/net-ath10k-Fix-a-NULL-ptr-deref-bug.patch.
  Update upsream status.
- commit 60a2268
* Mon Nov 25 2019 jslaby@suse.cz
- Refresh
  patches.suse/0001-ARM-bcm283x-Reduce-register-ranges-for-UART-SPI-and-.patch.
- Refresh
  patches.suse/0001-ARM-dts-bcm283x-Define-MMC-interfaces-at-board-level.patch.
- Refresh
  patches.suse/0001-ARM-dts-bcm283x-Define-memory-at-board-level.patch.
- Refresh
  patches.suse/0001-ARM-dts-bcm283x-Enable-HDMI-at-board-level.patch.
- Refresh
  patches.suse/0001-clk-bcm2835-Add-BCM2711_CLOCK_EMMC2-support.patch.
- Refresh
  patches.suse/0001-clk-bcm2835-Introduce-SoC-specific-clock-registratio.patch.
- Refresh
  patches.suse/0001-clk-bcm2835-Mark-PLLD_PER-as-CRITICAL.patch.
- Refresh
  patches.suse/0001-dt-bindings-bcm2835-cprman-Add-bcm2711-support.patch.
- Refresh
  patches.suse/0001-dt-bindings-i2c-bcm2835-Add-brcm-bcm2711-compatible.patch.
- Refresh
  patches.suse/0001-dt-bindings-mmc-sdhci-iproc-Add-brcm-bcm2711-emmc2.patch.
- Refresh
  patches.suse/0001-i2c-bcm2835-Add-full-name-of-devicetree-node-to-adap.patch.
- Refresh
  patches.suse/0001-i2c-bcm2835-Avoid-clk-stretch-quirk-for-BCM2711.patch.
- Refresh
  patches.suse/0001-mmc-bcm2835-Take-SWIOTLB-memory-size-limitation-into.patch.
- Refresh
  patches.suse/0001-mmc-sdhci-iproc-Add-support-for-emmc2-of-the-BCM2711.patch.
- Refresh
  patches.suse/0001-pinctrl-bcm2835-Add-brcm-bcm2711-compatible.patch.
- Refresh
  patches.suse/0001-pinctrl-bcm2835-Add-support-for-BCM2711-pull-up-func.patch.
- Refresh
  patches.suse/V4-10-10-MAINTAINERS-Add-BCM2711-to-BCM2835-ARCH.patch.
- Refresh
  patches.suse/v2-mmc-sdhci-iproc-fix-spurious-interrupts-on-Multiblock-reads-with-bcm2711.patch.
  Update upstream status.
- commit 29acd1d
* Mon Nov 25 2019 mkubecek@suse.cz
- Update to 5.4 final
- refresh configs (only update headers)
- commit 4c9cd0f
* Sun Nov 24 2019 mkubecek@suse.cz
- config: disable SECURITY_DMESG_RESTRICT (bsc#1157066)
  Enabling this option which restricts access to dmesg was not intentional
  and happened accidentally as part of a commit aiming to enable features
  which were enabled in SLE. We might restrict dmesg in the future if there
  is a consensus but for now the proper action is to revert this accidental
  change which only affected some architectures anyway.
- commit 5c1d459
* Thu Nov 21 2019 lpechacek@suse.com
- Add crypto modules required by tcrypt (FIPS)
  References: bsc#1153192
- commit 0bc5cd1
* Thu Nov 21 2019 jslaby@suse.cz
- Linux 5.3.12 (bnc#1151927).
- slcan: Fix memory leak in error path (bnc#1151927).
- mmc: sdhci-of-at91: fix quirk2 overwrite (bnc#1151927).
- mm/page_io.c: do not free shared swap slots (bnc#1151927).
- mm/memory_hotplug: fix try_offline_node() (bnc#1151927).
- mm: slub: really fix slab walking for init_on_free
  (bnc#1151927).
- mm: hugetlb: switch to css_tryget() in
  hugetlb_cgroup_charge_cgroup() (bnc#1151927).
- mm: memcg: switch to css_tryget() in get_mem_cgroup_from_mm()
  (bnc#1151927).
- mm: mempolicy: fix the wrong return value and potential pages
  leak of mbind (bnc#1151927).
- iommu/vt-d: Fix QI_DEV_IOTLB_PFSID and QI_DEV_EIOTLB_PFSID
  macros (bnc#1151927).
- net: ethernet: dwmac-sun8i: Use the correct function in exit
  path (bnc#1151927).
- ntp/y2038: Remove incorrect time_t truncation (bnc#1151927).
- Revert "drm/i915/ehl: Update MOCS table for EHL" (bnc#1151927).
- drm/i915: update rawclk also on resume (bnc#1151927).
- io_uring: ensure registered buffer import returns the IO length
  (bnc#1151927).
- ecryptfs_lookup_interpose(): lower_dentry->d_parent is not
  stable either (bnc#1151927).
- ecryptfs_lookup_interpose(): lower_dentry->d_inode is not stable
  (bnc#1151927).
- x86/quirks: Disable HPET on Intel Coffe Lake platforms
  (bnc#1151927).
- i2c: acpi: Force bus speed to 400KHz if a Silead touchscreen
  is present (bnc#1151927).
- IB/hfi1: Use a common pad buffer for 9B and 16B packets
  (bnc#1151927).
- IB/hfi1: Ensure full Gen3 speed in a Gen4 system (bnc#1151927).
- IB/hfi1: TID RDMA WRITE should not return
  IB_WC_RNR_RETRY_EXC_ERR (bnc#1151927).
- IB/hfi1: Calculate flow weight based on QP MTU for TID RDMA
  (bnc#1151927).
- IB/hfi1: Ensure r_tid_ack is valid before building TID RDMA
  ACK packet (bnc#1151927).
- KVM: MMU: Do not treat ZONE_DEVICE pages as being reserved
  (bnc#1151927).
- Input: synaptics-rmi4 - destroy F54 poller workqueue when
  removing (bnc#1151927).
- Input: synaptics-rmi4 - clear IRQ enables for F54 (bnc#1151927).
- Input: synaptics-rmi4 - do not consume more data than we have
  (F11, F12) (bnc#1151927).
- Input: synaptics-rmi4 - disable the relative position IRQ in
  the F12 driver (bnc#1151927).
- Input: synaptics-rmi4 - fix video buffer size (bnc#1151927).
- Input: ff-memless - kill timer in destroy() (bnc#1151927).
- cgroup: freezer: call cgroup_enter_frozen() with preemption
  disabled in ptrace_stop() (bnc#1151927).
- Btrfs: fix log context list corruption after rename exchange
  operation (bnc#1151927).
- ALSA: usb-audio: Fix incorrect size check for
  processing/extension units (bnc#1151927).
- ALSA: usb-audio: Fix incorrect NULL check in
  create_yamaha_midi_quirk() (bnc#1151927).
- ALSA: usb-audio: not submit urb for stopped endpoint
  (bnc#1151927).
- ALSA: usb-audio: Fix missing error check at mixer resolution
  test (bnc#1151927).
- net/smc: fix refcount non-blocking connect() -part 2
  (bnc#1151927).
- devlink: Add method for time-stamp on reporter's dump
  (bnc#1151927).
- dpaa2-eth: free already allocated channels on probe defer
  (bnc#1151927).
- tcp: remove redundant new line from tcp_event_sk_skb
  (bnc#1151927).
- slip: Fix memory leak in slip_open error path (bnc#1151927).
- net: usb: qmi_wwan: add support for Foxconn T77W968 LTE modules
  (bnc#1151927).
- net/smc: fix fastopen for non-blocking connect() (bnc#1151927).
- net: gemini: add missed free_netdev (bnc#1151927).
- mlxsw: core: Enable devlink reload only on probe (bnc#1151927).
- ipmr: Fix skb headroom in ipmr_get_route() (bnc#1151927).
- devlink: disallow reload operation during device cleanup
  (bnc#1151927).
- ax88172a: fix information leak on short answers (bnc#1151927).
- scsi: core: Handle drivers which set sg_tablesize to zero
  (bnc#1151927).
- commit a6f6081
* Mon Nov 18 2019 mkubecek@suse.cz
- Update to 5.4-rc8
- refresh
  patches.suse/vfs-add-super_operations-get_inode_dev
- update configs
  - add X86_INTEL_TSX_MODE_OFF=y
  - drop VBOXSF_FS (driver dropped for now)
- commit 97aef18
* Thu Nov 14 2019 guillaume.gardet@arm.com
- arm64: Enable CONFIG_IR_GPIO_CIR (boo#1156748)
- commit f47e51f
* Thu Nov 14 2019 mbrugger@suse.com
- arm64: Update config files.
  Enable HW_RANDOM_OMAP used by machiattobin (bsc#1156466).
- commit 1402755
* Tue Nov 12 2019 jslaby@suse.cz
- Linux 5.3.11 (bnc#1151927).
- bonding: fix state transition issue in link monitoring
  (bnc#1151927).
- CDC-NCM: handle incomplete transfer of MTU (bnc#1151927).
- ipv4: Fix table id reference in fib_sync_down_addr
  (bnc#1151927).
- net: ethernet: octeon_mgmt: Account for second possible VLAN
  header (bnc#1151927).
- net: fix data-race in neigh_event_send() (bnc#1151927).
- net: qualcomm: rmnet: Fix potential UAF when unregistering
  (bnc#1151927).
- net/tls: fix sk_msg trim on fallback to copy mode (bnc#1151927).
- net: usb: qmi_wwan: add support for DW5821e with eSIM support
  (bnc#1151927).
- NFC: fdp: fix incorrect free object (bnc#1151927).
- nfc: netlink: fix double device reference drop (bnc#1151927).
- NFC: st21nfca: fix double free (bnc#1151927).
- qede: fix NULL pointer deref in __qede_remove() (bnc#1151927).
- net: mscc: ocelot: don't handle netdev events for other netdevs
  (bnc#1151927).
- net: mscc: ocelot: fix NULL pointer on LAG slave removal
  (bnc#1151927).
- net/tls: don't pay attention to sk_write_pending when pushing
  partial records (bnc#1151927).
- net/tls: add a TX lock (bnc#1151927).
- selftests/tls: add test for concurrent recv and send
  (bnc#1151927).
- ipv6: fixes rt6_probe() and fib6_nh->last_probe init
  (bnc#1151927).
- net: hns: Fix the stray netpoll locks causing deadlock in NAPI
  path (bnc#1151927).
- net: prevent load/store tearing on sk->sk_stamp (bnc#1151927).
- net: sched: prevent duplicate flower rules from tcf_proto
  destroy race (bnc#1151927).
- net/smc: fix ethernet interface refcounting (bnc#1151927).
- vsock/virtio: fix sock refcnt holding during the shutdown
  (bnc#1151927).
- r8169: fix page read in r8168g_mdio_read (bnc#1151927).
- ALSA: timer: Fix incorrectly assigned timer instance
  (bnc#1151927).
- ALSA: bebob: fix to detect configured source of sampling clock
  for Focusrite Saffire Pro i/o series (bnc#1151927).
- mm: memcontrol: fix NULL-ptr deref in percpu stats flush
  (bnc#1151927).
- mm: memcontrol: fix network errors from failing __GFP_ATOMIC
  charges (bnc#1151927).
- mm, meminit: recalculate pcpu batch and high limits after init
  completes (bnc#1151927).
- mm: thp: handle page cache THP correctly in PageTransCompoundMap
  (bnc#1151927).
- mm, vmstat: hide /proc/pagetypeinfo from normal users
  (bnc#1151927).
- dump_stack: avoid the livelock of the dump_lock (bnc#1151927).
- mm: slab: make page_cgroup_ino() to recognize non-compound
  slab pages properly (bnc#1151927).
- btrfs: Consider system chunk array size for new SYSTEM chunks
  (bnc#1151927).
- btrfs: tree-checker: Fix wrong check on max devid (bnc#1151927).
- btrfs: save i_size to avoid double evaluation of i_size_read
  in compress_file_range (bnc#1151927).
- tools: gpio: Use !building_out_of_srctree to determine srctree
  (bnc#1151927).
- pinctrl: intel: Avoid potential glitches if pin is in GPIO mode
  (bnc#1151927).
- perf tools: Fix time sorting (bnc#1151927).
- perf map: Use zalloc for map_groups (bnc#1151927).
- drm/radeon: fix si_enable_smc_cac() failed issue (bnc#1151927).
- HID: wacom: generic: Treat serial number and related fields
  as unsigned (bnc#1151927).
- mm/khugepaged: fix might_sleep() warn with CONFIG_HIGHPTE=y
  (bnc#1151927).
- soundwire: depend on ACPI (bnc#1151927).
- soundwire: depend on ACPI || OF (bnc#1151927).
- soundwire: bus: set initial value to port_status (bnc#1151927).
- blkcg: make blkcg_print_stat() print stats only for online blkgs
  (bnc#1151927).
- arm64: Do not mask out PTE_RDONLY in pte_same() (bnc#1151927).
- ASoC: rsnd: dma: fix SSI9 4/5/6/7 busif dma address
  (bnc#1151927).
- ceph: fix use-after-free in __ceph_remove_cap() (bnc#1151927).
- ceph: fix RCU case handling in ceph_d_revalidate()
  (bnc#1151927).
- ceph: add missing check in d_revalidate snapdir handling
  (bnc#1151927).
- ceph: don't try to handle hashed dentries in non-O_CREAT
  atomic_open (bnc#1151927).
- ceph: don't allow copy_file_range when stripe_count != 1
  (bnc#1151927).
- iio: adc: stm32-adc: fix stopping dma (bnc#1151927).
- iio: imu: adis16480: make sure provided frequency is positive
  (bnc#1151927).
- iio: imu: inv_mpu6050: fix no data on MPU6050 (bnc#1151927).
- iio: srf04: fix wrong limitation in distance measuring
  (bnc#1151927).
- ARM: sunxi: Fix CPU powerdown on A83T (bnc#1151927).
- ARM: dts: imx6-logicpd: Re-enable SNVS power key (bnc#1151927).
- cpufreq: intel_pstate: Fix invalid EPB setting (bnc#1151927).
- clone3: validate stack arguments (bnc#1151927).
- netfilter: nf_tables: Align nft_expr private data to 64-bit
  (bnc#1151927).
- netfilter: ipset: Fix an error code in ip_set_sockfn_get()
  (bnc#1151927).
- intel_th: gth: Fix the window switching sequence (bnc#1151927).
- intel_th: pci: Add Comet Lake PCH support (bnc#1151927).
- intel_th: pci: Add Jasper Lake PCH support (bnc#1151927).
- x86/dumpstack/64: Don't evaluate exception stacks before setup
  (bnc#1151927).
- x86/apic/32: Avoid bogus LDR warnings (bnc#1151927).
- SMB3: Fix persistent handles reconnect (bnc#1151927).
- can: usb_8dev: fix use-after-free on disconnect (bnc#1151927).
- can: flexcan: disable completely the ECC mechanism
  (bnc#1151927).
- can: c_can: c_can_poll(): only read status register after
  status IRQ (bnc#1151927).
- can: peak_usb: fix a potential out-of-sync while decoding
  packets (bnc#1151927).
- can: rx-offload: can_rx_offload_queue_sorted(): fix error
  handling, avoid skb mem leak (bnc#1151927).
- can: gs_usb: gs_can_open(): prevent memory leak (bnc#1151927).
- can: dev: add missing of_node_put() after calling
  of_get_child_by_name() (bnc#1151927).
- can: mcba_usb: fix use-after-free on disconnect (bnc#1151927).
- can: peak_usb: fix slab info leak (bnc#1151927).
- configfs: fix a deadlock in configfs_symlink() (bnc#1151927).
- ALSA: usb-audio: More validations of descriptor units
  (bnc#1151927).
- ALSA: usb-audio: Simplify parse_audio_unit() (bnc#1151927).
- ALSA: usb-audio: Unify the release of usb_mixer_elem_info
  objects (bnc#1151927).
- ALSA: usb-audio: Remove superfluous bLength checks
  (bnc#1151927).
- ALSA: usb-audio: Clean up check_input_term() (bnc#1151927).
- ALSA: usb-audio: Fix possible NULL dereference at
  create_yamaha_midi_quirk() (bnc#1151927).
- ALSA: usb-audio: remove some dead code (bnc#1151927).
- ALSA: usb-audio: Fix copy&paste error in the validator
  (bnc#1151927).
- usbip: Implement SG support to vhci-hcd and stub driver
  (bnc#1151927).
- HID: google: add magnemite/masterball USB ids (bnc#1151927).
- dmaengine: sprd: Fix the link-list pointer register
  configuration issue (bnc#1151927).
- bpf: lwtunnel: Fix reroute supplying invalid dst (bnc#1151927).
- dmaengine: xilinx_dma: Fix 64-bit simple AXIDMA transfer
  (bnc#1151927).
- dmaengine: xilinx_dma: Fix control reg update in
  vdma_channel_set_config (bnc#1151927).
- dmaengine: sprd: Fix the possible memory leak issue
  (bnc#1151927).
- HID: intel-ish-hid: fix wrong error handling in
  ishtp_cl_alloc_tx_ring() (bnc#1151927).
- powerpc/32s: fix allow/prevent_user_access() when crossing
  segment boundaries (bnc#1151927).
- RDMA/mlx5: Clear old rate limit when closing QP (bnc#1151927).
- iw_cxgb4: fix ECN check on the passive accept (bnc#1151927).
- RDMA/siw: free siw_base_qp in kref release routine
  (bnc#1151927).
- RDMA/qedr: Fix reported firmware version (bnc#1151927).
- IB/core: Use rdma_read_gid_l2_fields to compare GID L2 fields
  (bnc#1151927).
- net/mlx5e: Tx, Fix assumption of single WQEBB of NOP in cleanup
  flow (bnc#1151927).
- net/mlx5e: kTLS, Release reference on DUMPed fragments in
  shutdown flow (bnc#1151927).
- net/mlx5e: TX, Fix consumer index of error cqe dump
  (bnc#1151927).
- net/mlx5: prevent memory leak in mlx5_fpga_conn_create_cq
  (bnc#1151927).
- net/mlx5: fix memory leak in mlx5_fw_fatal_reporter_dump
  (bnc#1151927).
- selftests/bpf: More compatible nc options in test_tc_edt
  (bnc#1151927).
- scsi: qla2xxx: fixup incorrect usage of host_byte (bnc#1151927).
- scsi: lpfc: Check queue pointer before use (bnc#1151927).
- scsi: ufs-bsg: Wake the device before sending raw upiu commands
  (bnc#1151927).
- ARC: [plat-hsdk]: Enable on-board SPI NOR flash IC
  (bnc#1151927).
- RDMA/uverbs: Prevent potential underflow (bnc#1151927).
- bpf: Fix use after free in subprog's jited symbol removal
  (bnc#1151927).
- net: stmmac: Fix the problem of tso_xmit (bnc#1151927).
- net: openvswitch: free vport unless register_netdevice()
  succeeds (bnc#1151927).
- scsi: lpfc: Honor module parameter lpfc_use_adisc (bnc#1151927).
- scsi: qla2xxx: Initialized mailbox to prevent driver load
  failure (bnc#1151927).
- bpf: Fix use after free in bpf_get_prog_name (bnc#1151927).
- iwlwifi: pcie: fix PCI ID 0x2720 configs that should be soc
  (bnc#1151927).
- iwlwifi: pcie: fix all 9460 entries for qnj (bnc#1151927).
- iwlwifi: pcie: 0x2720 is qu and 0x30DC is not (bnc#1151927).
- netfilter: nf_flow_table: set timeout before insertion into
  hashes (bnc#1151927).
- drm/v3d: Fix memory leak in v3d_submit_cl_ioctl (bnc#1151927).
- xsk: Fix registration of Rx-only sockets (bnc#1151927).
- net: phy: smsc: LAN8740: add PHY_RST_AFTER_CLK_EN flag
  (bnc#1151927).
- ipvs: don't ignore errors in case refcounting ip_vs module fails
  (bnc#1151927).
- ipvs: move old_secure_tcp into struct netns_ipvs (bnc#1151927).
- netfilter: nft_payload: fix missing check for matching length
  in offloads (bnc#1151927).
- RDMA/nldev: Skip counter if port doesn't match (bnc#1151927).
- bonding: fix unexpected IFF_BONDING bit unset (bnc#1151927).
- bonding: use dynamic lockdep key instead of subclass
  (bnc#1151927).
- macsec: fix refcnt leak in module exit routine (bnc#1151927).
- virt_wifi: fix refcnt leak in module exit routine (bnc#1151927).
- scsi: sd: define variable dif as unsigned int instead of bool
  (bnc#1151927).
- usb: dwc3: select CONFIG_REGMAP_MMIO (bnc#1151927).
- usb: fsl: Check memory resource before releasing it
  (bnc#1151927).
- usb: gadget: udc: atmel: Fix interrupt storm in FIFO mode
  (bnc#1151927).
- usb: gadget: composite: Fix possible double free memory bug
  (bnc#1151927).
- usb: gadget: configfs: fix concurrent issue between composite
  APIs (bnc#1151927).
- usb: dwc3: remove the call trace of USBx_GFLADJ (bnc#1151927).
- perf/x86/amd/ibs: Fix reading of the IBS OpData register and
  thus precise RIP validity (bnc#1151927).
- perf/x86/amd/ibs: Handle erratum #420 only on the affected
  CPU family (10h) (bnc#1151927).
- perf/x86/uncore: Fix event group support (bnc#1151927).
- USB: Skip endpoints with 0 maxpacket length (bnc#1151927).
- USB: ldusb: use unsigned size format specifiers (bnc#1151927).
- usbip: tools: Fix read_usb_vudc_device() error path handling
  (bnc#1151927).
- RDMA/iw_cxgb4: Avoid freeing skb twice in arp failure case
  (bnc#1151927).
- RDMA/hns: Prevent memory leaks of eq->buf_list (bnc#1151927).
- hwmon: (ina3221) Fix read timeout issue (bnc#1151927).
- scsi: qla2xxx: stop timer in shutdown path (bnc#1151927).
- sched/topology: Don't try to build empty sched domains
  (bnc#1151927).
- sched/topology: Allow sched_asym_cpucapacity to be disabled
  (bnc#1151927).
- nvme-multipath: fix possible io hang after ctrl reconnect
  (bnc#1151927).
- net: hisilicon: Fix "Trying to free already-free IRQ"
  (bnc#1151927).
- wimax: i2400: Fix memory leak in i2400m_op_rfkill_sw_toggle
  (bnc#1151927).
- net: mscc: ocelot: fix vlan_filtering when enslaving to bridge
  before link is up (bnc#1151927).
- net: mscc: ocelot: refuse to overwrite the port's native vlan
  (bnc#1151927).
- iommu/amd: Apply the same IVRS IOAPIC workaround to Acer Aspire
  A315-41 (bnc#1151927).
- mt76: dma: fix buffer unmap with non-linear skbs (bnc#1151927).
- drm/amdgpu/sdma5: do not execute 0-sized IBs (v2) (bnc#1151927).
- drm/sched: Set error to s_fence if HW job submission failed
  (bnc#1151927).
- drm/amdgpu: If amdgpu_ib_schedule fails return back the error
  (bnc#1151927).
- drm/amd/display: do not synchronize "drr" displays
  (bnc#1151927).
- drm/amd/display: add 50us buffer as WA for pstate switch in
  active (bnc#1151927).
- drm/amd/display: Passive DP->HDMI dongle detection fix
  (bnc#1151927).
- dc.c:use kzalloc without test (bnc#1151927).
- SUNRPC: The TCP back channel mustn't disappear while requests
  are outstanding (bnc#1151927).
- SUNRPC: The RDMA back channel mustn't disappear while requests
  are outstanding (bnc#1151927).
- SUNRPC: Destroy the back channel when we destroy the host
  transport (bnc#1151927).
- hv_netvsc: Fix error handling in netvsc_attach() (bnc#1151927).
- efi/tpm: Return -EINVAL when determining tpm final events log
  size fails (bnc#1151927).
- efi: libstub/arm: Account for firmware reserved memory at the
  base of RAM (bnc#1151927).
- x86, efi: Never relocate kernel below lowest acceptable address
  (bnc#1151927).
- arm64: cpufeature: Enable Qualcomm Falkor errata 1009 for Kryo
  (bnc#1151927).
- usb: dwc3: gadget: fix race when disabling ep with cancelled
  xfers (bnc#1151927).
- arm64: apply ARM64_ERRATUM_845719 workaround for Brahma-B53 core
  (bnc#1151927).
- arm64: Brahma-B53 is SSB and spectre v2 safe (bnc#1151927).
- arm64: apply ARM64_ERRATUM_843419 workaround for Brahma-B53 core
  (bnc#1151927).
- NFSv4: Don't allow a cached open with a revoked delegation
  (bnc#1151927).
- net: ethernet: arc: add the missed clk_disable_unprepare
  (bnc#1151927).
- igb: Fix constant media auto sense switching when no cable is
  connected (bnc#1151927).
- e1000: fix memory leaks (bnc#1151927).
- gve: Fixes DMA synchronization (bnc#1151927).
- ocfs2: protect extent tree in ocfs2_prepare_inode_for_write()
  (bnc#1151927).
- pinctrl: cherryview: Fix irq_valid_mask calculation
  (bnc#1151927).
- clk: imx8m: Use SYS_PLL1_800M as intermediate parent of CLK_ARM
  (bnc#1151927).
- timekeeping/vsyscall: Update VDSO data unconditionally
  (bnc#1151927).
- mm/filemap.c: don't initiate writeback if mapping has no dirty
  pages (bnc#1151927).
- cgroup,writeback: don't switch wbs immediately on dead wbs if
  the memcg is dead (bnc#1151927).
- ARM: dts: stm32: change joystick pinctrl definition on
  stm32mp157c-ev1 (bnc#1151927).
- ASoC: SOF: Intel: hda-stream: fix the CONFIG_ prefix missing
  (bnc#1151927).
- usbip: Fix free of unallocated memory in vhci tx (bnc#1151927).
- bonding: fix using uninitialized mode_lock (bnc#1151927).
- netfilter: ipset: Copy the right MAC address in hash:ip,mac
  IPv6 sets (bnc#1151927).
- arm64: errata: Update stale comment (bnc#1151927).
- net/ibmvnic: unlock rtnl_lock in reset so linkwatch_event can
  run (bnc#1151927).
- drm/i915: Rename gen7 cmdparser tables (bnc#1151927).
- drm/i915: Disable Secure Batches for gen6+ (bnc#1151927).
- drm/i915: Remove Master tables from cmdparser (bnc#1151927).
- drm/i915: Add support for mandatory cmdparsing (bnc#1151927).
- drm/i915: Support ro ppgtt mapped cmdparser shadow buffers
  (bnc#1151927).
- drm/i915: Allow parsing of unsized batches (bnc#1151927).
- drm/i915: Add gen9 BCS cmdparsing (bnc#1151927).
- drm/i915/cmdparser: Use explicit goto for error paths
  (bnc#1151927).
- drm/i915/cmdparser: Add support for backward jumps
  (bnc#1151927).
- drm/i915/cmdparser: Ignore Length operands during command
  matching (bnc#1151927).
- drm/i915: Lower RM timeout to avoid DSI hard hangs
  (bnc#1151927).
- drm/i915/gen8+: Add RC6 CTX corruption WA (bnc#1151927).
- drm/i915/cmdparser: Fix jump whitelist clearing (bnc#1151927).
- x86/msr: Add the IA32_TSX_CTRL MSR (bnc#1151927).
- x86/cpu: Add a helper function x86_read_arch_cap_msr()
  (bnc#1151927).
- x86/cpu: Add a "tsx=" cmdline option with TSX disabled by
  default (bnc#1151927).
- x86/speculation/taa: Add mitigation for TSX Async Abort
  (bnc#1151927).
- x86/speculation/taa: Add sysfs reporting for TSX Async Abort
  (bnc#1151927).
- kvm/x86: Export MDS_NO=0 to guests when TSX is enabled
  (bnc#1151927).
- x86/tsx: Add "auto" option to the tsx= cmdline parameter
  (bnc#1151927).
- x86/speculation/taa: Add documentation for TSX Async Abort
  (bnc#1151927).
- x86/tsx: Add config options to set tsx=on|off|auto
  (bnc#1151927).
- x86/speculation/taa: Fix printing of TAA_MSG_SMT on IBRS_ALL
  CPUs (bnc#1151927).
- x86/bugs: Add ITLB_MULTIHIT bug infrastructure (bnc#1151927).
- x86/cpu: Add Tremont to the cpu vulnerability whitelist
  (bnc#1151927).
- cpu/speculation: Uninline and export CPU mitigations helpers
  (bnc#1151927).
- Documentation: Add ITLB_MULTIHIT documentation (bnc#1151927).
- kvm: x86, powerpc: do not allow clearing largepages debugfs
  entry (bnc#1151927).
- kvm: mmu: ITLB_MULTIHIT mitigation (bnc#1151927).
- kvm: Add helper function for creating VM worker threads
  (bnc#1151927).
- kvm: x86: mmu: Recovery of shattered NX large pages
  (bnc#1151927).
- Update config files.
  Set X86_INTEL_TSX_MODE_OFF=y (the default)
- commit 0a195a8
* Mon Nov 11 2019 tiwai@suse.de
- usb: dwc3: pci: prevent memory leak in dwc3_pci_probe
  (CVE-2019-18813,bsc#1156278).
- ASoC: SOF: Fix memory leak in sof_dfsentry_write
  (CVE-2019-18812,bsc#1156277).
- commit 8a126f1
* Mon Nov 11 2019 jslaby@suse.cz
- Refresh
  patches.suse/stacktrace-don-t-skip-first-entry-on-noncurrent-task.patch.
  Update upstream status.
- commit baac78a
* Mon Nov 11 2019 mkubecek@suse.cz
- Update to 5.4-rc7
- eliminated 1 patch
- new config option
  - VBOXSF_FS=m (x86 only)
- commit c59faac
* Sun Nov 10 2019 jslaby@suse.cz
- Linux 5.3.10 (bnc#1151927).
- usb: gadget: udc: core: Fix segfault if udc_bind_to_driver()
  for pending driver fails (bnc#1151927).
- arm64: dts: ti: k3-am65-main: Fix gic-its node unit-address
  (bnc#1151927).
- ASoC: pcm3168a: The codec does not support S32_LE (bnc#1151927).
- selftests/powerpc: Fix compile error on tlbie_test due to
  newer gcc (bnc#1151927).
- selftests/powerpc: Add test case for tlbie vs mtpidr ordering
  issue (bnc#1151927).
- CIFS: Fix retry mid list corruption on reconnects (bnc#1151927).
- platform/x86: pmc_atom: Add Siemens SIMATIC IPC227E to
  critclk_systems DMI table (bnc#1151927).
- net/flow_dissector: switch to siphash (bnc#1151927).
- net: bcmgenet: reset 40nm EPHY on energy detect (bnc#1151927).
- net: phy: bcm7xxx: define soft_reset for 40nm EPHY
  (bnc#1151927).
- net: netem: correct the parent's backlog when corrupted packet
  was dropped (bnc#1151927).
- r8152: add device id for Lenovo ThinkPad USB-C Dock Gen 2
  (bnc#1151927).
- net: usb: lan78xx: Connect PHY before registering MAC
  (bnc#1151927).
- net: reorder 'struct net' fields to avoid false sharing
  (bnc#1151927).
- net: netem: fix error path for corrupted GSO frames
  (bnc#1151927).
- net: hns3: fix mis-counting IRQ vector numbers issue
  (bnc#1151927).
- net: ensure correct skb->tstamp in various fragmenters
  (bnc#1151927).
- net: dsa: fix switch tree list (bnc#1151927).
- net: dsa: b53: Do not clear existing mirrored port mask
  (bnc#1151927).
- net: bcmgenet: don't set phydev->link from MAC (bnc#1151927).
- ipv4: fix IPSKB_FRAG_PMTU handling with fragmentation
  (bnc#1151927).
- net/mlx5e: Fix handling of compressed CQEs in case of low NAPI
  budget (bnc#1151927).
- net/mlx5e: Fix ethtool self test: link speed (bnc#1151927).
- r8169: fix wrong PHY ID issue with RTL8168dp (bnc#1151927).
- mlxsw: core: Unpublish devlink parameters during reload
  (bnc#1151927).
- net/mlx5: Fix rtable reference leak (bnc#1151927).
- net/smc: fix refcounting for non-blocking connect()
  (bnc#1151927).
- net/mlx5: Fix flow counter list auto bits struct (bnc#1151927).
- net/mlx5e: Initialize on stack link modes bitmap (bnc#1151927).
- net/mlx5e: Remove incorrect match criteria assignment line
  (bnc#1151927).
- net/mlx5e: Determine source port properly for vlan push action
  (bnc#1151927).
- rxrpc: Fix handling of last subpacket of jumbo packet
  (bnc#1151927).
- net: phylink: Fix phylink_dbg() macro (bnc#1151927).
- keys: Fix memory leak in copy_net_ns (bnc#1151927).
- net/smc: keep vlan_id for SMC-R in smc_listen_work()
  (bnc#1151927).
- net/smc: fix closing of fallback SMC sockets (bnc#1151927).
- selftests: fib_tests: add more tests for metric update
  (bnc#1151927).
- ipv4: fix route update on metric change (bnc#1151927).
- net: add READ_ONCE() annotation in __skb_wait_for_more_packets()
  (bnc#1151927).
- net: use skb_queue_empty_lockless() in busy poll contexts
  (bnc#1151927).
- net: use skb_queue_empty_lockless() in poll() handlers
  (bnc#1151927).
- udp: use skb_queue_empty_lockless() (bnc#1151927).
- net: add skb_queue_empty_lockless() (bnc#1151927).
- vxlan: check tun_info options_len properly (bnc#1151927).
- udp: fix data-race in udp_set_dev_scratch() (bnc#1151927).
- selftests: net: reuseport_dualstack: fix uninitalized parameter
  (bnc#1151927).
- net: Zeroing the structure ethtool_wolinfo in ethtool_get_wol()
  (bnc#1151927).
- net: usb: lan78xx: Disable interrupts before calling
  generic_handle_irq() (bnc#1151927).
- net: rtnetlink: fix a typo fbd -> fdb (bnc#1151927).
- netns: fix GFP flags in rtnl_net_notifyid() (bnc#1151927).
- net/mlx4_core: Dynamically set guaranteed amount of counters
  per VF (bnc#1151927).
- net: hisilicon: Fix ping latency when deal with high throughput
  (bnc#1151927).
- net: fix sk_page_frag() recursion from memory reclaim
  (bnc#1151927).
- net: ethernet: ftgmac100: Fix DMA coherency issue with SW
  checksum (bnc#1151927).
- net: dsa: bcm_sf2: Fix IMP setup for port different than 8
  (bnc#1151927).
- net: annotate lockless accesses to sk->sk_napi_id (bnc#1151927).
- net: annotate accesses to sk->sk_incoming_cpu (bnc#1151927).
- inet: stop leaking jiffies on the wire (bnc#1151927).
- erspan: fix the tun_info options_len check for erspan
  (bnc#1151927).
- dccp: do not leak jiffies on the wire (bnc#1151927).
- cxgb4: request the TX CIDX updates to status page (bnc#1151927).
- cxgb4: fix panic when attaching to ULD fail (bnc#1151927).
- nbd: handle racing with error'ed out commands (bnc#1151927).
- nbd: protect cmd->status with cmd->lock (bnc#1151927).
- irqchip/sifive-plic: Skip contexts except supervisor in
  plic_init() (bnc#1151927).
- cifs: Fix cifsInodeInfo lock_sem deadlock when reconnect occurs
  (bnc#1151927).
- i2c: stm32f7: remove warning when compiling with W=1
  (bnc#1151927).
- i2c: stm32f7: fix a race in slave mode with arbitration loss
  irq (bnc#1151927).
- i2c: stm32f7: fix first byte to send in slave mode
  (bnc#1151927).
- i2c: mt65xx: fix NULL ptr dereference (bnc#1151927).
- irqchip/gic-v3-its: Use the exact ITSList for VMOVP
  (bnc#1151927).
- MIPS: bmips: mark exception vectors as char arrays
  (bnc#1151927).
- of: unittest: fix memory leak in unittest_data_add
  (bnc#1151927).
- ALSA: hda: Add Tigerlake/Jasperlake PCI ID (bnc#1151927).
- selftests: kvm: fix sync_regs_test with newer gccs
  (bnc#1151927).
- selftests: kvm: vmx_set_nested_state_test: don't check for
  VMX support twice (bnc#1151927).
- ARM: 8926/1: v7m: remove register save to stack before svc
  (bnc#1151927).
- drm/komeda: Don't flush inactive pipes (bnc#1151927).
- i2c: aspeed: fix master pending state handling (bnc#1151927).
- ARM: dts: bcm2837-rpi-cm3: Avoid leds-gpio probing issue
  (bnc#1151927).
- tracing: Fix "gfp_t" format for synthetic events (bnc#1151927).
- ASoC: SOF: control: return true when kcontrol values change
  (bnc#1151927).
- ASoC: Intel: sof-rt5682: add a check for devm_clk_get
  (bnc#1151927).
- scsi: hpsa: add missing hunks in reset-patch (bnc#1151927).
- scsi: target: core: Do not overwrite CDB byte 1 (bnc#1151927).
- drm/amdgpu: fix error handling in amdgpu_bo_list_create
  (bnc#1151927).
- drm/amdgpu: fix potential VM faults (bnc#1151927).
- ARM: davinci: dm365: Fix McBSP dma_slave_map entry
  (bnc#1151927).
- perf kmem: Fix memory leak in compact_gfp_flags() (bnc#1151927).
- 8250-men-mcb: fix error checking when get_num_ports returns
  - ENODEV (bnc#1151927).
- perf c2c: Fix memory leak in build_cl_output() (bnc#1151927).
- perf tools: Fix resource leak of closedir() on the error paths
  (bnc#1151927).
- arm64: dts: imx8mm: Use correct clock for usdhc's ipg clk
  (bnc#1151927).
- arm64: dts: imx8mq: Use correct clock for usdhc's ipg clk
  (bnc#1151927).
- ARM: dts: imx7s: Correct GPT's ipg clock source (bnc#1151927).
- ARM: dts: vf610-zii-scu4-aib: Specify 'i2c-mux-idle-disconnect'
  (bnc#1151927).
- ARM: dts: imx6q-logicpd: Re-Enable SNVS power key (bnc#1151927).
- arm64: dts: lx2160a: Correct CPU core idle state name
  (bnc#1151927).
- arm64: dts: rockchip: Fix usb-c on Hugsun X99 TV Box
  (bnc#1151927).
- arm64: dts: rockchip: fix RockPro64 sdmmc settings
  (bnc#1151927).
- ARM: 8914/1: NOMMU: Fix exc_ret for XIP (bnc#1151927).
- ARM: 8908/1: add __always_inline to functions called from
  __get_user_check() (bnc#1151927).
- scsi: fix kconfig dependency warning related to 53C700_LE_ON_BE
  (bnc#1151927).
- scsi: sni_53c710: fix compilation error (bnc#1151927).
- scsi: scsi_dh_alua: handle RTPG sense code correctly during
  state transitions (bnc#1151927).
- scsi: qla2xxx: fix a potential NULL pointer dereference
  (bnc#1151927).
- ARM: mm: fix alignment handler faults under memory pressure
  (bnc#1151927).
- ARM: dts: Use level interrupt for omap4 & 5 wlcore
  (bnc#1151927).
- ASoC: simple_card_utils.h: Fix potential multiple redefinition
  error (bnc#1151927).
- ASoC: msm8916-wcd-digital: add missing MIX2 path for RX1/2
  (bnc#1151927).
- ARM: dts: am3874-iceboard: Fix 'i2c-mux-idle-disconnect' usage
  (bnc#1151927).
- arm64: dts: zii-ultra: fix ARM regulator states (bnc#1151927).
- pinctrl: stmfx: fix null pointer on remove (bnc#1151927).
- pinctrl: ns2: Fix off by one bugs in ns2_pinmux_enable()
  (bnc#1151927).
- arm64: dts: rockchip: fix RockPro64 sdhci settings
  (bnc#1151927).
- arm64: dts: rockchip: fix RockPro64 vdd-log regulator settings
  (bnc#1151927).
- ARM: dts: logicpd-torpedo-som: Remove twl_keypad (bnc#1151927).
- arm64: dts: rockchip: fix Rockpro64 RK808 interrupt line
  (bnc#1151927).
- ASoc: rockchip: i2s: Fix RPM imbalance (bnc#1151927).
- ASoC: wm_adsp: Don't generate kcontrols without READ flags
  (bnc#1151927).
- regulator: pfuze100-regulator: Variable "val" in
  pfuze100_regulator_probe() could be uninitialized (bnc#1151927).
- ASoC: intel: bytcr_rt5651: add null check to
  support_button_press (bnc#1151927).
- ASoC: intel: sof_rt5682: add remove function to disable jack
  (bnc#1151927).
- ASoC: rt5682: add NULL handler to set_jack function
  (bnc#1151927).
- ASoC: SOF: Intel: hda: Disable DMI L1 entry during capture
  (bnc#1151927).
- Update config files.
  CONFIG_SND_SOC_SOF_HDA_ALWAYS_ENABLE_DMI_L1=n as per default.
- ASoC: SOF: Intel: initialise and verify FW crash dump data
  (bnc#1151927).
- ASoC: SOF: Intel: hda: fix warnings during FW load
  (bnc#1151927).
- ASoC: SOF: topology: fix parse fail issue for byte/bool tuple
  types (bnc#1151927).
- ASoC: SOF: loader: fix kernel oops on firmware boot failure
  (bnc#1151927).
- pinctrl: intel: Allocate IRQ chip dynamic (bnc#1151927).
- regulator: ti-abb: Fix timeout in
  ti_abb_wait_txdone/ti_abb_clear_all_txdone (bnc#1151927).
- arm64: dts: Fix gpio to pinmux mapping (bnc#1151927).
- arm64: dts: allwinner: a64: sopine-baseboard: Add PHY regulator
  delay (bnc#1151927).
- arm64: dts: allwinner: a64: Drop PMU node (bnc#1151927).
- arm64: dts: allwinner: a64: pine64-plus: Add PHY regulator delay
  (bnc#1151927).
- ASoC: topology: Fix a signedness bug in
  soc_tplg_dapm_widget_create() (bnc#1151927).
- regulator: da9062: fix suspend_enable/disable preparation
  (bnc#1151927).
- ASoC: wm8994: Do not register inapplicable controls for WM1811
  (bnc#1151927).
- ASoC: samsung: arndale: Add missing OF node dereferencing
  (bnc#1151927).
- regulator: of: fix suspend-min/max-voltage parsing
  (bnc#1151927).
- commit eedf3c5
* Fri Nov  8 2019 tiwai@suse.de
- fjes: Handle workqueue allocation failure
  (CVE-2019-16231,bsc#1150466).
- commit 3bf0c5a
* Thu Nov  7 2019 jslaby@suse.cz
- Linux 5.3.9 (bnc#11519).
- io_uring: fix up O_NONBLOCK handling for sockets (bnc#1151927).
- dm snapshot: introduce account_start_copy() and
  account_end_copy() (bnc#1151927).
- dm snapshot: rework COW throttling to fix deadlock
  (bnc#1151927).
- Btrfs: fix inode cache block reserve leak on failure to allocate
  data space (bnc#1151927).
- btrfs: qgroup: Always free PREALLOC META reserve in
  btrfs_delalloc_release_extents() (bnc#1151927).
- iio: adc: meson_saradc: Fix memory allocation order
  (bnc#1151927).
- iio: fix center temperature of bmc150-accel-core (bnc#1151927).
- libsubcmd: Make _FORTIFY_SOURCE defines dependent on the feature
  (bnc#1151927).
- perf tests: Avoid raising SEGV using an obvious NULL dereference
  (bnc#1151927).
- perf map: Fix overlapped map handling (bnc#1151927).
- perf script brstackinsn: Fix recovery from LBR/binary mismatch
  (bnc#1151927).
- perf jevents: Fix period for Intel fixed counters (bnc#1151927).
- perf tools: Propagate get_cpuid() error (bnc#1151927).
- perf annotate: Propagate perf_env__arch() error (bnc#1151927).
- perf annotate: Fix the signedness of failure returns
  (bnc#1151927).
- perf annotate: Propagate the symbol__annotate() error return
  (bnc#1151927).
- perf annotate: Fix arch specific ->init() failure errors
  (bnc#1151927).
- perf annotate: Return appropriate error code for allocation
  failures (bnc#1151927).
- perf annotate: Don't return -1 for error when doing BPF
  disassembly (bnc#1151927).
- staging: rtl8188eu: fix null dereference when kzalloc fails
  (bnc#1151927).
- RDMA/siw: Fix serialization issue in write_space()
  (bnc#1151927).
- RDMA/hfi1: Prevent memory leak in sdma_init (bnc#1151927).
- RDMA/iw_cxgb4: fix SRQ access from dump_qp() (bnc#1151927).
- RDMA/iwcm: Fix a lock inversion issue (bnc#1151927).
- HID: hyperv: Use in-place iterator API in the channel callback
  (bnc#1151927).
- kselftest: exclude failed TARGETS from runlist (bnc#1151927).
- selftests/kselftest/runner.sh: Add 45 second timeout per test
  (bnc#1151927).
- nfs: Fix nfsi->nrequests count error on nfs_inode_remove_request
  (bnc#1151927).
- arm64: cpufeature: Effectively expose FRINT capability to
  userspace (bnc#1151927).
- arm64: Fix incorrect irqflag restore for priority masking for
  compat (bnc#1151927).
- arm64: ftrace: Ensure synchronisation in PLT setup for
  Neoverse-N1 #1542419 (bnc#1151927).
- tty: serial: owl: Fix the link time qualifier of
  'owl_uart_exit()' (bnc#1151927).
- tty: serial: rda: Fix the link time qualifier of
  'rda_uart_exit()' (bnc#1151927).
- serial/sifive: select SERIAL_EARLYCON (bnc#1151927).
- tty: n_hdlc: fix build on SPARC (bnc#1151927).
- misc: fastrpc: prevent memory leak in fastrpc_dma_buf_attach
  (bnc#1151927).
- RDMA/core: Fix an error handling path in 'res_get_common_doit()'
  (bnc#1151927).
- RDMA/cm: Fix memory leak in cm_add/remove_one (bnc#1151927).
- RDMA/nldev: Reshuffle the code to avoid need to rebind QP in
  error path (bnc#1151927).
- RDMA/mlx5: Do not allow rereg of a ODP MR (bnc#1151927).
- RDMA/mlx5: Order num_pending_prefetch properly with
  synchronize_srcu (bnc#1151927).
- RDMA/mlx5: Add missing synchronize_srcu() for MW cases
  (bnc#1151927).
- gpio: max77620: Use correct unit for debounce times
  (bnc#1151927).
- fs: cifs: mute -Wunused-const-variable message (bnc#1151927).
- arm64: vdso32: Fix broken compat vDSO build warnings
  (bnc#1151927).
- arm64: vdso32: Detect binutils support for dmb ishld
  (bnc#1151927).
- serial: mctrl_gpio: Check for NULL pointer (bnc#1151927).
- serial: 8250_omap: Fix gpio check for auto RTS/CTS
  (bnc#1151927).
- arm64: Default to building compat vDSO with clang when
  CONFIG_CC_IS_CLANG (bnc#1151927).
- arm64: vdso32: Don't use KBUILD_CPPFLAGS unconditionally
  (bnc#1151927).
- efi/cper: Fix endianness of PCIe class code (bnc#1151927).
- efi/x86: Do not clean dummy variable in kexec path
  (bnc#1151927).
- MIPS: include: Mark __cmpxchg as __always_inline (bnc#1151927).
- riscv: avoid kernel hangs when trapped in BUG() (bnc#1151927).
- riscv: avoid sending a SIGTRAP to a user thread trapped in
  WARN() (bnc#1151927).
- riscv: Correct the handling of unexpected ebreak in
  do_trap_break() (bnc#1151927).
- x86/xen: Return from panic notifier (bnc#1151927).
- ocfs2: clear zero in unaligned direct IO (bnc#1151927).
- fs: ocfs2: fix possible null-pointer dereferences in
  ocfs2_xa_prepare_entry() (bnc#1151927).
- fs: ocfs2: fix a possible null-pointer dereference in
  ocfs2_write_end_nolock() (bnc#1151927).
- fs: ocfs2: fix a possible null-pointer dereference in
  ocfs2_info_scan_inode_alloc() (bnc#1151927).
- btrfs: silence maybe-uninitialized warning in clone_range
  (bnc#1151927).
- arm64: armv8_deprecated: Checking return value for memory
  allocation (bnc#1151927).
- x86/cpu: Add Comet Lake to the Intel CPU models header
  (bnc#1151927).
- sched/fair: Scale bandwidth quota and period without losing
  quota/period ratio precision (bnc#1151927).
- sched/vtime: Fix guest/system mis-accounting on task switch
  (bnc#1151927).
- perf/core: Rework memory accounting in perf_mmap()
  (bnc#1151927).
- perf/core: Fix corner case in perf_rotate_context()
  (bnc#1151927).
- perf/x86/amd: Change/fix NMI latency mitigation to use a
  timestamp (bnc#1151927).
- drm/amdgpu: fix memory leak (bnc#1151927).
- iio: imu: adis16400: release allocated memory on failure
  (bnc#1151927).
- iio: imu: adis16400: fix memory leak (bnc#1151927).
- iio: imu: st_lsm6dsx: fix waitime for st_lsm6dsx i2c controller
  (bnc#1151927).
- MIPS: include: Mark __xchg as __always_inline (bnc#1151927).
- MIPS: fw: sni: Fix out of bounds init of o32 stack
  (bnc#1151927).
- s390/cio: fix virtio-ccw DMA without PV (bnc#1151927).
- virt: vbox: fix memory leak in hgcm_call_preprocess_linaddr
  (bnc#1151927).
- nbd: fix possible sysfs duplicate warning (bnc#1151927).
- NFSv4: Fix leak of clp->cl_acceptor string (bnc#1151927).
- SUNRPC: fix race to sk_err after xs_error_report (bnc#1151927).
- s390/uaccess: avoid (false positive) compiler warnings
  (bnc#1151927).
- tracing: Initialize iter->seq after zeroing in
  tracing_read_pipe() (bnc#1151927).
- perf annotate: Fix multiple memory and file descriptor leaks
  (bnc#1151927).
- perf/aux: Fix tracking of auxiliary trace buffer allocation
  (bnc#1151927).
- USB: legousbtower: fix a signedness bug in tower_probe()
  (bnc#1151927).
- nbd: verify socket is supported during setup (bnc#1151927).
- arm64: dts: qcom: Add Lenovo Miix 630 (bnc#1151927).
- arm64: dts: qcom: Add HP Envy x2 (bnc#1151927).
- arm64: dts: qcom: Add Asus NovaGo TP370QL (bnc#1151927).
- rtw88: Fix misuse of GENMASK macro (bnc#1151927).
- s390/pci: fix MSI message data (bnc#1151927).
- thunderbolt: Correct path indices for PCIe tunnel (bnc#1151927).
- thunderbolt: Use 32-bit writes when writing ring
  producer/consumer (bnc#1151927).
- fuse: flush dirty data/metadata before non-truncate setattr
  (bnc#1151927).
- fuse: truncate pending writes on O_TRUNC (bnc#1151927).
- ALSA: bebob: Fix prototype of helper function to return negative
  value (bnc#1151927).
- ALSA: timer: Fix mutex deadlock at releasing card (bnc#1151927).
- ALSA: hda/realtek - Fix 2 front mics of codec 0x623
  (bnc#1151927).
- ALSA: hda/realtek - Add support for ALC623 (bnc#1151927).
- ath10k: fix latency issue for QCA988x (bnc#1151927).
- UAS: Revert commit 3ae62a42090f ("UAS: fix alignment of
  scatter/gather segments") (bnc#1151927).
- nl80211: fix validation of mesh path nexthop (bnc#1151927).
- USB: gadget: Reject endpoints with 0 maxpacket value
  (bnc#1151927).
- usb-storage: Revert commit 747668dbc061 ("usb-storage: Set
  virt_boundary_mask to avoid SG overflows") (bnc#1151927).
- USB: ldusb: fix ring-buffer locking (bnc#1151927).
- USB: ldusb: fix control-message timeout (bnc#1151927).
- usb: xhci: fix Immediate Data Transfer endianness (bnc#1151927).
- usb: xhci: fix __le32/__le64 accessors in debugfs code
  (bnc#1151927).
- USB: serial: whiteheat: fix potential slab corruption
  (bnc#1151927).
- USB: serial: whiteheat: fix line-speed endianness (bnc#1151927).
- xhci: Fix use-after-free regression in xhci clear hub TT
  implementation (bnc#1151927).
- scsi: qla2xxx: Fix partial flash write of MBI (bnc#1151927).
- scsi: target: cxgbit: Fix cxgbit_fw4_ack() (bnc#1151927).
- HID: i2c-hid: add Trekstor Primebook C11B to descriptor override
  (bnc#1151927).
- HID: Fix assumption that devices have inputs (bnc#1151927).
- HID: fix error message in hid_open_report() (bnc#1151927).
- HID: logitech-hidpp: split g920_get_config() (bnc#1151927).
- HID: logitech-hidpp: rework device validation (bnc#1151927).
- HID: logitech-hidpp: do all FF cleanup in hidpp_ff_destroy()
  (bnc#1151927).
- um-ubd: Entrust re-queue to the upper layers (bnc#1151927).
- s390/unwind: fix mixing regs and sp (bnc#1151927).
- s390/cmm: fix information leak in cmm_timeout_handler()
  (bnc#1151927).
- s390/idle: fix cpu idle time calculation (bnc#1151927).
- ARC: perf: Accommodate big-endian CPU (bnc#1151927).
- IB/hfi1: Avoid excessive retry for TID RDMA READ request
  (bnc#1151927).
- arm64: Ensure VM_WRITE|VM_SHARED ptes are clean by default
  (bnc#1151927).
- arm64: cpufeature: Enable Qualcomm Falkor/Kryo errata 1003
  (bnc#1151927).
- virtio_ring: fix stalls for packed rings (bnc#1151927).
- rtlwifi: rtl_pci: Fix problem of too small skb->len
  (bnc#1151927).
- KVM: vmx, svm: always run with EFER.NXE=1 when shadow paging
  is active (bnc#1151927).
- dmaengine: qcom: bam_dma: Fix resource leak (bnc#1151927).
- dmaengine: tegra210-adma: fix transfer failure (bnc#1151927).
- dmaengine: imx-sdma: fix size check for sdma script_number
  (bnc#1151927).
- dmaengine: cppi41: Fix cppi41_dma_prep_slave_sg() when idle
  (bnc#1151927).
- drm/amdgpu/gmc10: properly set BANK_SELECT and FRAGMENT_SIZE
  (bnc#1151927).
- drm/i915: Fix PCH reference clock for FDI on HSW/BDW
  (bnc#1151927).
- drm/amdgpu/gfx10: update gfx golden settings (bnc#1151927).
- drm/amdgpu/powerplay/vega10: allow undervolting in p7
  (bnc#1151927).
- drm/amdgpu: Fix SDMA hang when performing VKexample test
  (bnc#1151927).
- NFS: Fix an RCU lock leak in nfs4_refresh_delegation_stateid()
  (bnc#1151927).
- io_uring: ensure we clear io_kiocb->result before each issue
  (bnc#1151927).
- iommu/vt-d: Fix panic after kexec -p for kdump (bnc#1151927).
- batman-adv: Avoid free/alloc race when handling OGM buffer
  (bnc#1151927).
- llc: fix sk_buff leak in llc_sap_state_process() (bnc#1151927).
- llc: fix sk_buff leak in llc_conn_service() (bnc#1151927).
- rxrpc: Fix call ref leak (bnc#1151927).
- rxrpc: rxrpc_peer needs to hold a ref on the rxrpc_local record
  (bnc#1151927).
- rxrpc: Fix trace-after-put looking at the put peer record
  (bnc#1151927).
- NFC: pn533: fix use-after-free and memleaks (bnc#1151927).
- bonding: fix potential NULL deref in bond_update_slave_arr
  (bnc#1151927).
- netfilter: conntrack: avoid possible false sharing
  (bnc#1151927).
- net: usb: sr9800: fix uninitialized local variable
  (bnc#1151927).
- sch_netem: fix rcu splat in netem_enqueue() (bnc#1151927).
- net: sched: sch_sfb: don't call qdisc_put() while holding tree
  lock (bnc#1151927).
- iwlwifi: exclude GEO SAR support for 3168 (bnc#1151927).
- sched/fair: Fix low cpu usage with high throttling by removing
  expiration of cpu-local slices (bnc#1151927).
- ALSA: usb-audio: DSD auto-detection for Playback Designs
  (bnc#1151927).
- ALSA: usb-audio: Update DSD support quirks for Oppo and Rotel
  (bnc#1151927).
- ALSA: usb-audio: Add DSD support for Gustard U16/X26 USB
  Interface (bnc#1151927).
- RDMA/mlx5: Use irq xarray locking for mkey_table (bnc#1151927).
- sched/fair: Fix -Wunused-but-set-variable warnings
  (bnc#1151927).
- powerpc/powernv: Fix CPU idle to be called with IRQs disabled
  (bnc#1151927).
- Revert "nvme: allow 64-bit results in passthru commands"
  (bnc#1151927).
- Revert "ALSA: hda: Flush interrupts on disabling" (bnc#1151927).
- commit b0d4923
* Wed Nov  6 2019 tiwai@suse.de
- rpm/kernel-source.spec.in: Fix dependency of kernel-devel (bsc#1154043)
- commit ceb9273
* Wed Nov  6 2019 afaerber@suse.com
- config: armv7hl: Update to 5.4-rc6
- commit be38a7b
* Wed Nov  6 2019 jslaby@suse.cz
- rpm/kernel-binary.spec.in: add COMPRESS_VMLINUX (bnc#1155921)
  Let COMPRESS_VMLINUX determine the compression used for vmlinux. By
  default (historically), it is gz.
- commit c8b2d9f
* Wed Nov  6 2019 mkubecek@suse.cz
- config: refresh armv6hl/vanilla
- commit 152052e
* Tue Nov  5 2019 afaerber@suse.com
- config: armv6hl: Update to 5.4-rc6
- commit e45bb5a
* Tue Nov  5 2019 tiwai@suse.de
- ALSA: hda/ca0132 - Fix possible workqueue stall (bsc#1155836).
- commit 98ead79
* Tue Nov  5 2019 mbrugger@suse.com
- rpm/mkspec-dtb: add mt76 based dtb package
- commit 8ff92d0
* Tue Nov  5 2019 jslaby@suse.cz
- stacktrace: Don't skip first entry on noncurrent tasks
  (bnc#1154866).
- commit 897b65b
* Tue Nov  5 2019 jslaby@suse.cz
- stacktrace: Don't skip first entry on noncurrent tasks
  (bnc#1154866).
  Update upstream status.
- commit f4d9b5e
* Mon Nov  4 2019 msuchanek@suse.de
- rpm/kernel-subpackage-spec: Mention debuginfo in the subpackage
  description (bsc#1149119).
- commit 525ec92
* Mon Nov  4 2019 jslaby@suse.cz
- ata: make qc_prep return ata_completion_errors (bnc#1110252).
- ata: define AC_ERR_OK (bnc#1110252).
- ata: sata_mv, avoid trigerrable BUG_ON (bnc#1110252).
- commit 8bf663b
* Mon Nov  4 2019 mkubecek@suse.cz
- Update to 5.4-rc6
- eliminated 1 patch
- refresh configs
- commit 816e8ae
* Thu Oct 31 2019 afaerber@suse.de
- config: arm64: Re-enable default flavor, too
- commit c8cf7fe
* Wed Oct 30 2019 mkubecek@suse.cz
- config: refresh also arm64/vanilla
- commit a48c425
* Wed Oct 30 2019 jslaby@suse.cz
- Refresh
  patches.suse/stacktrace-don-t-skip-first-entry-on-noncurrent-task.patch.
  v3 of the patch
- commit ea4c828
* Wed Oct 30 2019 mkubecek@suse.cz
- config: refresh
- commit cb090f9
* Wed Oct 30 2019 afaerber@suse.de
- config: arm64: Update to 5.4-rc5
- commit 22182c8
* Tue Oct 29 2019 jslaby@suse.cz
- Linux 5.3.8 (bnc#1151927).
- drm: Free the writeback_job when it with an empty fb
  (bnc#1151927).
- drm: Clear the fence pointer when writeback job signaled
  (bnc#1151927).
- clk: ti: dra7: Fix mcasp8 clock bits (bnc#1151927).
- ARM: dts: Fix wrong clocks for dra7 mcasp (bnc#1151927).
- nvme-pci: Fix a race in controller removal (bnc#1151927).
- scsi: ufs: skip shutdown if hba is not powered (bnc#1151927).
- scsi: megaraid: disable device when probe failed after enabled
  device (bnc#1151927).
- scsi: qla2xxx: Silence fwdump template message (bnc#1151927).
- scsi: qla2xxx: Fix unbound sleep in fcport delete path
  (bnc#1151927).
- scsi: qla2xxx: Fix stale mem access on driver unload
  (bnc#1151927).
- scsi: qla2xxx: Fix N2N link reset (bnc#1151927).
- scsi: qla2xxx: Fix N2N link up fail (bnc#1151927).
- ARM: dts: Fix gpio0 flags for am335x-icev2 (bnc#1151927).
- ARM: OMAP2+: Fix missing reset done flag for am3 and am43
  (bnc#1151927).
- ARM: OMAP2+: Add missing LCDC midlemode for am335x
  (bnc#1151927).
- ARM: OMAP2+: Fix warnings with broken omap2_set_init_voltage()
  (bnc#1151927).
- nvme-tcp: fix wrong stop condition in io_work (bnc#1151927).
- nvme-pci: Save PCI state before putting drive into deepest state
  (bnc#1151927).
- nvme: fix an error code in nvme_init_subsystem() (bnc#1151927).
- nvme-rdma: Fix max_hw_sectors calculation (bnc#1151927).
- Added QUIRKs for ADATA XPG SX8200 Pro 512GB (bnc#1151927).
- nvme: Add quirk for Kingston NVME SSD running FW E8FK11.T
  (bnc#1151927).
- nvme: allow 64-bit results in passthru commands (bnc#1151927).
- drm/komeda: prevent memory leak in komeda_wb_connector_add
  (bnc#1151927).
- nvme-rdma: fix possible use-after-free in connect timeout
  (bnc#1151927).
- blk-mq: honor IO scheduler for multiqueue devices (bnc#1151927).
- ieee802154: ca8210: prevent memory leak (bnc#1151927).
- ARM: dts: am4372: Set memory bandwidth limit for DISPC
  (bnc#1151927).
- net: dsa: qca8k: Use up to 7 ports for all operations
  (bnc#1151927).
- MIPS: dts: ar9331: fix interrupt-controller size (bnc#1151927).
- xen/efi: Set nonblocking callbacks (bnc#1151927).
- loop: change queue block size to match when using DIO
  (bnc#1151927).
- nl80211: fix null pointer dereference (bnc#1151927).
- mac80211: fix txq null pointer dereference (bnc#1151927).
- netfilter: nft_connlimit: disable bh on garbage collection
  (bnc#1151927).
- net: mscc: ocelot: add missing of_node_put after calling
  of_get_child_by_name (bnc#1151927).
- net: dsa: rtl8366rb: add missing of_node_put after calling
  of_get_child_by_name (bnc#1151927).
- net: stmmac: xgmac: Not all Unicast addresses may be available
  (bnc#1151927).
- net: stmmac: dwmac4: Always update the MAC Hash Filter
  (bnc#1151927).
- net: stmmac: Correctly take timestamp for PTPv2 (bnc#1151927).
- net: stmmac: Do not stop PHY if WoL is enabled (bnc#1151927).
- net: ag71xx: fix mdio subnode support (bnc#1151927).
- RISC-V: Clear load reservations while restoring hart contexts
  (bnc#1151927).
- riscv: Fix memblock reservation for device tree blob
  (bnc#1151927).
- drm/amdgpu: fix multiple memory leaks in acp_hw_init
  (bnc#1151927).
- drm/amd/display: memory leak (bnc#1151927).
- mips: Loongson: Fix the link time qualifier of 'serial_exit()'
  (bnc#1151927).
- net: hisilicon: Fix usage of uninitialized variable in function
  mdio_sc_cfg_reg_write() (bnc#1151927).
- net: stmmac: Avoid deadlock on suspend/resume (bnc#1151927).
- selftests: kvm: Fix libkvm build error (bnc#1151927).
- lib: textsearch: fix escapes in example code (bnc#1151927).
- s390/mm: fix -Wunused-but-set-variable warnings (bnc#1151927).
- r8152: Set macpassthru in reset_resume callback (bnc#1151927).
- net: phy: allow for reset line to be tied to a sleepy GPIO
  controller (bnc#1151927).
- net: phy: fix write to mii-ctrl1000 register (bnc#1151927).
- namespace: fix namespace.pl script to support relative paths
  (bnc#1151927).
- Convert filldir[64]() from __put_user() to unsafe_put_user()
  (bnc#1151927).
- elf: don't use MAP_FIXED_NOREPLACE for elf executable mappings
  (bnc#1151927).
- Make filldir[64]() verify the directory entry filename is valid
  (bnc#1151927).
- uaccess: implement a proper unsafe_copy_to_user() and switch
  filldir over to it (bnc#1151927).
- filldir[64]: remove WARN_ON_ONCE() for bad directory entries
  (bnc#1151927).
- net_sched: fix backward compatibility for TCA_KIND
  (bnc#1151927).
- net_sched: fix backward compatibility for TCA_ACT_KIND
  (bnc#1151927).
- libata/ahci: Fix PCS quirk application (bnc#1151927).
- md/raid0: fix warning message for parameter default_layout
  (bnc#1151927).
- Revert "drm/radeon: Fix EEH during kexec" (bnc#1151927).
- ocfs2: fix panic due to ocfs2_wq is null (bnc#1151927).
- nvme-pci: Set the prp2 correctly when using more than 4k page
  (bnc#1151927).
- ipv4: fix race condition between route lookup and invalidation
  (bnc#1151927).
- ipv4: Return -ENETUNREACH if we can't create route but saddr
  is valid (bnc#1151927).
- net: avoid potential infinite loop in tc_ctl_action()
  (bnc#1151927).
- net: bcmgenet: Fix RGMII_MODE_EN value for GENET v1/2/3
  (bnc#1151927).
- net: bcmgenet: Set phydev->dev_flags only for internal PHYs
  (bnc#1151927).
- net: i82596: fix dma_alloc_attr for sni_82596 (bnc#1151927).
- net/ibmvnic: Fix EOI when running in XIVE mode (bnc#1151927).
- net: ipv6: fix listify ip6_rcv_finish in case of forwarding
  (bnc#1151927).
- net: stmmac: disable/enable ptp_ref_clk in suspend/resume flow
  (bnc#1151927).
- rxrpc: Fix possible NULL pointer access in ICMP handling
  (bnc#1151927).
- sched: etf: Fix ordering of packets with same txtime
  (bnc#1151927).
- sctp: change sctp_prot .no_autobind with true (bnc#1151927).
- net: aquantia: temperature retrieval fix (bnc#1151927).
- net: aquantia: when cleaning hw cache it should be toggled
  (bnc#1151927).
- net: aquantia: do not pass lro session with invalid tcp checksum
  (bnc#1151927).
- net: aquantia: correctly handle macvlan and multicast
  coexistence (bnc#1151927).
- net: phy: micrel: Discern KSZ8051 and KSZ8795 PHYs
  (bnc#1151927).
- net: phy: micrel: Update KSZ87xx PHY name (bnc#1151927).
- net: avoid errors when trying to pop MLPS header on non-MPLS
  packets (bnc#1151927).
- net/sched: fix corrupted L2 header with MPLS 'push' and 'pop'
  actions (bnc#1151927).
- netdevsim: Fix error handling in nsim_fib_init and nsim_fib_exit
  (bnc#1151927).
- net: ethernet: broadcom: have drivers select DIMLIB as needed
  (bnc#1151927).
- net: phy: Fix "link partner" information disappear issue
  (bnc#1151927).
- LSM: SafeSetID: Stop releasing uninitialized ruleset
  (bnc#1151927).
- rxrpc: use rcu protection while reading sk->sk_user_data
  (bnc#1151927).
- io_uring: fix bad inflight accounting for
  SETUP_IOPOLL|SETUP_SQTHREAD (bnc#1151927).
- io_uring: Fix corrupted user_data (bnc#1151927).
- USB: legousbtower: fix memleak on disconnect (bnc#1151927).
- ALSA: hda/realtek - Add support for ALC711 (bnc#1151927).
- ALSA: hda/realtek - Enable headset mic on Asus MJ401TA
  (bnc#1151927).
- ALSA: usb-audio: Disable quirks for BOSS Katana amplifiers
  (bnc#1151927).
- ALSA: hda - Force runtime PM on Nvidia HDMI codecs
  (bnc#1151927).
- usb: udc: lpc32xx: fix bad bit shift operation (bnc#1151927).
- USB: serial: ti_usb_3410_5052: fix port-close races
  (bnc#1151927).
- USB: ldusb: fix memleak on disconnect (bnc#1151927).
- USB: usblp: fix use-after-free on disconnect (bnc#1151927).
- USB: ldusb: fix read info leaks (bnc#1151927).
- binder: Don't modify VMA bounds in ->mmap handler (bnc#1151927).
- MIPS: tlbex: Fix build_restore_pagemask KScratch restore
  (bnc#1151927).
- staging: wlan-ng: fix exit return when sme->key_idx >=
  NUM_WEPKEYS (bnc#1151927).
- scsi: zfcp: fix reaction on bit error threshold notification
  (bnc#1151927).
- scsi: sd: Ignore a failure to sync cache due to lack of
  authorization (bnc#1151927).
- scsi: core: save/restore command resid for error handling
  (bnc#1151927).
- scsi: core: try to get module before removing device
  (bnc#1151927).
- scsi: ch: Make it possible to open a ch device multiple times
  again (bnc#1151927).
- Revert "Input: elantech - enable SMBus on new (2018+) systems"
  (bnc#1151927).
- Input: da9063 - fix capability and drop KEY_SLEEP (bnc#1151927).
- Input: synaptics-rmi4 - avoid processing unknown IRQs
  (bnc#1151927).
- Input: st1232 - fix reporting multitouch coordinates
  (bnc#1151927).
- ASoC: rsnd: Reinitialize bit clock inversion flag for every
  format setting (bnc#1151927).
- ACPI: CPPC: Set pcc_data[pcc_ss_id] to NULL in
  acpi_cppc_processor_exit() (bnc#1151927).
- ACPI: NFIT: Fix unlock on error in scrub_show() (bnc#1151927).
- iwlwifi: pcie: change qu with jf devices to use qu configuration
  (bnc#1151927).
- mac80211: Reject malformed SSID elements (bnc#1151927).
- drm/edid: Add 6 bpc quirk for SDC panel in Lenovo G50
  (bnc#1151927).
- drm/ttm: Restore ttm prefaulting (bnc#1151927).
- drm/panfrost: Handle resetting on timeout better (bnc#1151927).
- drm/amdgpu: Bail earlier when amdgpu.cik_/si_support is not
  set to 1 (bnc#1151927).
- drm/amdgpu/sdma5: fix mask value of POLL_REGMEM packet for
  pipe sync (bnc#1151927).
- drm/i915/userptr: Never allow userptr into the mappable GGTT
  (bnc#1151927).
- drm/i915: Favor last VBT child device with conflicting AUX
  ch/DDC pin (bnc#1151927 bnc#1152971 fdo#112028).
- drm/amdgpu/vce: fix allocation size in enc ring test
  (bnc#1151927).
- drm/amdgpu/vcn: fix allocation size in enc ring test
  (bnc#1151927).
- drm/amdgpu/uvd6: fix allocation size in enc ring test (v2)
  (bnc#1151927).
- drm/amdgpu/uvd7: fix allocation size in enc ring test (v2)
  (bnc#1151927).
- drm/amdgpu: user pages array memory leak fix (bnc#1151927).
- drivers/base/memory.c: don't access uninitialized memmaps in
  soft_offline_page_store() (bnc#1151927).
- fs/proc/page.c: don't access uninitialized memmaps in
  fs/proc/page.c (bnc#1151927).
- io_uring: Fix broken links with offloading (bnc#1151927).
- io_uring: Fix race for sqes with userspace (bnc#1151927).
- io_uring: used cached copies of sq->dropped and cq->overflow
  (bnc#1151927).
- mmc: mxs: fix flags passed to dmaengine_prep_slave_sg
  (bnc#1151927).
- mmc: cqhci: Commit descriptors before setting the doorbell
  (bnc#1151927).
- mmc: sdhci-omap: Fix Tuning procedure for temperatures < -20C
  (bnc#1151927).
- mm/memory-failure.c: don't access uninitialized memmaps in
  memory_failure() (bnc#1151927).
- mm/slub: fix a deadlock in show_slab_objects() (bnc#1151927).
- mm/page_owner: don't access uninitialized memmaps when reading
  /proc/pagetypeinfo (bnc#1151927).
- mm/memunmap: don't access uninitialized memmap in
  memunmap_pages() (bnc#1151927).
- mm: memcg/slab: fix panic in __free_slab() caused by premature
  memcg pointer release (bnc#1151927).
- mm, compaction: fix wrong pfn handling in
  __reset_isolation_pfn() (bnc#1151927).
- mm: memcg: get number of pages on the LRU list in memcgroup
  base on lru_zone_size (bnc#1151927).
- mm: memblock: do not enforce current limit for memblock_phys*
  family (bnc#1151927).
- hugetlbfs: don't access uninitialized memmaps in
  pfn_range_valid_gigantic() (bnc#1151927).
- mm/memory-failure: poison read receives SIGKILL instead of
  SIGBUS if mmaped more than once (bnc#1151927).
- zram: fix race between backing_dev_show and backing_dev_store
  (bnc#1151927).
- xtensa: drop EXPORT_SYMBOL for outs*/ins* (bnc#1151927).
- xtensa: fix change_bit in exclusive access option (bnc#1151927).
- s390/zcrypt: fix memleak at release (bnc#1151927).
- s390/kaslr: add support for R_390_GLOB_DAT relocation type
  (bnc#1151927).
- lib/vdso: Make clock_getres() POSIX compliant again
  (bnc#1151927).
- parisc: Fix vmap memory leak in ioremap()/iounmap()
  (bnc#1151927).
- EDAC/ghes: Fix Use after free in ghes_edac remove path
  (bnc#1151927).
- arm64: KVM: Trap VM ops when ARM64_WORKAROUND_CAVIUM_TX2_219_TVM
  is set (bnc#1151927).
- arm64: Avoid Cavium TX2 erratum 219 when switching TTBR
  (bnc#1151927).
- arm64: Enable workaround for Cavium TX2 erratum 219 when
  running SMT (bnc#1151927).
- arm64: Allow CAVIUM_TX2_ERRATUM_219 to be selected
  (bnc#1151927).
- CIFS: avoid using MID 0xFFFF (bnc#1151927).
- cifs: Fix missed free operations (bnc#1151927).
- CIFS: Fix use after free of file info structures (bnc#1151927).
- perf/aux: Fix AUX output stopping (bnc#1151927).
- tracing: Fix race in perf_trace_buf initialization
  (bnc#1151927).
- fs/dax: Fix pmd vs pte conflict detection (bnc#1151927).
- dm cache: fix bugs when a GFP_NOWAIT allocation fails
  (bnc#1151927).
- irqchip/sifive-plic: Switch to fasteoi flow (bnc#1151927).
- x86/apic/x2apic: Fix a NULL pointer deref when handling a
  dying cpu (bnc#1151927).
- x86/hyperv: Make vapic support x2apic mode (bnc#1151927).
- pinctrl: cherryview: restore Strago DMI workaround for all
  versions (bnc#1151927).
- pinctrl: armada-37xx: fix control of pins 32 and up
  (bnc#1151927).
- pinctrl: armada-37xx: swap polarity on LED group (bnc#1151927).
- btrfs: block-group: Fix a memory leak due to missing
  btrfs_put_block_group() (bnc#1151927).
- Btrfs: add missing extents release on file extent cluster
  relocation error (bnc#1151927).
- btrfs: don't needlessly create extent-refs kernel thread
  (bnc#1151927).
- Btrfs: fix qgroup double free after failure to reserve metadata
  for delalloc (bnc#1151927).
- Btrfs: check for the full sync flag while holding the inode
  lock during fsync (bnc#1151927).
- btrfs: tracepoints: Fix wrong parameter order for qgroup events
  (bnc#1151927).
- btrfs: tracepoints: Fix bad entry members of qgroup events
  (bnc#1151927).
- KVM: PPC: Book3S HV: XIVE: Ensure VP isn't already in use
  (bnc#1151927).
- memstick: jmb38x_ms: Fix an error handling path in
  'jmb38x_ms_probe()' (bnc#1151927).
- cpufreq: Avoid cpufreq_suspend() deadlock on system shutdown
  (bnc#1151927).
- ceph: just skip unrecognized info in ceph_reply_info_extra
  (bnc#1151927).
- xen/netback: fix error path of xenvif_connect_data()
  (bnc#1151927).
- PCI: PM: Fix pci_power_up() (bnc#1151927).
- opp: of: drop incorrect lockdep_assert_held() (bnc#1151927).
- of: reserved_mem: add missing of_node_put() for proper
  ref-counting (bnc#1151927).
- blk-rq-qos: fix first node deletion of rq_qos_del()
  (bnc#1151927).
- RDMA/cxgb4: Do not dma memory off of the stack (bnc#1151927).
- Delete
  patches.suse/Revert-drm-i915-bios-make-child-device-order-the-pri.patch.
- Update config files.
  CAVIUM_TX2_ERRATUM_219=y (default)
- commit f0ffcb7
* Tue Oct 29 2019 jslaby@suse.cz
- x86/boot/64: Make level2_kernel_pgt pages invalid outside
  kernel area (bnc#1153969).
- x86/boot/64: Round memory hole size up to next PMD page
  (bnc#1153969).
- commit 3501dc2
* Mon Oct 28 2019 tiwai@suse.de
- drm/amdgpu: Add DC feature mask to disable fractional pwm
  (bsc#1154010).
- commit 6ffba6e
* Sun Oct 27 2019 mkubecek@suse.cz
- Update to 4.5-rc5
- New config option:
  - SND_SOC_SOF_HDA_ALWAYS_ENABLE_DMI_L1=n (x86 only)
- commit 13dfd5f
* Fri Oct 25 2019 jslaby@suse.cz
- stacktrace: don't skip first entry on noncurrent tasks
  (bnc#1154866).
- commit 387f2bb
* Wed Oct 23 2019 mkubecek@suse.cz
- series.conf: cleanup
  Move two submitted wireless patches to "on the way to mainline" section.
  No effect on expanded tree.
- commit 21fb44d
* Tue Oct 22 2019 msuchanek@suse.de
- kernel-binary.spec.in: Fix build of non-modular kernels (boo#1154578).
- commit 7f1e881
* Tue Oct 22 2019 clin@suse.com
- ARM: 8904/1: skip nomap memblocks while finding the
  lowmem/highmem boundary (bsc#1122614).
- commit 9f59038
* Tue Oct 22 2019 acho@suse.com
- rtlwifi: Fix potential overflow on P2P code (bsc#1154372
  CVE-2019-17666).
- cfg80211: wext: avoid copying malformed SSIDs (bsc#1153158
  CVE-2019-17133).
- commit e229e3d
* Tue Oct 22 2019 acho@suse.com
- rtlwifi: Fix potential overflow on P2P code (bsc#1154372
  CVE-2019-17666).
- commit 6257f3c
* Mon Oct 21 2019 tiwai@suse.de
- libertas: fix a potential NULL pointer dereference
  (CVE-2019-16232,bsc#1150465).
- iwlwifi: pcie: fix rb_allocator workqueue allocation
  (CVE-2019-16234,bsc#1150452).
- commit 23c6b73
* Mon Oct 21 2019 msuchanek@suse.de
- kernel-binary.spec.in: Obsolete kgraft packages only when not building
  them.
- commit 25f7690
* Mon Oct 21 2019 msuchanek@suse.de
- kernel-subpackage-build: create zero size ghost for uncompressed vmlinux
  (bsc#1154354).
  It is not strictly necessary to uncompress it so maybe the ghost file
  can be 0 size in this case.
- commit 4bf73c8
* Mon Oct 21 2019 mkubecek@suse.cz
- Update to 5.4-rc4
- Eliminated 1 patch
- commit bdcace5
* Fri Oct 18 2019 jslaby@suse.cz
- Linux 5.3.7 (bnc#1151927).
- efi/tpm: Fix sanity check of unsigned tbl_size being less than
  zero (bnc#1151927).
- io_uring: only flush workqueues on fileset removal
  (bnc#1151927).
- x86/asm: Fix MWAITX C-state hint value (bnc#1151927).
- mtd: rawnand: au1550nd: Fix au_read_buf16() prototype
  (bnc#1151927).
- hwmon: Fix HWMON_P_MIN_ALARM mask (bnc#1151927).
- tracing: Get trace_array reference for available_tracers files
  (bnc#1151927).
- ftrace: Get a reference counter for the trace_array on filter
  files (bnc#1151927).
- tracing/hwlat: Don't ignore outer-loop duration when calculating
  max_latency (bnc#1151927).
- tracing/hwlat: Report total time spent in all NMIs during the
  sample (bnc#1151927).
- arm64/sve: Fix wrong free for task->thread.sve_state
  (bnc#1151927).
- media: stkwebcam: fix runtime PM after driver unbind
  (bnc#1151927).
- drm/msm: Use the correct dma_sync calls harder (bnc#1151927).
- drm/i915: Mark contents as dirty on a write fault (bnc#1151927).
- drm/i915: Whitelist COMMON_SLICE_CHICKEN2 (bnc#1151927).
- drm/i915: Bump skl+ max plane width to 5k for linear/x-tiled
  (bnc#1151927).
- Fix the locking in dcache_readdir() and friends (bnc#1151927).
- iio: light: fix vcnl4000 devicetree hooks (bnc#1151927).
- arm64: topology: Use PPTT to determine if PE is a thread
  (bnc#1151927).
- ACPI/PPTT: Add support for ACPI 6.3 thread flag (bnc#1151927).
- RDMA/vmw_pvrdma: Free SRQ only once (bnc#1151927).
- MIPS: elf_hwcap: Export userspace ASEs (bnc#1151927).
- MIPS: Disable Loongson MMI instructions for kernel build
  (bnc#1151927).
- NFS: Fix O_DIRECT accounting of number of bytes read/written
  (bnc#1151927).
- btrfs: fix uninitialized ret in ref-verify (bnc#1151927).
- btrfs: fix incorrect updating of log root tree (bnc#1151927).
- Btrfs: fix memory leak due to concurrent append writes with
  fiemap (bnc#1151927).
- btrfs: fix balance convert to single on 32-bit host CPUs
  (bnc#1151927).
- btrfs: allocate new inode in NOFS context (bnc#1151927).
- btrfs: relocation: fix use-after-free on dead relocation roots
  (bnc#1151927).
- gpiolib: don't clear FLAG_IS_OUT when emulating
  open-drain/open-source (bnc#1151927).
- gpio: fix getting nonexclusive gpiods from DT (bnc#1151927).
- firmware: google: increment VPD key_len properly (bnc#1151927).
- IB/core: Fix wrong iterating on ports (bnc#1151927).
- mm/vmpressure.c: fix a signedness bug in
  vmpressure_register_event() (bnc#1151927).
- mm/page_alloc.c: fix a crash in free_pages_prepare()
  (bnc#1151927).
- mm/z3fold.c: claim page in the beginning of free (bnc#1151927).
- kernel/sysctl.c: do not override max_threads provided by
  userspace (bnc#1151927).
- cifs: use cifsInodeInfo->open_file_lock while iterating to
  avoid a panic (bnc#1151927).
- CIFS: Force reval dentry if LOOKUP_REVAL flag is set
  (bnc#1151927).
- CIFS: Force revalidate inode when dentry is stale (bnc#1151927).
- CIFS: Gracefully handle QueryInfo errors during open
  (bnc#1151927).
- selinux: fix context string corruption in convert_context()
  (bnc#1151927).
- blk-wbt: fix performance regression in wbt scale_up/scale_down
  (bnc#1151927).
- drm/i915: Perform GGTT restore much earlier during resume
  (bnc#1151927).
- perf inject jit: Fix JIT_CODE_MOVE filename (bnc#1151927).
- perf llvm: Don't access out-of-scope array (bnc#1151927).
- efi/tpm: Only set 'efi_tpm_final_log_size' after successful
  event log parsing (bnc#1151927).
- efi/tpm: Don't traverse an event log with no events
  (bnc#1151927).
- efi/tpm: Don't access event->count when it isn't mapped
  (bnc#1151927).
- efivar/ssdt: Don't iterate over EFI vars if no SSDT override
  was specified (bnc#1151927).
- iio: accel: adxl372: Perform a reset at start up (bnc#1151927).
- iio: accel: adxl372: Fix push to buffers lost samples
  (bnc#1151927).
- iio: accel: adxl372: Fix/remove limitation for FIFO samples
  (bnc#1151927).
- iio: light: add missing vcnl4040 of_compatible (bnc#1151927).
- iio: light: opt3001: fix mutex unlock race (bnc#1151927).
- iio: adc: stm32-adc: fix a race when using several adcs with
  dma and irq (bnc#1151927).
- iio: adc: stm32-adc: move registers definitions (bnc#1151927).
- iio: adc: axp288: Override TS pin bias current for some models
  (bnc#1151927).
- iio: adc: ad799x: fix probe error handling (bnc#1151927).
- iio: adc: hx711: fix bug in sampling of data (bnc#1151927).
- staging: vt6655: Fix memory leak in vt6655_probe (bnc#1151927).
- staging: rtl8188eu: fix HighestRate check in
  odm_ARFBRefresh_8188E() (bnc#1151927).
- Staging: fbtft: fix memory leak in fbtft_framebuffer_alloc
  (bnc#1151927).
- staging: bcm2835-audio: Fix draining behavior regression
  (bnc#1151927).
- staging/fbtft: Depend on OF (bnc#1151927).
- gpio: eic: sprd: Fix the incorrect EIC offset when toggling
  (bnc#1151927).
- mei: avoid FW version request on Ibex Peak and earlier
  (bnc#1151927).
- mei: me: add comet point (lake) LP device ids (bnc#1151927).
- USB: legousbtower: fix use-after-free on release (bnc#1151927).
- USB: legousbtower: fix open after failed reset request
  (bnc#1151927).
- USB: legousbtower: fix potential NULL-deref on disconnect
  (bnc#1151927).
- USB: legousbtower: fix deadlock on disconnect (bnc#1151927).
- USB: legousbtower: fix slab info leak at probe (bnc#1151927).
- usb: typec: ucsi: displayport: Fix for the mode entering routine
  (bnc#1151927).
- usb: typec: ucsi: ccg: Remove run_isr flag (bnc#1151927).
- usb: typec: tcpm: usb: typec: tcpm: Fix a signedness bug in
  tcpm_fw_get_caps() (bnc#1151927).
- usb: renesas_usbhs: gadget: Fix usb_ep_set_{halt,wedge}()
  behavior (bnc#1151927).
- usb: renesas_usbhs: gadget: Do not discard queues in
  usb_ep_set_{halt,wedge}() (bnc#1151927).
- USB: dummy-hcd: fix power budget for SuperSpeed mode
  (bnc#1151927).
- USB: microtek: fix info-leak at probe (bnc#1151927).
- USB: usblcd: fix I/O after disconnect (bnc#1151927).
- USB: serial: fix runtime PM after driver unbind (bnc#1151927).
- USB: serial: option: add support for Cinterion CLS8 devices
  (bnc#1151927).
- USB: serial: option: add Telit FN980 compositions (bnc#1151927).
- USB: serial: ftdi_sio: add device IDs for Sienna and Echelon
  PL-20 (bnc#1151927).
- USB: serial: keyspan: fix NULL-derefs on open() and write()
  (bnc#1151927).
- serial: uartps: Fix uartps_major handling (bnc#1151927).
- serial: uartlite: fix exit path null pointer (bnc#1151927).
- USB: ldusb: fix NULL-derefs on driver unbind (bnc#1151927).
- USB: chaoskey: fix use-after-free on release (bnc#1151927).
- USB: usblp: fix runtime PM after driver unbind (bnc#1151927).
- USB: iowarrior: fix use-after-free after driver unbind
  (bnc#1151927).
- USB: iowarrior: fix use-after-free on release (bnc#1151927).
- USB: iowarrior: fix use-after-free on disconnect (bnc#1151927).
- USB: adutux: fix use-after-free on release (bnc#1151927).
- USB: adutux: fix NULL-derefs on disconnect (bnc#1151927).
- USB: adutux: fix use-after-free on disconnect (bnc#1151927).
- xhci: Fix NULL pointer dereference in
  xhci_clear_tt_buffer_complete() (bnc#1151927).
- xhci: Increase STS_SAVE timeout in xhci_suspend() (bnc#1151927).
- xhci: Prevent deadlock when xhci adapter breaks during init
  (bnc#1151927).
- usb: xhci: wait for CNR controller not ready bit in xhci resume
  (bnc#1151927).
- xhci: Fix USB 3.1 capability detection on early xHCI 1.1 spec
  based hosts (bnc#1151927).
- xhci: Check all endpoints for LPM timeout (bnc#1151927).
- xhci: Prevent device initiated U1/U2 link pm if exit latency
  is too long (bnc#1151927).
- xhci: Fix false warning message about wrong bounce buffer
  write length (bnc#1151927).
- USB: usb-skeleton: fix NULL-deref on disconnect (bnc#1151927).
- USB: usb-skeleton: fix runtime PM after driver unbind
  (bnc#1151927).
- USB: yurex: fix NULL-derefs on disconnect (bnc#1151927).
- USB: yurex: Don't retry on unexpected errors (bnc#1151927).
- USB: rio500: Remove Rio 500 kernel driver (bnc#1151927).
- panic: ensure preemption is disabled during panic()
  (bnc#1151927).
- commit f52c7f6
* Thu Oct 17 2019 jslaby@suse.cz
- Revert "drm/i915/bios: make child device order the priority
  order" (bnc#1152971 fdo#112028).
- commit 3eea5a9
* Thu Oct 17 2019 acho@suse.com
- cfg80211: wext: avoid copying malformed SSIDs (bsc#1153158
  CVE-2019-17133).
- commit fd3ccf8
* Wed Oct 16 2019 mkubecek@suse.cz
- Update patches.suse/supported-flag references (add bsc#974406).
- commit df31cdf
* Wed Oct 16 2019 lpechacek@suse.com
- Squash module-Inform-user-when-loading-externally-supported.patch from
  SLE into supported-flag (bsc#974406).
- commit 3fd4e95
* Tue Oct 15 2019 jslaby@suse.cz
- Update
  patches.kernel.org/5.3.4-063-sched-core-Fix-CPU-controller-for-RT_GROUP_SCHE.patch
  (bnc#1151927 bnc#1135646).
  Add a bnc ref.
- commit d6c109d
* Tue Oct 15 2019 jslaby@suse.cz
- Update config files.
  Disable CONFIG_RT_GROUP_SCHED again (bnc#950955 bnc#1153228).
- commit a55f3f6
* Tue Oct 15 2019 jslaby@suse.cz
- Update config files.
  Just refresh (RTC_DRV_BD70528 dismissed).
- commit 418ca4c
* Tue Oct 15 2019 jslaby@suse.cz
- Update config files.
  Disable CONFIG_RT_GROUP_SCHED again (bnc#950955 bnc#1153228).
- commit 53769fe
* Mon Oct 14 2019 mkubecek@suse.cz
- Update to 5.4-rc3
- Refresh configs
- commit 2309d7d
* Sun Oct 13 2019 jslaby@suse.cz
- Linux 5.3.6 (bnc#1151927).
- libnvdimm: prevent nvdimm from requesting key when security
  is disabled (bnc#1151927).
- staging: erofs: detect potential multiref due to corrupted
  images (bnc#1151927).
- staging: erofs: avoid endless loop of invalid lookback distance
  0 (bnc#1151927).
- staging: erofs: add two missing erofs_workgroup_put for
  corrupted images (bnc#1151927).
- staging: erofs: some compressed cluster should be submitted
  for corrupted images (bnc#1151927).
- staging: erofs: fix an error handling in erofs_readdir()
  (bnc#1151927).
- coresight: etm4x: Use explicit barriers on enable/disable
  (bnc#1151927).
- vfs: Fix EOVERFLOW testing in put_compat_statfs64 (bnc#1151927).
- riscv: Avoid interrupts being erroneously enabled in
  handle_exception() (bnc#1151927).
- perf stat: Reset previous counts on repeat with interval
  (bnc#1151927).
- tick: broadcast-hrtimer: Fix a race in bc_set_next
  (bnc#1151927).
- KVM: nVMX: Fix consistency check on injected exception error
  code (bnc#1151927).
- Btrfs: fix selftests failure due to uninitialized i_mode in
  test inodes (bnc#1151927).
- drm/radeon: Bail earlier when radeon.cik_/si_support=0 is passed
  (bnc#1151927).
- nfp: abm: fix memory leak in nfp_abm_u32_knode_replace
  (bnc#1151927).
- mlxsw: spectrum_flower: Fail in case user specifies multiple
  mirror actions (bnc#1151927).
- perf unwind: Fix libunwind build failure on i386 systems
  (bnc#1151927).
- i2c: qcom-geni: Disable DMA processing on the Lenovo Yoga C630
  (bnc#1151927).
- net: dsa: microchip: Always set regmap stride to 1
  (bnc#1151927).
- bpf: Fix bpf_event_output re-entry issue (bnc#1151927).
- blk-mq: move lockdep_assert_held() into elevator_exit
  (bnc#1151927).
- libbpf: fix false uninitialized variable warning (bnc#1151927).
- kernel/elfcore.c: include proper prototypes (bnc#1151927).
- selftests/bpf: adjust strobemeta loop to satisfy latest clang
  (bnc#1151927).
- include/trace/events/writeback.h: fix -Wstringop-truncation
  warnings (bnc#1151927).
- perf build: Add detection of java-11-openjdk-devel package
  (bnc#1151927).
- sched/core: Fix migration to invalid CPU in
  __set_cpus_allowed_ptr() (bnc#1151927).
- sched/membarrier: Fix private expedited registration check
  (bnc#1151927).
- sched/membarrier: Call sync_core only before usermode for same
  mm (bnc#1151927).
- libnvdimm/nfit_test: Fix acpi_handle redefinition (bnc#1151927).
- fuse: fix memleak in cuse_channel_open (bnc#1151927).
- =?UTF-8?q?libnvdimm:=20Fix=20endian=20conversion=20issues?=
  =?UTF-8?q?=C2=A0?= (bnc#1151927).
- libnvdimm/region: Initialize bad block for volatile namespaces
  (bnc#1151927).
- iommu/amd: Fix downgrading default page-sizes in alloc_pte()
  (bnc#1151927).
- thermal_hwmon: Sanitize thermal_zone type (bnc#1151927).
- thermal: Fix use-after-free when unregistering thermal zone
  device (bnc#1151927).
- ntb: point to right memory window index (bnc#1151927).
- x86/purgatory: Disable the stackleak GCC plugin for the
  purgatory (bnc#1151927).
- selftests/seccomp: fix build on older kernels (bnc#1151927).
- pwm: stm32-lp: Add check in case requested period cannot be
  achieved (bnc#1151927).
- SUNRPC: Don't try to parse incomplete RPC messages
  (bnc#1151927).
- pNFS: Ensure we do clear the return-on-close layout stateid
  on fatal errors (bnc#1151927).
- perf probe: Fix to clear tev->nargs in clear_probe_trace_event()
  (bnc#1151927).
- drm/amdgpu: Check for valid number of registers to read
  (bnc#1151927).
- drm/amdgpu: Fix KFD-related kernel oops on Hawaii (bnc#1151927).
- netfilter: nf_tables: allow lookups in dynamic sets
  (bnc#1151927).
- watchdog: aspeed: Add support for AST2600 (bnc#1151927).
- SUNRPC: RPC level errors should always set task->tk_rpc_status
  (bnc#1151927).
- ceph: reconnect connection if session hang in opening state
  (bnc#1151927).
- ceph: fetch cap_gen under spinlock in ceph_add_cap
  (bnc#1151927).
- ceph: fix directories inode i_blkbits initialization
  (bnc#1151927).
- fuse: fix request limit (bnc#1151927).
- xen/pci: reserve MCFG areas earlier (bnc#1151927).
- 9p: avoid attaching writeback_fid on mmap with type PRIVATE
  (bnc#1151927).
- 9p: Transport error uninitialized (bnc#1151927).
- xprtrdma: Send Queue size grows after a reconnect (bnc#1151927).
- xprtrdma: Toggle XPRT_CONGESTED in xprtrdma's slot methods
  (bnc#1151927).
- fs: nfs: Fix possible null-pointer dereferences in
  encode_attrs() (bnc#1151927).
- ima: fix freeing ongoing ahash_request (bnc#1151927).
- ima: always return negative code for error (bnc#1151927).
- drivers: thermal: qcom: tsens: Fix memory leak from qfprom read
  (bnc#1151927).
- cfg80211: initialize on-stack chandefs (bnc#1151927).
- cfg80211: validate SSID/MBSSID element ordering assumption
  (bnc#1151927).
- nl80211: validate beacon head (bnc#1151927).
- ieee802154: atusb: fix use-after-free at disconnect
  (bnc#1151927).
- xen/xenbus: fix self-deadlock after killing user process
  (bnc#1151927).
- xen/balloon: Set pages PageOffline() in balloon_add_region()
  (bnc#1151927).
- DTS: ARM: gta04: introduce legacy spi-cs-high to make display
  work again (bnc#1151927).
- sched: Add __ASSEMBLY__ guards around struct clone_args
  (bnc#1151927).
- libnvdimm/altmap: Track namespace boundaries in altmap
  (bnc#1151927).
- Revert "locking/pvqspinlock: Don't wait if vCPU is preempted"
  (bnc#1151927).
- mmc: sdhci: Let drivers define their DMA mask (bnc#1151927).
- mmc: sdhci-of-esdhc: set DMA snooping based on DMA coherence
  (bnc#1151927).
- mmc: sdhci: improve ADMA error reporting (bnc#1151927).
- mmc: tegra: Implement ->set_dma_mask() (bnc#1151927).
- mac80211: keep BHs disabled while calling drv_tx_wake_queue()
  (bnc#1151927).
- drm/i915: to make vgpu ppgtt notificaiton as atomic operation
  (bnc#1151927).
- drm/i915/gvt: update vgpu workload head pointer correctly
  (bnc#1151927).
- drm/amd/powerplay: change metrics update period from 1ms to
  100ms (bnc#1151927).
- drm/nouveau/kms/nv50-: Don't create MSTMs for eDP connectors
  (bnc#1151927).
- drm/msm/dsi: Fix return value check for clk_get_parent
  (bnc#1151927).
- drm/omap: fix max fclk divider for omap36xx (bnc#1151927).
- drm: mali-dp: Mark expected switch fall-through (bnc#1151927).
- drm/atomic: Take the atomic toys away from X (bnc#1151927).
- drm/atomic: Reject FLIP_ASYNC unconditionally (bnc#1151927).
- drm/i915/dp: Fix dsc bpp calculations, v5 (bnc#1151927).
- perf stat: Fix a segmentation fault when using repeat forever
  (bnc#1151927).
- perf tools: Fix segfault in cpu_cache_level__read()
  (bnc#1151927).
- watchdog: imx2_wdt: fix min() calculation in
  imx2_wdt_set_timeout (bnc#1151927).
- selftests: pidfd: Fix undefined reference to pthread_create()
  (bnc#1151927).
- selftests/tpm2: Add the missing TEST_FILES assignment
  (bnc#1151927).
- PCI: Restore Resizable BAR size bits correctly for 1MB BARs
  (bnc#1151927).
- PCI: vmd: Fix shadow offsets to reflect spec changes
  (bnc#1151927).
- PCI: hv: Avoid use of hv_pci_dev->pci_slot after freeing it
  (bnc#1151927).
- PCI: vmd: Fix config addressing when using bus offsets
  (bnc#1151927).
- timer: Read jiffies once when forwarding base clk (bnc#1151927).
- usercopy: Avoid HIGHMEM pfn warning (bnc#1151927).
- tracing: Make sure variable reference alias has correct
  var_ref_idx (bnc#1151927).
- power: supply: sbs-battery: only return health when battery
  present (bnc#1151927).
- power: supply: sbs-battery: use correct flags field
  (bnc#1151927).
- MIPS: Treat Loongson Extensions as ASEs (bnc#1151927).
- crypto: ccree - use the full crypt length value (bnc#1151927).
- crypto: ccree - account for TEE not ready to report
  (bnc#1151927).
- crypto: caam - fix concurrency issue in givencrypt descriptor
  (bnc#1151927).
- crypto: caam/qi - fix error handling in ERN handler
  (bnc#1151927).
- crypto: cavium/zip - Add missing single_release() (bnc#1151927).
- crypto: skcipher - Unmap pages after an external error
  (bnc#1151927).
- crypto: qat - Silence smp_processor_id() warning (bnc#1151927).
- tools lib traceevent: Do not free tep->cmdlines in
  add_new_comm() on failure (bnc#1151927).
- tools lib traceevent: Fix "robust" test of
  do_generate_dynamic_list_file (bnc#1151927).
- can: mcp251x: mcp251x_hw_reset(): allow more time after a reset
  (bnc#1151927).
- powerpc/mm: Fixup tlbie vs mtpidr/mtlpidr ordering issue on
  POWER9 (bnc#1151927).
- powerpc/mm: Fix an Oops in kasan_mmu_init() (bnc#1151927).
- powerpc/mm: Add a helper to select PAGE_KERNEL_RO or
  PAGE_READONLY (bnc#1151927).
- powerpc/book3s64/radix: Rename CPU_FTR_P9_TLBIE_BUG feature flag
  (bnc#1151927).
- powerpc/book3s64/mm: Don't do tlbie fixup for some hardware
  revisions (bnc#1151927).
- powerpc/kasan: Fix shadow area set up for modules (bnc#1151927).
- powerpc/kasan: Fix parallel loading of modules (bnc#1151927).
- powerpc/powernv/ioda: Fix race in TCE level allocation
  (bnc#1151927).
- powerpc/pseries: Fix cpu_hotplug_lock acquisition in
  resize_hpt() (bnc#1151927).
- powerpc/powernv: Restrict OPAL symbol map to only be readable
  by root (bnc#1151927).
- powerpc/ptdump: Fix addresses display on PPC32 (bnc#1151927).
- powerpc/32s: Fix boot failure with DEBUG_PAGEALLOC without KASAN
  (bnc#1151927).
- powerpc/603: Fix handling of the DIRTY flag (bnc#1151927).
- powerpc/mce: Schedule work from irq_work (bnc#1151927).
- powerpc/mce: Fix MCE handling for huge pages (bnc#1151927).
- powerpc/xive: Implement get_irqchip_state method for XIVE to
  fix shutdown race (bnc#1151927).
- ASoC: sgtl5000: Improve VAG power and mute control
  (bnc#1151927).
- ASoC: Define a set of DAPM pre/post-up events (bnc#1151927).
- PM / devfreq: tegra: Fix kHz to Hz conversion (bnc#1151927).
- nbd: fix max number of supported devs (bnc#1151927).
- KVM: X86: Fix userspace set invalid CR4 (bnc#1151927).
- KVM: PPC: Book3S HV: Don't lose pending doorbell request on
  migration on P9 (bnc#1151927).
- KVM: PPC: Book3S HV: Check for MMU ready on piggybacked virtual
  cores (bnc#1151927).
- KVM: PPC: Book3S HV: Fix race in re-enabling XIVE escalation
  interrupts (bnc#1151927).
- KVM: PPC: Book3S HV: Don't push XIVE context when not using
  XIVE device (bnc#1151927).
- KVM: PPC: Book3S HV: XIVE: Free escalation interrupts before
  disabling the VP (bnc#1151927).
- KVM: PPC: Book3S: Enable XIVE native capability only if OPAL
  has required functions (bnc#1151927).
- KVM: s390: fix __insn32_query() inline assembly (bnc#1151927).
- Revert "s390/dasd: Add discard support for ESE volumes"
  (bnc#1151927).
- s390/dasd: Fix error handling during online processing
  (bnc#1151927).
- s390/cio: exclude subchannels with no parent from pseudo check
  (bnc#1151927).
- s390/cio: avoid calling strlen on null pointer (bnc#1151927).
- s390/topology: avoid firing events before kobjs are created
  (bnc#1151927).
- KVM: s390: Test for bad access register and size at the start
  of S390_MEM_OP (bnc#1151927).
- s390/sclp: Fix bit checked for has_sipl (bnc#1151927).
- s390/process: avoid potential reading of freed stack
  (bnc#1151927).
- commit 519ea7b
* Tue Oct  8 2019 jslaby@suse.cz
- Linux 5.3.5 (bnc#1151927).
- vfs: set fs_context::user_ns for reconfigure (bnc#1151927).
- 9p/cache.c: Fix memory leak in v9fs_cache_session_get_cookie
  (bnc#1151927).
- KVM: hyperv: Fix Direct Synthetic timers assert an interrupt
  w/o lapic_in_kernel (bnc#1151927).
- kexec: bail out upon SIGKILL when allocating memory
  (bnc#1151927).
- NFC: fix attrs checks in netlink interface (bnc#1151927).
- dm zoned: fix invalid memory access (bnc#1151927).
- dm raid: fix updating of max_discard_sectors limit
  (bnc#1151927).
- smack: use GFP_NOFS while holding inode_smack::smk_lock
  (bnc#1151927).
- Smack: Don't ignore other bprm->unsafe flags if
  LSM_UNSAFE_PTRACE is set (bnc#1151927).
- net: sched: taprio: Avoid division by zero on invalid link speed
  (bnc#1151927).
- net: sched: cbs: Avoid division by zero when calculating the
  port rate (bnc#1151927).
- net: socionext: netsec: always grab descriptor lock
  (bnc#1151927).
- net: dsa: sja1105: Prevent leaking memory (bnc#1151927).
- net: dsa: sja1105: Ensure PTP time for rxtstamp reconstruction
  is not in the past (bnc#1151927).
- ptp_qoriq: Initialize the registers' spinlock before calling
  ptp_qoriq_settime (bnc#1151927).
- net: dsa: sja1105: Fix sleeping while atomic in
  .port_hwtstamp_set (bnc#1151927).
- xen-netfront: do not use ~0U as error return value for
  xennet_fill_frags() (bnc#1151927).
- net: dsa: sja1105: Initialize the meta_lock (bnc#1151927).
- net/rds: Fix error handling in rds_ib_add_one() (bnc#1151927).
- udp: only do GSO if # of segs > 1 (bnc#1151927).
- tcp: adjust rto_base in retransmits_timed_out() (bnc#1151927).
- net: dsa: rtl8366: Check VLAN ID and not ports (bnc#1151927).
- vsock: Fix a lockdep warning in __vsock_release() (bnc#1151927).
- udp: fix gso_segs calculations (bnc#1151927).
- tipc: fix unlimited bundling of small messages (bnc#1151927).
- sch_dsmark: fix potential NULL deref in dsmark_init()
  (bnc#1151927).
- sch_cbq: validate TCA_CBQ_WRROPT to avoid crash (bnc#1151927).
- rxrpc: Fix rxrpc_recvmsg tracepoint (bnc#1151927).
- qmi_wwan: add support for Cinterion CLS8 devices (bnc#1151927).
- nfc: fix memory leak in llcp_sock_bind() (bnc#1151927).
- net: Unpublish sk from sk_reuseport_cb before call_rcu
  (bnc#1151927).
- net: sched: taprio: Fix potential integer overflow in
  taprio_set_picos_per_byte (bnc#1151927).
- net: qlogic: Fix memory leak in ql_alloc_large_buffers
  (bnc#1151927).
- net: ipv4: avoid mixed n_redirects and rate_tokens usage
  (bnc#1151927).
- ipv6: Handle missing host route in __ipv6_ifa_notify
  (bnc#1151927).
- ipv6: drop incoming packets having a v4mapped source address
  (bnc#1151927).
- hso: fix NULL-deref on tty open (bnc#1151927).
- erspan: remove the incorrect mtu limit for erspan (bnc#1151927).
- cxgb4:Fix out-of-bounds MSI-X info array access (bnc#1151927).
- arm: use STACK_TOP when computing mmap base address
  (bnc#1151927).
- arm: properly account for stack randomization and stack guard
  gap (bnc#1151927).
- mips: properly account for stack randomization and stack guard
  gap (bnc#1151927).
- arm64: consider stack randomization for mmap base only when
  necessary (bnc#1151927).
- kmemleak: increase DEBUG_KMEMLEAK_EARLY_LOG_SIZE default to 16K
  (bnc#1151927).
- ocfs2: wait for recovering done after direct unlock request
  (bnc#1151927).
- kbuild: clean compressed initramfs image (bnc#1151927).
- mm: add dummy can_do_mlock() helper (bnc#1151927).
- crypto: hisilicon - Fix double free in sec_free_hw_sgl()
  (bnc#1151927).
- tools/power/x86/intel-speed-select: Fix high priority core
  mask over count (bnc#1151927).
- hypfs: Fix error number left in struct pointer member
  (bnc#1151927).
- pktcdvd: remove warning on attempting to register
  non-passthrough dev (bnc#1151927).
- fat: work around race with userspace's read via blockdev while
  mounting (bnc#1151927).
- block, bfq: push up injection only after setting service time
  (bnc#1151927).
- i2c: tegra: Move suspend handling to NOIRQ phase (bnc#1151927).
- ARM: 8903/1: ensure that usable memory in bank 0 starts from
  a PMD-aligned address (bnc#1151927).
- ARM: 8905/1: Emit __gnu_mcount_nc when using Clang 10.0.0 or
  newer (bnc#1151927).
- PCI: Use static const struct, not const static struct
  (bnc#1151927).
- security: smack: Fix possible null-pointer dereferences in
  smack_socket_sock_rcv_skb() (bnc#1151927).
- PCI: exynos: Propagate errors for optional PHYs (bnc#1151927).
- PCI: imx6: Propagate errors for optional regulators
  (bnc#1151927).
- PCI: histb: Propagate errors for optional regulators
  (bnc#1151927).
- PCI: rockchip: Propagate errors for optional regulators
  (bnc#1151927).
- HID: apple: Fix stuck function keys when using FN (bnc#1151927).
- PCI: Add pci_info_ratelimited() to ratelimit PCI separately
  (bnc#1151927).
- selinux: fix residual uses of current_security() for the
  SELinux blob (bnc#1151927).
- power: supply: register HWMON devices with valid names
  (bnc#1151927).
- rtc: pcf85363/pcf85263: fix regmap error in set_time
  (bnc#1151927).
- rtc: snvs: fix possible race condition (bnc#1151927).
- ARM: 8875/1: Kconfig: default to AEABI w/ Clang (bnc#1151927).
- PCI: mobiveil: Fix the CPU base address setup in inbound window
  (bnc#1151927).
- soundwire: intel: fix channel number reported by hardware
  (bnc#1151927).
- ARM: 8898/1: mm: Don't treat faults reported from cache
  maintenance as writes (bnc#1151927).
- mips/atomic: Fix smp_mb__{before,after}_atomic() (bnc#1151927).
- livepatch: Nullify obj->mod in klp_module_coming()'s error path
  (bnc#1151927).
- PCI: layerscape: Add the bar_fixed_64bit property to the
  endpoint driver (bnc#1151927).
- PCI: pci-hyperv: Fix build errors on non-SYSFS config
  (bnc#1151927).
- mips/atomic: Fix loongson_llsc_mb() wreckage (bnc#1151927).
- rtc: bd70528: fix driver dependencies (bnc#1151927).
- HID: wacom: Fix several minor compiler warnings (bnc#1151927).
- PCI: tegra: Fix OF node reference leak (bnc#1151927).
- mfd: intel-lpss: Remove D3cold delay (bnc#1151927).
- i2c-cht-wc: Fix lockdep warning (bnc#1151927).
- MIPS: tlbex: Explicitly cast _PAGE_NO_EXEC to a boolean
  (bnc#1151927).
- MIPS: Don't use bc_false uninitialized in __mm_isBranchInstr
  (bnc#1151927).
- MIPS: Ingenic: Disable broken BTB lookup optimization
  (bnc#1151927).
- ext4: fix potential use after free after remounting with
  noblock_validity (bnc#1151927).
- f2fs: fix to drop meta/node pages during umount (bnc#1151927).
- dma-buf/sw_sync: Synchronize signal vs syncpt free
  (bnc#1151927).
- scsi: core: Reduce memory required for SCSI logging
  (bnc#1151927).
- clk: sprd: add missing kfree (bnc#1151927).
- mbox: qcom: add APCS child device for QCS404 (bnc#1151927).
- powerpc: dump kernel log before carrying out fadump or kdump
  (bnc#1151927).
- clk: Make clk_bulk_get_all() return a valid "id" (bnc#1151927).
- clk: imx: clk-pll14xx: unbypass PLL by default (bnc#1151927).
- clk: imx: pll14xx: avoid glitch when set rate (bnc#1151927).
- clk: at91: select parent if main oscillator or bypass is enabled
  (bnc#1151927).
- arm64: fix unreachable code issue with cmpxchg (bnc#1151927).
- ARM: dts: dir685: Drop spi-cpol from the display (bnc#1151927).
- mailbox: mediatek: cmdq: clear the event in cmdq initial flow
  (bnc#1151927).
- pinctrl: meson-gxbb: Fix wrong pinning definition for uart_c
  (bnc#1151927).
- powerpc/pseries: correctly track irq state in default idle
  (bnc#1151927).
- clk: qcom: gcc-sdm845: Use floor ops for sdcc clks
  (bnc#1151927).
- powerpc/eeh: Clean up EEH PEs after recovery finishes
  (bnc#1151927).
- pstore: fs superblock limits (bnc#1151927).
- powerpc/64s/exception: machine check use correct cfar for late
  handler (bnc#1151927).
- drm/amdgpu/si: fix ASIC tests (bnc#1151927).
- kbuild: Do not enable -Wimplicit-fallthrough for clang for now
  (bnc#1151927).
- selftests/powerpc: Retry on host facility unavailable
  (bnc#1151927).
- drm/amd/display: fix trigger not generated for freesync
  (bnc#1151927).
- drm/amd/display: fix MPO HUBP underflow with Scatter Gather
  (bnc#1151927).
- drm/amd/powerpaly: fix navi series custom peak level value error
  (bnc#1151927).
- drm/amd/display: support spdif (bnc#1151927).
- clk: renesas: cpg-mssr: Set GENPD_FLAG_ALWAYS_ON for clock
  domain (bnc#1151927).
- clk: renesas: mstp: Set GENPD_FLAG_ALWAYS_ON for clock domain
  (bnc#1151927).
- pinctrl: amd: disable spurious-firing GPIO IRQs (bnc#1151927).
- drm/nouveau/volt: Fix for some cards having 0 maximum voltage
  (bnc#1151927).
- drm/nouveau/kms/tu102-: disable input lut when input is already
  FP16 (bnc#1151927).
- drm/amdgpu/sdma5: fix number of sdma5 trap irq types for navi1x
  (bnc#1151927).
- vfio_pci: Restore original state on release (bnc#1151927).
- powerpc/eeh: Clear stale EEH_DEV_NO_HANDLER flag (bnc#1151927).
- pinctrl: tegra: Fix write barrier placement in pmx_writel
  (bnc#1151927).
- powerpc/perf: fix imc allocation failure handling (bnc#1151927).
- powerpc/pseries/mobility: use cond_resched when updating device
  tree (bnc#1151927).
- powerpc/64s/radix: Fix memory hotplug section page table
  creation (bnc#1151927).
- powerpc/futex: Fix warning: 'oldval' may be used uninitialized
  in this function (bnc#1151927).
- powerpc/ptdump: fix walk_pagetables() address mismatch
  (bnc#1151927).
- powerpc/rtas: use device model APIs and serialization during
  LPM (bnc#1151927).
- powerpc/xmon: Check for HV mode when dumping XIVE info from OPAL
  (bnc#1151927).
- clk: sunxi: Don't call clk_hw_get_name() on a hw that isn't
  registered (bnc#1151927).
- clk: zx296718: Don't reference clk_init_data after registration
  (bnc#1151927).
- clk: sprd: Don't reference clk_init_data after registration
  (bnc#1151927).
- clk: meson: axg-audio: Don't reference clk_init_data after
  registration (bnc#1151927).
- clk: sirf: Don't reference clk_init_data after registration
  (bnc#1151927).
- clk: actions: Don't reference clk_init_data after registration
  (bnc#1151927).
- powerpc/powernv/ioda2: Allocate TCE table levels on demand
  for default DMA window (bnc#1151927).
- drm/amd/display: Register VUPDATE_NO_LOCK interrupts for DCN2
  (bnc#1151927).
- drm/amd/display: reprogram VM config when system resume
  (bnc#1151927).
- drm/amd/display: Fix frames_to_insert math (bnc#1151927).
- drm/amd/display: fix issue where 252-255 values are clipped
  (bnc#1151927).
- clk: sunxi-ng: v3s: add missing clock slices for MMC2 module
  clocks (bnc#1151927).
- clk: ingenic/jz4740: Fix "pll half" divider not read/written
  properly (bnc#1151927).
- clk: qoriq: Fix -Wunused-const-variable (bnc#1151927).
- ipmi_si: Only schedule continuously in the thread in maintenance
  mode (bnc#1151927).
- pinctrl: stmfx: update pinconf settings (bnc#1151927).
- PCI: rpaphp: Avoid a sometimes-uninitialized warning
  (bnc#1151927).
- clk: imx8mq: Mark AHB clock as critical (bnc#1151927).
- gpu: drm: radeon: Fix a possible null-pointer dereference in
  radeon_connector_set_property() (bnc#1151927).
- drm/radeon: Fix EEH during kexec (bnc#1151927).
- drm/amd/display: Use proper enum conversion functions
  (bnc#1151927).
- drm/amdgpu: Fix hard hang for S/G display BOs (bnc#1151927).
- drm/rockchip: Check for fast link training before enabling psr
  (bnc#1151927).
- drm/panel: check failure cases in the probe func (bnc#1151927).
- drm/bridge: sii902x: fix missing reference to mclk clock
  (bnc#1151927).
- drm/stm: attach gem fence to atomic state (bnc#1151927).
- drm/tinydrm/Kconfig: drivers: Select BACKLIGHT_CLASS_DEVICE
  (bnc#1151927).
- video: ssd1307fb: Start page range at page_offset (bnc#1151927).
- drm/amd/display: Copy GSL groups when committing a new context
  (bnc#1151927).
- drm/amd/display: Clear FEC_READY shadow register if DPCD write
  fails (bnc#1151927).
- drm/amd/display: fix not calling ppsmu to trigger PME
  (bnc#1151927).
- drm/amd/display: Power-gate all DSCs at driver init time
  (bnc#1151927).
- drm/amd/display: add monitor patch to add T7 delay
  (bnc#1151927).
- drm/panel: simple: fix AUO g185han01 horizontal blanking
  (bnc#1151927).
- drm/vkms: Avoid assigning 0 for possible_crtc (bnc#1151927).
- drm/bridge: tc358767: Increase AUX transfer length limit
  (bnc#1151927).
- drm/mcde: Fix uninitialized variable (bnc#1151927).
- drm/vkms: Fix crc worker races (bnc#1151927).
- commit 1838763
* Mon Oct  7 2019 mbrugger@suse.com
- arm64: Update config files.
- commit 4f2941c
* Mon Oct  7 2019 mbrugger@suse.com
- mm: refresh ZONE_DMA and ZONE_DMA32 comments in 'enum zone_type'
  (jsc#SLE-7772).
- arm64: use both ZONE_DMA and ZONE_DMA32 (jsc#SLE-7772).
- arm64: rename variables used to calculate ZONE_DMA32's size
  (jsc#SLE-7772).
- arm64: mm: use arm64_dma_phys_limit instead of calling
  max_zone_dma_phys() (jsc#SLE-7772).
- mmc: sdhci-iproc: fix spurious interrupts on Multiblock reads
  with bcm2711 (jsc#SLE-7772).
- MAINTAINERS: Add BCM2711 to BCM2835 ARCH (jsc#SLE-7772).
- arm64: dts: broadcom: Add reference to RPi 4 B (jsc#SLE-7772).
- ARM: dts: Add minimal Raspberry Pi 4 support (jsc#SLE-7772).
- ARM: bcm: Add support for BCM2711 SoC (jsc#SLE-7772).
- dt-bindings: arm: bcm2835: Add Raspberry Pi 4 to DT schema
  (jsc#SLE-7772).
- dt-bindings: arm: Convert BCM2835 board/soc bindings to
  json-schema (jsc#SLE-7772).
- ARM: dts: bcm283x: Move BCM2835/6/7 specific to
  bcm2835-common.dtsi (jsc#SLE-7772).
- ARM: dts: bcm283x: Remove brcm, bcm2835-pl011 compatible
  (jsc#SLE-7772).
- ARM: dts: bcm283x: Remove simple-bus from fixed clocks
  (jsc#SLE-7772).
- bluetooth: hci_bcm: Fix RTS handling during startup
  (jsc#SLE-7772).
- clk: bcm2835: Mark PLLD_PER as CRITICAL (jsc#SLE-7772).
- clk: bcm2835: Add BCM2711_CLOCK_EMMC2 support (jsc#SLE-7772).
- clk: bcm2835: Introduce SoC specific clock registration
  (jsc#SLE-7772).
- dt-bindings: bcm2835-cprman: Add bcm2711 support (jsc#SLE-7772).
- mmc: bcm2835: Take SWIOTLB memory size limitation into account
  (jsc#SLE-7772).
- mmc: sdhci-iproc: Add support for emmc2 of the BCM2711
  (jsc#SLE-7772).
- dt-bindings: mmc: sdhci-iproc: Add brcm,bcm2711-emmc2
  (jsc#SLE-7772).
- i2c: bcm2835: Add full name of devicetree node to adapter name
  (jsc#SLE-7772).
- i2c: bcm2835: Avoid clk stretch quirk for BCM2711
  (jsc#SLE-7772).
- dt-bindings: i2c: bcm2835: Add brcm,bcm2711 compatible
  (jsc#SLE-7772).
- ARM: dts: bcm283x: Enable HDMI at board level (jsc#SLE-7772).
- ARM: dts: bcm283x: Define memory at board level (jsc#SLE-7772).
- ARM: dts: bcm283x: Define MMC interfaces at board level
  (jsc#SLE-7772).
- pinctrl: bcm2835: Add support for BCM2711 pull-up functionality
  (jsc#SLE-7772).
- pinctrl: bcm2835: Add brcm,bcm2711 compatible (jsc#SLE-7772).
- ARM: bcm283x: Reduce register ranges for UART, SPI and I2C
  (jsc#SLE-7772).
- commit be4f5e9
* Mon Oct  7 2019 mkubecek@suse.cz
- Update to 5.4-rc2
- Eliminated 2 patches
- Refresh config/i386/default
- commit 5b664b4
* Mon Oct  7 2019 mkubecek@suse.cz
- Delete
  patches.suse/module-swap-the-order-of-symbol.namespace.patch.
  This is not the patch fixing bogus modpost warnings when building
  out-of-tree modules. The patch supposed to fix them, when applied on its
  own, makes modpost segfault. So let's better live with the warnings until
  this is sorted in upstream.
- commit 5bf1873
* Sun Oct  6 2019 mkubecek@suse.cz
- module: swap the order of symbol.namespace.
  Fixes bogus modpost warnings when building out-of-tree modules.
- commit c3db450
* Sun Oct  6 2019 jslaby@suse.cz
- Linux 5.3.4 (bnc#1151927).
- arcnet: provide a buffer big enough to actually receive packets
  (bnc#1151927).
- cdc_ncm: fix divide-by-zero caused by invalid wMaxPacketSize
  (bnc#1151927).
- ipv6: do not free rt if FIB_LOOKUP_NOREF is set on suppress rule
  (bnc#1151927).
- macsec: drop skb sk before calling gro_cells_receive
  (bnc#1151927).
- net/phy: fix DP83865 10 Mbps HDX loopback disable function
  (bnc#1151927).
- net: qrtr: Stop rx_worker before freeing node (bnc#1151927).
- net/sched: act_sample: don't push mac header on ip6gre ingress
  (bnc#1151927).
- net_sched: add max len check for TCA_KIND (bnc#1151927).
- net: stmmac: Fix page pool size (bnc#1151927).
- nfp: flower: fix memory leak in nfp_flower_spawn_vnic_reprs
  (bnc#1151927).
- nfp: flower: prevent memory leak in nfp_flower_spawn_phy_reprs
  (bnc#1151927).
- openvswitch: change type of UPCALL_PID attribute to NLA_UNSPEC
  (bnc#1151927).
- ppp: Fix memory leak in ppp_write (bnc#1151927).
- sch_netem: fix a divide by zero in tabledist() (bnc#1151927).
- selftests: Update fib_tests to handle missing ping6
  (bnc#1151927).
- skge: fix checksum byte order (bnc#1151927).
- tcp_bbr: fix quantization code to not raise cwnd if not probing
  bandwidth (bnc#1151927).
- usbnet: ignore endpoints with invalid wMaxPacketSize
  (bnc#1151927).
- usbnet: sanity checking of packet sizes and device mtu
  (bnc#1151927).
- net/rds: Check laddr_check before calling it (bnc#1151927).
- net/mlx5e: Fix matching on tunnel addresses type (bnc#1151927).
- ipv6: fix a typo in fib6_rule_lookup() (bnc#1151927).
- selftests: Update fib_nexthop_multiprefix to handle missing
  ping6 (bnc#1151927).
- net: phy: micrel: add Asym Pause workaround for KSZ9021
  (bnc#1151927).
- net/sched: cbs: Fix not adding cbs instance to list
  (bnc#1151927).
- ipv4: Revert removal of rt_uses_gateway (bnc#1151927).
- net_sched: add policy validation for action attributes
  (bnc#1151927).
- vrf: Do not attempt to create IPv6 mcast rule if IPv6 is
  disabled (bnc#1151927).
- net/mlx5e: Fix traffic duplication in ethtool steering
  (bnc#1151927).
- net: sched: fix possible crash in tcf_action_destroy()
  (bnc#1151927).
- tcp: better handle TCP_USER_TIMEOUT in SYN_SENT state
  (bnc#1151927).
- net/mlx5: Add device ID of upcoming BlueField-2 (bnc#1151927).
- mISDN: enforce CAP_NET_RAW for raw sockets (bnc#1151927).
- appletalk: enforce CAP_NET_RAW for raw sockets (bnc#1151927).
- ax25: enforce CAP_NET_RAW for raw sockets (bnc#1151927).
- ieee802154: enforce CAP_NET_RAW for raw sockets (bnc#1151927).
- nfc: enforce CAP_NET_RAW for raw sockets (bnc#1151927).
- ALSA: hda: Flush interrupts on disabling (bnc#1151927).
- ASoC: SOF: Intel: hda: Make hdac_device device-managed
  (bnc#1151927).
- cpufreq: ap806: Add NULL check after kcalloc (bnc#1151927).
- ALSA: hda/hdmi - Don't report spurious jack state changes
  (bnc#1151927).
- regulator: lm363x: Fix off-by-one n_voltages for lm3632
  ldo_vpos/ldo_vneg (bnc#1151927).
- regulator: lm363x: Fix n_voltages setting for lm36274
  (bnc#1151927).
- spi: dw-mmio: Clock should be shut when error occurs
  (bnc#1151927).
- ASoC: tlv320aic31xx: suppress error message for EPROBE_DEFER
  (bnc#1151927).
- ASoC: sgtl5000: Fix of unmute outputs on probe (bnc#1151927).
- ASoC: sgtl5000: Fix charge pump source assignment (bnc#1151927).
- firmware: qcom_scm: Use proper types for dma mappings
  (bnc#1151927).
- dmaengine: bcm2835: Print error in case setting DMA mask fails
  (bnc#1151927).
- leds: leds-lp5562 allow firmware files up to the maximum length
  (bnc#1151927).
- ASoC: SOF: reset DMA state in prepare (bnc#1151927).
- media: dib0700: fix link error for dibx000_i2c_set_speed
  (bnc#1151927).
- media: mtk-cir: lower de-glitch counter for rc-mm protocol
  (bnc#1151927).
- ASoC: SOF: pci: mark last_busy value at runtime PM init
  (bnc#1151927).
- media: exynos4-is: fix leaked of_node references (bnc#1151927).
- media: vivid:add sanity check to avoid divide error and set
  value to 1 if 0 (bnc#1151927).
- media: vb2: reorder checks in vb2_poll() (bnc#1151927).
- media: vivid: work around high stack usage with clang
  (bnc#1151927).
- media: hdpvr: Add device num check and handling (bnc#1151927).
- media: i2c: ov5640: Check for devm_gpiod_get_optional() error
  (bnc#1151927).
- time/tick-broadcast: Fix tick_broadcast_offline() lockdep
  complaint (bnc#1151927).
- sched/fair: Fix imbalance due to CPU affinity (bnc#1151927).
- sched/core: Fix CPU controller for !RT_GROUP_SCHED
  (bnc#1151927).
- x86/apic: Make apic_pending_intr_clear() more robust
  (bnc#1151927).
- sched/deadline: Fix bandwidth accounting at all levels after
  offline migration (bnc#1151927).
- x86/reboot: Always use NMI fallback when shutdown via reboot
  vector IPI fails (bnc#1151927).
- rcu/tree: Call setschedule() gp ktread to SCHED_FIFO outside
  of atomic region (bnc#1151927).
- x86/apic: Soft disable APIC before initializing it
  (bnc#1151927).
- ALSA: hda - Show the fatal CORB/RIRB error more clearly
  (bnc#1151927).
- ALSA: i2c: ak4xxx-adda: Fix a possible null pointer dereference
  in build_adc_controls() (bnc#1151927).
- rcu: Add destroy_work_on_stack() to match INIT_WORK_ONSTACK()
  (bnc#1151927).
- EDAC/mc: Fix grain_bits calculation (bnc#1151927).
- arm64: dts: imx8mq: Correct OPP table according to latest
  datasheet (bnc#1151927).
- media: iguanair: add sanity checks (bnc#1151927).
- cpuidle: teo: Allow tick to be stopped if PM QoS is used
  (bnc#1151927).
- gpio: madera: Add support for Cirrus Logic CS47L15
  (bnc#1151927).
- gpio: madera: Add support for Cirrus Logic CS47L92
  (bnc#1151927).
- arm64: mm: free the initrd reserved memblock in a aligned manner
  (bnc#1151927).
- soc: amlogic: meson-clk-measure: protect measure with a mutex
  (bnc#1151927).
- base: soc: Export soc_device_register/unregister APIs
  (bnc#1151927).
- ALSA: usb-audio: Skip bSynchAddress endpoint check if it is
  invalid (bnc#1151927).
- ia64:unwind: fix double free for mod->arch.init_unw_table
  (bnc#1151927).
- EDAC/altera: Use the proper type for the IRQ status bits
  (bnc#1151927).
- ASoC: rsnd: don't call clk_get_rate() under atomic context
  (bnc#1151927).
- arm64/prefetch: fix a -Wtype-limits warning (bnc#1151927).
- md/raid1: end bio when the device faulty (bnc#1151927).
- md: don't call spare_active in md_reap_sync_thread if all
  member devices can't work (bnc#1151927).
- md: don't set In_sync if array is frozen (bnc#1151927).
- media: media/platform: fsl-viu.c: fix build for MICROBLAZE
  (bnc#1151927).
- media: staging: tegra-vde: Fix build error (bnc#1151927).
- RAS: Build debugfs.o only when enabled in Kconfig (bnc#1151927).
- ASoC: hdac_hda: fix page fault issue by removing race
  (bnc#1151927).
- ACPI / processor: don't print errors for processorIDs == 0xff
  (bnc#1151927).
- loop: Add LOOP_SET_DIRECT_IO to compat ioctl (bnc#1151927).
- perf tools: Fix paths in include statements (bnc#1151927).
- EDAC, pnd2: Fix ioremap() size in dnv_rd_reg() (bnc#1151927).
- efi: cper: print AER info of PCIe fatal error (bnc#1151927).
- firmware: arm_scmi: Check if platform has released shmem before
  using (bnc#1151927).
- sched/fair: Use rq_lock/unlock in online_fair_sched_group
  (bnc#1151927).
- idle: Prevent late-arriving interrupts from disrupting offline
  (bnc#1151927).
- blk-mq: Fix memory leak in blk_mq_init_allocated_queue error
  handling (bnc#1151927).
- media: gspca: zero usb_buf on error (bnc#1151927).
- perf config: Honour $PERF_CONFIG env var to specify alternate
  .perfconfig (bnc#1151927).
- perf test vfs_getname: Disable ~/.perfconfig to get default
  output (bnc#1151927).
- media: mtk-mdp: fix reference count on old device tree
  (bnc#1151927).
- media: i2c: tda1997x: prevent potential NULL pointer access
  (bnc#1151927).
- media: fdp1: Reduce FCP not found message level to debug
  (bnc#1151927).
- media: em28xx: modules workqueue not inited for 2nd device
  (bnc#1151927).
- arm64/efi: Move variable assignments after SECTIONS
  (bnc#1151927).
- perf unwind: Fix libunwind when tid != pid (bnc#1151927).
- media: rc: imon: Allow iMON RC protocol for ffdc 7e device
  (bnc#1151927).
- dmaengine: iop-adma: use correct printk format strings
  (bnc#1151927).
- ARM: xscale: fix multi-cpu compilation (bnc#1151927).
- perf record: Support aarch64 random socket_id assignment
  (bnc#1151927).
- media: vsp1: fix memory leak of dl on error return path
  (bnc#1151927).
- media: i2c: ov5645: Fix power sequence (bnc#1151927).
- media: omap3isp: Don't set streaming state on random subdevs
  (bnc#1151927).
- media: imx: mipi csi-2: Don't fail if initial state times-out
  (bnc#1151927).
- kasan/arm64: fix CONFIG_KASAN_SW_TAGS && KASAN_INLINE
  (bnc#1151927).
- net: lpc-enet: fix printk format strings (bnc#1151927).
- m68k: Prevent some compiler warnings in Coldfire builds
  (bnc#1151927).
- ARM: dts: imx7d: cl-som-imx7: make ethernet work again
  (bnc#1151927).
- arm64: dts: qcom: qcs404-evb: Mark WCSS clocks protected
  (bnc#1151927).
- ARM: dts: imx7-colibri: disable HS400 (bnc#1151927).
- x86/platform/intel/iosf_mbi Rewrite locking (bnc#1151927).
- media: radio/si470x: kill urb on error (bnc#1151927).
- media: hdpvr: add terminating 0 at end of string (bnc#1151927).
- ASoC: uniphier: Fix double reset assersion when transitioning
  to suspend state (bnc#1151927).
- powerpc/Makefile: Always pass --synthetic to nm if supported
  (bnc#1151927).
- tools headers: Fixup bitsperlong per arch includes
  (bnc#1151927).
- ASoC: sun4i-i2s: Don't use the oversample to calculate BCLK
  (bnc#1151927).
- ASoC: mchp-i2s-mcc: Wait for RX/TX RDY only if controller is
  running (bnc#1151927).
- led: triggers: Fix a memory leak bug (bnc#1151927).
- ASoC: mchp-i2s-mcc: Fix unprepare of GCLK (bnc#1151927).
- nbd: add missing config put (bnc#1151927).
- ACPI / APEI: Release resources if gen_pool_add() fails
  (bnc#1151927).
- arm64: entry: Move ct_user_exit before any other exception
  (bnc#1151927).
- s390/kasan: provide uninstrumented __strlen (bnc#1151927).
- media: mceusb: fix (eliminate) TX IR signal length limit
  (bnc#1151927).
- media: dvb-frontends: use ida for pll number (bnc#1151927).
- posix-cpu-timers: Sanitize bogus WARNONS (bnc#1151927).
- media: dvb-core: fix a memory leak bug (bnc#1151927).
- EDAC/amd64: Support more than two controllers for chip selects
  handling (bnc#1151927).
- cpufreq: imx-cpufreq-dt: Add i.MX8MN support (bnc#1151927).
- libperf: Fix alignment trap with xyarray contents in 'perf stat'
  (bnc#1151927).
- EDAC/amd64: Recognize DRAM device type ECC capability
  (bnc#1151927).
- EDAC/amd64: Decode syndrome before translating address
  (bnc#1151927).
- ARM: at91: move platform-specific asm-offset.h to
  arch/arm/mach-at91 (bnc#1151927).
- soc: renesas: rmobile-sysc: Set GENPD_FLAG_ALWAYS_ON for
  always-on domain (bnc#1151927).
- soc: renesas: Enable ARM_ERRATA_754322 for affected Cortex-A9
  (bnc#1151927).
- PM / devfreq: Fix kernel oops on governor module load
  (bnc#1151927).
- ARM: OMAP2+: move platform-specific asm-offset.h to
  arch/arm/mach-omap2 (bnc#1151927).
- PM / devfreq: passive: Use non-devm notifiers (bnc#1151927).
- PM / devfreq: exynos-bus: Correct clock enable sequence
  (bnc#1151927).
- media: cec-notifier: clear cec_adap in cec_notifier_unregister
  (bnc#1151927).
- media: saa7146: add cleanup in hexium_attach() (bnc#1151927).
- media: cpia2_usb: fix memory leaks (bnc#1151927).
- media: saa7134: fix terminology around
  saa7134_i2c_eeprom_md7134_gate() (bnc#1151927).
- perf trace beauty ioctl: Fix off-by-one error in cmd->string
  table (bnc#1151927).
- perf report: Fix --ns time sort key output (bnc#1151927).
- perf script: Fix memory leaks in list_scripts() (bnc#1151927).
- media: aspeed-video: address a protential usage of an
  unitialized var (bnc#1151927).
- media: ov9650: add a sanity check (bnc#1151927).
- leds: lm3532: Fixes for the driver for stability (bnc#1151927).
- ASoC: es8316: fix headphone mixer volume table (bnc#1151927).
- ACPI / CPPC: do not require the _PSD method (bnc#1151927).
- sched/cpufreq: Align trace event behavior of fast switching
  (bnc#1151927).
- arm64: dts: meson: fix boards regulators states format
  (bnc#1151927).
- x86/apic/vector: Warn when vector space exhaustion breaks
  affinity (bnc#1151927).
- arm64: kpti: ensure patched kernel text is fetched from PoU
  (bnc#1151927).
- perf evlist: Use unshare(CLONE_FS) in sb threads to let
  setns(CLONE_NEWNS) work (bnc#1151927).
- arm64: Use correct ll/sc atomic constraints (bnc#1151927).
- jump_label: Don't warn on __exit jump entries (bnc#1151927).
- x86/mm/pti: Do not invoke PTI functions when PTI is disabled
  (bnc#1151927).
- ASoC: fsl_ssi: Fix clock control issue in master mode
  (bnc#1151927).
- x86/mm/pti: Handle unaligned address gracefully in
  pti_clone_pagetable() (bnc#1151927).
- nvmet: fix data units read and written counters in SMART log
  (bnc#1151927).
- nvme-multipath: fix ana log nsid lookup when nsid is not found
  (bnc#1151927).
- ALSA: firewire-motu: add support for MOTU 4pre (bnc#1151927).
- iommu/amd: Silence warnings under memory pressure (bnc#1151927).
- ASoC: Intel: Haswell: Adjust machine device private context
  (bnc#1151927).
- libata/ahci: Drop PCS quirk for Denverton and beyond
  (bnc#1151927).
- iommu/iova: Avoid false sharing on fq_timer_on (bnc#1151927).
- libtraceevent: Change users plugin directory (bnc#1151927).
- ASoC: dt-bindings: sun4i-spdif: Fix dma-names warning
  (bnc#1151927).
- ARM: dts: exynos: Mark LDO10 as always-on on Peach Pit/Pi
  Chromebooks (bnc#1151927).
- x86/amd_nb: Add PCI device IDs for family 17h, model 70h
  (bnc#1151927).
- ACPI: custom_method: fix memory leaks (bnc#1151927).
- ACPI / PCI: fix acpi_pci_irq_enable() memory leak (bnc#1151927).
- closures: fix a race on wakeup from closure_sync (bnc#1151927).
- hwmon: (k10temp) Add support for AMD family 17h, model 70h CPUs
  (bnc#1151927).
- hwmon: (acpi_power_meter) Change log level for 'unsafe software
  power cap' (bnc#1151927).
- md/raid1: fail run raid1 array when active disk less than one
  (bnc#1151927).
- dmaengine: ti: edma: Do not reset reserved paRAM slots
  (bnc#1151927).
- kprobes: Prohibit probing on BUG() and WARN() address
  (bnc#1151927).
- x86/mm: Fix cpumask_of_node() error condition (bnc#1151927).
- irqchip/sifive-plic: set max threshold for ignored handlers
  (bnc#1151927).
- s390/crypto: xts-aes-s390 fix extra run-time crypto self tests
  finding (bnc#1151927).
- irqchip/gic-v3-its: Fix LPI release for Multi-MSI devices
  (bnc#1151927).
- x86/cpu: Add Tiger Lake to Intel family (bnc#1151927).
- platform/x86: intel_pmc_core: Do not ioremap RAM (bnc#1151927).
- platform/x86: intel_pmc_core_pltdrv: Module removal warning fix
  (bnc#1151927).
- ASoC: dmaengine: Make the pcm->name equal to pcm->id if the
  name is not set (bnc#1151927).
- tools/power/x86/intel-speed-select: Fix memory leak
  (bnc#1151927).
- spi: bcm2835: Work around DONE bit erratum (bnc#1151927).
- io_uring: fix wrong sequence setting logic (bnc#1151927).
- block: make rq sector size accessible for block stats
  (bnc#1151927).
- raid5: don't set STRIPE_HANDLE to stripe which is in batch list
  (bnc#1151927).
- mmc: core: Clarify sdio_irq_pending flag for
  MMC_CAP2_SDIO_IRQ_NOTHREAD (bnc#1151927).
- sched/psi: Correct overly pessimistic size calculation
  (bnc#1151927).
- mmc: sdhci: Fix incorrect switch to HS mode (bnc#1151927).
- mmc: core: Add helper function to indicate if SDIO IRQs is
  enabled (bnc#1151927).
- mmc: dw_mmc: Re-store SDIO IRQs mask at system resume
  (bnc#1151927).
- raid5: don't increment read_errors on EILSEQ return
  (bnc#1151927).
- mmc: mtk-sd: Re-store SDIO IRQs mask at system resume
  (bnc#1151927).
- libertas: Add missing sentinel at end of if_usb.c fw_table
  (bnc#1151927).
- e1000e: add workaround for possible stalled packet
  (bnc#1151927).
- ALSA: hda - Add a quirk model for fixing Huawei Matebook X
  right speaker (bnc#1151927).
- ALSA: hda - Drop unsol event handler for Intel HDMI codecs
  (bnc#1151927).
- drm/amd/powerplay/smu7: enforce minimal VBITimeout (v2)
  (bnc#1151927).
- media: ttusb-dec: Fix info-leak in ttusb_dec_send_command()
  (bnc#1151927).
- drm: fix module name in edid_firmware log message (bnc#1151927).
- ALSA: hda/realtek - Blacklist PC beep for Lenovo ThinkCentre
  M73/93 (bnc#1151927).
- iommu/amd: Override wrong IVRS IOAPIC on Raven Ridge systems
  (bnc#1151927).
- zd1211rw: remove false assertion from zd_mac_clear()
  (bnc#1151927).
- btrfs: delayed-inode: Kill the BUG_ON() in
  btrfs_delete_delayed_dir_index() (bnc#1151927).
- btrfs: extent-tree: Make sure we only allocate extents from
  block groups with the same type (bnc#1151927).
- btrfs: tree-checker: Add ROOT_ITEM check (bnc#1151927).
- btrfs: Detect unbalanced tree with empty leaf before crashing
  btree operations (bnc#1151927).
- kvm: Nested KVM MMUs need PAE root too (bnc#1151927).
- media: omap3isp: Set device on omap3isp subdevs (bnc#1151927).
- PM / devfreq: passive: fix compiler warning (bnc#1151927).
- ARM: dts: logicpd-torpedo-baseboard: Fix missing video
  (bnc#1151927).
- ARM: omap2plus_defconfig: Fix missing video (bnc#1151927).
- ALSA: firewire-tascam: handle error code when getting current
  source of clock (bnc#1151927).
- ALSA: firewire-tascam: check intermediate state of clock status
  and retry (bnc#1151927).
- scsi: scsi_dh_rdac: zero cdb in send_mode_select()
  (bnc#1151927).
- scsi: qla2xxx: Fix Relogin to prevent modifying scan_state flag
  (bnc#1151927).
- printk: Do not lose last line in kmsg buffer dump (bnc#1151927).
- IB/mlx5: Free mpi in mp_slave mode (bnc#1151927).
- IB/hfi1: Define variables as unsigned long to fix KASAN warning
  (bnc#1151927).
- IB/hfi1: Do not update hcrc for a KDETH packet during fault
  injection (bnc#1151927).
- RDMA: Fix double-free in srq creation error flow (bnc#1151927).
- randstruct: Check member structs in is_pure_ops_struct()
  (bnc#1151927).
- ARM: dts: am3517-evm: Fix missing video (bnc#1151927).
- rcu/tree: Fix SCHED_FIFO params (bnc#1151927).
- ALSA: hda/realtek - PCI quirk for Medion E4254 (bnc#1151927).
- blk-mq: add callback of .cleanup_rq (bnc#1151927).
- scsi: implement .cleanup_rq callback (bnc#1151927).
- powerpc/imc: Dont create debugfs files for cpu-less nodes
  (bnc#1151927).
- tpm_tis_core: Turn on the TPM before probing IRQ's
  (bnc#1151927).
- tpm_tis_core: Set TPM_CHIP_FLAG_IRQ before probing for
  interrupts (bnc#1151927).
- tpm: Wrap the buffer from the caller to tpm_buf in tpm_send()
  (bnc#1151927).
- fuse: fix deadlock with aio poll and fuse_iqueue::waitq.lock
  (bnc#1151927).
- fuse: fix missing unlock_page in fuse_writepage() (bnc#1151927).
- fuse: fix beyond-end-of-page access in fuse_parse_cache()
  (bnc#1151927).
- parisc: Disable HP HSC-PCI Cards to prevent kernel crash
  (bnc#1151927).
- platform/x86: intel_int0002_vgpio: Fix wakeups not working on
  Cherry Trail (bnc#1151927).
- KVM: x86: always stop emulation on page fault (bnc#1151927).
- KVM: x86: set ctxt->have_exception in x86_decode_insn()
  (bnc#1151927).
- KVM: x86: Manually calculate reserved bits when loading PDPTRS
  (bnc#1151927).
- KVM: x86: Disable posted interrupts for non-standard IRQs
  delivery modes (bnc#1151927).
- kvm: x86: Add "significant index" flag to a few CPUID leaves
  (bnc#1151927).
- KVM: x86/mmu: Use fast invalidate mechanism to zap MMIO sptes
  (bnc#1151927).
- media: videobuf-core.c: poll_wait needs a non-NULL buf pointer
  (bnc#1151927).
- media: sn9c20x: Add MSI MS-1039 laptop to flip_dmi_table
  (bnc#1151927).
- media: hantro: Set DMA max segment size (bnc#1151927).
- media: don't drop front-end reference count for ->detach
  (bnc#1151927).
- media: vivid: fix device init when no_error_inj=1 and fb
  disabled (bnc#1151927).
- spi: ep93xx: Repair SPI CS lookup tables (bnc#1151927).
- spi: spi-fsl-dspi: Exit the ISR with IRQ_NONE when it's not ours
  (bnc#1151927).
- binfmt_elf: Do not move brk for INTERP-less ET_EXEC
  (bnc#1151927).
- ASoC: Intel: NHLT: Fix debug print format (bnc#1151927).
- ASoC: Intel: Skylake: Use correct function to access iomem space
  (bnc#1151927).
- ASoC: Intel: Fix use of potentially uninitialized variable
  (bnc#1151927).
- staging: erofs: cannot set EROFS_V_Z_INITED_BIT if
  fill_inode_lazy fails (bnc#1151927).
- ARM: samsung: Fix system restart on S3C6410 (bnc#1151927).
- ARM: zynq: Use memcpy_toio instead of memcpy on smp bring-up
  (bnc#1151927).
- arm64: tlb: Ensure we execute an ISB following walk cache
  invalidation (bnc#1151927).
- arm64: dts: rockchip: limit clock rate of MMC controllers for
  RK3328 (bnc#1151927).
- iommu/arm-smmu-v3: Disable detection of ATS and PRI
  (bnc#1151927).
- alarmtimer: Use EOPNOTSUPP instead of ENOTSUPP (bnc#1151927).
- iommu/vt-d: Fix wrong analysis whether devices share the same
  bus (bnc#1151927).
- regulator: Defer init completion for a while after late_initcall
  (bnc#1151927).
- efifb: BGRT: Improve efifb_bgrt_sanity_check (bnc#1151927).
- gfs2: clear buf_in_tr when ending a transaction in
  sweep_bh_for_rgrps (bnc#1151927).
- z3fold: fix retry mechanism in page reclaim (bnc#1151927).
- z3fold: fix memory leak in kmem cache (bnc#1151927).
- mm/compaction.c: clear total_{migrate,free}_scanned before
  scanning a new zone (bnc#1151927).
- memcg, oom: don't require __GFP_FS when invoking memcg OOM
  killer (bnc#1151927).
- memcg, kmem: do not fail __GFP_NOFAIL charges (bnc#1151927).
- lib/lzo/lzo1x_compress.c: fix alignment bug in lzo-rle
  (bnc#1151927).
- mt76: round up length on mt76_wr_copy (bnc#1151927).
- KEYS: trusted: correctly initialize digests and fix locking
  issue (bnc#1151927).
- rtw88: pci: Rearrange the memory usage for skb in RX ISR
  (bnc#1151927).
- rtw88: pci: Use DMA sync instead of remapping in RX ISR
  (bnc#1151927).
- ath10k: fix channel info parsing for non tlv target
  (bnc#1151927).
- i40e: check __I40E_VF_DISABLE bit in i40e_sync_filters_subtask
  (bnc#1151927).
- block: mq-deadline: Fix queue restart handling (bnc#1151927).
- block: fix null pointer dereference in blk_mq_rq_timed_out()
  (bnc#1151927).
- smb3: allow disabling requesting leases (bnc#1151927).
- smb3: fix unmount hang in open_shroot (bnc#1151927).
- smb3: fix leak in "open on server" perf counter (bnc#1151927).
- ovl: Fix dereferencing possible ERR_PTR() (bnc#1151927).
- ovl: filter of trusted xattr results in audit (bnc#1151927).
- btrfs: fix allocation of free space cache v1 bitmap pages
  (bnc#1151927).
- Btrfs: fix use-after-free when using the tree modification log
  (bnc#1151927).
- btrfs: Relinquish CPUs in btrfs_compare_trees (bnc#1151927).
- btrfs: adjust dirty_metadata_bytes after writeback failure of
  extent buffer (bnc#1151927).
- btrfs: qgroup: Fix the wrong target io_tree when freeing
  reserved data space (bnc#1151927).
- btrfs: qgroup: Fix reserved data space leak if we have multiple
  reserve calls (bnc#1151927).
- Btrfs: fix race setting up and completing qgroup rescan workers
  (bnc#1151927).
- btrfs: Fix a regression which we can't convert to SINGLE profile
  (bnc#1151927).
- SUNRPC: Dequeue the request from the receive queue while we're
  re-encoding (bnc#1151927).
- SUNRPC: Fix buffer handling of GSS MIC without slack
  (bnc#1151927).
- ACPI / LPSS: Save/restore LPSS private registers also on
  Lynxpoint (bnc#1151927).
- md/raid6: Set R5_ReadError when there is read failure on parity
  disk (bnc#1151927).
- md: don't report active array_state until after
  revalidate_disk() completes (bnc#1151927).
- md: only call set_in_sync() when it is expected to succeed
  (bnc#1151927).
- cfg80211: Purge frame registrations on iftype change
  (bnc#1151927).
- /dev/mem: Bail out upon SIGKILL (bnc#1151927).
- fs: Export generic_fadvise() (bnc#1151927).
- mm: Handle MADV_WILLNEED through vfs_fadvise() (bnc#1151927).
- xfs: Fix stale data exposure when readahead races with hole
  punch (bnc#1151927).
- ipmi: move message error checking to avoid deadlock
  (bnc#1151927).
- mtd: rawnand: stm32_fmc2: avoid warnings when building with
  W=1 option (bnc#1151927).
- ext4: fix warning inside ext4_convert_unwritten_extents_endio
  (bnc#1151927).
- ext4: fix punch hole for inline_data file systems (bnc#1151927).
- quota: fix wrong condition in is_quota_modification()
  (bnc#1151927).
- hwrng: core - don't wait on add_early_randomness()
  (bnc#1151927).
- i2c: riic: Clear NACK in tend isr (bnc#1151927).
- CIFS: fix max ea value size (bnc#1151927).
- CIFS: Fix oplock handling for SMB 2.1+ protocols (bnc#1151927).
- drm/amd/display: Restore backlight brightness after system
  resume (bnc#1151927).
- drm/amd/display: dce11.x /dce12 update formula input
  (bnc#1151927).
- drm/amd/display: Add missing HBM support and raise Vega20's uclk
  (bnc#1151927).
- drm/amdgpu/display: fix 64 bit divide (bnc#1151927).
- md/raid0: avoid RAID0 data corruption due to layout confusion
  (bnc#1151927).
- mt76: mt7615: always release sem in mt7615_load_patch
  (bnc#1151927).
- mt76: mt7615: fix mt7615 firmware path definitions
  (bnc#1151927).
- platform/chrome: cros_ec_rpmsg: Fix race with host command
  when probe failed (bnc#1151927).
- commit 6a02213
* Sun Oct  6 2019 jslaby@suse.cz
- Linux 5.3.3 (bnc#1151927).
- Revert "Linux 5.3.2" (bnc#1151927).
- Linux 5.3.2 (bnc#1151927).
- commit 98a6219
* Fri Oct  4 2019 vbabka@suse.cz
- config: enable DEBUG_PAGEALLOC (jsc#PM-1168, bsc#1144653)
  Build with page allocation debugging (boot with debug_pagealloc=on to enable).
  [js] run oldconfig
- config: enable DEBUG_PAGEALLOC (jsc#PM-1168, bsc#1144653)
  Build with page allocation debugging (boot with debug_pagealloc=on to enable).
- commit f6f1081
* Wed Oct  2 2019 jslaby@suse.cz
- iwlwifi: fw: don't send GEO_TX_POWER_LIMIT command to FW
  version 36 (bnc#1152036).
- commit c2cf223
* Wed Oct  2 2019 mkubecek@suse.cz
- s390: mark __cpacf_query() as __always_inline.
  Fix s390x/zfcpdump build.
- commit 6fce476
* Tue Oct  1 2019 mkubecek@suse.cz
- config: refresh vanilla configs
  Configs for vanilla flavor also need a refresh.
- commit f67b42c
* Tue Oct  1 2019 mkubecek@suse.cz
- config: enable X86_5LEVEL (jsc#SLE-9308)
  Enable 5-level page tables (x86_64 architecture only).
- commit 4e52759
* Tue Oct  1 2019 mkubecek@suse.cz
- Update to 5.4-rc1
- Eliminated 23 patches (22 stable, 1 other)
- ARM configs need update
- Refresh
  patches.rpmify/scripts-mkmakefile-honor-second-argument.patch
  patches.suse/Revert-netfilter-conntrack-remove-helper-hook-again.patch
  patches.suse/btrfs-fs-super.c-add-new-super-block-devices-super_block_d.patch
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  patches.suse/supported-flag
  patches.suse/supported-flag-external
  patches.suse/vfs-add-super_operations-get_inode_dev
- fix 32-bit builds:
  patches.rpmify/mlx5-avoid-64-bit-division-in-dr_icm_pool_mr_create.patch
- New config options:
  - General setup
  - UCLAMP_TASK_GROUP=n
  - MODULE_ALLOW_MISSING_NAMESPACE_IMPORTS=n
  - Power management and ACPI options
  - CPU_IDLE_GOV_HALTPOLL=y
  - HALTPOLL_CPUIDLE=m
  - Block layer
  - BLK_CGROUP_IOCOST=y
  - DM_CLONE=m
  - DM_VERITY_VERIFY_ROOTHASH_SIG=n
  - Memory Management
  - READ_ONLY_THP_FOR_FS=y
  - Networking
  - NET_TC_SKB_EXT=y
  - CAN_J1939=m
  - CAN_KVASER_PCIEFD=m
  - CAN_M_CAN_PLATFORM=m
  - CAN_M_CAN_TCAN4X5X=m
  - CAN_F81601=m
  - NET_DSA_MICROCHIP_KSZ9477_I2C=m
  - NET_DSA_MICROCHIP_KSZ8795=m
  - NET_DSA_MICROCHIP_KSZ8795_SPI=m
  - NET_DSA_SJA1105_TAS=y
  - MLX5_SW_STEERING=y
  - NET_VENDOR_PENSANDO=y
  - IONIC=m
  - ADIN_PHY=m
  - ATH9K_PCI_NO_EEPROM=m
  - Power management
  - SENSORS_AS370=m
  - SENSORS_INSPUR_IPSPS=m
  - REGULATOR_SY8824X=m
  - Graphics
  - DRM_AMD_DC_DCN2_1=y
  - DRM_GM12U320=m
  - Sound
  - SND_HDA_INTEL_DETECT_DMIC=y
  - SND_SOC_INTEL_CML_LP_DA7219_MAX98357A_MACH=m
  - SND_SOC_SOF_TIGERLAKE_SUPPORT=y
  - SND_SOC_SOF_ELKHARTLAKE_SUPPORT=y
  - SND_SOC_UDA1334=n
  - SND_SOC_SOF_OF=m
  - USB
  - USB_CONN_GPIO=m
  - USB_CDNS3=m
  - USB_CDNS3_HOST=y
  - USB_CDNS3_PCI_WRAP=m
  - Platform support
  - CROS_EC=m
  - CROS_EC_CHARDEV=m
  - CROS_EC_LIGHTBAR=m
  - CROS_EC_DEBUGFS=m
  - CROS_EC_SYSFS=m
  - CROS_EC_VBC=m
  - Industrial I/O
  - ADIS16460=n
  - NOA1305=n
  - MAX5432=n
  - Misc drivers
  - EFI_RCI2_TABLE=n
  - MTD_NAND_MXIC=m
  - JOYSTICK_FSIA6B=m
  - REMOTEPROC=n
  - SERIAL_FSL_LINFLEXUART=m
  - MFD_CROS_EC_DEV=m
  - W1_MASTER_SGI=m
  - W1_SLAVE_DS250X=m
  - VIDEO_OV5675=m
  - HID_CREATIVE_SB0540=m
  - DMABUF_SELFTESTS=n
  - MOXTET=n
  - File systems
  - FS_VERITY=y
  - FS_VERITY_DEBUG=n
  - FS_VERITY_BUILTIN_SIGNATURES=n
  - VIRTIO_FS=m
  - EXFAT_FS=m
  - EXFAT_DONT_MOUNT_VFAT=y
  - EXFAT_DISCARD=y
  - EXFAT_DELAYED_SYNC=n
  - EXFAT_KERNEL_DEBUG=n
  - EXFAT_DEBUG_MSG=n
  - EXFAT_DEFAULT_CODEPAGE=437
  - EXFAT_DEFAULT_IOCHARSET="utf8"
  - Security
  - SECURITY_LOCKDOWN_LSM=y
  - SECURITY_LOCKDOWN_LSM_EARLY=y
  - LOCK_DOWN_KERNEL_FORCE_NONE=y
  - IMA_DEFAULT_HASH_SHA512=n
  - IMA_APPRAISE_MODSIG=y
  - RANDOM_TRUST_BOOTLOADER=y
  - KEXEC_SIG=y
  - KEXEC_SIG_FORCE=n
  - KEXEC_BZIMAGE_VERIFY_SIG=y
  - Cryptographic API
  - CRYPTO_ESSIV=m
  - CRYPTO_DEV_CCP_DEBUGFS=n
  - CRYPTO_DEV_SAFEXCEL=m
  - PowerPC
  - PPC_SVM=y
  - OPAL_CORE=n
  - S/390
  - CRYPTO_SHA3_256_S390=m
  - CRYPTO_SHA3_512_S390=m
- commit 0599162
* Tue Oct  1 2019 jslaby@suse.cz
- Update config files.
  Enable CONFIG_X86_5LEVEL (jsc#SLE-9607).
- commit 5588b36
* Tue Oct  1 2019 jslaby@suse.cz
- Linux 5.3.2 (bnc#1151927).
- objtool: Clobber user CFLAGS variable (bnc#1151927).
- platform/x86: i2c-multi-instantiate: Derive the device name
  from parent (bnc#1151927).
- ALSA: hda - Apply AMD controller workaround for Raven platform
  (bnc#1151927).
- ALSA: hda - Add laptop imic fixup for ASUS M9V laptop
  (bnc#1151927).
- ALSA: dice: fix wrong packet parameter for Alesis iO26
  (bnc#1151927).
- ALSA: usb-audio: Add DSD support for EVGA NU Audio
  (bnc#1151927).
- ALSA: usb-audio: Add Hiby device family to quirks for native
  DSD support (bnc#1151927).
- Revert "mm/z3fold.c: fix race between migration and destruction"
  (bnc#1151927).
- clk: imx: imx8mm: fix audio pll setting (bnc#1151927).
- crypto: talitos - fix missing break in switch statement
  (bnc#1151927).
- mtd: cfi_cmdset_0002: Use chip_good() to retry in
  do_write_oneword() (bnc#1151927).
- HID: Add quirk for HP X500 PIXART OEM mouse (bnc#1151927).
- HID: hidraw: Fix invalid read in hidraw_ioctl (bnc#1151927).
- HID: logitech-dj: Fix crash when initial
  logi_dj_recv_query_paired_devices fails (bnc#1151927).
- HID: logitech: Fix general protection fault caused by Logitech
  driver (bnc#1151927).
- HID: sony: Fix memory corruption issue on cleanup (bnc#1151927).
- HID: prodikeys: Fix general protection fault during probe
  (bnc#1151927).
- powerpc/xive: Fix bogus error code returned by OPAL
  (bnc#1151927).
- drm/amd/display: readd -msse2 to prevent Clang from emitting
  libcalls to undefined SW FP routines (bnc#1151927).
- drm/amd/display: Don't replace the dc_state for fast updates
  (bnc#1151927).
- drm/amd/display: Skip determining update type for async updates
  (bnc#1151927).
- drm/amd/display: Allow cursor async updates for framebuffer
  swaps (bnc#1151927).
- clocksource/drivers: Do not warn on probe defer (bnc#1151927).
- clocksource/drivers/timer-of: Do not warn on deferred probe
  (bnc#1151927).
- netfilter: add missing IS_ENABLED(CONFIG_NF_TABLES) check to
  header-file (bnc#1151927).
- commit 17d14ca
* Wed Sep 25 2019 fvogt@suse.com
- config: Enable dual-role modes for DWC on arm64 as well
- CONFIG_USB_DWC2_DUAL_ROLE=y and CONFIG_USB_DWC3_DUAL_ROLE=y
- Previously that was only enabled on armv6/armv7
- commit 4940602
* Tue Sep 24 2019 hare@suse.de
- Compile nvme.ko as module (bsc#1150846, bsc#1150850, bsc#1161889)
- commit 3e12ff1
* Sat Sep 21 2019 jslaby@suse.cz
- Linux 5.3.1 (bnc#1012628).
- media: technisat-usb2: break out of loop at end of buffer
  (bnc#1012628).
- floppy: fix usercopy direction (bnc#1012628).
- phy: qcom-qmp: Correct ready status, again (bnc#1012628).
- ovl: fix regression caused by overlapping layers detection
  (bnc#1012628).
- Revert "arm64: Remove unnecessary ISBs from set_{pte,pmd,pud}"
  (bnc#1012628).
- nl80211: Fix possible Spectre-v1 for CQM RSSI thresholds
  (bnc#1012628).
- tty/serial: atmel: reschedule TX after RX was started
  (bnc#1012628).
- serial: sprd: correct the wrong sequence of arguments
  (bnc#1012628).
- firmware: google: check if size is valid when decoding VPD data
  (bnc#1012628).
- Documentation: sphinx: Add missing comma to list of strings
  (bnc#1012628).
- KVM: coalesced_mmio: add bounds checking (bnc#1012628).
- net: stmmac: Hold rtnl lock in suspend/resume callbacks
  (bnc#1012628).
- net: dsa: Fix load order between DSA drivers and taggers
  (bnc#1012628).
- xen-netfront: do not assume sk_buff_head list is empty in
  error handling (bnc#1012628).
- udp: correct reuseport selection with connected sockets
  (bnc#1012628).
- net_sched: let qdisc_put() accept NULL pointer (bnc#1012628).
- net/sched: fix race between deactivation and dequeue for NOLOCK
  qdisc (bnc#1012628).
- ip6_gre: fix a dst leak in ip6erspan_tunnel_xmit (bnc#1012628).
- phy: renesas: rcar-gen3-usb2: Disable clearing VBUS in
  over-current (bnc#1012628).
- media: tm6000: double free if usb disconnect while streaming
  (bnc#1012628).
- USB: usbcore: Fix slab-out-of-bounds bug during device reset
  (bnc#1012628).
- commit f187578
* Wed Sep 18 2019 jroedel@suse.de
- Update config files.
  Disable CONFIG_ARM_SMMU_DISABLE_BYPASS_BY_DEFAULT. Not all drivers are
  ready for this yet, so enabling this config option causes regressions.
  See bsc#1150577 for an example.
- commit f759adc
* Mon Sep 16 2019 mkubecek@suse.cz
- Update to 5.3 final
- Eliminated 3 patches
- Refresh configs
  - NF_CONNTRACK_SLP is gone
- commit 6baef36
* Fri Sep 13 2019 jslaby@suse.cz
- Btrfs: fix unwritten extent buffers and hangs on future
  writeback attempts (btrfs hangup).
- commit 7f85414
* Tue Sep 10 2019 mkubecek@suse.cz
- Delete patches.suse/netfilter-ip_conntrack_slp.patch (FATE#324143 jsc#SLE-8944 bsc#1127886).
  This veteran out of tree patch is no longer needed since the userspace
  conntrack helper (in conntrack-tools / conntrackd) has reached Factory.
- commit d6f0b71
* Tue Sep 10 2019 mkubecek@suse.cz
- Update and reenable
  patches.suse/Revert-netfilter-conntrack-remove-helper-hook-again.patch
  (FATE#324143 jsc#SLE-8944 bsc#1127886).
- commit 029452e
* Tue Sep 10 2019 jslaby@suse.cz
- Linux 5.2.14 (bnc#1012628).
- Revert "mmc: core: do not retry CMD6 in __mmc_switch()"
  (bnc#1012628).
- x86/boot: Preserve boot_params.secure_boot from sanitizing
  (bnc#1012628).
- Revert "x86/apic: Include the LDR when clearing out APIC
  registers" (bnc#1012628).
- libceph: allow ceph_buffer_put() to receive a NULL ceph_buffer
  (bnc#1012628).
- x86/boot/compressed/64: Fix missing initialization in
  find_trampoline_placement() (bnc#1012628).
- KVM: arm/arm64: VGIC: Properly initialise private IRQ affinity
  (bnc#1012628).
- gpio: Fix irqchip initialization order (bnc#1012628).
- RDMA/bnxt_re: Fix stack-out-of-bounds in
  bnxt_qplib_rcfw_send_message (bnc#1012628).
- afs: use correct afs_call_type in yfs_fs_store_opaque_acl2
  (bnc#1012628).
- afs: Fix possible oops in afs_lookup trace event (bnc#1012628).
- afs: Fix leak in afs_lookup_cell_rcu() (bnc#1012628).
- KVM: arm/arm64: Only skip MMIO insn once (bnc#1012628).
- ceph: fix buffer free while holding i_ceph_lock in fill_inode()
  (bnc#1012628).
- ceph: fix buffer free while holding i_ceph_lock in
  __ceph_build_xattrs_blob() (bnc#1012628).
- ceph: fix buffer free while holding i_ceph_lock in
  __ceph_setxattr() (bnc#1012628).
- drm/amdgpu: prevent memory leaks in AMDGPU_CS ioctl
  (bnc#1012628).
- selftests/kvm: make platform_info_test pass on AMD
  (bnc#1012628).
- selftests: kvm: fix state save/load on processors without XSAVE
  (bnc#1012628).
- infiniband: hfi1: fix memory leaks (bnc#1012628).
- infiniband: hfi1: fix a memory leak bug (bnc#1012628).
- IB/mlx4: Fix memory leaks (bnc#1012628).
- RDMA/cma: fix null-ptr-deref Read in cma_cleanup (bnc#1012628).
- nvme: Fix cntlid validation when not using NVMEoF (bnc#1012628).
- nvme-multipath: fix possible I/O hang when paths are updated
  (bnc#1012628).
- Tools: hv: kvp: eliminate 'may be used uninitialized' warning
  (bnc#1012628).
- Input: hyperv-keyboard: Use in-place iterator API in the
  channel callback (bnc#1012628).
- scsi: lpfc: Mitigate high memory pre-allocation by SCSI-MQ
  (bnc#1012628).
- x86/boot/compressed/64: Fix boot on machines with broken E820
  table (bnc#1012628).
- HID: cp2112: prevent sleeping function called from invalid
  context (bnc#1012628).
- HID: intel-ish-hid: ipc: add EHL device id (bnc#1012628).
- kprobes: Fix potential deadlock in kprobe_optimizer()
  (bnc#1012628).
- sched/core: Schedule new worker even if PI-blocked
  (bnc#1012628).
- ravb: Fix use-after-free ravb_tstamp_skb (bnc#1012628).
- wimax/i2400m: fix a memory leak bug (bnc#1012628).
- net: cavium: fix driver name (bnc#1012628).
- ibmvnic: Unmap DMA address of TX descriptor buffers after use
  (bnc#1012628).
- net: kalmia: fix memory leaks (bnc#1012628).
- cx82310_eth: fix a memory leak bug (bnc#1012628).
- vfs: fix page locking deadlocks when deduping files
  (bnc#1012628).
- lan78xx: Fix memory leaks (bnc#1012628).
- clk: Fix potential NULL dereference in clk_fetch_parent_index()
  (bnc#1012628).
- clk: Fix falling back to legacy parent string matching
  (bnc#1012628).
- net: myri10ge: fix memory leaks (bnc#1012628).
- liquidio: add cleanup in octeon_setup_iq() (bnc#1012628).
- selftests: kvm: fix vmx_set_nested_state_test (bnc#1012628).
- selftests: kvm: provide common function to enable eVMCS
  (bnc#1012628).
- selftests: kvm: do not try running the VM in
  vmx_set_nested_state_test (bnc#1012628).
- cxgb4: fix a memory leak bug (bnc#1012628).
- scsi: target: tcmu: avoid use-after-free after command timeout
  (bnc#1012628).
- scsi: qla2xxx: Fix gnl.l memory leak on adapter init failure
  (bnc#1012628).
- drm/mediatek: set DMA max segment size (bnc#1012628).
- drm/mediatek: use correct device to import PRIME buffers
  (bnc#1012628).
- netfilter: nft_flow_offload: skip tcp rst and fin packets
  (bnc#1012628).
- gpio: Fix build error of function redefinition (bnc#1012628).
- ibmveth: Convert multicast list size for little-endian system
  (bnc#1012628).
- s390/qeth: serialize cmd reply with concurrent timeout
  (bnc#1012628).
- Bluetooth: hci_qca: Send VS pre shutdown command (bnc#1012628).
- Bluetooth: btqca: Add a short delay before downloading the NVM
  (bnc#1012628).
- net: tc35815: Explicitly check NET_IP_ALIGN is not zero in
  tc35815_rx (bnc#1012628).
- hv_netvsc: Fix a warning of suspicious RCU usage (bnc#1012628).
- ixgbe: fix possible deadlock in ixgbe_service_task()
  (bnc#1012628).
- tools: bpftool: fix error message (prog -> object)
  (bnc#1012628).
- netfilter: nf_flow_table: teardown flow timeout race
  (bnc#1012628).
- netfilter: nf_flow_table: conntrack picks up expired flows
  (bnc#1012628).
- netfilter: nf_tables: use-after-free in failing rule with
  bound set (bnc#1012628).
- net: tundra: tsi108: use spin_lock_irqsave instead of
  spin_lock_irq in IRQ context (bnc#1012628).
- clk: samsung: exynos542x: Move MSCL subsystem clocks to its
  sub-CMU (bnc#1012628).
- clk: samsung: exynos5800: Move MAU subsystem clocks to MAU
  sub-CMU (bnc#1012628).
- clk: samsung: Change signature of exynos5_subcmus_init()
  function (bnc#1012628).
- net/mlx5e: Fix error flow of CQE recovery on tx reporter
  (bnc#1012628).
- netfilter: nf_flow_table: fix offload for flows that are
  subject to xfrm (bnc#1012628).
- libbpf: set BTF FD for prog only when there is supported
  .BTF.ext data (bnc#1012628).
- libbpf: fix erroneous multi-closing of BTF FD (bnc#1012628).
- batman-adv: Fix netlink dumping of all mcast_flags buckets
  (bnc#1012628).
- net/rds: Fix info leak in rds6_inc_info_copy() (bnc#1012628).
- net/sched: pfifo_fast: fix wrong dereference when qdisc is reset
  (bnc#1012628).
- net/sched: pfifo_fast: fix wrong dereference in
  pfifo_fast_enqueue (bnc#1012628).
- net: dsa: tag_8021q: Future-proof the reserved fields in the
  custom VID (bnc#1012628).
- Add genphy_c45_config_aneg() function to phy-c45.c
  (bnc#1012628).
- net/sched: cbs: Set default link speed to 10 Mbps in
  cbs_set_port_rate (bnc#1012628).
- taprio: Set default link speed to 10 Mbps in
  taprio_set_picos_per_byte (bnc#1012628).
- taprio: Fix kernel panic in taprio_destroy (bnc#1012628).
- r8152: remove calling netif_napi_del (bnc#1012628).
- Revert "r8152: napi hangup fix after disconnect" (bnc#1012628).
- nfp: flower: handle neighbour events on internal ports
  (bnc#1012628).
- nfp: flower: prevent ingress block binds on internal ports
  (bnc#1012628).
- tcp: remove empty skb from write queue in error cases
  (bnc#1012628).
- tcp: inherit timestamp on mtu probe (bnc#1012628).
- net: stmmac: dwmac-rk: Don't fail if phy regulator is absent
  (bnc#1012628).
- net_sched: fix a NULL pointer deref in ipt action (bnc#1012628).
- net: sched: act_sample: fix psample group handling on overwrite
  (bnc#1012628).
- net: fix skb use after free in netpoll (bnc#1012628).
- mld: fix memory leak in mld_del_delrec() (bnc#1012628).
- commit af75f09
* Mon Sep  9 2019 mgorman@suse.de
- config: enable SLAB_FREELIST_HARDENED (bsc#1127808)
  Enable SLAB_FREELIST_HARDENED on all architectures. This obscures the
  free object pointer on a per-cache basis making it more difficult to
  locate kernel objects via exploits probing the cache metadata.
  This change was requested by the upstream openSUSE community to make
  the kernel more resistent to slab freelist attacks. Tests conducted
  by the kernel performance teams confirmed that the performance impact
  is detectable but negligible.
- commit 94938f2
* Mon Sep  9 2019 guillaume.gardet@arm.com
- rpm/constraints.in: lower disk space required for ARM
  With a requirement of 35GB, only 2 slow workers are usable for ARM.
  Current aarch64 build requires 27G and armv6/7 requires 14G.
  Set requirements respectively to 30GB and 20GB.
- commit f84c163
* Mon Sep  9 2019 mkubecek@suse.cz
- Update to 5.3-rc8
- refresh armv6hl configs (IXP4xx drivers no longer visible)
- commit 3dea797
* Mon Sep  9 2019 mkubecek@suse.cz
- config: enable STACKPROTECTOR_STRONG also on armv6hl
  Recently reenabled armv6hl architecture has STACKPROTECTOR_STRONG disabled,
  enable it here as well.
- commit f434a32
* Fri Sep  6 2019 jslaby@suse.cz
- Linux 5.2.13 (bnc#1012628).
- Revert "Input: elantech - enable SMBus on new (2018+) systems"
  (bnc#1012628).
- commit acd8e88
* Fri Sep  6 2019 jslaby@suse.cz
- Linux 5.2.12 (bnc#1012628).
- dmaengine: ste_dma40: fix unneeded variable warning
  (bnc#1012628).
- nvme-multipath: revalidate nvme_ns_head gendisk in
  nvme_validate_ns (bnc#1012628).
- afs: Fix the CB.ProbeUuid service handler to reply correctly
  (bnc#1012628).
- afs: Fix loop index mixup in
  afs_deliver_vl_get_entry_by_name_u() (bnc#1012628).
- fs: afs: Fix a possible null-pointer dereference in
  afs_put_read() (bnc#1012628).
- afs: Fix off-by-one in afs_rename() expected data version
  calculation (bnc#1012628).
- afs: Only update d_fsdata if different in afs_d_revalidate()
  (bnc#1012628).
- afs: Fix missing dentry data version updating (bnc#1012628).
- nvmet: Fix use-after-free bug when a port is removed
  (bnc#1012628).
- nvmet-loop: Flush nvme_delete_wq when removing the port
  (bnc#1012628).
- nvmet-file: fix nvmet_file_flush() always returning an error
  (bnc#1012628).
- nvme-core: Fix extra device_put() call on error path
  (bnc#1012628).
- nvme: fix a possible deadlock when passthru commands sent to
  a multipath device (bnc#1012628).
- nvme-rdma: fix possible use-after-free in connect error flow
  (bnc#1012628).
- nvme: fix controller removal race with scan work (bnc#1012628).
- nvme-pci: Fix async probe remove race (bnc#1012628).
- soundwire: cadence_master: fix register definition for
  SLAVE_STATE (bnc#1012628).
- soundwire: cadence_master: fix definitions for INTSTAT0/1
  (bnc#1012628).
- auxdisplay: panel: need to delete scan_timer when misc_register
  fails in panel_attach (bnc#1012628).
- btrfs: trim: Check the range passed into to prevent overflow
  (bnc#1012628).
- IB/mlx5: Fix implicit MR release flow (bnc#1012628).
- dmaengine: stm32-mdma: Fix a possible null-pointer dereference
  in stm32_mdma_irq_handler() (bnc#1012628).
- omap-dma/omap_vout_vrfb: fix off-by-one fi value (bnc#1012628).
- iommu/dma: Handle SG length overflow better (bnc#1012628).
- dma-direct: don't truncate dma_required_mask to bus addressing
  capabilities (bnc#1012628).
- usb: gadget: composite: Clear "suspended" on reset/disconnect
  (bnc#1012628).
- usb: gadget: mass_storage: Fix races between fsg_disable and
  fsg_set_alt (bnc#1012628).
- habanalabs: fix DRAM usage accounting on context tear down
  (bnc#1012628).
- habanalabs: fix endianness handling for packets from user
  (bnc#1012628).
- habanalabs: fix completion queue handling when host is BE
  (bnc#1012628).
- habanalabs: fix endianness handling for internal QMAN submission
  (bnc#1012628).
- habanalabs: fix device IRQ unmasking for BE host (bnc#1012628).
- xen/blkback: fix memory leaks (bnc#1012628).
- arm64: cpufeature: Don't treat granule sizes as strict
  (bnc#1012628).
- riscv: fix flush_tlb_range() end address for flush_tlb_page()
  (bnc#1012628).
- i2c: rcar: avoid race when unregistering slave client
  (bnc#1012628).
- i2c: emev2: avoid race when unregistering slave client
  (bnc#1012628).
- drm/scheduler: use job count instead of peek (bnc#1012628).
- drm/ast: Fixed reboot test may cause system hanged
  (bnc#1012628).
- usb: host: fotg2: restart hcd after port reset (bnc#1012628).
- tools: hv: fixed Python pep8/flake8 warnings for lsvmbus
  (bnc#1012628).
- tools: hv: fix KVP and VSS daemons exit code (bnc#1012628).
- locking/rwsem: Add missing ACQUIRE to read_slowpath exit when
  queue is empty (bnc#1012628).
- lcoking/rwsem: Add missing ACQUIRE to read_slowpath sleep loop
  (bnc#1012628).
- watchdog: bcm2835_wdt: Fix module autoload (bnc#1012628).
- selftests/bpf: install files test_xdp_vlan.sh (bnc#1012628).
- drm/bridge: tfp410: fix memleak in get_modes() (bnc#1012628).
- mt76: usb: fix rx A-MSDU support (bnc#1012628).
- ipv6/addrconf: allow adding multicast addr if IFA_F_MCAUTOJOIN
  is set (bnc#1012628).
- ipv6: Fix return value of ipv6_mc_may_pull() for malformed
  packets (bnc#1012628).
- net: cpsw: fix NULL pointer exception in the probe error path
  (bnc#1012628).
- net: fix __ip_mc_inc_group usage (bnc#1012628).
- net/smc: make sure EPOLLOUT is raised (bnc#1012628).
- tcp: make sure EPOLLOUT wont be missed (bnc#1012628).
- ipv4: mpls: fix mpls_xmit for iptunnel (bnc#1012628).
- openvswitch: Fix conntrack cache with timeout (bnc#1012628).
- ipv4/icmp: fix rt dst dev null pointer dereference
  (bnc#1012628).
- xfrm/xfrm_policy: fix dst dev null pointer dereference in
  collect_md mode (bnc#1012628).
- mm/zsmalloc.c: fix build when CONFIG_COMPACTION=n (bnc#1012628).
- ALSA: usb-audio: Check mixer unit bitmap yet more strictly
  (bnc#1012628).
- ALSA: hda/ca0132 - Add new SBZ quirk (bnc#1012628).
- ALSA: line6: Fix memory leak at line6_init_pcm() error path
  (bnc#1012628).
- ALSA: hda - Fixes inverted Conexant GPIO mic mute led
  (bnc#1012628).
- ALSA: seq: Fix potential concurrent access to the deleted pool
  (bnc#1012628).
- ALSA: usb-audio: Fix invalid NULL check in
  snd_emuusb_set_samplerate() (bnc#1012628).
- ALSA: usb-audio: Add implicit fb quirk for Behringer UFX1604
  (bnc#1012628).
- kvm: x86: skip populating logical dest map if apic is not sw
  enabled (bnc#1012628).
- KVM: x86: hyper-v: don't crash on KVM_GET_SUPPORTED_HV_CPUID
  when kvm_intel.nested is disabled (bnc#1012628).
- KVM: x86: Don't update RIP or do single-step on faulting
  emulation (bnc#1012628).
- uprobes/x86: Fix detection of 32-bit user mode (bnc#1012628).
- x86/mm/cpa: Prevent large page split when ftrace flips RW on
  kernel text (bnc#1012628).
- x86/apic: Do not initialize LDR and DFR for bigsmp
  (bnc#1012628).
- x86/apic: Include the LDR when clearing out APIC registers
  (bnc#1012628).
- HID: logitech-hidpp: remove support for the G700 over USB
  (bnc#1012628).
- ftrace: Fix NULL pointer dereference in t_probe_next()
  (bnc#1012628).
- ftrace: Check for successful allocation of hash (bnc#1012628).
- ftrace: Check for empty hash and comment the race with
  registering probes (bnc#1012628).
- usbtmc: more sanity checking for packet size (bnc#1012628).
- usb-storage: Add new JMS567 revision to unusual_devs
  (bnc#1012628).
- USB: cdc-wdm: fix race between write and disconnect due to
  flag abuse (bnc#1012628).
- usb: hcd: use managed device resources (bnc#1012628).
- usb: chipidea: udc: don't do hardware access if gadget has
  stopped (bnc#1012628).
- usb: host: ohci: fix a race condition between shutdown and irq
  (bnc#1012628).
- usb: host: xhci: rcar: Fix typo in compatible string matching
  (bnc#1012628).
- USB: storage: ums-realtek: Update module parameter description
  for auto_delink_en (bnc#1012628).
- USB: storage: ums-realtek: Whitelist auto-delink support
  (bnc#1012628).
- tools/power turbostat: Fix caller parameter of get_tdp_amd()
  (bnc#1012628).
- KVM: PPC: Book3S: Fix incorrect guest-to-user-translation
  error handling (bnc#1012628).
- KVM: arm/arm64: vgic: Fix potential deadlock when ap_list is
  long (bnc#1012628).
- KVM: arm/arm64: vgic-v2: Handle SGI bits in GICD_I{S,C}PENDR0
  as WI (bnc#1012628).
- mei: me: add Tiger Lake point LP device ID (bnc#1012628).
- Revert "mmc: sdhci-tegra: drop ->get_ro() implementation"
  (bnc#1012628).
- mmc: sdhci-of-at91: add quirk for broken HS200 (bnc#1012628).
- mmc: sdhci-cadence: enable v4_mode to fix ADMA 64-bit addressing
  (bnc#1012628).
- mmc: core: Fix init of SD cards reporting an invalid VDD range
  (bnc#1012628).
- mmc: sdhci-sprd: fixed incorrect clock divider (bnc#1012628).
- mmc: sdhci-sprd: add SDHCI_QUIRK2_PRESET_VALUE_BROKEN
  (bnc#1012628).
- stm class: Fix a double free of stm_source_device (bnc#1012628).
- intel_th: pci: Add support for another Lewisburg PCH
  (bnc#1012628).
- intel_th: pci: Add Tiger Lake support (bnc#1012628).
- typec: tcpm: fix a typo in the comparison of pdo_max_voltage
  (bnc#1012628).
- fsi: scom: Don't abort operations for minor errors
  (bnc#1012628).
- lkdtm/bugs: fix build error in lkdtm_EXHAUST_STACK
  (bnc#1012628).
- NFSv4/pnfs: Fix a page lock leak in nfs_pageio_resend()
  (bnc#1012628).
- NFS: Ensure O_DIRECT reports an error if the bytes read/written
  is 0 (bnc#1012628).
- Revert "NFSv4/flexfiles: Abort I/O early if the layout segment
  was invalidated" (bnc#1012628).
- lib: logic_pio: Fix RCU usage (bnc#1012628).
- lib: logic_pio: Avoid possible overlap for unregistering regions
  (bnc#1012628).
- lib: logic_pio: Add logic_pio_unregister_range() (bnc#1012628).
- drm/amdgpu: Add APTX quirk for Dell Latitude 5495 (bnc#1012628).
- drm/amdgpu: fix GFXOFF on Picasso and Raven2 (bnc#1012628).
- drm/i915: Don't deballoon unused ggtt drm_mm_node in linux guest
  (bnc#1012628).
- drm/i915: Call dma_set_max_seg_size() in i915_driver_hw_probe()
  (bnc#1012628).
- i2c: piix4: Fix port selection for AMD Family 16h Model 30h
  (bnc#1012628).
- bus: hisi_lpc: Unregister logical PIO range to avoid potential
  use-after-free (bnc#1012628).
- bus: hisi_lpc: Add .remove method to avoid driver unbind crash
  (bnc#1012628).
- VMCI: Release resource if the work is already queued
  (bnc#1012628).
- crypto: ccp - Ignore unconfigured CCP device on suspend/resume
  (bnc#1012628).
- SUNRPC: Don't handle errors if the bind/connect succeeded
  (bnc#1012628).
- mt76: mt76x0u: do not reset radio on resume (bnc#1012628).
- mms: sdhci-sprd: add SDHCI_QUIRK_BROKEN_CARD_DETECTION
  (bnc#1012628).
- mm, memcg: partially revert "mm/memcontrol.c: keep local VM
  counters in sync with the hierarchical ones" (bnc#1012628).
- mm: memcontrol: fix percpu vmstats and vmevents flush
  (bnc#1012628).
- Revert "cfg80211: fix processing world regdomain when non
  modular" (bnc#1012628).
- mac80211: fix possible sta leak (bnc#1012628).
- cfg80211: Fix Extended Key ID key install checks (bnc#1012628).
- mac80211: Don't memset RXCB prior to PAE intercept
  (bnc#1012628).
- mac80211: Correctly set noencrypt for PAE frames (bnc#1012628).
- mmc: sdhci-sprd: clear the UHS-I modes read from registers
  (bnc#1012628).
- mmc: sdhci-sprd: Implement the get_max_timeout_count() interface
  (bnc#1012628).
- mmc: sdhci-sprd: add get_ro hook function (bnc#1012628).
- iwlwifi: add new cards for 22000 and fix struct name
  (bnc#1012628).
- iwlwifi: add new cards for 22000 and change wrong structs
  (bnc#1012628).
- iwlwifi: add new cards for 9000 and 20000 series (bnc#1012628).
- iwlwifi: change 0x02F0 fw from qu to quz (bnc#1012628).
- iwlwifi: pcie: add support for qu c-step devices (bnc#1012628).
- iwlwifi: pcie: don't switch FW to qnj when ax201 is detected
  (bnc#1012628).
- iwlwifi: pcie: handle switching killer Qu B0 NICs to C0
  (bnc#1012628).
- drm/i915: Do not create a new max_bpc prop for MST connectors
  (bnc#1012628).
- drm/i915/dp: Fix DSC enable code to use cpu_transcoder instead
  of encoder->type (bnc#1012628).
- bpf: fix use after free in prog symbol exposure (bnc#1012628).
- hsr: implement dellink to clean up resources (bnc#1012628).
- hsr: fix a NULL pointer deref in hsr_dev_xmit() (bnc#1012628).
- hsr: switch ->dellink() to ->ndo_uninit() (bnc#1012628).
- Revert "ASoC: Fail card instantiation if DAI format setup fails"
  (bnc#1012628).
- commit bb4c31d
* Fri Sep  6 2019 msuchanek@suse.de
- powerpc/tm: Fix restoring FP/VMX facility incorrectly on
  interrupts (CVE-2019-15031 bsc#1149713).
- powerpc/tm: Fix FP/VMX unavailable exceptions inside a
  transaction (CVE-2019-15030 bsc#1149713).
- commit 76a34af
* Thu Sep  5 2019 jslaby@suse.cz
- x86/ptrace: fix up botched merge of spectrev1 fix (bnc#1149376
  CVE-2019-15902).
- commit 77497b6
* Tue Sep  3 2019 mkubecek@suse.cz
- config: enable STACKPROTECTOR_STRONG (jsc#SLE-9120 bsc#1130365)
  Enable CONFIG_STACKPROTECTOR_STRONG on all architectures except s390x
  (where the feature is not available). This extends the number of functions
  which are protected by "stack canary" check to catch functions writing past
  their stack frame.
  This change was requested by SUSE security to make our kernels more
  resistant to some types of stack overflow attacks. Tests performed by
  kernel performance teams confirmed that performance impact is acceptable.
- commit d6e8aab
* Mon Sep  2 2019 mkubecek@suse.cz
- Update to 5.3-rc7
- Refresh configs
  - IXP4xx SoC drivers not visible
  - gcc 9.2.1
- commit 9bff5f9
* Sun Sep  1 2019 mkubecek@suse.cz
- config: armv7hl: Enable cadence watchdog
  CONFIG_CADENCE_WATCHDOG is required for Zynq-7000 based MIYR Zturn board.
- commit c4cbe5e
* Fri Aug 30 2019 dmueller@suse.com
- config.conf: Update ARMv6 config files
- commit c17167d
* Fri Aug 30 2019 dmueller@suse.com
- config.conf: Reenable ARMv7 config for Kernel 5.3
  All modules plus errata's enabled. Reused other
  values from x86_64 update.
- commit b1c627e
* Thu Aug 29 2019 jslaby@suse.cz
- Linux 5.2.11 (bnc#1012628).
- ASoC: simple_card_utils.h: care NULL dai at
  asoc_simple_debug_dai() (bnc#1012628).
- ASoC: simple-card: fix an use-after-free in
  simple_dai_link_of_dpcm() (bnc#1012628).
- ASoC: simple-card: fix an use-after-free in
  simple_for_each_link() (bnc#1012628).
- ASoC: audio-graph-card: fix use-after-free in
  graph_dai_link_of_dpcm() (bnc#1012628).
- ASoC: audio-graph-card: fix an use-after-free in
  graph_get_dai_id() (bnc#1012628).
- ASoC: audio-graph-card: add missing const at graph_get_dai_id()
  (bnc#1012628).
- regulator: axp20x: fix DCDCA and DCDCD for AXP806 (bnc#1012628).
- regulator: axp20x: fix DCDC5 and DCDC6 for AXP803 (bnc#1012628).
- ASoC: samsung: odroid: fix an use-after-free issue for codec
  (bnc#1012628).
- ASoC: samsung: odroid: fix a double-free issue for cpu_dai
  (bnc#1012628).
- ASoC: Intel: bytcht_es8316: Add quirk for Irbis NB41 netbook
  (bnc#1012628).
- HID: logitech-hidpp: add USB PID for a few more supported mice
  (bnc#1012628).
- HID: Add 044f:b320 ThrustMaster, Inc. 2 in 1 DT (bnc#1012628).
- MIPS: kernel: only use i8253 clocksource with periodic
  clockevent (bnc#1012628).
- mips: fix cacheinfo (bnc#1012628).
- libbpf: sanitize VAR to conservative 1-byte INT (bnc#1012628).
- netfilter: ebtables: fix a memory leak bug in compat
  (bnc#1012628).
- ASoC: dapm: Fix handling of custom_stop_condition on DAPM
  graph walks (bnc#1012628).
- ASoC: SOF: use __u32 instead of uint32_t in uapi headers
  (bnc#1012628).
- spi: pxa2xx: Balance runtime PM enable/disable on error
  (bnc#1012628).
- bpf: sockmap, sock_map_delete needs to use xchg (bnc#1012628).
- bpf: sockmap, synchronize_rcu before free'ing map (bnc#1012628).
- bpf: sockmap, only create entry if ulp is not already enabled
  (bnc#1012628).
- selftests/bpf: fix sendmsg6_prog on s390 (bnc#1012628).
- ASoC: dapm: fix a memory leak bug (bnc#1012628).
- bonding: Force slave speed check after link state recovery
  for 802.3ad (bnc#1012628).
- net: mvpp2: Don't check for 3 consecutive Idle frames for 10G
  links (bnc#1012628).
- selftests: forwarding: gre_multipath: Enable IPv4 forwarding
  (bnc#1012628).
- selftests: forwarding: gre_multipath: Fix flower filters
  (bnc#1012628).
- selftests/bpf: add another gso_segs access (bnc#1012628).
- libbpf: fix using uninitialized ioctl results (bnc#1012628).
- can: dev: call netif_carrier_off() in register_candev()
  (bnc#1012628).
- can: mcp251x: add error check when wq alloc failed
  (bnc#1012628).
- can: gw: Fix error path of cgw_module_init (bnc#1012628).
- ASoC: Fail card instantiation if DAI format setup fails
  (bnc#1012628).
- Staging: fbtft: Fix GPIO handling (bnc#1012628).
- libbpf: silence GCC8 warning about string truncation
  (bnc#1012628).
- st21nfca_connectivity_event_received: null check the allocation
  (bnc#1012628).
- st_nci_hci_connectivity_event_received: null check the
  allocation (bnc#1012628).
- {nl,mac}80211: fix interface combinations on crypto controlled
  devices (bnc#1012628).
- ASoC: ti: davinci-mcasp: Fix clk PDIR handling for i2s master
  mode (bnc#1012628).
- ASoC: rockchip: Fix mono capture (bnc#1012628).
- ASoC: ti: davinci-mcasp: Correct slot_width posed constraint
  (bnc#1012628).
- net: usb: qmi_wwan: Add the BroadMobi BM818 card (bnc#1012628).
- qed: RDMA - Fix the hw_ver returned in device attributes
  (bnc#1012628).
- isdn: mISDN: hfcsusb: Fix possible null-pointer dereferences
  in start_isoc_chain() (bnc#1012628).
- habanalabs: fix F/W download in BE architecture (bnc#1012628).
- mac80211_hwsim: Fix possible null-pointer dereferences in
  hwsim_dump_radio_nl() (bnc#1012628).
- net: stmmac: manage errors returned by of_get_mac_address()
  (bnc#1012628).
- netfilter: ipset: Actually allow destination MAC address for
  hash:ip,mac sets too (bnc#1012628).
- netfilter: ipset: Copy the right MAC address in bitmap:ip,mac
  and hash:ip,mac sets (bnc#1012628).
- netfilter: ipset: Fix rename concurrency with listing
  (bnc#1012628).
- rxrpc: Fix potential deadlock (bnc#1012628).
- rxrpc: Fix the lack of notification when sendmsg() fails on
  a DATA packet (bnc#1012628).
- nvmem: Use the same permissions for eeprom as for nvmem
  (bnc#1012628).
- iwlwifi: mvm: avoid races in rate init and rate perform
  (bnc#1012628).
- iwlwifi: dbg_ini: move iwl_dbg_tlv_load_bin out of debug
  override ifdef (bnc#1012628).
- iwlwifi: dbg_ini: move iwl_dbg_tlv_free outside of debugfs ifdef
  (bnc#1012628).
- iwlwifi: fix locking in delayed GTK setting (bnc#1012628).
- iwlwifi: mvm: send LQ command always ASYNC (bnc#1012628).
- enetc: Fix build error without PHYLIB (bnc#1012628).
- isdn: hfcsusb: Fix mISDN driver crash caused by transfer buffer
  on the stack (bnc#1012628).
- net: phy: phy_led_triggers: Fix a possible null-pointer
  dereference in phy_led_trigger_change_speed() (bnc#1012628).
- perf bench numa: Fix cpu0 binding (bnc#1012628).
- spi: pxa2xx: Add support for Intel Tiger Lake (bnc#1012628).
- can: sja1000: force the string buffer NULL-terminated
  (bnc#1012628).
- can: peak_usb: force the string buffer NULL-terminated
  (bnc#1012628).
- ASoC: amd: acp3x: use dma_ops of parent device for acp3x dma
  driver (bnc#1012628).
- net/ethernet/qlogic/qed: force the string buffer NULL-terminated
  (bnc#1012628).
- enetc: Select PHYLIB while CONFIG_FSL_ENETC_VF is set
  (bnc#1012628).
- NFSv4: Fix a credential refcount leak in
  nfs41_check_delegation_stateid (bnc#1012628).
- NFSv4: When recovering state fails with EAGAIN, retry the same
  recovery (bnc#1012628).
- NFSv4.1: Fix open stateid recovery (bnc#1012628).
- NFSv4.1: Only reap expired delegations (bnc#1012628).
- NFSv4: Fix a potential sleep while atomic in nfs4_do_reclaim()
  (bnc#1012628).
- NFS: Fix regression whereby fscache errors are appearing on
  'nofsc' mounts (bnc#1012628).
- HID: quirks: Set the INCREMENT_USAGE_ON_DUPLICATE quirk on
  Saitek X52 (bnc#1012628).
- HID: input: fix a4tech horizontal wheel custom usage
  (bnc#1012628).
- drm/rockchip: Suspend DP late (bnc#1012628).
- SMB3: Fix potential memory leak when processing compound chain
  (bnc#1012628).
- SMB3: Kernel oops mounting a encryptData share with
  CONFIG_DEBUG_VIRTUAL (bnc#1012628).
- sched/deadline: Fix double accounting of rq/running bw in push &
  pull (bnc#1012628).
- sched/psi: Reduce psimon FIFO priority (bnc#1012628).
- sched/psi: Do not require setsched permission from the trigger
  creator (bnc#1012628).
- s390/protvirt: avoid memory sharing for diag 308 set/store
  (bnc#1012628).
- s390/mm: fix dump_pagetables top level page table walking
  (bnc#1012628).
- s390: put _stext and _etext into .text section (bnc#1012628).
- ata: rb532_cf: Fix unused variable warning in
  rb532_pata_driver_probe (bnc#1012628).
- net: cxgb3_main: Fix a resource leak in a error path in
  'init_one()' (bnc#1012628).
- net: stmmac: Fix issues when number of Queues >= 4
  (bnc#1012628).
- net: stmmac: tc: Do not return a fragment entry (bnc#1012628).
- drm/amdgpu: pin the csb buffer on hw init for gfx v8
  (bnc#1012628).
- net: hisilicon: make hip04_tx_reclaim non-reentrant
  (bnc#1012628).
- net: hisilicon: fix hip04-xmit never return TX_BUSY
  (bnc#1012628).
- net: hisilicon: Fix dma_map_single failed on arm64
  (bnc#1012628).
- NFSv4: Ensure state recovery handles ETIMEDOUT correctly
  (bnc#1012628).
- libata: have ata_scsi_rw_xlat() fail invalid passthrough
  requests (bnc#1012628).
- libata: add SG safety checks in SFF pio transfers (bnc#1012628).
- x86/lib/cpu: Address missing prototypes warning (bnc#1012628).
- drm/vmwgfx: fix memory leak when too many retries have occurred
  (bnc#1012628).
- block: aoe: Fix kernel crash due to atomic sleep when exiting
  (bnc#1012628).
- block, bfq: handle NULL return value by bfq_init_rq()
  (bnc#1012628).
- perf ftrace: Fix failure to set cpumask when only one cpu is
  present (bnc#1012628).
- perf cpumap: Fix writing to illegal memory in handling cpumap
  mask (bnc#1012628).
- perf pmu-events: Fix missing "cpu_clk_unhalted.core" event
  (bnc#1012628).
- dt-bindings: riscv: fix the schema compatible string for the
  HiFive Unleashed board (bnc#1012628).
- KVM: arm64: Don't write junk to sysregs on reset (bnc#1012628).
- KVM: arm: Don't write junk to CP15 registers on reset
  (bnc#1012628).
- selftests: kvm: Adding config fragments (bnc#1012628).
- iwlwifi: mvm: disable TX-AMSDU on older NICs (bnc#1012628).
- HID: wacom: correct misreported EKR ring values (bnc#1012628).
- HID: wacom: Correct distance scale for 2nd-gen Intuos devices
  (bnc#1012628).
- Revert "KVM: x86/mmu: Zap only the relevant pages when removing
  a memslot" (bnc#1012628).
- Revert "dm bufio: fix deadlock with loop device" (bnc#1012628).
- clk: socfpga: stratix10: fix rate caclulationg for cnt_clks
  (bnc#1012628).
- ceph: clear page dirty before invalidate page (bnc#1012628).
- ceph: don't try fill file_lock on unsuccessful GETFILELOCK reply
  (bnc#1012628).
- libceph: fix PG split vs OSD (re)connect race (bnc#1012628).
- drm/amdgpu/gfx9: update pg_flags after determining if gfx off
  is possible (bnc#1012628).
- drm/nouveau: Don't retry infinitely when receiving no data on
  i2c over AUX (bnc#1012628).
- scsi: ufs: Fix NULL pointer dereference in
  ufshcd_config_vreg_hpm() (bnc#1012628).
- gpiolib: never report open-drain/source lines as 'input'
  to user-space (bnc#1012628).
- Drivers: hv: vmbus: Fix virt_to_hvpfn() for X86_PAE
  (bnc#1012628).
- userfaultfd_release: always remove uffd flags and clear
  vm_userfaultfd_ctx (bnc#1012628).
- x86/retpoline: Don't clobber RFLAGS during CALL_NOSPEC on i386
  (bnc#1012628).
- x86/CPU/AMD: Clear RDRAND CPUID bit on AMD family 15h/16h
  (bnc#1012628).
- x86/boot: Save fields explicitly, zero out everything else
  (bnc#1012628).
- x86/boot: Fix boot regression caused by bootparam sanitizing
  (bnc#1012628).
- IB/hfi1: Unsafe PSN checking for TID RDMA READ Resp packet
  (bnc#1012628).
- IB/hfi1: Add additional checks when handling TID RDMA READ
  RESP packet (bnc#1012628).
- IB/hfi1: Add additional checks when handling TID RDMA WRITE
  DATA packet (bnc#1012628).
- IB/hfi1: Drop stale TID RDMA packets that cause TIDErr
  (bnc#1012628).
- psi: get poll_work to run when calling poll syscall next time
  (bnc#1012628).
- dm kcopyd: always complete failed jobs (bnc#1012628).
- dm dust: use dust block size for badblocklist index
  (bnc#1012628).
- dm btree: fix order of block initialization in
  btree_split_beneath (bnc#1012628).
- dm integrity: fix a crash due to BUG_ON in
  __journal_read_write() (bnc#1012628).
- dm raid: add missing cleanup in raid_ctr() (bnc#1012628).
- dm space map metadata: fix missing store of apply_bops()
  return value (bnc#1012628).
- dm table: fix invalid memory accesses with too high sector
  number (bnc#1012628).
- dm zoned: improve error handling in reclaim (bnc#1012628).
- dm zoned: improve error handling in i/o map code (bnc#1012628).
- dm zoned: properly handle backing device failure (bnc#1012628).
- genirq: Properly pair kobject_del() with kobject_add()
  (bnc#1012628).
- mm/z3fold.c: fix race between migration and destruction
  (bnc#1012628).
- mm, page_alloc: move_freepages should not examine struct page
  of reserved memory (bnc#1012628).
- mm: memcontrol: flush percpu vmstats before releasing memcg
  (bnc#1012628).
- mm: memcontrol: flush percpu vmevents before releasing memcg
  (bnc#1012628).
- mm, page_owner: handle THP splits correctly (bnc#1012628).
- mm/zsmalloc.c: migration can leave pages in ZS_EMPTY
  indefinitely (bnc#1012628).
- mm/zsmalloc.c: fix race condition in zs_destroy_pool
  (bnc#1012628).
- mm/kasan: fix false positive invalid-free reports with
  CONFIG_KASAN_SW_TAGS=y (bnc#1012628).
- xfs: fix missing ILOCK unlock when xfs_setattr_nonsize fails
  due to EDQUOT (bnc#1012628).
- IB/hfi1: Drop stale TID RDMA packets (bnc#1012628).
- dm zoned: fix potential NULL dereference in dmz_do_reclaim()
  (bnc#1012628).
- io_uring: fix potential hang with polled IO (bnc#1012628).
- io_uring: don't enter poll loop if we have CQEs pending
  (bnc#1012628).
- io_uring: add need_resched() check in inner poll loop
  (bnc#1012628).
- powerpc: Allow flush_(inval_)dcache_range to work across ranges
  >4GB (bnc#1012628).
- rxrpc: Fix local endpoint refcounting (bnc#1012628).
- rxrpc: Fix read-after-free in rxrpc_queue_local() (bnc#1012628).
- rxrpc: Fix local endpoint replacement (bnc#1012628).
- rxrpc: Fix local refcounting (bnc#1012628).
- commit 6385110
* Wed Aug 28 2019 tiwai@suse.de
- mwifiex: Fix three heap overflow at
  parsing element in cfg80211_ap_settings
  (CVE-2019-14814,bsc#1146512,CVE-2019-14815,bsc#1146514,CVE-2019-14816,bsc#1146516).
- commit 528fd68
* Wed Aug 28 2019 tiwai@suse.de
- mwifiex: Fix three heap overflow at
  parsing element in cfg80211_ap_settings
  (CVE-2019-14814,bsc#1146512,CVE-2019-14815,bsc#1146514,CVE-2019-14816,bsc#1146516).
- commit 05e68fe
* Wed Aug 28 2019 mkubecek@suse.cz
- supported.conf: mark more core networking modules supported
  Two more netfilter modules and one more *_diag should be supported too.
- commit bee2dd8
* Wed Aug 28 2019 mkubecek@suse.cz
- supported.conf: update status of some networking core modules
  This marks new networking modules which should be supported as such; it is
  mostly netfilter and traffic control modules which have been following the
  "support all of them" policy for some time.
- commit 65e1131
* Wed Aug 28 2019 mkubecek@suse.cz
- supported.conf: obsolete paths cleanup
  Update paths for existing modules which were moved, clean up duplicate
  entries and drop entries for modules which no longer exist (either not
  built any more or built into the image now).
- commit 3bb142a
* Tue Aug 27 2019 mkubecek@suse.cz
- rpm: raise required disk space for binary packages
  Current disk space constraints (10 GB on s390x, 25 GB on other
  architectures) no longer suffice for 5.3 kernel builds. The statistics
  show ~30 GB of disk consumption on x86_64 and ~11 GB on s390x so raise
  the constraints to 35 GB in general and 14 GB on s390x.
- commit 527cb66
* Tue Aug 27 2019 jslaby@suse.cz
- Refresh
  patches.suse/x86-apic-Handle-missing-global-clockevent-gracefully.patch.
  Update to the upstreamed patch.
- commit bb236c2
* Mon Aug 26 2019 jgross@suse.com
- usb: Introduce Xen pvUSB frontend (xen hcd) (fate#315712).
- Update config files.
- usb: Add Xen pvUSB protocol description (fate#315712).
- commit b32b2bd
* Mon Aug 26 2019 tiwai@suse.de
- Update reference for ath6kl fix (CVE-2019-15290,bsc#1146543).
- commit b08d3d5
* Mon Aug 26 2019 tiwai@suse.de
- Update reference for ath6kl fix (CVE-2019-15290,bsc#1146543).
- commit 6f03484
* Mon Aug 26 2019 tiwai@suse.de
- Fix a NULL-ptr-deref bug in ath6kl_usb_alloc_urb_from_pipe
  (CVE-2019-15098,bsc#1146378).
- Fix a NULL-ptr-deref bug in ath10k_usb_alloc_urb_from_pipe
  (CVE-2019-15099,bsc#1146368).
- commit 758e216
* Mon Aug 26 2019 tiwai@suse.de
- Fix a NULL-ptr-deref bug in ath6kl_usb_alloc_urb_from_pipe
  (CVE-2019-15098,bsc#1146378).
- Fix a NULL-ptr-deref bug in ath10k_usb_alloc_urb_from_pipe
  (CVE-2019-15099,bsc#1146368).
- commit 8c61e43
* Mon Aug 26 2019 bpoirier@suse.com
- Fix a double free bug in rsi_91x_deinit (bnc#1147116
  CVE-2019-15504).
- commit 5009555
* Mon Aug 26 2019 bpoirier@suse.com
- Fix a double free bug in rsi_91x_deinit (bnc#1147116
  CVE-2019-15504).
- commit 8ae43d1
* Sun Aug 25 2019 mkubecek@suse.cz
- Update to 5.3-rc6
- commit 2831011
* Sun Aug 25 2019 jslaby@suse.cz
- Linux 5.2.10 (bnc#1012628).
- KEYS: trusted: allow module init if TPM is inactive or
  deactivated (bnc#1012628).
- sh: kernel: hw_breakpoint: Fix missing break in switch statement
  (bnc#1012628).
- seq_file: fix problem when seeking mid-record (bnc#1012628).
- mm/hmm: fix bad subpage pointer in try_to_unmap_one
  (bnc#1012628).
- mm: mempolicy: make the behavior consistent when MPOL_MF_MOVE*
  and MPOL_MF_STRICT were specified (bnc#1012628).
- mm: mempolicy: handle vma with unmovable pages mapped correctly
  in mbind (bnc#1012628).
- mm/z3fold.c: fix z3fold_destroy_pool() ordering (bnc#1012628).
- mm/z3fold.c: fix z3fold_destroy_pool() race condition
  (bnc#1012628).
- mm/memcontrol.c: fix use after free in mem_cgroup_iter()
  (bnc#1012628).
- mm/usercopy: use memory range to be accessed for wraparound
  check (bnc#1012628).
- mm, vmscan: do not special-case slab reclaim when watermarks
  are boosted (bnc#1012628).
- cpufreq: schedutil: Don't skip freq update when limits change
  (bnc#1012628).
- drm/amdgpu: fix gfx9 soft recovery (bnc#1012628).
- drm/nouveau: Only recalculate PBN/VCPI on mode/connector changes
  (bnc#1012628).
- xtensa: add missing isync to the cpu_reset TLB code
  (bnc#1012628).
- arm64: ftrace: Ensure module ftrace trampoline is coherent
  with I-side (bnc#1012628).
- ALSA: hda/realtek - Add quirk for HP Envy x360 (bnc#1012628).
- ALSA: usb-audio: Fix a stack buffer overflow bug in
  check_input_term (bnc#1012628).
- ALSA: usb-audio: Fix an OOB bug in parse_audio_mixer_unit
  (bnc#1012628).
- ALSA: hda - Apply workaround for another AMD chip 1022:1487
  (bnc#1012628).
- ALSA: hda - Fix a memory leak bug (bnc#1012628).
- ALSA: hda - Add a generic reboot_notify (bnc#1012628).
- ALSA: hda - Let all conexant codec enter D3 when rebooting
  (bnc#1012628).
- HID: holtek: test for sanity of intfdata (bnc#1012628).
- HID: hiddev: avoid opening a disconnected device (bnc#1012628).
- HID: hiddev: do cleanup in failure of opening a device
  (bnc#1012628).
- Input: kbtab - sanity check for endpoint type (bnc#1012628).
- Input: iforce - add sanity checks (bnc#1012628).
- net: usb: pegasus: fix improper read if get_registers() fail
  (bnc#1012628).
- bpf: fix access to skb_shared_info->gso_segs (bnc#1012628).
- netfilter: ebtables: also count base chain policies
  (bnc#1012628).
- riscv: Correct the initialized flow of FP register
  (bnc#1012628).
- riscv: Make __fstate_clean() work correctly (bnc#1012628).
- Revert "i2c: imx: improve the error handling in
  i2c_imx_dma_request()" (bnc#1012628).
- blk-mq: move cancel of requeue_work to the front of
  blk_exit_queue (bnc#1012628).
- io_uring: fix manual setup of iov_iter for fixed buffers
  (bnc#1012628).
- RDMA/hns: Fix sg offset non-zero issue (bnc#1012628).
- IB/mlx5: Replace kfree with kvfree (bnc#1012628).
- clk: at91: generated: Truncate divisor to GENERATED_MAX_DIV +
  1 (bnc#1012628).
- clk: sprd: Select REGMAP_MMIO to avoid compile errors
  (bnc#1012628).
- clk: renesas: cpg-mssr: Fix reset control race condition
  (bnc#1012628).
- dma-mapping: check pfn validity in dma_common_{mmap,get_sgtable}
  (bnc#1012628).
- platform/x86: pcengines-apuv2: Fix softdep statement
  (bnc#1012628).
- platform/x86: intel_pmc_core: Add ICL-NNPI support to PMC Core
  (bnc#1012628).
- mm/hmm: always return EBUSY for invalid ranges in
  hmm_range_{fault,snapshot} (bnc#1012628).
- xen/pciback: remove set but not used variable 'old_state'
  (bnc#1012628).
- irqchip/gic-v3-its: Free unused vpt_page when alloc vpe table
  fail (bnc#1012628).
- irqchip/irq-imx-gpcv2: Forward irq type to parent (bnc#1012628).
- f2fs: fix to read source block before invalidating it
  (bnc#1012628).
- tools perf beauty: Fix usbdevfs_ioctl table generator to handle
  _IOC() (bnc#1012628).
- perf header: Fix divide by zero error if f_header.attr_size==0
  (bnc#1012628).
- perf header: Fix use of unitialized value warning (bnc#1012628).
- RDMA/qedr: Fix the hca_type and hca_rev returned in device
  attributes (bnc#1012628).
- ALSA: pcm: fix lost wakeup event scenarios in snd_pcm_drain
  (bnc#1012628).
- libata: zpodd: Fix small read overflow in zpodd_get_mech_type()
  (bnc#1012628).
- powerpc/nvdimm: Pick nearby online node if the device node is
  not online (bnc#1012628).
- drm/bridge: lvds-encoder: Fix build error while
  CONFIG_DRM_KMS_HELPER=m (bnc#1012628).
- drm/bridge: tc358764: Fix build error (bnc#1012628).
- Btrfs: fix deadlock between fiemap and transaction commits
  (bnc#1012628).
- scsi: hpsa: correct scsi command status issue after reset
  (bnc#1012628).
- scsi: qla2xxx: Fix possible fcport null-pointer dereferences
  (bnc#1012628).
- tracing: Fix header include guards in trace event headers
  (bnc#1012628).
- drm/amdkfd: Fix byte align on VegaM (bnc#1012628).
- drm/amd/powerplay: fix null pointer dereference around dpm
  state relates (bnc#1012628).
- drm/amdgpu: fix error handling in amdgpu_cs_process_fence_dep
  (bnc#1012628).
- drm/amdgpu: fix a potential information leaking bug
  (bnc#1012628).
- ata: libahci: do not complain in case of deferred probe
  (bnc#1012628).
- kbuild: modpost: handle KBUILD_EXTRA_SYMBOLS only for external
  modules (bnc#1012628).
- kbuild: Check for unknown options with cc-option usage in
  Kconfig and clang (bnc#1012628).
- arm64/efi: fix variable 'si' set but not used (bnc#1012628).
- riscv: Fix perf record without libelf support (bnc#1012628).
- arm64: Lower priority mask for GIC_PRIO_IRQON (bnc#1012628).
- arm64: unwind: Prohibit probing on return_address()
  (bnc#1012628).
- arm64/mm: fix variable 'pud' set but not used (bnc#1012628).
- arm64/mm: fix variable 'tag' set but not used (bnc#1012628).
- IB/core: Add mitigation for Spectre V1 (bnc#1012628).
- IB/mlx5: Fix MR registration flow to use UMR properly
  (bnc#1012628).
- RDMA/restrack: Track driver QP types in resource tracker
  (bnc#1012628).
- IB/mad: Fix use-after-free in ib mad completion handling
  (bnc#1012628).
- RDMA/mlx5: Release locks during notifier unregister
  (bnc#1012628).
- drm: msm: Fix add_gpu_components (bnc#1012628).
- RDMA/hns: Fix error return code in hns_roce_v1_rsv_lp_qp()
  (bnc#1012628).
- drm/exynos: fix missing decrement of retry counter
  (bnc#1012628).
- arm64: kprobes: Recover pstate.D in single-step exception
  handler (bnc#1012628).
- arm64: Make debug exception handlers visible from RCU
  (bnc#1012628).
- Revert "kmemleak: allow to coexist with fault injection"
  (bnc#1012628).
- ocfs2: remove set but not used variable 'last_hash'
  (bnc#1012628).
- page flags: prioritize kasan bits over last-cpuid (bnc#1012628).
- asm-generic: fix -Wtype-limits compiler warnings (bnc#1012628).
- arm64: KVM: regmap: Fix unexpected switch fall-through
  (bnc#1012628).
- staging: comedi: dt3000: Fix signed integer overflow 'divider *
  base' (bnc#1012628).
- staging: comedi: dt3000: Fix rounding up of timer divisor
  (bnc#1012628).
- iio: adc: max9611: Fix temperature reading in probe
  (bnc#1012628).
- USB: core: Fix races in character device registration and
  deregistraion (bnc#1012628).
- usb: gadget: udc: renesas_usb3: Fix sysfs interface of "role"
  (bnc#1012628).
- usb: cdc-acm: make sure a refcount is taken early enough
  (bnc#1012628).
- USB: CDC: fix sanity checks in CDC union parser (bnc#1012628).
- USB: serial: option: add D-Link DWM-222 device ID (bnc#1012628).
- USB: serial: option: Add support for ZTE MF871A (bnc#1012628).
- USB: serial: option: add the BroadMobi BM818 card (bnc#1012628).
- USB: serial: option: Add Motorola modem UARTs (bnc#1012628).
- usb: setup authorized_default attributes using usb_bus_notify
  (bnc#1012628).
- netfilter: conntrack: Use consistent ct id hash calculation
  (bnc#1012628).
- Input: psmouse - fix build error of multiple definition
  (bnc#1012628).
- bnx2x: Fix VF's VLAN reconfiguration in reload (bnc#1012628).
- bonding: Add vlan tx offload to hw_enc_features (bnc#1012628).
- net: dsa: Check existence of .port_mdb_add callback before
  calling it (bnc#1012628).
- net/mlx4_en: fix a memory leak bug (bnc#1012628).
- net/packet: fix race in tpacket_snd() (bnc#1012628).
- net: sched: sch_taprio: fix memleak in error path for sched
  list parse (bnc#1012628).
- sctp: fix memleak in sctp_send_reset_streams (bnc#1012628).
- sctp: fix the transport error_count check (bnc#1012628).
- team: Add vlan tx offload to hw_enc_features (bnc#1012628).
- tipc: initialise addr_trail_end when setting node addresses
  (bnc#1012628).
- xen/netback: Reset nr_frags before freeing skb (bnc#1012628).
- net/mlx5e: Only support tx/rx pause setting for port owner
  (bnc#1012628).
- bnxt_en: Fix VNIC clearing logic for 57500 chips (bnc#1012628).
- bnxt_en: Improve RX doorbell sequence (bnc#1012628).
- bnxt_en: Fix handling FRAG_ERR when NVM_INSTALL_UPDATE cmd fails
  (bnc#1012628).
- bnxt_en: Suppress HWRM errors for HWRM_NVM_GET_VARIABLE command
  (bnc#1012628).
- bnxt_en: Use correct src_fid to determine direction of the flow
  (bnc#1012628).
- bnxt_en: Fix to include flow direction in L2 key (bnc#1012628).
- net sched: update skbedit action for batched events operations
  (bnc#1012628).
- tc-testing: updated skbedit action tests with batch
  create/delete (bnc#1012628).
- netdevsim: Restore per-network namespace accounting for fib
  entries (bnc#1012628).
- net/mlx5e: ethtool, Avoid setting speed to 56GBASE when autoneg
  off (bnc#1012628).
- net/mlx5e: Fix false negative indication on tx reporter CQE
  recovery (bnc#1012628).
- net/mlx5e: Remove redundant check in CQE recovery flow of tx
  reporter (bnc#1012628).
- net/mlx5e: Use flow keys dissector to parse packets for ARFS
  (bnc#1012628).
- net/tls: prevent skb_orphan() from leaking TLS plain text with
  offload (bnc#1012628).
- net: phy: consider AN_RESTART status when reading link status
  (bnc#1012628).
- netlink: Fix nlmsg_parse as a wrapper for strict message parsing
  (bnc#1012628).
- Refresh patches.suse/supported-flag.
- commit 5878ee6
* Fri Aug 23 2019 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Fix kernel-livepatch description typo.
- commit 36acf91
* Thu Aug 22 2019 msuchanek@suse.de
- Pull packaging cleanup from mkubecek.
- Parametrize kgraft vs livepatch.
- commit 16f6816
* Thu Aug 22 2019 msuchanek@suse.de
- rpm/config.sh: Enable livepatch.
- commit e001776
* Thu Aug 22 2019 mkubecek@suse.cz
- config: update from SLE15-SP2
  In general, we want features and drivers from SLE also in openSUSE unless
  we have a good reason not to. Enable most config options which were
  disabled in master but enabled in SLE15-SP2 (inherited from SLE15-SP1).
- commit 769684a
* Wed Aug 21 2019 mkubecek@suse.cz
- series.conf: reorganize sections
  With ~40 patches in master branch, we have accumulated way too many
  sections in series.conf, some of them being very specific. While new SLE
  and Leap branches are going to have more patches, vast majority of them is
  going to end up in the sorted section (e.g. less than 1%% of SLE15-SP1
  patches are neither sorted nor stable baskports right now - and that
  includes quite a few which would actually belong into the sorted section
  but are left outside for historical reasons).
  After the reorganization, series.conf is ordered like this:
  - stable backports (patches.kernel.org/*)
  - tweaks applied to vanilla (patches.rpmify/*)
  - sorted section (not in master)
  - unsorted patches expected to get into mainline soon
  - permanent and longterm non-upstream patches
  - kabi hacks (not in master)
  This commit has no effect on expanded tree.
- commit 8ac1895
* Wed Aug 21 2019 mkubecek@suse.cz
- series.conf: cleanup
  Only whitespace and comments, no efect on expanded tree.
- commit bf21808
* Wed Aug 21 2019 tiwai@suse.de
- iwlwifi: Add support for SAR South Korea limitation
  (bsc#1142128).
- commit 0100738
* Mon Aug 19 2019 bp@suse.de
- Update config files.
  As per https://jira.suse.com/browse/SLE-7041
  Factory first!
- commit fc98fd1
* Mon Aug 19 2019 mkubecek@suse.cz
- Update to 5.3-rc5
- Refresh configs
  - RDMA_SIW available on i386 (=m)
  - clean up unavailable options
- commit cadbe00
* Sun Aug 18 2019 afaerber@suse.de
- config: arm64: Enable I2C_IMX (boo#1146026)
  Needed for Google Coral board.
- commit 5057605
* Fri Aug 16 2019 jslaby@suse.cz
- Linux 5.2.9 (bnc#1012628).
- iwlwifi: mvm: fix version check for GEO_TX_POWER_LIMIT support
  (bnc#1012628).
- iwlwifi: mvm: don't send GEO_TX_POWER_LIMIT on version < 41
  (bnc#1012628).
- iwlwifi: mvm: fix a use-after-free bug in iwl_mvm_tx_tso_segment
  (bnc#1012628).
- iwlwifi: mvm: fix an out-of-bound access (bnc#1012628).
- iwlwifi: don't unmap as page memory that was mapped as single
  (bnc#1012628).
- mwifiex: fix 802.11n/WPA detection (bnc#1012628).
- KVM: arm/arm64: Sync ICH_VMCR_EL2 back when about to block
  (bnc#1012628).
- KVM: Fix leak vCPU's VMCS value into other pCPU (bnc#1012628).
- NFSv4: Fix an Oops in nfs4_do_setattr (bnc#1012628).
- NFSv4: Check the return value of update_open_stateid()
  (bnc#1012628).
- NFSv4: Fix delegation state recovery (bnc#1012628).
- smb3: send CAP_DFS capability during session setup
  (bnc#1012628).
- SMB3: Fix deadlock in validate negotiate hits reconnect
  (bnc#1012628).
- dax: dax_layout_busy_page() should not unmap cow pages
  (bnc#1012628).
- mac80211: don't WARN on short WMM parameters from AP
  (bnc#1012628).
- ALSA: hda - Workaround for crackled sound on AMD controller
  (1022:1457) (bnc#1012628).
- ALSA: hda - Don't override global PCM hw info flag
  (bnc#1012628).
- ALSA: hiface: fix multiple memory leak bugs (bnc#1012628).
- ALSA: firewire: fix a memory leak bug (bnc#1012628).
- drm/i915: Fix wrong escape clock divisor init for GLK
  (bnc#1012628).
- hwmon: (lm75) Fixup tmp75b clr_mask (bnc#1012628).
- hwmon: (nct7802) Fix wrong detection of in4 presence
  (bnc#1012628).
- can: peak_usb: pcan_usb_fd: Fix info-leaks to USB devices
  (bnc#1012628).
- can: peak_usb: pcan_usb_pro: Fix info-leaks to USB devices
  (bnc#1012628).
- KVM/nSVM: properly map nested VMCB (bnc#1012628).
- ALSA: usb-audio: fix a memory leak bug (bnc#1012628).
- HID: sony: Fix race condition between rumble and device remove
  (bnc#1012628).
- gen_compile_commands: lower the entry count threshold
  (bnc#1012628).
- s390/dma: provide proper ARCH_ZONE_DMA_BITS value (bnc#1012628).
- perf/core: Fix creating kernel counters for PMUs that override
  event->cpu (bnc#1012628).
- perf/x86: Apply more accurate check on hypervisor platform
  (bnc#1012628).
- perf/x86/intel: Fix invalid Bit 13 for Icelake MSR_OFFCORE_RSP_x
  register (bnc#1012628).
- perf/x86/intel: Fix SLOTS PEBS event constraint (bnc#1012628).
- tty/ldsem, locking/rwsem: Add missing ACQUIRE to read_failed
  sleep loop (bnc#1012628).
- test_firmware: fix a memory leak bug (bnc#1012628).
- scsi: scsi_dh_alua: always use a 2 second delay before retrying
  RTPG (bnc#1012628).
- scsi: ibmvfc: fix WARN_ON during event pool release
  (bnc#1012628).
- scsi: megaraid_sas: fix panic on loading firmware crashdump
  (bnc#1012628).
- ARM: dts: bcm: bcm47094: add missing #cells for mdio-bus-mux
  (bnc#1012628).
- ARM: davinci: fix sleep.S build error on ARMv4 (bnc#1012628).
- nvme: fix memory leak caused by incorrect subsystem free
  (bnc#1012628).
- nvme: ignore subnqn for ADATA SX6000LNP (bnc#1012628).
- ACPI/IORT: Fix off-by-one check in iort_dev_find_its_id()
  (bnc#1012628).
- drbd: dynamically allocate shash descriptor (bnc#1012628).
- perf probe: Avoid calling freeing routine multiple times for
  same pointer (bnc#1012628).
- perf session: Fix loading of compressed data split across
  adjacent records (bnc#1012628).
- perf stat: Fix segfault for event group in repeat mode
  (bnc#1012628).
- perf tools: Fix proper buffer size for feature processing
  (bnc#1012628).
- perf script: Fix off by one in brstackinsn IPC computation
  (bnc#1012628).
- ALSA: compress: Be more restrictive about when a drain is
  allowed (bnc#1012628).
- ALSA: compress: Don't allow paritial drain operations on
  capture streams (bnc#1012628).
- ALSA: compress: Prevent bypasses of set_params (bnc#1012628).
- ALSA: compress: Fix regression on compressed capture streams
  (bnc#1012628).
- s390/qdio: add sanity checks to the fast-requeue path
  (bnc#1012628).
- cpufreq/pasemi: fix use-after-free in pas_cpufreq_cpu_init()
  (bnc#1012628).
- arm64: dts: imx8mq: fix SAI compatible (bnc#1012628).
- arm64: dts: imx8mm: Correct SAI3 RXC/TXFS pin's mux option #1
  (bnc#1012628).
- drm: silence variable 'conn' set but not used (bnc#1012628).
- drm/msm/dpu: Correct dpu encoder spinlock initialization
  (bnc#1012628).
- iommu/vt-d: Check if domain->pgd was allocated (bnc#1012628).
- arm64: entry: SP Alignment Fault doesn't write to FAR_EL1
  (bnc#1012628).
- arm64: Force SSBS on context switch (bnc#1012628).
- powerpc/papr_scm: Force a scm-unbind if initial scm-bind fails
  (bnc#1012628).
- ARM: dts: imx6ul: fix clock frequency property name of I2C buses
  (bnc#1012628).
- hwmon: (nct6775) Fix register address and added missed tolerance
  for nct6106 (bnc#1012628).
- hwmon: (occ) Fix division by zero issue (bnc#1012628).
- allocate_flower_entry: should check for null deref
  (bnc#1012628).
- mac80211: don't warn about CW params when not using them
  (bnc#1012628).
- mac80211: fix possible memory leak in ieee80211_assign_beacon
  (bnc#1012628).
- nl80211: fix NL80211_HE_MAX_CAPABILITY_LEN (bnc#1012628).
- iscsi_ibft: make ISCSI_IBFT dependson ACPI instead of
  ISCSI_IBFT_FIND (bnc#1012628).
- Update config files.
  Set CONFIG_ISCSI_IBFT=m.
- drm/amd/display: Increase size of audios array (bnc#1012628).
- drm/amd/display: Only enable audio if speaker allocation exists
  (bnc#1012628).
- drm/amd/display: Fix dc_create failure handling and 666 color
  depths (bnc#1012628).
- drm/amd/display: allocate 4 ddc engines for RV2 (bnc#1012628).
- drm/amd/display: put back front end initialization sequence
  (bnc#1012628).
- drm/amd/display: use encoder's engine id to find matched free
  audio device (bnc#1012628).
- drm/amd/display: fix DMCU hang when going into Modern Standby
  (bnc#1012628).
- drm/amd/display: Wait for backlight programming completion in
  set backlight level (bnc#1012628).
- drm/amd/display: Clock does not lower in Updateplanes
  (bnc#1012628).
- drm/amd/display: No audio endpoint for Dell MST display
  (bnc#1012628).
- netfilter: nf_tables: Support auto-loading for inet nat
  (bnc#1012628).
- rq-qos: use a mb for got_token (bnc#1012628).
- rq-qos: set ourself TASK_UNINTERRUPTIBLE after we schedule
  (bnc#1012628).
- rq-qos: don't reset has_sleepers on spurious wakeups
  (bnc#1012628).
- scripts/sphinx-pre-install: fix latexmk dependencies
  (bnc#1012628).
- scripts/sphinx-pre-install: don't use LaTeX with CentOS 7
  (bnc#1012628).
- scripts/sphinx-pre-install: fix script for RHEL/CentOS
  (bnc#1012628).
- netfilter: nft_hash: fix symhash with modulus one (bnc#1012628).
- netfilter: conntrack: always store window size un-scaled
  (bnc#1012628).
- netfilter: nf_tables: fix module autoload for redir
  (bnc#1012628).
- netfilter: Fix rpfilter dropping vrf packets by mistake
  (bnc#1012628).
- vfio-ccw: Don't call cp_free if we are processing a channel
  program (bnc#1012628).
- vfio-ccw: Set pa_nr to 0 if memory allocation fails for
  pa_iova_pfn (bnc#1012628).
- netfilter: nfnetlink: avoid deadlock due to synchronous
  request_module (bnc#1012628).
- powerpc: fix off by one in max_zone_pfn initialization for
  ZONE_DMA (bnc#1012628).
- can: peak_usb: fix potential double kfree_skb() (bnc#1012628).
- can: flexcan: fix an use-after-free in flexcan_setup_stop_mode()
  (bnc#1012628).
- can: flexcan: fix stop mode acknowledgment (bnc#1012628).
- can: rcar_canfd: fix possible IRQ storm on high load
  (bnc#1012628).
- usb: typec: tcpm: Ignore unsupported/unknown alternate mode
  requests (bnc#1012628).
- usb: typec: tcpm: Add NULL check before dereferencing config
  (bnc#1012628).
- usb: typec: tcpm: remove tcpm dir if no children (bnc#1012628).
- usb: typec: tcpm: free log buf memory when remove debug file
  (bnc#1012628).
- usb: typec: ucsi: ccg: Fix uninitilized symbol error
  (bnc#1012628).
- usb: yurex: Fix use-after-free in yurex_delete (bnc#1012628).
- usb: host: xhci-rcar: Fix timeout in xhci_suspend()
  (bnc#1012628).
- gfs2: gfs2_walk_metadata fix (bnc#1012628).
- genirq/affinity: Create affinity mask for single vector
  (bnc#1012628).
- x86/purgatory: Use CFLAGS_REMOVE rather than reset KBUILD_CFLAGS
  (bnc#1012628).
- x86/purgatory: Do not use __builtin_memcpy and __builtin_memset
  (bnc#1012628).
- perf record: Fix module size on s390 (bnc#1012628).
- perf db-export: Fix thread__exec_comm() (bnc#1012628).
- perf annotate: Fix s390 gap between kernel end and module start
  (bnc#1012628).
- coresight: Fix DEBUG_LOCKS_WARN_ON for uninitialized attribute
  (bnc#1012628).
- mm/vmalloc: Sync unmappings in __purge_vmap_area_lazy()
  (bnc#1012628).
- x86/mm: Sync also unmappings in vmalloc_sync_all()
  (bnc#1012628).
- x86/mm: Check for pfn instead of page in vmalloc_sync_one()
  (bnc#1012628).
- Input: synaptics - enable RMI mode for HP Spectre X360
  (bnc#1012628).
- Input: elantech - enable SMBus on new (2018+) systems
  (bnc#1012628).
- Input: usbtouchscreen - initialize PM mutex before using it
  (bnc#1012628).
- bdev: Fixup error handling in blkdev_get() (bnc#1012628).
- loop: set PF_MEMALLOC_NOIO for the worker thread (bnc#1012628).
- mmc: cavium: Add the missing dma unmap when the dma has finished
  (bnc#1012628).
- mmc: cavium: Set the correct dma max segment size for mmc_host
  (bnc#1012628).
- sound: fix a memory leak bug (bnc#1012628).
- usb: iowarrior: fix deadlock on disconnect (bnc#1012628).
- Revert "USB: rio500: simplify locking" (bnc#1012628).
- usb: usbfs: fix double-free of usb memory upon submiturb error
  (bnc#1012628).
- driver core: platform: return -ENXIO for missing GpioInt
  (bnc#1012628).
- crypto: ccp - Ignore tag length when decrypting GCM ciphertext
  (bnc#1012628).
- crypto: ccp - Add support for valid authsize values less than 16
  (bnc#1012628).
- crypto: ccp - Fix oops by properly managing allocated structures
  (bnc#1012628).
- Staging: fbtft: Fix reset assertion when using gpio descriptor
  (bnc#1012628).
- Staging: fbtft: Fix probing of gpio descriptor (bnc#1012628).
- staging: android: ion: Bail out upon SIGKILL when allocating
  memory (bnc#1012628).
- staging: wilc1000: flush the workqueue before deinit the host
  (bnc#1012628).
- staging: gasket: apex: fix copy-paste typo (bnc#1012628).
- iio: adc: max9611: Fix misuse of GENMASK macro (bnc#1012628).
- iio: adc: gyroadc: fix uninitialized return code (bnc#1012628).
- iio: imu: mpu6050: add missing available scan masks
  (bnc#1012628).
- iio: cros_ec_accel_legacy: Fix incorrect channel setting
  (bnc#1012628).
- IIO: Ingenic JZ47xx: Set clock divider on probe (bnc#1012628).
- Revert "PCI: Add missing link delays required by the PCIe spec"
  (bnc#1012628).
- commit 80c0ffe
* Thu Aug 15 2019 msuchanek@suse.de
- Revert "Workaround gcc regression on ppc64 (bko#204125)."
  This reverts commit 8b84d1d46ff90146bb6ba5b760a54ddd87a1a680.
  Works for me 5.3-rc4-65-g329120423947
- commit d8f9e6c
* Tue Aug 13 2019 vbabka@suse.cz
- x86/kconfig: Remove X86_DIRECT_GBPAGES dependency on
  !DEBUG_PAGEALLOC (PM-1168, bsc#1144653, VM Debug Functionality).
  [js] update upstream status
- commit 1183125
* Mon Aug 12 2019 msuchanek@suse.de
- config.conf: syms should not depend on kernel-zfcpdump
  Kernel-zfcpdump is not modular so kernel-zfcpdump-devel does not make
  sense and is not built. kernel-syms cannot depend on it.
- commit 516192f
* Mon Aug 12 2019 msuchanek@suse.de
- rpm/mkspec: Correct tarball URL for rc kernels.
- commit c4ef18d
* Mon Aug 12 2019 jslaby@suse.cz
- x86/apic: Handle missing global clockevent gracefully
  (bnc#1142926).
- commit a44175e
* Sun Aug 11 2019 mkubecek@suse.cz
- Update to 5.3-rc4
- Refresh
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
- commit 5402233
* Fri Aug  9 2019 jslaby@suse.cz
- Linux 5.2.8 (bnc#1012628).
- scsi: fcoe: Embed fc_rport_priv in fcoe_rport structure
  (bnc#1012628).
- libnvdimm/bus: Prepare the nd_ioctl() path to be re-entrant
  (bnc#1012628).
- libnvdimm/bus: Fix wait_nvdimm_bus_probe_idle() ABBA deadlock
  (bnc#1012628).
- ALSA: usb-audio: Sanity checks for each pipe and EP types
  (bnc#1012628).
- ALSA: usb-audio: Fix gpf in snd_usb_pipe_sanity_check
  (bnc#1012628).
- HID: wacom: fix bit shift for Cintiq Companion 2 (bnc#1012628).
- HID: Add quirk for HP X1200 PIXART OEM mouse (bnc#1012628).
- atm: iphase: Fix Spectre v1 vulnerability (bnc#1012628).
- bnx2x: Disable multi-cos feature (bnc#1012628).
- drivers/net/ethernet/marvell/mvmdio.c: Fix non OF case
  (bnc#1012628).
- ife: error out when nla attributes are empty (bnc#1012628).
- ip6_gre: reload ipv6h in prepare_ip6gre_xmit_ipv6 (bnc#1012628).
- ip6_tunnel: fix possible use-after-free on xmit (bnc#1012628).
- ipip: validate header length in ipip_tunnel_xmit (bnc#1012628).
- mlxsw: spectrum: Fix error path in mlxsw_sp_module_init()
  (bnc#1012628).
- mvpp2: fix panic on module removal (bnc#1012628).
- mvpp2: refactor MTU change code (bnc#1012628).
- net: bridge: delete local fdb on device init failure
  (bnc#1012628).
- net: bridge: mcast: don't delete permanent entries when fast
  leave is enabled (bnc#1012628).
- net: bridge: move default pvid init/deinit to
  NETDEV_REGISTER/UNREGISTER (bnc#1012628).
- net: fix ifindex collision during namespace removal
  (bnc#1012628).
- net/mlx5e: always initialize frag->last_in_page (bnc#1012628).
- net/mlx5: Use reversed order when unregister devices
  (bnc#1012628).
- net: phy: fixed_phy: print gpio error only if gpio node is
  present (bnc#1012628).
- net: phylink: don't start and stop SGMII PHYs in SFP modules
  twice (bnc#1012628).
- net: phylink: Fix flow control for fixed-link (bnc#1012628).
- net: phy: mscc: initialize stats array (bnc#1012628).
- net: qualcomm: rmnet: Fix incorrect UL checksum offload logic
  (bnc#1012628).
- net: sched: Fix a possible null-pointer dereference in
  dequeue_func() (bnc#1012628).
- net sched: update vlan action for batched events operations
  (bnc#1012628).
- net: sched: use temporary variable for actions indexes
  (bnc#1012628).
- net/smc: do not schedule tx_work in SMC_CLOSED state
  (bnc#1012628).
- net: stmmac: Use netif_tx_napi_add() for TX polling function
  (bnc#1012628).
- NFC: nfcmrvl: fix gpio-handling regression (bnc#1012628).
- ocelot: Cancel delayed work before wq destruction (bnc#1012628).
- tipc: compat: allow tipc commands without arguments
  (bnc#1012628).
- tipc: fix unitilized skb list crash (bnc#1012628).
- tun: mark small packets as owned by the tap sock (bnc#1012628).
- net/mlx5: Fix modify_cq_in alignment (bnc#1012628).
- net/mlx5e: Prevent encap flow counter update async to user query
  (bnc#1012628).
- r8169: don't use MSI before RTL8168d (bnc#1012628).
- bpf: fix XDP vlan selftests test_xdp_vlan.sh (bnc#1012628).
- selftests/bpf: add wrapper scripts for test_xdp_vlan.sh
  (bnc#1012628).
- selftests/bpf: reduce time to execute test_xdp_vlan.sh
  (bnc#1012628).
- net: fix bpf_xdp_adjust_head regression for generic-XDP
  (bnc#1012628).
- hv_sock: Fix hang when a connection is closed (bnc#1012628).
- net: phy: fix race in genphy_update_link (bnc#1012628).
- net/smc: avoid fallback in case of non-blocking connect
  (bnc#1012628).
- rocker: fix memory leaks of fib_work on two error return paths
  (bnc#1012628).
- mlxsw: spectrum_buffers: Further reduce pool size on Spectrum-2
  (bnc#1012628).
- net/mlx5: Add missing RDMA_RX capabilities (bnc#1012628).
- net/mlx5e: Fix matching of speed to PRM link modes
  (bnc#1012628).
- compat_ioctl: pppoe: fix PPPOEIOCSFWD handling (bnc#1012628).
- Revert "mac80211: set NETIF_F_LLTX when using intermediate tx
  queues" (bnc#1012628).
- spi: bcm2835: Fix 3-wire mode if DMA is enabled (bnc#1012628).
- commit bf37e83
* Fri Aug  9 2019 msuchanek@suse.de
- rpm/config.sh: Enable building DTBs.
- commit 533dae1
* Fri Aug  9 2019 msuchanek@suse.de
- rpm/mkspec: Make building DTBs optional.
- commit 7c057c8
* Fri Aug  9 2019 mkubecek@suse.cz
- supported.conf: fix supported modules depending on unsupported on non-x86_64 architectures
  Some more "unsupported module needed by supported one" errors were reported
  on aarch64 and ppc64le.
- commit 6b609de
* Fri Aug  9 2019 mkubecek@suse.cz
- supported.conf: drop obsolete entry for hyperv_fb
  The module moved to a different directory, the obsolete entry causes
  file conflict betwen kernel-default and kernel-default-extra.
- commit 6b112e5
* Fri Aug  9 2019 msuchanek@suse.de
- rpm/modflist: Simplify compression support.
- commit fd135a6
* Fri Aug  9 2019 mkubecek@suse.cz
- supported.conf: close with respect to dependencies
  Modules which some supported module depends on must be supported as well.
  Also drop obsolete entries for rtsx_pci and rtsx_usb which were moved
  between 4.12 and 5.3.
- commit b781c36
* Fri Aug  9 2019 mkubecek@suse.cz
- rpm: support compressed modules
  Some of our scripts and scriptlets in rpm/ do not expect module files not
  ending with ".ko" which currently leads to failure in preuninstall
  scriptlet of cluster-md-kmp-default (and probably also other subpackages).
  Let those which could be run on compressed module files recognize ".ko.xz"
  in addition to ".ko".
- commit 18fcdff
* Fri Aug  9 2019 msuchanek@suse.de
- Bring back MODVERDIR to Makefile.modpost (bsc#1066369).
- commit 6cc69f5
* Fri Aug  9 2019 mkubecek@suse.cz
- supported.conf: sort again
  Make the order compatible with scripts/supported-conf-fixup (LC_ALL=C).
- commit 4a4b5dd
* Fri Aug  9 2019 msuchanek@suse.de
- supported.conf: Sort alphabetically, align comments.
- commit 5189766
* Fri Aug  9 2019 mkubecek@suse.cz
- supported.conf: drop extensions
  To make things more consistent, drop all ".ko" extensions.
- commit 398461b
* Fri Aug  9 2019 mkubecek@suse.cz
- Update patches.suse/supported-flag.
  Fix ReST table.
- commit 0692bf4
* Thu Aug  8 2019 msuchanek@suse.de
- Use upstream TAINT_AUX for TAINT_EXTERNAL_SUPPORT.
  Refresh patches.suse/supported-flag.
- commit a4999e0
* Thu Aug  8 2019 jslaby@suse.cz
- Use the upstream patch.
  (Including the tags.)
- commit 5dd5b2d
* Thu Aug  8 2019 jslaby@suse.cz
- s390: enable detection of kernel version from bzImage
  (bnc#1139939).
- commit 8434c05
* Thu Aug  8 2019 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: add dm-crypt for building with cryptsetup
  Co-Authored-By: Adam Spiers <aspiers@suse.com>
- commit 7cf5b9e
* Thu Aug  8 2019 mkubecek@suse.cz
- supported.conf: add missing entries for all architectures
  As list of built modules depends on architecture, we must also add entries
  for modules which are not built (or do not even exist) on x86_64 but are
  built on other architectures (aarch64, ppc64le, s390x).
- commit 8f74082
* Thu Aug  8 2019 mkubecek@suse.cz
- supported.conf: add missing entries
  Add all modules currently built but not listed in supported.conf.
  Another update will be necessary once we replace configs inherited from
  master with true SLE15-SP2 configs. This is also why entries for modules
  not built are left in the file for now.
- commit 0f5033c
* Thu Aug  8 2019 mkubecek@suse.cz
- supported.conf: sort
  Also remove one commented out line.
- commit b539157
* Thu Aug  8 2019 mkubecek@suse.cz
- supported.conf: cleanup
  Remove duplicate and shadowed entries.
- commit 25e91ec
* Thu Aug  8 2019 mkubecek@suse.cz
- supported.conf: update from SLE15-SP1
  Differences from current SLE15-SP1 supported.conf:
  - f71808e_wdt and it87_wdt supported (jdelvare)
  - bpfilter marked +base (tiwai, bsc#1106751)
  - unified indentation
- commit 02162e4
* Wed Aug  7 2019 tiwai@suse.de
- drm/i915/vbt: Fix VBT parsing for the PSR section (bsc#1143139).
- commit 0bef772
* Wed Aug  7 2019 msuchanek@suse.de
- rpm/kernel-binary.spec.in: support partial rt debug config.
- commit af37821
* Wed Aug  7 2019 afaerber@suse.de
- config: arm64: Update to 5.3-rc3
- commit f1f49f3
* Wed Aug  7 2019 afaerber@suse.de
- config: Enable SENSORS_GPIO_FAN for all of Arm (boo#1144723)
  We already had it for armv6hl but were lacking it on arm64.
  Add it on armv7hl for consistency while at it.
  (cherry picked from commit 607ebebd5af841d77de8908dbc8abb1fd7cdda4f)
- config: Enable SENSORS_GPIO_FAN for all of Arm (boo#1144723)
  We already had it for armv6hl but were lacking it on arm64.
  Add it on armv7hl for consistency while at it.
- commit 71d4424
* Tue Aug  6 2019 jslaby@suse.cz
- Linux 5.2.7 (bnc#1012628).
- Documentation: Add swapgs description to the Spectre v1
  documentation (bnc#1012628).
- x86/speculation/swapgs: Exclude ATOMs from speculation through
  SWAPGS (bnc#1012628).
- x86/entry/64: Use JMP instead of JMPQ (bnc#1012628).
- x86/speculation: Enable Spectre v1 swapgs mitigations
  (bnc#1012628).
- x86/speculation: Prepare entry code for Spectre v1 swapgs
  mitigations (bnc#1012628).
- x86/cpufeatures: Combine word 11 and 12 into a new scattered
  features word (bnc#1012628).
- x86/cpufeatures: Carve out CQM features retrieval (bnc#1012628).
- drm/i915/gvt: fix incorrect cache entry for guest page mapping
  (bnc#1012628).
- drm/i915/perf: fix ICL perf register offsets (bnc#1012628).
- IB/hfi1: Field not zero-ed when allocating TID flow memory
  (bnc#1012628).
- IB/hfi1: Drop all TID RDMA READ RESP packets after r_next_psn
  (bnc#1012628).
- IB/hfi1: Check for error on call to alloc_rsm_map_table
  (bnc#1012628).
- IB/mlx5: Fix RSS Toeplitz setup to be aligned with the HW
  specification (bnc#1012628).
- IB/mlx5: Fix clean_mr() to work in the expected order
  (bnc#1012628).
- IB/mlx5: Move MRs to a kernel PD when freeing them to the MR
  cache (bnc#1012628).
- IB/mlx5: Use direct mkey destroy command upon UMR unreg failure
  (bnc#1012628).
- IB/mlx5: Fix unreg_umr to ignore the mkey state (bnc#1012628).
- RDMA/devices: Do not deadlock during client removal
  (bnc#1012628).
- RDMA/bnxt_re: Honor vlan_id in GID entry comparison
  (bnc#1012628).
- xen/gntdev.c: Replace vm_map_pages() with vm_map_pages_zero()
  (bnc#1012628).
- xen/swiotlb: fix condition for calling
  xen_destroy_contiguous_region() (bnc#1012628).
- nbd: replace kill_bdev() with __invalidate_device() again
  (bnc#1012628).
- scsi: mpt3sas: Use 63-bit DMA addressing on SAS35 HBA
  (bnc#1012628).
- clk: mediatek: mt8183: Register 13MHz clock earlier for
  clocksource (bnc#1012628).
- io_uring: fix KASAN use after free in io_sq_wq_submit_work
  (bnc#1012628).
- arm64: cpufeature: Fix feature comparison for CTR_EL0.{CWG,ERG}
  (bnc#1012628).
- arm64: compat: Allow single-byte watchpoints on all addresses
  (bnc#1012628).
- drivers/perf: arm_pmu: Fix failure path in PM notifier
  (bnc#1012628).
- parisc: Fix build of compressed kernel even with debug enabled
  (bnc#1012628).
- parisc: Strip debug info from kernel before creating compressed
  vmlinuz (bnc#1012628).
- parisc: Add archclean Makefile target (bnc#1012628).
- cgroup: kselftest: relax fs_spec checks (bnc#1012628).
- s390/dasd: fix endless loop after read unit address
  configuration (bnc#1012628).
- loop: Fix mount(2) failure due to race with LOOP_SET_FD
  (bnc#1012628).
- mm/migrate.c: initialize pud_entry in migrate_vma()
  (bnc#1012628).
- ubsan: build ubsan.c more conservatively (bnc#1012628).
- mm: compaction: avoid 100%% CPU usage during compaction when
  a task is killed (bnc#1012628).
- mm: migrate: fix reference check race between __find_get_block()
  and migration (bnc#1012628).
- mm: vmscan: check if mem cgroup is disabled or not before
  calling memcg slab shrinker (bnc#1012628).
- ALSA: hda: Fix 1-minute detection delay when i915 module is
  not available (bnc#1012628).
- selinux: fix memory leak in policydb_init() (bnc#1012628).
- powerpc/kasan: fix early boot failure on PPC32 (bnc#1012628).
- i2c: at91: fix clk_offset for sama5d2 (bnc#1012628).
- i2c: at91: disable TXRDY interrupt after sending data
  (bnc#1012628).
- i2c: iproc: Fix i2c master read more than 63 bytes
  (bnc#1012628).
- eeprom: at24: make spd world-readable again (bnc#1012628).
- mtd: rawnand: micron: handle on-die "ECC-off" devices correctly
  (bnc#1012628).
- drm/nouveau: Only release VCPI slots on mode changes
  (bnc#1012628).
- IB/hfi1: Fix Spectre v1 vulnerability (bnc#1012628).
- gpiolib: fix incorrect IRQ requesting of an active-low lineevent
  (bnc#1012628).
- gpio: don't WARN() on NULL descs if gpiolib is disabled
  (bnc#1012628).
- gpiolib: Preserve desc->flags when setting state (bnc#1012628).
- mmc: mmc_spi: Enable stable writes (bnc#1012628).
- mmc: host: sdhci-sprd: Fix the missing pm_runtime_put_noidle()
  (bnc#1012628).
- mmc: meson-mx-sdio: Fix misuse of GENMASK macro (bnc#1012628).
- mmc: dw_mmc: Fix occasional hang after tuning on eMMC
  (bnc#1012628).
- fgraph: Remove redundant ftrace_graph_notrace_addr() test
  (bnc#1012628).
- dax: Fix missed wakeup in put_unlocked_entry() (bnc#1012628).
- Btrfs: fix race leading to fs corruption after transaction abort
  (bnc#1012628).
- Btrfs: fix incremental send failure after deduplication
  (bnc#1012628).
- tpm: Fix null pointer dereference on chip register error path
  (bnc#1012628).
- kbuild: modpost: include .*.cmd files only when targets exist
  (bnc#1012628).
- kbuild: initialize CLANG_FLAGS correctly in the top Makefile
  (bnc#1012628).
- kconfig: Clear "written" flag to avoid data loss (bnc#1012628).
- drm/nouveau/dmem: missing mutex_lock in error path
  (bnc#1012628).
- drm/nouveau: fix memory leak in nouveau_conn_reset()
  (bnc#1012628).
- bpf: Disable GCC -fgcse optimization for ___bpf_prog_run()
  (bnc#1012628).
- x86, boot: Remove multiple copy of static function
  sanitize_boot_params() (bnc#1012628).
- x86/paravirt: Fix callee-saved function ELF sizes (bnc#1012628).
- x86/kvm: Don't call kvm_spurious_fault() from .fixup
  (bnc#1012628).
- xen/pv: Fix a boot up hang revealed by int3 self test
  (bnc#1012628).
- crypto: ccp - Fix SEV_VERSION_GREATER_OR_EQUAL (bnc#1012628).
- stacktrace: Force USER_DS for stack_trace_save_user()
  (bnc#1012628).
- mm/hotplug: make remove_memory() interface usable (bnc#1012628).
- device-dax: fix memory and resource leak if hotplug fails
  (bnc#1012628).
- nds32: fix asm/syscall.h (bnc#1012628).
- ipc/mqueue.c: only perform resource calculation if user valid
  (bnc#1012628).
- drivers/rapidio/devices/rio_mport_cdev.c: NUL terminate some
  strings (bnc#1012628).
- uapi linux/coda_psdev.h: move upc_req definition from uapi to
  kernel side headers (bnc#1012628).
- coda: fix build using bare-metal toolchain (bnc#1012628).
- coda: add error handling for fget (bnc#1012628).
- mm/ioremap: check virtual address alignment while creating
  huge mappings (bnc#1012628).
- lib/test_string.c: avoid masking memset16/32/64 failures
  (bnc#1012628).
- lib/test_overflow.c: avoid tainting the kernel and fix wrap size
  (bnc#1012628).
- mm/cma.c: fail if fixed declaration can't be honored
  (bnc#1012628).
- x86: math-emu: Hide clang warnings for 16-bit overflow
  (bnc#1012628).
- x86/apic: Silence -Wtype-limits compiler warnings (bnc#1012628).
- mm/z3fold.c: reinitialize zhdr structs after migration
  (bnc#1012628).
- mm/memcontrol.c: keep local VM counters in sync with the
  hierarchical ones (bnc#1012628).
- mm/slab_common.c: work around clang bug #42570 (bnc#1012628).
- mm/z3fold: don't try to use buddy slots after free
  (bnc#1012628).
- be2net: Signal that the device cannot transmit during
  reconfiguration (bnc#1012628).
- bpf: fix BTF verifier size resolution logic (bnc#1012628).
- KVM: nVMX: Ignore segment base for VMX memory operand when
  segment not FS or GS (bnc#1012628).
- ACPI: fix false-positive -Wuninitialized warning (bnc#1012628).
- x86: kvm: avoid constant-conversion warning (bnc#1012628).
- perf version: Fix segfault due to missing OPT_END()
  (bnc#1012628).
- cifs: fix crash in cifs_dfs_do_automount (bnc#1012628).
- drm/amd/display: Expose audio inst from DC to DM (bnc#1012628).
- selftests/bpf: do not ignore clang failures (bnc#1012628).
- scsi: zfcp: fix GCC compiler warning emitted with
  - Wmaybe-uninitialized (bnc#1012628).
- ACPI: blacklist: fix clang warning for unused DMI table
  (bnc#1012628).
- virtio-mmio: add error check for platform_get_irq (bnc#1012628).
- ceph: return -ERANGE if virtual xattr value didn't fit in buffer
  (bnc#1012628).
- ceph: fix dir_lease_is_valid() (bnc#1012628).
- ceph: fix improper use of smp_mb__before_atomic() (bnc#1012628).
- cifs: Fix a race condition with cifs_echo_request (bnc#1012628).
- btrfs: qgroup: Don't hold qgroup_ioctl_lock in
  btrfs_qgroup_inherit() (bnc#1012628).
- remoteproc: copy parent dma_pfn_offset for vdev (bnc#1012628).
- btrfs: Flush before reflinking any extent to prevent NOCOW write
  falling back to COW without data reservation (bnc#1012628).
- btrfs: fix minimum number of chunk errors for DUP (bnc#1012628).
- btrfs: tree-checker: Check if the file extent end overflows
  (bnc#1012628).
- arm64: dts: rockchip: Fix USB3 Type-C on rk3399-sapphire
  (bnc#1012628).
- clk: sprd: Add check for return value of sprd_clk_regmap_init()
  (bnc#1012628).
- fs/adfs: super: fix use-after-free bug (bnc#1012628).
- clk: tegra210: fix PLLU and PLLU_OUT1 (bnc#1012628).
- ARM: exynos: Only build MCPM support if used (bnc#1012628).
- Update config files.
- dmaengine: rcar-dmac: Reject zero-length slave DMA requests
  (bnc#1012628).
- MIPS: lantiq: Fix bitfield masking (bnc#1012628).
- swiotlb: fix phys_addr_t overflow warning (bnc#1012628).
- arm64: qcom: qcs404: Add reset-cells to GCC node (bnc#1012628).
- soc: imx8: Fix potential kernel dump in error path
  (bnc#1012628).
- firmware/psci: psci_checker: Park kthreads before stopping them
  (bnc#1012628).
- PCI: OF: Initialize dev->fwnode appropriately (bnc#1012628).
- kernel/module.c: Only return -EEXIST for modules that have
  finished loading (bnc#1012628).
- arm64: dts: rockchip: fix isp iommu clocks and power domain
  (bnc#1012628).
- dmaengine: tegra-apb: Error out if DMA_PREP_INTERRUPT flag is
  unset (bnc#1012628).
- soc: imx: soc-imx8: Correct return value of error handle
  (bnc#1012628).
- arm64: dts: marvell: mcbin: enlarge PCI memory window
  (bnc#1012628).
- soc: qcom: rpmpd: fixup rpmpd set performance state
  (bnc#1012628).
- arm64: dts: qcom: qcs404-evb: fix l3 min voltage (bnc#1012628).
- ftrace: Enable trampoline when rec count returns back to one
  (bnc#1012628).
- ARM: dts: rockchip: Mark that the rk3288 timer might stop in
  suspend (bnc#1012628).
- clk: meson: mpll: properly handle spread spectrum (bnc#1012628).
- ARM: dts: rockchip: Make rk3288-veyron-mickey's emmc work again
  (bnc#1012628).
- ARM: dts: rockchip: Make rk3288-veyron-minnie run at hs200
  (bnc#1012628).
- ARM: riscpc: fix DMA (bnc#1012628).
- commit a3e04b1
* Mon Aug  5 2019 mkubecek@suse.cz
- Update to 5.3-rc3
- Eliminated 1 patch
- Refresh
  - patches.suse/supported-flag
  - patches.suse/supported-flag-external
- Refresh configs
- commit 571863b
* Sun Aug  4 2019 jslaby@suse.cz
- Linux 5.2.6 (bnc#1012628).
- vsock: correct removal of socket from the list (bnc#1012628).
- ISDN: hfcsusb: checking idx of ep configuration (bnc#1012628).
- bpf: fix NULL deref in btf_type_is_resolve_source_only
  (bnc#1012628).
- media: au0828: fix null dereference in error path (bnc#1012628).
- ath10k: Change the warning message string (bnc#1012628).
- media: cpia2_usb: first wake up, then free in disconnect
  (bnc#1012628).
- media: pvrusb2: use a different format for warnings
  (bnc#1012628).
- NFS: Cleanup if nfs_match_client is interrupted (bnc#1012628).
- media: radio-raremono: change devm_k*alloc to k*alloc
  (bnc#1012628).
- xfrm: policy: fix bydst hlist corruption on hash rebuild
  (bnc#1012628).
- nvme: fix multipath crash when ANA is deactivated (bnc#1012628).
- sched/fair: Don't free p->numa_faults with concurrent readers
  (bnc#1012628).
- sched/fair: Use RCU accessors consistently for ->numa_group
  (bnc#1012628).
- /proc/<pid>/cmdline: remove all the special cases (bnc#1012628).
- /proc/<pid>/cmdline: add back the setproctitle() special case
  (bnc#1012628).
- drivers/pps/pps.c: clear offset flags in PPS_SETPARAMS ioctl
  (bnc#1012628).
- Fix allyesconfig output (bnc#1012628).
- ceph: hold i_ceph_lock when removing caps for freeing inode
  (bnc#1012628).
- commit 187170c
* Fri Aug  2 2019 bwiedemann@suse.de
- kernel-binary: Drop .kernel-binary.spec.buildenv (boo#1154578).
  Without this patch,
  /usr/src/linux-@VERSION@-@RELEASE_SHORT@-obj/x86_64/vanilla/.kernel-binary.spec.buildenv
  contained rpm %%_smp_mflags in a line like
  export MAKE_ARGS=" --output-sync -j4"
  This made it hard to produce bit-identical builds.
- commit 789d131
* Thu Aug  1 2019 mkubecek@suse.cz
- config: refresh x86_64/default
  With HBMC_AM654 disabled, nothing selects MULTIPLEXER any more.
- commit 07a1a73
* Wed Jul 31 2019 acho@suse.com
- driver core: Fix use-after-free and double free on glue
  directory (bsc#1131281).
- Bluetooth: hci_uart: check for missing tty operations
  (CVE-2019-10207 bsc#1142857 bsc#1123959).
- commit 79b6a9c
* Wed Jul 31 2019 jslaby@suse.cz
- Update config files: ARCH_HAS_DMA_MMAP_PGPROT is now selected
- commit 0a5eef3
* Wed Jul 31 2019 jslaby@suse.cz
- Linux 5.2.5 (bnc#1012628).
- io_uring: don't use iov_iter_advance() for fixed buffers
  (bnc#1012628).
- io_uring: fix counter inc/dec mismatch in async_list
  (bnc#1012628).
- io_uring: ensure ->list is initialized for poll commands
  (bnc#1012628).
- io_uring: add a memory barrier before atomic_read (bnc#1012628).
- access: avoid the RCU grace period for the temporary subjective
  credentials (bnc#1012628).
- drm/i915: Make the semaphore saturation mask global
  (bnc#1012628).
- structleak: disable STRUCTLEAK_BYREF in combination with
  KASAN_STACK (bnc#1012628).
- libnvdimm/bus: Stop holding nvdimm_bus_list_mutex over
  __nd_ioctl() (bnc#1012628).
- libnvdimm/region: Register badblocks before namespaces
  (bnc#1012628).
- libnvdimm/bus: Prevent duplicate device_unregister() calls
  (bnc#1012628).
- drivers/base: Introduce kill_device() (bnc#1012628).
- iommu/iova: Fix compilation error with !CONFIG_IOMMU_IOVA
  (bnc#1012628).
- iommu/iova: Remove stale cached32_node (bnc#1012628).
- iommu/vt-d: Don't queue_iova() if there is no flush queue
  (bnc#1012628).
- io_uring: fix the sequence comparison in io_sequence_defer
  (bnc#1012628).
- powerpc/pmu: Set pmcregs_in_use in paca when running as LPAR
  (bnc#1012628).
- powerpc/tm: Fix oops on sigreturn on systems without TM
  (bnc#1012628).
- powerpc/mm: Limit rma_size to 1TB when running without HV mode
  (bnc#1012628).
- powerpc/xive: Fix loop exit-condition in
  xive_find_target_in_mask() (bnc#1012628).
- powerpc/dma: Fix invalid DMA mmap behavior (bnc#1012628).
- ALSA: hda - Add a conexant codec entry to let mute led work
  (bnc#1012628).
- ALSA: hda - Fix intermittent CORB/RIRB stall on Intel chips
  (bnc#1012628).
- ALSA: pcm: Fix refcount_inc() on zero usage (bnc#1012628).
- ALSA: line6: Fix wrong altsetting for LINE6_PODHD500_1
  (bnc#1012628).
- ALSA: ac97: Fix double free of ac97_codec_device (bnc#1012628).
- drm/panel: Add support for Armadeus ST0700 Adapt (bnc#1012628).
- hpet: Fix division by zero in hpet_time_div() (bnc#1012628).
- eeprom: make older eeprom drivers select NVMEM_SYSFS
  (bnc#1012628).
- mei: me: add mule creek canyon (EHL) device ids (bnc#1012628).
- fpga-manager: altera-ps-spi: Fix build error (bnc#1012628).
- binder: prevent transactions to context manager from its own
  process (bnc#1012628).
- binder: Set end of SG buffer area properly (bnc#1012628).
- x86/stacktrace: Prevent access_ok() warnings in
  arch_stack_walk_user() (bnc#1012628).
- x86/speculation/mds: Apply more accurate check on hypervisor
  platform (bnc#1012628).
- x86/sysfb_efi: Add quirks for some devices with swapped width
  and height (bnc#1012628).
- selinux: check sidtab limit before adding a new entry
  (bnc#1012628).
- btrfs: inode: Don't compress if NODATASUM or NODATACOW set
  (bnc#1012628).
- media: videodev2.h: change V4L2_PIX_FMT_BGRA444 define: fourcc
  was already in use (bnc#1012628).
- KVM: PPC: Book3S HV: XIVE: fix rollback when kvmppc_xive_create
  fails (bnc#1012628).
- KVM: PPC: Book3S HV: Save and restore guest visible PSSCR bits
  on pseries (bnc#1012628).
- KVM: PPC: Book3S HV: Always save guest pmu for guest capable
  of nesting (bnc#1012628).
- KVM: X86: Fix fpu state crash in kvm guest (bnc#1012628).
- usb: usb251xb: Reallow swap-dx-lanes to apply to the upstream
  port (bnc#1012628).
- Revert "usb: usb251xb: Add US port lanes inversion property"
  (bnc#1012628).
- Revert "usb: usb251xb: Add US lanes inversion dts-bindings"
  (bnc#1012628).
- usb: pci-quirks: Correct AMD PLL quirk detection (bnc#1012628).
- usb: wusbcore: fix unbalanced get/put cluster_id (bnc#1012628).
- usb-storage: Add a limitation for blk_queue_max_hw_sectors()
  (bnc#1012628).
- xhci: Fix crash if scatter gather is used with Immediate Data
  Transfer (IDT) (bnc#1012628).
- locking/lockdep: Hide unused 'class' variable (bnc#1012628).
- mm, swap: fix race between swapoff and some swap operations
  (bnc#1012628).
- mm: use down_read_killable for locking mmap_sem in
  access_remote_vm (bnc#1012628).
- locking/lockdep: Fix lock used or unused stats error
  (bnc#1012628).
- proc: use down_read_killable mmap_sem for /proc/pid/maps
  (bnc#1012628).
- cxgb4: reduce kernel stack usage in cudbg_collect_mem_region()
  (bnc#1012628).
- proc: use down_read_killable mmap_sem for /proc/pid/map_files
  (bnc#1012628).
- proc: use down_read_killable mmap_sem for /proc/pid/clear_refs
  (bnc#1012628).
- proc: use down_read_killable mmap_sem for /proc/pid/pagemap
  (bnc#1012628).
- proc: use down_read_killable mmap_sem for /proc/pid/smaps_rollup
  (bnc#1012628).
- mm/mmu_notifier: use hlist_add_head_rcu() (bnc#1012628).
- memcg, fsnotify: no oom-kill for remote memcg charging
  (bnc#1012628).
- mm/gup.c: remove some BUG_ONs from get_gate_page()
  (bnc#1012628).
- mm/gup.c: mark undo_dev_pagemap as __maybe_unused (bnc#1012628).
- mm/mincore.c: fix race between swapoff and mincore
  (bnc#1012628).
- 9p: pass the correct prototype to read_cache_page (bnc#1012628).
- mm/kmemleak.c: fix check for softirq context (bnc#1012628).
- sh: prevent warnings when using iounmap (bnc#1012628).
- nvme: fix NULL deref for fabrics options (bnc#1012628).
- block/bio-integrity: fix a memory leak bug (bnc#1012628).
- platform/x86: Fix PCENGINES_APU2 Kconfig warning (bnc#1012628).
- powerpc/eeh: Handle hugepages in ioremap space (bnc#1012628).
- dlm: check if workqueues are NULL before flushing/destroying
  (bnc#1012628).
- mailbox: handle failed named mailbox channel request
  (bnc#1012628).
- f2fs: avoid out-of-range memory access (bnc#1012628).
- f2fs: fix to avoid long latency during umount (bnc#1012628).
- rds: Accept peer connection reject messages due to incompatible
  version (bnc#1012628).
- block: init flush rq ref count to 1 (bnc#1012628).
- powerpc/boot: add {get, put}_unaligned_be32 to xz_config.h
  (bnc#1012628).
- powerpc/irq: Don't WARN continuously in arch_local_irq_restore()
  (bnc#1012628).
- nvme-tcp: set the STABLE_WRITES flag when data digests are
  enabled (bnc#1012628).
- io_uring: fix io_sq_thread_stop running in front of io_sq_thread
  (bnc#1012628).
- nvme-tcp: don't use sendpage for SLAB pages (bnc#1012628).
- nvme-pci: limit max_hw_sectors based on the DMA max mapping size
  (bnc#1012628).
- nvme-pci: check for NULL return from pci_alloc_p2pmem()
  (bnc#1012628).
- RDMA/core: Fix race when resolving IP address (bnc#1012628).
- perf intel-bts: Fix potential NULL pointer dereference found
  by the smatch tool (bnc#1012628).
- PCI: dwc: pci-dra7xx: Fix compilation when !CONFIG_GPIOLIB
  (bnc#1012628).
- RDMA/rxe: Fill in wc byte_len with IB_WC_RECV_RDMA_WITH_IMM
  (bnc#1012628).
- perf hists browser: Fix potential NULL pointer dereference
  found by the smatch tool (bnc#1012628).
- perf annotate: Fix dereferencing freed memory found by the
  smatch tool (bnc#1012628).
- perf map: Fix potential NULL pointer dereference found by
  smatch tool (bnc#1012628).
- perf session: Fix potential NULL pointer dereference found by
  the smatch tool (bnc#1012628).
- perf trace: Fix potential NULL pointer dereference found by
  the smatch tool (bnc#1012628).
- perf top: Fix potential NULL pointer dereference detected by
  the smatch tool (bnc#1012628).
- rseq/selftests: Fix Thumb mode build failure on arm32
  (bnc#1012628).
- perf stat: Fix use-after-freed pointer detected by the smatch
  tool (bnc#1012628).
- perf test mmap-thread-lookup: Initialize variable to suppress
  memory sanitizer warning (bnc#1012628).
- PCI: mobiveil: Use the 1st inbound window for MEM inbound
  transactions (bnc#1012628).
- PCI: mobiveil: Initialize Primary/Secondary/Subordinate bus
  numbers (bnc#1012628).
- kallsyms: exclude kasan local symbols on s390 (bnc#1012628).
- PCI: mobiveil: Fix the Class Code field (bnc#1012628).
- PCI: mobiveil: Fix PCI base address in MEM/IO outbound windows
  (bnc#1012628).
- KVM: nVMX: Stash L1's CR3 in vmcs01.GUEST_CR3 on nested entry
  w/o EPT (bnc#1012628).
- arm64: assembler: Switch ESB-instruction with a vanilla nop
  if !ARM64_HAS_RAS (bnc#1012628).
- IB/ipoib: Add child to parent list only if device initialized
  (bnc#1012628).
- powerpc/mm: Handle page table allocation failures (bnc#1012628).
- IB/mlx5: Fixed reporting counters on 2nd port for Dual port RoCE
  (bnc#1012628).
- serial: sh-sci: Fix TX DMA buffer flushing and workqueue races
  (bnc#1012628).
- serial: sh-sci: Terminate TX DMA during buffer flushing
  (bnc#1012628).
- RDMA/i40iw: Set queue pair state when being queried
  (bnc#1012628).
- powerpc/mm: mark more tlb functions as __always_inline
  (bnc#1012628).
- powerpc/4xx/uic: clear pending interrupt after irq type/pol
  change (bnc#1012628).
- powerpc: silence a -Wcast-function-type warning in
  dawr_write_file_bool (bnc#1012628).
- f2fs: fix is_idle() check for discard type (bnc#1012628).
- um: Silence lockdep complaint about mmap_sem (bnc#1012628).
- mm/swap: fix release_pages() when releasing devmap pages
  (bnc#1012628).
- mfd: hi655x-pmic: Fix missing return value check for
  devm_regmap_init_mmio_clk (bnc#1012628).
- mfd: arizona: Fix undefined behavior (bnc#1012628).
- mfd: core: Set fwnode for created devices (bnc#1012628).
- mfd: madera: Add missing of table registration (bnc#1012628).
- mfd: cros_ec: Register cros_ec_lid_angle driver when presented
  (bnc#1012628).
- recordmcount: Fix spurious mcount entries on powerpc
  (bnc#1012628).
- fixdep: check return value of printf() and putchar()
  (bnc#1012628).
- powerpc/rtas: retry when cpu offline races with
  suspend/migration (bnc#1012628).
- powerpc/xmon: Fix disabling tracing while in xmon (bnc#1012628).
- powerpc/cacheflush: fix variable set but not used (bnc#1012628).
- dt-bindings: backlight: lm3630a: correct schema validation
  (bnc#1012628).
- iio: iio-utils: Fix possible incorrect mask calculation
  (bnc#1012628).
- PCI: xilinx-nwl: Fix Multi MSI data programming (bnc#1012628).
- phy: meson-g12a-usb3-pcie: disable locking for cr_regmap
  (bnc#1012628).
- genksyms: Teach parser about 128-bit built-in types
  (bnc#1012628).
- kbuild: Add -Werror=unknown-warning-option to CLANG_FLAGS
  (bnc#1012628).
- i2c: stm32f7: fix the get_irq error cases (bnc#1012628).
- PCI: sysfs: Ignore lockdep for remove attribute (bnc#1012628).
- phy: renesas: rcar-gen3-usb2: fix imbalance powered flag
  (bnc#1012628).
- serial: mctrl_gpio: Check if GPIO property exisits before
  requesting it (bnc#1012628).
- drm/msm: Depopulate platform on probe failure (bnc#1012628).
- powerpc/pci/of: Fix OF flags parsing for 64bit BARs
  (bnc#1012628).
- drm/msm/adreno: Ensure that the zap shader region is big enough
  (bnc#1012628).
- kvm: vmx: segment limit check: use access length (bnc#1012628).
- KVM: nVMX: Intercept VMWRITEs to GUEST_{CS,SS}_AR_BYTES
  (bnc#1012628).
- mmc: sdhci: sdhci-pci-o2micro: Check if controller supports
  8-bit width (bnc#1012628).
- kvm: vmx: fix limit checking in get_vmx_mem_address()
  (bnc#1012628).
- usb: dwc3: Fix core validation in probe, move after clocks
  are enabled (bnc#1012628).
- usb: gadget: Zero ffs_io_data (bnc#1012628).
- tty: serial_core: Set port active bit in uart_port_activate
  (bnc#1012628).
- serial: uartps: Use the same dynamic major number for all ports
  (bnc#1012628).
- serial: imx: fix locking in set_termios() (bnc#1012628).
- iio: adxl372: fix iio_triggered_buffer_{pre,post}enable
  positions (bnc#1012628).
- platform/x86: asus-wmi: Increase input buffer size of WMI
  methods (bnc#1012628).
- drm/rockchip: Properly adjust to a true clock in adjusted_mode
  (bnc#1012628).
- dma-remap: Avoid de-referencing NULL atomic_pool (bnc#1012628).
- powerpc/pseries/mobility: prevent cpu hotplug during DT update
  (bnc#1012628).
- drm/bridge: tfp410: fix use of cancel_delayed_work_sync
  (bnc#1012628).
- sunhv: Fix device naming inconsistency between sunhv_console
  and sunhv_reg (bnc#1012628).
- drm/amd/display: fix compilation error (bnc#1012628).
- phy: renesas: rcar-gen2: Fix memory leak at error paths
  (bnc#1012628).
- drm/amd/display: set link->dongle_max_pix_clk to 0 on a
  disconnect (bnc#1012628).
- drm/virtio: Add memory barriers for capset cache (bnc#1012628).
- drm/amd/display: Update link rate from DPCD 10 (bnc#1012628).
- drm/amd/display: Always allocate initial connector state state
  (bnc#1012628).
- PCI: endpoint: Allocate enough space for fixed size BAR
  (bnc#1012628).
- serial: 8250: Fix TX interrupt handling condition (bnc#1012628).
- tty: serial: msm_serial: avoid system lockup condition
  (bnc#1012628).
- tty/serial: digicolor: Fix digicolor-usart already registered
  warning (bnc#1012628).
- memstick: Fix error cleanup path of memstick_init (bnc#1012628).
- drm/omap: don't check dispc timings for DSI (bnc#1012628).
- mm/hmm: fix use after free with struct hmm in the mmu notifiers
  (bnc#1012628).
- i2c: nvidia-gpu: resume ccgx i2c client (bnc#1012628).
- drm/vkms: Forward timer right after drm_crtc_handle_vblank
  (bnc#1012628).
- drm/crc-debugfs: Also sprinkle irqrestore over early exits
  (bnc#1012628).
- drm/crc-debugfs: User irqsafe spinlock in drm_crtc_add_crc_entry
  (bnc#1012628).
- gpu: host1x: Increase maximum DMA segment size (bnc#1012628).
- f2fs: Lower threshold for disable_cp_again (bnc#1012628).
- f2fs: Fix accounting for unusable blocks (bnc#1012628).
- drm/amd/display: Increase Backlight Gain Step Size
  (bnc#1012628).
- drm/amd/display: CS_TFM_1D only applied post EOTF (bnc#1012628).
- drm/amd/display: Reset planes for color management changes
  (bnc#1012628).
- drm/bridge: sii902x: pixel clock unit is 10kHz instead of 1kHz
  (bnc#1012628).
- drm/bridge: tc358767: read display_props in get_modes()
  (bnc#1012628).
- staging: kpc2000: report error status to spi core (bnc#1012628).
- PCI: Return error if cannot probe VF (bnc#1012628).
- tools: PCI: Fix broken pcitest compilation (bnc#1012628).
- drm/edid: Fix a missing-check bug in drm_load_edid_firmware()
  (bnc#1012628).
- drm/amdkfd: Fix sdma queue map issue (bnc#1012628).
- drm/amdkfd: Fix a potential memory leak (bnc#1012628).
- drm/amd/display: Disable ABM before destroy ABM struct
  (bnc#1012628).
- drm/amdgpu/sriov: Need to initialize the HDP_NONSURFACE_BAStE
  (bnc#1012628).
- f2fs: fix to avoid deadloop if data_flush is on (bnc#1012628).
- drm/amdgpu: Reserve shared fence for eviction fence
  (bnc#1012628).
- drm/amd/display: Fill plane attrs only for valid pxl format
  (bnc#1012628).
- drm/amd/display: Disable cursor when offscreen in negative
  direction (bnc#1012628).
- drm/msm/a6xx: Avoid freeing gmu resources multiple times
  (bnc#1012628).
- drm/amd/display: fix multi display seamless boot case
  (bnc#1012628).
- drm/amd/display: Fill prescale_params->scale for RGB565
  (bnc#1012628).
- ipmi_ssif: fix unexpected driver unregister warning
  (bnc#1012628).
- drm/msm/a6xx: Check for ERR or NULL before iounmap
  (bnc#1012628).
- f2fs: fix to check layout on last valid checkpoint park
  (bnc#1012628).
- tty: serial: cpm_uart - fix init when SMC is relocated
  (bnc#1012628).
- pinctrl: rockchip: fix leaked of_node references (bnc#1012628).
- tty: max310x: Fix invalid baudrate divisors calculator
  (bnc#1012628).
- usb: core: hub: Disable hub-initiated U1/U2 (bnc#1012628).
- drm/bochs: Fix connector leak during driver unload
  (bnc#1012628).
- staging: vt6656: use meaningful error code during buffer
  allocation (bnc#1012628).
- ipmi_si: fix unexpected driver unregister warning (bnc#1012628).
- staging: kpc2000: added missing clean-up to probe_core_uio
  (bnc#1012628).
- drm/virtio: set seqno for dma-fence (bnc#1012628).
- iio: adc: stm32-dfsdm: missing error case during probe
  (bnc#1012628).
- iio: adc: stm32-dfsdm: manage the get_irq error case
  (bnc#1012628).
- drm/panel: simple: Fix panel_simple_dsi_probe (bnc#1012628).
- drm/lima: handle shared irq case for lima_pp_bcast_irq_handler
  (bnc#1012628).
- btrfs: shut up bogus -Wmaybe-uninitialized warning
  (bnc#1012628).
- media: drivers: media: coda: fix warning same module names
  (bnc#1012628).
- regulator: 88pm800: fix warning same module names (bnc#1012628).
- commit b607c27
* Wed Jul 31 2019 jdelvare@suse.de
- Update config files: CONFIG_HBMC_AM654=n
  The TI AM654 is an ARM64 SoC, so disable the driver on all other
  architectures.
- commit 042f63f
* Tue Jul 30 2019 schwab@suse.de
- packaging: add support for riscv64
- commit c2885ea
* Sun Jul 28 2019 mkubecek@suse.cz
- Update to 5.3-rc2
- Eliminated 1 patch
  - patches.suse/dma-mapping-use-dma_get_mask-in-dma_addressing_limit.patch
- Refresh
  - patches.suse/netfilter-ip_conntrack_slp.patch
- Config changes
  - NF_TABLES_BRIDGE=m (was =y)
- commit fc5ebf3
* Sun Jul 28 2019 jslaby@suse.cz
- Linux 5.2.4 (bnc#1012628).
- net: sched: verify that q!=NULL before setting q->flags
  (bnc#1012628).
- block: Limit zone array allocation size (bnc#1012628).
- sd_zbc: Fix report zones buffer allocation (bnc#1012628).
- Revert "kvm: x86: Use task structs fpu field for user"
  (bnc#1012628).
- KVM: nVMX: Clear pending KVM_REQ_GET_VMCS12_PAGES when leaving
  nested (bnc#1012628).
- KVM: nVMX: do not use dangling shadow VMCS after guest reset
  (bnc#1012628).
- ext4: allow directory holes (bnc#1012628).
- ext4: use jbd2_inode dirty range scoping (bnc#1012628).
- jbd2: introduce jbd2_inode dirty range scoping (bnc#1012628).
- mm: add filemap_fdatawait_range_keep_errors() (bnc#1012628).
- ext4: enforce the immutable flag on open files (bnc#1012628).
- ext4: don't allow any modifications to an immutable file
  (bnc#1012628).
- perf/core: Fix race between close() and fork() (bnc#1012628).
- perf/core: Fix exclusive events' grouping (bnc#1012628).
- perf script: Assume native_arch for pipe mode (bnc#1012628).
- MIPS: lb60: Fix pin mappings (bnc#1012628).
- gpio: davinci: silence error prints in case of EPROBE_DEFER
  (bnc#1012628).
- gpiolib: of: fix a memory leak in of_gpio_flags_quirks()
  (bnc#1012628).
- Revert "gpio/spi: Fix spi-gpio regression on active high CS"
  (bnc#1012628).
- dma-buf: Discard old fence_excl on retrying get_fences_rcu
  for realloc (bnc#1012628).
- dma-buf: balance refcount inbalance (bnc#1012628).
- mlxsw: spectrum: Do not process learned records with a dummy
  FID (bnc#1012628).
- net/mlx5: E-Switch, Fix default encap mode (bnc#1012628).
- mlxsw: spectrum_dcb: Configure DSCP map as the last rule is
  removed (bnc#1012628).
- bnxt_en: Fix VNIC accounting when enabling aRFS on 57500 chips
  (bnc#1012628).
- net/mlx5e: Fix error flow in tx reporter diagnose (bnc#1012628).
- net/mlx5e: Fix return value from timeout recover function
  (bnc#1012628).
- net/mlx5e: Rx, Fix checksum calculation for new hardware
  (bnc#1012628).
- net/mlx5e: Fix port tunnel GRE entropy control (bnc#1012628).
- net/tls: reject offload of TLS 1.3 (bnc#1012628).
- net/tls: fix poll ignoring partially copied records
  (bnc#1012628).
- selftests: txring_overwrite: fix incorrect test of mmap()
  return value (bnc#1012628).
- netrom: hold sock when setting skb->destructor (bnc#1012628).
- netrom: fix a memory leak in nr_rx_frame() (bnc#1012628).
- macsec: fix checksumming after decryption (bnc#1012628).
- macsec: fix use-after-free of skb during RX (bnc#1012628).
- net: bridge: stp: don't cache eth dest pointer before skb pull
  (bnc#1012628).
- net: bridge: don't cache ether dest pointer on input
  (bnc#1012628).
- net: bridge: mcast: fix stale ipv6 hdr pointer when handling
  v6 query (bnc#1012628).
- net: bridge: mcast: fix stale nsrcs pointer in igmp3/mld2
  report handling (bnc#1012628).
- net/mlx5e: IPoIB, Add error path in mlx5_rdma_setup_rn
  (bnc#1012628).
- vrf: make sure skb->data contains ip header to make routing
  (bnc#1012628).
- tcp: Reset bytes_acked and bytes_received when disconnecting
  (bnc#1012628).
- tcp: fix tcp_set_congestion_control() use from bpf hook
  (bnc#1012628).
- tcp: be more careful in tcp_fragment() (bnc#1012628).
- sky2: Disable MSI on ASUS P6T (bnc#1012628).
- sctp: not bind the socket in sctp_connect (bnc#1012628).
- sctp: fix error handling on stream scheduler initialization
  (bnc#1012628).
- rxrpc: Fix send on a connected, but unbound socket
  (bnc#1012628).
- r8169: fix issue with confused RX unit after PHY power-down
  on RTL8411b (bnc#1012628).
- nfc: fix potential illegal memory access (bnc#1012628).
- net/tls: make sure offload also gets the keys wiped
  (bnc#1012628).
- net: stmmac: Re-work the queue selection for TSO packets
  (bnc#1012628).
- net_sched: unset TCQ_F_CAN_BYPASS when adding filters
  (bnc#1012628).
- net: phy: sfp: hwmon: Fix scaling of RX power (bnc#1012628).
- net: openvswitch: fix csum updates for MPLS actions
  (bnc#1012628).
- net: neigh: fix multiple neigh timer scheduling (bnc#1012628).
- net: make skb_dst_force return true when dst is refcounted
  (bnc#1012628).
- net: dsa: mv88e6xxx: wait after reset deactivation
  (bnc#1012628).
- net: bcmgenet: use promisc for unsupported filters
  (bnc#1012628).
- ipv6: Unlink sibling route in case of failure (bnc#1012628).
- ipv6: rt6_check should return NULL if 'from' is NULL
  (bnc#1012628).
- ipv4: don't set IPv6 only flags to IPv4 addresses (bnc#1012628).
- igmp: fix memory leak in igmpv3_del_delrec() (bnc#1012628).
- hv_netvsc: Fix extra rcu_read_unlock in netvsc_recv_callback()
  (bnc#1012628).
- caif-hsi: fix possible deadlock in cfhsi_exit_module()
  (bnc#1012628).
- bnx2x: Prevent load reordering in tx completion processing
  (bnc#1012628).
- commit d795a82
* Sat Jul 27 2019 msuchanek@suse.de
- rpm/macros.kernel-source: KMPs should depend on kmod-compat to build.
  kmod-compat links are used in find-provides.ksyms, find-requires.ksyms,
  and find-supplements.ksyms in rpm-config-SUSE.
- commit f97ca49
* Sat Jul 27 2019 msuchanek@suse.de
- scripts/run_oldconfig.sh: Fix update-vanilla
  When CC is set we want to use it for native only. Cross-compilation
  still needs the crosscompilers.
- commit 3b9fcdb
* Fri Jul 26 2019 jslaby@suse.cz
- Linux 5.2.3 (bnc#1012628).
- dm bufio: fix deadlock with loop device (bnc#1012628).
- dm thin metadata: check if in fail_io mode when setting
  needs_check (bnc#1012628).
- phy: qcom-qmp: Correct READY_STATUS poll break condition
  (bnc#1012628).
- pstore: Fix double-free in pstore_mkfile() failure path
  (bnc#1012628).
- dt-bindings: allow up to four clocks for orion-mdio
  (bnc#1012628).
- net: mvmdio: allow up to four clocks to be specified for
  orion-mdio (bnc#1012628).
- blkcg: update blkcg_print_stat() to handle larger outputs
  (bnc#1012628).
- blk-iolatency: clear use_delay when io.latency is set to zero
  (bnc#1012628).
- clk: imx: imx8mm: correct audio_pll2_clk to audio_pll2_out
  (bnc#1012628).
- blk-throttle: fix zero wait time for iops throttled group
  (bnc#1012628).
- usb: Handle USB3 remote wakeup for LPM enabled devices correctly
  (bnc#1012628).
- dax: Fix missed wakeup with PMD faults (bnc#1012628).
- Bluetooth: Add SMP workaround Microsoft Surface Precision
  Mouse bug (bnc#1012628).
- intel_th: msu: Fix single mode with disabled IOMMU
  (bnc#1012628).
- intel_th: msu: Remove set but not used variable 'last'
  (bnc#1012628).
- mtd: spinand: read returns badly if the last page has bitflips
  (bnc#1012628).
- mtd: rawnand: mtk: Correct low level time calculation of r/w
  cycle (bnc#1012628).
- eCryptfs: fix a couple type promotion bugs (bnc#1012628).
- mmc: sdhci-msm: fix mutex while in spinlock (bnc#1012628).
- powerpc/pseries: Fix oops in hotplug memory notifier
  (bnc#1012628).
- powerpc/pseries: Fix xive=off command line (bnc#1012628).
- powerpc/powernv: Fix stale iommu table base after VFIO
  (bnc#1012628).
- powerpc/powernv/idle: Fix restore of SPRN_LDBAR for POWER9
  stop state (bnc#1012628).
- powerpc/powernv/npu: Fix reference leak (bnc#1012628).
- powerpc/watchpoint: Restore NV GPRs while returning from
  exception (bnc#1012628).
- powerpc/mm/32s: fix condition that is always true (bnc#1012628).
- powerpc/32s: fix suspend/resume when IBATs 4-7 are used
  (bnc#1012628).
- parisc: Fix kernel panic due invalid values in IAOQ0 or IAOQ1
  (bnc#1012628).
- parisc: Avoid kernel panic triggered by invalid kprobe
  (bnc#1012628).
- parisc: Ensure userspace privilege for ptraced processes in
  regset functions (bnc#1012628).
- gpu: ipu-v3: ipu-ic: Fix saturation bit offset in TPMEM
  (bnc#1012628).
- resource: fix locking in find_next_iomem_res() (bnc#1012628).
- include/asm-generic/bug.h: fix "cut here" for WARN_ON for
  __WARN_TAINT architectures (bnc#1012628).
- coda: pass the host file in vma->vm_file on mmap (bnc#1012628).
- mm/z3fold.c: lock z3fold page before __SetPageMovable()
  (bnc#1012628).
- mm/memcontrol: fix wrong statistics in memory.stat
  (bnc#1012628).
- libnvdimm/pfn: fix fsdax-mode namespace info-block zero-fields
  (bnc#1012628).
- mm/nvdimm: add is_ioremap_addr and use that to check ioremap
  address (bnc#1012628).
- mm: vmscan: scan anonymous pages on file refaults (bnc#1012628).
- HID: wacom: correct touch resolution x/y typo (bnc#1012628).
- HID: wacom: generic: Correct pad syncing (bnc#1012628).
- HID: wacom: generic: only switch the mode on devices with LEDs
  (bnc#1012628).
- IB/mlx5: Report correctly tag matching rendezvous capability
  (bnc#1012628).
- Btrfs: add missing inode version, ctime and mtime updates when
  punching hole (bnc#1012628).
- Btrfs: fix fsync not persisting dentry deletions due to inode
  evictions (bnc#1012628).
- Btrfs: fix data loss after inode eviction, renaming it, and
  fsync it (bnc#1012628).
- btrfs: correctly validate compression type (bnc#1012628).
- PCI: qcom: Ensure that PERST is asserted for at least 100 ms
  (bnc#1012628).
- PCI: Do not poll for PME if the device is in D3cold
  (bnc#1012628).
- PCI: hv: Fix a use-after-free bug in hv_eject_device_work()
  (bnc#1012628).
- intel_th: pci: Add Ice Lake NNPI support (bnc#1012628).
- RDMA/odp: Fix missed unlock in non-blocking invalidate_start
  (bnc#1012628).
- RDMA/srp: Accept again source addresses that do not have a
  port number (bnc#1012628).
- block: Fix potential overflow in blk_report_zones()
  (bnc#1012628).
- block: Allow mapping of vmalloc-ed buffers (bnc#1012628).
- drm/edid: parse CEA blocks embedded in DisplayID (bnc#1012628).
- x86/stacktrace: Prevent infinite loop in arch_stack_walk_user()
  (bnc#1012628).
- perf/x86/amd/uncore: Set the thread mask for F17h L3 PMCs
  (bnc#1012628).
- perf/x86/amd/uncore: Do not set 'ThreadMask' and 'SliceMask'
  for non-L3 PMCs (bnc#1012628).
- perf/x86/intel: Fix spurious NMI on fixed counter (bnc#1012628).
- x86/boot: Fix memory leak in default_get_smp_config()
  (bnc#1012628).
- x86/hyper-v: Zero out the VP ASSIST PAGE on allocation
  (bnc#1012628).
- rt2x00usb: fix rx queue hang (bnc#1012628).
- 9p/virtio: Add cleanup path in p9_virtio_init (bnc#1012628).
- 9p/xen: Add cleanup path in p9_trans_xen_init (bnc#1012628).
- xen/events: fix binding user event channels to cpus
  (bnc#1012628).
- dm zoned: fix zone state management race (bnc#1012628).
- padata: use smp_mb in padata_reorder to avoid orphaned padata
  jobs (bnc#1012628).
- drm/nouveau/i2c: Enable i2c pads & busses during preinit
  (bnc#1012628).
- ARM: dts: gemini: Set DIR-685 SPI CS as active low
  (bnc#1012628).
- i3c: fix i2c and i3c scl rate by bus mode (bnc#1012628).
- fs/proc/proc_sysctl.c: fix the default values of i_uid/i_gid
  on /proc/sys inodes (bnc#1012628).
- signal: Correct namespace fixups of si_pid and si_uid
  (bnc#1012628).
- signal/usb: Replace kill_pid_info_as_cred with
  kill_pid_usb_asyncio (bnc#1012628).
- intel_th: msu: Fix unused variable warning on arm64 platform
  (bnc#1012628).
- arm64: Fix incorrect irqflag restore for priority masking
  (bnc#1012628).
- arm64: irqflags: Add condition flags to inline asm clobber list
  (bnc#1012628).
- arm64: tegra: Fix AGIC register range (bnc#1012628).
- KVM: x86/vPMU: refine kvm_pmu err msg when event creation failed
  (bnc#1012628).
- KVM: PPC: Book3S HV: Fix CR0 setting in TM emulation
  (bnc#1012628).
- KVM: PPC: Book3S HV: Clear pending decrementer exceptions on
  nested guest entry (bnc#1012628).
- KVM: PPC: Book3S HV: Signed extend decrementer value if not
  using large decrementer (bnc#1012628).
- KVM: Properly check if "page" is valid in kvm_vcpu_unmap
  (bnc#1012628).
- KVM: VMX: check CPUID before allowing read/write of IA32_XSS
  (bnc#1012628).
- KVM: VMX: Fix handling of #MC that occurs during VM-Entry
  (bnc#1012628).
- KVM: nVMX: Always sync GUEST_BNDCFGS when it comes from vmcs01
  (bnc#1012628).
- KVM: VMX: Always signal #GP on WRMSR to MSR_IA32_CR_PAT with
  bad value (bnc#1012628).
- KVM: nVMX: Don't dump VMCS if virtual APIC page can't be mapped
  (bnc#1012628).
- media: videobuf2-dma-sg: Prevent size from overflowing
  (bnc#1012628).
- media: videobuf2-core: Prevent size alignment wrapping buffer
  size to 0 (bnc#1012628).
- media: coda: Remove unbalanced and unneeded mutex unlock
  (bnc#1012628).
- media: v4l2: Test type instead of cfg->type in
  v4l2_ctrl_new_custom() (bnc#1012628).
- ceph: use ceph_evict_inode to cleanup inode's resource
  (bnc#1012628).
- ceph: fix end offset in truncate_inode_pages_range call
  (bnc#1012628).
- ALSA: hda/hdmi - Fix i915 reverse port/pin mapping
  (bnc#1012628).
- ALSA: hda/hdmi - Remove duplicated define (bnc#1012628).
- ALSA: hda/realtek: apply ALC891 headset fixup to one Dell
  machine (bnc#1012628).
- ALSA: hda/realtek - Fixed Headphone Mic can't record on Dell
  platform (bnc#1012628).
- ALSA: hda - Don't resume forcibly i915 HDMI/DP codec
  (bnc#1012628).
- ALSA: seq: Break too long mutex context in the write loop
  (bnc#1012628).
- kconfig: fix missing choice values in auto.conf (bnc#1012628).
- raid5-cache: Need to do start() part job after adding journal
  device (bnc#1012628).
- ASoC: core: Adapt for debugfs API change (bnc#1012628).
- ASoC: dapm: Adapt for debugfs API change (bnc#1012628).
- lib/scatterlist: Fix mapping iterator when sg->offset is
  greater than PAGE_SIZE (bnc#1012628).
- SUNRPC: Ensure the bvecs are reset when we re-encode the RPC
  request (bnc#1012628).
- pnfs: Fix a problem where we gratuitously start doing I/O
  through the MDS (bnc#1012628).
- pnfs/flexfiles: Fix PTR_ERR() dereferences in
  ff_layout_track_ds_error (bnc#1012628).
- Revert "NFS: readdirplus optimization by cache mechanism"
  (memleak) (bnc#1012628).
- NFSv4: Handle the special Linux file open access mode
  (bnc#1012628).
- tracing: Fix user stack trace "??" output (bnc#1012628).
- arm64: Fix interrupt tracing in the presence of NMIs
  (bnc#1012628).
- opp: Don't use IS_ERR on invalid supplies (bnc#1012628).
- iwlwifi: mvm: clear rfkill_safe_init_done when we start the
  firmware (bnc#1012628).
- iwlwifi: mvm: delay GTK setting in FW in AP mode (bnc#1012628).
- iwlwifi: fix RF-Kill interrupt while FW load for gen2 devices
  (bnc#1012628).
- iwlwifi: don't WARN when calling iwl_get_shared_mem_conf with
  RF-Kill (bnc#1012628).
- iwlwifi: pcie: fix ALIVE interrupt handling for gen2 devices
  w/o MSI-X (bnc#1012628).
- iwlwifi: pcie: don't service an interrupt that was masked
  (bnc#1012628).
- iwlwifi: add support for hr1 RF ID (bnc#1012628).
- arm64: tegra: Fix Jetson Nano GPU regulator (bnc#1012628).
- arm64: tegra: Update Jetson TX1 GPU regulator timings
  (bnc#1012628).
- regulator: s2mps11: Fix buck7 and buck8 wrong voltages
  (bnc#1012628).
- regulator: s2mps11: Fix ERR_PTR dereference on GPIO lookup
  failure (bnc#1012628).
- Input: alps - fix a mismatch between a condition check and
  its comment (bnc#1012628).
- Input: synaptics - whitelist Lenovo T580 SMBus intertouch
  (bnc#1012628).
- Input: alps - don't handle ALPS cs19 trackpoint-only device
  (bnc#1012628).
- Input: gtco - bounds check collection indent level
  (bnc#1012628).
- bcache: destroy dc->writeback_write_wq if failed to create
  dc->writeback_thread (bnc#1012628).
- bcache: fix mistaken sysfs entry for io_error counter
  (bnc#1012628).
- bcache: ignore read-ahead request failure on backing device
  (bnc#1012628).
- bcache: Revert "bcache: free heap cache_set->flush_btree in
  bch_journal_free" (bnc#1012628).
- bcache: Revert "bcache: fix high CPU occupancy during journal"
  (bnc#1012628).
- Revert "bcache: set CACHE_SET_IO_DISABLE in
  bch_cached_dev_error()" (bnc#1012628).
- CIFS: fix deadlock in cached root handling (bnc#1012628).
- cifs: flush before set-info if we have writeable handles
  (bnc#1012628).
- cifs: Properly handle auto disabling of serverino option
  (bnc#1012628).
- cifs: fix crash in smb2_compound_op()/smb2_set_next_command()
  (bnc#1012628).
- cifs: always add credits back for unsolicited PDUs
  (bnc#1012628).
- crypto: crypto4xx - fix a potential double free in
  ppc4xx_trng_probe (bnc#1012628).
- crypto: ccp/gcm - use const time tag comparison (bnc#1012628).
- crypto: ccp - memset structure fields to zero before reuse
  (bnc#1012628).
- crypto: crypto4xx - block ciphers should only accept complete
  blocks (bnc#1012628).
- crypto: crypto4xx - fix blocksize for cfb and ofb (bnc#1012628).
- crypto: crypto4xx - fix AES CTR blocksize value (bnc#1012628).
- crypto: chacha20poly1305 - fix atomic sleep when using async
  algorithm (bnc#1012628).
- crypto: arm64/sha2-ce - correct digest for empty data in finup
  (bnc#1012628).
- crypto: arm64/sha1-ce - correct digest for empty data in finup
  (bnc#1012628).
- crypto: ccp - Validate the the error value used to index error
  messages (bnc#1012628).
- crypto: caam - limit output IV to CBC to work around CTR mode
  DMA issue (bnc#1012628).
- crypto: ghash - fix unaligned memory access in ghash_setkey()
  (bnc#1012628).
- scsi: mac_scsi: Fix pseudo DMA implementation, take 2
  (bnc#1012628).
- scsi: mac_scsi: Increase PIO/PDMA transfer length threshold
  (bnc#1012628).
- scsi: megaraid_sas: Fix calculation of target ID (bnc#1012628).
- scsi: zfcp: fix request object use-after-free in send path
  causing wrong traces (bnc#1012628).
- scsi: zfcp: fix request object use-after-free in send path
  causing seqno errors (bnc#1012628).
- scsi: sd_zbc: Fix compilation warning (bnc#1012628).
- scsi: core: Fix race on creating sense cache (bnc#1012628).
- Revert "scsi: ncr5380: Increase register polling limit"
  (bnc#1012628).
- scsi: NCR5380: Handle PDMA failure reliably (bnc#1012628).
- scsi: NCR5380: Always re-enable reselection interrupt
  (bnc#1012628).
- xen: let alloc_xenballooned_pages() fail if not enough memory
  free (bnc#1012628).
- floppy: fix out-of-bounds read in copy_buffer (bnc#1012628).
- floppy: fix invalid pointer dereference in drive_name
  (bnc#1012628).
- floppy: fix out-of-bounds read in next_valid_format
  (bnc#1012628).
- floppy: fix div-by-zero in setup_format_params (bnc#1012628).
- libbpf: fix another GCC8 warning for strncpy (bnc#1012628).
- blk-iolatency: fix STS_AGAIN handling (bnc#1012628).
- iavf: fix dereference of null rx_buffer pointer (bnc#1012628).
- net: hns3: fix __QUEUE_STATE_STACK_XOFF not cleared issue
  (bnc#1012628).
- net: mvmdio: defer probe of orion-mdio if a clock is not ready
  (bnc#1012628).
- xdp: fix race on generic receive path (bnc#1012628).
- gtp: fix use-after-free in gtp_newlink() (bnc#1012628).
- gtp: fix use-after-free in gtp_encap_destroy() (bnc#1012628).
- gtp: fix Illegal context switch in RCU read-side critical
  section (bnc#1012628).
- gtp: fix suspicious RCU usage (bnc#1012628).
- Bluetooth: validate BLE connection interval updates
  (bnc#1012628).
- gtp: add missing gtp_encap_disable_sock() in gtp_encap_enable()
  (bnc#1012628).
- Bluetooth: hidp: NUL terminate a string in the compat ioctl
  (bnc#1012628).
- Bluetooth: Check state in l2cap_disconnect_rsp (bnc#1012628).
- perf tests: Fix record+probe_libc_inet_pton.sh for powerpc64
  (bnc#1012628).
- genirq: Update irq stats from NMI handlers (bnc#1012628).
- Bluetooth: 6lowpan: search for destination address in all peers
  (bnc#1012628).
- Bluetooth: Add new 13d3:3501 QCA_ROME device (bnc#1012628).
- Bluetooth: Add new 13d3:3491 QCA_ROME device (bnc#1012628).
- Bluetooth: hci_bcsp: Fix memory leak in rx_skb (bnc#1012628).
- net: hns3: fix port capbility updating issue (bnc#1012628).
- net: hns3: enable broadcast promisc mode when initializing VF
  (bnc#1012628).
- tools: bpftool: Fix json dump crash on powerpc (bnc#1012628).
- ASoC: audio-graph-card: fix use-after-free in
  graph_for_each_link (bnc#1012628).
- iommu/arm-smmu-v3: Invalidate ATC when detaching a device
  (bnc#1012628).
- gpiolib: Fix references to gpiod_[gs]et_*value_cansleep()
  variants (bnc#1012628).
- bonding: validate ip header before check IPPROTO_IGMP
  (bnc#1012628).
- selftests: bpf: fix inlines in test_lwt_seg6local (bnc#1012628).
- bpf, libbpf, smatch: Fix potential NULL pointer dereference
  (bnc#1012628).
- libbpf: fix GCC8 warning for strncpy (bnc#1012628).
- rxrpc: Fix oops in tracepoint (bnc#1012628).
- net: usb: asix: init MAC address buffers (bnc#1012628).
- bnx2x: Prevent ptp_task to be rescheduled indefinitely
  (bnc#1012628).
- vxlan: do not destroy fdb if register_netdevice() is failed
  (bnc#1012628).
- perf stat: Fix group lookup for metric group (bnc#1012628).
- perf stat: Don't merge events in the same PMU (bnc#1012628).
- perf stat: Fix metrics with --no-merge (bnc#1012628).
- perf stat: Make metric event lookup more robust (bnc#1012628).
- ALSA: hda: Fix a headphone detection issue when using SOF
  (bnc#1012628).
- bnxt_en: Cap the returned MSIX vectors to the RDMA driver
  (bnc#1012628).
- bnxt_en: Fix statistics context reservation logic for RDMA
  driver (bnc#1012628).
- bnxt_en: Disable bus master during PCI shutdown and driver
  unload (bnc#1012628).
- iwlwifi: dbg: fix debug monitor stop and restart delays
  (bnc#1012628).
- netfilter: Fix remainder of pseudo-header protocol 0
  (bnc#1012628).
- bpf: fix uapi bpf_prog_info fields alignment (bnc#1012628).
- iwlwifi: mvm: Drop large non sta frames (bnc#1012628).
- ixgbe: Avoid NULL pointer dereference with VF on non-IPsec hw
  (bnc#1012628).
- net: ethernet: ti: cpsw: Assign OF node to slave devices
  (bnc#1012628).
- net: hns3: add Asym Pause support to fix autoneg problem
  (bnc#1012628).
- igb: clear out skb->tstamp after reading the txtime
  (bnc#1012628).
- net: mvpp2: prs: Don't override the sign bit in SRAM parser
  shift (bnc#1012628).
- ath10k: destroy sdio workqueue while remove sdio module
  (bnc#1012628).
- ath10k: Fix memory leak in qmi (bnc#1012628).
- net: hns3: add some error checking in hclge_tm module
  (bnc#1012628).
- net: hns3: fix a -Wformat-nonliteral compile warning
  (bnc#1012628).
- bcache: fix potential deadlock in cached_def_free()
  (bnc#1012628).
- bcache: avoid a deadlock in bcache_reboot() (bnc#1012628).
- bcache: check c->gc_thread by IS_ERR_OR_NULL in
  cache_set_flush() (bnc#1012628).
- bcache: acquire bch_register_lock later in cached_dev_free()
  (bnc#1012628).
- bcache: check CACHE_SET_IO_DISABLE bit in bch_journal()
  (bnc#1012628).
- bcache: check CACHE_SET_IO_DISABLE in allocator code
  (bnc#1012628).
- bcache: fix return value error in bch_journal_read()
  (bnc#1012628).
- net/mlx5e: Attach/detach XDP program safely (bnc#1012628).
- EDAC: Fix global-out-of-bounds write when setting
  edac_mc_poll_msec (bnc#1012628).
- wil6210: drop old event after wmi_call timeout (bnc#1012628).
- ath9k: correctly handle short radar pulses (bnc#1012628).
- crypto: asymmetric_keys - select CRYPTO_HASH where needed
  (bnc#1012628).
- crypto: serpent - mark __serpent_setkey_sbox noinline
  (bnc#1012628).
- ixgbe: Check DDM existence in transceiver before access
  (bnc#1012628).
- net/mlx5: Get vport ACL namespace by vport index (bnc#1012628).
- net: hns3: restore the MAC autoneg state after reset
  (bnc#1012628).
- gpio: Fix return value mismatch of function
  gpiod_get_from_of_node() (bnc#1012628).
- rslib: Fix handling of of caller provided syndrome
  (bnc#1012628).
- bpf: fix BPF_ALU32 | BPF_ARSH on BE arches (bnc#1012628).
- rslib: Fix decoding of shortened codes (bnc#1012628).
- xsk: Properly terminate assignment in xskq_produce_flush_desc
  (bnc#1012628).
- netfilter: ctnetlink: Fix regression in conntrack entry deletion
  (bnc#1012628).
- clocksource/drivers/exynos_mct: Increase priority over ARM
  arch timer (bnc#1012628).
- clocksource/drivers/tegra: Restore base address before cleanup
  (bnc#1012628).
- libata: don't request sense data on !ZAC ATA devices
  (bnc#1012628).
- clocksource/drivers/tegra: Release all IRQ's on request_irq()
  error (bnc#1012628).
- block, bfq: fix rq_in_driver check in bfq_update_inject_limit
  (bnc#1012628).
- ASoC: Intel: hdac_hdmi: Set ops to NULL on remove (bnc#1012628).
- perf tools: Increase MAX_NR_CPUS and MAX_CACHES (bnc#1012628).
- ALSA: hdac: Fix codec name after machine driver is unloaded
  and reloaded (bnc#1012628).
- ath10k: fix PCIE device wake up failed (bnc#1012628).
- ath10k: fix fw crash by moving chip reset after napi disabled
  (bnc#1012628).
- ath10k: add missing error handling (bnc#1012628).
- mt76: mt7615: do not process rx packets if the device is not
  initialized (bnc#1012628).
- ipvs: fix tinfo memory leak in start_sync_thread (bnc#1012628).
- mt7601u: fix possible memory leak when the device is
  disconnected (bnc#1012628).
- x86/build: Add 'set -e' to mkcapflags.sh to delete broken
  capflags.c (bnc#1012628).
- mt7601u: do not schedule rx_tasklet when the device has been
  disconnected (bnc#1012628).
- rtlwifi: rtl8192cu: fix error handle when usb probe failed
  (bnc#1012628).
- net: stmmac: sun8i: force select external PHY when no internal
  one (bnc#1012628).
- media: hdpvr: fix locking and a missing msleep (bnc#1012628).
- media: vimc: cap: check v4l2_fill_pixfmt return value
  (bnc#1012628).
- media: coda: increment sequence offset for the last returned
  frame (bnc#1012628).
- media: coda: fix last buffer handling in V4L2_ENC_CMD_STOP
  (bnc#1012628).
- media: coda: fix mpeg2 sequence number handling (bnc#1012628).
- acpi/arm64: ignore 5.1 FADTs that are reported as 5.0
  (bnc#1012628).
- ASoC: soc-core: call snd_soc_unbind_card() under mutex_lock;
  (bnc#1012628).
- media: mt9m111: fix fw-node refactoring (bnc#1012628).
- timer_list: Guard procfs specific code (bnc#1012628).
- ntp: Limit TAI-UTC offset (bnc#1012628).
- media: i2c: fix warning same module names (bnc#1012628).
- media: s5p-mfc: Make additional clocks optional (bnc#1012628).
- ipvs: defer hook registration to avoid leaks (bnc#1012628).
- media: staging: davinci: fix memory leaks and check for
  allocation failure (bnc#1012628).
- ipsec: select crypto ciphers for xfrm_algo (bnc#1012628).
- arm64: Do not enable IRQs for ct_user_exit (bnc#1012628).
- nvme-pci: adjust irq max_vector using num_possible_cpus()
  (bnc#1012628).
- lightnvm: fix uninitialized pointer in nvm_remove_tgt()
  (bnc#1012628).
- lightnvm: pblk: fix freeing of merged pages (bnc#1012628).
- nvme-pci: set the errno on ctrl state change error
  (bnc#1012628).
- nvme-pci: properly report state change failure in
  nvme_reset_work (bnc#1012628).
- nvme: fix possible io failures when removing multipathed ns
  (bnc#1012628).
- EDAC/sysfs: Fix memory leak when creating a csrow object
  (bnc#1012628).
- EDAC/sysfs: Drop device references properly (bnc#1012628).
- spi: fix ctrl->num_chipselect constraint (bnc#1012628).
- ACPICA: Clear status of GPEs on first direct enable
  (bnc#1012628).
- blk-iolatency: only account submitted bios (bnc#1012628).
- x86/cacheinfo: Fix a -Wtype-limits warning (bnc#1012628).
- net: netsec: initialize tx ring on ndo_open (bnc#1012628).
- PCI: Add missing link delays required by the PCIe spec
  (bnc#1012628).
- perf build: Handle slang being in /usr/include and in
  /usr/include/slang/ (bnc#1012628).
- bpf: fix callees pruning callers (bnc#1012628).
- tools build: Fix the zstd test in the test-all.c common case
  feature test (bnc#1012628).
- ASoC: rsnd: fixup mod ID calculation in rsnd_ctu_probe_
  (bnc#1012628).
- ipoib: correcly show a VF hardware address (bnc#1012628).
- iavf: allow null RX descriptors (bnc#1012628).
- vhost_net: disable zerocopy by default (bnc#1012628).
- perf evsel: Make perf_evsel__name() accept a NULL argument
  (bnc#1012628).
- x86/atomic: Fix smp_mb__{before,after}_atomic() (bnc#1012628).
- integrity: Fix __integrity_init_keyring() section mismatch
  (bnc#1012628).
- perf/x86/intel/uncore: Handle invalid event coding for
  free-running counter (bnc#1012628).
- perf/x86/intel: Disable check_msr for real HW (bnc#1012628).
- sched/fair: Fix "runnable_avg_yN_inv" not used warnings
  (bnc#1012628).
- perf/x86/intel: Add more Icelake CPUIDs (bnc#1012628).
- sched/core: Add __sched tag for io_schedule() (bnc#1012628).
- xfrm: fix sa selector validation (bnc#1012628).
- blkcg, writeback: dead memcgs shouldn't contribute to writeback
  ownership arbitration (bnc#1012628).
- block: null_blk: fix race condition for null_del_dev
  (bnc#1012628).
- net: hns3: delay ring buffer clearing during reset
  (bnc#1012628).
- net: hns3: fix for skb leak when doing selftest (bnc#1012628).
- net: hns3: fix for dereferencing before null checking
  (bnc#1012628).
- qed: iWARP - Fix tc for MPA ll2 connection (bnc#1012628).
- x86/cpufeatures: Add FDP_EXCPTN_ONLY and ZERO_FCS_FDS
  (bnc#1012628).
- perf/x86: Add Intel Ice Lake NNPI uncore support (bnc#1012628).
- rcu: Force inlining of rcu_read_lock() (bnc#1012628).
- ASoC: meson: axg-tdm: fix sample clock inversion (bnc#1012628).
- x86/cpu: Add Ice Lake NNPI to Intel family (bnc#1012628).
- crypto: testmgr - add some more preemption points (bnc#1012628).
- selinux: fix empty write to keycreate file (bnc#1012628).
- media: s5p-mfc: fix reading min scratch buffer size on MFC v6/v7
  (bnc#1012628).
- bpf: silence warning messages in core (bnc#1012628).
- media: davinci: vpif_capture: fix memory leak in vpif_probe()
  (bnc#1012628).
- gpio: omap: Fix lost edge wake-up interrupts (bnc#1012628).
- regmap: fix bulk writes on paged registers (bnc#1012628).
- gpio: omap: ensure irq is enabled before wakeup (bnc#1012628).
- gpio: omap: fix lack of irqstatus_raw0 for OMAP4 (bnc#1012628).
- iommu: Fix a leak in iommu_insert_resv_region (bnc#1012628).
- media: fdp1: Support M3N and E3 platforms (bnc#1012628).
- media: uvcvideo: Fix access to uninitialized fields on probe
  error (bnc#1012628).
- irqchip/meson-gpio: Add support for Meson-G12A SoC
  (bnc#1012628).
- selftests/bpf : clean up feature/ when make clean (bnc#1012628).
- perf report: Fix OOM error in TUI mode on s390 (bnc#1012628).
- perf test 6: Fix missing kvm module load for s390 (bnc#1012628).
- perf cs-etm: Properly set the value of 'old' and 'head' in
  snapshot mode (bnc#1012628).
- ipset: Fix memory accounting for hash types on resize
  (bnc#1012628).
- netfilter: ipset: fix a missing check of nla_parse
  (bnc#1012628).
- net: sfp: add mutex to prevent concurrent state checks
  (bnc#1012628).
- RAS/CEC: Fix pfn insertion (bnc#1012628).
- s390/qdio: handle PENDING state for QEBSM devices (bnc#1012628).
- net: axienet: Fix race condition causing TX hang (bnc#1012628).
- net: fec: Do not use netdev messages too early (bnc#1012628).
- crypto: inside-secure - do not rely on the hardware last bit
  for result descriptors (bnc#1012628).
- net: stmmac: modify default value of tx-frames (bnc#1012628).
- net: stmmac: dwmac4: fix flow control issue (bnc#1012628).
- media: aspeed: fix a kernel warning on clk control
  (bnc#1012628).
- media: aspeed: change irq to threaded irq (bnc#1012628).
- perf jvmti: Address gcc string overflow warning for strncpy()
  (bnc#1012628).
- media: imx7-mipi-csis: Propagate the error if clock enabling
  fails (bnc#1012628).
- arm64: mm: make CONFIG_ZONE_DMA32 configurable (bnc#1012628).
- cpupower : frequency-set -r option misses the last cpu in
  related cpu list (bnc#1012628).
- net: hns3: set ops to null when unregister ad_dev (bnc#1012628).
- net: hns3: add a check to pointer in error_detected and
  slot_reset (bnc#1012628).
- media: wl128x: Fix some error handling in
  fm_v4l2_init_video_device() (bnc#1012628).
- media: platform: ao-cec-g12a: disable regmap fast_io for cec
  bus regmap (bnc#1012628).
- locking/lockdep: Fix merging of hlocks with non-zero references
  (bnc#1012628).
- locking/lockdep: Fix OOO unlock when hlocks need merging
  (bnc#1012628).
- batman-adv: Fix duplicated OGMs on NETDEV_UP (bnc#1012628).
- tua6100: Avoid build warnings (bnc#1012628).
- crypto: talitos - Align SEC1 accesses to 32 bits boundaries
  (bnc#1012628).
- crypto: talitos - properly handle split ICV (bnc#1012628).
- net: dsa: sja1105: Fix broken fixed-link interfaces on user
  ports (bnc#1012628).
- net: phy: Check against net_device being NULL (bnc#1012628).
- media: staging: media: davinci_vpfe: - Fix for memory leak if
  decoder initialization fails (bnc#1012628).
- ASoC: Intel: sof-rt5682: fix undefined references with
  Baytrail-only support (bnc#1012628).
- media: saa7164: fix remove_proc_entry warning (bnc#1012628).
- media: mc-device.c: don't memset __user pointer contents
  (bnc#1012628).
- ice: Check all VFs for MDD activity, don't disable
  (bnc#1012628).
- perf annotate TUI browser: Do not use member from variable
  within its own initialization (bnc#1012628).
- media: usb:zr364xx:Fix KASAN:null-ptr-deref Read in
  zr364xx_vidioc_querycap (bnc#1012628).
- fscrypt: clean up some BUG_ON()s in block encryption/decryption
  (bnc#1012628).
- media: v4l2-core: fix use-after-free error (bnc#1012628).
- media: vim2m: fix two double-free issues (bnc#1012628).
- xfrm: Fix xfrm sel prefix length validation (bnc#1012628).
- af_key: fix leaks in key_pol_get_resp and dump_sp (bnc#1012628).
- signal/pid_namespace: Fix reboot_pid_ns to use send_sig not
  force_sig (bnc#1012628).
- qed: Set the doorbell address correctly (bnc#1012628).
- net: hns3: fix for FEC configuration (bnc#1012628).
- net: hns3: initialize CPU reverse mapping (bnc#1012628).
- net: mvpp2: cls: Extract the RSS context when parsing the
  ethtool rule (bnc#1012628).
- ice: Fix couple of issues in ice_vsi_release (bnc#1012628).
- net: stmmac: Prevent missing interrupts when running NAPI
  (bnc#1012628).
- net: stmmac: dwmac4/5: Clear unused address entries
  (bnc#1012628).
- net: stmmac: dwmac1000: Clear unused address entries
  (bnc#1012628).
- crypto: caam - avoid S/G table fetching for AEAD zero-length
  output (bnc#1012628).
- media: venus: firmware: fix leaked of_node references
  (bnc#1012628).
- ice: Gracefully handle reset failure in ice_alloc_vfs()
  (bnc#1012628).
- media: media_device_enum_links32: clean a reserved field
  (bnc#1012628).
- media: vpss: fix a potential NULL pointer dereference
  (bnc#1012628).
- selftests/bpf: adjust verifier scale test (bnc#1012628).
- media: marvell-ccic: fix DMA s/g desc number calculation
  (bnc#1012628).
- media: ov7740: avoid invalid framesize setting (bnc#1012628).
- crypto: talitos - fix skcipher failure due to wrong output IV
  (bnc#1012628).
- media: spi: IR LED: add missing of table registration
  (bnc#1012628).
- media: dvb: usb: fix use after free in dvb_usb_device_exit
  (bnc#1012628).
- batman-adv: fix for leaked TVLV handler (bnc#1012628).
- regmap: debugfs: Fix memory leak in regmap_debugfs_init
  (bnc#1012628).
- ath10k: Fix encoding for protected management frames
  (bnc#1012628).
- ath: DFS JP domain W56 fixed pulse type 3 RADAR detection
  (bnc#1012628).
- wil6210: fix spurious interrupts in 3-msi (bnc#1012628).
- ath10k: add peer id check in ath10k_peer_find_by_id
  (bnc#1012628).
- ath6kl: add some bounds checking (bnc#1012628).
- wil6210: fix missed MISC mbox interrupt (bnc#1012628).
- ath10k: Fix the wrong value of enums for wmi tlv stats id
  (bnc#1012628).
- ath9k: Check for errors when reading SREV register
  (bnc#1012628).
- spi: rockchip: turn down tx dma bursts (bnc#1012628).
- ath10k: Do not send probe response template for mesh
  (bnc#1012628).
- wil6210: fix potential out-of-bounds read (bnc#1012628).
- ath9k: Don't trust TX status TID number when reporting airtime
  (bnc#1012628).
- ath10k: fix incorrect multicast/broadcast rate setting
  (bnc#1012628).
- ath10k: htt: don't use txdone_fifo with SDIO (bnc#1012628).
- ath10k: Check tx_stats before use it (bnc#1012628).
- commit f5296b5
* Wed Jul 24 2019 msuchanek@suse.de
- dma-mapping: use dma_get_mask in dma_addressing_limited
  (https://lore.kernel.org/lkml/cda1952f-0265-e055-a3ce-237c59069a3f@suse.com/T/#u).
- commit c584343
* Wed Jul 24 2019 msuchanek@suse.de
- scripts/arch-symbols: add missing link.
- commit ee7c635
* Tue Jul 23 2019 tiwai@suse.de
- rpm/config.sh: enable kernel module compression (bsc#1135854)
- commit b333e24
* Tue Jul 23 2019 tiwai@suse.de
- Add kernel module compression support (bsc#1135854)
  For enabling the kernel module compress, add the item COMPRESS_MODULES="xz"
  in config.sh, then mkspec will pass it to the spec file.
- commit cdf5806
* Tue Jul 23 2019 msuchanek@suse.de
- Workaround gcc regression on ppc64 (bko#204125).
- commit 8b84d1d
* Tue Jul 23 2019 msuchanek@suse.de
- config.conf: Add ppc64 kvmsmall config (bsc#1137361).
- Remove superfluous i2c drivers from ppc64 config
  - CONFIG_I2C_ALGOPCA=m
  - CONFIG_I2C_AMD8111=m
  - CONFIG_I2C_CBUS_GPIO=m
  - CONFIG_I2C_DESIGNWARE_CORE=y
  - CONFIG_I2C_DESIGNWARE_PLATFORM=y
  - CONFIG_I2C_DESIGNWARE_PCI=m
  - CONFIG_I2C_OCORES=m
  - CONFIG_I2C_PCA_PLATFORM=m
  Can't get rid of i2c in kvmsmall anyway but at least the DW i2c is gone.
- commit 3d0102c
* Tue Jul 23 2019 jeffm@suse.com
- config: enable PPPoE for kvmsmall (bsc#1133945).
- commit 72c928d
* Mon Jul 22 2019 jeffm@suse.com
- config: remove unnecessary drivers from kvmsmall
  The initial merge was incomplete and needed revisiting, which didn't really
  happen.  Since then, new options have been added and not removed from
  kvmsmall, leading to grow in size.
  This commit uses the following blacklist:
  _(BT|CHARGER|CHROMEOS|CROS|DVB|DW|EDAC|FPGA|GPIO|GNSS|HID|INFINIBAND|IR|JOYSTICK|LEDS|MFD|PINCTRL|REGULATOR|RTC|SENSORS|SND_SOC|STAGING|TOUCHSCREEN|VIDEO|XEN|XILINX)[_=]
  ... along with some manual removal of NET_VENDORs with no relevant drivers.
- commit e850d85
* Mon Jul 22 2019 mkubecek@suse.cz
- rpm/klp-symbols: update to work with kernel >= 5.3
  Since mainline commit b7dca6dd1e59 ("kbuild: create *.mod with full
  directory path and remove MODVERDIR") in v5.3-rc1, *.mod files are created
  in the build tree rather than in a single directory .tmp_versions
  ($MODVERDIR). They also do not provide path to the *.ko module file on
  their first line as the path is the same (except for the suffix).
  Update klp-symbols script to handle this new layout and format of *.mod
  files to fix build of 5.3-rc1 and newer kernel.
  Note: this is a quick band-aid to fix master branch build without risk of
  breaking any other branch. A more proper cleanup will follow.
- commit c32f8e7
* Mon Jul 22 2019 mkubecek@suse.cz
- Update to 5.3-rc1
- Eliminated 89 patches (83 stable, 6 other)
- ARM configs need update
- Refresh
  patches.suse/btrfs-8447-serialize-subvolume-mounts-with-potentially-mi.patch
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  patches.suse/netfilter-ip_conntrack_slp.patch
  patches.suse/rpm-kernel-config
  patches.suse/supported-flag
  patches.suse/vfs-add-super_operations-get_inode_dev
- replace patches.rpmify/BPF-UMH-do-not-detect-if-compiler-can-link-userspace.patch
  with patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch
- New config options:
  - General setup
  - HEADER_TEST=y
  - KERNEL_HEADER_TEST=y
  - PREEMPT_LL=n
  - UCLAMP_TASK=y
  - UCLAMP_BUCKETS_COUNT=5
  - Processor type and features
  - ACRN_GUEST=y
  - LEGACY_VSYSCALL_XONLY=y
  - IO Schedulers
  - BFQ_CGROUP_DEBUG=n (=y in */debug)
  - Networking
  - NFT_SYNPROXY=m
  - NFT_BRIDGE_META=m
  - NF_CONNTRACK_BRIDGE=m
  - NET_ACT_MPLS=m
  - NET_ACT_CTINFO=m
  - NET_ACT_CT=m
  - BT_HCIBTUSB_MTK=y
  - GVE=m
  - MLX5_FPGA_IPSEC=y
  - MLX5_FPGA_TLS=y
  - MLX5_TLS=y
  - STMMAC_SELFTESTS=n
  - XILINX_AXI_EMAC=m
  - SFP=m
  - NXP_TJA11XX_PHY=m
  - PHY_MIXEL_MIPI_DPHY=m
  - File systems
  - UBIFS_FS_ZSTD=y
  - SUNRPC_DISABLE_INSECURE_ENCTYPES=n
  - CEPH_FS_SECURITY_LABEL=y
  - Generic driver options
  - FW_LOADER_COMPRESS=y
  - Storage
  - SCSI_FDOMAIN_PCI=m
  - SCSI_FDOMAIN_ISA=n
  - PCMCIA_FDOMAIN=n
  - Input
  - KEYBOARD_APPLESPI=m
  - Power supply and hardware monitoring
  - POWER_SUPPLY_HWMON=y
  - CHARGER_WILCO=m
  - SENSORS_IRPS5401=m
  - SENSORS_PXE1610=m
  - REGULATOR_ARIZONA_LDO1=m
  - REGULATOR_ARIZONA_MICSUPP=m
  - REGULATOR_SLG51000=m
  - Multimedia
  - DVB_USB_CXUSB_ANALOG=y
  - VIDEO_TDA1997X=m
  - VIDEO_TLV320AIC23B=m
  - VIDEO_ADV7180=m
  - VIDEO_ADV7183=m
  - VIDEO_ADV7604=m
  - VIDEO_ADV7604_CEC=y
  - VIDEO_ADV7842=m
  - VIDEO_ADV7842_CEC=y
  - VIDEO_BT819=m
  - VIDEO_BT856=m
  - VIDEO_BT866=m
  - VIDEO_KS0127=m
  - VIDEO_ML86V7667=m
  - VIDEO_SAA7110=m
  - VIDEO_TC358743=m
  - VIDEO_TC358743_CEC=y
  - VIDEO_TVP514X=m
  - VIDEO_TVP7002=m
  - VIDEO_TW9910=m
  - VIDEO_VPX3220=m
  - VIDEO_SAA7185=m
  - VIDEO_ADV7170=m
  - VIDEO_ADV7175=m
  - VIDEO_ADV7343=m
  - VIDEO_ADV7393=m
  - VIDEO_ADV7511=m
  - VIDEO_ADV7511_CEC=y
  - VIDEO_AD9389B=m
  - VIDEO_AK881X=m
  - VIDEO_THS8200=m
  - VIDEO_IMX214=m
  - VIDEO_IMX258=m
  - VIDEO_IMX274=m
  - VIDEO_IMX319=m
  - VIDEO_IMX355=m
  - VIDEO_OV2659=m
  - VIDEO_OV2680=m
  - VIDEO_OV2685=m
  - VIDEO_OV5647=m
  - VIDEO_OV6650=m
  - VIDEO_OV5670=m
  - VIDEO_OV5695=m
  - VIDEO_OV7251=m
  - VIDEO_OV772X=m
  - VIDEO_OV7740=m
  - VIDEO_OV8856=m
  - VIDEO_OV9640=m
  - VIDEO_OV9650=m
  - VIDEO_OV13858=m
  - VIDEO_VS6624=m
  - VIDEO_MT9M001=m
  - VIDEO_MT9M032=m
  - VIDEO_MT9M111=m
  - VIDEO_MT9P031=m
  - VIDEO_MT9T001=m
  - VIDEO_MT9T112=m
  - VIDEO_MT9V032=m
  - VIDEO_MT9V111=m
  - VIDEO_SR030PC30=m
  - VIDEO_NOON010PC30=m
  - VIDEO_M5MOLS=m
  - VIDEO_RJ54N1=m
  - VIDEO_S5K6AA=m
  - VIDEO_S5K6A3=m
  - VIDEO_S5K4ECGX=m
  - VIDEO_S5K5BAF=m
  - VIDEO_SMIAPP=m
  - VIDEO_ET8EK8=m
  - VIDEO_S5C73M3=m
  - VIDEO_AD5820=m
  - VIDEO_AK7375=m
  - VIDEO_DW9714=m
  - VIDEO_DW9807_VCM=m
  - VIDEO_ADP1653=m
  - VIDEO_LM3560=m
  - VIDEO_LM3646=m
  - SDR_MAX2175=m
  - VIDEO_THS7303=m
  - VIDEO_I2C=m
  - VIDEO_ST_MIPID02=n
  - VIDEO_GS1662=m
  - DVB_S5H1432=m
  - DVB_DIB9000=m
  - DVB_CXD2880=m
  - DVB_MN88443X=m
  - DVB_LNBH29=m
  - DVB_LGS8GL5=m
  - Graphics
  - DRM_AMD_DC_DCN2_0=y
  - DRM_AMD_DC_DSC_SUPPORT=y
  - DRM_I915_FORCE_PROBE=""
  - DRM_I915_DEBUG_MMIO=n
  - DRM_I915_USERFAULT_AUTOSUSPEND=250
  - DRM_I915_SPIN_REQUEST=5
  - DRM_PANEL_OSD_OSD101T2587_53TS=m
  - DRM_PANEL_SAMSUNG_S6E63M0=m
  - Sound
  - SND_SOC_INTEL_CML_H=m
  - SND_SOC_INTEL_CML_LP=m
  - SND_SOC_INTEL_BYT_CHT_CX2072X_MACH=m
  - SND_SOC_SOF_COMETLAKE_LP_SUPPORT=y
  - SND_SOC_SOF_COMETLAKE_H_SUPPORT=y
  - SND_SOC_CX2072X=m
  - InfiniBand
  - RDMA_SIW=m
  - Platform specific drivers
  - XIAOMI_WMI=m
  - ACPI_CMPC=m
  - SAMSUNG_Q10=m
  - INTEL_SPEED_SELECT_INTERFACE=m
  - CROS_EC_ISHTP=m
  - WILCO_EC_EVENTS=m
  - WILCO_EC_TELEMETRY=m
  - Industrial I/O
  - XILINX_XADC=n
  - ADF4371=n
  - DPS310=n
  - LEDs
  - LEDS_SPI_BYTE=m
  - LEDS_TI_LMU_COMMON=m
  - LEDS_LM3697=m
  - LEDS_LM36274=m
  - Other drivers
  - MTD_HYPERBUS=m
  - HBMC_AM654=m
  - XILINX_SDFEC=n
  - GPIO_XILINX=m
  - WATCHDOG_OPEN_TIMEOUT=0
  - MFD_CS47L15=y
  - MFD_CS47L92=y
  - MFD_ROHM_BD70528=n
  - RTC_DRV_BD70528=m
  - DW_EDMA=m
  - DW_EDMA_PCIE=m
  - COMMON_CLK_SI5341=m
  - EXTCON_FSA9480=m
  - NTB_MSI=y
  - NTB_MSI_TEST=n
  - RAS_CEC_DEBUG=n
  - AL_FIC=n
  - Virtualization
  - VIRTIO_PMEM=m
  - Security options
  - KEYS_REQUEST_CACHE=y
  - Kernel hardening options
  - INIT_ON_ALLOC_DEFAULT_ON=n
  - INIT_ON_FREE_DEFAULT_ON=n
  - Cryptographic API
  - CRYPTO_XXHASH=n
  - CRYPTO_DEV_ATMEL_ECC=m
  - CRYPTO_DEV_ATMEL_SHA204A=m
  - Kernel hacking
  - HEADERS_INSTALL=n
  - REED_SOLOMON_TEST=n
  - TEST_BLACKHOLE_DEV=n
  - TEST_MEMINIT=n
- commit 0a6d0d9
* Sun Jul 21 2019 mkubecek@suse.cz
- Revert "netfilter: conntrack: remove helper hook again"
  (http://lkml.kernel.org/r/20190718092128.zbw4qappq6jsb4ja@breakpoint.cc).
- commit 8e9a006
* Sun Jul 21 2019 jslaby@suse.cz
- Linux 5.2.2 (bnc#1012628).
- x86/entry/32: Fix ENDPROC of common_spurious (bnc#1012628).
- crypto/NX: Set receive window credits to max number of CRBs
  in RxFIFO (bnc#1012628).
- crypto: talitos - fix hash on SEC1 (bnc#1012628).
- crypto: talitos - move struct talitos_edesc into talitos.h
  (bnc#1012628).
- s390/qdio: don't touch the dsci in tiqdio_add_input_queues()
  (bnc#1012628).
- s390/qdio: (re-)initialize tiqdio list entries (bnc#1012628).
- s390: fix stfle zero padding (bnc#1012628).
- s390/ipl: Fix detection of has_secure attribute (bnc#1012628).
- ARC: hide unused function unw_hdr_alloc (bnc#1012628).
- x86/irq: Seperate unused system vectors from spurious entry
  again (bnc#1012628).
- x86/irq: Handle spurious interrupt after shutdown gracefully
  (bnc#1012628).
- x86/ioapic: Implement irq_get_irqchip_state() callback
  (bnc#1012628).
- genirq: Add optional hardware synchronization for shutdown
  (bnc#1012628).
- genirq: Fix misleading synchronize_irq() documentation
  (bnc#1012628).
- genirq: Delay deactivation in free_irq() (bnc#1012628).
- firmware: improve LSM/IMA security behaviour (bnc#1012628).
- drivers: base: cacheinfo: Ensure cpu hotplug work is done
  before Intel RDT (bnc#1012628).
- nilfs2: do not use unexported cpu_to_le32()/le32_to_cpu()
  in uapi header (bnc#1012628).
- Input: synaptics - enable SMBUS on T480 thinkpad trackpad
  (bnc#1012628).
- e1000e: start network tx queue only when link is up
  (bnc#1012628).
- Revert "e1000e: fix cyclic resets at link up with active tx"
  (bnc#1012628).
- commit 93f0a54
* Tue Jul 16 2019 lpechacek@suse.com
- rpm/kernel-binary.spec.in: build kernel-*-kgraft only for default SLE kernel
  RT and Azure variants are excluded for the moment. (bsc#1141600)
- commit 620816f
* Sun Jul 14 2019 jslaby@suse.cz
- Linux 5.2.1 (bnc#1012628).
- staging: rtl8712: reduce stack usage, again (bnc#1012628).
- staging: bcm2835-camera: Handle empty EOS buffers whilst
  streaming (bnc#1012628).
- staging: bcm2835-camera: Remove check of the number of buffers
  supplied (bnc#1012628).
- staging: bcm2835-camera: Ensure all buffers are returned on
  disable (bnc#1012628).
- staging: bcm2835-camera: Replace spinlock protecting context_map
  with mutex (bnc#1012628).
- staging: fsl-dpaa2/ethsw: fix memory leak of switchdev_work
  (bnc#1012628).
- staging: vchiq: revert "switch to wait_for_completion_killable"
  (bnc#1012628).
- staging: vchiq: make wait events interruptible (bnc#1012628).
- staging: vchiq_2835_arm: revert "quit using custom
  down_interruptible()" (bnc#1012628).
- VMCI: Fix integer overflow in VMCI handle arrays (bnc#1012628).
- Revert "x86/build: Move _etext to actual end of .text"
  (bnc#1012628).
- carl9170: fix misuse of device driver API (bnc#1012628).
- coresight: tmc-etf: Do not call smp_processor_id from
  preemptible (bnc#1012628).
- coresight: tmc-etr: alloc_perf_buf: Do not call smp_processor_id
  from preemptible (bnc#1012628).
- coresight: tmc-etr: Do not call smp_processor_id() from
  preemptible (bnc#1012628).
- coresight: etb10: Do not call smp_processor_id from preemptible
  (bnc#1012628).
- coresight: Potential uninitialized variable in probe()
  (bnc#1012628).
- iio: adc: stm32-adc: add missing vdda-supply (bnc#1012628).
- binder: return errors from buffer copy functions (bnc#1012628).
- binder: fix memory leak in error path (bnc#1012628).
- lkdtm: support llvm-objcopy (bnc#1012628).
- HID: Add another Primax PIXART OEM mouse quirk (bnc#1012628).
- staging: mt7621-pci: fix PCIE_FTS_NUM_LO macro (bnc#1012628).
- staging: comedi: amplc_pci230: fix null pointer deref on
  interrupt (bnc#1012628).
- staging: bcm2835-camera: Restore return behavior of
  ctrl_set_bitrate() (bnc#1012628).
- staging: wilc1000: fix error path cleanup in
  wilc_wlan_initialize() (bnc#1012628).
- staging: comedi: dt282x: fix a null pointer deref on interrupt
  (bnc#1012628).
- p54: fix crash during initialization (bnc#1012628).
- drivers/usb/typec/tps6598x.c: fix 4CC cmd write (bnc#1012628).
- drivers/usb/typec/tps6598x.c: fix portinfo width (bnc#1012628).
- usb: renesas_usbhs: add a workaround for a race condition of
  workqueue (bnc#1012628).
- usb: dwc2: use a longer AHB idle timeout in dwc2_core_reset()
  (bnc#1012628).
- usb: gadget: ether: Fix race between gether_disconnect and
  rx_submit (bnc#1012628).
- usb: gadget: f_fs: data_len used before properly set
  (bnc#1012628).
- p54usb: Fix race between disconnect and firmware loading
  (bnc#1012628).
- Revert "serial: 8250: Don't service RX FIFO if interrupts are
  disabled" (bnc#1012628).
- USB: serial: option: add support for GosunCn ME3630 RNDIS mode
  (bnc#1012628).
- USB: serial: ftdi_sio: add ID for isodebug v1 (bnc#1012628).
- mwifiex: Don't abort on small, spec-compliant vendor IEs
  (bnc#1012628).
- Documentation/admin: Remove the vsyscall=native documentation
  (bnc#1012628).
- Documentation: Add section about CPU vulnerabilities for Spectre
  (bnc#1012628).
- x86/tls: Fix possible spectre-v1 in do_get_thread_area()
  (bnc#1012628).
- x86/ptrace: Fix possible spectre-v1 in ptrace_get_debugreg()
  (bnc#1012628).
- perf header: Assign proper ff->ph in
  perf_event__synthesize_features() (bnc#1012628).
- perf thread-stack: Fix thread stack return from kernel for
  kernel-only case (bnc#1012628).
- perf pmu: Fix uncore PMU alias list for ARM64 (bnc#1012628).
- perf intel-pt: Fix itrace defaults for perf script intel-pt
  documentation (bnc#1012628).
- perf auxtrace: Fix itrace defaults for perf script
  (bnc#1012628).
- perf intel-pt: Fix itrace defaults for perf script
  (bnc#1012628).
- block, bfq: NULL out the bic when it's no longer valid
  (bnc#1012628).
- block: fix .bi_size overflow (bnc#1012628).
- tpm: Fix TPM 1.2 Shutdown sequence to prevent future TPM
  operations (bnc#1012628).
- tpm: Actually fail on TPM errors during "get random"
  (bnc#1012628).
- ALSA: hda/realtek - Headphone Mic can't record after S3
  (bnc#1012628).
- ALSA: usb-audio: Fix parse of UAC2 Extension Units
  (bnc#1012628).
- media: stv0297: fix frequency range limit (bnc#1012628).
- udf: Fix incorrect final NOT_ALLOCATED (hole) extent length
  (bnc#1012628).
- fscrypt: don't set policy for a dead directory (bnc#1012628).
- crypto: talitos - rename alternative AEAD algos (bnc#1012628).
- crypto: lrw - use correct alignmask (bnc#1012628).
- commit 51ca500
* Thu Jul 11 2019 glin@suse.com
- net: bpfilter: print umh messages to /dev/kmsg (bsc#1140221).
- commit 139acc9
* Wed Jul 10 2019 jslaby@suse.cz
- series.conf: sync with master
- commit 80522d2
* Wed Jul 10 2019 jslaby@suse.cz
- rpm/kernel-binary.spec.in: handle modules.builtin.modinfo
  It was added in 5.2.
- commit eb88df3
* Tue Jul  9 2019 rgoldwyn@suse.com
- Disable CONFIG_OVERLAY_FS_REDIRECT_ALWAYS_FOLLOW in config (bsc#1140494)
- commit 8d950e4
* Tue Jul  9 2019 schwab@suse.de
- Build against openSUSE:Factory:RISCV for riscv64
- commit 74d6e96
* Tue Jul  9 2019 jslaby@suse.cz
- Delete patches.suse/Revert-ovl-detect-overlapping-layers.patch.
- Delete
  patches.suse/Revert-ovl-don-t-fail-with-disconnected-lower-NFS.patch.
- Delete
  patches.suse/Revert-ovl-fix-bogus-Wmaybe-unitialized-warning.patch.
  transactional-update was fixed, see sr#714110.
- commit 927afc9
* Mon Jul  8 2019 mkubecek@suse.cz
- Update to 5.2 final
- Eliminated 1 patch
- commit b36439f
* Sun Jul  7 2019 msuchanek@suse.de
- Refresh tpm: tpm_ibm_vtpm: Fix unallocated banks (boo#1139244).
- commit 99f9469
* Fri Jul  5 2019 tiwai@suse.de
- config: align CONFIG_PHYSICAL_START and CONFIG_PHYSICAL_ALIGN to default values
  As suggested in bsc#1067593, our kconfig keeps the old default values
  while the upstream took different (actually swapped) values for x86
  CONFIG_PHYSICAL_START and CONFIG_PHYSICAL_ALIGN.   Let's follow the
  upstream default now.
- commit baa2434
* Fri Jul  5 2019 mkubecek@suse.cz
- Rename patches.suse/[PATCH]_tpm:_fixes_uninitialized_allocated_banks_for_IBM_vtpm_driver
  to patches.suse/tpm-fixes-uninitialized-allocated-banks-for-IBM-vtpm-driver.patch
  Let's not risk some tool somewhere does not handle special characters correctly.
- commit 8a3fff9
* Thu Jul  4 2019 msuchanek@suse.de
- tpm: fixes uninitialized allocated banks for IBM vtpm driver
  (boo#1139244).
- Delete patches.suse/Revert-tpm-pass-an-array-of-tpm_extend_digest-struct.patch.
- commit 43ec0a5
* Wed Jul  3 2019 msuchanek@suse.de
- crypto: user - prevent operating on larval algorithms
  (bsc#1133401).
- Delete patches.suse/crypto-algapi-guard-against-uninitialized-spawn-list.patch.
- commit 90eea5d
* Wed Jul  3 2019 schwab@suse.de
- rpm/dtb.spec.in.in: don't make dtb directory inaccessible
  There is no reason to lock down the dtb directory for ordinary users.
- commit a69437a
* Wed Jul  3 2019 jslaby@suse.cz
- Linux 5.1.16 (bnc#1012628).
- arm64: insn: Fix ldadd instruction encoding (bnc#1012628).
- tipc: pass tunnel dev as NULL to udp_tunnel(6)_xmit_skb
  (bnc#1012628).
- fanotify: update connector fsid cache on add mark (bnc#1012628).
- RDMA: Directly cast the sockaddr union to sockaddr
  (bnc#1012628).
- futex: Update comments and docs about return values of arch
  futex code (bnc#1012628).
- bpf, arm64: use more scalable stadd over ldxr / stxr loop in
  xadd (bnc#1012628).
- arm64: futex: Avoid copying out uninitialised stack in failed
  cmpxchg() (bnc#1012628).
- bpf: udp: ipv6: Avoid running reuseport's bpf_prog from
  __udp6_lib_err (bnc#1012628).
- bpf: udp: Avoid calling reuseport's bpf_prog from udp_gro
  (bnc#1012628).
- bpf: fix unconnected udp hooks (bnc#1012628).
- bpf: fix nested bpf tracepoints with per-cpu data (bnc#1012628).
- bpf: lpm_trie: check left child of last leftmost node for NULL
  (bnc#1012628).
- bpf: simplify definition of BPF_FIB_LOOKUP related flags
  (bnc#1012628).
- net: aquantia: fix vlans not working over bridged network
  (bnc#1012628).
- tun: wake up waitqueues after IFF_UP is set (bnc#1012628).
- tipc: check msg->req data len in tipc_nl_compat_bearer_disable
  (bnc#1012628).
- tipc: change to use register_pernet_device (bnc#1012628).
- team: Always enable vlan tx offload (bnc#1012628).
- sctp: change to hold sk after auth shkey is created successfully
  (bnc#1012628).
- net/tls: fix page double free on TX cleanup (bnc#1012628).
- net: stmmac: set IC bit when transmitting frames with HW
  timestamp (bnc#1012628).
- net: stmmac: fixed new system time seconds value calculation
  (bnc#1012628).
- net: remove duplicate fetch in sock_getsockopt (bnc#1012628).
- net/packet: fix memory leak in packet_set_ring() (bnc#1012628).
- ipv4: Use return value of inet_iif() for __raw_v4_lookup in
  the while loop (bnc#1012628).
- bonding: Always enable vlan tx offload (bnc#1012628).
- af_packet: Block execution of tasks waiting for transmit to
  complete in AF_PACKET (bnc#1012628).
- irqchip/mips-gic: Use the correct local interrupt map registers
  (bnc#1012628).
- SUNRPC: Fix up calculation of client message length
  (bnc#1012628).
- cpu/speculation: Warn on unsupported mitigations= parameter
  (bnc#1012628).
- NFS/flexfiles: Use the correct TCP timeout for flexfiles I/O
  (bnc#1012628).
- efi/memreserve: deal with memreserve entries in unmapped memory
  (bnc#1012628).
- mm: fix page cache convergence regression (bnc#1012628).
- x86/resctrl: Prevent possible overrun during bitmap operations
  (bnc#1012628).
- x86/microcode: Fix the microcode load on CPU hotplug for real
  (bnc#1012628).
- x86/speculation: Allow guests to use SSBD even if host does not
  (bnc#1012628).
- scsi: vmw_pscsi: Fix use-after-free in pvscsi_queue_lck()
  (bnc#1012628).
- io_uring: ensure req->file is cleared on allocation
  (bnc#1012628).
- dm log writes: make sure super sector log updates are written
  in order (bnc#1012628).
- dm init: fix incorrect uses of kstrndup() (bnc#1012628).
- mm, swap: fix THP swap out (bnc#1012628).
- mm/page_idle.c: fix oops because end_pfn is larger than max_pfn
  (bnc#1012628).
- mm: hugetlb: soft-offline: dissolve_free_huge_page() return
  zero on !PageHuge (bnc#1012628).
- mm: soft-offline: return -EBUSY if
  set_hwpoison_free_buddy_page() fails (bnc#1012628).
- drm/i915: Skip modeset for cdclk changes if possible
  (bnc#1012628).
- drm/i915: Remove redundant store of logical CDCLK state
  (bnc#1012628).
- drm/i915: Save the old CDCLK atomic state (bnc#1012628).
- drm/i915: Force 2*96 MHz cdclk on glk/cnl when audio power is
  enabled (bnc#1012628).
- clk: socfpga: stratix10: fix divider entry for the emac clocks
  (bnc#1012628).
- clk: tegra210: Fix default rates for HDA clocks (bnc#1012628).
- fs/binfmt_flat.c: make load_flat_shared_library() work
  (bnc#1012628).
- mm/mempolicy.c: fix an incorrect rebind node in
  mpol_rebind_nodemask (bnc#1012628).
- fs/proc/array.c: allow reporting eip/esp for all coredumping
  threads (bnc#1012628).
- qmi_wwan: Fix out-of-bounds read (bnc#1012628).
- Revert "x86/uaccess, ftrace: Fix ftrace_likely_update()
  vs. SMAP" (bnc#1012628).
- arm64: Don't unconditionally add -Wno-psabi to KBUILD_CFLAGS
  (bnc#1012628).
- commit 2af8a22
* Wed Jul  3 2019 jslaby@suse.cz
- Update config files.
  Set CONFIG_SCSI_SCAN_ASYNC=y (bnc#1137686).
- commit a156b11
* Wed Jul  3 2019 mkubecek@suse.cz
- config: switch to SLUB allocator (Jira:PM-1158)
- new config options:
  - SLUB=y
  - SLUB_DEBUG=y
  - SLUB_MEMCG_SYSFS_ON=y
  - SLAB_FREELIST_HARDENED=n
  - SLUB_CPU_PARTIAL=y
  - SLUB_DEBUG_ON=n
  - SLUB_STATS=n
- commit 0ab8cfd
* Tue Jul  2 2019 jslaby@suse.cz
- Update patches.suse/Revert-ovl-detect-overlapping-layers.patch
  (bnc#1140057).
- Update
  patches.suse/Revert-ovl-don-t-fail-with-disconnected-lower-NFS.patch
  (bnc#1140057).
- Update
  patches.suse/Revert-ovl-fix-bogus-Wmaybe-unitialized-warning.patch
  (bnc#1140057).
  Add bnc to references.
- commit 512bcbe
* Tue Jul  2 2019 jslaby@suse.cz
- Revert "ovl: detect overlapping layers" (openqa tests failing).
- Revert "ovl: don't fail with disconnected lower NFS" (openqa
  tests failing).
- Revert "ovl: fix bogus -Wmaybe-unitialized warning" (openqa
  tests failing).
- commit cb24bc9
* Sun Jun 30 2019 mkubecek@suse.cz
- Update to 5.2-rc7
- Refresh configs
- commit 2d405cc
* Sun Jun 30 2019 msuchanek@suse.de
- Delete patches.rpmify/BPF-UMH-do-not-detect-if-compiler-can-link-userspace.patch.
  Obsoleted by the gcc9 cross-compilers with libc.
- commit 0e0679b
* Sun Jun 30 2019 msuchanek@suse.de
- Revert "tpm: pass an array of tpm_extend_digest structures to
  tpm_pcr_extend()" (boo#1139244).
- commit b09a129
* Fri Jun 28 2019 msuchanek@suse.de
- Refresh patches.suse/supported-flag.
  Supported kernel does not build with the patch in master so imported
  patch from SLE15.
- commit 10d9b2c
* Thu Jun 27 2019 msuchanek@suse.de
- Update config files
  - Add core options from SLE15 which are not enabled on master for no
  obvious reason
  - Add core option from x86 which are not enabled on non-x86 for no
  obvious reason
  - Enable fadump
  Changes:
  Scheduling:
    +CONFIG_CONTEXT_TRACKING=y
  - CONFIG_TICK_CPU_ACCOUNTING=y
    +CONFIG_VIRT_CPU_ACCOUNTING_GEN=y
    +CONFIG_VIRT_CPU_ACCOUNTING=y
    +CONFIG_IRQ_TIME_ACCOUNTING=y
    +CONFIG_TASKS_RCU=y
    +CONFIG_RT_GROUP_SCHED=y
  mm:
    +# CONFIG_TRANSPARENT_HUGEPAGE_ALWAYS is not set
    +CONFIG_TRANSPARENT_HUGEPAGE_MADVISE=y
    +CONFIG_FRONTSWAP=y
    +CONFIG_ZSWAP=y
  arc/ppc:
    +CONFIG_FA_DUMP=y
  fs:
    +CONFIG_9P_FSCACHE=y
  net:
    +CONFIG_TIPC=m
    +CONFIG_TIPC_DIAG=m
    +CONFIG_TIPC_MEDIA_UDP=y
  misc:
  - CONFIG_SERIAL_SIFIVE=m
    +CONFIG_SYSCTL_SYSCALL=y
  debug&test:
    +CONFIG_PAGE_EXTENSION=y
    +CONFIG_PAGE_OWNER=y
    +CONFIG_DEBUG_MISC=y
    +CONFIG_RCU_TRACE=y
    +CONFIG_KGDB_SERIAL_CONSOLE=y
    +CONFIG_SCOM_DEBUGFS=y
    +CONFIG_CRYPTO_TEST=m
    +CONFIG_RCU_TORTURE_TEST=m
    +CONFIG_TEST_FIRMWARE=m
    +CONFIG_TEST_LIVEPATCH=m
    +CONFIG_TEST_LKM=m
    +CONFIG_TEST_SYSCTL=m
    +CONFIG_TORTURE_TEST=m
- commit ce08519
* Tue Jun 25 2019 jslaby@suse.cz
- Linux 5.1.15 (bnc#1012628).
- tracing: Silence GCC 9 array bounds warning (bnc#1012628).
- mmc: sdhci: sdhci-pci-o2micro: Correctly set bus width when
  tuning (bnc#1012628).
- mmc: sdhi: disallow HS400 for M3-W ES1.2, RZ/G2M, and V3H
  (bnc#1012628).
- mmc: mediatek: fix SDIO IRQ interrupt handle flow (bnc#1012628).
- mmc: mediatek: fix SDIO IRQ detection issue (bnc#1012628).
- mmc: core: API to temporarily disable retuning for SDIO CRC
  errors (bnc#1012628).
- mmc: core: Add sdio_retune_hold_now() and sdio_retune_release()
  (bnc#1012628).
- mmc: core: Prevent processing SDIO IRQs when the card is
  suspended (bnc#1012628).
- scsi: ufs: Avoid runtime suspend possibly being blocked forever
  (bnc#1012628).
- usb: chipidea: udc: workaround for endpoint conflict issue
  (bnc#1012628).
- xhci: detect USB 3.2 capable host controllers correctly
  (bnc#1012628).
- usb: xhci: Don't try to recover an endpoint if port is in
  error state (bnc#1012628).
- cifs: add spinlock for the openFileList to cifsInodeInfo
  (bnc#1012628).
- cifs: fix GlobalMid_Lock bug in cifs_reconnect (bnc#1012628).
- IB/hfi1: Validate fault injection opcode user input
  (bnc#1012628).
- IB/hfi1: Close PSM sdma_progress sleep window (bnc#1012628).
- IB/hfi1: Avoid hardlockup with flushlist_lock (bnc#1012628).
- IB/hfi1: Correct tid qp rcd to match verbs context
  (bnc#1012628).
- IB/hfi1: Silence txreq allocation warnings (bnc#1012628).
- iio: imu: st_lsm6dsx: fix PM support for st_lsm6dsx i2c
  controller (bnc#1012628).
- iio: temperature: mlx90632 Relax the compatibility check
  (bnc#1012628).
- Input: synaptics - enable SMBus on ThinkPad E480 and E580
  (bnc#1012628).
- Input: uinput - add compat ioctl number translation for
  UI_*_FF_UPLOAD (bnc#1012628).
- Input: silead - add MSSL0017 to acpi_device_id (bnc#1012628).
- apparmor: fix PROFILE_MEDIATES for untrusted input
  (bnc#1012628).
- apparmor: enforce nullbyte at end of tag string (bnc#1012628).
- apparmor: reset pos on failure to unpack for various functions
  (bnc#1012628).
- Revert "brcmfmac: disable command decode in sdio_aos"
  (bnc#1012628).
- brcmfmac: sdio: Disable auto-tuning around commands expected
  to fail (bnc#1012628).
- brcmfmac: sdio: Don't tune while the card is off (bnc#1012628).
- lkdtm/usercopy: Moves the KERNEL_DS test to non-canonical
  (bnc#1012628).
- ARC: fix build warnings (bnc#1012628).
- dmaengine: jz4780: Fix transfers being ACKed too soon
  (bnc#1012628).
- dmaengine: dw-axi-dmac: fix null dereference when pointer
  first is null (bnc#1012628).
- dmaengine: mediatek-cqdma: sleeping in atomic context
  (bnc#1012628).
- dmaengine: sprd: Fix the possible crash when getting descriptor
  status (bnc#1012628).
- dmaengine: sprd: Add validation of current descriptor in irq
  handler (bnc#1012628).
- dmaengine: sprd: Fix the incorrect start for 2-stage destination
  channels (bnc#1012628).
- dmaengine: sprd: Fix block length overflow (bnc#1012628).
- dmaengine: sprd: Fix the right place to configure 2-stage
  transfer (bnc#1012628).
- ARC: [plat-hsdk]: Add missing multicast filter bins number to
  GMAC node (bnc#1012628).
- ARC: [plat-hsdk]: Add missing FIFO size entry in GMAC node
  (bnc#1012628).
- MIPS: mark ginvt() as __always_inline (bnc#1012628).
- fpga: stratix10-soc: fix use-after-free on s10_init()
  (bnc#1012628).
- fpga: dfl: afu: Pass the correct device to dma_mapping_error()
  (bnc#1012628).
- fpga: dfl: Add lockdep classes for pdata->lock (bnc#1012628).
- parport: Fix mem leak in parport_register_dev_model
  (bnc#1012628).
- parisc: Fix compiler warnings in float emulation code
  (bnc#1012628).
- habanalabs: fix bug in checking huge page optimization
  (bnc#1012628).
- IB/rdmavt: Fix alloc_qpn() WARN_ON() (bnc#1012628).
- IB/hfi1: Insure freeze_work work_struct is canceled on shutdown
  (bnc#1012628).
- IB/{qib, hfi1, rdmavt}: Correct ibv_devinfo max_mr value
  (bnc#1012628).
- IB/hfi1: Validate page aligned for a given virtual address
  (bnc#1012628).
- MIPS: uprobes: remove set but not used variable 'epc'
  (bnc#1012628).
- crypto: hmac - fix memory leak in hmac_init_tfm() (bnc#1012628).
- xtensa: Fix section mismatch between memblock_reserve and
  mem_reserve (bnc#1012628).
- kselftest/cgroup: fix unexpected testing failure on
  test_memcontrol (bnc#1012628).
- kselftest/cgroup: fix unexpected testing failure on test_core
  (bnc#1012628).
- kselftest/cgroup: fix incorrect test_core skip (bnc#1012628).
- userfaultfd: selftest: fix compiler warning (bnc#1012628).
- selftests: vm: install test_vmalloc.sh for run_vmtests
  (bnc#1012628).
- net: dsa: mv88e6xxx: avoid error message on remove from VLAN 0
  (bnc#1012628).
- net: hns: Fix loopback test failed at copper ports
  (bnc#1012628).
- mdesc: fix a missing-check bug in get_vdev_port_node_info()
  (bnc#1012628).
- sparc: perf: fix updated event period in response to
  PERF_EVENT_IOC_PERIOD (bnc#1012628).
- net: ethernet: mediatek: Use hw_feature to judge if HWLRO is
  supported (bnc#1012628).
- net: ethernet: mediatek: Use NET_IP_ALIGN to judge if HW
  RX_2BYTE_OFFSET is enabled (bnc#1012628).
- selftests: set sysctl bc_forwarding properly in
  router_broadcast.sh (bnc#1012628).
- drm/arm/mali-dp: Add a loop around the second set CVAL and
  try 5 times (bnc#1012628).
- drm/arm/hdlcd: Actually validate CRTC modes (bnc#1012628).
- drm/arm/hdlcd: Allow a bit of clock tolerance (bnc#1012628).
- nvmet: fix data_len to 0 for bdev-backed write_zeroes
  (bnc#1012628).
- kbuild: tar-pkg: enable communication with jobserver
  (bnc#1012628).
- scripts/checkstack.pl: Fix arm64 wrong or unknown architecture
  (bnc#1012628).
- net: phylink: avoid reducing support mask (bnc#1012628).
- scsi: ufs: Check that space was properly alloced in
  copy_query_response (bnc#1012628).
- scsi: smartpqi: unlock on error in
  pqi_submit_raid_request_synchronous() (bnc#1012628).
- net: ipvlan: Fix ipvlan device tso disabled while
  NETIF_F_IP_CSUM is set (bnc#1012628).
- udmabuf: actually unmap the scatterlist (bnc#1012628).
- tests: fix pidfd-test compilation (bnc#1012628).
- s390/qeth: handle limited IPv4 broadcast in L3 TX path
  (bnc#1012628).
- s390/qeth: check dst entry before use (bnc#1012628).
- s390/qeth: fix VLAN attribute in bridge_hostnotify udev event
  (bnc#1012628).
- hwmon: (core) add thermal sensors only if dev->of_node is
  present (bnc#1012628).
- hwmon: (pmbus/core) Treat parameters as paged if on multiple
  pages (bnc#1012628).
- arm64: Silence gcc warnings about arch ABI drift (bnc#1012628).
- nvme: Fix u32 overflow in the number of namespace list
  calculation (bnc#1012628).
- ovl: detect overlapping layers (bnc#1012628).
- ovl: don't fail with disconnected lower NFS (bnc#1012628).
- ovl: fix bogus -Wmaybe-unitialized warning (bnc#1012628).
- btrfs: start readahead also in seed devices (bnc#1012628).
- can: xilinx_can: use correct bittiming_const for CAN FD core
  (bnc#1012628).
- can: flexcan: fix timeout when set small bitrate (bnc#1012628).
- can: purge socket error queue on sock destruct (bnc#1012628).
- riscv: mm: synchronize MMU after pte change (bnc#1012628).
- powerpc/bpf: use unsigned division instruction for 64-bit
  operations (bnc#1012628).
- ARM: imx: cpuidle-imx6sx: Restrict the SW2ISO increase to
  i.MX6SX (bnc#1012628).
- ARM: mvebu_v7_defconfig: fix Ethernet on Clearfog (bnc#1012628).
- ARM: dts: dra76x: Update MMC2_HS200_MANUAL1 iodelay values
  (bnc#1012628).
- ARM: dts: am57xx-idk: Remove support for voltage switching
  for SD card (bnc#1012628).
- arm64/sve: <uapi/asm/ptrace.h> should not depend on
  <uapi/linux/prctl.h> (bnc#1012628).
- arm64: ssbd: explicitly depend on <linux/prctl.h> (bnc#1012628).
- KVM: x86/mmu: Allocate PAE root array when using SVM's 32-bit
  NPT (bnc#1012628).
- ovl: make i_ino consistent with st_ino in more cases
  (bnc#1012628).
- drm/vmwgfx: Use the backdoor port if the HB port is not
  available (bnc#1012628).
- drm/i915: Don't clobber M/N values during fastset check
  (bnc#1012628).
- binder: fix possible UAF when freeing buffer (bnc#1012628).
- staging: erofs: add requirements field in superblock
  (bnc#1012628).
- Bluetooth: Align minimum encryption key size for LE and BR/EDR
  connections (bnc#1012628).
- Bluetooth: Fix regression with minimum encryption key size
  alignment (bnc#1012628).
- SMB3: retry on STATUS_INSUFFICIENT_RESOURCES instead of failing
  write (bnc#1012628).
- x86/vdso: Prevent segfaults due to hoisted vclock reads
  (bnc#1012628).
- fs/namespace: fix unprivileged mount propagation (bnc#1012628).
- cfg80211: fix memory leak of wiphy device name (bnc#1012628).
- mac80211: drop robust management frames from unknown TA
  (bnc#1012628).
- {nl,mac}80211: allow 4addr AP operation on crypto controlled
  devices (bnc#1012628).
- mac80211: handle deauthentication/disassociation from TDLS peer
  (bnc#1012628).
- nl80211: fix station_info pertid memory leak (bnc#1012628).
- mac80211: Do not use stack memory with scatterlist for GMAC
  (bnc#1012628).
- x86/resctrl: Don't stop walking closids when a locksetup group
  is found (bnc#1012628).
- powerpc/mm/64s/hash: Reallocate context ids on fork
  (bnc#1012628).
- Refresh patches.suse/apparmor-compatibility-with-v2.x-net.patch.
- commit e222743
* Mon Jun 24 2019 msuchanek@suse.de
- crypto: algapi - guard against uninitialized spawn list in
  crypto_remove_spawns (bsc#1133401).
- commit 543f67d
* Mon Jun 24 2019 tiwai@suse.de
- fonts: Prefer a bigger font for high resolution screens
  (bsc#1138496).
- fonts: Use BUILD_BUG_ON() for checking empty font table
  (bsc#1138496).
- fonts: Fix coding style (bsc#1138496).
- commit f99f70b
* Sun Jun 23 2019 mkubecek@suse.cz
- Update to 5.2-rc6
- Eliminated 5 patches
  - patches.suse/net-phy-rename-Asix-Electronics-PHY-driver.patch
  - patches.suse/tcp-limit-payload-size-of-sacked-skbs.patch
  - patches.suse/tcp-tcp_fragment-should-apply-sane-memory-limits.patch
  - patches.suse/tcp-add-tcp_min_snd_mss-sysctl.patch
  - patches.suse/tcp-enforce-tcp_min_snd_mss-in-tcp_mtu_probing.patch
- Refresh
  - patches.suse/apparmor-compatibility-with-v2.x-net.patch
- commit 75acedc
* Sat Jun 22 2019 jslaby@suse.cz
- Linux 5.1.14 (bnc#1012628).
- tcp: refine memory limit test in tcp_fragment() (bnc#1012628).
- commit f291042
* Sat Jun 22 2019 jslaby@suse.cz
- Linux 5.1.13 (bnc#1012628).
- coredump: fix race condition between collapse_huge_page()
  and core dumping (bnc#1012628).
- nvme-tcp: fix queue mapping when queue count is limited
  (bnc#1012628).
- nvme-tcp: fix possible null deref on a timed out io queue
  connect (bnc#1012628).
- nvme-tcp: rename function to have nvme_tcp prefix (bnc#1012628).
- mm: mmu_gather: remove __tlb_reset_range() for force flush
  (bnc#1012628).
- ocfs2: fix error path kobject memory leak (bnc#1012628).
- mlxsw: spectrum: Prevent force of 56G (bnc#1012628).
- scsi: libsas: delete sas port if expander discover failed
  (bnc#1012628).
- scsi: scsi_dh_alua: Fix possible null-ptr-deref (bnc#1012628).
- scsi: smartpqi: properly set both the DMA mask and the coherent
  DMA mask (bnc#1012628).
- scsi: libcxgbi: add a check for NULL pointer in
  cxgbi_check_route() (bnc#1012628).
- net: phy: dp83867: Set up RGMII TX delay (bnc#1012628).
- net: phy: dp83867: increase SGMII autoneg timer duration
  (bnc#1012628).
- net: phy: dp83867: fix speed 10 in sgmii mode (bnc#1012628).
- net: phylink: ensure consistent phy interface mode
  (bnc#1012628).
- blk-mq: Fix memory leak in error handling (bnc#1012628).
- net: sh_eth: fix mdio access in sh_eth_close() for R-Car Gen2
  and RZ/A1 SoCs (bnc#1012628).
- arm64: use the correct function type for __arm64_sys_ni_syscall
  (bnc#1012628).
- arm64: use the correct function type in SYSCALL_DEFINE0
  (bnc#1012628).
- arm64: fix syscall_fn_t type (bnc#1012628).
- ALSA: fireface: Use ULL suffixes for 64-bit constants
  (bnc#1012628).
- KVM: PPC: Book3S HV: Don't take kvm->lock around
  kvm_for_each_vcpu (bnc#1012628).
- KVM: PPC: Book3S: Use new mutex to synchronize access to rtas
  token list (bnc#1012628).
- KVM: PPC: Book3S HV: Use new mutex to synchronize MMU setup
  (bnc#1012628).
- dfs_cache: fix a wrong use of kfree in flush_cache_ent()
  (bnc#1012628).
- xenbus: Avoid deadlock during suspend due to open transactions
  (bnc#1012628).
- xen/pvcalls: Remove set but not used variable (bnc#1012628).
- dpaa_eth: use only online CPU portals (bnc#1012628).
- ia64: fix build errors by exporting paddr_to_nid()
  (bnc#1012628).
- perf record: Fix s390 missing module symbol and warning for
  non-root users (bnc#1012628).
- perf namespace: Protect reading thread's namespace
  (bnc#1012628).
- s390/zcrypt: Fix wrong dispatching for control domain CPRBs
  (bnc#1012628).
- perf data: Fix 'strncat may truncate' build failure with recent
  gcc (bnc#1012628).
- configfs: Fix use-after-free when accessing sd->s_dentry
  (bnc#1012628).
- ALSA: hda - Force polling mode on CNL for fixing codec
  communication (bnc#1012628).
- i2c: dev: fix potential memory leak in i2cdev_ioctl_rdwr
  (bnc#1012628).
- net: aquantia: fix LRO with FCS error (bnc#1012628).
- net: aquantia: tx clean budget logic error (bnc#1012628).
- drm/etnaviv: lock MMU while dumping core (bnc#1012628).
- ACPI/PCI: PM: Add missing wakeup.flags.valid checks
  (bnc#1012628).
- net: tulip: de4x5: Drop redundant MODULE_DEVICE_TABLE()
  (bnc#1012628).
- dpaa2-eth: Use PTR_ERR_OR_ZERO where appropriate (bnc#1012628).
- dpaa2-eth: Fix potential spectre issue (bnc#1012628).
- io_uring: Fix __io_uring_register() false success (bnc#1012628).
- net: stmmac: dwmac-mediatek: modify csr_clk value to fix mdio
  read/write fail (bnc#1012628).
- net: stmmac: fix csr_clk can't be zero issue (bnc#1012628).
- net: stmmac: update rx tail pointer register to fix rx dma
  hang issue (bnc#1012628).
- gpio: fix gpio-adp5588 build errors (bnc#1012628).
- perf/ring-buffer: Always use {READ,WRITE}_ONCE() for
  rb->user_page data (bnc#1012628).
- perf/ring_buffer: Add ordering to rb->nest increment
  (bnc#1012628).
- perf/ring_buffer: Fix exposing a temporarily decreased data_head
  (bnc#1012628).
- x86/CPU/AMD: Don't force the CPB cap when running under a
  hypervisor (bnc#1012628).
- mISDN: make sure device name is NUL terminated (bnc#1012628).
- usb: xhci: Fix a potential null pointer dereference in
  xhci_debugfs_create_endpoint() (bnc#1012628).
- powerpc/powernv: Return for invalid IMC domain (bnc#1012628).
- clk: ti: clkctrl: Fix clkdm_clk handling (bnc#1012628).
- selftests: netfilter: missing error check when setting up veth
  interface (bnc#1012628).
- ipvs: Fix use-after-free in ip_vs_in (bnc#1012628).
- netfilter: nft_fib: Fix existence check support (bnc#1012628).
- netfilter: nf_queue: fix reinject verdict handling
  (bnc#1012628).
- perf/x86/intel/ds: Fix EVENT vs. UEVENT PEBS constraints
  (bnc#1012628).
- netfilter: nf_tables: fix oops during rule dump (bnc#1012628).
- pinctrl: intel: Clear interrupt status in mask/unmask callback
  (bnc#1012628).
- staging: wilc1000: Fix some double unlock bugs in
  wilc_wlan_cleanup() (bnc#1012628).
- Staging: vc04_services: Fix a couple error codes (bnc#1012628).
- staging: erofs: set sb->s_root to NULL when failing from
  __getname() (bnc#1012628).
- iio: imu: mpu6050: Fix FIFO layout for ICM20602 (bnc#1012628).
- net/mlx5e: Avoid detaching non-existing netdev under switchdev
  mode (bnc#1012628).
- net: correct udp zerocopy refcnt also when zerocopy only on
  append (bnc#1012628).
- net/mlx5e: Support tagged tunnel over bond (bnc#1012628).
- mlxsw: spectrum_buffers: Reduce pool size on Spectrum-2
  (bnc#1012628).
- net/mlx5e: Fix source port matching in fdb peer flow rule
  (bnc#1012628).
- mlxsw: spectrum_flower: Fix TOS matching (bnc#1012628).
- net/mlx5e: Add ndo_set_feature for uplink representor
  (bnc#1012628).
- mlxsw: spectrum_router: Refresh nexthop neighbour when it
  becomes dead (bnc#1012628).
- net/mlx5: Update pci error handler entries and command
  translation (bnc#1012628).
- net: ethtool: Allow matching on vlan DEI bit (bnc#1012628).
- net: dsa: microchip: Don't try to read stats for unused ports
  (bnc#1012628).
- net: mvpp2: prs: Use the correct helpers when removing all
  VID filters (bnc#1012628).
- net: mvpp2: prs: Fix parser range for VID filtering
  (bnc#1012628).
- geneve: Don't assume linear buffers in error handler
  (bnc#1012628).
- vxlan: Don't assume linear buffers in error handler
  (bnc#1012628).
- net/mlx5: Avoid reloading already removed devices (bnc#1012628).
- vsock/virtio: set SOCK_DONE on peer shutdown (bnc#1012628).
- tipc: purge deferredq list for each grp member in
  tipc_group_delete (bnc#1012628).
- sunhv: Fix device naming inconsistency between sunhv_console
  and sunhv_reg (bnc#1012628).
- sctp: Free cookie before we memdup a new one (bnc#1012628).
- nfc: Ensure presence of required attributes in the
  deactivate_target handler (bnc#1012628).
- net: tls, correctly account for copied bytes with multiple
  sk_msgs (bnc#1012628).
- net: openvswitch: do not free vport if register_netdevice()
  is failed (bnc#1012628).
- net: dsa: rtl8366: Fix up VLAN filtering (bnc#1012628).
- neigh: fix use-after-free read in pneigh_get_next (bnc#1012628).
- lapb: fixed leak of control-blocks (bnc#1012628).
- ipv6: flowlabel: fl6_sock_lookup() must use atomic_inc_not_zero
  (bnc#1012628).
- hv_netvsc: Set probe mode to sync (bnc#1012628).
- be2net: Fix number of Rx queues used for flow hashing
  (bnc#1012628).
- ax25: fix inconsistent lock state in ax25_destroy_timer
  (bnc#1012628).
- netfilter: nat: fix udp checksum corruption (bnc#1012628).
- commit 5fe336c
* Thu Jun 20 2019 msuchanek@suse.de
- kernel-binary: rpm does not support multiline condition
- commit aceae50
* Thu Jun 20 2019 msuchanek@suse.de
- kernel-binary: Use -c grep option in klp project detection.
- commit 5def2a2
* Thu Jun 20 2019 msuchanek@suse.de
- kernel-binary: fix missing \
- commit 8325214
* Thu Jun 20 2019 jslaby@suse.cz
- Update
  patches.kernel.org/5.1.8-025-btrfs-qgroup-Check-bg-while-resuming-relocation.patch
  (bnc#1012628 bnc#1134806).
- commit e868173
* Wed Jun 19 2019 jslaby@suse.cz
- Linux 5.1.12 (bnc#1012628).
- powerpc/64s: Fix THP PMD collapse serialisation (bnc#1012628).
- powerpc: Fix kexec failure on book3s/32 (bnc#1012628).
- drm: add fallback override/firmware EDID modes workaround
  (bnc#1012628).
- drm/edid: abstract override/firmware EDID retrieval
  (bnc#1012628).
- x86/resctrl: Prevent NULL pointer dereference when local MBM
  is disabled (bnc#1012628).
- x86/mm/KASLR: Compute the size of the vmemmap section properly
  (bnc#1012628).
- x86/kasan: Fix boot with 5-level paging and KASAN (bnc#1012628).
- x86/microcode, cpuhotplug: Add a microcode loader CPU hotplug
  callback (bnc#1012628).
- RAS/CEC: Fix binary search function (bnc#1012628).
- RAS/CEC: Convert the timer callback to a workqueue
  (bnc#1012628).
- timekeeping: Repair ktime_get_coarse*() granularity
  (bnc#1012628).
- tracing/uprobe: Fix NULL pointer dereference in
  trace_uprobe_create() (bnc#1012628).
- USB: serial: option: add Telit 0x1260 and 0x1261 compositions
  (bnc#1012628).
- USB: serial: option: add support for Simcom SIM7500/SIM7600
  RNDIS mode (bnc#1012628).
- USB: serial: pl2303: add Allied Telesis VT-Kit3 (bnc#1012628).
- USB: usb-storage: Add new ID to ums-realtek (bnc#1012628).
- USB: Fix chipmunk-like voice when using Logitech C270 for
  recording audio (bnc#1012628).
- usb: dwc2: host: Fix wMaxPacketSize handling (fix webcam
  regression) (bnc#1012628).
- usb: dwc2: Fix DMA cache alignment issues (bnc#1012628).
- drm/vmwgfx: NULL pointer dereference from
  vmw_cmd_dx_view_define() (bnc#1012628).
- drm/vmwgfx: integer underflow in vmw_cmd_dx_set_shader()
  leading to an invalid read (bnc#1012628).
- tools/kvm_stat: fix fields filter for child events
  (bnc#1012628).
- kvm: selftests: aarch64: fix default vm mode (bnc#1012628).
- kvm: selftests: aarch64: dirty_log_test: fix unaligned memslot
  size (bnc#1012628).
- KVM: s390: fix memory slot handling for
  KVM_SET_USER_MEMORY_REGION (bnc#1012628).
- KVM: x86/pmu: do not mask the value that is written to fixed
  PMUs (bnc#1012628).
- KVM: x86/pmu: mask the result of rdpmc according to the width
  of the counters (bnc#1012628).
- KVM: x86: do not spam dmesg with VMCS/VMCB dumps (bnc#1012628).
- KVM: LAPIC: Fix lapic_timer_advance_ns parameter overflow
  (bnc#1012628).
- kvm: vmx: Fix -Wmissing-prototypes warnings (bnc#1012628).
- KVM: selftests: Fix a condition in test_hv_cpuid()
  (bnc#1012628).
- KVM: nVMX: really fix the size checks on KVM_SET_NESTED_STATE
  (bnc#1012628).
- KVM: arm/arm64: Move cc/it checks under hyp's Makefile to
  avoid instrumentation (bnc#1012628).
- tools/io_uring: fix Makefile for pthread library link
  (bnc#1012628).
- nvme-pci: use blk-mq mapping for unmanaged irqs (bnc#1012628).
- usbnet: ipheth: fix racing condition (bnc#1012628).
- tracing: Prevent hist_field_var_ref() from accessing NULL
  tracing_map_elts (bnc#1012628).
- selftests/timers: Add missing fflush(stdout) calls
  (bnc#1012628).
- selftests: fib_rule_tests: fix local IPv4 address typo
  (bnc#1012628).
- libnvdimm: Fix compilation warnings with W=1 (bnc#1012628).
- drm/amdgpu: keep stolen memory on picasso (bnc#1012628).
- scsi: bnx2fc: fix incorrect cast to u64 on shift operation
  (bnc#1012628).
- scsi: myrs: Fix uninitialized variable (bnc#1012628).
- platform/x86: pmc_atom: Add several Beckhoff Automation boards
  to critclk_systems DMI table (bnc#1012628).
- platform/x86: pmc_atom: Add Lex 3I380D industrial PC to
  critclk_systems DMI table (bnc#1012628).
- nvme: fix memory leak for power latency tolerance (bnc#1012628).
- nvme: release namespace SRCU protection before performing
  controller ioctls (bnc#1012628).
- nvme: merge nvme_ns_ioctl into nvme_ioctl (bnc#1012628).
- nvme: remove the ifdef around nvme_nvm_ioctl (bnc#1012628).
- nvme: fix srcu locking on error return in nvme_get_ns_from_disk
  (bnc#1012628).
- nvme-pci: Fix controller freeze wait disabling (bnc#1012628).
- selftests/bpf: fix bpf_get_current_task (bnc#1012628).
- tools/bpftool: move set_max_rlimit() before
  __bpf_object__open_xattr() (bnc#1012628).
- arm64/mm: Inhibit huge-vmap with ptdump (bnc#1012628).
- bpf, tcp: correctly handle DONT_WAIT flags and timeo == 0
  (bnc#1012628).
- enetc: Fix NULL dma address unmap for Tx BD extensions
  (bnc#1012628).
- net: macb: fix error format in dev_err() (bnc#1012628).
- arm64: Print physical address of page table base in show_pte()
  (bnc#1012628).
- scsi: lpfc: add check for loss of ndlp when sending RRQ
  (bnc#1012628).
- scsi: lpfc: correct rcu unlock issue in lpfc_nvme_info_show
  (bnc#1012628).
- scsi: lpfc: resolve lockdep warnings (bnc#1012628).
- scsi: qedi: remove set but not used variables 'cdev' and 'udev'
  (bnc#1012628).
- scsi: qedi: remove memset/memcpy to nfunc and use func instead
  (bnc#1012628).
- scsi: qla2xxx: Add cleanup for PCI EEH recovery (bnc#1012628).
- bpf: sockmap fix msg->sg.size account on ingress skb
  (bnc#1012628).
- bpf: sockmap remove duplicate queue free (bnc#1012628).
- bpf: sockmap, only stop/flush strp if it was enabled at some
  point (bnc#1012628).
- drivers/perf: arm_spe: Don't error on high-order pages for
  aux buf (bnc#1012628).
- f2fs: fix to avoid accessing xattr across the boundary
  (bnc#1012628).
- Drivers: misc: fix out-of-bounds access in function
  param_set_kgdbts_var (bnc#1012628).
- Revert "ALSA: seq: Protect in-kernel ioctl calls with mutex"
  (bnc#1012628).
- ALSA: seq: Fix race of get-subscription call vs port-delete
  ioctls (bnc#1012628).
- ALSA: seq: Protect in-kernel ioctl calls with mutex
  (bnc#1012628).
- x86/uaccess, kcov: Disable stack protector (bnc#1012628).
- drm/i915/dmc: protect against reading random memory
  (bnc#1012628).
- drm/i915: Fix per-pixel alpha with CCS (bnc#1012628).
- drm/i915/dsi: Use a fuzzy check for burst mode clock check
  (bnc#1012628).
- drm/i915/sdvo: Implement proper HDMI audio support for SDVO
  (bnc#1012628).
- drm/amdgpu/{uvd,vcn}: fetch ring's read_ptr after alloc
  (bnc#1012628).
- ASoC: soc-core: fixup references at soc_cleanup_card_resources()
  (bnc#1012628).
- ASoC: fsl_asrc: Fix the issue about unsupported rate
  (bnc#1012628).
- ASoC: cs42xx8: Add regcache mask dirty (bnc#1012628).
- cgroup: Use css_tryget() instead of css_tryget_online() in
  task_get_css() (bnc#1012628).
- bcache: only set BCACHE_DEV_WB_RUNNING when cached device
  attached (bnc#1012628).
- bcache: fix stack corruption by PRECEDING_KEY() (bnc#1012628).
- i2c: acorn: fix i2c warning (bnc#1012628).
- Smack: Restore the smackfsdef mount option and add missing
  prefixes (bnc#1012628).
- iommu/arm-smmu: Avoid constant zero in TLBI writes
  (bnc#1012628).
- media: dvb: warning about dvb frequency limits produces too
  much noise (bnc#1012628).
- ptrace: restore smp_rmb() in __ptrace_may_access()
  (bnc#1012628).
- signal/ptrace: Don't leak unitialized kernel memory with
  PTRACE_PEEK_SIGINFO (bnc#1012628).
- mm/vmscan.c: fix trying to reclaim unevictable LRU page
  (bnc#1012628).
- fs/ocfs2: fix race in ocfs2_dentry_attach_lock() (bnc#1012628).
- mm/list_lru.c: fix memory leak in __memcg_init_list_lru_node
  (bnc#1012628).
- io_uring: fix memory leak of UNIX domain socket inode
  (bnc#1012628).
- libata: Extend quirks for the ST1000LM024 drives with NOLPM
  quirk (bnc#1012628).
- selinux: fix a missing-check bug in selinux_sb_eat_lsm_opts()
  (bnc#1012628).
- selinux: fix a missing-check bug in selinux_add_mnt_opt( )
  (bnc#1012628).
- selinux: log raw contexts as untrusted strings (bnc#1012628).
- ALSA: firewire-motu: fix destruction of data for isochronous
  resources (bnc#1012628).
- ALSA: hda/realtek - Update headset mode for ALC256
  (bnc#1012628).
- ALSA: ice1712: Check correct return value to snd_i2c_sendbytes
  (EWS/DMX 6Fire) (bnc#1012628).
- ALSA: oxfw: allow PCM capture for Stanton SCS.1m (bnc#1012628).
- Revert "ALSA: hda/realtek - Improve the headset mic for Acer
  Aspire laptops" (bnc#1012628).
- HID: wacom: Sync INTUOSP2_BT touch state after each frame if
  necessary (bnc#1012628).
- HID: wacom: Correct button numbering 2nd-gen Intuos Pro over
  Bluetooth (bnc#1012628).
- HID: wacom: Send BTN_TOUCH in response to INTUOSP2_BT eraser
  contact (bnc#1012628).
- HID: wacom: Don't report anything prior to the tool entering
  range (bnc#1012628).
- HID: wacom: Don't set tool type until we're in range
  (bnc#1012628).
- HID: multitouch: handle faulty Elo touch device (bnc#1012628).
- Revert "HID: Increase maximum report size allowed by
  hid_field_extract()" (bnc#1012628).
- HID: input: fix assignment of .value (bnc#1012628).
- HID: input: make sure the wheel high resolution multiplier is
  set (bnc#1012628).
- nouveau: Fix build with CONFIG_NOUVEAU_LEGACY_CTX_SUPPORT
  disabled (bnc#1012628).
- drm/nouveau: add kconfig option to turn off nouveau legacy
  contexts. (v3) (bnc#1012628).
- commit c3db4a3
* Wed Jun 19 2019 mkubecek@suse.cz
- config: refresh i386/default
- commit a562f5a
* Wed Jun 19 2019 jslaby@suse.cz
- Update config files.
  Enable SECURITY_YAMA to allow protection against ptrace attacks
  (bnc#1128245).
- commit fb39868
* Tue Jun 18 2019 jslaby@suse.cz
- Update config files.
  Set HARDENED_USERCOPY=y (bnc#1127808). This can be disabled on the
  commandline using hardened_usercopy=n.
- commit 04b86aa
* Tue Jun 18 2019 tiwai@suse.de
- config: enable CONFIG_FONT_TER16x32 for HiDPI monitors (boo#1138496)
- commit 073136d
* Mon Jun 17 2019 mkubecek@suse.cz
- tcp: enforce tcp_min_snd_mss in tcp_mtu_probing()
  (CVE-2019-11479 bsc#1137586).
- tcp: add tcp_min_snd_mss sysctl (CVE-2019-11479 bsc#1137586).
- tcp: tcp_fragment() should apply sane memory limits
  (CVE-2019-11478 bsc#1137586).
- tcp: limit payload size of sacked skbs (CVE-2019-11477
  bsc#1137586).
- commit ab45ff3
* Mon Jun 17 2019 jslaby@suse.cz
- Update
  patches.kernel.org/5.1.11-001-tcp-limit-payload-size-of-sacked-skbs.patch
  (bnc#1012628 bsc#1137586 CVE-2019-11477).
- Update
  patches.kernel.org/5.1.11-002-tcp-tcp_fragment-should-apply-sane-memory-limi.patch
  (bnc#1012628 bsc#1137586 CVE-2019-11477).
- Update
  patches.kernel.org/5.1.11-003-tcp-add-tcp_min_snd_mss-sysctl.patch
  (bnc#1012628 bsc#1137586 CVE-2019-11477).
- Update
  patches.kernel.org/5.1.11-004-tcp-enforce-tcp_min_snd_mss-in-tcp_mtu_probing.patch
  (bnc#1012628 bsc#1137586 CVE-2019-11477).
  Add CVE references back.
- commit fa73bae
* Mon Jun 17 2019 jslaby@suse.cz
- Linux 5.1.11 (bnc#1012628).
- commit 4aff7dc
* Mon Jun 17 2019 jslaby@suse.cz
- move patches from .fixes to .suse
  There is no patches.fixes in stable.
- commit ad24342
* Mon Jun 17 2019 jslaby@suse.cz
- tcp: enforce tcp_min_snd_mss in tcp_mtu_probing() (bsc#1137586
  CVE-2019-11479).
- tcp: add tcp_min_snd_mss sysctl (bsc#1137586 CVE-2019-11479).
- tcp: tcp_fragment() should apply sane memory limits (bsc#1137586
  CVE-2019-11478).
- tcp: limit payload size of sacked skbs (bsc#1137586
  CVE-2019-11477).
- commit a5ec6d9
* Mon Jun 17 2019 jslaby@suse.cz
- Linux 5.1.10 (bnc#1012628).
- media: rockchip/vpu: Fix/re-order probe-error/remove path
  (bnc#1012628).
- media: rockchip/vpu: Add missing dont_use_autosuspend() calls
  (bnc#1012628).
- rapidio: fix a NULL pointer dereference when create_workqueue()
  fails (bnc#1012628).
- fs/fat/file.c: issue flush after the writeback of FAT
  (bnc#1012628).
- sysctl: return -EINVAL if val violates minmax (bnc#1012628).
- ipc: prevent lockup on alloc_msg and free_msg (bnc#1012628).
- drm/msm: correct attempted NULL pointer dereference in debugfs
  (bnc#1012628).
- drm/pl111: Initialize clock spinlock early (bnc#1012628).
- mm/mprotect.c: fix compilation warning because of unused 'mm'
  variable (bnc#1012628).
- ARM: prevent tracing IPI_CPU_BACKTRACE (bnc#1012628).
- mm/hmm: select mmu notifier when selecting HMM (bnc#1012628).
- hugetlbfs: on restore reserve error path retain subpool
  reservation (bnc#1012628).
- mm/memory_hotplug: release memory resource after
  arch_remove_memory() (bnc#1012628).
- mem-hotplug: fix node spanned pages when we have a node with
  only ZONE_MOVABLE (bnc#1012628).
- mm/cma.c: fix crash on CMA allocation if bitmap allocation fails
  (bnc#1012628).
- initramfs: free initrd memory if opening /initrd.image fails
  (bnc#1012628).
- mm/compaction.c: fix an undefined behaviour (bnc#1012628).
- mm/memory_hotplug.c: fix the wrong usage of N_HIGH_MEMORY
  (bnc#1012628).
- mm/cma.c: fix the bitmap status to show failed allocation reason
  (bnc#1012628).
- mm: page_mkclean vs MADV_DONTNEED race (bnc#1012628).
- mm/cma_debug.c: fix the break condition in cma_maxchunk_get()
  (bnc#1012628).
- mm/slab.c: fix an infinite loop in leaks_show() (bnc#1012628).
- kernel/sys.c: prctl: fix false positive in validate_prctl_map()
  (bnc#1012628).
- thermal: rcar_gen3_thermal: disable interrupt in .remove
  (bnc#1012628).
- drivers: thermal: tsens: Don't print error message on
  - EPROBE_DEFER (bnc#1012628).
- mfd: tps65912-spi: Add missing of table registration
  (bnc#1012628).
- mfd: intel-lpss: Set the device in reset state when init
  (bnc#1012628).
- drm/nouveau/disp/dp: respect sink limits when selecting failsafe
  link configuration (bnc#1012628).
- mfd: twl6040: Fix device init errors for ACCCTL register
  (bnc#1012628).
- perf/x86/intel: Allow PEBS multi-entry in watermark mode
  (bnc#1012628).
- drm/nouveau/kms/gf119-gp10x: push HeadSetControlOutputResource()
  mthd when encoders change (bnc#1012628).
- drm/nouveau: fix duplication of nv50_head_atom struct
  (bnc#1012628).
- drm/bridge: adv7511: Fix low refresh rate selection
  (bnc#1012628).
- objtool: Don't use ignore flag for fake jumps (bnc#1012628).
- drm/nouveau/kms/gv100-: fix spurious window immediate interlocks
  (bnc#1012628).
- bpf: fix undefined behavior in narrow load handling
  (bnc#1012628).
- EDAC/mpc85xx: Prevent building as a module (bnc#1012628).
- pwm: meson: Use the spin-lock only to protect register
  modifications (bnc#1012628).
- mailbox: stm32-ipcc: check invalid irq (bnc#1012628).
- ntp: Allow TAI-UTC offset to be set to zero (bnc#1012628).
- f2fs: fix to avoid panic in do_recover_data() (bnc#1012628).
- f2fs: fix to avoid panic in f2fs_inplace_write_data()
  (bnc#1012628).
- f2fs: fix error path of recovery (bnc#1012628).
- f2fs: fix to avoid panic in f2fs_remove_inode_page()
  (bnc#1012628).
- f2fs: fix to do sanity check on free nid (bnc#1012628).
- f2fs: fix to clear dirty inode in error path of f2fs_iget()
  (bnc#1012628).
- f2fs: fix to avoid panic in dec_valid_block_count()
  (bnc#1012628).
- f2fs: fix to use inline space only if inline_xattr is enable
  (bnc#1012628).
- f2fs: fix to avoid panic in dec_valid_node_count()
  (bnc#1012628).
- f2fs: fix to do sanity check on valid block count of segment
  (bnc#1012628).
- f2fs: fix to avoid deadloop in foreground GC (bnc#1012628).
- f2fs: fix to retrieve inline xattr space (bnc#1012628).
- f2fs: fix to do checksum even if inode page is uptodate
  (bnc#1012628).
- media: atmel: atmel-isc: fix asd memory allocation
  (bnc#1012628).
- percpu: remove spurious lock dependency between percpu and sched
  (bnc#1012628).
- configfs: fix possible use-after-free in configfs_register_group
  (bnc#1012628).
- uml: fix a boot splat wrt use of cpu_all_mask (bnc#1012628).
- PCI: dwc: Free MSI in dw_pcie_host_init() error path
  (bnc#1012628).
- PCI: dwc: Free MSI IRQ page in dw_pcie_free_msi() (bnc#1012628).
- fbcon: Don't reset logo_shown when logo is currently shown
  (bnc#1012628).
- ovl: do not generate duplicate fsnotify events for "fake" path
  (bnc#1012628).
- mmc: mmci: Prevent polling for busy detection in IRQ context
  (bnc#1012628).
- netfilter: nf_flow_table: fix missing error check for
  rhashtable_insert_fast (bnc#1012628).
- netfilter: nf_conntrack_h323: restore boundary check correctness
  (bnc#1012628).
- mips: Make sure dt memory regions are valid (bnc#1012628).
- netfilter: nf_tables: fix base chain stat rcu_dereference usage
  (bnc#1012628).
- watchdog: imx2_wdt: Fix set_timeout for big timeout values
  (bnc#1012628).
- watchdog: fix compile time error of pretimeout governors
  (bnc#1012628).
- blk-mq: move cancel of requeue_work into blk_mq_release
  (bnc#1012628).
- iommu/vt-d: Set intel_iommu_gfx_mapped correctly (bnc#1012628).
- vfio-pci/nvlink2: Fix potential VMA leak (bnc#1012628).
- misc: pci_endpoint_test: Fix test_reg_bar to be updated in
  pci_endpoint_test (bnc#1012628).
- PCI: designware-ep: Use aligned ATU window for raising MSI
  interrupts (bnc#1012628).
- nvme-pci: unquiesce admin queue on shutdown (bnc#1012628).
- nvme-pci: shutdown on timeout during deletion (bnc#1012628).
- netfilter: nf_flow_table: check ttl value in flow offload data
  path (bnc#1012628).
- netfilter: nf_flow_table: fix netdev refcnt leak (bnc#1012628).
- ALSA: hda - Register irq handler after the chip initialization
  (bnc#1012628).
- powerpc/pseries: Track LMB nid instead of using device tree
  (bnc#1012628).
- arm64: defconfig: Update UFSHCD for Hi3660 soc (bnc#1012628).
- iommu/vt-d: Don't request page request irq under
  dmar_global_lock (bnc#1012628).
- nvmem: core: fix read buffer in place (bnc#1012628).
- nvmem: sunxi_sid: Support SID on A83T and H5 (bnc#1012628).
- fuse: retrieve: cap requested size to negotiated max_write
  (bnc#1012628).
- nfsd: allow fh_want_write to be called twice (bnc#1012628).
- nfsd: avoid uninitialized variable warning (bnc#1012628).
- vfio: Fix WARNING "do not call blocking ops when !TASK_RUNNING"
  (bnc#1012628).
- iommu/arm-smmu-v3: Don't disable SMMU in kdump kernel
  (bnc#1012628).
- switchtec: Fix unintended mask of MRPC event (bnc#1012628).
- net: thunderbolt: Unregister ThunderboltIP protocol handler
  when suspending (bnc#1012628).
- x86/PCI: Fix PCI IRQ routing table memory leak (bnc#1012628).
- soc/tegra: pmc: Remove reset sysfs entries on error
  (bnc#1012628).
- i40e: Queues are reserved despite "Invalid argument" error
  (bnc#1012628).
- power: supply: cpcap-battery: Fix signed counter sample register
  (bnc#1012628).
- platform/chrome: cros_ec_proto: check for NULL transfer function
  (bnc#1012628).
- PCI: keystone: Invoke phy_reset() API before enabling PHY
  (bnc#1012628).
- PCI: keystone: Prevent ARM32 specific code to be compiled for
  ARM64 (bnc#1012628).
- soc: mediatek: pwrap: Zero initialize rdata in pwrap_init_cipher
  (bnc#1012628).
- clk: rockchip: Turn on "aclk_dmac1" for suspend on rk3288
  (bnc#1012628).
- usb: ohci-da8xx: disable the regulator if the overcurrent irq
  fired (bnc#1012628).
- iommu/vt-d: Flush IOTLB for untrusted device in time
  (bnc#1012628).
- soc: rockchip: Set the proper PWM for rk3288 (bnc#1012628).
- arm64: dts: imx8mq: Mark iomuxc_gpr as i.MX6Q compatible
  (bnc#1012628).
- ARM: dts: imx51: Specify IMX5_CLK_IPG as "ahb" clock to SDMA
  (bnc#1012628).
- ARM: dts: imx50: Specify IMX5_CLK_IPG as "ahb" clock to SDMA
  (bnc#1012628).
- ARM: dts: imx53: Specify IMX5_CLK_IPG as "ahb" clock to SDMA
  (bnc#1012628).
- ARM: dts: imx6sx: Specify IMX6SX_CLK_IPG as "ahb" clock to SDMA
  (bnc#1012628).
- ARM: dts: imx6sll: Specify IMX6SLL_CLK_IPG as "ipg" clock to
  SDMA (bnc#1012628).
- ARM: dts: imx7d: Specify IMX7D_CLK_IPG as "ipg" clock to SDMA
  (bnc#1012628).
- ARM: dts: imx6ul: Specify IMX6UL_CLK_IPG as "ipg" clock to SDMA
  (bnc#1012628).
- ARM: dts: imx6sx: Specify IMX6SX_CLK_IPG as "ipg" clock to SDMA
  (bnc#1012628).
- ARM: dts: imx6qdl: Specify IMX6QDL_CLK_IPG as "ipg" clock to
  SDMA (bnc#1012628).
- PCI: rpadlpar: Fix leaked device_node references in add/remove
  paths (bnc#1012628).
- drm/amd/display: disable link before changing link settings
  (bnc#1012628).
- drm/amd/display: Use plane->color_space for dpp if specified
  (bnc#1012628).
- ARM: OMAP2+: pm33xx-core: Do not Turn OFF CEFUSE as PPA may
  be using it (bnc#1012628).
- pinctrl: pinctrl-intel: move gpio suspend/resume to noirq phase
  (bnc#1012628).
- platform/x86: intel_pmc_ipc: adding error handling
  (bnc#1012628).
- power: supply: max14656: fix potential use-before-alloc
  (bnc#1012628).
- f2fs: fix potential recursive call when enabling data_flush
  (bnc#1012628).
- net: hns3: return 0 and print warning when hit duplicate MAC
  (bnc#1012628).
- PCI: dwc: Remove default MSI initialization for platform
  specific MSI chips (bnc#1012628).
- PCI: rcar: Fix a potential NULL pointer dereference
  (bnc#1012628).
- PCI: rcar: Fix 64bit MSI message address handling (bnc#1012628).
- scsi: qla2xxx: Reset the FCF_ASYNC_{SENT|ACTIVE} flags
  (bnc#1012628).
- Input: goodix - add GT5663 CTP support (bnc#1012628).
- video: hgafb: fix potential NULL pointer dereference
  (bnc#1012628).
- video: imsttfb: fix potential NULL pointer dereferences
  (bnc#1012628).
- block, bfq: increase idling for weight-raised queues
  (bnc#1012628).
- PCI: xilinx: Check for __get_free_pages() failure (bnc#1012628).
- arm64: dts: qcom: qcs404: Fix regulator supply names
  (bnc#1012628).
- gpio: gpio-omap: add check for off wake capable gpios
  (bnc#1012628).
- gpio: gpio-omap: limit errata 1.101 handling to wkup domain
  gpios only (bnc#1012628).
- ice: Add missing case in print_link_msg for printing flow
  control (bnc#1012628).
- media: v4l2-ctrl: v4l2_ctrl_request_setup returns with error
  upon failure (bnc#1012628).
- batman-adv: Adjust name for batadv_dat_send_data (bnc#1012628).
- ice: Enable LAN_EN for the right recipes (bnc#1012628).
- ice: Do not set LB_EN for prune switch rules (bnc#1012628).
- dmaengine: idma64: Use actual device for DMA transfers
  (bnc#1012628).
- pwm: tiehrpwm: Update shadow register for disabling PWMs
  (bnc#1012628).
- media: v4l2-fwnode: Defaults may not override endpoint
  configuration in firmware (bnc#1012628).
- ARM: dts: exynos: Always enable necessary APIO_1V8 and ABB_1V8
  regulators on Arndale Octa (bnc#1012628).
- pwm: Fix deadlock warning when removing PWM device
  (bnc#1012628).
- ARM: exynos: Fix undefined instruction during Exynos5422 resume
  (bnc#1012628).
- usb: typec: fusb302: Check vconn is off when we start toggling
  (bnc#1012628).
- soc: renesas: Identify R-Car M3-W ES1.3 (bnc#1012628).
- ARM: shmobile: porter: enable R-Car Gen2 regulator quirk
  (bnc#1012628).
- gpio: vf610: Do not share irq_chip (bnc#1012628).
- percpu: do not search past bitmap when allocating an area
  (bnc#1012628).
- Revert "Bluetooth: Align minimum encryption key size for LE
  and BR/EDR connections" (bnc#1012628).
- Revert "drm/nouveau: add kconfig option to turn off nouveau
  legacy contexts. (v3)" (bnc#1012628).
- ovl: check the capability before cred overridden (bnc#1012628).
- ovl: support stacked SEEK_HOLE/SEEK_DATA (bnc#1012628).
- ALSA: seq: Cover unsubscribe_port() in list_mutex (bnc#1012628).
- io_uring: fix failure to verify SQ_AFF cpu (bnc#1012628).
- Refresh
  patches.suse/RFC-Bluetooth-Check-key-sizes-only-when-Secure-Simple-Pairing-is-enabled.patch.
- commit 0aa1dd8
* Sun Jun 16 2019 mkubecek@suse.cz
- Update to 5.2-rc5
- Config changes:
  - Sound:
  - SND_SOC_SOF_NOCODEC_SUPPORT=n on x86, =y on ARM
  - Storage:
  - MQ_IOSCHED_DEADLINE m -> y on arm64
- commit b5857f8
* Thu Jun 13 2019 msuchanek@suse.de
- Build klp-symbols in kernel devel projects.
- commit ffd0ed9
* Thu Jun 13 2019 jdelvare@suse.de
- supported.conf: Enable it87_wdt and f71808e_wdt
  Both drivers are for watchdog devices included in Super-I/O chipsets
  which are popular on x86 PC mainboards. Code is clean and simple,
  so supporting them isn't a problem.
- commit b818771
* Wed Jun 12 2019 jslaby@suse.cz
- Update config files.
  The previous commit did not play well. 5.1.9 is broken with =n of that
  option, so leave it as =y as it was before 5.1.9.
- commit e68f829
* Wed Jun 12 2019 jslaby@suse.cz
- Update config files.
  Set CONFIG_NOUVEAU_LEGACY_CTX_SUPPORT=n, the same as master.
- commit cf58ab1
* Tue Jun 11 2019 jslaby@suse.cz
- Linux 5.1.9 (bnc#1012628).
- ethtool: fix potential userspace buffer overflow (bnc#1012628).
- Fix memory leak in sctp_process_init (bnc#1012628).
- ipv4: not do cache for local delivery if bc_forwarding is
  enabled (bnc#1012628).
- ipv6: fix the check before getting the cookie in rt6_get_cookie
  (bnc#1012628).
- net: ethernet: ti: cpsw_ethtool: fix ethtool ring param set
  (bnc#1012628).
- net: mvpp2: Use strscpy to handle stat strings (bnc#1012628).
- net: rds: fix memory leak in rds_ib_flush_mr_pool (bnc#1012628).
- net: sfp: read eeprom in maximum 16 byte increments
  (bnc#1012628).
- packet: unconditionally free po->rollover (bnc#1012628).
- pktgen: do not sleep with the thread lock held (bnc#1012628).
- Revert "fib_rules: return 0 directly if an exactly same rule
  exists when NLM_F_EXCL not supplied" (bnc#1012628).
- udp: only choose unbound UDP socket for multicast when not in
  a VRF (bnc#1012628).
- ipv6: use READ_ONCE() for inet->hdrincl as in ipv4
  (bnc#1012628).
- ipv6: fix EFAULT on sendto with icmpv6 and hdrincl
  (bnc#1012628).
- net: aquantia: fix wol configuration not applied sometimes
  (bnc#1012628).
- neighbor: Reset gc_entries counter if new entry is released
  before insert (bnc#1012628).
- neighbor: Call __ipv4_neigh_lookup_noref in neigh_xmit
  (bnc#1012628).
- cls_matchall: avoid panic when receiving a packet before filter
  set (bnc#1012628).
- ipmr_base: Do not reset index in mr_table_dump (bnc#1012628).
- net/mlx4_en: ethtool, Remove unsupported SFP EEPROM high pages
  query (bnc#1012628).
- net/tls: replace the sleeping lock around RX resync with a
  bit lock (bnc#1012628).
- rcu: locking and unlocking need to always be at least barriers
  (bnc#1012628).
- habanalabs: fix debugfs code (bnc#1012628).
- ARC: mm: SIGSEGV userspace trying to access kernel virtual
  memory (bnc#1012628).
- parisc: Use implicit space register selection for loading the
  coherence index of I/O pdirs (bnc#1012628).
- parisc: Fix crash due alternative coding for NP iopdir_fdc bit
  (bnc#1012628).
- SUNRPC fix regression in umount of a secure mount (bnc#1012628).
- SUNRPC: Fix a use after free when a server rejects the
  RPCSEC_GSS credential (bnc#1012628).
- NFSv4.1: Again fix a race where CB_NOTIFY_LOCK fails to wake
  a waiter (bnc#1012628).
- NFSv4.1: Fix bug only first CB_NOTIFY_LOCK is handled
  (bnc#1012628).
- fuse: fallocate: fix return with locked inode (bnc#1012628).
- fuse: fix copy_file_range() in the writeback case (bnc#1012628).
- pstore: Set tfm to NULL on free_buf_for_compression
  (bnc#1012628).
- pstore/ram: Run without kernel crash dump region (bnc#1012628).
- kbuild: use more portable 'command -v' for cc-cross-prefix
  (bnc#1012628).
- memstick: mspro_block: Fix an error code in
  mspro_block_issue_req() (bnc#1012628).
- mmc: tmio: fix SCC error handling to avoid false positive CRC
  error (bnc#1012628).
- mmc: sdhci_am654: Fix SLOTTYPE write (bnc#1012628).
- x86/power: Fix 'nosmt' vs hibernation triple fault during resume
  (bnc#1012628).
- x86/insn-eval: Fix use-after-free access to LDT entry
  (bnc#1012628).
- i2c: xiic: Add max_read_len quirk (bnc#1012628).
- s390/mm: fix address space detection in exception handling
  (bnc#1012628).
- nvme-rdma: fix queue mapping when queue count is limited
  (bnc#1012628).
- xen-blkfront: switch kcalloc to kvcalloc for large array
  allocation (bnc#1012628).
- MIPS: Bounds check virt_addr_valid (bnc#1012628).
- MIPS: pistachio: Build uImage.gz by default (bnc#1012628).
- genwqe: Prevent an integer overflow in the ioctl (bnc#1012628).
- test_firmware: Use correct snprintf() limit (bnc#1012628).
- drm/rockchip: fix fb references in async update (bnc#1012628).
- drm/vc4: fix fb references in async update (bnc#1012628).
- drm/gma500/cdv: Check vbt config bits when detecting lvds panels
  (bnc#1012628).
- drm/msm: fix fb references in async update (bnc#1012628).
- drm: add non-desktop quirk for Valve HMDs (bnc#1012628).
- drm/nouveau: add kconfig option to turn off nouveau legacy
  contexts. (v3) (bnc#1012628).
- drm: add non-desktop quirks to Sensics and OSVR headsets
  (bnc#1012628).
- drm: Fix timestamp docs for variable refresh properties
  (bnc#1012628).
- drm/amdgpu/psp: move psp version specific function pointers
  to early_init (bnc#1012628).
- drm/radeon: prefer lower reference dividers (bnc#1012628).
- drm/amdgpu: remove ATPX_DGPU_REQ_POWER_FOR_DISPLAYS check when
  hotplug-in (bnc#1012628).
- drm/i915: Fix I915_EXEC_RING_MASK (bnc#1012628).
- drm/amdgpu/soc15: skip reset on init (bnc#1012628).
- drm/amd/display: Add ASICREV_IS_PICASSO (bnc#1012628).
- drm/amdgpu: fix ring test failure issue during s3 in vce 3.0
  (V2) (bnc#1012628).
- drm/i915/fbc: disable framebuffer compression on GeminiLake
  (bnc#1012628).
- drm/i915/gvt: emit init breadcrumb for gvt request
  (bnc#1012628).
- drm: don't block fb changes for async plane updates
  (bnc#1012628).
- drm/i915/gvt: Initialize intel_gvt_gtt_entry in stack
  (bnc#1012628).
- drm/amd: fix fb references in async update (bnc#1012628).
- ipv4: Define __ipv4_neigh_lookup_noref when CONFIG_INET is
  disabled (bnc#1012628).
- commit 8904439
* Tue Jun 11 2019 jslaby@suse.cz
- Revert "drm: allow render capable master with DRM_AUTH ioctls"
  (fix radv check).
- commit 3ca4077
* Tue Jun 11 2019 jslaby@suse.cz
- drm/i915: Maintain consistent documentation subsection ordering
  (fix kernel-doc).
- Delete
  patches.rpmify/Revert-doc-Cope-with-the-deprecation-of-AutoReporter.patch.
  Use usptream fix instead of revert.
- commit 4e8aae9
* Mon Jun 10 2019 lduncan@suse.com
- scsi: mpt3sas_ctl: fix double-fetch bug in _ctl_ioctl_main()
  (bsc#1136922 cve-2019-12456).
- commit 0c3fc9f
* Mon Jun 10 2019 jslaby@suse.cz
- Revert "doc: Cope with the deprecation of AutoReporter"
  (fix kernel-doc).
- commit 1c5c2b4
* Mon Jun 10 2019 mkubecek@suse.cz
- Update to 5.2-rc4
- Eliminated 1 patch
  - patches.rpmify/mlx5-avoid-64-bit-division.patch
- Refresh configs
  - IKHEADERS_PROC -> IKHEADERS
- commit c8bdb02
* Sun Jun  9 2019 jslaby@suse.cz
- Linux 5.1.8 (bnc#1012628).
- sparc64: Fix regression in non-hypervisor TLB flush xcall
  (bnc#1012628).
- include/linux/bitops.h: sanitize rotate primitives
  (bnc#1012628).
- xhci: update bounce buffer with correct sg num (bnc#1012628).
- xhci: Use %%zu for printing size_t type (bnc#1012628).
- xhci: Convert xhci_handshake() to use
  readl_poll_timeout_atomic() (bnc#1012628).
- usb: xhci: avoid null pointer deref when bos field is NULL
  (bnc#1012628).
- usbip: usbip_host: fix BUG: sleeping function called from
  invalid context (bnc#1012628).
- usbip: usbip_host: fix stub_dev lock context imbalance
  regression (bnc#1012628).
- USB: Fix slab-out-of-bounds write in usb_get_bos_descriptor
  (bnc#1012628).
- USB: sisusbvga: fix oops in error path of sisusb_probe
  (bnc#1012628).
- USB: Add LPM quirk for Surface Dock GigE adapter (bnc#1012628).
- USB: rio500: refuse more than one device at a time
  (bnc#1012628).
- USB: rio500: fix memory leak in close after disconnect
  (bnc#1012628).
- media: usb: siano: Fix general protection fault in smsusb
  (bnc#1012628).
- media: usb: siano: Fix false-positive "uninitialized variable"
  warning (bnc#1012628).
- media: smsusb: better handle optional alignment (bnc#1012628).
- brcmfmac: fix NULL pointer derefence during USB disconnect
  (bnc#1012628).
- scsi: zfcp: fix missing zfcp_port reference put on -EBUSY from
  port_remove (bnc#1012628).
- scsi: zfcp: fix to prevent port_remove with pure auto scan LUNs
  (only sdevs) (bnc#1012628).
- tracing: Avoid memory leak in predicate_parse() (bnc#1012628).
- Btrfs: fix wrong ctime and mtime of a directory after log replay
  (bnc#1012628).
- Btrfs: fix race updating log root item during fsync
  (bnc#1012628).
- Btrfs: fix fsync not persisting changed attributes of a
  directory (bnc#1012628).
- btrfs: correct zstd workspace manager lock to use spin_lock_bh()
  (bnc#1012628).
- btrfs: qgroup: Check bg while resuming relocation to avoid
  NULL pointer dereference (bnc#1012628).
- Btrfs: incremental send, fix file corruption when no-holes
  feature is enabled (bnc#1012628).
- btrfs: reloc: Also queue orphan reloc tree for cleanup to
  avoid BUG_ON() (bnc#1012628).
- iio: dac: ds4422/ds4424 fix chip verification (bnc#1012628).
- iio: adc: ads124: avoid buffer overflow (bnc#1012628).
- iio: adc: modify NPCM ADC read reference voltage (bnc#1012628).
- iio: adc: ti-ads8688: fix timestamp is not updated in buffer
  (bnc#1012628).
- s390/crypto: fix gcm-aes-s390 selftest failures (bnc#1012628).
- s390/crypto: fix possible sleep during spinlock aquired
  (bnc#1012628).
- KVM: PPC: Book3S HV: XIVE: Do not clear IRQ data of passthrough
  interrupts (bnc#1012628).
- KVM: PPC: Book3S HV: Fix lockdep warning when entering guest
  on POWER9 (bnc#1012628).
- KVM: PPC: Book3S HV: Restore SPRG3 in kvmhv_p9_guest_entry()
  (bnc#1012628).
- powerpc/perf: Fix MMCRA corruption by bhrb_filter (bnc#1012628).
- powerpc/kexec: Fix loading of kernel + initramfs with
  kexec_file_load() (bnc#1012628).
- ALSA: line6: Assure canceling delayed work at disconnection
  (bnc#1012628).
- ALSA: hda/realtek - Set default power save node to 0
  (bnc#1012628).
- ALSA: hda/realtek - Improve the headset mic for Acer Aspire
  laptops (bnc#1012628).
- KVM: s390: Do not report unusabled IDs via KVM_CAP_MAX_VCPU_ID
  (bnc#1012628).
- drm/nouveau/i2c: Disable i2c bus access after ->fini()
  (bnc#1012628).
- i2c: mlxcpld: Fix wrong initialization order in probe
  (bnc#1012628).
- i2c: synquacer: fix synquacer_i2c_doxfer() return value
  (bnc#1012628).
- tty: serial: msm_serial: Fix XON/XOFF (bnc#1012628).
- tty: max310x: Fix external crystal register setup (bnc#1012628).
- mm, memcg: consider subtrees in memory.events (bnc#1012628).
- kasan: initialize tag to 0xff in __kasan_kmalloc (bnc#1012628).
- kernel/signal.c: trace_signal_deliver when signal_group_exit
  (bnc#1012628).
- signal/arm64: Use force_sig not force_sig_fault for SIGKILL
  (bnc#1012628).
- mm, compaction: make sure we isolate a valid PFN (bnc#1012628).
- arm64: Fix the arm64_personality() syscall wrapper redirection
  (bnc#1012628).
- docs: Fix conf.py for Sphinx 2.0 (bnc#1012628).
- doc: Cope with the deprecation of AutoReporter (bnc#1012628).
- doc: Cope with Sphinx logging deprecations (bnc#1012628).
- x86/ima: Check EFI_RUNTIME_SERVICES before using (bnc#1012628).
- ima: fix wrong signed policy requirement when not appraising
  (bnc#1012628).
- ima: show rules with IMA_INMASK correctly (bnc#1012628).
- evm: check hash algorithm passed to init_desc() (bnc#1012628).
- clk: imx: imx8mm: fix int pll clk gate (bnc#1012628).
- vt/fbcon: deinitialize resources in visual_init() after failed
  memory allocation (bnc#1012628).
- serial: sh-sci: disable DMA for uart_console (bnc#1012628).
- staging: vc04_services: prevent integer overflow in
  create_pagelist() (bnc#1012628).
- staging: wlan-ng: fix adapter initialization failure
  (bnc#1012628).
- cifs: fix memory leak of pneg_inbuf on -EOPNOTSUPP ioctl case
  (bnc#1012628).
- CIFS: cifs_read_allocate_pages: don't iterate through whole
  page array on ENOMEM (bnc#1012628).
- Revert "lockd: Show pid of lockd for remote locks"
  (bnc#1012628).
- gcc-plugins: Fix build failures under Darwin host (bnc#1012628).
- drm/tegra: gem: Fix CPU-cache maintenance for BO's allocated
  using get_pages() (bnc#1012628).
- drm/vmwgfx: Fix user space handle equal to zero (bnc#1012628).
- drm/vmwgfx: Fix compat mode shader operation (bnc#1012628).
- drm/vmwgfx: Don't send drm sysfs hotplug events on initial
  master set (bnc#1012628).
- drm/sun4i: Fix sun8i HDMI PHY clock initialization
  (bnc#1012628).
- drm/sun4i: Fix sun8i HDMI PHY configuration for > 148.5 MHz
  (bnc#1012628).
- drm/imx: ipuv3-plane: fix atomic update status query for
  non-plus i.MX6Q (bnc#1012628).
- drm/fb-helper: generic: Call drm_client_add() after setup is
  done (bnc#1012628).
- drm/atomic: Wire file_priv through for property changes
  (bnc#1012628).
- drm: Expose "FB_DAMAGE_CLIPS" property to atomic aware
  user-space only (bnc#1012628).
- drm/rockchip: shutdown drm subsystem on shutdown (bnc#1012628).
- drm/lease: Make sure implicit planes are leased (bnc#1012628).
- drm/cma-helper: Fix drm_gem_cma_free_object() (bnc#1012628).
- Revert "x86/build: Move _etext to actual end of .text"
  (bnc#1012628).
- x86/kprobes: Set instruction page as executable (bnc#1012628).
- commit ed4965b
* Fri Jun  7 2019 mvedovati@suse.com
- rpm/post.sh: correct typo in err msg (bsc#1137625)
- commit 9fe85cc
* Thu Jun  6 2019 jslaby@suse.cz
- s390: drop meaningless 'targets' from tools Makefile (s390
  kmp build fix).
- commit c8cc0ca
* Wed Jun  5 2019 mvedovati@suse.com
- Enhance kvmsmall configuration (bsc#1137361)
  Add a minimal set of modules to  kvmsmall, to make this config usable
  to set up guest VMs interacting with the host.
- commit 34c4eab
* Wed Jun  5 2019 mkubecek@suse.cz
- config: refresh configs
  No functional change.
- commit cbc8b7e
* Tue Jun  4 2019 oneukum@suse.com
- mwifiex: Fix heap overflow in mwifiex_uap_parse_tail_ies()
  (bsc#1136935).
- commit eda4f06
* Tue Jun  4 2019 oneukum@suse.com
- mwifiex: Abort at too short BSS descriptor element (bsc#1136424
  CVE-2019-3846).
- commit 1841f21
* Tue Jun  4 2019 oneukum@suse.com
- mwifiex: Fix possible buffer overflows at parsing bss descriptor
- commit 3972810
* Tue Jun  4 2019 jslaby@suse.cz
- Update config files.
  Enable CRASH_DUMP and RELOCATABLE on ppc64le to be on par with the
  other archs and to allow for kdump (bnc#1135217).
- commit a6a9f0e
* Tue Jun  4 2019 jslaby@suse.cz
- Linux 5.1.7 (bnc#1012628).
- tipc: fix modprobe tipc failed after switch order of device
  registration (bnc#1012628).
- Revert "tipc: fix modprobe tipc failed after switch order of
  device registration" (bnc#1012628).
- crypto: vmx - ghash: do nosimd fallback manually (bnc#1012628).
- net: correct zerocopy refcnt with udp MSG_MORE (bnc#1012628).
- cxgb4: Revert "cxgb4: Remove SGE_HOST_PAGE_SIZE dependency on
  page size" (bnc#1012628).
- net/tls: don't ignore netdev notifications if no TLS features
  (bnc#1012628).
- net/tls: fix state removal with feature flags off (bnc#1012628).
- selftests/tls: add test for sleeping even though there is data
  (bnc#1012628).
- net/tls: fix no wakeup on partial reads (bnc#1012628).
- selftests/tls: test for lowat overshoot with multiple records
  (bnc#1012628).
- net/tls: fix lowat calculation if some data came from previous
  record (bnc#1012628).
- bnxt_en: Reduce memory usage when running in kdump kernel
  (bnc#1012628).
- bnxt_en: Fix possible BUG() condition when calling
  pci_disable_msix() (bnc#1012628).
- bnxt_en: Fix aggregation buffer leak under OOM condition
  (bnc#1012628).
- net: stmmac: dma channel control register need to be init first
  (bnc#1012628).
- net: stmmac: fix ethtool flow control not able to get/set
  (bnc#1012628).
- net/mlx5e: Disable rxhash when CQE compress is enabled
  (bnc#1012628).
- net/mlx5: Allocate root ns memory using kzalloc to match kfree
  (bnc#1012628).
- tipc: Avoid copying bytes beyond the supplied data
  (bnc#1012628).
- net/mlx5: Avoid double free in fs init error unwinding path
  (bnc#1012628).
- usbnet: fix kernel crash after disconnect (bnc#1012628).
- r8169: fix MAC address being lost in PCI D3 (bnc#1012628).
- net: stmmac: fix reset gpio free missing (bnc#1012628).
- net: sched: don't use tc_action->order during action dump
  (bnc#1012628).
- net: phy: marvell10g: report if the PHY fails to boot firmware
  (bnc#1012628).
- net: mvpp2: fix bad MVPP2_TXQ_SCHED_TOKEN_CNTR_REG queue value
  (bnc#1012628).
- net: mvneta: Fix err code path of probe (bnc#1012628).
- net-gro: fix use-after-free read in napi_gro_frags()
  (bnc#1012628).
- net: fec: fix the clk mismatch in failed_reset path
  (bnc#1012628).
- net: dsa: mv88e6xxx: fix handling of upper half of
  STATS_TYPE_PORT (bnc#1012628).
- mlxsw: spectrum_acl: Avoid warning after identical rules
  insertion (bnc#1012628).
- llc: fix skb leak in llc_build_and_send_ui_pkt() (bnc#1012628).
- ipv6: Fix redirect with VRF (bnc#1012628).
- ipv6: Consider sk_bound_dev_if when binding a raw socket to
  an address (bnc#1012628).
- ipv4/igmp: fix build error if !CONFIG_IP_MULTICAST
  (bnc#1012628).
- ipv4/igmp: fix another memory leak in igmpv3_del_delrec()
  (bnc#1012628).
- inet: switch IP ID generator to siphash (bnc#1012628).
- ethtool: Check for vlan etype or vlan tci when parsing flow_rule
  (bnc#1012628).
- cxgb4: offload VLAN flows regardless of VLAN ethtype
  (bnc#1012628).
- bonding/802.3ad: fix slave link initialization transition states
  (bnc#1012628).
- commit 55f2451
* Mon Jun  3 2019 mkubecek@suse.cz
- Update to 5.2-rc3
- Eliminated 1 patch
  - patches.suse/kvm-memunmap-also-needs-HAS_IOMEM.patch
- commit 038ee83
* Mon Jun  3 2019 jslaby@suse.cz
- Refresh
  patches.suse/memcg-make-it-work-on-sparse-non-0-node-systems.patch.
  Update upstream status.
- commit 2e484d7
* Fri May 31 2019 jslaby@suse.cz
- Linux 5.1.6 (bnc#1012628).
- x86: Hide the int3_emulate_call/jmp functions from UML
  (bnc#1012628).
- ext4: do not delete unlinked inode from orphan list on failed
  truncate (bnc#1012628).
- ext4: wait for outstanding dio during truncate in nojournal mode
  (bnc#1012628).
- KVM: x86: fix return value for reserved EFER (bnc#1012628).
- bio: fix improper use of smp_mb__before_atomic() (bnc#1012628).
- sbitmap: fix improper use of smp_mb__before_atomic()
  (bnc#1012628).
- Revert "scsi: sd: Keep disk read-only when re-reading partition"
  (bnc#1012628).
- crypto: hash - fix incorrect HASH_MAX_DESCSIZE (bnc#1012628).
- crypto: vmx - CTR: always increment IV as quadword
  (bnc#1012628).
- mmc: sdhci-iproc: cygnus: Set NO_HISPD bit to fix HS50 data
  hold time problem (bnc#1012628).
- mmc: sdhci-iproc: Set NO_HISPD bit to fix HS50 data hold time
  problem (bnc#1012628).
- tracing: Add a check_val() check before updating cond_snapshot()
  track_val (bnc#1012628).
- dax: Arrange for dax_supported check to span multiple devices
  (bnc#1012628).
- kvm: Check irqchip mode before assign irqfd (bnc#1012628).
- kvm: svm/avic: fix off-by-one in checking host APIC ID
  (bnc#1012628).
- KVM: nVMX: Fix using __this_cpu_read() in preemptible context
  (bnc#1012628).
- libnvdimm/pmem: Bypass CONFIG_HARDENED_USERCOPY overhead
  (bnc#1012628).
- arm64/kernel: kaslr: reduce module randomization range to 2 GB
  (bnc#1012628).
- arm64: Kconfig: Make ARM64_PSEUDO_NMI depend on BROKEN for now
  (bnc#1012628).
- arm64/iommu: handle non-remapped addresses in ->mmap and
  - >get_sgtable (bnc#1012628).
- gfs2: Fix sign extension bug in gfs2_update_stats (bnc#1012628).
- btrfs: don't double unlock on error in btrfs_punch_hole
  (bnc#1012628).
- btrfs: Check the compression level before getting a workspace
  (bnc#1012628).
- Btrfs: do not abort transaction at btrfs_update_root() after
  failure to COW path (bnc#1012628).
- Btrfs: avoid fallback to transaction commit during fsync of
  files with holes (bnc#1012628).
- Btrfs: fix race between ranged fsync and writeback of adjacent
  ranges (bnc#1012628).
- btrfs: sysfs: Fix error path kobject memory leak (bnc#1012628).
- btrfs: sysfs: don't leak memory when failing add fsid
  (bnc#1012628).
- fbdev: fix divide error in fb_var_to_videomode (bnc#1012628).
- arm64: errata: Add workaround for Cortex-A76 erratum #1463225
  (bnc#1012628).
- ovl: relax WARN_ON() for overlapping layers use case
  (bnc#1012628).
- fbdev: fix WARNING in __alloc_pages_nodemask bug (bnc#1012628).
- media: cpia2: Fix use-after-free in cpia2_exit (bnc#1012628).
- media: serial_ir: Fix use-after-free in serial_ir_init_module
  (bnc#1012628).
- media: vb2: add waiting_in_dqbuf flag (bnc#1012628).
- media: vivid: use vfree() instead of kfree() for dev->bitmap_cap
  (bnc#1012628).
- ssb: Fix possible NULL pointer dereference in
  ssb_host_pcmcia_exit (bnc#1012628).
- bpf: devmap: fix use-after-free Read in __dev_map_entry_free
  (bnc#1012628).
- batman-adv: mcast: fix multicast tt/tvlv worker locking
  (bnc#1012628).
- at76c50x-usb: Don't register led_trigger if usb_register_driver
  failed (bnc#1012628).
- acct_on(): don't mess with freeze protection (bnc#1012628).
- netfilter: ctnetlink: Resolve conntrack L3-protocol flush
  regression (bnc#1012628).
- Revert "btrfs: Honour FITRIM range constraints during free
  space trim" (bnc#1012628).
- gfs2: Fix lru_count going negative (bnc#1012628).
- cxgb4: Fix error path in cxgb4_init_module (bnc#1012628).
- afs: Fix getting the afs.fid xattr (bnc#1012628).
- NFS: make nfs_match_client killable (bnc#1012628).
- gfs2: fix race between gfs2_freeze_func and unmount
  (bnc#1012628).
- io_uring: use cpu_online() to check p->sq_thread_cpu instead
  of cpu_possible() (bnc#1012628).
- IB/hfi1: Fix WQ_MEM_RECLAIM warning (bnc#1012628).
- gfs2: Fix occasional glock use-after-free (bnc#1012628).
- mmc: core: Verify SD bus width (bnc#1012628).
- tools/bpf: fix perf build error with uClibc (seen on ARC)
  (bnc#1012628).
- i40e: Fix of memory leak and integer truncation in
  i40e_virtchnl.c (bnc#1012628).
- libbpf: fix invalid munmap call (bnc#1012628).
- selftests/bpf: set RLIMIT_MEMLOCK properly for
  test_libbpf_open.c (bnc#1012628).
- bpftool: exclude bash-completion/bpftool from .gitignore pattern
  (bnc#1012628).
- ice: Separate if conditions for ice_set_features()
  (bnc#1012628).
- ice: Preserve VLAN Rx stripping settings (bnc#1012628).
- blk-mq: split blk_mq_alloc_and_init_hctx into two parts
  (bnc#1012628).
- blk-mq: grab .q_usage_counter when queuing request from plug
  code path (bnc#1012628).
- dmaengine: tegra210-dma: free dma controller in remove()
  (bnc#1012628).
- net: ena: gcc 8: fix compilation warning (bnc#1012628).
- net: ena: fix: set freed objects to NULL to avoid failing
  future allocations (bnc#1012628).
- hv_netvsc: fix race that may miss tx queue wakeup (bnc#1012628).
- Bluetooth: Ignore CC events not matching the last HCI command
  (bnc#1012628).
- pinctrl: zte: fix leaked of_node references (bnc#1012628).
- ASoC: Intel: kbl_da7219_max98357a: Map BTN_0 to KEY_PLAYPAUSE
  (bnc#1012628).
- usb: dwc2: gadget: Increase descriptors count for ISOC's
  (bnc#1012628).
- usb: dwc3: move synchronize_irq() out of the spinlock protected
  block (bnc#1012628).
- usb: gadget: f_fs: don't free buffer prematurely (bnc#1012628).
- ASoC: hdmi-codec: unlock the device on startup errors
  (bnc#1012628).
- powerpc/perf: Return accordingly on invalid chip-id in
  (bnc#1012628).
- powerpc/boot: Fix missing check of lseek() return value
  (bnc#1012628).
- powerpc/perf: Fix loop exit condition in nest_imc_event_init
  (bnc#1012628).
- spi: atmel-quadspi: fix crash while suspending (bnc#1012628).
- ASoC: imx: fix fiq dependencies (bnc#1012628).
- spi: pxa2xx: fix SCR (divisor) calculation (bnc#1012628).
- net/mlx5: E-Switch, Use atomic rep state to serialize state
  change (bnc#1012628).
- brcm80211: potential NULL dereference in
  brcmf_cfg80211_vndr_cmds_dcmd_handler() (bnc#1012628).
- ACPI / property: fix handling of data_nodes in
  acpi_get_next_subnode() (bnc#1012628).
- drm/nouveau/bar/nv50: ensure BAR is mapped (bnc#1012628).
- media: stm32-dcmi: return appropriate error codes during probe
  (bnc#1012628).
- ARM: vdso: Remove dependency with the arch_timer driver
  internals (bnc#1012628).
- arm64: Fix compiler warning from pte_unmap() with
  - Wunused-but-set-variable (bnc#1012628).
- mt76: remove mt76_queue dependency from tx_queue_skb function
  pointer (bnc#1012628).
- x86/ftrace: Set trampoline pages as executable (bnc#1012628).
- powerpc/watchdog: Use hrtimers for per-CPU heartbeat
  (bnc#1012628).
- cpufreq: Fix kobject memleak (bnc#1012628).
- scsi: qla2xxx: Fix a qla24xx_enable_msix() error path
  (bnc#1012628).
- scsi: qla2xxx: Fix abort handling in tcm_qla2xxx_write_pending()
  (bnc#1012628).
- scsi: qla2xxx: Avoid that lockdep complains about unsafe
  locking in tcm_qla2xxx_close_session() (bnc#1012628).
- scsi: qla2xxx: Fix hardirq-unsafe locking (bnc#1012628).
- x86/modules: Avoid breaking W^X while loading modules
  (bnc#1012628).
- Btrfs: fix data bytes_may_use underflow with fallocate due to
  failed quota reserve (bnc#1012628).
- btrfs: fix panic during relocation after ENOSPC before writeback
  happens (bnc#1012628).
- btrfs: Don't panic when we can't find a root key (bnc#1012628).
- iwlwifi: pcie: don't crash on invalid RX interrupt
  (bnc#1012628).
- rtc: 88pm860x: prevent use-after-free on device remove
  (bnc#1012628).
- rtc: stm32: manage the get_irq probe defer case (bnc#1012628).
- scsi: qedi: Abort ep termination if offload not scheduled
  (bnc#1012628).
- s390/kexec_file: Fix detection of text segment in ELF loader
  (bnc#1012628).
- ALSA: hda: fix unregister device twice on ASoC driver
  (bnc#1012628).
- sched/nohz: Run NOHZ idle load balancer on HK_FLAG_MISC CPUs
  (bnc#1012628).
- net: ethernet: ti: cpsw: fix allmulti cfg in dual_mac mode
  (bnc#1012628).
- w1: fix the resume command API (bnc#1012628).
- net: hns3: fix pause configure fail problem (bnc#1012628).
- net: hns3: fix for TX clean num when cleaning TX BD
  (bnc#1012628).
- net: phy: improve genphy_soft_reset (bnc#1012628).
- s390: qeth: address type mismatch warning (bnc#1012628).
- arm64: futex: Fix FUTEX_WAKE_OP atomic ops with non-zero result
  value (bnc#1012628).
- net: hns3: use atomic_t replace u32 for arq's count
  (bnc#1012628).
- dmaengine: pl330: _stop: clear interrupt status (bnc#1012628).
- mac80211/cfg80211: update bss channel on channel switch
  (bnc#1012628).
- drm: prefix header search paths with $(srctree)/ (bnc#1012628).
- libbpf: fix samples/bpf build failure due to undefined
  UINT32_MAX (bnc#1012628).
- slimbus: fix a potential NULL pointer dereference in
  of_qcom_slim_ngd_register (bnc#1012628).
- regulator: core: Actually put the gpiod after use (bnc#1012628).
- ASoC: fsl_sai: Update is_slave_mode with correct value
  (bnc#1012628).
- Fix nfs4.2 return -EINVAL when do dedupe operation
  (bnc#1012628).
- mwifiex: prevent an array overflow (bnc#1012628).
- rsi: Fix NULL pointer dereference in kmalloc (bnc#1012628).
- net: cw1200: fix a NULL pointer dereference (bnc#1012628).
- nvme: set 0 capacity if namespace block size exceeds PAGE_SIZE
  (bnc#1012628).
- nvme-rdma: fix a NULL deref when an admin connect times out
  (bnc#1012628).
- nvme-tcp: fix a NULL deref when an admin connect times out
  (bnc#1012628).
- crypto: sun4i-ss - Fix invalid calculation of hash end
  (bnc#1012628).
- bcache: avoid potential memleak of list of journal_replay(s)
  in the CACHE_SYNC branch of run_cache_set (bnc#1012628).
- bcache: return error immediately in bch_journal_replay()
  (bnc#1012628).
- bcache: fix failure in journal relplay (bnc#1012628).
- bcache: add failure check to run_cache_set() for journal replay
  (bnc#1012628).
- bcache: avoid clang -Wunintialized warning (bnc#1012628).
- RDMA/cma: Consider scope_id while binding to ipv6 ll address
  (bnc#1012628).
- vfio-ccw: Do not call flush_workqueue while holding the spinlock
  (bnc#1012628).
- vfio-ccw: Release any channel program when releasing/removing
  vfio-ccw mdev (bnc#1012628).
- x86/build: Move _etext to actual end of .text (bnc#1012628).
- smpboot: Place the __percpu annotation correctly (bnc#1012628).
- x86/uaccess: Dont leak the AC flag into __put_user() argument
  evaluation (bnc#1012628).
- x86/mm: Remove in_nmi() warning from 64-bit implementation of
  vmalloc_fault() (bnc#1012628).
- mm/uaccess: Use 'unsigned long' to placate UBSAN warnings on
  older GCC versions (bnc#1012628).
- Bluetooth: hci_qca: Fix crash with non-serdev devices
  (bnc#1012628).
- Bluetooth: hci_qca: Give enough time to ROME controller to
  bootup (bnc#1012628).
- Bluetooth: btbcm: Add default address for BCM43341B
  (bnc#1012628).
- Bluetooth: mediatek: Fixed incorrect type in assignment
  (bnc#1012628).
- HID: logitech-hidpp: use RAP instead of FAP to get the protocol
  version (bnc#1012628).
- pinctrl: pistachio: fix leaked of_node references (bnc#1012628).
- pinctrl: st: fix leaked of_node references (bnc#1012628).
- pinctrl: samsung: fix leaked of_node references (bnc#1012628).
- clk: rockchip: undo several noc and special clocks as critical
  on rk3288 (bnc#1012628).
- perf/arm-cci: Remove broken race mitigation (bnc#1012628).
- dmaengine: at_xdmac: remove BUG_ON macro in tasklet
  (bnc#1012628).
- media: coda: clear error return value before picture run
  (bnc#1012628).
- media: ov6650: Move v4l2_clk_get() to ov6650_video_probe()
  helper (bnc#1012628).
- media: au0828: stop video streaming only when last user stops
  (bnc#1012628).
- media: ov2659: make S_FMT succeed even if requested format
  doesn't match (bnc#1012628).
- audit: fix a memory leak bug (bnc#1012628).
- media: stm32-dcmi: fix crash when subdev do not expose any
  formats (bnc#1012628).
- media: au0828: Fix NULL pointer dereference in
  au0828_analog_stream_enable() (bnc#1012628).
- media: pvrusb2: Prevent a buffer overflow (bnc#1012628).
- iio: adc: stm32-dfsdm: fix unmet direct dependencies detected
  (bnc#1012628).
- block: fix use-after-free on gendisk (bnc#1012628).
- powerpc/numa: improve control of topology updates (bnc#1012628).
- powerpc/64: Fix booting large kernels with STRICT_KERNEL_RWX
  (bnc#1012628).
- random: fix CRNG initialization when random.trust_cpu=1
  (bnc#1012628).
- random: add a spinlock_t to struct batched_entropy
  (bnc#1012628).
- cgroup: protect cgroup->nr_(dying_)descendants by css_set_lock
  (bnc#1012628).
- sched/core: Check quota and period overflow at usec to nsec
  conversion (bnc#1012628).
- sched/rt: Check integer overflow at usec to nsec conversion
  (bnc#1012628).
- sched/core: Handle overflow in cpu_shares_write_u64
  (bnc#1012628).
- staging: vc04_services: handle kzalloc failure (bnc#1012628).
- drm/msm/dpu: release resources on modeset failure (bnc#1012628).
- drm/msm: a5xx: fix possible object reference leak (bnc#1012628).
- drm/msm: dpu: Don't set frame_busy_mask for async updates
  (bnc#1012628).
- drm/msm: Fix NULL pointer dereference (bnc#1012628).
- irq_work: Do not raise an IPI when queueing work on the local
  CPU (bnc#1012628).
- thunderbolt: Take domain lock in switch sysfs attribute
  callbacks (bnc#1012628).
- s390/qeth: handle error from qeth_update_from_chp_desc()
  (bnc#1012628).
- USB: core: Don't unbind interfaces following device reset
  failure (bnc#1012628).
- x86/irq/64: Limit IST stack overflow check to #DB stack
  (bnc#1012628).
- drm: etnaviv: avoid DMA API warning when importing buffers
  (bnc#1012628).
- dt-bindings: phy-qcom-qmp: Add UFS PHY reset (bnc#1012628).
- phy: sun4i-usb: Make sure to disable PHY0 passby for peripheral
  mode (bnc#1012628).
- phy: mapphone-mdm6600: add gpiolib dependency (bnc#1012628).
- phy: ti: usb2: fix OMAP_CONTROL_PHY dependency (bnc#1012628).
- dpaa2-eth: Fix Rx classification status (bnc#1012628).
- i40e: Able to add up to 16 MAC filters on an untrusted VF
  (bnc#1012628).
- i40e: don't allow changes to HW VLAN stripping on active port
  VLANs (bnc#1012628).
- ACPI/IORT: Reject platform device creation on NUMA node mapping
  failure (bnc#1012628).
- arm64: vdso: Fix clock_getres() for CLOCK_REALTIME
  (bnc#1012628).
- RDMA/cxgb4: Fix null pointer dereference on alloc_skb failure
  (bnc#1012628).
- fscrypt: use READ_ONCE() to access ->i_crypt_info (bnc#1012628).
- perf/x86/msr: Add Icelake support (bnc#1012628).
- perf/x86/intel/rapl: Add Icelake support (bnc#1012628).
- perf/x86/intel/cstate: Add Icelake support (bnc#1012628).
- PM / devfreq: Fix static checker warning in
  try_then_request_governor (bnc#1012628).
- hwmon: (vt1211) Use request_muxed_region for Super-IO accesses
  (bnc#1012628).
- hwmon: (smsc47m1) Use request_muxed_region for Super-IO accesses
  (bnc#1012628).
- hwmon: (smsc47b397) Use request_muxed_region for Super-IO
  accesses (bnc#1012628).
- hwmon: (pc87427) Use request_muxed_region for Super-IO accesses
  (bnc#1012628).
- hwmon: (f71805f) Use request_muxed_region for Super-IO accesses
  (bnc#1012628).
- scsi: libsas: Do discovery on empty PHY to update PHY info
  (bnc#1012628).
- mmc: core: make pwrseq_emmc (partially) support sleepy GPIO
  controllers (bnc#1012628).
- mmc_spi: add a status check for spi_sync_locked (bnc#1012628).
- mmc: sdhci-of-esdhc: add erratum eSDHC5 support (bnc#1012628).
- mmc: sdhci-of-esdhc: add erratum A-009204 support (bnc#1012628).
- mmc: sdhci-of-esdhc: add erratum eSDHC-A001 and A-008358 support
  (bnc#1012628).
- net: hns3: free the pending skb when clean RX ring
  (bnc#1012628).
- drm/amdgpu: fix old fence check in amdgpu_fence_emit
  (bnc#1012628).
- PM / core: Propagate dev->power.wakeup_path when no callbacks
  (bnc#1012628).
- clk: rockchip: Fix video codec clocks on rk3288 (bnc#1012628).
- extcon: arizona: Disable mic detect if running when driver is
  removed (bnc#1012628).
- clk: rockchip: Make rkpwm a critical clock on rk3288
  (bnc#1012628).
- clk: zynqmp: fix check for fractional clock (bnc#1012628).
- s390: zcrypt: initialize variables before_use (bnc#1012628).
- x86/microcode: Fix the ancient deprecated microcode loading
  method (bnc#1012628).
- drm/amd/display: Initialize stream_update with memset
  (bnc#1012628).
- s390/mm: silence compiler warning when compiling without
  CONFIG_PGSTE (bnc#1012628).
- s390: cio: fix cio_irb declaration (bnc#1012628).
- drm/amd/display: use proper formula to calculate bandwidth
  from timing (bnc#1012628).
- selftests: cgroup: fix cleanup path in
  test_memcg_subtree_control() (bnc#1012628).
- net: hns3: fix keep_alive_timer not stop problem (bnc#1012628).
- qmi_wwan: Add quirk for Quectel dynamic config (bnc#1012628).
- net: hns3: add error handler for initializing command queue
  (bnc#1012628).
- cpufreq: ppc_cbe: fix possible object reference leak
  (bnc#1012628).
- cpufreq/pasemi: fix possible object reference leak
  (bnc#1012628).
- cpufreq: pmac32: fix possible object reference leak
  (bnc#1012628).
- cpufreq: kirkwood: fix possible object reference leak
  (bnc#1012628).
- cpufreq: imx6q: fix possible object reference leak
  (bnc#1012628).
- cpufreq: ap806: fix possible object reference leak
  (bnc#1012628).
- block: sed-opal: fix IOC_OPAL_ENABLE_DISABLE_MBR (bnc#1012628).
- habanalabs: prevent device PTE read/write during hard-reset
  (bnc#1012628).
- habanalabs: all FD must be closed before removing device
  (bnc#1012628).
- samples/bpf: fix build with new clang (bnc#1012628).
- x86/build: Keep local relocations with ld.lld (bnc#1012628).
- spi: Don't call spi_get_gpio_descs() before device name is set
  (bnc#1012628).
- regulator: core: Avoid potential deadlock on
  regulator_unregister (bnc#1012628).
- ASoC: core: remove link components before cleaning up card
  resources (bnc#1012628).
- drm/pl111: fix possible object reference leak (bnc#1012628).
- iio: ad_sigma_delta: Properly handle SPI bus locking vs CS
  assertion (bnc#1012628).
- iio: hmc5843: fix potential NULL pointer dereferences
  (bnc#1012628).
- iio: common: ssp_sensors: Initialize calculated_time in
  ssp_common_process_data (bnc#1012628).
- iio: adc: ti-ads7950: Fix improper use of mlock (bnc#1012628).
- net: hns3: check resetting status in hns3_get_stats()
  (bnc#1012628).
- net: hns3: add protect when handling mac addr list
  (bnc#1012628).
- selftests/bpf: ksym_search won't check symbols exists
  (bnc#1012628).
- rtlwifi: fix a potential NULL pointer dereference (bnc#1012628).
- mwifiex: Fix mem leak in mwifiex_tm_cmd (bnc#1012628).
- brcmfmac: fix missing checks for kmemdup (bnc#1012628).
- b43: shut up clang -Wuninitialized variable warning
  (bnc#1012628).
- brcmfmac: convert dev_init_lock mutex to completion
  (bnc#1012628).
- brcmfmac: fix WARNING during USB disconnect in case of unempty
  psq (bnc#1012628).
- brcmfmac: fix race during disconnect when USB completion is
  in progress (bnc#1012628).
- brcmfmac: fix Oops when bringing up interface during USB
  disconnect (bnc#1012628).
- rtc: xgene: fix possible race condition (bnc#1012628).
- spi: Add missing error handling for CS GPIOs (bnc#1012628).
- rtlwifi: fix potential NULL pointer dereference (bnc#1012628).
- scsi: ufs: Fix regulator load and icc-level configuration
  (bnc#1012628).
- scsi: ufs: Avoid configuring regulator with undefined voltage
  range (bnc#1012628).
- drm/panel: otm8009a: Add delay at the end of initialization
  (bnc#1012628).
- drm/amd/display: Prevent cursor hotspot overflow for RV overlay
  planes (bnc#1012628).
- arm64: cpu_ops: fix a leaked reference by adding missing
  of_node_put (bnc#1012628).
- locking/static_key: Fix false positive warnings on concurrent
  dec/inc (bnc#1012628).
- wil6210: fix return code of wmi_mgmt_tx and wmi_mgmt_tx_ext
  (bnc#1012628).
- x86/uaccess, ftrace: Fix ftrace_likely_update() vs. SMAP
  (bnc#1012628).
- iwlwifi: mvm: IBSS: use BE FIFO for multicast (bnc#1012628).
- x86/uaccess, signal: Fix AC=1 bloat (bnc#1012628).
- x86/ia32: Fix ia32_restore_sigcontext() AC leak (bnc#1012628).
- x86/uaccess: Fix up the fixup (bnc#1012628).
- chardev: add additional check for minor range overlap
  (bnc#1012628).
- RDMA/hns: Fix bad endianess of port_pd variable (bnc#1012628).
- sh: sh7786: Add explicit I/O cast to sh7786_mm_sel()
  (bnc#1012628).
- HID: core: move Usage Page concatenation to Main item
  (bnc#1012628).
- ASoC: eukrea-tlv320: fix a leaked reference by adding missing
  of_node_put (bnc#1012628).
- ASoC: fsl_utils: fix a leaked reference by adding missing
  of_node_put (bnc#1012628).
- ASoC: wcd9335: fix a leaked reference by adding missing
  of_node_put (bnc#1012628).
- cxgb3/l2t: Fix undefined behaviour (bnc#1012628).
- clk: renesas: rcar-gen3: Correct parent clock of SYS-DMAC
  (bnc#1012628).
- block: avoid to break XEN by multi-page bvec (bnc#1012628).
- block: pass page to xen_biovec_phys_mergeable (bnc#1012628).
- clk: renesas: rcar-gen3: Correct parent clock of Audio-DMAC
  (bnc#1012628).
- HID: logitech-hidpp: change low battery level threshold from
  31 to 30 percent (bnc#1012628).
- spi: tegra114: reset controller on probe (bnc#1012628).
- habanalabs: prevent CPU soft lockup on Palladium (bnc#1012628).
- kobject: Don't trigger kobject_uevent(KOBJ_REMOVE) twice
  (bnc#1012628).
- media: video-mux: fix null pointer dereferences (bnc#1012628).
- media: wl128x: prevent two potential buffer overflows
  (bnc#1012628).
- media: gspca: Kill URBs on USB device disconnect (bnc#1012628).
- media: mtk-vcodec: fix access to incorrect planes member
  (bnc#1012628).
- thunderbolt: property: Fix a missing check of kzalloc
  (bnc#1012628).
- thunderbolt: Fix to check the return value of kmemdup
  (bnc#1012628).
- drm: rcar-du: lvds: Set LVEN and LVRES bits together on D3
  (bnc#1012628).
- drm: rcar-du: lvds: Fix post-DLL divider calculation
  (bnc#1012628).
- timekeeping: Force upper bound for setting CLOCK_REALTIME
  (bnc#1012628).
- IB/mlx5: Compare only index part of a memory window rkey
  (bnc#1012628).
- scsi: qedf: Add missing return in qedf_post_io_req() in the
  fcport offload check (bnc#1012628).
- misc: fastrpc: consider address offset before sending to DSP
  (bnc#1012628).
- misc: fastrpc: make sure memory read and writes are visible
  (bnc#1012628).
- misc: fastrpc: Fix a possible double free (bnc#1012628).
- virtio_console: initialize vtermno value for ports
  (bnc#1012628).
- tty: ipwireless: fix missing checks for ioremap (bnc#1012628).
- staging: mt7621-mmc: Initialize completions a single time
  during probe (bnc#1012628).
- overflow: Fix -Wtype-limits compilation warnings (bnc#1012628).
- x86/mce: Fix machine_check_poll() tests for error types
  (bnc#1012628).
- rcutorture: Fix cleanup path for invalid torture_type strings
  (bnc#1012628).
- x86/mce: Handle varying MCA bank counts (bnc#1012628).
- rcuperf: Fix cleanup path for invalid perf_type strings
  (bnc#1012628).
- rcu: Do a single rhp->func read in rcu_head_after_call_rcu()
  (bnc#1012628).
- x86/platform/uv: Fix missing checks of kcalloc() return values
  (bnc#1012628).
- RDMA/rxe: Fix slab-out-bounds access which lead to kernel
  crash later (bnc#1012628).
- spi: stm32-qspi: add spi_master_put in release function
  (bnc#1012628).
- usb: core: Add PM runtime calls to usb_hcd_platform_shutdown
  (bnc#1012628).
- ice: Fix for adaptive interrupt moderation (bnc#1012628).
- scsi: qla4xxx: avoid freeing unallocated dma memory
  (bnc#1012628).
- scsi: lpfc: avoid uninitialized variable warning (bnc#1012628).
- media: vicodec: bugfix - call v4l2_m2m_buf_copy_metadata also
  if decoding fails (bnc#1012628).
- ice: Prevent unintended multiple chain resets (bnc#1012628).
- selinux: avoid uninitialized variable warning (bnc#1012628).
- batman-adv: allow updating DAT entry timeouts on incoming ARP
  Replies (bnc#1012628).
- dmaengine: tegra210-adma: use devm_clk_*() helpers
  (bnc#1012628).
- x86/CPU/hygon: Fix phys_proc_id calculation logic for multi-die
  processors (bnc#1012628).
- net/mlx5e: Fix compilation warning in en_tc.c (bnc#1012628).
- staging: mt7621-mmc: Check for nonzero number of scatterlist
  entries (bnc#1012628).
- hwrng: omap - Set default quality (bnc#1012628).
- thunderbolt: Fix to check return value of ida_simple_get
  (bnc#1012628).
- thunderbolt: Fix to check for kmemdup failure (bnc#1012628).
- spi: export tracepoint symbols to modules (bnc#1012628).
- regulator: add regulator_get_linear_step() stub helper
  (bnc#1012628).
- drm/amd/display: fix releasing planes when exiting odm
  (bnc#1012628).
- drm/amd/display: Link train only when link is DP and backend
  is enabled (bnc#1012628).
- drm/amd/display: Update ABM crtc state on non-modeset
  (bnc#1012628).
- drm/amd/display: Reset alpha state for planes to the correct
  values (bnc#1012628).
- thunderbolt: property: Fix a NULL pointer dereference
  (bnc#1012628).
- media: v4l2-fwnode: The first default data lane is 0 on C-PHY
  (bnc#1012628).
- media: ov7670: restore default settings after power-up
  (bnc#1012628).
- media: staging/intel-ipu3: mark PM function as __maybe_unused
  (bnc#1012628).
- media: vicodec: reset last_src/dst_buf based on the IS_OUTPUT
  (bnc#1012628).
- ice: Fix issue with VF reset and multiple VFs support on PFs
  (bnc#1012628).
- e1000e: Disable runtime PM on CNP+ (bnc#1012628).
- tinydrm/mipi-dbi: Use dma-safe buffers for all SPI transfers
  (bnc#1012628).
- igb: Exclude device from suspend direct complete optimization
  (bnc#1012628).
- media: si2165: fix a missing check of return value
  (bnc#1012628).
- media: dvbsky: Avoid leaking dvb frontend (bnc#1012628).
- media: m88ds3103: serialize reset messages in
  m88ds3103_set_frontend (bnc#1012628).
- drm/amd/display: add pipe lock during stream update
  (bnc#1012628).
- media: staging: davinci_vpfe: disallow building with
  COMPILE_TEST (bnc#1012628).
- drm/amd/display: Fix Divide by 0 in memory calculations
  (bnc#1012628).
- drm/amd/display: Re-add custom degamma support (bnc#1012628).
- drm/amd/display: half bandwidth for YCbCr420 during validation
  (bnc#1012628).
- drm/amd/display: Set stream->mode_changed when connectors change
  (bnc#1012628).
- scsi: ufs: fix a missing check of devm_reset_control_get
  (bnc#1012628).
- media: vimc: stream: fix thread state before sleep
  (bnc#1012628).
- media: gspca: do not resubmit URBs when streaming has stopped
  (bnc#1012628).
- media: vicodec: avoid clang frame size warning (bnc#1012628).
- media: go7007: avoid clang frame overflow warning with KASAN
  (bnc#1012628).
- media: mtk-vcodec: fix access to vb2_v4l2_buffer struct
  (bnc#1012628).
- media: imx: vdic: Restore default case to
  prepare_vdi_in_buffers() (bnc#1012628).
- media: vimc: zero the media_device on probe (bnc#1012628).
- media: vim2m: replace devm_kzalloc by kzalloc (bnc#1012628).
- media: cedrus: Add a quirk for not setting DMA offset
  (bnc#1012628).
- scsi: lpfc: Fix FDMI manufacturer attribute value (bnc#1012628).
- scsi: lpfc: Fix fc4type information for FDMI (bnc#1012628).
- scsi: lpfc: Fix io lost on host resets (bnc#1012628).
- media: saa7146: avoid high stack usage with clang (bnc#1012628).
- scsi: lpfc: Fix SLI3 commands being issued on SLI4 devices
  (bnc#1012628).
- scsi: lpfc: Fix mailbox hang on adapter init (bnc#1012628).
- scsi: lpfc: Resolve inconsistent check of hdwq in
  lpfc_scsi_cmd_iocb_cmpl (bnc#1012628).
- scsi: lpfc: Resolve irq-unsafe lockdep heirarchy warning in
  lpfc_io_free (bnc#1012628).
- scsi: lpfc: Fix use-after-free mailbox cmd completion
  (bnc#1012628).
- audit: fix a memleak caused by auditing load module
  (bnc#1012628).
- spi : spi-topcliff-pch: Fix to handle empty DMA buffers
  (bnc#1012628).
- drm: writeback: Fix leak of writeback job (bnc#1012628).
- drm/omap: dsi: Fix PM for display blank with paired dss_pll
  calls (bnc#1012628).
- drm/omap: Notify all devices in the pipeline of output
  disconnection (bnc#1012628).
- spi: rspi: Fix sequencer reset during initialization
  (bnc#1012628).
- regulator: wm831x ldo: Fix notifier mutex lock warning
  (bnc#1012628).
- regulator: wm831x isink: Fix notifier mutex lock warning
  (bnc#1012628).
- regulator: ltc3676: Fix notifier mutex lock warning
  (bnc#1012628).
- regulator: ltc3589: Fix notifier mutex lock warning
  (bnc#1012628).
- regulator: pv88060: Fix notifier mutex lock warning
  (bnc#1012628).
- spi: imx: stop buffer overflow in RX FIFO flush (bnc#1012628).
- regulator: lp8755: Fix notifier mutex lock warning
  (bnc#1012628).
- regulator: da9211: Fix notifier mutex lock warning
  (bnc#1012628).
- regulator: da9063: Fix notifier mutex lock warning
  (bnc#1012628).
- regulator: pv88080: Fix notifier mutex lock warning
  (bnc#1012628).
- regulator: wm831x: Fix notifier mutex lock warning
  (bnc#1012628).
- regulator: pv88090: Fix notifier mutex lock warning
  (bnc#1012628).
- regulator: da9062: Fix notifier mutex lock warning
  (bnc#1012628).
- regulator: da9055: Fix notifier mutex lock warning
  (bnc#1012628).
- spi: Fix zero length xfer bug (bnc#1012628).
- ASoC: davinci-mcasp: Fix clang warning without CONFIG_PM
  (bnc#1012628).
- ASoC: ti: fix davinci_mcasp_probe dependencies (bnc#1012628).
- drm/v3d: Handle errors from IRQ setup (bnc#1012628).
- drm/amd/display: Fix exception from AUX acquire failure
  (bnc#1012628).
- drm/amd/display: Reset planes that were disabled in init_pipes
  (bnc#1012628).
- drm/drv: Hold ref on parent device during drm_device lifetime
  (bnc#1012628).
- drm: Wake up next in drm_read() chain if we are forced to
  putback the event (bnc#1012628).
- drm/sun4i: dsi: Change the start delay calculation
  (bnc#1012628).
- drm/sun4i: dsi: Restrict DSI tcon clock divider (bnc#1012628).
- vfio-ccw: Prevent quiesce function going into an infinite loop
  (bnc#1012628).
- extcon: axp288: Add a depends on ACPI to the Kconfig entry
  (bnc#1012628).
- ice: Put __ICE_PREPARED_FOR_RESET check in ice_prepare_for_reset
  (bnc#1012628).
- drm/sun4i: dsi: Enforce boundaries on the start delay
  (bnc#1012628).
- NFS: Fix a double unlock from nfs_match,get_client
  (bnc#1012628).
- Update config files.
- commit 7375706
* Wed May 29 2019 mkubecek@suse.cz
- config: refresh vanilla configs
- commit cbe6c1c
* Wed May 29 2019 mkubecek@suse.cz
- reenable ARM architectures
- commit 194828b
* Wed May 29 2019 mkubecek@suse.cz
- refresh configs after Tumbleweed switch to gcc9 as default
- commit 3b7ae7e
* Wed May 29 2019 yousaf.kaukab@suse.com
- config: armv7hl: lpae: Update to v5.2.0-rc2
- commit 38ac345
* Wed May 29 2019 yousaf.kaukab@suse.com
- config: armv7hl: Update to v5.2.0-rc2
- commit 737b08e
* Wed May 29 2019 yousaf.kaukab@suse.com
- config: armv6hl: Update to v5.2.0-rc2
- commit c7bc712
* Tue May 28 2019 yousaf.kaukab@suse.com
- config: arm64: Update to v5.2.0-rc2
- commit 18d0586
* Mon May 27 2019 jslaby@suse.cz
- Update config files.
- commit 6ad4f79
* Mon May 27 2019 mkubecek@suse.cz
- Update to 5.2-rc2
- Eliminated 4 patches
  - patches.suse/dm-make-sure-to-obey-max_io_len_target_boundary.patch
  - patches.suse/kvm-make-kvm_vcpu_-un-map-dependency-on-CONFIG_HAS_I.patch
  - patches.suse/vfio_pci-Add-local-source-directory-as-include.patch
  - patches.suse/x86-kvm-pmu-Set-AMD-s-virt-PMU-version-to-1.patch
- add s390x/zfcpdump build fix
  - patches.suse/kvm-memunmap-also-needs-HAS_IOMEM.patch
- commit b02c459
* Sun May 26 2019 jslaby@suse.cz
- Linux 5.1.5 (bnc#1012628).
- ipv6: fix src addr routing with the exception table
  (bnc#1012628).
- ipv6: prevent possible fib6 leaks (bnc#1012628).
- net: Always descend into dsa/ (bnc#1012628).
- net: avoid weird emergency message (bnc#1012628).
- net/mlx4_core: Change the error print to info print
  (bnc#1012628).
- net: test nouarg before dereferencing zerocopy pointers
  (bnc#1012628).
- net: usb: qmi_wwan: add Telit 0x1260 and 0x1261 compositions
  (bnc#1012628).
- nfp: flower: add rcu locks when accessing netdev for tunnels
  (bnc#1012628).
- ppp: deflate: Fix possible crash in deflate_init (bnc#1012628).
- rtnetlink: always put IFLA_LINK for links with a link-netnsid
  (bnc#1012628).
- tipc: switch order of device registration to fix a crash
  (bnc#1012628).
- vsock/virtio: free packets during the socket release
  (bnc#1012628).
- tipc: fix modprobe tipc failed after switch order of device
  registration (bnc#1012628).
- mlxsw: core: Prevent QSFP module initialization for old hardware
  (bnc#1012628).
- mlxsw: core: Prevent reading unsupported slave address from
  SFP EEPROM (bnc#1012628).
- flow_offload: support CVLAN match (bnc#1012628).
- net/mlx5e: Fix calling wrong function to get inner vlan key
  and mask (bnc#1012628).
- net/mlx5: Fix peer pf disable hca command (bnc#1012628).
- vsock/virtio: Initialize core virtio vsock before registering
  the driver (bnc#1012628).
- net/mlx5e: Add missing ethtool driver info for representors
  (bnc#1012628).
- net/mlx5e: Additional check for flow destination comparison
  (bnc#1012628).
- net/mlx5: Imply MLXFW in mlx5_core (bnc#1012628).
- net/mlx5e: Fix ethtool rxfh commands when CONFIG_MLX5_EN_RXNFC
  is disabled (bnc#1012628).
- blk-mq: free hw queue's resource in hctx's release handler
  (bnc#1012628).
- regulator: core: fix error path for
  regulator_set_voltage_unlocked (bnc#1012628).
- parisc: Export running_on_qemu symbol for modules (bnc#1012628).
- parisc: Add memory clobber to TLB purges (bnc#1012628).
- parisc: Skip registering LED when running in QEMU (bnc#1012628).
- parisc: Add memory barrier to asm pdc and sync instructions
  (bnc#1012628).
- parisc: Allow live-patching of __meminit functions
  (bnc#1012628).
- parisc: Use PA_ASM_LEVEL in boot code (bnc#1012628).
- parisc: Rename LEVEL to PA_ASM_LEVEL to avoid name clash with
  DRBD code (bnc#1012628).
- stm class: Fix channel free in stm output free path
  (bnc#1012628).
- stm class: Fix channel bitmap on 32-bit systems (bnc#1012628).
- brd: re-enable __GFP_HIGHMEM in brd_insert_page() (bnc#1012628).
- proc: prevent changes to overridden credentials (bnc#1012628).
- Revert "MD: fix lock contention for flush bios" (bnc#1012628).
- md: batch flush requests (bnc#1012628).
- md: add mddev->pers to avoid potential NULL pointer dereference
  (bnc#1012628).
- md: add a missing endianness conversion in check_sb_changes
  (bnc#1012628).
- dcache: sort the freeing-without-RCU-delay mess for good
  (bnc#1012628).
- intel_th: msu: Fix single mode with IOMMU (bnc#1012628).
- p54: drop device reference count if fails to enable device
  (bnc#1012628).
- of: fix clang -Wunsequenced for be32_to_cpu() (bnc#1012628).
- brcmfmac: Add DMI nvram filename quirk for ACEPC T8 and T11
  mini PCs (bnc#1012628).
- cifs: fix credits leak for SMB1 oplock breaks (bnc#1012628).
- cifs: fix strcat buffer overflow and reduce raciness in
  smb21_set_oplock_level() (bnc#1012628).
- phy: ti-pipe3: fix missing bit-wise or operator when assigning
  val (bnc#1012628).
- media: ov6650: Fix sensor possibly not detected on probe
  (bnc#1012628).
- media: seco-cec: fix building with RC_CORE=m (bnc#1012628).
- media: imx: csi: Allow unknown nearest upstream entities
  (bnc#1012628).
- media: imx: Clear fwnode link struct for each endpoint iteration
  (bnc#1012628).
- media: imx: Rename functions that add IPU-internal subdevs
  (bnc#1012628).
- media: imx: Don't register IPU subdevs/links if CSI port missing
  (bnc#1012628).
- RDMA/mlx5: Use get_zeroed_page() for clock_info (bnc#1012628).
- RDMA/ipoib: Allow user space differentiate between valid
  dev_port (bnc#1012628).
- NFS4: Fix v4.0 client state corruption when mount (bnc#1012628).
- PNFS fallback to MDS if no deviceid found (bnc#1012628).
- clk: hi3660: Mark clk_gate_ufs_subsys as critical (bnc#1012628).
- clk: tegra: Fix PLLM programming on Tegra124+ when PMC overrides
  divider (bnc#1012628).
- clk: mediatek: Disable tuner_en before change PLL rate
  (bnc#1012628).
- clk: rockchip: fix wrong clock definitions for rk3328
  (bnc#1012628).
- udlfb: delete the unused parameter for dlfb_handle_damage
  (bnc#1012628).
- udlfb: fix sleeping inside spinlock (bnc#1012628).
- udlfb: introduce a rendering mutex (bnc#1012628).
- fuse: fix writepages on 32bit (bnc#1012628).
- fuse: honor RLIMIT_FSIZE in fuse_file_fallocate (bnc#1012628).
- ovl: fix missing upper fs freeze protection on copy up for ioctl
  (bnc#1012628).
- fsnotify: fix unlink performance regression (bnc#1012628).
- gcc-plugins: arm_ssp_per_task_plugin: Fix for older GCC < 6
  (bnc#1012628).
- iommu/tegra-smmu: Fix invalid ASID bits on Tegra30/114
  (bnc#1012628).
- ceph: flush dirty inodes before proceeding with remount
  (bnc#1012628).
- x86_64: Add gap to int3 to allow for call emulation
  (bnc#1012628).
- x86_64: Allow breakpoints to emulate call instructions
  (bnc#1012628).
- ftrace/x86_64: Emulate call function while updating in
  breakpoint handler (bnc#1012628).
- tracing: Fix partial reading of trace event's id file
  (bnc#1012628).
- tracing: probeevent: Fix to make the type of $comm string
  (bnc#1012628).
- memory: tegra: Fix integer overflow on tick value calculation
  (bnc#1012628).
- perf intel-pt: Fix instructions sampling rate (bnc#1012628).
- perf intel-pt: Fix improved sample timestamp (bnc#1012628).
- perf intel-pt: Fix sample timestamp wrt non-taken branches
  (bnc#1012628).
- MIPS: perf: Fix build with CONFIG_CPU_BMIPS5000 enabled
  (bnc#1012628).
- objtool: Allow AR to be overridden with HOSTAR (bnc#1012628).
- x86/mpx, mm/core: Fix recursive munmap() corruption
  (bnc#1012628).
- fbdev/efifb: Ignore framebuffer memmap entries that lack any
  memory types (bnc#1012628).
- fbdev: sm712fb: fix brightness control on reboot, don't set SR30
  (bnc#1012628).
- fbdev: sm712fb: fix VRAM detection, don't set SR70/71/74/75
  (bnc#1012628).
- fbdev: sm712fb: fix white screen of death on reboot, don't
  set CR3B-CR3F (bnc#1012628).
- fbdev: sm712fb: fix boot screen glitch when sm712fb replaces
  VGA (bnc#1012628).
- fbdev: sm712fb: fix crashes during framebuffer writes by
  correctly mapping VRAM (bnc#1012628).
- fbdev: sm712fb: fix support for 1024x768-16 mode (bnc#1012628).
- fbdev: sm712fb: use 1024x768 by default on non-MIPS, fix
  garbled display (bnc#1012628).
- fbdev: sm712fb: fix crashes and garbled display during DPMS
  modesetting (bnc#1012628).
- PCI: Mark AMD Stoney Radeon R7 GPU ATS as broken (bnc#1012628).
- PCI: Mark Atheros AR9462 to avoid bus reset (bnc#1012628).
- PCI: Reset Lenovo ThinkPad P50 nvgpu at boot if necessary
  (bnc#1012628).
- PCI: Init PCIe feature bits for managed host bridge alloc
  (bnc#1012628).
- PCI/AER: Change pci_aer_init() stub to return void
  (bnc#1012628).
- PCI: rcar: Add the initialization of PCIe link in resume_noirq()
  (bnc#1012628).
- PCI: Factor out pcie_retrain_link() function (bnc#1012628).
- PCI: Work around Pericom PCIe-to-PCI bridge Retrain Link erratum
  (bnc#1012628).
- dm cache metadata: Fix loading discard bitset (bnc#1012628).
- dm zoned: Fix zone report handling (bnc#1012628).
- dm init: fix max devices/targets checks (bnc#1012628).
- dm delay: fix a crash when invalid device is specified
  (bnc#1012628).
- dm crypt: move detailed message into debug level (bnc#1012628).
- dm integrity: correctly calculate the size of metadata area
  (bnc#1012628).
- dm ioctl: fix hang in early create error condition
  (bnc#1012628).
- dm mpath: always free attached_handler_name in parse_path()
  (bnc#1012628).
- fuse: Add FOPEN_STREAM to use stream_open() (bnc#1012628).
- md/raid: raid5 preserve the writeback action after the parity
  check (bnc#1012628).
- dmaengine: imx-sdma: Only check ratio on parts that support 1:1
  (bnc#1012628).
- driver core: Postpone DMA tear-down until after devres release
  for probe failure (bnc#1012628).
- bpf: relax inode permission check for retrieving bpf program
  (bnc#1012628).
- bpf: add map_lookup_elem_sys_only for lookups from syscall side
  (bnc#1012628).
- bpf, lru: avoid messing with eviction heuristics upon syscall
  lookup (bnc#1012628).
- y2038: Make CONFIG_64BIT_TIME unconditional (bnc#1012628).
- btrfs: reloc: Fix NULL pointer dereference due to expanded
  reloc_root lifespan (bnc#1012628).
- ARM: dts: imx6q-logicpd: Reduce inrush current on USBH1
  (bnc#1012628).
- ARM: dts: imx6q-logicpd: Reduce inrush current on start
  (bnc#1012628).
- fbdev: sm712fb: fix memory frequency by avoiding a switch/case
  fallthrough (bnc#1012628).
- Update config files.
- commit bde30e1
* Thu May 23 2019 tiwai@suse.de
- Bluetooth: Check key sizes only when Secure Simple Pairing is
  enabled (bsc#1135556).
- commit ed1f493
* Wed May 22 2019 msuchanek@suse.de
- Delete patches.suse/Revert-Bluetooth-btusb-driver-to-enable-the-usb-wake.patch (boo#1130448).
  Should be fixed in 5.1-rc5
  commit 771acc7e4a6e5dba779cb1a7fd851a164bc81033
  Author: Brian Norris <briannorris@chromium.org>
  Date:   Tue Apr 9 11:49:17 2019 -0700
    Bluetooth: btusb: request wake pin with NOAUTOEN
- commit 817786b
* Wed May 22 2019 jslaby@suse.cz
- Update config files.
- commit 0739fa4
* Wed May 22 2019 jslaby@suse.cz
- dm: make sure to obey max_io_len_target_boundary (bnc#1135868).
- commit dbeb07c
* Wed May 22 2019 jslaby@suse.cz
- Linux 5.1.4 (bnc#1012628).
- s390/mm: convert to the generic get_user_pages_fast code
  (bnc#1012628).
- s390/mm: make the pxd_offset functions more robust
  (bnc#1012628).
- libnvdimm/namespace: Fix label tracking error (bnc#1012628).
- powerpc/32s: fix flush_hash_pages() on SMP (bnc#1012628).
- xen/pvh: correctly setup the PV EFI interface for dom0
  (bnc#1012628).
- xen/pvh: set xen_domain_type to HVM in xen_pvh_init
  (bnc#1012628).
- kbuild: turn auto.conf.cmd into a mandatory include file
  (bnc#1012628).
- smb3: display session id in debug data (bnc#1012628).
- KVM: lapic: Busy wait for timer to expire when using hv_timer
  (bnc#1012628).
- KVM: x86: Skip EFER vs. guest CPUID checks for host-initiated
  writes (bnc#1012628).
- KVM: Fix the bitmap range to copy during clear dirty
  (bnc#1012628).
- Revert "KVM: nVMX: Expose RDPMC-exiting only when guest supports
  PMU" (bnc#1012628).
- jbd2: fix potential double free (bnc#1012628).
- ALSA: hda/realtek - Fix for Lenovo B50-70 inverted internal
  microphone bug (bnc#1012628).
- ALSA: hda/realtek - Fixup headphone noise via runtime suspend
  (bnc#1012628).
- ALSA: hda/realtek - Corrected fixup for System76 Gazelle
  (gaze14) (bnc#1012628).
- ext4: avoid panic during forced reboot due to aborted journal
  (bnc#1012628).
- ext4: fix use-after-free in dx_release() (bnc#1012628).
- ext4: fix data corruption caused by overlapping unaligned and
  aligned IO (bnc#1012628).
- ext4: zero out the unused memory region in the extent tree block
  (bnc#1012628).
- tty: Don't force RISCV SBI console as preferred console
  (bnc#1012628).
- fs/writeback.c: use rcu_barrier() to wait for inflight wb
  switches going into workqueue when umount (bnc#1012628).
- mm/compaction.c: correct zone boundary handling when isolating
  pages from a pageblock (bnc#1012628).
- ARM: dts: imx: Fix the AR803X phy-mode (bnc#1012628).
- ipmi:ssif: compare block number correctly for multi-part return
  messages (bnc#1012628).
- ipmi: Add the i2c-addr property for SSIF interfaces
  (bnc#1012628).
- bcache: never set KEY_PTRS of journal key to 0 in
  journal_reclaim() (bnc#1012628).
- bcache: fix a race between cache register and cacheset
  unregister (bnc#1012628).
- Btrfs: fix race between send and deduplication that lead to
  failures and crashes (bnc#1012628).
- Btrfs: do not start a transaction at iterate_extent_inodes()
  (bnc#1012628).
- Btrfs: do not start a transaction during fiemap (bnc#1012628).
- Btrfs: send, flush dellaloc in order to avoid data loss
  (bnc#1012628).
- btrfs: Honour FITRIM range constraints during free space trim
  (bnc#1012628).
- btrfs: Correctly free extent buffer in case
  btree_read_extent_buffer_pages fails (bnc#1012628).
- btrfs: Check the first key and level for cached extent buffer
  (bnc#1012628).
- ext4: fix ext4_show_options for file systems w/o journal
  (bnc#1012628).
- ext4: actually request zeroing of inode table after grow
  (bnc#1012628).
- ext4: fix use-after-free race with debug_want_extra_isize
  (bnc#1012628).
- ext4: avoid drop reference to iloc.bh twice (bnc#1012628).
- ext4: ignore e_value_offs for xattrs with value-in-ea-inode
  (bnc#1012628).
- ext4: make sanity check in mballoc more strict (bnc#1012628).
- jbd2: check superblock mapped prior to committing (bnc#1012628).
- tty/vt: fix write/write race in ioctl(KDSKBSENT) handler
  (bnc#1012628).
- tty: vt.c: Fix TIOCL_BLANKSCREEN console blanking if
  blankinterval == 0 (bnc#1012628).
- mtd: maps: Allow MTD_PHYSMAP with MTD_RAM (bnc#1012628).
- mtd: maps: physmap: Store gpio_values correctly (bnc#1012628).
- mtd: spi-nor: intel-spi: Avoid crossing 4K address boundary
  on read/write (bnc#1012628).
- mfd: max77620: Fix swapped FPS_PERIOD_MAX_US values
  (bnc#1012628).
- mfd: da9063: Fix OTP control register names to match datasheets
  for DA9063/63L (bnc#1012628).
- ACPICA: Linux: move ACPI_DEBUG_DEFAULT flag out of ifndef
  (bnc#1012628).
- ACPI: PM: Set enable_for_wake for wakeup GPEs during
  suspend-to-idle (bnc#1012628).
- userfaultfd: use RCU to free the task struct when fork fails
  (bnc#1012628).
- ocfs2: fix ocfs2 read inode data panic in ocfs2_iget
  (bnc#1012628).
- hugetlb: use same fault hash key for shared and private mappings
  (bnc#1012628).
- mm/hugetlb.c: don't put_page in lock of hugetlb_lock
  (bnc#1012628).
- mm/huge_memory: fix vmf_insert_pfn_{pmd, pud}() crash, handle
  unaligned addresses (bnc#1012628).
- mm/mincore.c: make mincore() more conservative (bnc#1012628).
- crypto: ccree - handle tee fips error during power management
  resume (bnc#1012628).
- crypto: ccree - add function to handle cryptocell tee fips error
  (bnc#1012628).
- crypto: ccree - HOST_POWER_DOWN_EN should be the last CC access
  during suspend (bnc#1012628).
- crypto: ccree - pm resume first enable the source clk
  (bnc#1012628).
- crypto: ccree - don't map AEAD key and IV on stack
  (bnc#1012628).
- crypto: ccree - use correct internal state sizes for export
  (bnc#1012628).
- crypto: ccree - don't map MAC key on stack (bnc#1012628).
- crypto: ccree - fix mem leak on error path (bnc#1012628).
- crypto: ccree - remove special handling of chained sg
  (bnc#1012628).
- bpf: fix out of bounds backwards jmps due to dead code removal
  (bnc#1012628).
- bpf, arm64: remove prefetch insn in xadd mapping (bnc#1012628).
- ASoC: codec: hdac_hdmi add device_link to card device
  (bnc#1012628).
- ASoC: fsl_esai: Fix missing break in switch statement
  (bnc#1012628).
- ASoC: RT5677-SPI: Disable 16Bit SPI Transfers (bnc#1012628).
- ASoC: max98090: Fix restore of DAPM Muxes (bnc#1012628).
- ALSA: hdea/realtek - Headset fixup for System76 Gazelle (gaze14)
  (bnc#1012628).
- ALSA: hda/realtek - EAPD turn on later (bnc#1012628).
- ALSA: hda/hdmi - Consider eld_valid when reporting jack event
  (bnc#1012628).
- ALSA: hda/hdmi - Read the pin sense from register when repolling
  (bnc#1012628).
- ALSA: usb-audio: Fix a memory leak bug (bnc#1012628).
- ALSA: line6: toneport: Fix broken usage of timer for delayed
  execution (bnc#1012628).
- mmc: sdhci-pci: Fix BYT OCP setting (bnc#1012628).
- mmc: core: Fix tag set memory leak (bnc#1012628).
- mmc: tegra: fix ddr signaling for non-ddr modes (bnc#1012628).
- dt-bindings: mmc: Add disable-cqe-dcmd property (bnc#1012628).
- drivers/dax: Allow to include DEV_DAX_PMEM as builtin
  (bnc#1012628).
- crypto: arm64/aes-neonbs - don't access already-freed walk.iv
  (bnc#1012628).
- crypto: arm/aes-neonbs - don't access already-freed walk.iv
  (bnc#1012628).
- crypto: caam/qi2 - generate hash keys in-place (bnc#1012628).
- crypto: caam/qi2 - fix DMA mapping of stack memory
  (bnc#1012628).
- crypto: caam/qi2 - fix zero-length buffer DMA mapping
  (bnc#1012628).
- crypto: rockchip - update IV buffer to contain the next IV
  (bnc#1012628).
- crypto: gcm - fix incompatibility between "gcm" and "gcm_base"
  (bnc#1012628).
- crypto: arm64/gcm-aes-ce - fix no-NEON fallback code
  (bnc#1012628).
- crypto: x86/crct10dif-pcl - fix use via crypto_shash_digest()
  (bnc#1012628).
- crypto: crct10dif-generic - fix use via crypto_shash_digest()
  (bnc#1012628).
- crypto: skcipher - don't WARN on unprocessed data after slow
  walk step (bnc#1012628).
- crypto: vmx - fix copy-paste error in CTR mode (bnc#1012628).
- crypto: ccp - Do not free psp_master when PLATFORM_INIT fails
  (bnc#1012628).
- crypto: ccm - fix incompatibility between "ccm" and "ccm_base"
  (bnc#1012628).
- crypto: chacha20poly1305 - set cra_name correctly (bnc#1012628).
- crypto: chacha-generic - fix use as arm64 no-NEON fallback
  (bnc#1012628).
- crypto: lrw - don't access already-freed walk.iv (bnc#1012628).
- crypto: salsa20 - don't access already-freed walk.iv
  (bnc#1012628).
- crypto: crypto4xx - fix cfb and ofb "overran dst buffer" issues
  (bnc#1012628).
- crypto: crypto4xx - fix ctr-aes missing output IV (bnc#1012628).
- x86/MCE/AMD: Don't report L1 BTB MCA errors on some family
  17h models (bnc#1012628).
- x86/MCE: Add an MCE-record filtering function (bnc#1012628).
- sched/x86: Save [ER]FLAGS on context switch (bnc#1012628).
- arm64: Save and restore OSDLR_EL1 across suspend/resume
  (bnc#1012628).
- arm64: Clear OSDLR_EL1 on CPU boot (bnc#1012628).
- arm64: compat: Reduce address limit (bnc#1012628).
- arm64: arch_timer: Ensure counter register reads occur with
  seqlock held (bnc#1012628).
- arm64: mmap: Ensure file offset is treated as unsigned
  (bnc#1012628).
- power: supply: axp288_fuel_gauge: Add ACEPC T8 and T11 mini
  PCs to the blacklist (bnc#1012628).
- power: supply: axp288_charger: Fix unchecked return value
  (bnc#1012628).
- ARM: exynos: Fix a leaked reference by adding missing
  of_node_put (bnc#1012628).
- mmc: sdhci-of-arasan: Add DTS property to disable DCMDs
  (bnc#1012628).
- ARM: dts: exynos: Fix audio (microphone) routing on Odroid XU3
  (bnc#1012628).
- ARM: dts: exynos: Fix audio routing on Odroid XU3 (bnc#1012628).
- ARM: dts: exynos: Fix interrupt for shared EINTs on Exynos5260
  (bnc#1012628).
- ARM: dts: qcom: ipq4019: enlarge PCIe BAR range (bnc#1012628).
- arm64: dts: rockchip: Disable DCMDs on RK3399's eMMC controller
  (bnc#1012628).
- arm64: dts: rockchip: fix IO domain voltage setting of APIO5
  on rockpro64 (bnc#1012628).
- objtool: Fix function fallthrough detection (bnc#1012628).
- x86/speculation/mds: Improve CPU buffer clear documentation
  (bnc#1012628).
- x86/speculation/mds: Revert CPU buffer clear on double fault
  exit (bnc#1012628).
- locking/rwsem: Prevent decrement of reader count before
  increment (bnc#1012628).
- commit 047096a
* Tue May 21 2019 jslaby@suse.cz
- TTY: serial_core, add ->install (bnc#1129693).
- commit da4e6dd
* Mon May 20 2019 mkubecek@suse.cz
- kvm: make kvm_vcpu_(un)map dependency on CONFIG_HAS_IOMEM
  explicit.
  Fixes build of s390x/zfcpdump.
- commit b33dbfc
* Mon May 20 2019 mkubecek@suse.cz
- config: refresh vanilla configs
- commit 4c41263
* Mon May 20 2019 mkubecek@suse.cz
- net: phy: rename Asix Electronics PHY driver.
  Fix duplicate module name asix by renaming phy driver to ax88796b.
- Update config files.
- commit df18320
* Mon May 20 2019 mkubecek@suse.cz
- mlx5: avoid 64-bit division.
  Fix i386 build.
- commit 89c5a47
* Mon May 20 2019 mkubecek@suse.cz
- Update to 5.2-rc1
- Eliminated 106 patches (105 stable, 1 other)
- ARM configs need update
- Refresh
  patches.rpmify/scripts-mkmakefile-honor-second-argument.patch
  patches.suse/dm-mpath-leastpending-path-update
  patches.suse/supported-flag
  patches.suse/supported-flag-external
  patches.suse/vfs-add-super_operations-get_inode_dev
- New config options:
  - General setup
  - IKHEADERS_PROC=n
  - SHUFFLE_PAGE_ALLOCATOR=y
  - Security
  - SECURITY_TOMOYO_INSECURE_BUILTIN_SETTING=n
  - Filesystems
  - UNICODE=y
  - UNICODE_NORMALIZATION_SELFTEST=n
  - Crypto
  - CRYPTO_ECRDSA=m
  - Networking
  - BATMAN_ADV_SYSFS=y
  - BT_MTKSDIO=m
  - XILINX_LL_TEMAC=m
  - MT7615E=m
  - RTW88=m
  - RTW88_8822BE=y
  - RTW88_8822CE=y
  - RTW88_DEBUG=n
  - RTW88_DEBUGFS=n
  - INFINIBAND_EFA=m
  - Storage
  - DM_DUST=m
  - MTD drivers
  - MTD_RAW_NAND=m
  - MTD_NAND_ECC_SW_BCH=y
  - MTD_NAND_ECC_SW_HAMMING_SMC=n
  - Input
  - KEYBOARD_QT1050=m
  - TOUCHSCREEN_IQS5XX=m
  - INPUT_GPIO_VIBRA=n
  - INPUT_REGULATOR_HAPTIC=m
  - HID_MACALLY=m
  - HID_U2FZERO=m
  - INPUT_MAX77650_ONKEY=m
  - Serial
  - NULL_TTY=m
  - SERIAL_SIFIVE=m
  - Power management
  - CHARGER_MANAGER=y
  - CHARGER_LT3651=m
  - CHARGER_UCS1002=m
  - SENSORS_IR38064=m
  - SENSORS_ISL68137=m
  - SENSORS_LTC2978_REGULATOR=y
  - THERMAL_MMIO=m
  - MFD_MAX77650=m
  - MFD_STMFX=m
  - REGULATOR_DEBUG=n
  - REGULATOR_FIXED_VOLTAGE=m
  - REGULATOR_VIRTUAL_CONSUMER=m
  - REGULATOR_USERSPACE_CONSUMER=m
  - REGULATOR_88PG86X=m
  - REGULATOR_ACT8865=m
  - REGULATOR_AD5398=m
  - REGULATOR_AXP20X=m
  - REGULATOR_DA9062=m
  - REGULATOR_DA9210=m
  - REGULATOR_DA9211=m
  - REGULATOR_FAN53555=m
  - REGULATOR_GPIO=m
  - REGULATOR_ISL9305=m
  - REGULATOR_ISL6271A=m
  - REGULATOR_LM363X=m
  - REGULATOR_LP3971=m
  - REGULATOR_LP3972=m
  - REGULATOR_LP872X=m
  - REGULATOR_LP8755=m
  - REGULATOR_LTC3589=m
  - REGULATOR_LTC3676=m
  - REGULATOR_MAX1586=m
  - REGULATOR_MAX77650=m
  - REGULATOR_MAX8649=m
  - REGULATOR_MAX8660=m
  - REGULATOR_MAX8907=m
  - REGULATOR_MAX8952=m
  - REGULATOR_MAX8973=m
  - REGULATOR_MCP16502=m
  - REGULATOR_MT6311=m
  - REGULATOR_PFUZE100=m
  - REGULATOR_PV88060=m
  - REGULATOR_PV88080=m
  - REGULATOR_PV88090=m
  - REGULATOR_PWM=m
  - REGULATOR_QCOM_SPMI=m
  - REGULATOR_SY8106A=m
  - REGULATOR_TPS51632=m
  - REGULATOR_TPS62360=m
  - REGULATOR_TPS65023=m
  - REGULATOR_TPS6507X=m
  - REGULATOR_TPS65132=m
  - REGULATOR_TPS6524X=m
  - REGULATOR_VCTRL=m
  - CHARGER_MAX77650=m
  - Media
  - MEDIA_CONTROLLER_REQUEST_API=y
  - VIDEO_V4L2_SUBDEV_API=y
  - V4L2_FLASH_LED_CLASS=m
  - VIDEO_COBALT=n
  - VIDEO_IPU3_CIO2=m
  - VIDEO_CADENCE_CSI2RX=m
  - VIDEO_CADENCE_CSI2TX=m
  - VIDEO_MUX=m
  - VIDEO_XILINX=m
  - VIDEO_XILINX_TPG=m
  - VIDEO_VIMC=m
  - VIDEO_IPU3_IMGU=m
  - DRM
  - NOUVEAU_LEGACY_CTX_SUPPORT=n
  - DRM_PANEL_FEIYANG_FY07024DI26A30D=n
  - DRM_PANEL_ROCKTECH_JH057N00900=n
  - DRM_PANEL_RONBO_RB070D30=n
  - Sound
  - SND_SOC_FSL_AUDMIX=n
  - SND_SOC_SOF_TOPLEVEL=y
  - SND_SOC_SOF_PCI=m
  - SND_SOC_SOF_ACPI=m
  - SND_SOC_SOF_NOCODEC=n
  - SND_SOC_SOF_STRICT_ABI_CHECKS=n
  - SND_SOC_SOF_DEBUG=n
  - SND_SOC_SOF_INTEL_TOPLEVEL=y
  - SND_SOC_SOF_BAYTRAIL_SUPPORT=y
  - SND_SOC_SOF_BROADWELL_SUPPORT=y
  - SND_SOC_SOF_MERRIFIELD_SUPPORT=y
  - SND_SOC_SOF_APOLLOLAKE_SUPPORT=y
  - SND_SOC_SOF_GEMINILAKE_SUPPORT=y
  - SND_SOC_SOF_CANNONLAKE_SUPPORT=y
  - SND_SOC_SOF_COFFEELAKE_SUPPORT=y
  - SND_SOC_SOF_ICELAKE_SUPPORT=y
  - SND_SOC_SOF_HDA_LINK=y
  - SND_SOC_SOF_HDA_AUDIO_CODEC=y
  - SND_SOC_INTEL_SOF_RT5682_MACH=m
  - USB
  - TYPEC_NVIDIA_ALTMODE=m
  - LEDS
  - LEDS_LM3532=m
  - LEDS_REGULATOR=m
  - LEDS_MAX77650=m
  - Platform
  - CROS_EC_RPMSG=m
  - CROS_USBPD_LOGGER=m
  - CLK_SIFIVE=n
  - IXP4XX_QMGR=n
  - IXP4XX_NPE=m
  - IIO
  - CC10001_ADC=n
  - TI_ADS8344=n
  - FXAS21002C=n
  - MB1232=n
  - MAX31856=m
  - Misc drivers
  - I2C_AMD_MP2=m
  - PINCTRL_STMFX=n
  - FIELDBUS_DEV=n
  - KPC2000=n
  - NVMEM_SYSFS=y
  - COUNTER=n
  - GPIO_MAX77650=m
  - Library
  - PACKING=n
  - Debugging and testing
  - DEBUG_INFO_BTF=n
  - DEBUG_MISC=n
  - DEBUG_PLIST=n
  - TEST_STRSCPY=n
  - x86
  - ACPI_HMAT=y
  - INTEL_CHT_INT33FE=m
  - INTEL_ISH_FIRMWARE_DOWNLOADER=m
  - i386
  - MEMORY_HOTPLUG=y
  - MEMORY_HOTPLUG_DEFAULT_ONLINE=n
  - MEMORY_HOTREMOVE
  - XEN_BALLOON_MEMORY_HOTPLUG=y
  - XEN_BALLOON_MEMORY_HOTPLUG_LIMIT=4
  - DEV_DAX_KMEM=m
  - MEMORY_NOTIFIER_ERROR_INJECT=m
  - ACPI_HOTPLUG_MEMORY=y
  - ppc64 / ppc64le
  - PPC_KUEP=y
  - PPC_KUAP=y
  - PPC_KUAP_DEBUG=n
  - MTD_NAND_DENALI_PCI=m
  - MTD_NAND_CAFE=m
  - MTD_NAND_GPIO=m
  - MTD_NAND_PLATFORM=m
  - MTD_NAND_NANDSIM=m
  - MTD_NAND_RICOH=m
  - MTD_NAND_DISKONCHIP=m
  - MTD_NAND_DISKONCHIP_PROBE_ADVANCED=n
  - MTD_NAND_DISKONCHIP_BBTWRITE=n
  - INTEGRITY_PLATFORM_KEYRING=y
  - OPTIMIZE_INLINING=y
  - XMON_DEFAULT_RO_MODE=y
  - s390x
  - KEXEC_VERIFY_SIG=n
  - RELOCATABLE=y
  - RANDOMIZE_BASE=y
  - PROTECTED_VIRTUALIZATION_GUEST=y
  - LCD_CLASS_DEVICE=n
  - BACKLIGHT_CLASS_DEVICE=n
  - INTEGRITY_PLATFORM_KEYRING=y
  - OPTIMIZE_INLINING=n
- commit c8b1101
* Fri May 17 2019 jslaby@suse.cz
- Refresh
  patches.suse/memcg-make-it-work-on-sparse-non-0-node-systems.patch.
  Update to a solution proposed by upstream.
- commit 53906c9
* Fri May 17 2019 jslaby@suse.cz
- Revert "selinux: do not report error on connect(AF_UNSPEC)"
  (git-fixes).
- Revert "Don't jump to compute_result state from check_result
  state" (git-fixes).
- commit 3d34296
* Fri May 17 2019 jslaby@suse.cz
- Linux 5.1.3 (bnc#1012628).
- f2fs: Fix use of number of devices (bnc#1012628).
- PCI: hv: Add pci_destroy_slot() in pci_devices_present_work(),
  if necessary (bnc#1012628).
- PCI: hv: Add hv_pci_remove_slots() when we unload the driver
  (bnc#1012628).
- PCI: hv: Fix a memory leak in hv_eject_device_work()
  (bnc#1012628).
- virtio_ring: Fix potential mem leak in
  virtqueue_add_indirect_packed (bnc#1012628).
- powerpc/booke64: set RI in default MSR (bnc#1012628).
- powerpc/powernv/idle: Restore IAMR after idle (bnc#1012628).
- powerpc/book3s/64: check for NULL pointer in pgd_alloc()
  (bnc#1012628).
- drivers/virt/fsl_hypervisor.c: prevent integer overflow in ioctl
  (bnc#1012628).
- drivers/virt/fsl_hypervisor.c: dereferencing error pointers
  in ioctl (bnc#1012628).
- isdn: bas_gigaset: use usb_fill_int_urb() properly
  (bnc#1012628).
- flow_dissector: disable preemption around BPF calls
  (bnc#1012628).
- net: phy: fix phy_validate_pause (bnc#1012628).
- tuntap: synchronize through tfiles array instead of
  tun->numqueues (bnc#1012628).
- tuntap: fix dividing by zero in ebpf queue selection
  (bnc#1012628).
- vrf: sit mtu should not be updated when vrf netdev is the link
  (bnc#1012628).
- vlan: disable SIOCSHWTSTAMP in container (bnc#1012628).
- tipc: fix hanging clients using poll with EPOLLOUT flag
  (bnc#1012628).
- selinux: do not report error on connect(AF_UNSPEC)
  (bnc#1012628).
- packet: Fix error path in packet_init (bnc#1012628).
- net: ucc_geth - fix Oops when changing number of buffers in
  the ring (bnc#1012628).
- net: seeq: fix crash caused by not set dev.parent (bnc#1012628).
- net: macb: Change interrupt and napi enable order in open
  (bnc#1012628).
- net: ethernet: stmmac: dwmac-sun8i: enable support of unicast
  filtering (bnc#1012628).
- net: dsa: Fix error cleanup path in dsa_init_module
  (bnc#1012628).
- ipv4: Fix raw socket lookup for local traffic (bnc#1012628).
- fib_rules: return 0 directly if an exactly same rule exists
  when NLM_F_EXCL not supplied (bnc#1012628).
- dpaa_eth: fix SG frame cleanup (bnc#1012628).
- bridge: Fix error path for kobject_init_and_add() (bnc#1012628).
- bonding: fix arp_validate toggling in active-backup mode
  (bnc#1012628).
- Don't jump to compute_result state from check_result state
  (bnc#1012628).
- rtlwifi: rtl8723ae: Fix missing break in switch statement
  (bnc#1012628).
- mwl8k: Fix rate_idx underflow (bnc#1012628).
- USB: serial: fix unthrottle races (bnc#1012628).
- virt: vbox: Sanity-check parameter types for hgcm-calls coming
  from userspace (bnc#1012628).
- kernfs: fix barrier usage in __kernfs_new_node() (bnc#1012628).
- i2c: core: ratelimit 'transfer when suspended' errors
  (bnc#1012628).
- selftests/seccomp: Handle namespace failures gracefully
  (bnc#1012628).
- hwmon: (occ) Fix extended status bits (bnc#1012628).
- hwmon: (pwm-fan) Disable PWM if fetching cooling data fails
  (bnc#1012628).
- platform/x86: dell-laptop: fix rfkill functionality
  (bnc#1012628).
- platform/x86: thinkpad_acpi: Disable Bluetooth for some machines
  (bnc#1012628).
- platform/x86: sony-laptop: Fix unintentional fall-through
  (bnc#1012628).
- commit 073196d
* Thu May 16 2019 mwilck@suse.com
- Update config files: disable CONFIG_IDE for ppc64/ppc64le (bsc#1135333)
- commit 012b7ed
* Wed May 15 2019 mkubecek@suse.cz
- x86/kvm/pmu: Set AMD's virt PMU version to 1
  (https://patchwork.kernel.org/patch/10936271/).
- commit d737fc7
* Tue May 14 2019 jslaby@suse.cz
- Linux 5.1.2 (bnc#1012628).
- x86/speculation/mds: Fix documentation typo (bnc#1012628).
- Documentation: Correct the possible MDS sysfs values
  (bnc#1012628).
- x86/mds: Add MDSUM variant to the MDS documentation
  (bnc#1012628).
- x86/speculation/mds: Add 'mitigations=' support for MDS
  (bnc#1012628).
- s390/speculation: Support 'mitigations=' cmdline option
  (bnc#1012628).
- powerpc/speculation: Support 'mitigations=' cmdline option
  (bnc#1012628).
- x86/speculation: Support 'mitigations=' cmdline option
  (bnc#1012628).
- cpu/speculation: Add 'mitigations=' cmdline option
  (bnc#1012628).
- x86/speculation/mds: Print SMT vulnerable on MSBDS with
  mitigations off (bnc#1012628).
- x86/speculation/mds: Fix comment (bnc#1012628).
- x86/speculation/mds: Add SMT warning message (bnc#1012628).
- x86/speculation: Move arch_smt_update() call to after mitigation
  decisions (bnc#1012628).
- x86/speculation/mds: Add mds=full,nosmt cmdline option
  (bnc#1012628).
- Documentation: Add MDS vulnerability documentation
  (bnc#1012628).
- Documentation: Move L1TF to separate directory (bnc#1012628).
- x86/speculation/mds: Add mitigation mode VMWERV (bnc#1012628).
- x86/speculation/mds: Add sysfs reporting for MDS (bnc#1012628).
- x86/speculation/mds: Add mitigation control for MDS
  (bnc#1012628).
- x86/speculation/mds: Conditionally clear CPU buffers on idle
  entry (bnc#1012628).
- x86/kvm/vmx: Add MDS protection when L1D Flush is not active
  (bnc#1012628).
- x86/speculation/mds: Clear CPU buffers on exit to user
  (bnc#1012628).
- x86/speculation/mds: Add mds_clear_cpu_buffers() (bnc#1012628).
- x86/kvm: Expose X86_FEATURE_MD_CLEAR to guests (bnc#1012628).
- x86/speculation/mds: Add BUG_MSBDS_ONLY (bnc#1012628).
- x86/speculation/mds: Add basic bug infrastructure for MDS
  (bnc#1012628).
- x86/speculation: Consolidate CPU whitelists (bnc#1012628).
- x86/msr-index: Cleanup bit defines (bnc#1012628).
- commit 5a8c05f
* Tue May 14 2019 mkubecek@suse.cz
- config: keep LSM empty in s390x/zfcpdump
  This config doesn't really build AppArmor and always had
  DEFAULT_SECURITY_DAC so it seems more consistent to keep LSM list empty.
- commit 3073856
* Tue May 14 2019 mkubecek@suse.cz
- config: enable AppArmor by default again (bsc#1134906)
  AppArmor used to be enabled in kernel by default by after the recent
  introduction of CONFIG_LSM, we disabled all LSM modules. Enable AppArmor
  again.
- commit 953db35
* Tue May 14 2019 mkubecek@suse.cz
- Update upstream reference:
  patches.suse/efifb-Omit-memory-map-check-on-legacy-boot.patch
- commit 133a780
* Sat May 11 2019 jslaby@suse.cz
- Linux 5.1.1 (bnc#1012628).
- arm64: futex: Bound number of LDXR/STXR loops in FUTEX_WAKE_OP
  (bnc#1012628).
- locking/futex: Allow low-level atomic operations to return
  - EAGAIN (bnc#1012628).
- i3c: Fix a shift wrap bug in i3c_bus_set_addr_slot_status()
  (bnc#1012628).
- ASoC: Intel: avoid Oops if DMA setup fails (bnc#1012628).
- UAS: fix alignment of scatter/gather segments (bnc#1012628).
- Bluetooth: hci_bcm: Fix empty regulator supplies for Intel Macs
  (bnc#1012628).
- Bluetooth: Fix not initializing L2CAP tx_credits (bnc#1012628).
- Bluetooth: Align minimum encryption key size for LE and BR/EDR
  connections (bnc#1012628).
- Bluetooth: hidp: fix buffer overflow (bnc#1012628).
- scsi: qla2xxx: Fix device staying in blocked state
  (bnc#1012628).
- scsi: qla2xxx: Set remote port devloss timeout to 0
  (bnc#1012628).
- scsi: qla2xxx: Fix incorrect region-size setting in optrom
  SYSFS routines (bnc#1012628).
- scsi: lpfc: change snprintf to scnprintf for possible overflow
  (bnc#1012628).
- soc: sunxi: Fix missing dependency on REGMAP_MMIO (bnc#1012628).
- ACPI / LPSS: Use acpi_lpss_* instead of acpi_subsys_* functions
  for hibernate (bnc#1012628).
- cpufreq: armada-37xx: fix frequency calculation for opp
  (bnc#1012628).
- iio: adc: qcom-spmi-adc5: Fix of-based module autoloading
  (bnc#1012628).
- intel_th: pci: Add Comet Lake support (bnc#1012628).
- genirq: Prevent use-after-free and work list corruption
  (bnc#1012628).
- usb-storage: Set virt_boundary_mask to avoid SG overflows
  (bnc#1012628).
- USB: cdc-acm: fix unthrottle races (bnc#1012628).
- USB: serial: f81232: fix interrupt worker not stop
  (bnc#1012628).
- usb: dwc3: Fix default lpm_nyet_threshold value (bnc#1012628).
- usb: dwc3: Allow building USB_DWC3_QCOM without EXTCON
  (bnc#1012628).
- staging: most: sound: pass correct device when creating a
  sound card (bnc#1012628).
- staging: most: cdev: fix chrdev_region leak in mod_exit
  (bnc#1012628).
- staging: wilc1000: Avoid GFP_KERNEL allocation from atomic
  context (bnc#1012628).
- staging: greybus: power_supply: fix prop-descriptor request size
  (bnc#1012628).
- ubsan: Fix nasty -Wbuiltin-declaration-mismatch GCC-9 warnings
  (bnc#1012628).
- Drivers: hv: vmbus: Remove the undesired put_cpu_ptr() in
  hv_synic_cleanup() (bnc#1012628).
- commit 8e0a089
* Thu May  9 2019 guillaume.gardet@free.fr
- Sign non-x86 kernels when possible (boo#1134303)
- commit bac621c
* Mon May  6 2019 mkubecek@suse.cz
- Update to 5.1 final
- Eliminated 1 patch
- New config options:
  - PCI:
  - PCIE_BW=n (recommended default)
- commit a974d8b
* Sun May  5 2019 jslaby@suse.cz
- Linux 5.0.13 (bnc#1012628).
- ipv4: ip_do_fragment: Preserve skb_iif during fragmentation
  (bnc#1012628).
- ipv6: A few fixes on dereferencing rt->from (bnc#1012628).
- ipv6: fix races in ip6_dst_destroy() (bnc#1012628).
- ipv6/flowlabel: wait rcu grace period before put_pid()
  (bnc#1012628).
- ipv6: invert flowlabel sharing check in process and user mode
  (bnc#1012628).
- l2ip: fix possible use-after-free (bnc#1012628).
- l2tp: use rcu_dereference_sk_user_data() in
  l2tp_udp_encap_recv() (bnc#1012628).
- net: dsa: bcm_sf2: fix buffer overflow doing set_rxnfc
  (bnc#1012628).
- net: phy: marvell: Fix buffer overrun with stats counters
  (bnc#1012628).
- net/tls: avoid NULL pointer deref on nskb->sk in fallback
  (bnc#1012628).
- rxrpc: Fix net namespace cleanup (bnc#1012628).
- sctp: avoid running the sctp state machine recursively
  (bnc#1012628).
- selftests: fib_rule_tests: print the result and return 1 if
  any tests failed (bnc#1012628).
- packet: validate msg_namelen in send directly (bnc#1012628).
- packet: in recvmsg msg_name return at least sizeof sockaddr_ll
  (bnc#1012628).
- selftests: fib_rule_tests: Fix icmp proto with ipv6
  (bnc#1012628).
- tcp: add sanity tests in tcp_add_backlog() (bnc#1012628).
- udp: fix GRO reception in case of length mismatch (bnc#1012628).
- udp: fix GRO packet of death (bnc#1012628).
- bnxt_en: Improve multicast address setup logic (bnc#1012628).
- bnxt_en: Free short FW command HWRM memory in error path in
  bnxt_init_one() (bnc#1012628).
- bnxt_en: Fix possible crash in bnxt_hwrm_ring_free() under
  error conditions (bnc#1012628).
- bnxt_en: Pass correct extended TX port statistics size to
  firmware (bnc#1012628).
- bnxt_en: Fix statistics context reservation logic (bnc#1012628).
- bnxt_en: Fix uninitialized variable usage in bnxt_rx_pkt()
  (bnc#1012628).
- net/tls: don't copy negative amounts of data in reencrypt
  (bnc#1012628).
- net/tls: fix copy to fragments in reencrypt (bnc#1012628).
- KVM: nVMX: Fix size checks in vmx_set_nested_state
  (bnc#1012628).
- ALSA: line6: use dynamic buffers (bnc#1012628).
- iwlwifi: mvm: properly check debugfs dentry before using it
  (bnc#1012628).
- ath10k: Drop WARN_ON()s that always trigger during system resume
  (bnc#1012628).
- commit b11e2d7
* Sat May  4 2019 jslaby@suse.cz
- Linux 5.0.12 (bnc#1012628).
- selinux: use kernel linux/socket.h for genheaders and mdp
  (bnc#1012628).
- drm/i915: Do not enable FEC without DSC (bnc#1012628).
- mm: make page ref count overflow check tighter and more explicit
  (bnc#1012628).
- mm: add 'try_get_page()' helper function (bnc#1012628).
- mm: prevent get_user_pages() from overflowing page refcount
  (bnc#1012628).
- fs: prevent page refcount overflow in pipe_buf_get
  (bnc#1012628).
- arm64: dts: renesas: r8a77990: Fix SCIF5 DMA channels
  (bnc#1012628).
- ARM: dts: bcm283x: Fix hdmi hpd gpio pull (bnc#1012628).
- s390: limit brk randomization to 32MB (bnc#1012628).
- mt76x02: fix hdr pointer in write txwi for USB (bnc#1012628).
- mt76: mt76x2: fix external LNA gain settings (bnc#1012628).
- mt76: mt76x2: fix 2.4 GHz channel gain settings (bnc#1012628).
- net: ieee802154: fix a potential NULL pointer dereference
  (bnc#1012628).
- ieee802154: hwsim: propagate genlmsg_reply return code
  (bnc#1012628).
- Btrfs: fix file corruption after snapshotting due to mix of
  buffered/DIO writes (bnc#1012628).
- net: stmmac: don't set own bit too early for jumbo frames
  (bnc#1012628).
- net: stmmac: fix jumbo frame sending with non-linear skbs
  (bnc#1012628).
- qlcnic: Avoid potential NULL pointer dereference (bnc#1012628).
- xsk: fix umem memory leak on cleanup (bnc#1012628).
- staging: axis-fifo: add CONFIG_OF dependency (bnc#1012628).
- staging, mt7621-pci: fix build without pci support
  (bnc#1012628).
- netfilter: nft_set_rbtree: check for inactive element after
  flag mismatch (bnc#1012628).
- netfilter: bridge: set skb transport_header before entering
  NF_INET_PRE_ROUTING (bnc#1012628).
- netfilter: fix NETFILTER_XT_TARGET_TEE dependencies
  (bnc#1012628).
- netfilter: ip6t_srh: fix NULL pointer dereferences
  (bnc#1012628).
- s390/qeth: fix race when initializing the IP address table
  (bnc#1012628).
- ARM: imx51: fix a leaked reference by adding missing of_node_put
  (bnc#1012628).
- sc16is7xx: missing unregister/delete driver on error in
  sc16is7xx_init() (bnc#1012628).
- serial: ar933x_uart: Fix build failure with disabled console
  (bnc#1012628).
- KVM: arm64: Reset the PMU in preemptible context (bnc#1012628).
- arm64: KVM: Always set ICH_HCR_EL2.EN if GICv4 is enabled
  (bnc#1012628).
- KVM: arm/arm64: vgic-its: Take the srcu lock when writing to
  guest memory (bnc#1012628).
- KVM: arm/arm64: vgic-its: Take the srcu lock when parsing the
  memslots (bnc#1012628).
- usb: dwc3: pci: add support for Comet Lake PCH ID (bnc#1012628).
- usb: gadget: net2280: Fix overrun of OUT messages (bnc#1012628).
- usb: gadget: net2280: Fix net2280_dequeue() (bnc#1012628).
- usb: gadget: net2272: Fix net2272_dequeue() (bnc#1012628).
- ARM: dts: pfla02: increase phy reset duration (bnc#1012628).
- i2c: i801: Add support for Intel Comet Lake (bnc#1012628).
- KVM: arm/arm64: Fix handling of stage2 huge mappings
  (bnc#1012628).
- net: ks8851: Dequeue RX packets explicitly (bnc#1012628).
- net: ks8851: Reassert reset pin if chip ID check fails
  (bnc#1012628).
- net: ks8851: Delay requesting IRQ until opened (bnc#1012628).
- net: ks8851: Set initial carrier state to down (bnc#1012628).
- staging: rtl8188eu: Fix potential NULL pointer dereference of
  kcalloc (bnc#1012628).
- staging: rtlwifi: rtl8822b: fix to avoid potential NULL pointer
  dereference (bnc#1012628).
- staging: rtl8712: uninitialized memory in read_bbreg_hdl()
  (bnc#1012628).
- staging: rtlwifi: Fix potential NULL pointer dereference of
  kzalloc (bnc#1012628).
- net: phy: Add DP83825I to the DP83822 driver (bnc#1012628).
- net: macb: Add null check for PCLK and HCLK (bnc#1012628).
- net/sched: don't dereference a->goto_chain to read the chain
  index (bnc#1012628).
- ARM: dts: imx6qdl: Fix typo in imx6qdl-icore-rqs.dtsi
  (bnc#1012628).
- drm/tegra: hub: Fix dereference before check (bnc#1012628).
- NFS: Fix a typo in nfs_init_timeout_values() (bnc#1012628).
- net: xilinx: fix possible object reference leak (bnc#1012628).
- net: ibm: fix possible object reference leak (bnc#1012628).
- net: ethernet: ti: fix possible object reference leak
  (bnc#1012628).
- drm: Fix drm_release() and device unplug (bnc#1012628).
- gpio: aspeed: fix a potential NULL pointer dereference
  (bnc#1012628).
- drm/meson: Fix invalid pointer in meson_drv_unbind()
  (bnc#1012628).
- drm/meson: Uninstall IRQ handler (bnc#1012628).
- ARM: davinci: fix build failure with allnoconfig (bnc#1012628).
- sbitmap: order READ/WRITE freed instance and setting clear bit
  (bnc#1012628).
- staging: vc04_services: Fix an error code in vchiq_probe()
  (bnc#1012628).
- scsi: mpt3sas: Fix kernel panic during expander reset
  (bnc#1012628).
- scsi: aacraid: Insure we don't access PCIe space during AER/EEH
  (bnc#1012628).
- scsi: qla4xxx: fix a potential NULL pointer dereference
  (bnc#1012628).
- usb: usb251xb: fix to avoid potential NULL pointer dereference
  (bnc#1012628).
- leds: trigger: netdev: fix refcnt leak on interface rename
  (bnc#1012628).
- SUNRPC: fix uninitialized variable warning (bnc#1012628).
- x86/realmode: Don't leak the trampoline kernel address
  (bnc#1012628).
- usb: u132-hcd: fix resource leak (bnc#1012628).
- ceph: fix use-after-free on symlink traversal (bnc#1012628).
- scsi: zfcp: reduce flood of fcrscn1 trace records on
  multi-element RSCN (bnc#1012628).
- x86/mm: Don't exceed the valid physical address space
  (bnc#1012628).
- libata: fix using DMA buffers on stack (bnc#1012628).
- kbuild: skip parsing pre sub-make code for recursion
  (bnc#1012628).
- afs: Fix StoreData op marshalling (bnc#1012628).
- gpio: of: Check propname before applying "cs-gpios" quirks
  (bnc#1012628).
- gpio: of: Check for "spi-cs-high" in child instead of parent
  node (bnc#1012628).
- KVM: nVMX: Do not inherit quadrant and invalid for the root
  shadow EPT (bnc#1012628).
- KVM: SVM: Workaround errata#1096 (insn_len maybe zero on SMAP
  violation) (bnc#1012628).
- kvm/x86: Move MSR_IA32_ARCH_CAPABILITIES to array emulated_msrs
  (bnc#1012628).
- x86/kvm/hyper-v: avoid spurious pending stimer on vCPU init
  (bnc#1012628).
- KVM: selftests: assert on exit reason in CR4/cpuid sync test
  (bnc#1012628).
- KVM: selftests: explicitly disable PIE for tests (bnc#1012628).
- KVM: selftests: disable stack protector for all KVM tests
  (bnc#1012628).
- KVM: selftests: complete IO before migrating guest state
  (bnc#1012628).
- gpio: of: Fix of_gpiochip_add() error path (bnc#1012628).
- nvme-multipath: relax ANA state check (bnc#1012628).
- nvmet: fix building bvec from sg list (bnc#1012628).
- nvmet: fix error flow during ns enable (bnc#1012628).
- perf cs-etm: Add missing case value (bnc#1012628).
- perf machine: Update kernel map address and re-order properly
  (bnc#1012628).
- kconfig/[mn]conf: handle backspace (^H) key (bnc#1012628).
- iommu/amd: Reserve exclusion range in iova-domain (bnc#1012628).
- kasan: fix variable 'tag' set but not used warning
  (bnc#1012628).
- ptrace: take into account saved_sigmask in
  PTRACE{GET,SET}SIGMASK (bnc#1012628).
- leds: pca9532: fix a potential NULL pointer dereference
  (bnc#1012628).
- leds: trigger: netdev: use memcpy in device_name_store
  (bnc#1012628).
- commit 0b5ff0f
* Thu May  2 2019 jslaby@suse.cz
- Refresh
  patches.suse/KVM-x86-Whitelist-port-0x7e-for-pre-incrementing-rip.patch.
  Update upstream status.
- commit 410b1c0
* Thu May  2 2019 jslaby@suse.cz
- Linux 5.0.11 (bnc#1012628).
- netfilter: nf_tables: bogus EBUSY when deleting set after flush
  (bnc#1012628).
- netfilter: nf_tables: bogus EBUSY in helper removal from
  transaction (bnc#1012628).
- intel_th: gth: Fix an off-by-one in output unassigning
  (bnc#1012628).
- powerpc/vdso32: fix CLOCK_MONOTONIC on PPC64 (bnc#1012628).
- ALSA: hda/realtek - Move to ACT_INIT state (bnc#1012628).
- fs/proc/proc_sysctl.c: Fix a NULL pointer dereference
  (bnc#1012628).
- block, bfq: fix use after free in bfq_bfqq_expire (bnc#1012628).
- cifs: fix memory leak in SMB2_read (bnc#1012628).
- cifs: fix page reference leak with readv/writev (bnc#1012628).
- cifs: do not attempt cifs operation on smb2+ rename error
  (bnc#1012628).
- tracing: Fix a memory leak by early error exit in
  trace_pid_write() (bnc#1012628).
- tracing: Fix buffer_ref pipe ops (bnc#1012628).
- crypto: xts - Fix atomic sleep when walking skcipher
  (bnc#1012628).
- crypto: lrw - Fix atomic sleep when walking skcipher
  (bnc#1012628).
- gpio: eic: sprd: Fix incorrect irq type setting for the sync
  EIC (bnc#1012628).
- zram: pass down the bvec we need to read into in the work struct
  (bnc#1012628).
- lib/Kconfig.debug: fix build error without CONFIG_BLOCK
  (bnc#1012628).
- MIPS: scall64-o32: Fix indirect syscall number load
  (bnc#1012628).
- trace: Fix preempt_enable_no_resched() abuse (bnc#1012628).
- mm: do not boost watermarks to avoid fragmentation for the
  DISCONTIG memory model (bnc#1012628).
- arm64: mm: Ensure tail of unaligned initrd is reserved
  (bnc#1012628).
- IB/rdmavt: Fix frwr memory registration (bnc#1012628).
- RDMA/mlx5: Do not allow the user to write to the clock page
  (bnc#1012628).
- RDMA/mlx5: Use rdma_user_map_io for mapping BAR pages
  (bnc#1012628).
- RDMA/ucontext: Fix regression with disassociate (bnc#1012628).
- sched/numa: Fix a possible divide-by-zero (bnc#1012628).
- ceph: only use d_name directly when parent is locked
  (bnc#1012628).
- ceph: ensure d_name stability in ceph_dentry_hash()
  (bnc#1012628).
- ceph: fix ci->i_head_snapc leak (bnc#1012628).
- nfsd: Don't release the callback slot unless it was actually
  held (bnc#1012628).
- nfsd: wake waiters blocked on file_lock before deleting it
  (bnc#1012628).
- nfsd: wake blocked file lock waiters before sending callback
  (bnc#1012628).
- sunrpc: don't mark uninitialised items as VALID (bnc#1012628).
- perf/x86/intel: Update KBL Package C-state events to also
  include PC8/PC9/PC10 counters (bnc#1012628).
- Input: synaptics-rmi4 - write config register values to the
  right offset (bnc#1012628).
- dmaengine: sh: rcar-dmac: With cyclic DMA residue 0 is valid
  (bnc#1012628).
- dmaengine: sh: rcar-dmac: Fix glitch in dmaengine_tx_status
  (bnc#1012628).
- dmaengine: mediatek-cqdma: fix wrong register usage in
  mtk_cqdma_start (bnc#1012628).
- ARM: 8857/1: efi: enable CP15 DMB instructions before cleaning
  the cache (bnc#1012628).
- powerpc/mm/radix: Make Radix require HUGETLB_PAGE (bnc#1012628).
- drm/vc4: Fix memory leak during gpu reset (bnc#1012628).
- drm/ttm: fix re-init of global structures (bnc#1012628).
- drm/vc4: Fix compilation error reported by kbuild test bot
  (bnc#1012628).
- USB: Add new USB LPM helpers (bnc#1012628).
- USB: Consolidate LPM checks to avoid enabling LPM twice
  (bnc#1012628).
- ext4: fix some error pointer dereferences (bnc#1012628).
- loop: do not print warn message if partition scan is successful
  (bnc#1012628).
- tipc: handle the err returned from cmd header function
  (bnc#1012628).
- slip: make slhc_free() silently accept an error pointer
  (bnc#1012628).
- workqueue: Try to catch flush_work() without INIT_WORK()
  (bnc#1012628).
- binder: fix handling of misaligned binder object (bnc#1012628).
- sched/deadline: Correctly handle active 0-lag timers
  (bnc#1012628).
- mac80211_hwsim: calculate if_combination.max_interfaces
  (bnc#1012628).
- NFS: Forbid setting AF_INET6 to "struct sockaddr_in"->sin_family
  (bnc#1012628).
- netfilter: ebtables: CONFIG_COMPAT: drop a bogus WARN_ON
  (bnc#1012628).
- fm10k: Fix a potential NULL pointer dereference (bnc#1012628).
- tipc: check bearer name with right length in
  tipc_nl_compat_bearer_enable (bnc#1012628).
- tipc: check link name with right length in
  tipc_nl_compat_link_set (bnc#1012628).
- net: netrom: Fix error cleanup path of nr_proto_init
  (bnc#1012628).
- net/rds: Check address length before reading address family
  (bnc#1012628).
- rxrpc: fix race condition in rxrpc_input_packet() (bnc#1012628).
- pin iocb through aio (bnc#1012628).
- aio: fold lookup_kiocb() into its sole caller (bnc#1012628).
- aio: keep io_event in aio_kiocb (bnc#1012628).
- aio: store event at final iocb_put() (bnc#1012628).
- Fix aio_poll() races (bnc#1012628).
- x86, retpolines: Raise limit for generating indirect calls
  from switch-case (bnc#1012628).
- x86/retpolines: Disable switch jump tables when retpolines
  are enabled (bnc#1012628).
- rdma: fix build errors on s390 and MIPS due to bad ZERO_PAGE
  use (bnc#1012628).
- ipv4: add sanity checks in ipv4_link_failure() (bnc#1012628).
- ipv4: set the tcp_min_rtt_wlen range from 0 to one day
  (bnc#1012628).
- mlxsw: spectrum: Fix autoneg status in ethtool (bnc#1012628).
- net/mlx5e: ethtool, Remove unsupported SFP EEPROM high pages
  query (bnc#1012628).
- net: rds: exchange of 8K and 1M pool (bnc#1012628).
- net/rose: fix unbound loop in rose_loopback_timer()
  (bnc#1012628).
- net: stmmac: move stmmac_check_ether_addr() to driver probe
  (bnc#1012628).
- net/tls: fix refcount adjustment in fallback (bnc#1012628).
- stmmac: pci: Adjust IOT2000 matching (bnc#1012628).
- team: fix possible recursive locking when add slaves
  (bnc#1012628).
- net: socionext: replace napi_alloc_frag with the netdev variant
  on init (bnc#1012628).
- net/ncsi: handle overflow when incrementing mac address
  (bnc#1012628).
- mlxsw: pci: Reincrease PCI reset timeout (bnc#1012628).
- mlxsw: spectrum: Put MC TCs into DWRR mode (bnc#1012628).
- net/mlx5e: Fix the max MTU check in case of XDP (bnc#1012628).
- net/mlx5e: Fix use-after-free after xdp_return_frame
  (bnc#1012628).
- net/tls: avoid potential deadlock in tls_set_device_offload_rx()
  (bnc#1012628).
- net/tls: don't leak IV and record seq when offload fails
  (bnc#1012628).
- commit 07c5318
* Wed May  1 2019 tiwai@suse.de
- Revert "ACPICA: Clear status of GPEs before enabling them"
  (bsc#1132943).
- commit 13cf3aa
* Tue Apr 30 2019 tiwai@suse.de
- HID: i2c-hid: Ignore input report if there's no data present
  on Elan touchpanels (bsc#1133486).
- commit 5a94296
* Tue Apr 30 2019 mkubecek@suse.cz
- rdma: fix build errors on s390 and MIPS due to bad ZERO_PAGE use
  (http://lkml.kernel.org/r/20190429052136.GA21672@unicorn.suse.cz).
- Delete
  patches.suse/rdma-fix-argument-of-ZERO_PAGE-in-rdma_umap_fault.patch.
- commit a764394
* Tue Apr 30 2019 jslaby@suse.cz
- KVM: x86: Whitelist port 0x7e for pre-incrementing %%rip
  (bnc#1132694).
- Delete patches.suse/kvm-Workaround-OUT-0x7E.patch.
  Update per upstream.
- commit 93ba681
* Mon Apr 29 2019 jslaby@suse.cz
- memcg: make it work on sparse non-0-node systems (bnc#1133616).
- commit c0ba22a
* Mon Apr 29 2019 jslaby@suse.cz
- Workaround Qemu "OUT 0x7E" handling in KVM (bnc#1132694).
- commit e8fc1e9
* Mon Apr 29 2019 mkubecek@suse.cz
- Update to 5.1-rc7
- add patches.suse/rdma-fix-argument-of-ZERO_PAGE-in-rdma_umap_fault.patch
  (tentative s390x build fix)
- New config options:
  - ARM:
  - KEYBOARD_SNVS_PWRKEY=m
  - armv7hl:
  - FRAME_POINTER=y
  - UNWINDER_FRAME_POINTER=y
- commit 04c1966
* Sat Apr 27 2019 jslaby@suse.cz
- Linux 5.0.10 (bnc#1012628).
- bonding: fix event handling for stacked bonds (bnc#1012628).
- failover: allow name change on IFF_UP slave interfaces
  (bnc#1012628).
- net: atm: Fix potential Spectre v1 vulnerabilities
  (bnc#1012628).
- net: bridge: fix per-port af_packet sockets (bnc#1012628).
- net: bridge: multicast: use rcu to access port list from
  br_multicast_start_querier (bnc#1012628).
- net: fec: manage ahb clock in runtime pm (bnc#1012628).
- net: Fix missing meta data in skb with vlan packet
  (bnc#1012628).
- net: fou: do not use guehdr after iptunnel_pull_offloads in
  gue_udp_recv (bnc#1012628).
- tcp: tcp_grow_window() needs to respect tcp_space()
  (bnc#1012628).
- team: set slave to promisc if team is already in promisc mode
  (bnc#1012628).
- tipc: missing entries in name table of publications
  (bnc#1012628).
- vhost: reject zero size iova range (bnc#1012628).
- ipv4: recompile ip options in ipv4_link_failure (bnc#1012628).
- ipv4: ensure rcu_read_lock() in ipv4_link_failure()
  (bnc#1012628).
- mlxsw: spectrum_switchdev: Add MDB entries in prepare phase
  (bnc#1012628).
- mlxsw: core: Do not use WQ_MEM_RECLAIM for EMAD workqueue
  (bnc#1012628).
- mlxsw: core: Do not use WQ_MEM_RECLAIM for mlxsw ordered
  workqueue (bnc#1012628).
- mlxsw: core: Do not use WQ_MEM_RECLAIM for mlxsw workqueue
  (bnc#1012628).
- mlxsw: spectrum_router: Do not check VRF MAC address
  (bnc#1012628).
- net: thunderx: raise XDP MTU to 1508 (bnc#1012628).
- net: thunderx: don't allow jumbo frames with XDP (bnc#1012628).
- net/tls: fix the IV leaks (bnc#1012628).
- net/tls: don't leak partially sent record in device mode
  (bnc#1012628).
- net: strparser: partially revert "strparser: Call skb_unclone
  conditionally" (bnc#1012628).
- net/tls: fix build without CONFIG_TLS_DEVICE (bnc#1012628).
- net: bridge: fix netlink export of vlan_stats_per_port option
  (bnc#1012628).
- net/mlx5e: XDP, Avoid checksum complete when XDP prog is loaded
  (bnc#1012628).
- net/mlx5e: Protect against non-uplink representor for encap
  (bnc#1012628).
- net/mlx5e: Switch to Toeplitz RSS hash by default (bnc#1012628).
- net/mlx5e: Rx, Fixup skb checksum for packets with tail padding
  (bnc#1012628).
- net/mlx5e: Rx, Check ip headers sanity (bnc#1012628).
- Revert "net/mlx5e: Enable reporting checksum unnecessary also
  for L3 packets" (bnc#1012628).
- net/mlx5: FPGA, tls, hold rcu read lock a bit longer
  (bnc#1012628).
- net/tls: prevent bad memory access in
  tls_is_sk_tx_device_offloaded() (bnc#1012628).
- net/mlx5: FPGA, tls, idr remove on flow delete (bnc#1012628).
- route: Avoid crash from dereferencing NULL rt->from
  (bnc#1012628).
- nfp: flower: replace CFI with vlan present (bnc#1012628).
- nfp: flower: remove vlan CFI bit from push vlan action
  (bnc#1012628).
- sch_cake: Use tc_skb_protocol() helper for getting packet
  protocol (bnc#1012628).
- sch_cake: Make sure we can write the IP header before changing
  DSCP bits (bnc#1012628).
- NFC: nci: Add some bounds checking in nci_hci_cmd_received()
  (bnc#1012628).
- nfc: nci: Potential off by one in ->pipes[] array (bnc#1012628).
- sch_cake: Simplify logic in cake_select_tin() (bnc#1012628).
- CIFS: keep FileInfo handle live during oplock break
  (bnc#1012628).
- cifs: Fix lease buffer length error (bnc#1012628).
- cifs: Fix use-after-free in SMB2_write (bnc#1012628).
- cifs: Fix use-after-free in SMB2_read (bnc#1012628).
- cifs: fix handle leak in smb2_query_symlink() (bnc#1012628).
- fs/dax: Deposit pagetable even when installing zero page
  (bnc#1012628).
- KVM: x86: Don't clear EFER during SMM transitions for 32-bit
  vCPU (bnc#1012628).
- KVM: x86: svm: make sure NMI is injected after nmi_singlestep
  (bnc#1012628).
- Staging: iio: meter: fixed typo (bnc#1012628).
- staging: iio: ad7192: Fix ad7193 channel address (bnc#1012628).
- iio: gyro: mpu3050: fix chip ID reading (bnc#1012628).
- iio/gyro/bmg160: Use millidegrees for temperature scale
  (bnc#1012628).
- iio:chemical:bme680: Fix, report temperature in millidegrees
  (bnc#1012628).
- iio:chemical:bme680: Fix SPI read interface (bnc#1012628).
- iio: cros_ec: Fix the maths for gyro scale calculation
  (bnc#1012628).
- iio: ad_sigma_delta: select channel when reading register
  (bnc#1012628).
- iio: dac: mcp4725: add missing powerdown bits in store eeprom
  (bnc#1012628).
- iio: Fix scan mask selection (bnc#1012628).
- iio: adc: at91: disable adc channel interrupt in timeout case
  (bnc#1012628).
- iio: core: fix a possible circular locking dependency
  (bnc#1012628).
- io: accel: kxcjk1013: restore the range after resume
  (bnc#1012628).
- staging: most: core: use device description as name
  (bnc#1012628).
- staging: comedi: vmk80xx: Fix use of uninitialized semaphore
  (bnc#1012628).
- staging: comedi: vmk80xx: Fix possible double-free of
  - >usb_rx_buf (bnc#1012628).
- staging: comedi: ni_usb6501: Fix use of uninitialized mutex
  (bnc#1012628).
- staging: comedi: ni_usb6501: Fix possible double-free of
  - >usb_rx_buf (bnc#1012628).
- ALSA: hda/realtek - add two more pin configuration sets to
  quirk table (bnc#1012628).
- ALSA: core: Fix card races between register and disconnect
  (bnc#1012628).
- Input: elan_i2c - add hardware ID for multiple Lenovo laptops
  (bnc#1012628).
- serial: sh-sci: Fix HSCIF RX sampling point adjustment
  (bnc#1012628).
- serial: sh-sci: Fix HSCIF RX sampling point calculation
  (bnc#1012628).
- vt: fix cursor when clearing the screen (bnc#1012628).
- scsi: core: set result when the command cannot be dispatched
  (bnc#1012628).
- Revert "scsi: fcoe: clear FC_RP_STARTED flags when receiving
  a LOGO" (bnc#1012628).
- i3c: dw: Fix dw_i3c_master_disable controller by using correct
  mask (bnc#1012628).
- i3c: Fix the verification of random PID (bnc#1012628).
- Revert "svm: Fix AVIC incomplete IPI emulation" (bnc#1012628).
- coredump: fix race condition between
  mmget_not_zero()/get_task_mm() and core dumping (bnc#1012628).
- x86/kvm: move kvm_load/put_guest_xcr0 into atomic context
  (bnc#1012628).
- ipmi: fix sleep-in-atomic in free_user at cleanup SRCU
  user->release_barrier (bnc#1012628).
- crypto: x86/poly1305 - fix overflow during partial reduction
  (bnc#1012628).
- drm/ttm: fix out-of-bounds read in ttm_put_pages() v2
  (bnc#1012628).
- arm64: futex: Restore oldval initialization to work around
  buggy compilers (bnc#1012628).
- x86/kprobes: Verify stack frame on kretprobe (bnc#1012628).
- kprobes: Mark ftrace mcount handler functions nokprobe
  (bnc#1012628).
- x86/kprobes: Avoid kretprobe recursion bug (bnc#1012628).
- kprobes: Fix error check when reusing optimized probes
  (bnc#1012628).
- rt2x00: do not increment sequence number while re-transmitting
  (bnc#1012628).
- mac80211: do not call driver wake_tx_queue op during reconfig
  (bnc#1012628).
- s390/mem_detect: Use IS_ENABLED(CONFIG_BLK_DEV_INITRD)
  (bnc#1012628).
- drm/amdgpu/gmc9: fix VM_L2_CNTL3 programming (bnc#1012628).
- perf/x86/amd: Add event map for AMD Family 17h (bnc#1012628).
- x86/cpu/bugs: Use __initconst for 'const' init data
  (bnc#1012628).
- perf/x86: Fix incorrect PEBS_REGS (bnc#1012628).
- x86/speculation: Prevent deadlock on ssb_state::lock
  (bnc#1012628).
- timers/sched_clock: Prevent generic sched_clock wrap caused
  by tick_freeze() (bnc#1012628).
- nfit/ars: Remove ars_start_flags (bnc#1012628).
- nfit/ars: Introduce scrub_flags (bnc#1012628).
- nfit/ars: Allow root to busy-poll the ARS state machine
  (bnc#1012628).
- nfit/ars: Avoid stale ARS results (bnc#1012628).
- tpm/tpm_i2c_atmel: Return -E2BIG when the transfer is incomplete
  (bnc#1012628).
- tpm: Fix the type of the return value in calc_tpm2_event_size()
  (bnc#1012628).
- Revert "kbuild: use -Oz instead of -Os when using clang"
  (bnc#1012628).
- sched/fair: Limit sched_cfs_period_timer() loop to avoid hard
  lockup (bnc#1012628).
- tpm: fix an invalid condition in tpm_common_poll (bnc#1012628).
- mt76x02: avoid status_list.lock and sta->rate_ctrl_lock
  dependency (bnc#1012628).
- device_cgroup: fix RCU imbalance in error case (bnc#1012628).
- perf/ring_buffer: Fix AUX record suppression (bnc#1012628).
- mm/memory_hotplug: do not unlock after failing to take the
  device_hotplug_lock (bnc#1012628).
- mm/vmstat.c: fix /proc/vmstat format for CONFIG_DEBUG_TLBFLUSH=y
  CONFIG_SMP=n (bnc#1012628).
- ALSA: info: Fix racy addition/deletion of nodes (bnc#1012628).
- percpu: stop printing kernel addresses (bnc#1012628).
- commit 048e1d2
* Fri Apr 26 2019 jslaby@suse.cz
- kernel/sysctl.c: fix out-of-bounds access when setting file-max
  (kasan).
- commit 09ca824
* Sun Apr 21 2019 mkubecek@suse.cz
- Update to v5.1-rc6
- New config options:
  - IIO:
  - SENSIRION_SGP30=n
- commit ab97af0
* Sun Apr 21 2019 jslaby@suse.cz
- Linux 5.0.9 (bnc#1012628).
- paride/pcd: Fix potential NULL pointer dereference and mem leak
  (bnc#1012628).
- paride/pf: Fix potential NULL pointer dereference (bnc#1012628).
- IB/hfi1: Failed to drain send queue when QP is put into error
  state (bnc#1012628).
- bpf: fix use after free in bpf_evict_inode (bnc#1012628).
- include/linux/swap.h: use offsetof() instead of custom
  __swapoffset macro (bnc#1012628).
- f2fs: fix to add refcount once page is tagged PG_private
  (bnc#1012628).
- f2fs: fix to use kvfree instead of kzfree (bnc#1012628).
- f2fs: fix to dirty inode for i_mode recovery (bnc#1012628).
- rxrpc: Fix client call connect/disconnect race (bnc#1012628).
- lib/div64.c: off by one in shift (bnc#1012628).
- cifs: return -ENODATA when deleting an xattr that does not exist
  (bnc#1012628).
- appletalk: Fix use-after-free in atalk_proc_exit (bnc#1012628).
- drm/amdkfd: use init_mqd function to allocate object for hid_mqd
  (CI) (bnc#1012628).
- ARM: 8839/1: kprobe: make patch_lock a raw_spinlock_t
  (bnc#1012628).
- platform/x86: intel_pmc_core: Quirk to ignore XTAL shutdown
  (bnc#1012628).
- drm/nouveau/volt/gf117: fix speedo readout register
  (bnc#1012628).
- f2fs: sync filesystem after roll-forward recovery (bnc#1012628).
- PCI/ASPM: Save LTR Capability for suspend/resume (bnc#1012628).
- PCI: Blacklist power management of Gigabyte X299 DESIGNARE EX
  PCIe ports (bnc#1012628).
- coresight: cpu-debug: Support for CA73 CPUs (bnc#1012628).
- RDMA/hns: Fix the Oops during rmmod or insmod ko when reset
  occurs (bnc#1012628).
- Revert "ACPI / EC: Remove old CLEAR_ON_RESUME quirk"
  (bnc#1012628).
- crypto: axis - fix for recursive locking from bottom half
  (bnc#1012628).
- net: hns3: Fix NULL deref when unloading driver (bnc#1012628).
- drm/panel: panel-innolux: set display off in
  innolux_panel_unprepare (bnc#1012628).
- drm/amdgpu: psp_ring_destroy cause psp->km_ring.ring_mem NULL
  (bnc#1012628).
- lkdtm: Add tests for NULL pointer dereference (bnc#1012628).
- lkdtm: Print real addresses (bnc#1012628).
- ext4: prohibit fstrim in norecovery mode (bnc#1012628).
- x86/gart: Exclude GART aperture from kcore (bnc#1012628).
- cifs: Fix slab-out-of-bounds when tracing SMB tcon
  (bnc#1012628).
- fix incorrect error code mapping for OBJECTID_NOT_FOUND
  (bnc#1012628).
- cifs: fix that return -EINVAL when do dedupe operation
  (bnc#1012628).
- x86/hw_breakpoints: Make default case in
  hw_breakpoint_arch_parse() return an error (bnc#1012628).
- iommu/vt-d: Save the right domain ID used by hardware
  (bnc#1012628).
- iommu/vt-d: Check capability before disabling protected memory
  (bnc#1012628).
- drm/nouveau/debugfs: Fix check of pm_runtime_get_sync failure
  (bnc#1012628).
- x86/cpu/cyrix: Use correct macros for Cyrix calls on Geode
  processors (bnc#1012628).
- x86/hyperv: Prevent potential NULL pointer dereference
  (bnc#1012628).
- x86/hpet: Prevent potential NULL pointer dereference
  (bnc#1012628).
- irqchip/mbigen: Don't clear eventid when freeing an MSI
  (bnc#1012628).
- irqchip/stm32: Don't set rising configuration registers at init
  (bnc#1012628).
- irqchip/stm32: Don't clear rising/falling config registers at
  init (bnc#1012628).
- drm/exynos/mixer: fix MIXER shadow registry synchronisation code
  (bnc#1012628).
- blk-iolatency: #include "blk.h" (bnc#1012628).
- PM / Domains: Avoid a potential deadlock (bnc#1012628).
- ACPI / utils: Drop reference in test for device presence
  (bnc#1012628).
- perf tests: Fix a memory leak in
  test__perf_evsel__tp_sched_test() (bnc#1012628).
- perf tests: Fix memory leak by expr__find_other() in
  test__expr() (bnc#1012628).
- perf tests: Fix a memory leak of cpu_map object in the
  openat_syscall_event_on_all_cpus test (bnc#1012628).
- perf evsel: Free evsel->counts in perf_evsel__exit()
  (bnc#1012628).
- perf top: Fix global-buffer-overflow issue (bnc#1012628).
- perf maps: Purge all maps from the 'names' tree (bnc#1012628).
- perf map: Remove map from 'names' tree in __maps__remove()
  (bnc#1012628).
- perf hist: Add missing map__put() in error case (bnc#1012628).
- perf top: Fix error handling in cmd_top() (bnc#1012628).
- perf build-id: Fix memory leak in print_sdt_events()
  (bnc#1012628).
- perf config: Fix a memory leak in collect_config()
  (bnc#1012628).
- perf config: Fix an error in the config template documentation
  (bnc#1012628).
- perf tools: Fix errors under optimization level '-Og'
  (bnc#1012628).
- perf list: Don't forget to drop the reference to the allocated
  thread_map (bnc#1012628).
- perf stat: Fix --no-scale (bnc#1012628).
- scsi: qla2xxx: Fix NULL pointer crash due to stale CPUID
  (bnc#1012628).
- scsi: core: Also call destroy_rcu_head() for passthrough
  requests (bnc#1012628).
- tools/power turbostat: return the exit status of a command
  (bnc#1012628).
- x86/mm: Don't leak kernel addresses (bnc#1012628).
- sched/core: Fix buffer overflow in cgroup2 property cpu.max
  (bnc#1012628).
- sched/cpufreq: Fix 32-bit math overflow (bnc#1012628).
- scsi: iscsi: flush running unbind operations when removing a
  session (bnc#1012628).
- thermal/intel_powerclamp: fix truncated kthread name
  (bnc#1012628).
- thermal/int340x_thermal: fix mode setting (bnc#1012628).
- thermal/int340x_thermal: Add additional UUIDs (bnc#1012628).
- thermal: bcm2835: Fix crash in bcm2835_thermal_debugfs
  (bnc#1012628).
- thermal: samsung: Fix incorrect check after code merge
  (bnc#1012628).
- thermal/intel_powerclamp: fix __percpu declaration of
  worker_data (bnc#1012628).
- paride/pcd: cleanup queues when detection fails (bnc#1012628).
- paride/pf: cleanup queues when detection fails (bnc#1012628).
- ALSA: opl3: fix mismatch between snd_opl3_drum_switch definition
  and declaration (bnc#1012628).
- mmc: davinci: remove extraneous __init annotation (bnc#1012628).
- i40iw: Avoid panic when handling the inetdev event
  (bnc#1012628).
- IB/mlx4: Fix race condition between catas error reset and
  aliasguid flows (bnc#1012628).
- drm/udl: use drm_gem_object_put_unlocked (bnc#1012628).
- auxdisplay: hd44780: Fix memory leak on ->remove()
  (bnc#1012628).
- ALSA: sb8: add a check for request_region (bnc#1012628).
- ALSA: echoaudio: add a check for ioremap_nocache (bnc#1012628).
- ext4: report real fs size after failed resize (bnc#1012628).
- ext4: add missing brelse() in add_new_gdb_meta_bg()
  (bnc#1012628).
- ext4: avoid panic during forced reboot (bnc#1012628).
- mips: bcm47xx: Enable USB power on Netgear WNDR3400v2
  (bnc#1012628).
- perf/core: Restore mmap record type correctly (bnc#1012628).
- inotify: Fix fsnotify_mark refcount leak in
  inotify_update_existing_watch() (bnc#1012628).
- arc: hsdk_defconfig: Enable CONFIG_BLK_DEV_RAM (bnc#1012628).
- ARC: u-boot args: check that magic number is correct
  (bnc#1012628).
- commit 7bd8353
* Wed Apr 17 2019 tiwai@suse.de
- brcmfmac: assure SSID length from firmware is limited
  (CVE-2019-9500,bsc#1132681).
- brcmfmac: add subtype check for event handling in data path
  (CVE-2019-8564,bsc#1132673).
- commit 4835ec0
* Wed Apr 17 2019 jslaby@suse.cz
- Move the vfio patch from kernel.org to suse.
  kernel.org is only for stable patches.
- commit 6daf8be
* Wed Apr 17 2019 jslaby@suse.cz
- Linux 5.0.8 (bnc#1012628).
- drm/i915/gvt: do not let pin count of shadow mm go negative
  (bnc#1012628).
- kbuild: pkg: use -f $(srctree)/Makefile to recurse to top
  Makefile (bnc#1012628).
- netfilter: nft_compat: use .release_ops and remove list of
  extension (bnc#1012628).
- netfilter: nf_tables: use-after-free in dynamic operations
  (bnc#1012628).
- netfilter: nf_tables: add missing ->release_ops() in error
  path of newrule() (bnc#1012628).
- hv_netvsc: Fix unwanted wakeup after tx_disable (bnc#1012628).
- ibmvnic: Fix completion structure initialization (bnc#1012628).
- ip6_tunnel: Match to ARPHRD_TUNNEL6 for dev type (bnc#1012628).
- ipv6: Fix dangling pointer when ipv6 fragment (bnc#1012628).
- ipv6: sit: reset ip header pointer in ipip6_rcv (bnc#1012628).
- net: ethtool: not call vzalloc for zero sized memory request
  (bnc#1012628).
- net-gro: Fix GRO flush when receiving a GSO packet
  (bnc#1012628).
- net/mlx5: Decrease default mr cache size (bnc#1012628).
- netns: provide pure entropy for net_hash_mix() (bnc#1012628).
- net: rds: force to destroy connection if t_sock is NULL in
  rds_tcp_kill_sock() (bnc#1012628).
- net/sched: act_sample: fix divide by zero in the traffic path
  (bnc#1012628).
- net/sched: fix ->get helper of the matchall cls (bnc#1012628).
- openvswitch: fix flow actions reallocation (bnc#1012628).
- qmi_wwan: add Olicard 600 (bnc#1012628).
- r8169: disable ASPM again (bnc#1012628).
- sctp: initialize _pad of sockaddr_in before copying to user
  memory (bnc#1012628).
- tcp: Ensure DCTCP reacts to losses (bnc#1012628).
- tcp: fix a potential NULL pointer dereference in tcp_sk_exit
  (bnc#1012628).
- vrf: check accept_source_route on the original netdevice
  (bnc#1012628).
- net/mlx5e: Fix error handling when refreshing TIRs
  (bnc#1012628).
- net/mlx5e: Add a lock on tir list (bnc#1012628).
- nfp: validate the return code from dev_queue_xmit()
  (bnc#1012628).
- nfp: disable netpoll on representors (bnc#1012628).
- bnxt_en: Improve RX consumer index validity check (bnc#1012628).
- bnxt_en: Reset device on RX buffer errors (bnc#1012628).
- net: ip_gre: fix possible use-after-free in erspan_rcv
  (bnc#1012628).
- net: ip6_gre: fix possible use-after-free in ip6erspan_rcv
  (bnc#1012628).
- net: bridge: always clear mcast matching struct on reports
  and leaves (bnc#1012628).
- net: thunderx: fix NULL pointer dereference in
  nicvf_open/nicvf_stop (bnc#1012628).
- net: vrf: Fix ping failed when vrf mtu is set to 0
  (bnc#1012628).
- net: core: netif_receive_skb_list: unlist skb before passing
  to pt->func (bnc#1012628).
- r8169: disable default rx interrupt coalescing on RTL8168
  (bnc#1012628).
- net: mlx5: Add a missing check on idr_find, free buf
  (bnc#1012628).
- net/mlx5e: Update xoff formula (bnc#1012628).
- net/mlx5e: Update xon formula (bnc#1012628).
- kbuild: clang: choose GCC_TOOLCHAIN_DIR not on LD (bnc#1012628).
- lib/string.c: implement a basic bcmp (bnc#1012628).
- Revert "clk: meson: clean-up clock registration" (bnc#1012628).
- tty: mark Siemens R3964 line discipline as BROKEN (bnc#1012628).
- tty: ldisc: add sysctl to prevent autoloading of ldiscs
  (bnc#1012628).
- hwmon: (w83773g) Select REGMAP_I2C to fix build error
  (bnc#1012628).
- hwmon: (occ) Fix power sensor indexing (bnc#1012628).
- SMB3: Allow persistent handle timeout to be configurable on
  mount (bnc#1012628).
- HID: logitech: Handle 0 scroll events for the m560
  (bnc#1012628).
- ACPICA: Clear status of GPEs before enabling them (bnc#1012628).
- ACPICA: Namespace: remove address node from global list after
  method termination (bnc#1012628).
- ALSA: seq: Fix OOB-reads from strlcpy (bnc#1012628).
- ALSA: hda/realtek: Enable headset MIC of Acer TravelMate
  B114-21 with ALC233 (bnc#1012628).
- ALSA: hda/realtek - Add quirk for Tuxedo XC 1509 (bnc#1012628).
- ALSA: xen-front: Do not use stream buffer size before it is set
  (bnc#1012628).
- ALSA: hda - Add two more machines to the power_save_blacklist
  (bnc#1012628).
- mm/huge_memory.c: fix modifying of page protection by
  insert_pfn_pmd() (bnc#1012628).
- arm64: dts: rockchip: fix rk3328 sdmmc0 write errors
  (bnc#1012628).
- mmc: alcor: don't write data before command has completed
  (bnc#1012628).
- mmc: sdhci-omap: Don't finish_mrq() on a command error during
  tuning (bnc#1012628).
- parisc: Detect QEMU earlier in boot process (bnc#1012628).
- parisc: regs_return_value() should return gpr28 (bnc#1012628).
- parisc: also set iaoq_b in instruction_pointer_set()
  (bnc#1012628).
- alarmtimer: Return correct remaining time (bnc#1012628).
- drm/i915/gvt: do not deliver a workload if its creation fails
  (bnc#1012628).
- drm/sun4i: DW HDMI: Lower max. supported rate for H6
  (bnc#1012628).
- drm/udl: add a release method and delay modeset teardown
  (bnc#1012628).
- kvm: svm: fix potential get_num_contig_pages overflow
  (bnc#1012628).
- include/linux/bitrev.h: fix constant bitrev (bnc#1012628).
- mm: writeback: use exact memcg dirty counts (bnc#1012628).
- ASoC: intel: Fix crash at suspend/resume after failed codec
  registration (bnc#1012628).
- ASoC: fsl_esai: fix channel swap issue when stream starts
  (bnc#1012628).
- Btrfs: do not allow trimming when a fs is mounted with the
  nologreplay option (bnc#1012628).
- btrfs: prop: fix zstd compression parameter validation
  (bnc#1012628).
- btrfs: prop: fix vanished compression property after failed set
  (bnc#1012628).
- riscv: Fix syscall_get_arguments() and syscall_set_arguments()
  (bnc#1012628).
- block: Revert v5.0 blk_mq_request_issue_directly() changes
  (bnc#1012628).
- block: do not leak memory in bio_copy_user_iov() (bnc#1012628).
- block: fix the return errno for direct IO (bnc#1012628).
- genirq: Respect IRQCHIP_SKIP_SET_WAKE in
  irq_chip_set_wake_parent() (bnc#1012628).
- genirq: Initialize request_mutex if CONFIG_SPARSE_IRQ=n
  (bnc#1012628).
- virtio: Honour 'may_reduce_num' in vring_create_virtqueue
  (bnc#1012628).
- ARM: OMAP1: ams-delta: Fix broken GPIO ID allocation
  (bnc#1012628).
- ARM: dts: rockchip: fix rk3288 cpu opp node reference
  (bnc#1012628).
- ARM: dts: am335x-evmsk: Correct the regulators for the audio
  codec (bnc#1012628).
- ARM: dts: am335x-evm: Correct the regulators for the audio codec
  (bnc#1012628).
- ARM: dts: rockchip: Fix SD card detection on rk3288-tinker
  (bnc#1012628).
- ARM: dts: at91: Fix typo in ISC_D0 on PC9 (bnc#1012628).
- arm64: futex: Fix FUTEX_WAKE_OP atomic ops with non-zero result
  value (bnc#1012628).
- arm64: dts: rockchip: Fix vcc_host1_5v GPIO polarity on
  rk3328-rock64 (bnc#1012628).
- arm64: dts: rockchip: fix rk3328 rgmii high tx error rate
  (bnc#1012628).
- arm64: backtrace: Don't bother trying to unwind the userspace
  stack (bnc#1012628).
- arm64/ftrace: fix inadvertent BUG() in trampoline check
  (bnc#1012628).
- IB/mlx5: Reset access mask when looping inside page fault
  handler (bnc#1012628).
- xen: Prevent buffer overflow in privcmd ioctl (bnc#1012628).
- sched/fair: Do not re-read ->h_load_next during hierarchical
  load calculation (bnc#1012628).
- xtensa: fix return_address (bnc#1012628).
- csky: Fix syscall_get_arguments() and syscall_set_arguments()
  (bnc#1012628).
- x86/asm: Remove dead __GNUC__ conditionals (bnc#1012628).
- x86/asm: Use stricter assembly constraints in bitops
  (bnc#1012628).
- x86/perf/amd: Resolve race condition when disabling PMC
  (bnc#1012628).
- x86/perf/amd: Resolve NMI latency issues for active PMCs
  (bnc#1012628).
- x86/perf/amd: Remove need to check "running" bit in NMI handler
  (bnc#1012628).
- PCI: Add function 1 DMA alias quirk for Marvell 9170 SATA
  controller (bnc#1012628).
- PCI: pciehp: Ignore Link State Changes after powering off a slot
  (bnc#1012628).
- xprtrdma: Fix helper that drains the transport (bnc#1012628).
- powerpc/64s/radix: Fix radix segment exception handling
  (bnc#1012628).
- dm integrity: change memcmp to strncmp in dm_integrity_ctr
  (bnc#1012628).
- dm: revert 8f50e358153d ("dm: limit the max bio size as
  BIO_MAX_PAGES * PAGE_SIZE") (bnc#1012628).
- dm table: propagate BDI_CAP_STABLE_WRITES to fix sporadic
  checksum errors (bnc#1012628).
- dm: disable DISCARD if the underlying storage no longer supports
  it (bnc#1012628).
- dm integrity: fix deadlock with overlapping I/O (bnc#1012628).
- drm/virtio: do NOT reuse resource ids (bnc#1012628).
- Update config files: keep LDISC_AUTOLOAD and let R3964 go
  * LDISC_AUTOLOAD is new and =y preserves the original behaviour.
  * R3964 was marked as BROKEN.
- commit 33c0e93
* Tue Apr 16 2019 mkubecek@suse.cz
- series.conf: cleanup
  patches.suse/ext2-fsync-err was deleted in 2011 but its (commented out)
  line in series.conf was left behind.
- commit d2aebe3
* Mon Apr 15 2019 jkosina@suse.cz
- Delete
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Delete
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- Delete
  patches.suse/0003-x86-idle-Control-Indirect-Branch-Speculation-in-idle.patch.
- Delete
  patches.suse/0004-x86-enter-Create-macros-to-restrict-unrestrict-Indir.patch.
- Delete
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
  Drop SUSE-specific IBRS-on-SKL implementation. Please refer to
  page 16 of Intel's paper [1]: "Intel considers the risk of an attack
  based on exploiting deep call stacks low."
  [1] https://software.intel.com/security-software-guidance/api-app/sites/default/files/Retpoline-A-Branch-Target-Injection-Mitigation.pdf
- Delete
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Delete
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- Delete
  patches.suse/0003-x86-idle-Control-Indirect-Branch-Speculation-in-idle.patch.
- Delete
  patches.suse/0004-x86-enter-Create-macros-to-restrict-unrestrict-Indir.patch.
- Delete
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
  Drop SUSE-specific IBRS-on-SKL implementation. Please refer to
  page 16 of [1]
  [1] https://software.intel.com/security-software-guidance/api-app/sites/default/files/Retpoline-A-Branch-Target-Injection-Mitigation.pdf
- commit 2cfda4d
* Mon Apr 15 2019 jslaby@suse.cz
- Refresh
  patches.suse/drm-i915-dp-revert-back-to-max-link-rate-and-lane-count-on-eDP.patch.
- commit 8a6bcaf
* Mon Apr 15 2019 mkubecek@suse.cz
- Update to 5.1-rc5
- commit 2fd333d
* Fri Apr 12 2019 jroedel@suse.de
- vfio/type1: Limit DMA mappings per container (CVE-2019-3882 bsc#1131427).
- commit 012b5f1
* Fri Apr 12 2019 jroedel@suse.de
- KVM: x86: nVMX: fix x2APIC VTPR read intercept (CVE-2019-3887
  bsc#1131800).
- KVM: x86: nVMX: close leak of L0's x2APIC MSRs (CVE-2019-3887)
  (CVE-2019-3887 bsc#1131800).
- commit d597027
* Thu Apr 11 2019 msuchanek@suse.de
- Do not provide kernel-default from kernel-default-base (boo#1132154, bsc#1106751).
- commit 0e54e61
* Thu Apr 11 2019 msuchanek@suse.de
- rpm/kernel-subpackage-spec: only provide firmware actually present in
  subpackage.
- commit 839debd
* Thu Apr 11 2019 jslaby@suse.cz
- kcm: switch order of device registration to fix a crash
  (bnc#1130527).
- commit 508a450
* Wed Apr 10 2019 msuchanek@suse.de
- kernel-subpackage-spec: Add dummy package to ensure subpackages are
  rebuilt with kernel update (bsc#1106751).
  In factory packages are not rebuilt automatically so a dependency is
  needed on the old kernel to get a rebuild with the new kernel. THe
  subpackage itself cannot depend on the kernel so add another empty
  pacakge that does depend on it.
- commit 6d14837
* Wed Apr 10 2019 tiwai@suse.de
- drm/i915/dp: revert back to max link rate and lane count on eDP
  (bsc#1132033).
- commit d7dabeb
* Tue Apr  9 2019 jdelvare@suse.de
- Disable CONFIG_SERIO_OLPC_APSP on all but armv7
  This driver is only used by ARMv7-based OLPC laptops.
- commit 7b1b640
* Tue Apr  9 2019 jdelvare@suse.de
- Disable CONFIG_SENSORS_OCC_*
  These drivers are running on the BMC of PowerPC servers. The BMC runs
  OpenBMC and is not a target for SUSE distributions.
- commit a82eb87
* Mon Apr  8 2019 mkubecek@suse.cz
- config: disable DEVKMEM (bsc#1128045)
- commit 8b88553
* Mon Apr  8 2019 mkubecek@suse.cz
- Update to 5.1-rc4
- Refresh configs
- commit e334e4f
* Sat Apr  6 2019 jslaby@suse.cz
- Linux 5.0.7 (bnc#1012628).
- ext4: cleanup bh release code in ext4_ind_remove_space()
  (bnc#1012628).
- CIFS: fix POSIX lock leak and invalid ptr deref (bnc#1012628).
- nvme-fc: fix numa_node when dev is null (bnc#1012628).
- nvme-loop: init nvmet_ctrl fatal_err_work when allocate
  (bnc#1012628).
- h8300: use cc-cross-prefix instead of hardcoding
  h8300-unknown-linux- (bnc#1012628).
- f2fs: fix to adapt small inline xattr space in
  __find_inline_xattr() (bnc#1012628).
- f2fs: fix to avoid deadlock in f2fs_read_inline_dir()
  (bnc#1012628).
- apparmor: fix double free when unpack of secmark rules fails
  (bnc#1012628).
- tracing: kdb: Fix ftdump to not sleep (bnc#1012628).
- net/mlx5e: Fix access to non-existing receive queue
  (bnc#1012628).
- net/mlx5: Avoid panic when setting vport rate (bnc#1012628).
- net/mlx5: Avoid panic when setting vport mac, getting vport
  config (bnc#1012628).
- xsk: fix to reject invalid flags in xsk_bind (bnc#1012628).
- clk: ti: clkctrl: Fix clkdm_name regression for
  TI_CLK_CLKCTRL_COMPAT (bnc#1012628).
- gpio: gpio-omap: fix level interrupt idling (bnc#1012628).
- include/linux/relay.h: fix percpu annotation in struct rchan
  (bnc#1012628).
- sysctl: handle overflow for file-max (bnc#1012628).
- net: stmmac: Avoid sometimes uninitialized Clang warnings
  (bnc#1012628).
- enic: fix build warning without CONFIG_CPUMASK_OFFSTACK
  (bnc#1012628).
- libbpf: force fixdep compilation at the start of the build
  (bnc#1012628).
- scsi: hisi_sas: Set PHY linkrate when disconnected
  (bnc#1012628).
- scsi: hisi_sas: Fix a timeout race of driver internal and SMP IO
  (bnc#1012628).
- iio: adc: fix warning in Qualcomm PM8xxx HK/XOADC driver
  (bnc#1012628).
- x86/hyperv: Fix kernel panic when kexec on HyperV (bnc#1012628).
- perf c2c: Fix c2c report for empty numa node (bnc#1012628).
- mm/sparse: fix a bad comparison (bnc#1012628).
- mm/cma.c: cma_declare_contiguous: correct err handling
  (bnc#1012628).
- mm/page_ext.c: fix an imbalance with kmemleak (bnc#1012628).
- mm, swap: bounds check swap_info array accesses to avoid NULL
  derefs (bnc#1012628).
- docs/core-api/mm: fix user memory accessors formatting
  (bnc#1012628).
- mm,oom: don't kill global init via memory.oom.group
  (bnc#1012628).
- memcg: killed threads should not invoke memcg OOM killer
  (bnc#1012628).
- mm, mempolicy: fix uninit memory access (bnc#1012628).
- mm/vmalloc.c: fix kernel BUG at mm/vmalloc.c:512! (bnc#1012628).
- mm/slab.c: kmemleak no scan alien caches (bnc#1012628).
- ocfs2: fix a panic problem caused by o2cb_ctl (bnc#1012628).
- f2fs: do not use mutex lock in atomic context (bnc#1012628).
- f2fs: fix to data block override node segment by mistake
  (bnc#1012628).
- fs/file.c: initialize init_files.resize_wait (bnc#1012628).
- page_poison: play nicely with KASAN (bnc#1012628).
- kasan: fix kasan_check_read/write definitions (bnc#1012628).
- cifs: use correct format characters (bnc#1012628).
- dm thin: add sanity checks to thin-pool and external snapshot
  creation (bnc#1012628).
- f2fs: fix to check inline_xattr_size boundary correctly
  (bnc#1012628).
- cifs: Accept validate negotiate if server return
  NT_STATUS_NOT_SUPPORTED (bnc#1012628).
- perf beauty msg_flags: Add missing %%s lost when adding prefix
  suppression logic (bnc#1012628).
- netfilter: nf_tables: check the result of dereferencing
  base_chain->stats (bnc#1012628).
- PCI: mediatek: Fix memory mapped IO range size computation
  (bnc#1012628).
- netfilter: conntrack: tcp: only close if RST matches exact
  sequence (bnc#1012628).
- iommu/vt-d: Disable ATS support on untrusted devices
  (bnc#1012628).
- jbd2: fix invalid descriptor block checksum (bnc#1012628).
- ext4: fix bigalloc cluster freeing when hole punching under load
  (bnc#1012628).
- fs: fix guard_bio_eod to check for real EOD errors
  (bnc#1012628).
- tools lib traceevent: Fix buffer overflow in arg_eval
  (bnc#1012628).
- mm/resource: Return real error codes from walk failures
  (bnc#1012628).
- PCI/PME: Fix hotplug/sysfs remove deadlock in pcie_pme_remove()
  (bnc#1012628).
- wil6210: check null pointer in _wil_cfg80211_merge_extra_ies
  (bnc#1012628).
- mt76: fix a leaked reference by adding a missing of_node_put
  (bnc#1012628).
- ath10k: Fix the wrong updation of BW in tx_stats debugfs entry
  (bnc#1012628).
- lockdep/lib/tests: Fix run_tests.sh (bnc#1012628).
- crypto: crypto4xx - add missing of_node_put after
  of_device_is_available (bnc#1012628).
- crypto: cavium/zip - fix collision with generic cra_driver_name
  (bnc#1012628).
- tools/bpf: selftests: add map lookup to test_map_in_map bpf prog
  (bnc#1012628).
- usb: chipidea: Grab the (legacy) USB PHY by phandle first
  (bnc#1012628).
- powerpc/powernv/ioda: Fix locked_vm counting for memory used
  by IOMMU tables (bnc#1012628).
- scsi: core: replace GFP_ATOMIC with GFP_KERNEL in scsi_scan.c
  (bnc#1012628).
- kbuild: invoke syncconfig if include/config/auto.conf.cmd is
  missing (bnc#1012628).
- kbuild: make -r/-R effective in top Makefile for old Make
  versions (bnc#1012628).
- btrfs: save drop_progress if we drop refs at all (bnc#1012628).
- drm/amd/display: Fix reference counting for struct dc_sink
  (bnc#1012628).
- ath10k: don't report unset rssi values to mac80211
  (bnc#1012628).
- powerpc/xmon: Fix opcode being uninitialized in
  print_insn_powerpc (bnc#1012628).
- coresight: etm4x: Add support to enable ETMv4.2 (bnc#1012628).
- serial: 8250_pxa: honor the port number from devicetree
  (bnc#1012628).
- ARM: 8840/1: use a raw_spinlock_t in unwind (bnc#1012628).
- ARM: 8845/1: use unified assembler in c files (bnc#1012628).
- iommu/io-pgtable-arm-v7s: Only kmemleak_ignore L2 tables
  (bnc#1012628).
- powerpc/hugetlb: Handle mmap_min_addr correctly in
  get_unmapped_area callback (bnc#1012628).
- net: dsa: mv88e6xxx: Default CMODE to 1000BaseX only on 6390X
  (bnc#1012628).
- ice: fix ice_remove_rule_internal vsi_list handling
  (bnc#1012628).
- perf script: Handle missing fields with -F +. (bnc#1012628).
- btrfs: qgroup: Make qgroup async transaction commit more
  aggressive (bnc#1012628).
- btrfs: don't enospc all tickets on flush failure (bnc#1012628).
- mmc: omap: fix the maximum timeout setting (bnc#1012628).
- net: dsa: mv88e6xxx: Add lockdep classes to fix false positive
  splat (bnc#1012628).
- net: hns3: fix setting of the hns reset_type for rdma hw errors
  (bnc#1012628).
- veth: Fix -Wformat-truncation (bnc#1012628).
- e1000e: Fix -Wformat-truncation warnings (bnc#1012628).
- mlxsw: spectrum: Avoid -Wformat-truncation warnings
  (bnc#1012628).
- i2c: Allow recovery of the initial IRQ by an I2C client device
  (bnc#1012628).
- platform/x86: ideapad-laptop: Fix no_hw_rfkill_list for Lenovo
  RESCUER R720-15IKBN (bnc#1012628).
- platform/mellanox: mlxreg-hotplug: Fix KASAN warning
  (bnc#1012628).
- loop: set GENHD_FL_NO_PART_SCAN after blkdev_reread_part()
  (bnc#1012628).
- i2c: designware: Do not allow i2c_dw_xfer() calls while
  suspended (bnc#1012628).
- IB/mlx4: Increase the timeout for CM cache (bnc#1012628).
- clk: fractional-divider: check parent rate only if flag is set
  (bnc#1012628).
- perf annotate: Fix getting source line failure (bnc#1012628).
- powerpc/44x: Force PCI on for CURRITUCK (bnc#1012628).
- ASoC: qcom: Fix of-node refcount unbalance in
  qcom_snd_parse_of() (bnc#1012628).
- cpufreq: acpi-cpufreq: Report if CPU doesn't support boost
  technologies (bnc#1012628).
- efi: cper: Fix possible out-of-bounds access (bnc#1012628).
- s390/ism: ignore some errors during deregistration
  (bnc#1012628).
- scsi: megaraid_sas: return error when create DMA pool failed
  (bnc#1012628).
- scsi: fcoe: make use of fip_mode enum complete (bnc#1012628).
- drm/amd/display: Clear stream->mode_changed after commit
  (bnc#1012628).
- perf test: Fix failure of 'evsel-tp-sched' test on s390
  (bnc#1012628).
- mwifiex: don't advertise IBSS features without FW support
  (bnc#1012628).
- perf report: Don't shadow inlined symbol with different addr
  range (bnc#1012628).
- SoC: imx-sgtl5000: add missing put_device() (bnc#1012628).
- media: ov7740: fix runtime pm initialization (bnc#1012628).
- media: sh_veu: Correct return type for mem2mem buffer helpers
  (bnc#1012628).
- media: s5p-jpeg: Correct return type for mem2mem buffer helpers
  (bnc#1012628).
- media: rockchip/rga: Correct return type for mem2mem buffer
  helpers (bnc#1012628).
- media: s5p-g2d: Correct return type for mem2mem buffer helpers
  (bnc#1012628).
- media: mx2_emmaprp: Correct return type for mem2mem buffer
  helpers (bnc#1012628).
- media: mtk-jpeg: Correct return type for mem2mem buffer helpers
  (bnc#1012628).
- media: rockchip/vpu: Correct return type for mem2mem buffer
  helpers (bnc#1012628).
- mt76: usb: do not run mt76u_queues_deinit twice (bnc#1012628).
- gpio: of: Apply regulator-gpio quirk only to enable-gpios
  (bnc#1012628).
- xen/gntdev: Do not destroy context while dma-bufs are in use
  (bnc#1012628).
- vfs: fix preadv64v2 and pwritev64v2 compat syscalls with offset
  == -1 (bnc#1012628).
- HID: intel-ish-hid: avoid binding wrong ishtp_cl_device
  (bnc#1012628).
- cgroup, rstat: Don't flush subtree root unless necessary
  (bnc#1012628).
- efi: Fix build error due to enum collision between efi.h and
  ima.h (bnc#1012628).
- drm/sched: Fix entities with 0 rqs (bnc#1012628).
- regulator: core: Take lock before applying system load
  (bnc#1012628).
- jbd2: fix race when writing superblock (bnc#1012628).
- leds: lp55xx: fix null deref on firmware load failure
  (bnc#1012628).
- tools build: Add -lrt to FEATURE_CHECK_LDFLAGS-libaio
  (bnc#1012628).
- tools build: Add test-reallocarray.c to test-all.c to fix the
  build (bnc#1012628).
- perf beauty waitid options: Fix up prefix showing logic
  (bnc#1012628).
- perf trace: Check if the 'fd' is negative when mapping it to
  pathname (bnc#1012628).
- perf report: Add s390 diagnosic sampling descriptor size
  (bnc#1012628).
- perf coresight: Do not test for libopencsd by default
  (bnc#1012628).
- iwlwifi: pcie: fix emergency path (bnc#1012628).
- ACPI / video: Refactor and fix dmi_is_desktop() (bnc#1012628).
- =?UTF-8?q?selftests:=20ir:=20fix=20warning:=20"%%s"=20dire?=
  =?UTF-8?q?ctive=20output=20may=20be=20truncated=20=E2=80=99=20directive?=
  =?UTF-8?q?=20output=20may=20be=20truncated?= (bnc#1012628).
- selftests: skip seccomp get_metadata test if not real root
  (bnc#1012628).
- kprobes: Prohibit probing on bsearch() (bnc#1012628).
- kprobes: Prohibit probing on RCU debug routine (bnc#1012628).
- netfilter: conntrack: fix cloned unconfirmed skb->_nfct race
  in __nf_conntrack_confirm (bnc#1012628).
- ARM: 8833/1: Ensure that NEON code always compiles with Clang
  (bnc#1012628).
- ARM: dts: meson8b: fix the Ethernet data line signals in
  eth_rgmii_pins (bnc#1012628).
- ALSA: PCM: check if ops are defined before suspending PCM
  (bnc#1012628).
- ath10k: fix shadow register implementation for WCN3990
  (bnc#1012628).
- usb: f_fs: Avoid crash due to out-of-scope stack ptr access
  (bnc#1012628).
- sched/topology: Fix percpu data types in struct sd_data &
  struct s_data (bnc#1012628).
- bcache: fix input overflow to cache set sysfs file
  io_error_halflife (bnc#1012628).
- bcache: fix input overflow to sequential_cutoff (bnc#1012628).
- bcache: fix potential div-zero error of
  writeback_rate_i_term_inverse (bnc#1012628).
- bcache: improve sysfs_strtoul_clamp() (bnc#1012628).
- genirq: Avoid summation loops for /proc/stat (bnc#1012628).
- net: marvell: mvpp2: fix stuck in-band SGMII negotiation
  (bnc#1012628).
- iw_cxgb4: fix srqidx leak during connection abort (bnc#1012628).
- net: phy: consider latched link-down status in polling mode
  (bnc#1012628).
- fbdev: fbmem: fix memory access if logo is bigger than the
  screen (bnc#1012628).
- cdrom: Fix race condition in cdrom_sysctl_register
  (bnc#1012628).
- drm: rcar-du: add missing of_node_put (bnc#1012628).
- drm/amd/display: Don't re-program planes for DPMS changes
  (bnc#1012628).
- bpf: test_maps: fix possible out of bound access warning
  (bnc#1012628).
- x86/kexec: Fill in acpi_rsdp_addr from the first kernel
  (bnc#1012628).
- powerpc/ptrace: Mitigate potential Spectre v1 (bnc#1012628).
- drm/amd/display: Disconnect mpcc when changing tg (bnc#1012628).
- perf/aux: Make perf_event accessible to setup_aux()
  (bnc#1012628).
- e1000e: fix cyclic resets at link up with active tx
  (bnc#1012628).
- e1000e: Exclude device from suspend direct complete optimization
  (bnc#1012628).
- platform/x86: intel_pmc_core: Fix PCH IP sts reading
  (bnc#1012628).
- i2c: of: Try to find an I2C adapter matching the parent
  (bnc#1012628).
- staging: spi: mt7621: Add return code check on device_reset()
  (bnc#1012628).
- iwlwifi: mvm: fix RFH config command with >=10 CPUs
  (bnc#1012628).
- ASoC: fsl-asoc-card: fix object reference leaks in
  fsl_asoc_card_probe (bnc#1012628).
- sched/debug: Initialize sd_sysctl_cpus if
  !CONFIG_CPUMASK_OFFSTACK (bnc#1012628).
- efi/memattr: Don't bail on zero VA if it equals the region's PA
  (bnc#1012628).
- sched/core: Use READ_ONCE()/WRITE_ONCE() in
  move_queued_task()/task_rq_lock() (bnc#1012628).
- drm/vkms: Bugfix racing hrtimer vblank handle (bnc#1012628).
- drm/vkms: Bugfix extra vblank frame (bnc#1012628).
- ARM: dts: lpc32xx: Remove leading 0x and 0s from bindings
  notation (bnc#1012628).
- efi/arm/arm64: Allow SetVirtualAddressMap() to be omitted
  (bnc#1012628).
- soc: qcom: gsbi: Fix error handling in gsbi_probe()
  (bnc#1012628).
- drm/msm/dpu: Convert to a chained irq chip (bnc#1012628).
- mt7601u: bump supported EEPROM version (bnc#1012628).
- ARM: 8830/1: NOMMU: Toggle only bits in EXC_RETURN we are
  really care of (bnc#1012628).
- ARM: avoid Cortex-A9 livelock on tight dmb loops (bnc#1012628).
- block, bfq: fix in-service-queue check for queue merging
  (bnc#1012628).
- block, bfq: fix queue removal from weights tree (bnc#1012628).
- bpf: fix missing prototype warnings (bnc#1012628).
- selftests/bpf: skip verifier tests for unsupported program types
  (bnc#1012628).
- powerpc/64s: Clear on-stack exception marker upon exception
  return (bnc#1012628).
- cgroup/pids: turn cgroup_subsys->free() into
  cgroup_subsys->release() to fix the accounting (bnc#1012628).
- backlight: pwm_bl: Use gpiod_get_value_cansleep() to get
  initial state (bnc#1012628).
- tty: increase the default flip buffer limit to 2*640K
  (bnc#1012628).
- powerpc/pseries: Perform full re-add of CPU for topology update
  post-migration (bnc#1012628).
- drm/amd/display: Enable vblank interrupt during CRC capture
  (bnc#1012628).
- ALSA: dice: add support for Solid State Logic Duende
  Classic/Mini (bnc#1012628).
- regulator: mcp16502: Include linux/gpio/consumer.h to fix
  build error (bnc#1012628).
- usb: dwc3: gadget: Fix OTG events when gadget driver isn't
  loaded (bnc#1012628).
- platform/x86: intel-hid: Missing power button release on some
  Dell models (bnc#1012628).
- perf trace: Fixup etcsnoop example (bnc#1012628).
- perf script python: Use PyBytes for attr in trace-event-python
  (bnc#1012628).
- perf script python: Add trace_context extension module to
  sys.modules (bnc#1012628).
- media: mt9m111: set initial frame size other than 0x0
  (bnc#1012628).
- hwrng: virtio - Avoid repeated init of completion (bnc#1012628).
- soc/tegra: fuse: Fix illegal free of IO base address
  (bnc#1012628).
- selftests/bpf: suppress readelf stderr when probing for BTF
  support (bnc#1012628).
- HID: intel-ish: ipc: handle PIMR before ish_wakeup also clear
  PISR busy_clear bit (bnc#1012628).
- f2fs: UBSAN: set boolean value iostat_enable correctly
  (bnc#1012628).
- f2fs: fix to initialize variable to avoid UBSAN/smatch warning
  (bnc#1012628).
- hpet: Fix missing '=' character in the __setup() code of
  hpet_mmap_enable (bnc#1012628).
- pinctrl: meson: fix G12A ao pull registers base address
  (bnc#1012628).
- pinctrl: sh-pfc: r8a77990: Fix MOD_SEL bit numbering
  (bnc#1012628).
- pinctrl: sh-pfc: r8a77995: Fix MOD_SEL bit numbering
  (bnc#1012628).
- cpu/hotplug: Mute hotplug lockdep during init (bnc#1012628).
- dmaengine: imx-dma: fix warning comparison of distinct pointer
  types (bnc#1012628).
- dmaengine: qcom_hidma: assign channel cookie correctly
  (bnc#1012628).
- dmaengine: qcom_hidma: initialize tx flags in hidma_prep_dma_*
  (bnc#1012628).
- netfilter: physdev: relax br_netfilter dependency (bnc#1012628).
- media: rcar-vin: Allow independent VIN link enablement
  (bnc#1012628).
- media: s5p-jpeg: Check for fmt_ver_flag when doing fmt
  enumeration (bnc#1012628).
- PCI: pciehp: Assign ctrl->slot_ctrl before writing it to
  hardware (bnc#1012628).
- audit: hand taken context to audit_kill_trees for syscall
  logging (bnc#1012628).
- regulator: act8865: Fix act8600_sudcdc_voltage_ranges setting
  (bnc#1012628).
- pinctrl: meson: meson8b: add the eth_rxd2 and eth_rxd3 pins
  (bnc#1012628).
- drm: Auto-set allow_fb_modifiers when given modifiers at plane
  init (bnc#1012628).
- drm/nouveau: Stop using drm_crtc_force_disable (bnc#1012628).
- x86/build: Specify elf_i386 linker emulation explicitly for
  i386 objects (bnc#1012628).
- selinux: do not override context on context mounts
  (bnc#1012628).
- brcmfmac: Use firmware_request_nowarn for the clm_blob
  (bnc#1012628).
- wlcore: Fix memory leak in case wl12xx_fetch_firmware failure
  (bnc#1012628).
- x86/build: Mark per-CPU symbols as absolute explicitly for LLD
  (bnc#1012628).
- drm/fb-helper: fix leaks in error path of
  drm_fb_helper_fbdev_setup (bnc#1012628).
- clk: meson: clean-up clock registration (bnc#1012628).
- ARM: shmobile: Fix R-Car Gen2 regulator quirk (bnc#1012628).
- clk: rockchip: fix frac settings of GPLL clock for rk3328
  (bnc#1012628).
- dmaengine: tegra: avoid overflow of byte tracking (bnc#1012628).
- staging: iio: adt7316: fix dac_bits assignment (bnc#1012628).
- Input: soc_button_array - fix mapping of the 5th GPIO in a
  PNP0C40 device (bnc#1012628).
- ASoC: simple-card-utils: check "reg" property on
  asoc_simple_card_get_dai_id() (bnc#1012628).
- drm: Reorder set_property_atomic to avoid returning with an
  active ww_ctx (bnc#1012628).
- drm/dp/mst: Configure no_stop_bit correctly for remote i2c xfers
  (bnc#1012628).
- net: stmmac: Avoid one more sometimes uninitialized Clang
  warning (bnc#1012628).
- appletalk: Fix compile regression (bnc#1012628).
- gpio: of: Restrict enable-gpio quirk to regulator-gpio
  (bnc#1012628).
- ACPI / video: Extend chassis-type detection with a "Lunch Box"
  check (bnc#1012628).
- bcache: fix potential div-zero error of
  writeback_rate_p_term_inverse (bnc#1012628).
- kbuild: add workaround for Debian make-kpkg (bnc#1012628).
- kbuild: skip sub-make for in-tree build with GNU Make 4.x
  (bnc#1012628).
- commit 8f18342
* Thu Apr  4 2019 jslaby@suse.cz
- Linux 5.0.6 (bnc#1012628).
- mt76x02u: use usb_bulk_msg to upload firmware (bnc#1012628).
- bpf: do not restore dst_reg when cur_state is freed
  (bnc#1012628).
- KVM: x86: update %%rip after emulating IO (bnc#1012628).
- KVM: x86: Emulate MSR_IA32_ARCH_CAPABILITIES on AMD hosts
  (bnc#1012628).
- KVM: Reject device ioctls from processes other than the VM's
  creator (bnc#1012628).
- x86/smp: Enforce CONFIG_HOTPLUG_CPU when SMP=y (bnc#1012628).
- cpu/hotplug: Prevent crash when CPU bringup fails on
  CONFIG_HOTPLUG_CPU=n (bnc#1012628).
- watchdog: Respect watchdog cpumask on CPU hotplug (bnc#1012628).
- powerpc/pseries/mce: Fix misleading print for TLB mutlihit
  (bnc#1012628).
- powerpc/64: Fix memcmp reading past the end of src/dest
  (bnc#1012628).
- powerpc/pseries/energy: Use OF accessor functions to read
  ibm,drc-indexes (bnc#1012628).
- objtool: Query pkg-config for libelf location (bnc#1012628).
- perf intel-pt: Fix TSC slip (bnc#1012628).
- perf pmu: Fix parser error for uncore event alias (bnc#1012628).
- mm/migrate.c: add missing flush_dcache_page for non-mapped
  page migrate (bnc#1012628).
- mm/page_isolation.c: fix a wrong flag in
  set_migratetype_isolate() (bnc#1012628).
- mm/memory_hotplug.c: fix notification in offline error path
  (bnc#1012628).
- mm/debug.c: fix __dump_page when mapping->host is not set
  (bnc#1012628).
- mm: mempolicy: make mbind() return -EIO when MPOL_MF_STRICT
  is specified (bnc#1012628).
- iommu/io-pgtable-arm-v7s: request DMA32 memory, and improve
  debugging (bnc#1012628).
- mm: add support for kmem caches in DMA32 zone (bnc#1012628).
- mm/hotplug: fix offline undo_isolate_page_range() (bnc#1012628).
- usb: typec: Fix unchecked return value (bnc#1012628).
- usb: typec: tcpm: Try PD-2.0 if sink does not respond to 3.0
  source-caps (bnc#1012628).
- usb: cdc-acm: fix race during wakeup blocking TX traffic
  (bnc#1012628).
- xhci: Don't let USB3 ports stuck in polling state prevent
  suspend (bnc#1012628).
- usb: xhci: dbc: Don't free all memory with spinlock held
  (bnc#1012628).
- xhci: Fix port resume done detection for SS ports with LPM
  enabled (bnc#1012628).
- usb: host: xhci-rcar: Add XHCI_TRUST_TX_LENGTH quirk
  (bnc#1012628).
- mm/memory.c: fix modifying of page protection by insert_pfn()
  (bnc#1012628).
- usb: common: Consider only available nodes for dr_mode
  (bnc#1012628).
- USB: gadget: f_hid: fix deadlock in f_hidg_write()
  (bnc#1012628).
- usb: mtu3: fix EXTCON dependency (bnc#1012628).
- phy: sun4i-usb: Support set_mode to USB_HOST for non-OTG PHYs
  (bnc#1012628).
- gpio: adnp: Fix testing wrong value in adnp_gpio_direction_input
  (bnc#1012628).
- gpio: exar: add a check for the return value of ida_simple_get
  fails (bnc#1012628).
- drm/i915/icl: Fix the TRANS_DDI_FUNC_CTL2 bitfield macro
  (bnc#1012628).
- drm/i915/gvt: Fix MI_FLUSH_DW parsing with correct index check
  (bnc#1012628).
- drm/i915: Mark AML 0x87CA as ULX (bnc#1012628).
- drm/vkms: fix use-after-free when drm_gem_handle_create()
  fails (bnc#1012628).
- drm/vgem: fix use-after-free when drm_gem_handle_create()
  fails (bnc#1012628).
- cpufreq: scpi: Fix use after free (bnc#1012628).
- cpufreq: intel_pstate: Also use CPPC nominal_perf for
  base_frequency (bnc#1012628).
- blk-mq: fix sbitmap ws_active for shared tags (bnc#1012628).
- drivers/block/zram/zram_drv.c: fix idle/writeback string compare
  (bnc#1012628).
- fs/proc/proc_sysctl.c: fix NULL pointer dereference in put_links
  (bnc#1012628).
- Disable kgdboc failed by echo space to
  /sys/module/kgdboc/parameters/kgdboc (bnc#1012628).
- ACPI / CPPC: Fix guaranteed performance handling (bnc#1012628).
- USB: serial: option: add Olicard 600 (bnc#1012628).
- USB: serial: option: add support for Quectel EM12 (bnc#1012628).
- USB: serial: option: set driver_info for SIM5218 and compatibles
  (bnc#1012628).
- USB: serial: mos7720: fix mos_parport refcount imbalance on
  error path (bnc#1012628).
- USB: serial: ftdi_sio: add additional NovaTech products
  (bnc#1012628).
- USB: serial: cp210x: add new device id (bnc#1012628).
- serial: sh-sci: Fix setting SCSCR_TIE while transferring data
  (bnc#1012628).
- serial: mvebu-uart: Fix to avoid a potential NULL pointer
  dereference (bnc#1012628).
- serial: max310x: Fix to avoid potential NULL pointer dereference
  (bnc#1012628).
- staging: erofs: keep corrupted fs from crashing kernel in
  erofs_readdir() (bnc#1012628).
- staging: erofs: fix error handling when failed to read
  compresssed data (bnc#1012628).
- staging: erofs: fix to handle error path of erofs_vmap()
  (bnc#1012628).
- staging: vt6655: Fix interrupt race condition on device start up
  (bnc#1012628).
- staging: vt6655: Remove vif check from vnt_interrupt
  (bnc#1012628).
- staging: speakup_soft: Fix alternate speech with other synths
  (bnc#1012628).
- staging: olpc_dcon_xo_1: add missing 'const' qualifier
  (bnc#1012628).
- staging: comedi: ni_mio_common: Fix divide-by-zero for DIO
  cmdtest (bnc#1012628).
- tty: serial: qcom_geni_serial: Initialize baud in
  qcom_geni_console_setup (bnc#1012628).
- tty: atmel_serial: fix a potential NULL pointer dereference
  (bnc#1012628).
- tty: mxs-auart: fix a potential NULL pointer dereference
  (bnc#1012628).
- tty/serial: atmel: RS485 HD w/DMA: enable RX after TX is stopped
  (bnc#1012628).
- tty/serial: atmel: Add is_half_duplex helper (bnc#1012628).
- drm/rockchip: vop: reset scale mode when win is disabled
  (bnc#1012628).
- scsi: zfcp: fix scsi_eh host reset with port_forced ERP for
  non-NPIV FCP devices (bnc#1012628).
- scsi: zfcp: fix rport unblock if deleted SCSI devices on
  Scsi_Host (bnc#1012628).
- scsi: sd: Quiesce warning if device does not report optimal
  I/O size (bnc#1012628).
- scsi: sd: Fix a race between closing an sd device and sd I/O
  (bnc#1012628).
- ocfs2: fix inode bh swapping mixup in ocfs2_reflink_inodes_lock
  (bnc#1012628).
- fs/open.c: allow opening only regular files during execve()
  (bnc#1012628).
- kbuild: modversions: Fix relative CRC byte order interpretation
  (bnc#1012628).
- ALSA: hda/realtek - Fix speakers on Acer Predator Helios 500
  Ryzen laptops (bnc#1012628).
- ALSA: hda/realtek: Enable headset MIC of ASUS X430UN and X512DK
  with ALC256 (bnc#1012628).
- ALSA: hda/realtek: Enable headset mic of ASUS P5440FF with
  ALC256 (bnc#1012628).
- ALSA: hda/realtek: Enable ASUS X441MB and X705FD headset MIC
  with ALC256 (bnc#1012628).
- ALSA: hda/realtek - Add support for Acer Aspire E5-523G/ES1-432
  headset mic (bnc#1012628).
- ALSA: hda/realtek: Enable headset MIC of Acer Aspire Z24-890
  with ALC286 (bnc#1012628).
- ALSA: hda/realtek: Enable headset MIC of Acer AIO with ALC286
  (bnc#1012628).
- ALSA: hda/realtek - Add support headset mode for New DELL WYSE
  NB (bnc#1012628).
- ALSA: hda/realtek - Add support headset mode for DELL WYSE AIO
  (bnc#1012628).
- ALSA: hda/realtek: merge alc_fixup_headset_jack to
  alc295_fixup_chromebook (bnc#1012628).
- ALSA: hda/realtek - Fixed Headset Mic JD not stable
  (bnc#1012628).
- ALSA: pcm: Don't suspend stream in unrecoverable PCM state
  (bnc#1012628).
- ALSA: pcm: Fix possible OOB access in PCM oss plugins
  (bnc#1012628).
- ALSA: seq: oss: Fix Spectre v1 vulnerability (bnc#1012628).
- ALSA: rawmidi: Fix potential Spectre v1 vulnerability
  (bnc#1012628).
- net: dsa: qca8k: remove leftover phy accessors (bnc#1012628).
- NFSv4.1 don't free interrupted slot on open (bnc#1012628).
- NFS: fix mount/umount race in nlmclnt (bnc#1012628).
- NFS: Fix nfs4_lock_state refcounting in
  nfs4_alloc_{lock,unlock}data() (bnc#1012628).
- vfio: ccw: only free cp on final interrupt (bnc#1012628).
- powerpc: bpf: Fix generation of load/store DW instructions
  (bnc#1012628).
- ARM: imx6q: cpuidle: fix bug that CPU might not wake up at
  expected time (bnc#1012628).
- tracing: initialize variable in create_dyn_event()
  (bnc#1012628).
- locks: wake any locks blocked on request before deadlock check
  (bnc#1012628).
- Btrfs: fix assertion failure on fsync with NO_HOLES enabled
  (bnc#1012628).
- btrfs: Avoid possible qgroup_rsv_size overflow in
  btrfs_calculate_inode_block_rsv_size (bnc#1012628).
- btrfs: Fix bound checking in qgroup_trace_new_subtree_blocks
  (bnc#1012628).
- btrfs: raid56: properly unmap parity page in
  finish_parity_scrub() (bnc#1012628).
- btrfs: don't report readahead errors and don't update statistics
  (bnc#1012628).
- btrfs: remove WARN_ON in log_dir_items (bnc#1012628).
- Btrfs: fix incorrect file size after shrinking truncate and
  fsync (bnc#1012628).
- powerpc/fsl: Fix the flush of branch predictor (bnc#1012628).
- tun: add a missing rcu_read_unlock() in error path
  (bnc#1012628).
- ila: Fix rhashtable walker list corruption (bnc#1012628).
- r8169: fix cable re-plugging issue (bnc#1012628).
- net: phy: don't clear BMCR in genphy_soft_reset (bnc#1012628).
- net: mii: Fix PAUSE cap advertisement from
  linkmode_adv_to_lcl_adv_t() helper (bnc#1012628).
- net: dsa: mv88e6xxx: fix few issues in mv88e6390x_port_set_cmode
  (bnc#1012628).
- thunderx: eliminate extra calls to put_page() for pages held
  for recycling (bnc#1012628).
- thunderx: enable page recycling for non-XDP case (bnc#1012628).
- vxlan: Don't call gro_cells_destroy() before device is
  unregistered (bnc#1012628).
- vrf: prevent adding upper devices (bnc#1012628).
- tun: properly test for IFF_UP (bnc#1012628).
- tipc: fix cancellation of topology subscriptions (bnc#1012628).
- tipc: change to check tipc_own_id to return in tipc_net_stop
  (bnc#1012628).
- tipc: allow service ranges to be connect()'ed on RDM/DGRAM
  (bnc#1012628).
- tcp: do not use ipv6 header for ipv4 flow (bnc#1012628).
- sctp: use memdup_user instead of vmemdup_user (bnc#1012628).
- sctp: get sctphdr by offset in sctp_compute_cksum (bnc#1012628).
- rhashtable: Still do rehash when we get EEXIST (bnc#1012628).
- packets: Always register packet sk in the same order
  (bnc#1012628).
- net: usb: aqc111: Extend HWID table by QNAP device
  (bnc#1012628).
- net-sysfs: call dev_hold if kobject_init_and_add success
  (bnc#1012628).
- net: stmmac: fix memory corruption with large MTUs
  (bnc#1012628).
- net: rose: fix a possible stack overflow (bnc#1012628).
- net: phy: meson-gxl: fix interrupt support (bnc#1012628).
- net/packet: Set __GFP_NOWARN upon allocation in alloc_pg_vec
  (bnc#1012628).
- net: datagram: fix unbounded loop in __skb_try_recv_datagram()
  (bnc#1012628).
- net: aquantia: fix rx checksum offload for UDP/TCP over IPv6
  (bnc#1012628).
- mISDN: hfcpci: Test both vendor & device ID for Digium HFC4S
  (bnc#1012628).
- mac8390: Fix mmio access size probe (bnc#1012628).
- ipv6: make ip6_create_rt_rcu return ip6_null_entry instead of
  NULL (bnc#1012628).
- gtp: change NET_UDP_TUNNEL dependency to select (bnc#1012628).
- genetlink: Fix a memory leak on error path (bnc#1012628).
- dccp: do not use ipv6 header for ipv4 flow (bnc#1012628).
- netfilter: nf_tables: fix set double-free in abort path
  (bnc#1012628).
- Bluetooth: Verify that l2cap_get_conf_opt provides large enough
  buffer (bnc#1012628).
- Bluetooth: Check L2CAP option sizes returned from
  l2cap_get_conf_opt (bnc#1012628).
- commit dff56e4
* Mon Apr  1 2019 tiwai@suse.de
- efifb: Omit memory map check on legacy boot (bsc#1127339).
- commit 8a60576
* Mon Apr  1 2019 mkubecek@suse.cz
- Update to 5.1-rc3
- Eliminated 1 patch
- Config changes:
  - SECURITY_DEFAULT_* are back
  - enable CONFIG_OF in i386/pae and copy dependent options from default
- commit 7474ec2
* Sun Mar 31 2019 tiwai@suse.de
- Revert "drm/i915/fbdev: Actually configure untiled displays"
  (bsc#1129027, bsc#1131048).
- commit 591a6df
* Thu Mar 28 2019 yousaf.kaukab@suse.com
- config: arm64: enable CPPC support
- commit 1a52e49
* Thu Mar 28 2019 yousaf.kaukab@suse.com
- config: arm64: enable CPPC support
- commit c97748e
* Wed Mar 27 2019 jslaby@suse.cz
- Linux 5.0.5 (bnc#1012628).
- ALSA: hda - Enforces runtime_resume after S3 and S4 for each
  codec (bnc#1012628).
- ALSA: hda - Record the current power state before suspend/resume
  calls (bnc#1012628).
- locking/lockdep: Add debug_locks check in __lock_downgrade()
  (bnc#1012628).
- x86/unwind: Add hardcoded ORC entry for NULL (bnc#1012628).
- x86/unwind: Handle NULL pointer calls better in frame unwinder
  (bnc#1012628).
- loop: access lo_backing_file only when the loop device is
  Lo_bound (bnc#1012628).
- netfilter: ebtables: remove BUGPRINT messages (bnc#1012628).
- aio: simplify - and fix - fget/fput for io_submit()
  (bnc#1012628).
- f2fs: fix to avoid deadlock of atomic file operations
  (bnc#1012628).
- RDMA/cma: Rollback source IP address if failing to acquire
  device (bnc#1012628).
- drm/vkms: Fix flush_work() without INIT_WORK() (bnc#1012628).
- Bluetooth: hci_ldisc: Postpone HCI_UART_PROTO_READY bit set
  in hci_uart_set_proto() (bnc#1012628).
- Bluetooth: hci_ldisc: Initialize hci_dev before open()
  (bnc#1012628).
- Bluetooth: Fix decrementing reference count twice in releasing
  socket (bnc#1012628).
- Bluetooth: hci_uart: Check if socket buffer is ERR_PTR in
  h4_recv_buf() (bnc#1012628).
- media: v4l2-ctrls.c/uvc: zero v4l2_event (bnc#1012628).
- ext4: brelse all indirect buffer in ext4_ind_remove_space()
  (bnc#1012628).
- ext4: fix data corruption caused by unaligned direct AIO
  (bnc#1012628).
- ext4: fix NULL pointer dereference while journal is aborted
  (bnc#1012628).
- ALSA: ac97: Fix of-node refcount unbalance (bnc#1012628).
- ALSA: hda - Don't trigger jackpoll_work in azx_resume
  (bnc#1012628).
- SMB3: Fix SMB3.1.1 guest mounts to Samba (bnc#1012628).
- clocksource/drivers/riscv: Fix clocksource mask (bnc#1012628).
- irqchip/gic-v3-its: Fix comparison logic in lpi_range_cmp
  (bnc#1012628).
- objtool: Move objtool_file struct off the stack (bnc#1012628).
- perf probe: Fix getting the kernel map (bnc#1012628).
- cifs: allow guest mounts to work for smb3.11 (bnc#1012628).
- futex: Ensure that futex address is aligned in
  handle_futex_death() (bnc#1012628).
- scsi: ibmvscsi: Fix empty event pool access during host removal
  (bnc#1012628).
- scsi: ibmvscsi: Protect ibmvscsi_head from concurrent
  modificaiton (bnc#1012628).
- scsi: qla2xxx: Fix FC-AL connection target discovery
  (bnc#1012628).
- scsi: core: Avoid that a kernel warning appears during system
  resume (bnc#1012628).
- net/mlx5: Fix DCT creation bad flow (bnc#1012628).
- powerpc/security: Fix spectre_v2 reporting (bnc#1012628).
- powerpc/vdso64: Fix CLOCK_MONOTONIC inconsistencies across Y2038
  (bnc#1012628).
- MIPS: Fix kernel crash for R6 in jump label branch function
  (bnc#1012628).
- MIPS: Ensure ELF appended dtb is relocated (bnc#1012628).
- mips: loongson64: lemote-2f: Add IRQF_NO_SUSPEND to "cascade"
  irqaction (bnc#1012628).
- udf: Fix crash on IO error during truncate (bnc#1012628).
- libceph: wait for latest osdmap in ceph_monc_blacklist_add()
  (bnc#1012628).
- iommu/iova: Fix tracking of recently failed iova address
  (bnc#1012628).
- iommu/amd: fix sg->dma_address for sg->offset bigger than
  PAGE_SIZE (bnc#1012628).
- drm/vmwgfx: Return 0 when gmrid::get_node runs out of ID's
  (bnc#1012628).
- drm/vmwgfx: Don't double-free the mode stored in par->set_mode
  (bnc#1012628).
- drm/amdgpu: fix invalid use of change_bit (bnc#1012628).
- mmc: renesas_sdhi: limit block count to 16 bit for old revisions
  (bnc#1012628).
- mmc: mxcmmc: "Revert mmc: mxcmmc: handle highmem pages"
  (bnc#1012628).
- mmc: alcor: fix DMA reads (bnc#1012628).
- mmc: pxamci: fix enum type confusion (bnc#1012628).
- ALSA: firewire-motu: use 'version' field of unit directory to
  identify model (bnc#1012628).
- ALSA: hda - add Lenovo IdeaCentre B550 to the
  power_save_blacklist (bnc#1012628).
- commit 0fb0b14
* Tue Mar 26 2019 msuchanek@suse.de
- Revert "Bluetooth: btusb: driver to enable the usb-wakeup
  feature" (boo#1130448).
  System still wakes up when connected BT device is powered off.
- Revert "Bluetooth: btusb: driver to enable the usb-wakeup
  feature" (boo#1130448).
- commit b043955
* Tue Mar 26 2019 mkubecek@suse.cz
- Revert "parport: daisy: use new parport device model"
  (http://lkml.kernel.org/r/20190313064557.GA14531@unicorn.suse.cz).
- Delete
  patches.suse/parport-daisy-do-not-try-to-load-lowlevel-driver.patch.
- commit 7da01f5
* Tue Mar 26 2019 jbeulich@suse.com
- patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch:
  Fix re-basing mistake - IBRS enabling should not be skipped for PV Xen.
- commit 177c0f8
* Tue Mar 26 2019 mkubecek@suse.cz
- parport: daisy: do not try to load lowlevel driver
  (http://lkml.kernel.org/r/20190313064557.GA14531@unicorn.suse.cz).
- commit 4f8876e
* Mon Mar 25 2019 jeffm@suse.com
- btrfs: honor path->skip_locking in backref code (bsc#1099312).
- commit 76ff396
* Mon Mar 25 2019 mkubecek@suse.cz
- Update to 5.1-rc2
- New config options:
  - CHARLCD_BL_FLASH=y
  - PARPORT_PANEL=m (renamed from PANEL)
  - PANEL=m
- commit ede8a59
* Sun Mar 24 2019 jslaby@suse.cz
- Linux 5.0.4 (bnc#1012628).
- SUNRPC: Respect RPC call timeouts when retrying transmission
  (bnc#1012628).
- SUNRPC: Fix up RPC back channel transmission (bnc#1012628).
- SUNRPC: Prevent thundering herd when the socket is not connected
  (bnc#1012628).
- s390/setup: fix boot crash for machine without EDAT-1
  (bnc#1012628).
- net: dsa: lantiq_gswip: fix OF child-node lookups (bnc#1012628).
- net: dsa: lantiq_gswip: fix use-after-free on failed probe
  (bnc#1012628).
- KVM: nVMX: Check a single byte for VMCS "launched" in nested
  early checks (bnc#1012628).
- KVM: nVMX: Ignore limit checks on VMX instructions using flat
  segments (bnc#1012628).
- KVM: nVMX: Apply addr size mask to effective address for VMX
  instructions (bnc#1012628).
- KVM: nVMX: Sign extend displacements of VMX instr's mem operands
  (bnc#1012628).
- KVM: x86/mmu: Do not cache MMIO accesses while memslots are
  in flux (bnc#1012628).
- KVM: x86/mmu: Detect MMIO generation wrap in any address space
  (bnc#1012628).
- KVM: VMX: Zero out *all* general purpose registers after VM-Exit
  (bnc#1012628).
- KVM: VMX: Compare only a single byte for VMCS' "launched"
  in vCPU-run (bnc#1012628).
- KVM: Call kvm_arch_memslots_updated() before updating memslots
  (bnc#1012628).
- drm/amd/display: don't call dm_pp_ function from an fpu block
  (bnc#1012628).
- drm/amd/powerplay: correct power reading on fiji (bnc#1012628).
- drm/radeon/evergreen_cs: fix missing break in switch statement
  (bnc#1012628).
- drm/fb-helper: generic: Fix drm_fbdev_client_restore()
  (bnc#1012628).
- media: imx: csi: Stop upstream before disabling IDMA channel
  (bnc#1012628).
- media: imx: csi: Disable CSI immediately after last EOF
  (bnc#1012628).
- media: imx-csi: Input connections to CSI should be optional
  (bnc#1012628).
- media: vimc: Add vimc-streamer for stream control (bnc#1012628).
- media: uvcvideo: Avoid NULL pointer dereference at the end of
  streaming (bnc#1012628).
- media: sun6i: Fix CSI regmap's max_register (bnc#1012628).
- media: lgdt330x: fix lock status reporting (bnc#1012628).
- media: imx: prpencvf: Stop upstream before disabling IDMA
  channel (bnc#1012628).
- rcu: Do RCU GP kthread self-wakeup from softirq and interrupt
  (bnc#1012628).
- tpm: Unify the send callback behaviour (bnc#1012628).
- tpm/tpm_crb: Avoid unaligned reads in crb_recv() (bnc#1012628).
- x86/ftrace: Fix warning and considate ftrace_jmp_replace()
  and ftrace_call_replace() (bnc#1012628).
- x86/kvmclock: set offset for kvm unstable clock (bnc#1012628).
- md: Fix failed allocation of md_register_thread (bnc#1012628).
- perf intel-pt: Fix divide by zero when TSC is not available
  (bnc#1012628).
- perf/x86/intel/uncore: Fix client IMC events return huge result
  (bnc#1012628).
- perf intel-pt: Fix overlap calculation for padding
  (bnc#1012628).
- perf auxtrace: Define auxtrace record alignment (bnc#1012628).
- perf tools: Fix split_kallsyms_for_kcore() for trampoline
  symbols (bnc#1012628).
- perf intel-pt: Fix CYC timestamp calculation after OVF
  (bnc#1012628).
- x86/unwind/orc: Fix ORC unwind table alignment (bnc#1012628).
- vt: perform safe console erase in the right order (bnc#1012628).
- stable-kernel-rules.rst: add link to networking patch queue
  (bnc#1012628).
- bcache: use (REQ_META|REQ_PRIO) to indicate bio for metadata
  (bnc#1012628).
- bcache: treat stale && dirty keys as bad keys (bnc#1012628).
- bcache: never writeback a discard operation (bnc#1012628).
- PM / OPP: Update performance state when freq == old_freq
  (bnc#1012628).
- PM / wakeup: Rework wakeup source timer cancellation
  (bnc#1012628).
- svcrpc: fix UDP on servers with lots of threads (bnc#1012628).
- NFSv4.1: Reinitialise sequence results before retransmitting
  a request (bnc#1012628).
- nfsd: fix wrong check in write_v4_end_grace() (bnc#1012628).
- nfsd: fix memory corruption caused by readdir (bnc#1012628).
- nfsd: fix performance-limiting session calculation
  (bnc#1012628).
- NFS: Don't recoalesce on error in nfs_pageio_complete_mirror()
  (bnc#1012628).
- NFS: Fix an I/O request leakage in nfs_do_recoalesce
  (bnc#1012628).
- NFS: Fix I/O request leakages (bnc#1012628).
- cpuidle: governor: Add new governors to cpuidle_governors again
  (bnc#1012628).
- cpcap-charger: generate events for userspace (bnc#1012628).
- mfd: sm501: Fix potential NULL pointer dereference
  (bnc#1012628).
- media: cx25840: mark pad sig_types to fix cx231xx init
  (bnc#1012628).
- dm integrity: limit the rate of error messages (bnc#1012628).
- dm: fix to_sector() for 32bit (bnc#1012628).
- ipmi_si: fix use-after-free of resource->name (bnc#1012628).
- ipmi_si: Fix crash when using hard-coded device (bnc#1012628).
- Revert "KVM/MMU: Flush tlb directly in the kvm_zap_gfn_range()"
  (bnc#1012628).
- arm64: KVM: Fix architecturally invalid reset value for
  FPEXC32_EL2 (bnc#1012628).
- arm64: debug: Ensure debug handlers check triggering exception
  level (bnc#1012628).
- arm64: debug: Don't propagate UNKNOWN FAR into si_code for
  debug signals (bnc#1012628).
- arm64: Fix HCR.TGE status for NMI contexts (bnc#1012628).
- ARM: s3c24xx: Fix boolean expressions in osiris_dvs_notify
  (bnc#1012628).
- powerpc/traps: Fix the message printed when stack overflows
  (bnc#1012628).
- powerpc/traps: fix recoverability of machine check handling
  on book3s/32 (bnc#1012628).
- powerpc/smp: Fix NMI IPI xmon timeout (bnc#1012628).
- powerpc/smp: Fix NMI IPI timeout (bnc#1012628).
- powerpc/hugetlb: Don't do runtime allocation of 16G pages in
  LPAR configuration (bnc#1012628).
- powerpc/ptrace: Simplify vr_get/set() to avoid GCC warning
  (bnc#1012628).
- powerpc: Fix 32-bit KVM-PR lockup and host crash with MacOS
  guest (bnc#1012628).
- powerpc/64s/hash: Fix assert_slb_presence() use of the
  slbfee. instruction (bnc#1012628).
- powerpc/powernv: Don't reprogram SLW image on every KVM guest
  entry/exit (bnc#1012628).
- powerpc/kvm: Save and restore host AMR/IAMR/UAMOR (bnc#1012628).
- powerpc/83xx: Also save/restore SPRG4-7 during suspend
  (bnc#1012628).
- powerpc/powernv: Make opal log only readable by root
  (bnc#1012628).
- powerpc/wii: properly disable use of BATs when requested
  (bnc#1012628).
- powerpc/32: Clear on-stack exception marker upon exception
  return (bnc#1012628).
- security/selinux: fix SECURITY_LSM_NATIVE_LABELS on reused
  superblock (bnc#1012628).
- selinux: add the missing walk_size + len check in
  selinux_sctp_bind_connect (bnc#1012628).
- jbd2: fix compile warning when using JBUFFER_TRACE
  (bnc#1012628).
- jbd2: clear dirty flag when revoking a buffer from an older
  transaction (bnc#1012628).
- serial: 8250_pci: Have ACCES cards that use the four
  port Pericom PI7C9X7954 chip use the pci_pericom_setup()
  (bnc#1012628).
- serial: 8250_pci: Fix number of ports for ACCES serial cards
  (bnc#1012628).
- serial: 8250_of: assume reg-shift of 2 for mrvl,mmp-uart
  (bnc#1012628).
- serial: uartps: Fix stuck ISR if RX disabled with non-empty FIFO
  (bnc#1012628).
- dmaengine: usb-dmac: Make DMAC system sleep callbacks explicit
  (bnc#1012628).
- usb: typec: tps6598x: handle block writes separately with
  plain-I2C adapters (bnc#1012628).
- usb: chipidea: tegra: Fix missed ci_hdrc_remove_device()
  (bnc#1012628).
- clk: ingenic: Fix doc of ingenic_cgu_div_info (bnc#1012628).
- clk: ingenic: Fix round_rate misbehaving with non-integer
  dividers (bnc#1012628).
- clk: samsung: exynos5: Fix kfree() of const memory on setting
  driver_override (bnc#1012628).
- clk: samsung: exynos5: Fix possible NULL pointer exception on
  platform_device_alloc() failure (bnc#1012628).
- clk: clk-twl6040: Fix imprecise external abort for pdmclk
  (bnc#1012628).
- clk: uniphier: Fix update register for CPU-gear (bnc#1012628).
- ext2: Fix underflow in ext2_max_size() (bnc#1012628).
- cxl: Wrap iterations over afu slices inside 'afu_list_lock'
  (bnc#1012628).
- IB/rdmavt: Fix concurrency panics in QP post_send and modify
  to error (bnc#1012628).
- IB/rdmavt: Fix loopback send with invalidate ordering
  (bnc#1012628).
- IB/hfi1: Close race condition on user context disable and close
  (bnc#1012628).
- PCI: pci-bridge-emul: Extend pci_bridge_emul_init() with flags
  (bnc#1012628).
- PCI: pci-bridge-emul: Create per-bridge copy of register
  behavior (bnc#1012628).
- PCI: pciehp: Disable Data Link Layer State Changed event on
  suspend (bnc#1012628).
- PCI: dwc: skip MSI init if MSIs have been explicitly disabled
  (bnc#1012628).
- PCI: qcom: Don't deassert reset GPIO during probe (bnc#1012628).
- PCI/DPC: Fix print AER status in DPC event handling
  (bnc#1012628).
- PCI/ASPM: Use LTR if already enabled by platform (bnc#1012628).
- swiotlb: Add is_swiotlb_active() function (bnc#1012628).
- swiotlb: Introduce swiotlb_max_mapping_size() (bnc#1012628).
- dma: Introduce dma_max_mapping_size() (bnc#1012628).
- ext4: fix crash during online resizing (bnc#1012628).
- ext4: add mask of ext4 flags to swap (bnc#1012628).
- ext4: update quota information while swapping boot loader inode
  (bnc#1012628).
- gpio: pca953x: Fix dereference of irq data in shutdown
  (bnc#1012628).
- media: i2c: ov5640: Fix post-reset delay (bnc#1012628).
- i2c: tegra: update maximum transfer size (bnc#1012628).
- i2c: tegra: fix maximum transfer size (bnc#1012628).
- parport_pc: fix find_superio io compare code, should use equal
  test (bnc#1012628).
- intel_th: Don't reference unassigned outputs (bnc#1012628).
- device property: Fix the length used in PROPERTY_ENTRY_STRING()
  (bnc#1012628).
- nvmem: core: don't check the return value of notifier chain call
  (bnc#1012628).
- kernel/sysctl.c: add missing range check in
  do_proc_dointvec_minmax_conv (bnc#1012628).
- mm/memory.c: do_fault: avoid usage of stale vm_area_struct
  (bnc#1012628).
- mm/vmalloc: fix size check for remap_vmalloc_range_partial()
  (bnc#1012628).
- mm: hwpoison: fix thp split handing in
  soft_offline_in_use_page() (bnc#1012628).
- ext4: cleanup pagecache before swap i_data (bnc#1012628).
- ext4: fix check of inode in swap_inode_boot_loader
  (bnc#1012628).
- cpufreq: pxa2xx: remove incorrect __init annotation
  (bnc#1012628).
- cpufreq: tegra124: add missing of_node_put() (bnc#1012628).
- cpufreq: kryo: Release OPP tables on module removal
  (bnc#1012628).
- x86/kprobes: Prohibit probing on optprobe template code
  (bnc#1012628).
- irqchip/brcmstb-l2: Use _irqsave locking variants in
  non-interrupt code (bnc#1012628).
- irqchip/gic-v3-its: Avoid parsing _indirect_ twice for Device
  table (bnc#1012628).
- libertas_tf: don't set URB_ZERO_PACKET on IN USB transfer
  (bnc#1012628).
- soc: qcom: rpmh: Avoid accessing freed memory from batch API
  (bnc#1012628).
- Btrfs: fix deadlock between clone/dedupe and rename
  (bnc#1012628).
- Btrfs: fix corruption reading shared and compressed extents
  after hole punching (bnc#1012628).
- btrfs: init csum_list before possible free (bnc#1012628).
- btrfs: ensure that a DUP or RAID1 block group has exactly two
  stripes (bnc#1012628).
- btrfs: drop the lock on error in btrfs_dev_replace_cancel
  (bnc#1012628).
- btrfs: scrub: fix circular locking dependency warning
  (bnc#1012628).
- Btrfs: setup a nofs context for memory allocation at
  __btrfs_set_acl (bnc#1012628).
- Btrfs: setup a nofs context for memory allocation at
  btrfs_create_tree() (bnc#1012628).
- m68k: Add -ffreestanding to CFLAGS (bnc#1012628).
- ovl: Do not lose security.capability xattr over metadata file
  copy-up (bnc#1012628).
- ovl: During copy up, first copy up data and then xattrs
  (bnc#1012628).
- splice: don't merge into linked buffers (bnc#1012628).
- fs/devpts: always delete dcache dentry-s in dput()
  (bnc#1012628).
- scsi: qla2xxx: Use complete switch scan for RSCN events
  (bnc#1012628).
- scsi: qla2xxx: Avoid PCI IRQ affinity mapping when multiqueue
  is not supported (bnc#1012628).
- scsi: qla2xxx: Fix LUN discovery if loop id is not assigned
  yet by firmware (bnc#1012628).
- scsi: target/iscsi: Avoid iscsit_release_commands_from_conn()
  deadlock (bnc#1012628).
- scsi: sd: Optimal I/O size should be a multiple of physical
  block size (bnc#1012628).
- scsi: aacraid: Fix performance issue on logical drives
  (bnc#1012628).
- scsi: virtio_scsi: don't send sc payload with tmfs
  (bnc#1012628).
- s390/virtio: handle find on invalid queue gracefully
  (bnc#1012628).
- s390/setup: fix early warning messages (bnc#1012628).
- s390: vfio_ap: link the vfio_ap devices to the vfio_ap bus
  subsystem (bnc#1012628).
- clocksource/drivers/arch_timer: Workaround for Allwinner A64
  timer instability (bnc#1012628).
- Update config files.
  Set SUN50I_ERRATUM_UNKNOWN1=y to stay aligned with the master branch.
- clocksource/drivers/exynos_mct: Clear timer interrupt when
  shutdown (bnc#1012628).
- clocksource/drivers/exynos_mct: Move one-shot check from tick
  clear to ISR (bnc#1012628).
- mt76: fix corrupted software generated tx CCMP PN (bnc#1012628).
- regulator: s2mpa01: Fix step values for some LDOs (bnc#1012628).
- regulator: max77620: Initialize values for DT properties
  (bnc#1012628).
- regulator: s2mps11: Fix steps for buck7, buck8 and LDO35
  (bnc#1012628).
- spi: spi-gpio: fix SPI_CS_HIGH capability (bnc#1012628).
- spi: omap2-mcspi: Fix DMA and FIFO event trigger size mismatch
  (bnc#1012628).
- spi: pxa2xx: Setup maximum supported DMA transfer length
  (bnc#1012628).
- spi: ti-qspi: Fix mmap read when more than one CS in use
  (bnc#1012628).
- mmc:fix a bug when max_discard is 0 (bnc#1012628).
- mmc: renesas_sdhi: Fix card initialization failure in high
  speed mode (bnc#1012628).
- mmc: sdhci-esdhc-imx: fix HS400 timing issue (bnc#1012628).
- ACPI / device_sysfs: Avoid OF modalias creation for removed
  device (bnc#1012628).
- xen: fix dom0 boot on huge systems (bnc#1012628).
- vmw_balloon: release lock on error in vmballoon_reset()
  (bnc#1012628).
- tracing/perf: Use strndup_user() instead of buggy open-coded
  version (bnc#1012628).
- tracing: Do not free iter->trace in fail path of
  tracing_open_pipe() (bnc#1012628).
- tracing: Use strncpy instead of memcpy for string keys in hist
  triggers (bnc#1012628).
- smb3: make default i/o size for smb3 mounts larger
  (bnc#1012628).
- CIFS: Fix read after write for files with read caching
  (bnc#1012628).
- CIFS: Do not skip SMB2 message IDs on send failures
  (bnc#1012628).
- CIFS: Do not reset lease state to NONE on lease break
  (bnc#1012628).
- CIFS: Fix leaking locked VFS cache pages in writeback retry
  (bnc#1012628).
- crypto: arm64/aes-ccm - fix bugs in non-NEON fallback routine
  (bnc#1012628).
- crypto: arm64/aes-ccm - fix logical bug in AAD MAC handling
  (bnc#1012628).
- crypto: x86/morus - fix handling chunked inputs and MAY_SLEEP
  (bnc#1012628).
- crypto: x86/aesni-gcm - fix crash on empty plaintext
  (bnc#1012628).
- crypto: x86/aegis - fix handling chunked inputs and MAY_SLEEP
  (bnc#1012628).
- crypto: testmgr - skip crc32c context test for ahash algorithms
  (bnc#1012628).
- crypto: skcipher - set CRYPTO_TFM_NEED_KEY if ->setkey() fails
  (bnc#1012628).
- crypto: pcbc - remove bogus memcpy()s with src == dest
  (bnc#1012628).
- crypto: morus - fix handling chunked inputs (bnc#1012628).
- crypto: hash - set CRYPTO_TFM_NEED_KEY if ->setkey() fails
  (bnc#1012628).
- crypto: arm64/crct10dif - revert to C code for short inputs
  (bnc#1012628).
- crypto: arm64/aes-neonbs - fix returning final keystream block
  (bnc#1012628).
- crypto: arm/crct10dif - revert to C code for short inputs
  (bnc#1012628).
- crypto: aegis - fix handling chunked inputs (bnc#1012628).
- crypto: aead - set CRYPTO_TFM_NEED_KEY if ->setkey() fails
  (bnc#1012628).
- fix cgroup_do_mount() handling of failure exits (bnc#1012628).
- libnvdimm: Fix altmap reservation size calculation
  (bnc#1012628).
- libnvdimm/pmem: Honor force_raw for legacy pmem regions
  (bnc#1012628).
- libnvdimm, pfn: Fix over-trim in trim_pfn_device()
  (bnc#1012628).
- libnvdimm/label: Clear 'updating' flag after label-set update
  (bnc#1012628).
- nfit/ars: Attempt short-ARS even in the no_init_ars case
  (bnc#1012628).
- nfit/ars: Attempt a short-ARS whenever the ARS state is idle
  at boot (bnc#1012628).
- acpi/nfit: Fix bus command validation (bnc#1012628).
- nfit: acpi_nfit_ctl(): Check out_obj->type in the right place
  (bnc#1012628).
- nfit: Fix nfit_intel_shutdown_status() command submission
  (bnc#1012628).
- dax: Flush partial PMDs correctly (bnc#1012628).
- crypto: rockchip - update new iv to device in multiple
  operations (bnc#1012628).
- crypto: rockchip - fix scatterlist nents error (bnc#1012628).
- crypto: ahash - fix another early termination in hash walk
  (bnc#1012628).
- crypto: ofb - fix handling partial blocks and make thread-safe
  (bnc#1012628).
- crypto: cfb - remove bogus memcpy() with src == dest
  (bnc#1012628).
- crypto: cfb - add missing 'chunksize' property (bnc#1012628).
- crypto: ccree - don't copy zero size ciphertext (bnc#1012628).
- crypto: ccree - unmap buffer before copying IV (bnc#1012628).
- crypto: ccree - fix free of unallocated mlli buffer
  (bnc#1012628).
- crypto: caam - fix DMA mapping of stack memory (bnc#1012628).
- crypto: caam - fixed handling of sg list (bnc#1012628).
- crypto: ccree - fix missing break in switch statement
  (bnc#1012628).
- crypto: caam - fix hash context DMA unmap size (bnc#1012628).
- stm class: Fix an endless loop in channel allocation
  (bnc#1012628).
- stm class: Prevent division by zero (bnc#1012628).
- mei: bus: move hw module get/put to probe/release (bnc#1012628).
- mei: hbm: clean the feature flags on link reset (bnc#1012628).
- iio: adc: exynos-adc: Use proper number of channels for
  Exynos4x12 (bnc#1012628).
- iio: adc: exynos-adc: Fix NULL pointer exception on unbind
  (bnc#1012628).
- ASoC: codecs: pcm186x: Fix energysense SLEEP bit (bnc#1012628).
- ASoC: codecs: pcm186x: fix wrong usage of DECLARE_TLV_DB_SCALE()
  (bnc#1012628).
- ASoC: fsl_esai: fix register setting issue in RIGHT_J mode
  (bnc#1012628).
- 9p/net: fix memory leak in p9_client_create (bnc#1012628).
- 9p: use inode->i_lock to protect i_size_write() under 32-bit
  (bnc#1012628).
- commit c52890c
* Fri Mar 22 2019 msuchanek@suse.de
- Do not provide kernel-default-srchash from kernel-default-base.
- commit d6c71ce
* Thu Mar 21 2019 mkubecek@suse.cz
- config: apply recent changes to ARM configs
- CONFIG_PREEMPT_VOLUNTARY=y
- disable CONFIG_IMA_ARCH_POLICY
- enable CONFIG_IMA_APPRAISE_BOOTPARAM
- CONFIG_LSM=""
- commit fd95045
* Wed Mar 20 2019 yousaf.kaukab@suse.com
- config: arm64: Update to v5.1-rc1
- commit 590226b
* Wed Mar 20 2019 msuchanek@suse.de
- rpm/kernel-subpackage-build: handle arm kernel zImage.
- commit 81a63c3
* Wed Mar 20 2019 jslaby@suse.cz
- config: disable IMA_ARCH_POLICY for now
  When IMA_ARCH_POLICY was enabled during the 5.0-rc* stage, IMA causes
  kdump load to fail:
  kexec_file_load failed: Permission denied
  ima: impossible to appraise a kernel image without a file descriptor; try using kexec_file_load syscall.
  We have to fix kexec tooling before enabling IMA for everyone.
  BTW IMA_APPRAISE_BOOTPARAM was disabled by IMA_ARCH_POLICY=y. So
  restore the original state (and functionality).
- commit 3fe0cfc
* Wed Mar 20 2019 yousaf.kaukab@suse.com
- config: armv6hl: Update to v5.1-rc1
  CONFIG_BPFILTER_UMH is disabled due to bsc#1127188
- commit 608f8e5
* Wed Mar 20 2019 tiwai@suse.de
- rpm/kernel-source.changes.old: Really drop old changelogs (bsc#1098995)
- commit 9e463cf
* Tue Mar 19 2019 msuchanek@suse.de
- config: disable BPFILTER_UMH on arm (bsc#1127188).
- commit a705565
* Tue Mar 19 2019 yousaf.kaukab@suse.com
- config: armv7hl: Update to v5.1-rc1
  CONFIG_BPFILTER_UMH is disabled due to bsc#1127188
- commit 0042582
* Tue Mar 19 2019 jslaby@suse.cz
- Linux 5.0.3 (bnc#1012628).
- drm: Block fb changes for async plane updates (bnc#1012628).
- It's wrong to add len to sector_nr in raid10 reshape twice
  (bnc#1012628).
- perf/x86/intel: Make dev_attr_allow_tsx_force_abort static
  (bnc#1012628).
- perf/x86/intel: Fix memory corruption (bnc#1012628).
- ALSA: hda/realtek: Enable headset MIC of Acer TravelMate
  X514-51T with ALC255 (bnc#1012628).
- ALSA: hda/realtek - Reduce click noise on Dell Precision 5820
  headphone (bnc#1012628).
- ALSA: hda/realtek: Enable audio jacks of ASUS UX362FA with
  ALC294 (bnc#1012628).
- ALSA: hda - add more quirks for HP Z2 G4 and HP Z240
  (bnc#1012628).
- ALSA: hda: Extend i915 component bind timeout (bnc#1012628).
- ALSA: firewire-motu: fix construction of PCM frame for capture
  direction (bnc#1012628).
- ALSA: bebob: use more identical mod_alias for Saffire Pro 10
  I/O against Liquid Saffire 56 (bnc#1012628).
- perf/x86: Fixup typo in stub functions (bnc#1012628).
- f2fs: wait on atomic writes to count F2FS_CP_WB_DATA
  (bnc#1012628).
- net: sched: flower: insert new filter to idr after setting
  its mask (bnc#1012628).
- vsock/virtio: fix kernel panic from
  virtio_transport_reset_no_sock (bnc#1012628).
- net: hns3: fix to stop multiple HNS reset due to the AER changes
  (bnc#1012628).
- net: dsa: mv88e6xxx: Set correct interface mode for CPU/DSA
  ports (bnc#1012628).
- net/mlx4_core: Fix qp mtt size calculation (bnc#1012628).
- net/mlx4_core: Fix locking in SRIOV mode when switching between
  events and polling (bnc#1012628).
- net/mlx4_core: Fix reset flow when in command polling mode
  (bnc#1012628).
- vxlan: test dev->flags & IFF_UP before calling
  gro_cells_receive() (bnc#1012628).
- vxlan: Fix GRO cells race condition between receive and link
  delete (bnc#1012628).
- tcp: handle inet_csk_reqsk_queue_add() failures (bnc#1012628).
- tcp: Don't access TCP_SKB_CB before initializing it
  (bnc#1012628).
- tcp: do not report TCP_CM_INQ of 0 for closed connections
  (bnc#1012628).
- sctp: remove sched init from sctp_stream_init (bnc#1012628).
- rxrpc: Fix client call queueing, waiting for channel
  (bnc#1012628).
- route: set the deleted fnhe fnhe_daddr to 0 in ip_del_fnhe to
  fix a race (bnc#1012628).
- ravb: Decrease TxFIFO depth of Q3 and Q2 to one (bnc#1012628).
- pptp: dst_release sk_dst_cache in pptp_sock_destruct
  (bnc#1012628).
- net/x25: reset state in x25_connect() (bnc#1012628).
- net/x25: fix use-after-free in x25_device_event() (bnc#1012628).
- net: sit: fix UBSAN Undefined behaviour in check_6rd
  (bnc#1012628).
- net/hsr: fix possible crash in add_timer() (bnc#1012628).
- net: hsr: fix memory leak in hsr_dev_finalize() (bnc#1012628).
- net: hns3: add dma_rmb() for rx description (bnc#1012628).
- lan743x: Fix TX Stall Issue (bnc#1012628).
- lan743x: Fix RX Kernel Panic (bnc#1012628).
- l2tp: fix infoleak in l2tp_ip6_recvmsg() (bnc#1012628).
- ipv4/route: fail early when inet dev is missing (bnc#1012628).
- gro_cells: make sure device is up in gro_cells_receive()
  (bnc#1012628).
- fou, fou6: avoid uninit-value in gue_err() and gue6_err()
  (bnc#1012628).
- connector: fix unsafe usage of ->real_parent (bnc#1012628).
- commit 843d1cc
* Tue Mar 19 2019 yousaf.kaukab@suse.com
- config: armv6hl: Update to v5.0.2
- commit a2d3030
* Tue Mar 19 2019 yousaf.kaukab@suse.com
- config: armv7hl: Update to v5.0.2
- commit 70aaed6
* Mon Mar 18 2019 mkubecek@suse.cz
- Update to 5.1-rc1
- Eliminated 74 patches (73 stable, 1 other)
- ARM configs need update
- Refresh
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch
  patches.suse/btrfs-fs-super.c-add-new-super-block-devices-super_block_d.patch
  patches.suse/genksyms-add-override-flag.diff
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  patches.suse/readahead-request-tunables.patch
  patches.suse/supported-flag
  patches.suse/vfs-add-super_operations-get_inode_dev
- New config options:
  - General:
  - IO_URING=y
  - PRINTK_CALLER=n
  - File systems:
  - CONFIG_SUNRPC_DISABLE_INSECURE_ENCTYPES=n
  - VALIDATE_FS_PARSER=n
  - Networking:
  - NET_DEVLINK=y
  - XDP_SOCKETS_DIAG=m
  - MT7603E=m
  - TI_CPSW_PHY_SEL=n
  - Power management:
  - CPU_IDLE_GOV_TEO=y
  - DAX:
  - DEV_DAX_KMEM=m
  - DEV_DAX_PMEM_COMPAT=m
  - USB:
  - USB_AUTOSUSPEND_DELAY=2
  - USB_EHCI_FSL=m
  - Graphics:
  - DRM_ETNAVIV=n
  - DRM_NOUVEAU_SVM=n
  - VIDEO_FB_IVTV_FORCE_PAT=n
  - Sound:
  - SND_SOC_CROS_EC_CODEC=m
  - SND_SOC_CS35L36=m
  - SND_SOC_CS4341=m
  - SND_SOC_FSL_MICFIL=n
  - SND_SOC_MAX98373=m
  - SND_SOC_MT6358=n
  - SND_SOC_MTK_BTCVSD=m
  - SND_SOC_RK3328=n
  - SND_SOC_WM8904=n
  - SND_SOC_XILINX_AUDIO_FORMATTER=n
  - SND_SOC_XILINX_SPDIF=n
  - Input:
  - HID_MALTRON=m
  - HID_VIEWSONIC=m
  - TTY:
  - LDISC_AUTOLOAD=y
  - RTC:
  - RTC_DRV_ABEOZ9=m
  - RTC_DRV_RV3028=m
  - RTC_DRV_SD3078=m
  - RTC_DRV_WILCO_EC=m
  - Industrial IO:
  - AD7606_IFACE_PARALLEL=n
  - AD7606_IFACE_SPI=n
  - AD7768_1=n
  - MAX44009=m
  - PMS7003=n
  - SPS30=n
  - TI_DAC7612=n
  - Misc drivers:
  - ALTERA_FREEZE_BRIDGE=m
  - EDAC_I10NM=m
  - EXTCON_PTN5150=m
  - GNSS_MTK_SERIAL=m
  - GPIO_AMD_FCH=m
  - GPIO_TQMX86=m
  - HABANA_AI=m
  - INPUT_MSM_VIBRATOR=n
  - INTEL_MEI_HDCP=m
  - INTERCONNECT=m
  - IR_RCMM_DECODER=m
  - MFD_TQMX86=m
  - MLX_WDT=m
  - SPI_MTK_QUADSPI=m
  - SPI_NXP_FLEXSPI=n
  - SPI_SIFIVE=n
  - WILCO_EC=m
  - WILCO_EC_DEBUGFS=n
  - Virtualization:
  - HYPERV_IOMMU=y
  - Security:
  - LSM=""
  - SECURITY_SAFESETID=n
  - Testing:
  - TEST_LIVEPATCH=n
  - TEST_STACKINIT=n
  - TEST_VMALLOC=n
  - x86:
  - PCENGINES_APU2=m
  - ppc64/ppc64le:
  - NVRAM=m
  - KCOV=n
  - s390x:
  UID16=y
  DMA_FENCE_TRACE=n
  SCSI_GDTH=n
  UDMABUF=y
  - */debug:
  - PRINTK_CALLER=n
- commit b493de0
* Mon Mar 18 2019 msuchanek@suse.de
- Trim build dependencies of sample subpackage spec file (FATE#326579,
  jsc#SLE-4117, jsc#SLE-3853, bsc#1128910).
- commit 2eae420
* Mon Mar 18 2019 jslaby@suse.cz
- cifs: Fix NULL pointer dereference of devname (bnc#1129519).
- commit 018878b
* Sun Mar 17 2019 mkubecek@suse.cz
- Drop stale disabled patches
  As discussed in
  http://mailman.suse.de/mlarch/SuSE/kernel/2019/kernel.2019.02/msg00118.html
  http://mailman.suse.de/mlarch/SuSE/kernel/2019/kernel.2019.03/msg00016.html
  some of our patches have been disabled for quite long and attempts to get
  them reviewed failed. Let's drop them now:
  patches.suse/0036-arm-Add-BTB-invalidation-on-switch_mm-for-Cortex-A9-.patch
  patches.suse/0037-arm-Invalidate-BTB-on-prefetch-abort-outside-of-user.patch
  patches.suse/0038-arm-KVM-Invalidate-BTB-on-guest-exit.patch
  patches.suse/0039-arm-Add-icache-invalidation-on-switch_mm-for-Cortex-.patch
  patches.suse/0040-arm-Invalidate-icache-on-prefetch-abort-outside-of-u.patch
  patches.suse/0041-arm-KVM-Invalidate-icache-on-guest-exit-for-Cortex-A.patch
  patches.suse/binutils2_26.patch
  patches.suse/dm-mpath-accept-failed-paths
  patches.suse/pstore-backend-autoaction
- commit 55d6d1e
* Sun Mar 17 2019 mkubecek@suse.cz
- config: enable RANDOM_TRUST_CPU
  The outcome from mailing list discussion when this config option
  appeared was that it makes more sense to enable it by default and let
  those who do not trust their CPU override it on command line; but then
  I forgot to actually change the value.
- commit 138b5df
* Fri Mar 15 2019 tiwai@suse.de
- Update config files: disable CONFIG_FRAMEBUFFER_CONSOLE_DEFERRED_TAKEOVER (bsc#1127552)
  The deferred fbcon takeover makes little sense with the current openSUSE
  boot setup, and it's harmful (more glitches, etc).  Disable it for now.
- commit 14fa903
* Fri Mar 15 2019 msuchanek@suse.de
- Remove the previous subpackage infrastructure.
  This partially reverts commit 9b3ca32c11854156b2f950ff5e26131377d8445e
  ("Add kernel-subpackage-build.spec (FATE#326579).")
- commit a5ee24e
* Fri Mar 15 2019 msuchanek@suse.de
- Add sample kernel-default-base spec file (FATE#326579, jsc#SLE-4117,
  jsc#SLE-3853, bsc#1128910).
- commit 35c4a52
* Thu Mar 14 2019 msuchanek@suse.de
- Install extra rpm scripts for kernel subpackaging (FATE#326579,
  jsc#SLE-4117, jsc#SLE-3853, bsc#1128910).
- commit ad7c227
* Thu Mar 14 2019 jslaby@suse.cz
- Linux 5.0.2 (bnc#1012628).
- perf/x86/intel: Implement support for TSX Force Abort
  (bnc#1012628).
- x86: Add TSX Force Abort CPUID/MSR (bnc#1012628).
- perf/x86/intel: Generalize dynamic constraint creation
  (bnc#1012628).
- perf/x86/intel: Make cpuc allocations consistent (bnc#1012628).
- ath9k: Avoid OF no-EEPROM quirks without qca,no-eeprom
  (bnc#1012628).
- scripts/gdb: replace flags (MS_xyz -> SB_xyz) (bnc#1012628).
- staging: erofs: compressed_pages should not be accessed again
  after freed (bnc#1012628).
- staging: erofs: keep corrupted fs from crashing kernel in
  erofs_namei() (bnc#1012628).
- gfs2: Fix missed wakeups in find_insert_glock (bnc#1012628).
- bpf: Stop the psock parser before canceling its work
  (bnc#1012628).
- Revert "PCI/PME: Implement runtime PM callbacks" (bnc#1012628).
- media: Revert "media: rc: some events are dropped by userspace"
  (bnc#1012628).
- drm: disable uncached DMA optimization for ARM and arm64
  (bnc#1012628).
- ARM: dts: exynos: Fix max voltage for buck8 regulator on Odroid
  XU3/XU4 (bnc#1012628).
- ARM: dts: exynos: Add minimal clkout parameters to Exynos3250
  PMU (bnc#1012628).
- ARM: dts: exynos: Fix pinctrl definition for eMMC RTSN line
  on Odroid X2/U3 (bnc#1012628).
- arm64: dts: hikey: Revert "Enable HS200 mode on eMMC"
  (bnc#1012628).
- arm64: dts: hikey: Give wifi some time after power-on
  (bnc#1012628).
- arm64: dts: zcu100-revC: Give wifi some time after power-on
  (bnc#1012628).
- x86/PCI: Fixup RTIT_BAR of Intel Denverton Trace Hub
  (bnc#1012628).
- scsi: aacraid: Fix missing break in switch statement
  (bnc#1012628).
- iscsi_ibft: Fix missing break in switch statement (bnc#1012628).
- Input: elan_i2c - add id for touchpad found in Lenovo s21e-20
  (bnc#1012628).
- Input: wacom_serial4 - add support for Wacom ArtPad II tablet
  (bnc#1012628).
- media: uvcvideo: Fix 'type' check leading to overflow
  (bnc#1012628).
- commit 815c1bc
* Mon Mar 11 2019 mkubecek@suse.cz
- Update patches.suse/0001-media-usb-pwc-Don-t-use-coherent-DMA-buffers-for-ISO.patch
  upstream reference.
- commit ff7c8cd
* Sun Mar 10 2019 jslaby@suse.cz
- Linux 5.0.1 (bnc#1012628).
- exec: Fix mem leak in kernel_read_file (bnc#1012628).
- Bluetooth: Fix locking in bt_accept_enqueue() for BH context
  (bnc#1012628).
- Bluetooth: btrtl: Restore old logic to assume firmware is
  already loaded (bnc#1012628).
- selftests: firmware: fix verify_reqs() return value
  (bnc#1012628).
- Revert "selftests: firmware: remove use of non-standard diff
  - Z option" (bnc#1012628).
- Revert "selftests: firmware: add
  CONFIG_FW_LOADER_USER_HELPER_FALLBACK to config" (bnc#1012628).
- USB: serial: cp210x: fix GPIO in autosuspend (bnc#1012628).
- gnss: sirf: fix premature wakeup interrupt enable (bnc#1012628).
- xtensa: fix get_wchan (bnc#1012628).
- aio: Fix locking in aio_poll() (bnc#1012628).
- MIPS: irq: Allocate accurate order pages for irq stack
  (bnc#1012628).
- alpha: wire up io_pgetevents system call (bnc#1012628).
- applicom: Fix potential Spectre v1 vulnerabilities
  (bnc#1012628).
- usb: xhci: Fix for Enabling USB ROLE SWITCH QUIRK on
  INTEL_SUNRISEPOINT_LP_XHCI (bnc#1012628).
- xhci: tegra: Prevent error pointer dereference (bnc#1012628).
- tracing: Fix event filters and triggers to handle negative
  numbers (bnc#1012628).
- x86/boot/compressed/64: Do not read legacy ROM on EFI system
  (bnc#1012628).
- x86/CPU/AMD: Set the CPB bit unconditionally on F17h
  (bnc#1012628).
- tipc: fix RDM/DGRAM connect() regression (bnc#1012628).
- team: Free BPF filter when unregistering netdev (bnc#1012628).
- sky2: Disable MSI on Dell Inspiron 1545 and Gateway P-79
  (bnc#1012628).
- sctp: call iov_iter_revert() after sending ABORT (bnc#1012628).
- qmi_wwan: Add support for Quectel EG12/EM12 (bnc#1012628).
- net-sysfs: Fix mem leak in netdev_register_kobject
  (bnc#1012628).
- net: sched: put back q.qlen into a single location
  (bnc#1012628).
- net: mscc: Enable all ports in QSGMII (bnc#1012628).
- net: dsa: mv8e6xxx: fix number of internal PHYs for 88E6x90
  family (bnc#1012628).
- net: dsa: mv88e6xxx: handle unknown duplex modes gracefully
  in mv88e6xxx_port_set_duplex (bnc#1012628).
- net: dsa: mv88e6xxx: add call to mv88e6xxx_ports_cmode_init
  to probe for new DSA framework (bnc#1012628).
- ip6mr: Do not call __IP6_INC_STATS() from preemptible context
  (bnc#1012628).
- staging: android: ashmem: Avoid range_alloc() allocation with
  ashmem_mutex held (bnc#1012628).
- staging: android: ashmem: Don't call fallocate() with
  ashmem_mutex held (bnc#1012628).
- staging: android: ion: fix sys heap pool's gfp_flags
  (bnc#1012628).
- staging: wilc1000: fix to set correct value for 'vif_num'
  (bnc#1012628).
- staging: comedi: ni_660x: fix missing break in switch statement
  (bnc#1012628).
- staging: erofs: fix illegal address access under memory pressure
  (bnc#1012628).
- staging: erofs: fix race of initializing xattrs of a inode at
  the same time (bnc#1012628).
- staging: erofs: fix memleak of inode's shared xattr array
  (bnc#1012628).
- staging: erofs: fix fast symlink w/o xattr when fs xattr is on
  (bnc#1012628).
- driver core: Postpone DMA tear-down until after devres release
  (bnc#1012628).
- USB: serial: ftdi_sio: add ID for Hjelmslund Electronics USB485
  (bnc#1012628).
- USB: serial: cp210x: add ID for Ingenico 3070 (bnc#1012628).
- USB: serial: option: add Telit ME910 ECM composition
  (bnc#1012628).
- binder: create node flag to request sender's security context
  (bnc#1012628).
- staging: erofs: fix mis-acted TAIL merging behavior
  (bnc#1012628).
- cpufreq: Use struct kobj_attribute instead of struct global_attr
  (bnc#1012628).
- commit 47a2a02
* Thu Mar  7 2019 msuchanek@suse.de
- KMPs: provide and conflict a kernel version specific KMP name
  (bsc#1127155, bsc#1109137).
- commit 5568093
* Wed Mar  6 2019 msuchanek@suse.de
- Revert "Drop multiversion(kernel) from the KMP template (fate#323189)"
  (bsc#1109137).
  This reverts commit 71504d805c1340f68715ad41958e5ef35da2c351.
- commit adade9f
* Tue Mar  5 2019 mkubecek@suse.cz
- config: disable BPFILTER_UMH on non-x86 architectures (bsc#1127188)
  CONFIG_BPFILTER_UMH depends on ability to compile and link a userspace
  binary so that it currently doesn't work in our kbuild check setups using
  a cross compiler. Disable the option on architectures where cross compiler
  is used (i.e. all except x86_64 and i386).
- commit cfb8371
* Mon Mar  4 2019 msuchanek@suse.de
- KMPs: obsolete older KMPs of the same flavour (bsc#1127155, bsc#1109137).
- commit 821419f
* Mon Mar  4 2019 mkubecek@suse.cz
- Update to 5.0 final
- Refresh configs
- commit 8f71df2
* Wed Feb 27 2019 jslaby@suse.cz
- Linux 4.20.13 (bnc#1012628).
- net: phylink: avoid resolving link state too early
  (bnc#1012628).
- pinctrl: max77620: Use define directive for
  max77620_pinconf_param values (bnc#1012628).
- netfilter: ipt_CLUSTERIP: fix sleep-in-atomic bug in
  clusterip_config_entry_put() (bnc#1012628).
- netfilter: nfnetlink_osf: add missing fmatch check
  (bnc#1012628).
- netfilter: ipv6: Don't preserve original oif for loopback
  address (bnc#1012628).
- netfilter: nft_compat: use-after-free when deleting targets
  (bnc#1012628).
- netfilter: nf_tables: fix flush after rule deletion in the
  same batch (bnc#1012628).
- Revert "bridge: do not add port to router list when receives
  query with source 0.0.0.0" (bnc#1012628).
- staging: erofs: unzip_vle_lz4.c,utils.c: rectify BUG_ONs
  (bnc#1012628).
- staging: erofs: unzip_{pagevec.h,vle.c}: rectify BUG_ONs
  (bnc#1012628).
- staging: erofs: {dir,inode,super}.c: rectify BUG_ONs
  (bnc#1012628).
- staging: erofs: add a full barrier in erofs_workgroup_unfreeze
  (bnc#1012628).
- staging: erofs: fix `erofs_workgroup_{try_to_freeze, unfreeze}'
  (bnc#1012628).
- staging: erofs: atomic_cond_read_relaxed on ref-locked workgroup
  (bnc#1012628).
- staging: erofs: remove the redundant d_rehash() for the root
  dentry (bnc#1012628).
- net: avoid false positives in untrusted gso validation
  (bnc#1012628).
- net: validate untrusted gso packets without csum offload
  (bnc#1012628).
- ASoC: soc-core: fix init platform memory handling (bnc#1012628).
- s390: vsie: Use effective CRYCBD.31 to check CRYCBD validity
  (bnc#1012628).
- kvm: x86: Return LA57 feature based on hardware capability
  (bnc#1012628).
- x86/kvm/mmu: fix switch between root and guest MMUs
  (bnc#1012628).
- KVM: MMU: record maximum physical address width in
  kvm_mmu_extended_role (bnc#1012628).
- mac80211: allocate tailroom for forwarded mesh packets
  (bnc#1012628).
- mac80211: Change default tx_sk_pacing_shift to 7 (bnc#1012628).
- drm/amd/display: Fix MST reboot/poweroff sequence (bnc#1012628).
- drm/amdgpu: disable bulk moves for now (bnc#1012628).
- drm/i915/fbdev: Actually configure untiled displays
  (bnc#1012628).
- gpu: drm: radeon: Set DPM_FLAG_NEVER_SKIP when enabling
  PM-runtime (bnc#1012628).
- drm/amdgpu: Set DPM_FLAG_NEVER_SKIP when enabling PM-runtime
  (bnc#1012628).
- cpufreq: scmi: Fix use-after-free in scmi_cpufreq_exit()
  (bnc#1012628).
- ARC: define ARCH_SLAB_MINALIGN = 8 (bnc#1012628).
- ARC: U-boot: check arguments paranoidly (bnc#1012628).
- ARCv2: Enable unaligned access in early ASM code (bnc#1012628).
- parisc: Fix ptrace syscall number modification (bnc#1012628).
- clk: at91: fix at91sam9x5 peripheral clock number (bnc#1012628).
- clk: at91: fix masterck name (bnc#1012628).
- KEYS: always initialize keyring_index_key::desc_len
  (bnc#1012628).
- KEYS: user: Align the payload buffer (bnc#1012628).
- RDMA/srp: Rework SCSI device reset handling (bnc#1012628).
- scsi: sd_zbc: Fix sd_zbc_report_zones() buffer allocation
  (bnc#1012628).
- net/mlx5e: XDP, fix redirect resources availability check
  (bnc#1012628).
- net/mlx5e: FPGA, fix Innova IPsec TX offload data path
  performance (bnc#1012628).
- net_sched: fix two more memory leaks in cls_tcindex
  (bnc#1012628).
- net_sched: fix a memory leak in cls_tcindex (bnc#1012628).
- net_sched: fix a race condition in tcindex_destroy()
  (bnc#1012628).
- sit: check if IPv6 enabled before calling
  ip6_err_gen_icmpv6_unreach() (bnc#1012628).
- geneve: should not call rt6_lookup() when ipv6 was disabled
  (bnc#1012628).
- net: socket: make bond ioctls go through compat_ifreq_ioctl()
  (bnc#1012628).
- net: socket: fix SIOCGIFNAME in compat (bnc#1012628).
- Revert "kill dev_ifsioc()" (bnc#1012628).
- Revert "socket: fix struct ifreq size in compat ioctl"
  (bnc#1012628).
- net: dsa: Fix NPD checking for br_vlan_enabled() (bnc#1012628).
- team: avoid complex list operations in team_nl_cmd_options_set()
  (bnc#1012628).
- sctp: set stream ext to NULL after freeing it in
  sctp_stream_outq_migrate (bnc#1012628).
- sctp: call gso_reset_checksum when computing checksum in
  sctp_gso_segment (bnc#1012628).
- net: sfp: do not probe SFP module before we're attached
  (bnc#1012628).
- net/packet: fix 4gb buffer limit due to overflow check
  (bnc#1012628).
- net/mlx5e: Don't overwrite pedit action when multiple pedit used
  (bnc#1012628).
- net/mlx4_en: Force CHECKSUM_NONE for short ethernet frames
  (bnc#1012628).
- net: ena: fix race between link up and device initalization
  (bnc#1012628).
- ipv6: propagate genlmsg_reply return code (bnc#1012628).
- inet_diag: fix reporting cgroup classid and fallback to priority
  (bnc#1012628).
- batman-adv: fix uninit-value in batadv_interface_tx()
  (bnc#1012628).
- isdn: avm: Fix string plus integer warning from Clang
  (bnc#1012628).
- net/mlx5e: Fix wrong (zero) TX drop counter indication for
  representor (bnc#1012628).
- bpf: pull in pkt_sched.h header for tooling to fix bpftool build
  (bnc#1012628).
- selftests: forwarding: Add a test case for externally learned
  FDB entries (bnc#1012628).
- mlxsw: spectrum_switchdev: Do not treat static FDB entries as
  sticky (bnc#1012628).
- net: bridge: Mark FDB entries that were added by user as such
  (bnc#1012628).
- mlxsw: pci: Return error on PCI reset timeout (bnc#1012628).
- dpaa_eth: NETIF_F_LLTX requires to do our own update of
  trans_start (bnc#1012628).
- bpf: fix SO_MAX_PACING_RATE to support TCP internal pacing
  (bnc#1012628).
- bpf: bpf_setsockopt: reset sock dst on SO_MARK changes
  (bnc#1012628).
- leds: lp5523: fix a missing check of return value of lp55xx_read
  (bnc#1012628).
- hwmon: (tmp421) Correct the misspelling of the tmp442 compatible
  attribute in OF device ID table (bnc#1012628).
- atm: he: fix sign-extension overflow on large shift
  (bnc#1012628).
- selftests/bpf: retry tests that expect build-id (bnc#1012628).
- bpf: zero out build_id for BPF_STACK_BUILD_ID_IP (bnc#1012628).
- bpf: don't assume build-id length is always 20 bytes
  (bnc#1012628).
- afs: Fix race in async call refcounting (bnc#1012628).
- afs: Provide a function to get a ref on a call (bnc#1012628).
- afs: Fix key refcounting in file locking code (bnc#1012628).
- afs: Don't set vnode->cb_s_break in afs_validate()
  (bnc#1012628).
- selftests: tc-testing: fix parsing of ife type (bnc#1012628).
- selftests: tc-testing: fix tunnel_key failure if dst_port is
  unspecified (bnc#1012628).
- selftests: tc-testing: drop test on missing tunnel key id
  (bnc#1012628).
- net: phy: micrel: set soft_reset callback to genphy_soft_reset
  for KSZ9031 (bnc#1012628).
- ACPI: EC: Look for ECDT EC after calling acpi_load_tables()
  (bnc#1012628).
- pvcalls-front: fix potential null dereference (bnc#1012628).
- drm/sun4i: backend: add missing of_node_puts (bnc#1012628).
- SUNRPC: Ensure we respect the RPCSEC_GSS sequence number limit
  (bnc#1012628).
- SUNRPC: Ensure rq_bytes_sent is reset before request
  transmission (bnc#1012628).
- samples/bpf: workaround clang asm goto compilation errors
  (bnc#1012628).
- selftests/bpf: install with_tunnels.sh for
  test_flow_dissector.sh (bnc#1012628).
- xsk: Check if a queue exists during umem setup (bnc#1012628).
- vhost/scsi: Use copy_to_iter() to send control queue response
  (bnc#1012628).
- vhost: return EINVAL if iovecs size does not match the message
  size (bnc#1012628).
- drm/amd/display: fix PME notification not working in RV desktop
  (bnc#1012628).
- drm/amdkfd: Don't assign dGPUs to APU topology devices
  (bnc#1012628).
- drm/meson: add missing of_node_put (bnc#1012628).
- always clear the X2APIC_ENABLE bit for PV guest (bnc#1012628).
- netfilter: nft_flow_offload: fix checking method of conntrack
  helper (bnc#1012628).
- scsi: cxgb4i: add wait_for_completion() (bnc#1012628).
- scsi: qla1280: set 64bit coherent mask (bnc#1012628).
- scsi: ufs: Fix geometry descriptor size (bnc#1012628).
- scsi: qedi: Add ep_state for login completion on un-reachable
  targets (bnc#1012628).
- scsi: ufs: Fix system suspend status (bnc#1012628).
- scsi: tcmu: avoid cmd/qfull timers updated whenever a new cmd
  comes (bnc#1012628).
- isdn: i4l: isdn_tty: Fix some concurrency double-free bugs
  (bnc#1012628).
- net: stmmac: Prevent RX starvation in stmmac_napi_poll()
  (bnc#1012628).
- net: stmmac: Fix the logic of checking if RX Watchdog must be
  enabled (bnc#1012628).
- net: stmmac: Check if CBS is supported before configuring
  (bnc#1012628).
- net: stmmac: dwxgmac2: Only clear interrupts that are active
  (bnc#1012628).
- net: stmmac: Fix PCI module removal leak (bnc#1012628).
- acpi/nfit: Fix race accessing memdev in nfit_get_smbios_id()
  (bnc#1012628).
- powerpc/8xx: fix setting of pagetable for Abatron BDI debug tool
  (bnc#1012628).
- RDMA/mthca: Clear QP objects during their allocation
  (bnc#1012628).
- netfilter: nft_flow_offload: fix interaction with vrf slave
  device (bnc#1012628).
- afs: Set correct lock type for the yfs CreateFile (bnc#1012628).
- bpf: fix panic in stack_map_get_build_id() on i386 and arm32
  (bnc#1012628).
- selftests: bpf: install files tcp_(server|client)*.py
  (bnc#1012628).
- pvcalls-front: Avoid get_free_pages(GFP_KERNEL) under spinlock
  (bnc#1012628).
- bpf: correctly set initial window on active Fast Open sender
  (bnc#1012628).
- netfilter: nft_flow_offload: Fix reverse route lookup
  (bnc#1012628).
- MIPS: jazz: fix 64bit build (bnc#1012628).
- include/linux/compiler*.h: fix OPTIMIZER_HIDE_VAR (bnc#1012628).
- scsi: isci: initialize shost fully before calling
  scsi_add_host() (bnc#1012628).
- scsi: qla4xxx: check return code of
  qla4xxx_copy_from_fwddb_param (bnc#1012628).
- netfilter: nf_tables: fix leaking object reference count
  (bnc#1012628).
- selftests: forwarding: Add a test for VLAN deletion
  (bnc#1012628).
- mlxsw: spectrum: Add VXLAN dependency for spectrum
  (bnc#1012628).
- mlxsw: spectrum_acl: Add cleanup after C-TCAM update error
  condition (bnc#1012628).
- xprtrdma: Double free in rpcrdma_sendctxs_create()
  (bnc#1012628).
- MIPS: ath79: Enable OF serial ports in the default config
  (bnc#1012628).
- net/mlx4: Get rid of page operation after dma_alloc_coherent
  (bnc#1012628).
- watchdog: mt7621_wdt/rt2880_wdt: Fix compilation problem
  (bnc#1012628).
- hwmon: (nct6775) Enable IO mapping for NCT6797D and NCT6798D
  (bnc#1012628).
- hwmon: (nct6775) Fix chip ID for NCT6798D (bnc#1012628).
- selftests/bpf: Test [::] -> [::1] rewrite in sys_sendmsg in
  test_sock_addr (bnc#1012628).
- bpf: Fix [::] -> [::1] rewrite in sys_sendmsg (bnc#1012628).
- selftests: net: fix/improve ip_defrag selftest (bnc#1012628).
- net: hns: Fix use after free identified by SLUB debug
  (bnc#1012628).
- qed: Fix qed_ll2_post_rx_buffer_notify_fw() by adding a write
  memory barrier (bnc#1012628).
- qed: Fix qed_chain_set_prod() for PBL chains with non power
  of 2 page count (bnc#1012628).
- soc/fsl/qe: fix err handling of ucc_of_parse_tdm (bnc#1012628).
- xen/pvcalls: remove set but not used variable 'intf'
  (bnc#1012628).
- mfd: mc13xxx: Fix a missing check of a register-read failure
  (bnc#1012628).
- mfd: tps65218: Use devm_regmap_add_irq_chip and clean up error
  path in probe() (bnc#1012628).
- mfd: cros_ec_dev: Add missing mfd_remove_devices() call in
  remove (bnc#1012628).
- mfd: axp20x: Add supported cells for AXP803 (bnc#1012628).
- mfd: axp20x: Re-align MFD cell entries (bnc#1012628).
- mfd: axp20x: Add AC power supply cell for AXP813 (bnc#1012628).
- mfd: wm5110: Add missing ASRC rate register (bnc#1012628).
- mfd: qcom_rpm: write fw_version to CTRL_REG (bnc#1012628).
- mfd: at91-usart: Add platform dependency (bnc#1012628).
- mfd: bd9571mwv: Add volatile register to make DVFS work
  (bnc#1012628).
- mfd: ab8500-core: Return zero in get_register_interruptible()
  (bnc#1012628).
- mfd: mt6397: Do not call irq_domain_remove if PMIC unsupported
  (bnc#1012628).
- mfd: db8500-prcmu: Fix some section annotations (bnc#1012628).
- mfd: twl-core: Fix section annotations on {,un}protect_pm_master
  (bnc#1012628).
- pvcalls-back: set -ENOTCONN in pvcalls_conn_back_read
  (bnc#1012628).
- pvcalls-front: properly allocate sk (bnc#1012628).
- pvcalls-front: don't try to free unallocated rings
  (bnc#1012628).
- pvcalls-front: read all data before closing the connection
  (bnc#1012628).
- mfd: ti_am335x_tscadc: Use PLATFORM_DEVID_AUTO while registering
  mfd cells (bnc#1012628).
- backlight: pwm_bl: Fix devicetree parsing with auto-generated
  brightness tables (bnc#1012628).
- KEYS: allow reaching the keys quotas exactly (bnc#1012628).
- ALSA: hda/realtek: Disable PC beep in passthrough on alc285
  (bnc#1012628).
- ALSA: hda/realtek - Headset microphone and internal speaker
  support for System76 oryp5 (bnc#1012628).
- proc, oom: do not report alien mms when setting oom_score_adj
  (bnc#1012628).
- numa: change get_mempolicy() to use nr_node_ids instead of
  MAX_NUMNODES (bnc#1012628).
- ceph: avoid repeatedly adding inode to mdsc->snap_flush_list
  (bnc#1012628).
- libceph: handle an empty authorize reply (bnc#1012628).
- pinctrl: qcom: qcs404: Correct SDC tile (bnc#1012628).
- mac80211: Free mpath object when rhashtable insertion fails
  (bnc#1012628).
- mac80211: Use linked list instead of rhashtable walk for mesh
  tables (bnc#1012628).
- mac80211: Restore vif beacon interval if start ap fails
  (bnc#1012628).
- gpio: pxa: avoid attempting to set pin direction via pinctrl
  on MMP2 (bnc#1012628).
- gpio: MT7621: use a per instance irq_chip structure
  (bnc#1012628).
- mt76x0u: fix suspend/resume (bnc#1012628).
- MIPS: eBPF: Always return sign extended 32b values
  (bnc#1012628).
- tracing: Fix number of entries in trace header (bnc#1012628).
- kprobe: Do not use uaccess functions to access kernel memory
  that can fault (bnc#1012628).
- ARM: 8834/1: Fix: kprobes: optimized kprobes illegal instruction
  (bnc#1012628).
- commit fb7c4a5
* Wed Feb 27 2019 msuchanek@suse.de
- BPF: UMH: do not detect if compiler can link userspace program
  (boo#1127188).
- commit 784e336
* Mon Feb 25 2019 mkubecek@suse.cz
- Update to 5.0-rc8
- Eliminated 1 patch
- commit 4ddf057
* Sat Feb 23 2019 jslaby@suse.cz
- Linux 4.20.12 (bnc#1012628).
- dsa: mv88e6xxx: Ensure all pending interrupts are handled
  prior to exit (bnc#1012628).
- net: fix IPv6 prefix route residue (bnc#1012628).
- net: ipv4: use a dedicated counter for icmp_v4 redirect packets
  (bnc#1012628).
- vsock: cope with memory allocation failure at socket creation
  time (bnc#1012628).
- vxlan: test dev->flags & IFF_UP before calling netif_rx()
  (bnc#1012628).
- mlxsw: __mlxsw_sp_port_headroom_set(): Fix a use of local
  variable (bnc#1012628).
- net: Fix for_each_netdev_feature on Big endian (bnc#1012628).
- net: ip6_gre: initialize erspan_ver just for erspan tunnels
  (bnc#1012628).
- net: phy: xgmiitorgmii: Support generic PHY status read
  (bnc#1012628).
- net: stmmac: Fix a race in EEE enable callback (bnc#1012628).
- net: stmmac: handle endianness in dwmac4_get_timestamp
  (bnc#1012628).
- sky2: Increase D3 delay again (bnc#1012628).
- vhost: correctly check the return value of translate_desc()
  in log_used() (bnc#1012628).
- net: Add header for usage of fls64() (bnc#1012628).
- tcp: clear icsk_backoff in tcp_write_queue_purge()
  (bnc#1012628).
- tcp: tcp_v4_err() should be more careful (bnc#1012628).
- net: netcp: Fix ethss driver probe issue (bnc#1012628).
- net: Do not allocate page fragments that are not skb aligned
  (bnc#1012628).
- af_packet: fix raw sockets over 6in4 tunnel (bnc#1012628).
- arm64, mm, efi: Account for GICv3 LPI tables in static memblock
  reserve table (bnc#1012628).
- efi/arm: Revert "Defer persistent reservations until after
  paging_init()" (bnc#1012628).
- PCI: Fix __initdata issue with "pci=disable_acs_redir" parameter
  (bnc#1012628).
- scsi: target/core: Use kmem_cache_free() instead of kfree()
  (bnc#1012628).
- mmc: meson-gx: fix interrupt name (bnc#1012628).
- hwmon: (lm80) Fix missing unlock on error in set_fan_div()
  (bnc#1012628).
- netfilter: nf_nat_snmp_basic: add missing length checks in
  ASN.1 cbs (bnc#1012628).
- net/x25: do not hold the cpu too long in x25_new_lci()
  (bnc#1012628).
- mISDN: fix a race in dev_expire_timer() (bnc#1012628).
- ax25: fix possible use-after-free (bnc#1012628).
- commit b35c1fc
* Fri Feb 22 2019 mkubecek@suse.cz
- net: crypto set sk to NULL when af_alg_release (CVE-2019-8912
  bsc#1125907).
- commit e1b5b1f
* Fri Feb 22 2019 mkubecek@suse.cz
- net: crypto set sk to NULL when af_alg_release (CVE-2019-8912
  bsc#1125907).
- commit 3aed52e
* Fri Feb 22 2019 mkubecek@suse.cz
- config: enable PREEMPT_VOLUNTARY (bsc#1125004)
  Switch to PREEMPT_VOLUNTARY everywhere except s390x/zfcpdump.
  [js] switch also armv7hl. armv6hl seems to have PREEMPT=n.
- config: enable PREEMPT_VOLUNTARY (bsc#1125004)
  Switch to PREEMPT_VOLUNTARY everywhere except s390x/zfcpdump.
- commit 5cf91fd
* Wed Feb 20 2019 jslaby@suse.cz
- Linux 4.20.11 (bnc#1012628).
- dt-bindings: eeprom: at24: add "atmel,24c2048" compatible string
  (bnc#1012628).
- eeprom: at24: add support for 24c2048 (bnc#1012628).
- blk-mq: fix a hung issue when fsync (bnc#1012628).
- drm/amdgpu/sriov:Correct pfvf exchange logic (bnc#1012628).
- ACPI: NUMA: Use correct type for printing addresses on i386-PAE
  (bnc#1012628).
- perf stat: Fix endless wait for child process (bnc#1012628).
- perf report: Fix wrong iteration count in --branch-history
  (bnc#1012628).
- perf test shell: Use a fallback to get the pathname in
  vfs_getname (bnc#1012628).
- soc: renesas: r8a774c0-sysc: Fix initialization order of
  3DG-{A,B} (bnc#1012628).
- tools uapi: fix RISC-V 64-bit support (bnc#1012628).
- riscv: fix trace_sys_exit hook (bnc#1012628).
- cpufreq: check if policy is inactive early in __cpufreq_get()
  (bnc#1012628).
- csky: fixup relocation error with 807 & 860 (bnc#1012628).
- csky: fixup CACHEV1 store instruction fast retire (bnc#1012628).
- irqchip/csky: fixup handle_irq_perbit break irq (bnc#1012628).
- drm/amd/powerplay: avoid possible buffer overflow (bnc#1012628).
- drm/bridge: tc358767: add bus flags (bnc#1012628).
- drm/bridge: tc358767: add defines for DP1_SRCCTRL & PHY_2LANE
  (bnc#1012628).
- drm/bridge: tc358767: fix single lane configuration
  (bnc#1012628).
- drm/bridge: tc358767: fix initial DP0/1_SRCCTRL value
  (bnc#1012628).
- drm/bridge: tc358767: reject modes which require too much BW
  (bnc#1012628).
- drm/bridge: tc358767: fix output H/V syncs (bnc#1012628).
- nvme-pci: use the same attributes when freeing
  host_mem_desc_bufs (bnc#1012628).
- nvme-pci: fix out of bounds access in nvme_cqe_pending
  (bnc#1012628).
- nvme-multipath: zero out ANA log buffer (bnc#1012628).
- nvme: pad fake subsys NQN vid and ssvid with zeros
  (bnc#1012628).
- nvme: introduce NVME_QUIRK_IGNORE_DEV_SUBNQN (bnc#1012628).
- drm/amdgpu: fix CPDMA hang in PRT mode for VEGA20 (bnc#1012628).
- drm/amdgpu: set WRITE_BURST_LENGTH to 64B to workaround SDMA1
  hang (bnc#1012628).
- drm/amdgpu: disable system memory page tables for now
  (bnc#1012628).
- ARM: dts: da850-evm: Correct the audio codec regulators
  (bnc#1012628).
- ARM: dts: da850-evm: Correct the sound card name (bnc#1012628).
- ARM: dts: da850-lcdk: Correct the audio codec regulators
  (bnc#1012628).
- ARM: dts: da850-lcdk: Correct the sound card name (bnc#1012628).
- ARM: dts: kirkwood: Fix polarity of GPIO fan lines
  (bnc#1012628).
- csky: fixup compile error with CPU 810 (bnc#1012628).
- gpio: pl061: handle failed allocations (bnc#1012628).
- drm/nouveau: Don't disable polling in fallback mode
  (bnc#1012628).
- drm/nouveau/falcon: avoid touching registers if engine is off
  (bnc#1012628).
- cifs: Limit memory used by lock request calls to a page
  (bnc#1012628).
- CIFS: Fix credits calculation for cancelled requests
  (bnc#1012628).
- CIFS: Move credit processing to mid callbacks for SMB3
  (bnc#1012628).
- CIFS: Fix error paths in writeback code (bnc#1012628).
- kvm: sev: Fail KVM_SEV_INIT if already initialized
  (bnc#1012628).
- CIFS: Fix credit calculations in compound mid callback
  (bnc#1012628).
- CIFS: Do not assume one credit for async responses
  (bnc#1012628).
- CIFS: Fix mounts if the client is low on credits (bnc#1012628).
- gpio: mxc: move gpio noirq suspend/resume to syscore phase
  (bnc#1012628).
- Revert "Input: elan_i2c - add ACPI ID for touchpad in ASUS
  Aspire F5-573G" (bnc#1012628).
- Input: elan_i2c - add ACPI ID for touchpad in Lenovo V330-15ISK
  (bnc#1012628).
- arm64: dts: rockchip: enable usb-host regulators at boot on
  rk3328-rock64 (bnc#1012628).
- ARM: OMAP5+: Fix inverted nirq pin interrupts with irq_set_type
  (bnc#1012628).
- perf/core: Fix impossible ring-buffer sizes warning
  (bnc#1012628).
- perf/x86: Add check_period PMU callback (bnc#1012628).
- ALSA: hda - Add quirk for HP EliteBook 840 G5 (bnc#1012628).
- ALSA: usb-audio: Fix implicit fb endpoint setup by quirk
  (bnc#1012628).
- ALSA: pcm: Revert capture stream behavior change in blocking
  mode (bnc#1012628).
- ASoC: hdmi-codec: fix oops on re-probe (bnc#1012628).
- tools uapi: fix Alpha support (bnc#1012628).
- riscv: Add pte bit to distinguish swap from invalid
  (bnc#1012628).
- x86/kvm/nVMX: read from MSR_IA32_VMX_PROCBASED_CTLS2 only when
  it is available (bnc#1012628).
- kvm: vmx: Fix entry number check for add_atomic_switch_msr()
  (bnc#1012628).
- mmc: sunxi: Disable HS-DDR mode for H5 eMMC controller by
  default (bnc#1012628).
- mmc: sunxi: Filter out unsupported modes declared in the device
  tree (bnc#1012628).
- mmc: block: handle complete_work on separate workqueue
  (bnc#1012628).
- Input: bma150 - register input device after setting private data
  (bnc#1012628).
- Input: elantech - enable 3rd button support on Fujitsu CELSIUS
  H780 (bnc#1012628).
- Revert "nfsd4: return default lease period" (bnc#1012628).
- Revert "mm: don't reclaim inodes with many attached pages"
  (bnc#1012628).
- Revert "mm: slowly shrink slabs with a relatively small number
  of objects" (bnc#1012628).
- mm: proc: smaps_rollup: fix pss_locked calculation
  (bnc#1012628).
- alpha: fix page fault handling for r16-r18 targets
  (bnc#1012628).
- alpha: Fix Eiger NR_IRQS to 128 (bnc#1012628).
- s390/suspend: fix stack setup in swsusp_arch_suspend
  (bnc#1012628).
- s390/zcrypt: fix specification exception on z196 during ap probe
  (bnc#1012628).
- tracing: probeevent: Correctly update remaining space in
  dynamic area (bnc#1012628).
- x86/platform/UV: Use efi_runtime_lock to serialise BIOS calls
  (bnc#1012628).
- powerpc/64s: Fix possible corruption on big endian due to
  pgd/pud_present() (bnc#1012628).
- scsi: sd: fix entropy gathering for most rotational disks
  (bnc#1012628).
- crypto: ccree - fix resume race condition on init (bnc#1012628).
- md/raid1: don't clear bitmap bits on interrupted recovery
  (bnc#1012628).
- x86/a.out: Clear the dump structure initially (bnc#1012628).
- sunrpc: fix 4 more call sites that were using stack memory
  with a scatterlist (bnc#1012628).
- dm crypt: don't overallocate the integrity tag space
  (bnc#1012628).
- dm thin: fix bug where bio that overwrites thin block ignores
  FUA (bnc#1012628).
- drm: Use array_size() when creating lease (bnc#1012628).
- drm/vkms: Fix license inconsistent (bnc#1012628).
- drm/sched: Always trace the dependencies we wait on, to fix
  a race (bnc#1012628).
- drm/i915: Block fbdev HPD processing during suspend
  (bnc#1012628).
- drm/i915: Prevent a race during I915_GEM_MMAP ioctl with WC set
  (bnc#1012628).
- commit eba2b68
* Tue Feb 19 2019 mbenes@suse.cz
- rpm/klp-symbols: Remove the second column in Symbols.list
  Symbols.list file contains also a symbol type next to its name.
  klp-convert cannot handle it well and it is superfluous anyway.
- commit 62a0a00
* Tue Feb 19 2019 jslaby@suse.cz
- signal: Restore the stop PTRACE_EVENT_EXIT (strace
  threads-execve regression).
- Delete
  patches.suse/revert-signal-Always-notice-exiting-tasks.patch.
- commit 8c9f09c
* Tue Feb 19 2019 jslaby@suse.cz
- Revert "signal: Always notice exiting tasks" (strace
  threads-execve regression).
- commit 08d0345
* Mon Feb 18 2019 mkubecek@suse.cz
- Update to 5.0-rc7
- commit b094e66
* Fri Feb 15 2019 jslaby@suse.cz
- Revert "exec: load_script: don't blindly truncate shebang
  string" (bnc#1012628).
- Linux 4.20.10 (bnc#1012628).
- Delete
  patches.suse/Revert-exec-load_script-don-t-blindly-truncate-sheba.patch.
- commit 4c06520
* Fri Feb 15 2019 jslaby@suse.cz
- Linux 4.20.9 (bnc#1012628).
- batman-adv: Force mac header to start of data on xmit
  (bnc#1012628).
- batman-adv: Avoid WARN on net_device without parent in netns
  (bnc#1012628).
- xfrm: refine validation of template and selector families
  (bnc#1012628).
- libceph: avoid KEEPALIVE_PENDING races in ceph_con_keepalive()
  (bnc#1012628).
- Revert "ext4: use ext4_write_inode() when fsyncing w/o a
  journal" (bnc#1012628).
- drm/i915: Try to sanitize bogus DPLL state left over by broken
  SNB BIOSen (bnc#1012628).
- xfrm: Make set-mark default behavior backward compatible
  (bnc#1012628).
- drm/vmwgfx: Return error code from vmw_execbuf_copy_fence_user
  (bnc#1012628).
- drm/vmwgfx: Fix an uninitialized fence handle value
  (bnc#1012628).
- drm/vmwgfx: Fix setting of dma masks (bnc#1012628).
- drm/i915: always return something on DDI clock selection
  (bnc#1012628).
- drm/amd/powerplay: Fix missing break in switch (bnc#1012628).
- drm/rockchip: rgb: update SPDX license identifier (bnc#1012628).
- drm/modes: Prevent division by zero htotal (bnc#1012628).
- mac80211: ensure that mgmt tx skbs have tailroom for encryption
  (bnc#1012628).
- mic: vop: Fix use-after-free on remove (bnc#1012628).
- powerpc/radix: Fix kernel crash with mremap() (bnc#1012628).
- powerpc/papr_scm: Use the correct bind address (bnc#1012628).
- firmware: arm_scmi: provide the mandatory device release
  callback (bnc#1012628).
- ARM: dts: da850: fix interrupt numbers for clocksource
  (bnc#1012628).
- ARM: tango: Improve ARCH_MULTIPLATFORM compatibility
  (bnc#1012628).
- ARM: iop32x/n2100: fix PCI IRQ mapping (bnc#1012628).
- MIPS: VDSO: Include $(ccflags-vdso) in o32,n32 .lds builds
  (bnc#1012628).
- mips: loongson64: remove unreachable(), fix loongson_poweroff()
  (bnc#1012628).
- MIPS: VDSO: Use same -m%%-float cflag as the kernel proper
  (bnc#1012628).
- MIPS: OCTEON: don't set octeon_dma_bar_type if PCI is disabled
  (bnc#1012628).
- MIPS: Use lower case for addresses in nexys4ddr.dts
  (bnc#1012628).
- mips: cm: reprime error cause (bnc#1012628).
- tracing: uprobes: Fix typo in pr_fmt string (bnc#1012628).
- tracing/uprobes: Fix output for multiple string arguments
  (bnc#1012628).
- pinctrl: cherryview: fix Strago DMI workaround (bnc#1012628).
- pinctrl: sunxi: Correct number of IRQ banks on H6 main pin
  controller (bnc#1012628).
- svcrdma: Remove max_sge check at connect time (bnc#1012628).
- debugfs: fix debugfs_rename parameter checking (bnc#1012628).
- samples: mei: use /dev/mei0 instead of /dev/mei (bnc#1012628).
- mei: me: add ice lake point device id (bnc#1012628).
- cfg80211: call disconnect_wk when AP stops (bnc#1012628).
- misc: vexpress: Off by one in vexpress_syscfg_exec()
  (bnc#1012628).
- signal: Better detection of synchronous signals (bnc#1012628).
- signal: Always notice exiting tasks (bnc#1012628).
- signal: Always attempt to allocate siginfo for SIGSTOP
  (bnc#1012628).
- iio: ti-ads8688: Update buffer allocation for timestamps
  (bnc#1012628).
- iio: chemical: atlas-ph-sensor: correct IIO_TEMP values to
  millicelsius (bnc#1012628).
- iio: adc: axp288: Fix TS-pin handling (bnc#1012628).
- tools: iio: iio_generic_buffer: make num_loops signed
  (bnc#1012628).
- libata: Add NOLPM quirk for SAMSUNG MZ7TE512HMHP-000L1 SSD
  (bnc#1012628).
- mtd: rawnand: gpmi: fix MX28 bus master lockup problem
  (bnc#1012628).
- mtd: spinand: Fix the error/cleanup path in spinand_init()
  (bnc#1012628).
- mtd: spinand: Handle the case where PROGRAM LOAD does not
  reset the cache (bnc#1012628).
- mtd: Make sure mtd->erasesize is valid even if the partition
  is of size 0 (bnc#1012628).
- commit 54de81d
* Fri Feb 15 2019 jslaby@suse.cz
- Revert "exec: load_script: don't blindly truncate shebang
  string" (shebang regression).
- commit c99a06a
* Wed Feb 13 2019 jslaby@suse.cz
- Update config files.
  Fix armv6 build, set USB_ROLE_SWITCH=m.
- commit cc8092a
* Tue Feb 12 2019 jslaby@suse.cz
- Linux 4.20.8 (bnc#1012628).
- ath9k: dynack: check da->enabled first in sampling routines
  (bnc#1012628).
- ath9k: dynack: make ewma estimation faster (bnc#1012628).
- nfsd: Fix error return values for nfsd4_clone_file_range()
  (bnc#1012628).
- cacheinfo: Keep the old value if of_property_read_u32 fails
  (bnc#1012628).
- serial: sh-sci: Do not free irqs that have already been freed
  (bnc#1012628).
- serial: 8250_pci: Make PCI class test non fatal (bnc#1012628).
- serial: fix race between flush_to_ldisc and tty_open
  (bnc#1012628).
- perf tests evsel-tp-sched: Fix bitwise operator (bnc#1012628).
- perf/core: Don't WARN() for impossible ring-buffer sizes
  (bnc#1012628).
- x86/MCE: Initialize mce.bank in the case of a fatal error in
  mce_no_way_out() (bnc#1012628).
- perf/x86/intel: Delay memory deallocation until
  x86_pmu_dead_cpu() (bnc#1012628).
- perf/x86/intel/uncore: Add Node ID mask (bnc#1012628).
- cpu/hotplug: Fix "SMT disabled by BIOS" detection for KVM
  (bnc#1012628).
- KVM: nVMX: unconditionally cancel preemption timer in
  free_nested (CVE-2019-7221) (bnc#1012628).
- kvm: fix kvm_ioctl_create_device() reference counting
  (CVE-2019-6974) (bnc#1012628).
- KVM: x86: work around leak of uninitialized stack contents
  (CVE-2019-7222) (bnc#1012628).
- scsi: aic94xx: fix module loading (bnc#1012628).
- scsi: cxlflash: Prevent deadlock when adapter probe fails
  (bnc#1012628).
- scsi: sd_zbc: Fix zone information messages (bnc#1012628).
- staging: speakup: fix tty-operation NULL derefs (bnc#1012628).
- usb: gadget: musb: fix short isoc packets with inventra dma
  (bnc#1012628).
- usb: gadget: udc: net2272: Fix bitwise and boolean operations
  (bnc#1012628).
- usb: dwc3: gadget: Handle 0 xfer length for OUT EP
  (bnc#1012628).
- usb: phy: am335x: fix race condition in _probe (bnc#1012628).
- arm64: dts: allwinner: a64: Fix USB OTG regulator (bnc#1012628).
- irqchip/gic-v3-its: Plug allocation race for devices sharing
  a DevID (bnc#1012628).
- futex: Handle early deadlock return correctly (bnc#1012628).
- dmaengine: imx-dma: fix wrong callback invoke (bnc#1012628).
- dmaengine: bcm2835: Fix abort of transactions (bnc#1012628).
- dmaengine: bcm2835: Fix interrupt race on RT (bnc#1012628).
- HID: debug: fix the ring buffer implementation (bnc#1012628).
- cuse: fix ioctl (bnc#1012628).
- fuse: handle zero sized retrieve correctly (bnc#1012628).
- fuse: decrement NR_WRITEBACK_TEMP on the right page
  (bnc#1012628).
- fuse: call pipe_buf_release() under pipe lock (bnc#1012628).
- ALSA: hda/realtek - Headset microphone support for System76
  darp5 (bnc#1012628).
- ALSA: hda/realtek - Use a common helper for hp pin reference
  (bnc#1012628).
- ALSA: hda/realtek - Fix lose hp_pins for disable auto mute
  (bnc#1012628).
- ALSA: hda - Serialize codec registrations (bnc#1012628).
- ALSA: usb-audio: Add support for new T+A USB DAC (bnc#1012628).
- ALSA: compress: Fix stop handling on compressed capture streams
  (bnc#1012628).
- xfs: eof trim writeback mapping as soon as it is cached
  (bnc#1012628).
- net/mlx5e: Force CHECKSUM_UNNECESSARY for short ethernet frames
  (bnc#1012628).
- net/mlx5e: Use the inner headers to determine tc/pedit offload
  limitation on decap flows (bnc#1012628).
- net: dsa: b53: Fix for failure when irq is not defined in dt
  (bnc#1012628).
- net: cls_flower: Remove filter from mask before freeing it
  (bnc#1012628).
- bnxt_en: Disable interrupts when allocating CP rings or NQs
  (bnc#1012628).
- virtio_net: Account for tx bytes and packets on sending
  xdp_frames (bnc#1012628).
- skge: potential memory corruption in skge_get_regs()
  (bnc#1012628).
- sctp: walk the list of asoc safely (bnc#1012628).
- sctp: check and update stream->out_curr when allocating
  stream_out (bnc#1012628).
- rxrpc: bad unlock balance in rxrpc_recvmsg (bnc#1012628).
- Revert "net: phy: marvell: avoid pause mode on SGMII-to-Copper
  for 88e151x" (bnc#1012628).
- rds: fix refcount bug in rds_sock_addref (bnc#1012628).
- net: systemport: Fix WoL with password after deep sleep
  (bnc#1012628).
- net: dsa: slave: Don't propagate flag changes on down slave
  interfaces (bnc#1012628).
- net: dsa: mv88e6xxx: Fix counting of ATU violations
  (bnc#1012628).
- net: dsa: Fix NULL checking in dsa_slave_set_eee()
  (bnc#1012628).
- net: dsa: Fix lockdep false positive splat (bnc#1012628).
- net: dp83640: expire old TX-skb (bnc#1012628).
- lib/test_rhashtable: Make test_insert_dup() allocate its hash
  table dynamically (bnc#1012628).
- enic: fix checksum validation for IPv6 (bnc#1012628).
- dccp: fool proof ccid_hc_[rt]x_parse_options() (bnc#1012628).
- thermal: hwmon: inline helpers when CONFIG_THERMAL_HWMON is
  not set (bnc#1012628).
- xprtrdma: Don't wake pending tasks until disconnect is done
  (bnc#1012628).
- scripts/gdb: fix lx-version string output (bnc#1012628).
- kernel/kcov.c: mark write_comp_data() as notrace (bnc#1012628).
- exec: load_script: don't blindly truncate shebang string
  (bnc#1012628).
- fs/epoll: drop ovflist branch prediction (bnc#1012628).
- kernel/hung_task.c: force console verbose before panic
  (bnc#1012628).
- proc/sysctl: fix return error for proc_doulongvec_minmax()
  (bnc#1012628).
- kernel/hung_task.c: break RCU locks based on jiffies
  (bnc#1012628).
- arm64/sve: ptrace: Fix SVE_PT_REGS_OFFSET definition
  (bnc#1012628).
- HID: lenovo: Add checks to fix of_led_classdev_register
  (bnc#1012628).
- thermal: generic-adc: Fix adc to temp interpolation
  (bnc#1012628).
- block/swim3: Fix regression on PowerBook G3 (bnc#1012628).
- PCI: imx: Enable MSI from downstream components (bnc#1012628).
- thermal: tsens: qcom: do not create duplicate regmap debugfs
  entries (bnc#1012628).
- kdb: Don't back trace on a cpu that didn't round up
  (bnc#1012628).
- thermal: bcm2835: enable hwmon explicitly (bnc#1012628).
- block/swim3: Fix -EBUSY error when re-opening device after
  unmount (bnc#1012628).
- fsl/fman: Use GFP_ATOMIC in {memac,tgec}_add_hash_mac_address()
  (bnc#1012628).
- gdrom: fix a memory leak bug (bnc#1012628).
- isdn: hisax: hfc_pci: Fix a possible concurrency use-after-free
  bug in HFCPCI_l1hw() (bnc#1012628).
- zram: fix lockdep warning of free block handling (bnc#1012628).
- mm/page_alloc.c: don't call kasan_free_pages() at deferred
  mem init (bnc#1012628).
- ocfs2: improve ocfs2 Makefile (bnc#1012628).
- ocfs2: don't clear bh uptodate for block read (bnc#1012628).
- arch/sh/boards/mach-kfr2r09/setup.c: fix struct mtd_oob_ops
  build warning (bnc#1012628).
- scripts/decode_stacktrace: only strip base path when a prefix
  of the path (bnc#1012628).
- perf python: Do not force closing original perf descriptor in
  evlist.get_pollfd() (bnc#1012628).
- cgroup: fix parsing empty mount option string (bnc#1012628).
- f2fs: fix sbi->extent_list corruption issue (bnc#1012628).
- niu: fix missing checks of niu_pci_eeprom_read (bnc#1012628).
- um: Avoid marking pages with "changed protection" (bnc#1012628).
- f2fs: fix use-after-free issue when accessing sbi->stat_info
  (bnc#1012628).
- cifs: check ntwrk_buf_start for NULL before dereferencing it
  (bnc#1012628).
- MIPS: ralink: Select CONFIG_CPU_MIPSR2_IRQ_VI on MT7620/8
  (bnc#1012628).
- crypto: ux500 - Use proper enum in hash_set_dma_transfer
  (bnc#1012628).
- crypto: ux500 - Use proper enum in cryp_set_dma_transfer
  (bnc#1012628).
- seq_buf: Make seq_buf_puts() null-terminate the buffer
  (bnc#1012628).
- hwmon: (lm80) fix a missing check of bus read in lm80 probe
  (bnc#1012628).
- hwmon: (lm80) fix a missing check of the status of SMBus read
  (bnc#1012628).
- perf build: Don't unconditionally link the libbfd feature test
  to -liberty and -lz (bnc#1012628).
- NFS: nfs_compare_mount_options always compare auth flavors
  (bnc#1012628).
- kvm: Change offset in kvm_write_guest_offset_cached to unsigned
  (bnc#1012628).
- selftests: kvm: report failed stage when exit reason is
  unexpected (bnc#1012628).
- powerpc/fadump: Do not allow hot-remove memory from fadump
  reserved area (bnc#1012628).
- KVM: x86: svm: report MSR_IA32_MCG_EXT_CTL as unsupported
  (bnc#1012628).
- pinctrl: meson: meson8b: fix the GPIO function for the GPIOAO
  pins (bnc#1012628).
- pinctrl: meson: meson8: fix the GPIO function for the GPIOAO
  pins (bnc#1012628).
- bpf: sk_msg, fix socket data_ready events (bnc#1012628).
- powerpc/mm: Fix reporting of kernel execute faults on the 8xx
  (bnc#1012628).
- bpf: sk_msg, zap ingress queue on psock down (bnc#1012628).
- fbdev: fbcon: Fix unregister crash when more than one
  framebuffer (bnc#1012628).
- ACPI/APEI: Clear GHES block_status before panic() (bnc#1012628).
- igb: Fix an issue that PME is not enabled during runtime suspend
  (bnc#1012628).
- ice: Do not enable NAPI on q_vectors that have no rings
  (bnc#1012628).
- i40e: define proper net_device::neigh_priv_len (bnc#1012628).
- fbdev: fbmem: behave better with small rotated displays and
  many CPUs (bnc#1012628).
- md: fix raid10 hang issue caused by barrier (bnc#1012628).
- video: clps711x-fb: release disp device node in probe()
  (bnc#1012628).
- drm/amd/display: validate extended dongle caps (bnc#1012628).
- ath10k: fix tx_stats memory leak (bnc#1012628).
- ath10k: fix kernel panic due to use after free (bnc#1012628).
- drbd: Avoid Clang warning about pointless switch statment
  (bnc#1012628).
- drbd: skip spurious timeout (ping-timeo) when failing promote
  (bnc#1012628).
- drbd: disconnect, if the wrong UUIDs are attached on a connected
  peer (bnc#1012628).
- drbd: narrow rcu_read_lock in drbd_sync_handshake (bnc#1012628).
- mlx5: update timecounter at least twice per counter overflow
  (bnc#1012628).
- powerpc/powernv/ioda: Allocate indirect TCE levels of cached
  userspace addresses on demand (bnc#1012628).
- iwlwifi: mvm: fix setting HE ppe FW config (bnc#1012628).
- powerpc/perf: Fix thresholding counter data for unknown type
  (bnc#1012628).
- net: hns3: don't restore rules when flow director is disabled
  (bnc#1012628).
- net: hns3: fix the descriptor index when get rss type
  (bnc#1012628).
- net: hns3: add max vector number check for pf (bnc#1012628).
- cw1200: Fix concurrency use-after-free bugs in cw1200_hw_scan()
  (bnc#1012628).
- scsi: smartpqi: increase fw status register read timeout
  (bnc#1012628).
- scsi: smartpqi: correct volume status (bnc#1012628).
- scsi: smartpqi: correct host serial num for ssa (bnc#1012628).
- mlxsw: spectrum: Properly cleanup LAG uppers when removing
  port from LAG (bnc#1012628).
- xfrm6_tunnel: Fix spi check in __xfrm6_tunnel_alloc_spi
  (bnc#1012628).
- mac80211: fix radiotap vendor presence bitmap handling
  (bnc#1012628).
- powerpc/uaccess: fix warning/error with access_ok()
  (bnc#1012628).
- drm/amd/display: fix YCbCr420 blank color (bnc#1012628).
- Bluetooth: hci_bcm: Handle deferred probing for the clock supply
  (bnc#1012628).
- drm/amd/display: Wait edp HPD to high in detect_sink
  (bnc#1012628).
- drm/amd/display: Add retry to read ddc_clock pin (bnc#1012628).
- net: hns3: fix incomplete uninitialization of IRQ in the
  hns3_nic_uninit_vector_data() (bnc#1012628).
- net: hns3: fix error handling int the hns3_get_vector_ring_chain
  (bnc#1012628).
- percpu: convert spin_lock_irq to spin_lock_irqsave
  (bnc#1012628).
- perf tools: Cast off_t to s64 to avoid warning on bionic libc
  (bnc#1012628).
- perf header: Fix up argument to ctime() (bnc#1012628).
- usb: musb: dsps: fix runtime pm for peripheral mode
  (bnc#1012628).
- usb: musb: dsps: fix otg state machine (bnc#1012628).
- arm64: KVM: Skip MMIO insn after emulation (bnc#1012628).
- livepatch: check kzalloc return values (bnc#1012628).
- mac80211: Properly handle SKB with radiotap only (bnc#1012628).
- pinctrl: rza1: Handle devm_kasprintf() failure cases
  (bnc#1012628).
- tools/power/x86/intel_pstate_tracer: Fix non root execution
  for post processing a trace file (bnc#1012628).
- bnxt_en: Disable MSIX before re-reserving NQs/CMPL rings
  (bnc#1012628).
- i2c: sh_mobile: Add support for r8a774c0 (RZ/G2E) (bnc#1012628).
- perf probe: Fix unchecked usage of strncpy() (bnc#1012628).
- btrfs: use tagged writepage to mitigate livelock of snapshot
  (bnc#1012628).
- perf header: Fix unchecked usage of strncpy() (bnc#1012628).
- perf dso: Fix unchecked usage of strncpy() (bnc#1012628).
- perf test: Fix perf_event_attr test failure (bnc#1012628).
- perf stat: Fix CSV mode column output for non-cgroup events
  (bnc#1012628).
- tty: serial: samsung: Properly set flags in autoCTS mode
  (bnc#1012628).
- serial: sh-sci: Resume PIO in sci_rx_interrupt() on DMA failure
  (bnc#1012628).
- serial: sh-sci: Fix locking in sci_submit_rx() (bnc#1012628).
- btrfs: harden agaist duplicate fsid on scanned devices
  (bnc#1012628).
- usb: renesas_usbhs: add support for RZ/G2E (bnc#1012628).
- mmc: jz4740: Get CD/WP GPIOs from descriptors (bnc#1012628).
- mmc: sdhci-xenon: Fix timeout checks (bnc#1012628).
- mmc: sdhci-omap: Fix timeout checks (bnc#1012628).
- mmc: sdhci-of-esdhc: Fix timeout checks (bnc#1012628).
- memstick: Prevent memstick host from getting runtime suspended
  during card detection (bnc#1012628).
- mmc: meson-mx-sdio: check devm_kasprintf for failure
  (bnc#1012628).
- mmc: bcm2835: reset host on timeout (bnc#1012628).
- mmc: bcm2835: Recover from MMC_SEND_EXT_CSD (bnc#1012628).
- KVM: PPC: Book3S: Only report KVM_CAP_SPAPR_TCE_VFIO on powernv
  machines (bnc#1012628).
- tools: bpftool: fix -Wmissing declaration warnings
  (bnc#1012628).
- ipv6: Fix handling of LLA with VRF and sockets bound to VRF
  (bnc#1012628).
- f2fs: fix to reorder set_page_dirty and wait_on_page_writeback
  (bnc#1012628).
- clk: qcom: Leave mmss noc on for 8998 (bnc#1012628).
- fix dma-buf/udmabuf selftest (bnc#1012628).
- ASoC: fsl: Fix SND_SOC_EUKREA_TLV320 build error on i.MX8M
  (bnc#1012628).
- ARM: pxa: avoid section mismatch warning (bnc#1012628).
- selftests/bpf: use __bpf_constant_htons in test_prog.c
  (bnc#1012628).
- switchtec: Fix SWITCHTEC_IOCTL_EVENT_IDX_ALL flags overwrite
  (bnc#1012628).
- udf: Fix BUG on corrupted inode (bnc#1012628).
- mlxsw: spectrum_acl: Limit priority value (bnc#1012628).
- phy: sun4i-usb: add support for missing USB PHY index
  (bnc#1012628).
- lightnvm: Fix uninitialized return value in nvm_get_chunk_meta()
  (bnc#1012628).
- i2c-axxia: check for error conditions first (bnc#1012628).
- lightnvm: pblk: add lock protection to list operations
  (bnc#1012628).
- lightnvm: pblk: fix resubmission of overwritten write err lbas
  (bnc#1012628).
- drm/msm: dpu: Only check flush register against pending flushes
  (bnc#1012628).
- drm/msm/dsi: fix dsi clock names in DSI 10nm PLL driver
  (bnc#1012628).
- tee: optee: avoid possible double list_del() (bnc#1012628).
- OPP: Use opp_table->regulators to verify no regulator case
  (bnc#1012628).
- cpuidle: big.LITTLE: fix refcount leak (bnc#1012628).
- platform/x86: mlx-platform: Fix tachometer registers
  (bnc#1012628).
- clk: imx6sl: ensure MMDC CH0 handshake is bypassed
  (bnc#1012628).
- sata_rcar: fix deferred probing (bnc#1012628).
- iommu/arm-smmu-v3: Use explicit mb() when moving cons pointer
  (bnc#1012628).
- iommu/arm-smmu: Add support for qcom,smmu-v2 variant
  (bnc#1012628).
- iommu/arm-smmu-v3: Avoid memory corruption from Hisilicon MSI
  payloads (bnc#1012628).
- usb: dwc3: gadget: Disable CSP for stream OUT ep (bnc#1012628).
- ARM: dts: imx51-zii-rdu1: Do not specify "power-gpio" for hpa1
  (bnc#1012628).
- watchdog: renesas_wdt: don't set divider while watchdog is
  running (bnc#1012628).
- ARM: dts: Fix up the D-Link DIR-685 MTD partition info
  (bnc#1012628).
- arm64: dts: meson: Fix IRQ trigger type for macirq
  (bnc#1012628).
- media: coda: fix H.264 deblocking filter controls (bnc#1012628).
- mips: bpf: fix encoding bug for mm_srlv32_op (bnc#1012628).
- ARM: dts: Fix OMAP4430 SDP Ethernet startup (bnc#1012628).
- ARM: OMAP1: ams-delta: Fix audio permanently muted
  (bnc#1012628).
- media: v4l2-device: Link subdevices to their parent devices
  if available (bnc#1012628).
- iommu/amd: Fix amd_iommu=force_isolation (bnc#1012628).
- pinctrl: sx150x: handle failure case of devm_kstrdup
  (bnc#1012628).
- gpio: mt7621: pass mediatek_gpio_bank_probe() failure up the
  stack (bnc#1012628).
- gpio: mt7621: report failure of devm_kasprintf() (bnc#1012628).
- usb: dwc3: trace: add missing break statement to make compiler
  happy (bnc#1012628).
- IB/hfi1: Unreserve a reserved request when it is completed
  (bnc#1012628).
- kobject: return error code if writing /sys/.../uevent fails
  (bnc#1012628).
- driver core: Move async_synchronize_full call (bnc#1012628).
- arm64: dts: rockchip: fix rk3399-rockpro64 regulator gpios
  (bnc#1012628).
- tipc: fix node keep alive interval calculation (bnc#1012628).
- drm/amdgpu/powerplay: fix clock stretcher limits on polaris (v2)
  (bnc#1012628).
- pinctrl: nuvoton: check for devm_kasprintf() failure
  (bnc#1012628).
- mac80211: fix deauth TX when we disconnect (bnc#1012628).
- media: imx274: select REGMAP_I2C (bnc#1012628).
- clk: sunxi-ng: a33: Set CLK_SET_RATE_PARENT for all audio
  module clocks (bnc#1012628).
- usb: mtu3: fix the issue about SetFeature(U1/U2_Enable)
  (bnc#1012628).
- timekeeping: Use proper seqcount initializer (bnc#1012628).
- usb: hub: delay hub autosuspend if USB3 port is still link
  training (bnc#1012628).
- usb: dwc2: Disable power down feature on Samsung SoCs
  (bnc#1012628).
- dmaengine: sprd: Support DMA link-list cyclic callback
  (bnc#1012628).
- usb: dwc3: Correct the logic for checking TRB full in
  __dwc3_prepare_one_trb() (bnc#1012628).
- xtensa: xtfpga.dtsi: fix dtc warnings about SPI (bnc#1012628).
- smack: fix access permissions for keyring (bnc#1012628).
- platform/x86: Fix config space access for intel_atomisp2_pm
  (bnc#1012628).
- media: DaVinci-VPBE: fix error handling in vpbe_initialize()
  (bnc#1012628).
- media: i2c: TDA1997x: select CONFIG_HDMI (bnc#1012628).
- x86/fpu: Add might_fault() to user_insn() (bnc#1012628).
- spi: fix spi-at91-usart.c build errors when PINCTRL is not set
  (bnc#1012628).
- ARM: dts: aspeed: add missing memory unit-address (bnc#1012628).
- ARM: dts: mmp2: fix TWSI2 (bnc#1012628).
- drm/v3d: Fix prime imports of buffers from other drivers
  (bnc#1012628).
- arm64: ftrace: don't adjust the LR value (bnc#1012628).
- mt76x0: dfs: fix IBI_R11 configuration on non-radar channels
  (bnc#1012628).
- s390/zcrypt: improve special ap message cmd handling
  (bnc#1012628).
- firmware/efi: Add NULL pointer checks in efivars API functions
  (bnc#1012628).
- thermal: Fix locking in cooling device sysfs update cur_state
  (bnc#1012628).
- Thermal: do not clear passive state during system sleep
  (bnc#1012628).
- arm64: io: Ensure value passed to __iormb() is held in a 64-bit
  register (bnc#1012628).
- perf: arm_spe: handle devm_kasprintf() failure (bnc#1012628).
- drm: Clear state->acquire_ctx before leaving
  drm_atomic_helper_commit_duplicated_state() (bnc#1012628).
- nfsd4: fix crash on writing v4_end_grace before nfsd startup
  (bnc#1012628).
- soc: bcm: brcmstb: Don't leak device tree node reference
  (bnc#1012628).
- sunvdc: Do not spin in an infinite loop when vio_ldc_send()
  returns EAGAIN (bnc#1012628).
- net: aquantia: return 'err' if set MPI_DEINIT state fails
  (bnc#1012628).
- arm64: io: Ensure calls to delay routines are ordered against
  prior readX() (bnc#1012628).
- i2c: sh_mobile: add support for r8a77990 (R-Car E3)
  (bnc#1012628).
- f2fs: fix wrong return value of f2fs_acl_create (bnc#1012628).
- f2fs: fix race between write_checkpoint and write_begin
  (bnc#1012628).
- f2fs: move dir data flush to write checkpoint process
  (bnc#1012628).
- f2fs: avoid GC causing encrypted file corrupted (bnc#1012628).
- staging: pi433: fix potential null dereference (bnc#1012628).
- ACPI: SPCR: Consider baud rate 0 as preconfigured state
  (bnc#1012628).
- media: adv*/tc358743/ths8200: fill in min
  width/height/pixelclock (bnc#1012628).
- iio: accel: kxcjk1013: Add KIOX010A ACPI Hardware-ID
  (bnc#1012628).
- iio: adc: meson-saradc: fix internal clock names (bnc#1012628).
- iio: adc: meson-saradc: check for devm_kasprintf failure
  (bnc#1012628).
- powerpc/32: Add .data..Lubsan_data*/.data..Lubsan_type*
  sections explicitly (bnc#1012628).
- dmaengine: xilinx_dma: Remove __aligned attribute on
  zynqmp_dma_desc_ll (bnc#1012628).
- ptp: Fix pass zero to ERR_PTR() in ptp_clock_register
  (bnc#1012628).
- clk: meson: meson8b: mark the CPU clock as CLK_IS_CRITICAL
  (bnc#1012628).
- clk: meson: meson8b: fix the width of the cpu_scale_div clock
  (bnc#1012628).
- clk: meson: meson8b: do not use cpu_div3 for cpu_scale_out_sel
  (bnc#1012628).
- drm: rcar-du: Fix external clock error checks (bnc#1012628).
- RDMA/core: Sync unregistration with netlink commands
  (bnc#1012628).
- media: vivid: fill in media_device bus_info (bnc#1012628).
- staging: erofs: fix race when the managed cache is enabled
  (bnc#1012628).
- staging: erofs: fix the definition of DBG_BUGON (bnc#1012628).
- media: mtk-vcodec: Release device nodes in
  mtk_vcodec_init_enc_pm() (bnc#1012628).
- media: video-i2c: avoid accessing released memory area when
  removing driver (bnc#1012628).
- media: rc: ensure close() is called on rc_unregister_device
  (bnc#1012628).
- soc/tegra: Don't leak device tree node reference (bnc#1012628).
- scsi: cxgb4i: fix thermal configuration dependencies
  (bnc#1012628).
- perf tools: Add Hygon Dhyana support (bnc#1012628).
- modpost: validate symbol names also in find_elf_symbol
  (bnc#1012628).
- net/mlx5: EQ, Use the right place to store/read IRQ affinity
  hint (bnc#1012628).
- bpf: libbpf: retry map creation without the name (bnc#1012628).
- drm/amd/display: calculate stream->phy_pix_clk before clock
  mapping (bnc#1012628).
- drm/amd/display: fix gamma not being applied correctly
  (bnc#1012628).
- ARM: OMAP2+: hwmod: Fix some section annotations (bnc#1012628).
- drm/rockchip: fix for mailbox read size (bnc#1012628).
- usbnet: smsc95xx: fix rx packet alignment (bnc#1012628).
- staging: iio: ad7780: update voltage on read (bnc#1012628).
- scsi: hisi_sas: change the time of SAS SSP connection
  (bnc#1012628).
- i40e: prevent overlapping tx_timeout recover (bnc#1012628).
- i40e: suppress bogus error message (bnc#1012628).
- platform/chrome: don't report EC_MKBP_EVENT_SENSOR_FIFO as
  wakeup (bnc#1012628).
- vbox: fix link error with 'gcc -Og' (bnc#1012628).
- fpga: altera-cvp: fix 'bad IO access' on x86_64 (bnc#1012628).
- Tools: hv: kvp: Fix a warning of buffer overflow with gcc 8.0.1
  (bnc#1012628).
- fpga: altera-cvp: Fix registration for CvP incapable devices
  (bnc#1012628).
- staging:iio:ad2s90: Make probe handle spi_setup failure
  (bnc#1012628).
- iwlwifi: fw: do not set sgi bits for HE connection
  (bnc#1012628).
- dpaa2-ptp: defer probe when portal allocation failed
  (bnc#1012628).
- MIPS: Boston: Disable EG20T prefetch (bnc#1012628).
- ptp: check gettime64 return code in PTP_SYS_OFFSET ioctl
  (bnc#1012628).
- serial: fsl_lpuart: clear parity enable bit when disable parity
  (bnc#1012628).
- drm/vc4: ->x_scaling[1] should never be set to VC4_SCALING_NONE
  (bnc#1012628).
- crypto: aes_ti - disable interrupts while accessing S-box
  (bnc#1012628).
- s390/qeth: utilize virtual MAC for Layer2 OSD devices
  (bnc#1012628).
- bpftool: Improve handling of ENOENT on map dumps (bnc#1012628).
- powerpc/pseries: add of_node_put() in dlpar_detach_node()
  (bnc#1012628).
- x86/PCI: Fix Broadcom CNB20LE unintended sign extension (redux)
  (bnc#1012628).
- dlm: Don't swamp the CPU with callbacks queued during recovery
  (bnc#1012628).
- clk: boston: fix possible memory leak in clk_boston_setup()
  (bnc#1012628).
- ARM: 8808/1: kexec:offline panic_smp_self_stop CPU
  (bnc#1012628).
- scsi: lpfc: Fix LOGO/PLOGI handling when triggerd by ABTS
  Timeout event (bnc#1012628).
- scsi: mpt3sas: Call sas_remove_host before removing the target
  devices (bnc#1012628).
- scsi: lpfc: Correct LCB RJT handling (bnc#1012628).
- ath9k: dynack: use authentication messages for 'late' ack
  (bnc#1012628).
- ath10k: assign 'n_cipher_suites' for WCN3990 (bnc#1012628).
- wil6210: fix memory leak in wil_find_tx_bcast_2 (bnc#1012628).
- wil6210: fix reset flow for Talyn-mb (bnc#1012628).
- nds32: Fix gcc 8.0 compiler option incompatible (bnc#1012628).
- drm/amd/display: Fix potential nullptr error (bnc#1012628).
- gpu: ipu-v3: image-convert: Prevent race between run and
  unprepare (bnc#1012628).
- genirq/affinity: Spread IRQs to all available NUMA nodes
  (bnc#1012628).
- ath10k: fixup extended per sta tx statistics (bnc#1012628).
- drm/sun4i: Initialize registers in tcon-top driver
  (bnc#1012628).
- gpiolib: Fix possible use after free on label (bnc#1012628).
- ASoC: Intel: mrfld: fix uninitialized variable access
  (bnc#1012628).
- clk: sunxi-ng: h6: Set video PLLs limits (bnc#1012628).
- pinctrl: bcm2835: Use raw spinlock for RT compatibility
  (bnc#1012628).
- drm/vgem: Fix vgem_init to get drm device available
  (bnc#1012628).
- staging: iio: adc: ad7280a: handle error from __ad7280_read32()
  (bnc#1012628).
- drm/v3d: Fix a use-after-free race accessing the scheduler's
  fences (bnc#1012628).
- drm/bufs: Fix Spectre v1 vulnerability (bnc#1012628).
- commit 02864b1
* Mon Feb 11 2019 mkubecek@suse.cz
- Update to 5.0-rc6
- commit eb4b248
* Fri Feb  8 2019 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Build livepatch support in SUSE release
  projects (bsc#1124167).
- commit 7519080
* Thu Feb  7 2019 jslaby@suse.cz
- Linux 4.20.7 (bnc#1012628).
- drm/msm/gpu: fix building without debugfs (bnc#1012628).
- ipv6: sr: clear IP6CB(skb) on SRH ip4ip6 encapsulation
  (bnc#1012628).
- ipvlan, l3mdev: fix broken l3s mode wrt local routes
  (bnc#1012628).
- l2tp: copy 4 more bytes to linear part if necessary
  (bnc#1012628).
- l2tp: fix reading optional fields of L2TPv3 (bnc#1012628).
- net: ip_gre: always reports o_key to userspace (bnc#1012628).
- net: ip_gre: use erspan key field for tunnel lookup
  (bnc#1012628).
- net/ipv6: don't return positive numbers when nothing was dumped
  (bnc#1012628).
- net/mlx4_core: Add masking for a few queries on HCA caps
  (bnc#1012628).
- netrom: switch to sock timer API (bnc#1012628).
- net/rose: fix NULL ax25_cb kernel panic (bnc#1012628).
- net: set default network namespace in init_dummy_netdev()
  (bnc#1012628).
- ravb: expand rx descriptor data to accommodate hw checksum
  (bnc#1012628).
- sctp: improve the events for sctp stream reset (bnc#1012628).
- tun: move the call to tun_set_real_num_queues (bnc#1012628).
- ucc_geth: Reset BQL queue when stopping device (bnc#1012628).
- vhost: fix OOB in get_rx_bufs() (bnc#1012628).
- net: ip6_gre: always reports o_key to userspace (bnc#1012628).
- sctp: improve the events for sctp stream adding (bnc#1012628).
- net/mlx5e: Allow MAC invalidation while spoofchk is ON
  (bnc#1012628).
- ip6mr: Fix notifiers call on mroute_clean_tables()
  (bnc#1012628).
- Revert "net/mlx5e: E-Switch, Initialize eswitch only if eswitch
  manager" (bnc#1012628).
- sctp: set chunk transport correctly when it's a new asoc
  (bnc#1012628).
- sctp: set flow sport from saddr only when it's 0 (bnc#1012628).
- net: tls: Fix deadlock in free_resources tx (bnc#1012628).
- net: tls: Save iv in tls_rec for async crypto requests
  (bnc#1012628).
- virtio_net: Don't enable NAPI when interface is down
  (bnc#1012628).
- virtio_net: Don't call free_old_xmit_skbs for xdp_frames
  (bnc#1012628).
- virtio_net: Fix not restoring real_num_rx_queues (bnc#1012628).
- virtio_net: Fix out of bounds access of sq (bnc#1012628).
- virtio_net: Don't process redirected XDP frames when XDP is
  disabled (bnc#1012628).
- virtio_net: Use xdp_return_frame to free xdp_frames on
  destroying vqs (bnc#1012628).
- virtio_net: Differentiate sk_buff and xdp_frame on freeing
  (bnc#1012628).
- ipv6: Consider sk_bound_dev_if when binding a socket to an
  address (bnc#1012628).
- CIFS: Do not count -ENODATA as failure for query directory
  (bnc#1012628).
- CIFS: Fix possible oops and memory leaks in async IO
  (bnc#1012628).
- CIFS: Fix trace command logging for SMB2 reads and writes
  (bnc#1012628).
- CIFS: fix use-after-free of the lease keys (bnc#1012628).
- CIFS: Do not consider -ENODATA as stat failure for reads
  (bnc#1012628).
- fs/dcache: Fix incorrect nr_dentry_unused accounting in
  shrink_dcache_sb() (bnc#1012628).
- iommu/vt-d: Fix memory leak in intel_iommu_put_resv_regions()
  (bnc#1012628).
- selftests/seccomp: Enhance per-arch ptrace syscall skip tests
  (bnc#1012628).
- NFS: Fix up return value on fatal errors in
  nfs_page_async_flush() (bnc#1012628).
- ARM: cns3xxx: Fix writing to wrong PCI config registers after
  alignment (bnc#1012628).
- arm64: kaslr: ensure randomized quantities are clean also when
  kaslr is off (bnc#1012628).
- arm64: Do not issue IPIs for user executable ptes (bnc#1012628).
- arm64: hyp-stub: Forbid kprobing of the hyp-stub (bnc#1012628).
- arm64: hibernate: Clean the __hyp_text to PoC after resume
  (bnc#1012628).
- gpio: altera-a10sr: Set proper output level for direction_output
  (bnc#1012628).
- gpiolib: fix line event timestamps for nested irqs
  (bnc#1012628).
- gpio: pcf857x: Fix interrupts on multiple instances
  (bnc#1012628).
- gpio: sprd: Fix the incorrect data register (bnc#1012628).
- gpio: sprd: Fix incorrect irq type setting for the async EIC
  (bnc#1012628).
- gfs2: Revert "Fix loop in gfs2_rbm_find" (bnc#1012628).
- mmc: bcm2835: Fix DMA channel leak on probe error (bnc#1012628).
- mmc: mediatek: fix incorrect register setting of
  hs400_cmd_int_delay (bnc#1012628).
- ALSA: usb-audio: Add Opus #3 to quirks for native DSD support
  (bnc#1012628).
- ALSA: hda/realtek - Fixed hp_pin no value (bnc#1012628).
- ALSA: pcm: Fix tight loop of OSS capture stream (bnc#1012628).
- IB/uverbs: Fix OOPs upon device disassociation (bnc#1012628).
- IB/uverbs: Fix OOPs in uverbs_user_mmap_disassociate
  (bnc#1012628).
- IB/hfi1: Remove overly conservative VM_EXEC flag check
  (bnc#1012628).
- IB/hfi1: Add limit test for RC/UC send via loopback
  (bnc#1012628).
- platform/x86: asus-nb-wmi: Map 0x35 to KEY_SCREENLOCK
  (bnc#1012628).
- platform/x86: asus-nb-wmi: Drop mapping of 0x33 and 0x34 scan
  codes (bnc#1012628).
- Btrfs: fix deadlock when allocating tree block during leaf/node
  split (bnc#1012628).
- btrfs: On error always free subvol_name in btrfs_mount
  (bnc#1012628).
- kernel/exit.c: release ptraced tasks before zap_pid_ns_processes
  (bnc#1012628).
- mm/hugetlb.c: teach follow_hugetlb_page() to handle FOLL_NOWAIT
  (bnc#1012628).
- oom, oom_reaper: do not enqueue same task twice (bnc#1012628).
- mm,memory_hotplug: fix scan_movable_pages() for gigantic
  hugepages (bnc#1012628).
- mm, oom: fix use-after-free in oom_kill_process (bnc#1012628).
- mm: hwpoison: use do_send_sig_info() instead of force_sig()
  (bnc#1012628).
- mm: migrate: don't rely on __PageMovable() of newpage after
  unlocking it (bnc#1012628).
- of: overlay: add tests to validate kfrees from overlay removal
  (bnc#1012628).
- of: overlay: add missing of_node_get() in __of_attach_node_sysfs
  (bnc#1012628).
- of: overlay: use prop add changeset entry for property in new
  nodes (bnc#1012628).
- of: overlay: do not duplicate properties from overlay for new
  nodes (bnc#1012628).
- md/raid5: fix 'out of memory' during raid cache recovery
  (bnc#1012628).
- cifs: Always resolve hostname before reconnecting (bnc#1012628).
- Refresh
  patches.suse/btrfs-8447-serialize-subvolume-mounts-with-potentially-mi.patch.
- commit 730812f
* Mon Feb  4 2019 mkubecek@suse.cz
- Update to 5.0-rc5
- Config changes:
  - x86:
  - X86_RESCTRL renamed to X86_CPU_RESCTRL
- commit a42dcc6
* Thu Jan 31 2019 jslaby@suse.cz
- Linux 4.20.6 (bnc#1012628).
- amd-xgbe: Fix mdio access for non-zero ports and clause 45 PHYs
  (bnc#1012628).
- net: bridge: Fix ethernet header pointer before check skb
  forwardable (bnc#1012628).
- net: Fix usage of pskb_trim_rcsum (bnc#1012628).
- net: phy: marvell: Errata for mv88e6390 internal PHYs
  (bnc#1012628).
- net: phy: mdio_bus: add missing device_del() in
  mdiobus_register() error handling (bnc#1012628).
- net: phy: phy driver features are mandatory (bnc#1012628).
- net/sched: act_tunnel_key: fix memory leak in case of action
  replace (bnc#1012628).
- net_sched: refetch skb protocol for each filter (bnc#1012628).
- openvswitch: Avoid OOB read when parsing flow nlattrs
  (bnc#1012628).
- vhost: log dirty page correctly (bnc#1012628).
- mlxsw: pci: Increase PCI SW reset timeout (bnc#1012628).
- net: ipv4: Fix memory leak in network namespace dismantle
  (bnc#1012628).
- mlxsw: spectrum_fid: Update dummy FID index (bnc#1012628).
- mlxsw: pci: Ring CQ's doorbell before RDQ's (bnc#1012628).
- net/sched: cls_flower: allocate mask dynamically in fl_change()
  (bnc#1012628).
- udp: with udp_segment release on error path (bnc#1012628).
- ip6_gre: fix tunnel list corruption for x-netns (bnc#1012628).
- erspan: build the header with the right proto according to
  erspan_ver (bnc#1012628).
- net: phy: marvell: Fix deadlock from wrong locking
  (bnc#1012628).
- ip6_gre: update version related info when changing link
  (bnc#1012628).
- tcp: allow MSG_ZEROCOPY transmission also in CLOSE_WAIT state
  (bnc#1012628).
- ARM: fix the cockup in the previous patch (bnc#1012628).
- SUNRPC: Address Kerberos performance/behavior regression
  (bnc#1012628).
- mei: me: mark LBG devices as having dma support (bnc#1012628).
- mei: me: add denverton innovation engine device IDs
  (bnc#1012628).
- USB: leds: fix regression in usbport led trigger (bnc#1012628).
- USB: EHCI: ehci-mv: add MODULE_DEVICE_TABLE (bnc#1012628).
- USB: serial: ftdi_sio: fix GPIO not working in autosuspend
  (bnc#1012628).
- USB: serial: simple: add Motorola Tetra TPG2200 device id
  (bnc#1012628).
- USB: serial: pl2303: add new PID to support PL2303TB
  (bnc#1012628).
- ceph: clear inode pointer when snap realm gets dropped by its
  inode (bnc#1012628).
- ASoC: atom: fix a missing check of snd_pcm_lib_malloc_pages
  (bnc#1012628).
- ASoC: rt5514-spi: Fix potential NULL pointer dereference
  (bnc#1012628).
- ASoC: tlv320aic32x4: Kernel OOPS while entering DAPM standby
  mode (bnc#1012628).
- clk: zynqmp: Fix memory allocation in zynqmp_clk_setup
  (bnc#1012628).
- clk: socfpga: stratix10: fix rate calculation for pll clocks
  (bnc#1012628).
- clk: socfpga: stratix10: fix naming convention for the
  fixed-clocks (bnc#1012628).
- inotify: Fix fd refcount leak in inotify_add_watch()
  (bnc#1012628).
- ALSA: hda/realtek - Fix typo for ALC225 model (bnc#1012628).
- ALSA: hda - Add mute LED support for HP ProBook 470 G5
  (bnc#1012628).
- ARCv2: lib: memeset: fix doing prefetchw outside of buffer
  (bnc#1012628).
- ARC: adjust memblock_reserve of kernel memory (bnc#1012628).
- ARC: perf: map generic branches to correct hardware condition
  (bnc#1012628).
- s390/vdso: correct vdso mapping for compat tasks (bnc#1012628).
- s390/mm: always force a load of the primary ASCE on context
  switch (bnc#1012628).
- s390/early: improve machine detection (bnc#1012628).
- s390/smp: fix CPU hotplug deadlock with CPU rescan
  (bnc#1012628).
- s390/smp: Fix calling smp_call_ipl_cpu() from ipl CPU
  (bnc#1012628).
- misc: ibmvsm: Fix potential NULL pointer dereference
  (bnc#1012628).
- char/mwave: fix potential Spectre v1 vulnerability
  (bnc#1012628).
- mmc: sdhci-iproc: handle mmc_of_parse() errors during probe
  (bnc#1012628).
- mmc: dw_mmc-bluefield: : Fix the license information
  (bnc#1012628).
- mmc: meson-gx: Free irq in release() callback (bnc#1012628).
- staging: rtl8188eu: Add device code for D-Link DWA-121 rev B1
  (bnc#1012628).
- tty: Handle problem if line discipline does not have receive_buf
  (bnc#1012628).
- uart: Fix crash in uart_write and uart_put_char (bnc#1012628).
- tty/n_hdlc: fix __might_sleep warning (bnc#1012628).
- hv_balloon: avoid touching uninitialized struct page during
  tail onlining (bnc#1012628).
- Drivers: hv: vmbus: Check for ring when getting debug info
  (bnc#1012628).
- vgacon: unconfuse vc_origin when using soft scrollback
  (bnc#1012628).
- CIFS: Fix possible hang during async MTU reads and writes
  (bnc#1012628).
- CIFS: Fix credits calculations for reads with errors
  (bnc#1012628).
- CIFS: Fix credit calculation for encrypted reads with errors
  (bnc#1012628).
- CIFS: Do not reconnect TCP session in add_credits()
  (bnc#1012628).
- smb3: add credits we receive from oplock/break PDUs
  (bnc#1012628).
- Input: xpad - add support for SteelSeries Stratus Duo
  (bnc#1012628).
- Input: input_event - provide override for sparc64 (bnc#1012628).
- Input: uinput - fix undefined behavior in
  uinput_validate_absinfo() (bnc#1012628).
- acpi/nfit: Block function zero DSMs (bnc#1012628).
- acpi/nfit: Fix command-supported detection (bnc#1012628).
- scsi: ufs: Use explicit access size in ufshcd_dump_regs
  (bnc#1012628).
- dm thin: fix passdown_double_checking_shared_status()
  (bnc#1012628).
- dm crypt: fix parsing of extended IV arguments (bnc#1012628).
- drm/amdgpu: Add APTX quirk for Lenovo laptop (bnc#1012628).
- EDAC, altera: Fix S10 persistent register offset (bnc#1012628).
- KVM: x86: Fix single-step debugging (bnc#1012628).
- KVM: x86: Fix PV IPIs for 32-bit KVM host (bnc#1012628).
- KVM: x86: WARN_ONCE if sending a PV IPI returns a fatal error
  (bnc#1012628).
- kvm: x86/vmx: Use kzalloc for cached_vmcs12 (bnc#1012628).
- x86/pkeys: Properly copy pkey state at fork() (bnc#1012628).
- x86/selftests/pkeys: Fork() to check for state being preserved
  (bnc#1012628).
- x86/kaslr: Fix incorrect i8254 outb() parameters (bnc#1012628).
- x86/entry/64/compat: Fix stack switching for XEN PV
  (bnc#1012628).
- posix-cpu-timers: Unbreak timer rearming (bnc#1012628).
- net: sun: cassini: Cleanup license conflict (bnc#1012628).
- irqchip/gic-v3-its: Align PCI Multi-MSI allocation on their size
  (bnc#1012628).
- can: dev: __can_get_echo_skb(): fix bogous check for
  non-existing skb by removing it (bnc#1012628).
- can: bcm: check timer values before ktime conversion
  (bnc#1012628).
- can: flexcan: fix NULL pointer exception during bringup
  (bnc#1012628).
- vt: make vt_console_print() compatible with the unicode screen
  buffer (bnc#1012628).
- vt: always call notifier with the console lock held
  (bnc#1012628).
- vt: invoke notifier on screen size change (bnc#1012628).
- drm/meson: Fix atomic mode switching regression (bnc#1012628).
- bpf: move {prev_,}insn_idx into verifier env (bnc#1012628).
- bpf: move tmp variable into ax register in interpreter
  (bnc#1012628).
- nvmet-rdma: Add unlikely for response allocated check
  (bnc#1012628).
- nvmet-rdma: fix null dereference under heavy load (bnc#1012628).
- bpf: enable access to ax register also from verifier rewrite
  (bnc#1012628).
- bpf: restrict map value pointer arithmetic for unprivileged
  (bnc#1012628).
- bpf: restrict stack pointer arithmetic for unprivileged
  (bnc#1012628).
- bpf: restrict unknown scalars of mixed signed bounds for
  unprivileged (bnc#1012628).
- bpf: fix check_map_access smin_value test when pointer contains
  offset (bnc#1012628).
- bpf: prevent out of bounds speculation on pointer arithmetic
  (bnc#1012628).
- bpf: fix sanitation of alu op with pointer / scalar type from
  different paths (bnc#1012628).
- bpf: fix inner map masking to prevent oob under speculation
  (bnc#1012628).
- Drivers: hv: vmbus: Remove the useless API
  vmbus_get_outgoing_channel() (bnc#1012628).
- vmbus: fix subchannel removal (bnc#1012628).
- Revert "mm, memory_hotplug: initialize struct pages for the
  full memory section" (bnc#1012628).
- usb: dwc3: gadget: Clear req->needs_extra_trb flag on cleanup
  (bnc#1012628).
- mt76x0: do not overwrite other MT_BBP(AGC, 8) fields
  (bnc#1012628).
- mt76x0: use band parameter for LC calibration (bnc#1012628).
- mt76x02: run calibration after scanning (bnc#1012628).
- mt76x02: assure we update gain after scan (bnc#1012628).
- mt76x0: do not perform MCU calibration for MT7630 (bnc#1012628).
- mt76x0: antenna select corrections (bnc#1012628).
- mt76x0: phy: unify calibration between mt76x0u and mt76x0e
  (bnc#1012628).
- ide: fix a typo in the settings proc file name (bnc#1012628).
- Input: input_event - fix the CONFIG_SPARC64 mixup (bnc#1012628).
- Refresh
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- commit 463cfd2
* Wed Jan 30 2019 mwilck@suse.com
- rpm/kernel-binary.spec.in: fix initrd permissions (bsc#1123697)
  dracut has been using permissions 0600 for the initrd for a long
  time. On SLE15 or higher, that leads to a permission mismatch
  reported by "rpm -V". Set the permissions correctly for our
  ghost file.
- commit 9e5e2a5
* Wed Jan 30 2019 mwilck@suse.com
- config files: set CONFIG_SCSI_MQ_DEFAULT=y (bsc#1122182)
  Kernel 4.20 and newer use blk_mq for device mapper exclusively.
  Thus stacking device mapper on SCSI devices fails unless we
  use blk_mq for SCSI devices as well.
- commit 0a5bbbc
* Mon Jan 28 2019 tiwai@suse.de
- doc/README.SUSE: Correct description for building a kernel (bsc#1123348)
  The obsoleted make cloneconfig is corrected.  Also the order of make
  scripts and make prepare are corrected as well.
- commit 17a2073
* Mon Jan 28 2019 tiwai@suse.de
- rpm/release-projects: Add SUSE:Maintenance:* for MU kernels (bsc#1123317)
- commit c784b79
* Mon Jan 28 2019 mkubecek@suse.cz
- Update to 5.0-rc4
- commit 8e6abff
* Sat Jan 26 2019 jslaby@suse.cz
- Linux 4.20.5 (bnc#1012628).
- ipmi:ssif: Fix handling of multi-part return messages
  (bnc#1012628).
- ipmi: Prevent use-after-free in deliver_response (bnc#1012628).
- ipmi: msghandler: Fix potential Spectre v1 vulnerabilities
  (bnc#1012628).
- ipmi: Don't initialize anything in the core until something
  uses it (bnc#1012628).
- ipmi: fix use-after-free of user->release_barrier.rda
  (bnc#1012628).
- Bluetooth: Fix unnecessary error message for HCI request
  completion (bnc#1012628).
- drm/amd/display: Fix disabled cursor on top screen edge
  (bnc#1012628).
- mm/memblock.c: skip kmemleak for kasan_init() (bnc#1012628).
- mm, proc: be more verbose about unstable VMA flags in
  /proc/<pid>/smaps (bnc#1012628).
- userfaultfd: clear flag if remap event not enabled
  (bnc#1012628).
- mm/swap: use nr_node_ids for avail_lists in swap_info_struct
  (bnc#1012628).
- mm/page-writeback.c: don't break integrity writeback on
  - >writepage() error (bnc#1012628).
- ocfs2: fix panic due to unrecovered local alloc (bnc#1012628).
- iomap: don't search past page end in iomap_is_partially_uptodate
  (bnc#1012628).
- scsi: megaraid: fix out-of-bound array accesses (bnc#1012628).
- KVM: PPC: Book3S HV: Apply combination of host and l1 pte rc
  for nested guest (bnc#1012628).
- KVM: PPC: Book3S HV: Align gfn to L1 page size when inserting
  nest-rmap entry (bnc#1012628).
- scsi: smartpqi: call pqi_free_interrupts() in pqi_shutdown()
  (bnc#1012628).
- ath10k: fix peer stats null pointer dereference (bnc#1012628).
- scsi: smartpqi: correct lun reset issues (bnc#1012628).
- scsi: mpt3sas: fix memory ordering on 64bit writes
  (bnc#1012628).
- IB/usnic: Fix potential deadlock (bnc#1012628).
- sysfs: Disable lockdep for driver bind/unbind files
  (bnc#1012628).
- ALSA: bebob: fix model-id of unit for Apogee Ensemble
  (bnc#1012628).
- Bluetooth: btusb: Add support for Intel bluetooth device
  8087:0029 (bnc#1012628).
- dm: Check for device sector overflow if CONFIG_LBDAF is not set
  (bnc#1012628).
- clocksource/drivers/integrator-ap: Add missing of_node_put()
  (bnc#1012628).
- quota: Lock s_umount in exclusive mode for Q_XQUOTA{ON,OFF}
  quotactls (bnc#1012628).
- perf tools: Add missing open_memstream() prototype for systems
  lacking it (bnc#1012628).
- perf tools: Add missing sigqueue() prototype for systems
  lacking it (bnc#1012628).
- perf cs-etm: Correct packets swapping in cs_etm__flush()
  (bnc#1012628).
- dm snapshot: Fix excessive memory usage and workqueue stalls
  (bnc#1012628).
- tools lib subcmd: Don't add the kernel sources to the include
  path (bnc#1012628).
- perf stat: Avoid segfaults caused by negated options
  (bnc#1012628).
- dm kcopyd: Fix bug causing workqueue stalls (bnc#1012628).
- dm crypt: use u64 instead of sector_t to store iv_offset
  (bnc#1012628).
- x86/topology: Use total_cpus for max logical packages
  calculation (bnc#1012628).
- netfilter: ipt_CLUSTERIP: fix deadlock in netns exit routine
  (bnc#1012628).
- netfilter: ipt_CLUSTERIP: remove wrong WARN_ON_ONCE in netns
  exit routine (bnc#1012628).
- netfilter: ipt_CLUSTERIP: check MAC address when duplicate
  config is set (bnc#1012628).
- perf vendor events intel: Fix Load_Miss_Real_Latency on SKL/SKX
  (bnc#1012628).
- perf parse-events: Fix unchecked usage of strncpy()
  (bnc#1012628).
- perf svghelper: Fix unchecked usage of strncpy() (bnc#1012628).
- perf tests ARM: Disable breakpoint tests 32-bit (bnc#1012628).
- perf intel-pt: Fix error with config term "pt=0" (bnc#1012628).
- tools lib traceevent: Fix compile warnings in
  tools/lib/traceevent/event-parse.c (bnc#1012628).
- tty/serial: do not free trasnmit buffer page under port lock
  (bnc#1012628).
- btrfs: improve error handling of btrfs_add_link (bnc#1012628).
- btrfs: fix use-after-free due to race between replace start
  and cancel (bnc#1012628).
- btrfs: alloc_chunk: fix more DUP stripe size handling
  (bnc#1012628).
- btrfs: volumes: Make sure there is no overlap of dev extents
  at mount time (bnc#1012628).
- mmc: atmel-mci: do not assume idle after atmci_request_end
  (bnc#1012628).
- kconfig: fix memory leak when EOF is encountered in quotation
  (bnc#1012628).
- kconfig: fix file name and line number of
  warn_ignored_character() (bnc#1012628).
- x86/resctrl: Fix rdt_find_domain() return value and checks
  (bnc#1012628).
- usb: dwc2: Fix disable all EP's on disconnect (bnc#1012628).
- bpf: relax verifier restriction on BPF_MOV | BPF_ALU
  (bnc#1012628).
- arm64: Fix minor issues with the dcache_by_line_op macro
  (bnc#1012628).
- clk: imx6q: reset exclusive gates on init (bnc#1012628).
- arm64: kasan: Increase stack size for KASAN_EXTRA (bnc#1012628).
- selftests: do not macro-expand failed assertion expressions
  (bnc#1012628).
- scsi: target/core: Make sure that target_wait_for_sess_cmds()
  waits long enough (bnc#1012628).
- scsi: target: use consistent left-aligned ASCII INQUIRY data
  (bnc#1012628).
- net: call sk_dst_reset when set SO_DONTROUTE (bnc#1012628).
- staging: erofs: fix use-after-free of on-stack
  `z_erofs_vle_unzip_io' (bnc#1012628).
- media: venus: core: Set dma maximum segment size (bnc#1012628).
- coresight: tmc: Fix bad register address for CLAIM
  (bnc#1012628).
- ASoC: use dma_ops of parent device for acp_audio_dma
  (bnc#1012628).
- media: firewire: Fix app_info parameter type in
  avc_ca{,_app}_info (bnc#1012628).
- arm64: relocatable: fix inconsistencies in linker script and
  options (bnc#1012628).
- powerpc/pseries/cpuidle: Fix preempt warning (bnc#1012628).
- powerpc/xmon: Fix invocation inside lock region (bnc#1012628).
- media: uvcvideo: Refactor teardown of uvc on USB disconnect
  (bnc#1012628).
- pstore/ram: Do not treat empty buffers as valid (bnc#1012628).
- clk: imx: make mux parent strings const (bnc#1012628).
- kbuild: let fixdep directly write to .*.cmd files (bnc#1012628).
- jffs2: Fix use of uninitialized delayed_work, lockdep breakage
  (bnc#1012628).
- efi/libstub: Disable some warnings for x86{,_64} (bnc#1012628).
- rxe: IB_WR_REG_MR does not capture MR's iova field
  (bnc#1012628).
- drm/amdgpu: Reorder uvd ring init before uvd resume
  (bnc#1012628).
- net: ethernet: ave: Set initial wol state to disabled
  (bnc#1012628).
- scsi: qedi: Check for session online before getting iSCSI TLV
  data (bnc#1012628).
- ASoC: pcm3168a: Don't disable pcm3168a when CONFIG_PM defined
  (bnc#1012628).
- arm64: Use a raw spinlock in __install_bp_hardening_cb()
  (bnc#1012628).
- selinux: always allow mounting submounts (bnc#1012628).
- fpga: altera-cvp: fix probing for multiple FPGAs on the bus
  (bnc#1012628).
- usb: gadget: udc: renesas_usb3: add a safety connection way
  for forced_b_device (bnc#1012628).
- samples: bpf: fix: error handling regarding kprobe_events
  (bnc#1012628).
- clk: meson: meson8b: fix incorrect divider mapping in
  cpu_scale_table (bnc#1012628).
- clk: meson: meson8b: add support for more M/N values in sys_pll
  (bnc#1012628).
- drm/atomic-helper: Complete fake_commit->flip_done potentially
  earlier (bnc#1012628).
- MIPS: Loongson: Add Loongson-3A R2.1 basic support
  (bnc#1012628).
- arm64: perf: set suppress_bind_attrs flag to true (bnc#1012628).
- drm/scheduler: Fix bad job be re-processed in TDR (bnc#1012628).
- crypto: ecc - regularize scalar for scalar multiplication
  (bnc#1012628).
- MIPS: SiByte: Enable swiotlb for SWARM, LittleSur and BigSur
  (bnc#1012628).
- x86/mce: Fix -Wmissing-prototypes warnings (bnc#1012628).
- ALSA: oxfw: add support for APOGEE duet FireWire (bnc#1012628).
- bpf: Allow narrow loads with offset > 0 (bnc#1012628).
- serial: set suppress_bind_attrs flag only if builtin
  (bnc#1012628).
- writeback: don't decrement wb->refcnt if !wb->bdi (bnc#1012628).
- of: overlay: add missing of_node_put() after add new node to
  changeset (bnc#1012628).
- selftests/bpf: enable (uncomment) all tests in test_libbpf.sh
  (bnc#1012628).
- usb: typec: tcpm: Do not disconnect link for self powered
  devices (bnc#1012628).
- e1000e: allow non-monotonic SYSTIM readings (bnc#1012628).
- platform/x86: asus-wmi: Tell the EC the OS will handle the
  display off hotkey (bnc#1012628).
- ixgbe: allow IPsec Tx offload in VEPA mode (bnc#1012628).
- qtnfmac: fix error handling in control path (bnc#1012628).
- drm/amdkfd: fix interrupt spin lock (bnc#1012628).
- drm/amd/display: Guard against null stream_state in
  set_crc_source (bnc#1012628).
- ASoC: wm97xx: fix uninitialized regmap pointer problem
  (bnc#1012628).
- gpio: pl061: Move irq_chip definition inside struct pl061
  (bnc#1012628).
- netfilter: ipset: Allow matching on destination MAC address
  for mac and ipmac sets (bnc#1012628).
- net: clear skb->tstamp in bridge forwarding path (bnc#1012628).
- openvswitch: Fix IPv6 later frags parsing (bnc#1012628).
- octeontx2-af: Fix a resource leak in an error handling path in
  'cgx_probe()' (bnc#1012628).
- netlink: fixup regression in RTM_GETADDR (bnc#1012628).
- ipv6: Fix dump of specific table with strict checking
  (bnc#1012628).
- ipv6: Take rcu_read_lock in __inet6_bind for mapped addresses
  (bnc#1012628).
- r8169: Add support for new Realtek Ethernet (bnc#1012628).
- qmi_wwan: add MTU default to qmap network interface
  (bnc#1012628).
- net, skbuff: do not prefer skb allocation fails early
  (bnc#1012628).
- net: dsa: mv88x6xxx: mv88e6390 errata (bnc#1012628).
- mlxsw: spectrum_switchdev: Set PVID correctly during VLAN
  deletion (bnc#1012628).
- mlxsw: spectrum: Disable lag port TX before removing it
  (bnc#1012628).
- ipv6: Consider sk_bound_dev_if when binding a socket to a v4
  mapped address (bnc#1012628).
- commit 34ae151
* Thu Jan 24 2019 ptesarik@suse.cz
- Add product identifying information to VMCOREINFO (bsc#1123015).
- commit 68ca35e
* Thu Jan 24 2019 msuchanek@suse.de
- rpm/kernel-*.spec.in: replace update srchash dependencies (FATE#325312).
  Due to some limitations version cannot be matched so move the hash into
  the provide name.
- commit 219bcec
* Wed Jan 23 2019 jslaby@suse.cz
- Linux 4.20.4 (bnc#1012628).
- tty/ldsem: Wake up readers after timed out down_write()
  (bnc#1012628).
- tty: Hold tty_ldisc_lock() during tty_reopen() (bnc#1012628).
- tty: Simplify tty->count math in tty_reopen() (bnc#1012628).
- tty: Don't hold ldisc lock in tty_reopen() if ldisc present
  (bnc#1012628).
- can: gw: ensure DLC boundaries after CAN frame modification
  (bnc#1012628).
- netfilter: nf_conncount: replace CONNCOUNT_LOCK_SLOTS with
  CONNCOUNT_SLOTS (bnc#1012628).
- netfilter: nf_conncount: don't skip eviction when age is
  negative (bnc#1012628).
- netfilter: nf_conncount: split gc in two phases (bnc#1012628).
- netfilter: nf_conncount: restart search when nodes have been
  erased (bnc#1012628).
- netfilter: nf_conncount: merge lookup and add functions
  (bnc#1012628).
- netfilter: nf_conncount: move all list iterations under spinlock
  (bnc#1012628).
- netfilter: nf_conncount: speculative garbage collection on
  empty lists (bnc#1012628).
- netfilter: nf_conncount: fix argument order to find_next_bit
  (bnc#1012628).
- mmc: sdhci-msm: Disable CDR function on TX (bnc#1012628).
- arm64/kvm: consistently handle host HCR_EL2 flags (bnc#1012628).
- arm64: Don't trap host pointer auth use to EL2 (bnc#1012628).
- ipv6: fix kernel-infoleak in ipv6_local_error() (bnc#1012628).
- net: bridge: fix a bug on using a neighbour cache entry without
  checking its state (bnc#1012628).
- packet: Do not leak dev refcounts on error exit (bnc#1012628).
- tcp: change txhash on SYN-data timeout (bnc#1012628).
- tun: publish tfile after it's fully initialized (bnc#1012628).
- net: phy: add missing phy driver features (bnc#1012628).
- net: phy: Add missing features to PHY drivers (bnc#1012628).
- net: phy: meson-gxl: Use the genphy_soft_reset callback
  (bnc#1012628).
- lan743x: Remove phy_read from link status change function
  (bnc#1012628).
- IN_BADCLASS: fix macro to actually work (bnc#1012628).
- r8169: load Realtek PHY driver module before r8169
  (bnc#1012628).
- bonding: update nest level on unlink (bnc#1012628).
- ip: on queued skb use skb_header_pointer instead of
  pskb_may_pull (bnc#1012628).
- r8169: don't try to read counters if chip is in a PCI power-save
  state (bnc#1012628).
- smc: move unhash as early as possible in smc_release()
  (bnc#1012628).
- crypto: sm3 - fix undefined shift by >= width of value
  (bnc#1012628).
- crypto: caam - fix zero-length buffer DMA mapping (bnc#1012628).
- crypto: authencesn - Avoid twice completion call in decrypt path
  (bnc#1012628).
- crypto: ccree - convert to use crypto_authenc_extractkeys()
  (bnc#1012628).
- crypto: bcm - convert to use crypto_authenc_extractkeys()
  (bnc#1012628).
- crypto: authenc - fix parsing key with misaligned rta_len
  (bnc#1012628).
- crypto: talitos - reorder code in talitos_edesc_alloc()
  (bnc#1012628).
- crypto: talitos - fix ablkcipher for CONFIG_VMAP_STACK
  (bnc#1012628).
- xen: Fix x86 sched_clock() interface for xen (bnc#1012628).
- Revert "btrfs: balance dirty metadata pages in
  btrfs_finish_ordered_io" (bnc#1012628).
- btrfs: wait on ordered extents on abort cleanup (bnc#1012628).
- Yama: Check for pid death before checking ancestry
  (bnc#1012628).
- scsi: core: Synchronize request queue PM status only on
  successful resume (bnc#1012628).
- scsi: sd: Fix cache_type_store() (bnc#1012628).
- virtio: don't allocate vqs when names[i] = NULL (bnc#1012628).
- virtio-balloon: tweak config_changed implementation
  (bnc#1012628).
- mips: fix n32 compat_ipc_parse_version (bnc#1012628).
- MIPS: BCM47XX: Setup struct device for the SoC (bnc#1012628).
- MIPS: lantiq: Fix IPI interrupt handling (bnc#1012628).
- MIPS: OCTEON: fix kexec support (bnc#1012628).
- drm/i915/gvt: Fix mmap range check (bnc#1012628).
- drm/rockchip: add missing of_node_put (bnc#1012628).
- OF: properties: add missing of_node_put (bnc#1012628).
- mfd: tps6586x: Handle interrupts on suspend (bnc#1012628).
- media: v4l: ioctl: Validate num_planes for debug messages
  (bnc#1012628).
- media: vim2m: only cancel work if it is for right context
  (bnc#1012628).
- RDMA/nldev: Don't expose unsafe global rkey to regular user
  (bnc#1012628).
- RDMA/vmw_pvrdma: Return the correct opcode when creating WR
  (bnc#1012628).
- kbuild: Disable LD_DEAD_CODE_DATA_ELIMINATION with ftrace &
  GCC <= 4.7 (bnc#1012628).
- kbuild: fix single target build for external module
  (bnc#1012628).
- kbuild: mark prepare0 as PHONY to fix external module build
  (bnc#1012628).
- net: dsa: realtek-smi: fix OF child-node lookup (bnc#1012628).
- pstore/ram: Avoid allocation and leak of platform data
  (bnc#1012628).
- SUNRPC: Fix TCP receive code on archs with flush_dcache_page()
  (bnc#1012628).
- powerpc/tm: Limit TM code inside PPC_TRANSACTIONAL_MEM
  (bnc#1012628).
- arm64: kaslr: ensure randomized quantities are clean to the PoC
  (bnc#1012628).
- arm64: dts: marvell: armada-ap806: reserve PSCI area
  (bnc#1012628).
- fbdev: offb: Fix OF node name handling (bnc#1012628).
- Disable MSI also when pcie-octeon.pcie_disable on (bnc#1012628).
- fix int_sqrt64() for very large numbers (bnc#1012628).
- omap2fb: Fix stack memory disclosure (bnc#1012628).
- media: vivid: fix error handling of kthread_run (bnc#1012628).
- media: vivid: set min width/height to a value > 0 (bnc#1012628).
- bpf: in __bpf_redirect_no_mac pull mac only if present
  (bnc#1012628).
- ipv6: make icmp6_send() robust against null skb->dev
  (bnc#1012628).
- LSM: Check for NULL cred-security on free (bnc#1012628).
- media: vb2: vb2_mmap: move lock up (bnc#1012628).
- sunrpc: handle ENOMEM in rpcb_getport_async (bnc#1012628).
- netfilter: ebtables: account ebt_table_info to kmemcg
  (bnc#1012628).
- block: use rcu_work instead of call_rcu to avoid sleep in
  softirq (bnc#1012628).
- drm/vkms: Fix plane duplicate_state (bnc#1012628).
- gpu/drm: Fix lock held when returning to user space
  (bnc#1012628).
- selinux: fix GPF on invalid policy (bnc#1012628).
- blockdev: Fix livelocks on loop device (bnc#1012628).
- sctp: allocate sctp_sockaddr_entry with kzalloc (bnc#1012628).
- tipc: fix uninit-value in in tipc_conn_rcv_sub (bnc#1012628).
- tipc: fix uninit-value in tipc_nl_compat_link_reset_stats
  (bnc#1012628).
- tipc: fix uninit-value in tipc_nl_compat_bearer_enable
  (bnc#1012628).
- tipc: fix uninit-value in tipc_nl_compat_link_set (bnc#1012628).
- tipc: fix uninit-value in tipc_nl_compat_name_table_dump
  (bnc#1012628).
- tipc: fix uninit-value in tipc_nl_compat_doit (bnc#1012628).
- block/loop: Don't grab "struct file" for vfs_getattr() operation
  (bnc#1012628).
- block/loop: Use global lock for ioctl() operation (bnc#1012628).
- loop: Fold __loop_release into loop_release (bnc#1012628).
- loop: Get rid of loop_index_mutex (bnc#1012628).
- loop: Push lo_ctl_mutex down into individual ioctls
  (bnc#1012628).
- loop: Split setting of lo_state from loop_clr_fd (bnc#1012628).
- loop: Push loop_ctl_mutex down into loop_clr_fd() (bnc#1012628).
- loop: Push loop_ctl_mutex down to loop_get_status()
  (bnc#1012628).
- loop: Push loop_ctl_mutex down to loop_set_status()
  (bnc#1012628).
- loop: Push loop_ctl_mutex down to loop_set_fd() (bnc#1012628).
- loop: Push loop_ctl_mutex down to loop_change_fd()
  (bnc#1012628).
- loop: Move special partition reread handling in loop_clr_fd()
  (bnc#1012628).
- loop: Move loop_reread_partitions() out of loop_ctl_mutex
  (bnc#1012628).
- loop: Fix deadlock when calling blkdev_reread_part()
  (bnc#1012628).
- loop: Avoid circular locking dependency between loop_ctl_mutex
  and bd_mutex (bnc#1012628).
- loop: Get rid of 'nested' acquisition of loop_ctl_mutex
  (bnc#1012628).
- loop: Fix double mutex_unlock(&loop_ctl_mutex) in
  loop_control_ioctl() (bnc#1012628).
- loop: drop caches if offset or block_size are changed
  (bnc#1012628).
- drm/fb-helper: Ignore the value of fb_var_screeninfo.pixclock
  (bnc#1012628).
- media: vb2: be sure to unlock mutex on errors (bnc#1012628).
- nbd: Use set_blocksize() to set device blocksize (bnc#1012628).
- Refresh
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch.
- commit b458db8
* Tue Jan 22 2019 oneukum@suse.com
- media: usb: pwc: Don't use coherent DMA buffers for ISO transfer
  (bsc#1054610).
- commit 59d243a
* Mon Jan 21 2019 mkubecek@suse.cz
- Update to 5.0-rc3
- Config changes:
  - ARM64:
  - HSA_AMD=y
- commit 05bf5c0
* Fri Jan 18 2019 jslaby@suse.cz
- Linux 4.20.3 (bnc#1012628).
- Btrfs: use nofs context when initializing security xattrs to
  avoid deadlock (bnc#1012628).
- Btrfs: fix deadlock when enabling quotas due to concurrent
  snapshot creation (bnc#1012628).
- Btrfs: fix access to available allocation bits when starting
  balance (bnc#1012628).
- sunrpc: use-after-free in svc_process_common() (bnc#1012628).
- mm: page_mapped: don't assume compound page is huge or THP
  (bnc#1012628).
- ext4: fix special inode number checks in __ext4_iget()
  (bnc#1012628).
- ext4: track writeback errors using the generic tracking
  infrastructure (bnc#1012628).
- ext4: use ext4_write_inode() when fsyncing w/o a journal
  (bnc#1012628).
- ext4: avoid kernel warning when writing the superblock to a
  dead device (bnc#1012628).
- ext4: fix a potential fiemap/page fault deadlock w/ inline_data
  (bnc#1012628).
- ext4: make sure enough credits are reserved for dioread_nolock
  writes (bnc#1012628).
- rbd: don't return 0 on unmap if RBD_DEV_FLAG_REMOVING is set
  (bnc#1012628).
- drm/amdgpu: Don't fail resume process if resuming atomic state
  fails (bnc#1012628).
- drm/amdgpu: Don't ignore rc from
  drm_dp_mst_topology_mgr_resume() (bnc#1012628).
- drm/i915: Unwind failure on pinning the gen7 ppgtt
  (bnc#1012628).
- drm/fb-helper: Partially bring back workaround for bugs of
  SDL 1.2 (bnc#1012628).
- drm/amd/display: Fix MST dp_blank REG_WAIT timeout
  (bnc#1012628).
- PCI: dwc: Move interrupt acking into the proper callback
  (bnc#1012628).
- PCI: dwc: Take lock when ACKing an interrupt (bnc#1012628).
- PCI: dwc: Use interrupt masking instead of disabling
  (bnc#1012628).
- drm/amdgpu: Add new VegaM pci id (bnc#1012628).
- vfio/type1: Fix unmap overflow off-by-one (bnc#1012628).
- mtd: rawnand: qcom: fix memory corruption that causes panic
  (bnc#1012628).
- i2c: dev: prevent adapter retries and timeout being set as
  minus value (bnc#1012628).
- ACPI/IORT: Fix rc_dma_get_range() (bnc#1012628).
- ACPI / PMIC: xpower: Fix TS-pin current-source handling
  (bnc#1012628).
- ACPI: power: Skip duplicate power resource references in _PRx
  (bnc#1012628).
- mm, memcg: fix reclaim deadlock with writeback (bnc#1012628).
- mm/usercopy.c: no check page span for stack objects
  (bnc#1012628).
- slab: alien caches must not be initialized if the allocation
  of the alien cache failed (bnc#1012628).
- fork, memcg: fix cached_stacks case (bnc#1012628).
- USB: Add USB_QUIRK_DELAY_CTRL_MSG quirk for Corsair K70 RGB
  (bnc#1012628).
- USB: storage: add quirk for SMI SM3350 (bnc#1012628).
- USB: storage: don't insert sane sense for SPC3+ when bad sense
  specified (bnc#1012628).
- usb: cdc-acm: send ZLP for Telit 3G Intel based modems
  (bnc#1012628).
- ARM: davinci: da830-evm: fix label names in GPIO lookup entries
  (bnc#1012628).
- ARM: davinci: dm644x-evm: fix label names in GPIO lookup entries
  (bnc#1012628).
- ARM: davinci: omapl138-hawk: fix label names in GPIO lookup
  entries (bnc#1012628).
- ARM: davinci: da850-evm: fix label names in GPIO lookup entries
  (bnc#1012628).
- ARM: davinci: dm355-evm: fix label names in GPIO lookup entries
  (bnc#1012628).
- cifs: check kzalloc return (bnc#1012628).
- cifs: Fix potential OOB access of lock element array
  (bnc#1012628).
- CIFS: Fix credit computation for compounded requests
  (bnc#1012628).
- CIFS: Do not hide EINTR after sending network packets
  (bnc#1012628).
- CIFS: Do not set credits to 1 if the server didn't grant
  anything (bnc#1012628).
- CIFS: Fix adjustment of credits for MTU requests (bnc#1012628).
- ALSA: hda/realtek - Disable headset Mic VREF for headset mode
  of ALC225 (bnc#1012628).
- ALSA: hda/realtek - Add unplug function into unplug state of
  Headset Mode for ALC225 (bnc#1012628).
- ALSA: hda/realtek - Support Dell headset mode for New AIO
  platform (bnc#1012628).
- x86, modpost: Replace last remnants of RETPOLINE with
  CONFIG_RETPOLINE (bnc#1012628).
- cpufreq: scmi: Fix frequency invariance in slow path
  (bnc#1012628).
- cpufreq: scpi/scmi: Fix freeing of dynamic OPPs (bnc#1012628).
- staging: rtl8188eu: Fix module loading from tasklet for WEP
  encryption (bnc#1012628).
- staging: rtl8188eu: Fix module loading from tasklet for CCMP
  encryption (bnc#1012628).
- usbcore: Select only first configuration for non-UAC3 compliant
  devices (bnc#1012628).
- Btrfs: fix deadlock when using free space tree due to block
  group creation (bnc#1012628).
- powerpc/tm: Unset MSR[TS] if not recheckpointing (bnc#1012628).
- commit 4b478de
* Mon Jan 14 2019 mkubecek@suse.cz
- Update to 5.0-rc2
- Config changes:
  - x86:
  - RESCTRL renamed to X86_RESCTRL
- commit 879eb5c
* Sun Jan 13 2019 jslaby@suse.cz
- Linux 4.20.2 (bnc#1012628).
- drm/rockchip: psr: do not dereference encoder before it is
  null checked (bnc#1012628).
- drm/vc4: Set ->is_yuv to false when num_planes == 1
  (bnc#1012628).
- drm/nouveau/drm/nouveau: Check rc from
  drm_dp_mst_topology_mgr_resume() (bnc#1012628).
- lib: fix build failure in CONFIG_DEBUG_VIRTUAL test
  (bnc#1012628).
- of: __of_detach_node() - remove node from phandle cache
  (bnc#1012628).
- of: of_node_get()/of_node_put() nodes held in phandle cache
  (bnc#1012628).
- power: supply: olpc_battery: correct the temperature units
  (bnc#1012628).
- intel_th: msu: Fix an off-by-one in attribute store
  (bnc#1012628).
- genwqe: Fix size check (bnc#1012628).
- selftests: Fix test errors related to lib.mk khdr target
  (bnc#1012628).
- powerpc/4xx/ocm: Fix compilation error due to PAGE_KERNEL usage
  (bnc#1012628).
- drivers/perf: hisi: Fixup one DDRC PMU register offset
  (bnc#1012628).
- video: fbdev: pxafb: Fix "WARNING: invalid free of devm_
  allocated data" (bnc#1012628).
- ceph: don't update importing cap's mseq when handing cap export
  (bnc#1012628).
- sched/fair: Fix infinite loop in update_blocked_averages()
  by reverting a9e7f6544b9c (bnc#1012628).
- iommu/vt-d: Handle domain agaw being less than iommu agaw
  (bnc#1012628).
- RDMA/iwcm: Don't copy past the end of dev_name() string
  (bnc#1012628).
- RDMA/srpt: Fix a use-after-free in the channel release code
  (bnc#1012628).
- stm class: Fix a module refcount leak in policy creation error
  path (bnc#1012628).
- rxe: fix error completion wr_id and qp_num (bnc#1012628).
- 9p/net: put a lower bound on msize (bnc#1012628).
- iio: dac: ad5686: fix bit shift read register (bnc#1012628).
- iio: adc: qcom-spmi-adc5: Initialize prescale properly
  (bnc#1012628).
- powerpc/tm: Set MSR[TS] just prior to recheckpoint
  (bnc#1012628).
- Revert "powerpc/tm: Unset MSR[TS] if not recheckpointing"
  (bnc#1012628).
- nfsd4: zero-length WRITE should succeed (bnc#1012628).
- xprtrdma: Yet another double DMA-unmap (bnc#1012628).
- lockd: Show pid of lockd for remote locks (bnc#1012628).
- PCI / PM: Allow runtime PM without callback functions
  (bnc#1012628).
- selinux: policydb - fix byte order and alignment issues
  (bnc#1012628).
- b43: Fix error in cordic routine (bnc#1012628).
- gfs2: Fix loop in gfs2_rbm_find (bnc#1012628).
- gfs2: Get rid of potential double-freeing in gfs2_create_inode
  (bnc#1012628).
- dlm: memory leaks on error path in dlm_user_request()
  (bnc#1012628).
- dlm: lost put_lkb on error path in receive_convert() and
  receive_unlock() (bnc#1012628).
- dlm: possible memory leak on error path in create_lkb()
  (bnc#1012628).
- dlm: fixed memory leaks after failed ls_remove_names allocation
  (bnc#1012628).
- dm: do not allow readahead to limit IO size (bnc#1012628).
- block: mq-deadline: Fix write completion handling (bnc#1012628).
- block: deactivate blk_stat timer in wbt_disable_default()
  (bnc#1012628).
- Fix failure path in alloc_pid() (bnc#1012628).
- driver core: Add missing dev->bus->need_parent_lock checks
  (bnc#1012628).
- srcu: Lock srcu_data structure in srcu_gp_start() (bnc#1012628).
- ALSA: usb-audio: Always check descriptor sizes in parser code
  (bnc#1012628).
- ALSA: usb-audio: Fix an out-of-bound read in
  create_composite_quirks (bnc#1012628).
- ALSA: usb-audio: Check mixer unit descriptors more strictly
  (bnc#1012628).
- ALSA: usb-audio: Avoid access before bLength check in
  build_audio_procunit() (bnc#1012628).
- ALSA: cs46xx: Potential NULL dereference in probe (bnc#1012628).
- media: cx23885: only reset DMA on problematic CPUs
  (bnc#1012628).
- mm, swap: fix swapoff with KSM pages (bnc#1012628).
- mm, hmm: mark hmm_devmem_{add, add_resource} EXPORT_SYMBOL_GPL
  (bnc#1012628).
- mm, hmm: replace hmm_devmem_pages_create() with
  devm_memremap_pages() (bnc#1012628).
- mm, hmm: use devm semantics for hmm_devmem_{add, remove}
  (bnc#1012628).
- mm, devm_memremap_pages: add MEMORY_DEVICE_PRIVATE support
  (bnc#1012628).
- sunrpc: use SVC_NET() in svcauth_gss_* functions (bnc#1012628).
- sunrpc: fix cache_head leak due to queued request (bnc#1012628).
- memcg, oom: notify on oom killer invocation from the charge path
  (bnc#1012628).
- mm, devm_memremap_pages: fix shutdown handling (bnc#1012628).
- mm, devm_memremap_pages: kill mapping "System RAM" support
  (bnc#1012628).
- mm, devm_memremap_pages: mark devm_memremap_pages()
  EXPORT_SYMBOL_GPL (bnc#1012628).
- hwpoison, memory_hotplug: allow hwpoisoned pages to be offlined
  (bnc#1012628).
- zram: fix double free backing device (bnc#1012628).
- fork: record start_time late (bnc#1012628).
- scsi: lpfc: do not set queue->page_count to 0 if
  pc_sli4_params.wqpcnt is invalid (bnc#1012628).
- scsi: zfcp: fix posting too many status read buffers leading
  to adapter shutdown (bnc#1012628).
- commit 036c5c2
* Fri Jan 11 2019 afaerber@suse.de
- config: arm64: Update to 5.0-rc1
- commit 88c2434
* Wed Jan  9 2019 jslaby@suse.cz
- Linux 4.20.1 (bnc#1012628).
- panic: avoid deadlocks in re-entrant console drivers
  (bnc#1012628).
- iwlwifi: add new cards for 9560, 9462, 9461 and killer series
  (bnc#1012628).
- media: ov5640: Fix set format regression (bnc#1012628).
- bnx2x: Fix NULL pointer dereference in bnx2x_del_all_vlans()
  on some hw (bnc#1012628).
- tap: call skb_probe_transport_header after setting skb->dev
  (bnc#1012628).
- ax25: fix a use-after-free in ax25_fillin_cb() (bnc#1012628).
- ibmveth: fix DMA unmap error in ibmveth_xmit_start error path
  (bnc#1012628).
- ieee802154: lowpan_header_create check must check daddr
  (bnc#1012628).
- ip: validate header length on virtual device xmit (bnc#1012628).
- net/hamradio/6pack: use mod_timer() to rearm timers
  (bnc#1012628).
- isdn: fix kernel-infoleak in capi_unlocked_ioctl (bnc#1012628).
- netrom: fix locking in nr_find_socket() (bnc#1012628).
- net/wan: fix a double free in x25_asy_open_tty() (bnc#1012628).
- ptr_ring: wrap back ->producer in __ptr_ring_swap_queue()
  (bnc#1012628).
- sock: Make sock->sk_stamp thread-safe (bnc#1012628).
- tipc: fix a double free in tipc_enable_bearer() (bnc#1012628).
- IB/hfi1: Incorrect sizing of sge for PIO will OOPs
  (bnc#1012628).
- ALSA: rme9652: Fix potential Spectre v1 vulnerability
  (bnc#1012628).
- ALSA: emu10k1: Fix potential Spectre v1 vulnerabilities
  (bnc#1012628).
- ALSA: pcm: Fix potential Spectre v1 vulnerability (bnc#1012628).
- ALSA: emux: Fix potential Spectre v1 vulnerabilities
  (bnc#1012628).
- powerpc/fsl: Fix spectre_v2 mitigations reporting (bnc#1012628).
- mtd: atmel-quadspi: disallow building on ebsa110 (bnc#1012628).
- mtd: rawnand: marvell: prevent timeouts on a loaded machine
  (bnc#1012628).
- mtd: rawnand: Fix JEDEC detection (bnc#1012628).
- mtd: rawnand: omap2: Pass the parent of pdev to
  dma_request_chan() (bnc#1012628).
- ALSA: hda: add mute LED support for HP EliteBook 840 G4
  (bnc#1012628).
- ALSA: hda/realtek: Enable audio jacks of ASUS UX391UA with
  ALC294 (bnc#1012628).
- ALSA: fireface: fix for state to fetch PCM frames (bnc#1012628).
- ALSA: firewire-lib: fix wrong handling payload_length as
  payload_quadlet (bnc#1012628).
- ALSA: firewire-lib: fix wrong assignment for
  'out_packet_without_header' tracepoint (bnc#1012628).
- ALSA: firewire-lib: use the same print format for
  'without_header' tracepoints (bnc#1012628).
- ALSA: hda/realtek: Enable the headset mic auto detection for
  ASUS laptops (bnc#1012628).
- ALSA: hda/tegra: clear pending irq handlers (bnc#1012628).
- usb: dwc2: host: use hrtimer for NAK retries (bnc#1012628).
- USB: serial: pl2303: add ids for Hewlett-Packard HP POS pole
  displays (bnc#1012628).
- USB: serial: option: add Fibocom NL678 series (bnc#1012628).
- usb: r8a66597: Fix a possible concurrency use-after-free bug
  in r8a66597_endpoint_disable() (bnc#1012628).
- usb: dwc2: disable power_down on Amlogic devices (bnc#1012628).
- Revert "usb: dwc3: pci: Use devm functions to get the phy GPIOs"
  (bnc#1012628).
- usb: roles: Add a description for the class to Kconfig
  (bnc#1012628).
- media: dvb-usb-v2: Fix incorrect use of transfer_flags
  URB_FREE_BUFFER (bnc#1012628).
- i915: fix missing user_access_end() in page fault exception case
  (bnc#1012628).
- staging: wilc1000: fix missing read_write setting when reading
  data (bnc#1012628).
- staging: bcm2835-audio: double free in init error path
  (bnc#1012628).
- ASoC: intel: cht_bsw_max98090_ti: Add pmc_plt_clk_0 quirk for
  Chromebook Clapper (bnc#1012628).
- ASoC: intel: cht_bsw_max98090_ti: Add pmc_plt_clk_0 quirk for
  Chromebook Gnawty (bnc#1012628).
- s390/pci: fix sleeping in atomic during hotplug (bnc#1012628).
- Input: atmel_mxt_ts - don't try to free unallocated kernel
  memory (bnc#1012628).
- Input: elan_i2c - add ACPI ID for touchpad in ASUS Aspire
  F5-573G (bnc#1012628).
- x86/speculation/l1tf: Drop the swap storage limit restriction
  when l1tf=off (bnc#1012628).
- x86/mm: Drop usage of __flush_tlb_all() in
  kernel_physical_mapping_init() (bnc#1012628).
- KVM: x86: Use jmp to invoke kvm_spurious_fault() from .fixup
  (bnc#1012628).
- arm64: KVM: Make VHE Stage-2 TLB invalidation operations
  non-interruptible (bnc#1012628).
- KVM: PPC: Book3S HV: Fix race between kvm_unmap_hva_range and
  MMU mode switch (bnc#1012628).
- KVM: nVMX: Free the VMREAD/VMWRITE bitmaps if alloc_kvm_area()
  fails (bnc#1012628).
- platform-msi: Free descriptors in platform_msi_domain_free()
  (bnc#1012628).
- drm/v3d: Skip debugfs dumping GCA on platforms without GCA
  (bnc#1012628).
- DRM: UDL: get rid of useless vblank initialization
  (bnc#1012628).
- clocksource/drivers/arc_timer: Utilize generic sched_clock
  (bnc#1012628).
- perf machine: Record if a arch has a single user/kernel address
  space (bnc#1012628).
- perf thread: Add fallback functions for cases where cpumode
  is insufficient (bnc#1012628).
- perf tools: Use fallback for sample_addr_correlates_sym()
  cases (bnc#1012628).
- perf script: Use fallbacks for branch stacks (bnc#1012628).
- perf pmu: Suppress potential format-truncation warning
  (bnc#1012628).
- perf env: Also consider env->arch == NULL as local operation
  (bnc#1012628).
- ocxl: Fix endiannes bug in ocxl_link_update_pe() (bnc#1012628).
- ocxl: Fix endiannes bug in read_afu_name() (bnc#1012628).
- ext4: add ext4_sb_bread() to disambiguate ENOMEM cases
  (bnc#1012628).
- ext4: fix possible use after free in ext4_quota_enable
  (bnc#1012628).
- ext4: missing unlock/put_page() in
  ext4_try_to_write_inline_data() (bnc#1012628).
- ext4: fix EXT4_IOC_GROUP_ADD ioctl (bnc#1012628).
- ext4: include terminating u32 in size of xattr entries when
  expanding inodes (bnc#1012628).
- ext4: avoid declaring fs inconsistent due to invalid file
  handles (bnc#1012628).
- ext4: force inode writes when nfsd calls commit_metadata()
  (bnc#1012628).
- ext4: check for shutdown and r/o file system in
  ext4_write_inode() (bnc#1012628).
- spi: bcm2835: Fix race on DMA termination (bnc#1012628).
- spi: bcm2835: Fix book-keeping of DMA termination (bnc#1012628).
- spi: bcm2835: Avoid finishing transfer prematurely in IRQ mode
  (bnc#1012628).
- clk: rockchip: fix typo in rk3188 spdif_frac parent
  (bnc#1012628).
- clk: sunxi-ng: Use u64 for calculation of NM rate (bnc#1012628).
- crypto: cavium/nitrox - fix a DMA pool free failure
  (bnc#1012628).
- crypto: chcr - small packet Tx stalls the queue (bnc#1012628).
- crypto: testmgr - add AES-CFB tests (bnc#1012628).
- crypto: cfb - fix decryption (bnc#1012628).
- cgroup: fix CSS_TASK_ITER_PROCS (bnc#1012628).
- binder: fix use-after-free due to ksys_close() during fdget()
  (bnc#1012628).
- cdc-acm: fix abnormal DATA RX issue for Mediatek Preloader
  (bnc#1012628).
- btrfs: dev-replace: go back to suspended state if target device
  is missing (bnc#1012628).
- btrfs: dev-replace: go back to suspend state if another EXCL_OP
  is running (bnc#1012628).
- Btrfs: fix deadlock with memory reclaim during scrub
  (bnc#1012628).
- btrfs: skip file_extent generation check for free_space_inode
  in run_delalloc_nocow (bnc#1012628).
- Btrfs: fix fsync of files with multiple hard links in new
  directories (bnc#1012628).
- btrfs: run delayed items before dropping the snapshot
  (bnc#1012628).
- Btrfs: send, fix race with transaction commits that create
  snapshots (bnc#1012628).
- brcmfmac: fix roamoff=1 modparam (bnc#1012628).
- brcmfmac: Fix out of bounds memory access during fw load
  (bnc#1012628).
- KEYS: fix parsing invalid pkey info string (bnc#1012628).
- powerpc/tm: Unset MSR[TS] if not recheckpointing (bnc#1012628).
- f2fs: read page index before freeing (bnc#1012628).
- f2fs: fix to update new block address correctly for OPU
  (bnc#1012628).
- f2fs: fix missing unlock(sbi->gc_mutex) (bnc#1012628).
- f2fs: fix validation of the block count in
  sanity_check_raw_super (bnc#1012628).
- f2fs: sanity check of xattr entry size (bnc#1012628).
- serial: uartps: Fix interrupt mask issue to handle the RX
  interrupts properly (bnc#1012628).
- media: cec: keep track of outstanding transmits (bnc#1012628).
- media: cec-pin: fix broken tx_ignore_nack_until_eom error
  injection (bnc#1012628).
- media: rc: cec devices do not have a lirc chardev (bnc#1012628).
- media: imx274: fix stack corruption in imx274_read_reg
  (bnc#1012628).
- media: vivid: free bitmap_cap when updating std/timings/etc
  (bnc#1012628).
- media: vim2m: use cancel_delayed_work_sync instead of
  flush_schedule_work (bnc#1012628).
- media: vb2: check memory model for VIDIOC_CREATE_BUFS
  (bnc#1012628).
- media: v4l2-tpg: array index could become negative
  (bnc#1012628).
- media: v4l2-fwnode: Fix setting V4L2_MBUS_DATA_ACTIVE_HIGH/LOW
  flag (bnc#1012628).
- tools lib traceevent: Fix processing of dereferenced args in
  bprintk events (bnc#1012628).
- MIPS: math-emu: Write-protect delay slot emulation pages
  (bnc#1012628).
- MIPS: c-r4k: Add r4k_blast_scache_node for Loongson-3
  (bnc#1012628).
- MIPS: Ensure pmd_present() returns false after
  pmd_mknotpresent() (bnc#1012628).
- MIPS: Align kernel load address to 64KB (bnc#1012628).
- MIPS: Expand MIPS32 ASIDs to 64 bits (bnc#1012628).
- MIPS: OCTEON: mark RGMII interface disabled on OCTEON III
  (bnc#1012628).
- MIPS: Fix a R10000_LLSC_WAR logic in atomic.h (bnc#1012628).
- CIFS: Fix error mapping for SMB2_LOCK command which caused
  OFD lock problem (bnc#1012628).
- smb3: fix large reads on encrypted connections (bnc#1012628).
- CIFS: return correct errors when pinning memory failed for
  direct I/O (bnc#1012628).
- CIFS: use the correct length when pinning memory for direct
  I/O for write (bnc#1012628).
- arm64: KVM: Avoid setting the upper 32 bits of VTCR_EL2 to 1
  (bnc#1012628).
- arm/arm64: KVM: vgic: Force VM halt when changing the active
  state of GICv3 PPIs/SGIs (bnc#1012628).
- ARM: dts: exynos: Specify I2S assigned clocks in proper node
  (bnc#1012628).
- rtc: m41t80: Correct alarm month range with RTC reads
  (bnc#1012628).
- KVM: arm/arm64: vgic: Do not cond_resched_lock() with IRQs
  disabled (bnc#1012628).
- KVM: arm/arm64: vgic: Cap SPIs to the VM-defined maximum
  (bnc#1012628).
- KVM: arm/arm64: vgic-v2: Set active_source to 0 when restoring
  state (bnc#1012628).
- KVM: arm/arm64: Fix VMID alloc race by reverting to lock-less
  (bnc#1012628).
- KVM: arm/arm64: vgic: Fix off-by-one bug in vgic_get_irq()
  (bnc#1012628).
- iommu/arm-smmu-v3: Fix big-endian CMD_SYNC writes (bnc#1012628).
- arm64: compat: Avoid sending SIGILL for unallocated syscall
  numbers (bnc#1012628).
- arm64: compat: Don't pull syscall number from regs in
  arm_compat_syscall (bnc#1012628).
- parisc: Remap hugepage-aligned pages in set_kernel_text_rw()
  (bnc#1012628).
- tpm: tpm_try_transmit() refactor error flow (bnc#1012628).
- tpm: tpm_i2c_nuvoton: use correct command duration for TPM 2.x
  (bnc#1012628).
- spi: bcm2835: Unbreak the build of esoteric configs
  (bnc#1012628).
- MIPS: Only include mmzone.h when CONFIG_NEED_MULTIPLE_NODES=y
  (bnc#1012628).
- commit 5978cc8
* Tue Jan  8 2019 jslaby@suse.cz
- packet: validate address length if non-zero (nmap EINVAL
  failure).
- commit 34f009a
* Mon Jan  7 2019 mkubecek@suse.cz
- config: restore accidentally lost BPFILTER_UMH (ppc64, ppc64le, s390x)
- commit a56baa9
* Mon Jan  7 2019 mkubecek@suse.cz
- vfio_pci: Add local source directory as include.
- commit ea6d6e3
* Mon Jan  7 2019 mkubecek@suse.cz
- Update to 5.0-rc1
- Eliminated 1 patch
- ARM configs need update
- Config changes:
  - PM:
  - ENERGY_MODEL=y
  - Networking:
  - CAN_FLEXCAN=m
  - USB_NET_AQC111=m
  - QTNFMAC_PCIE=m
  - VIRT_WIFI=m
  - PCI:
  - PCI_MESON=n
  - SCSI:
  - SCSI_UFS_CDNS_PLATFORM=m
  - NVME:
  - NVME_TCP=m
  - NVME_TARGET_TCP=m
  - Graphics:
  - DRM_PANEL_OLIMEX_LCD_OLINUXINO=n
  - DRM_PANEL_SAMSUNG_S6D16D0=n
  - DRM_PANEL_TRULY_NT35597_WQXGA=n
  - TINYDRM_HX8357D=n
  - Sound:
  - SND_SOC_AMD_ACP3x=n
  - SND_SOC_INTEL_KBL_RT5660_MACH=m
  - SND_SOC_XILINX_I2S=n
  - SND_SOC_AK4118=n
  - Multimedia:
  - VIDEO_ASPEED=m
  - VIDEO_SECO_CEC=m
  - VIDEO_SECO_RC=y
  - I3C:
  - I3C=m
  - CDNS_I3C_MASTER=m
  - DW_I3C_MASTER=m
  - IIO:
  - AD7124=n
  - AD7949=n
  - TI_DAC7311=n
  - VCNL4035=n
  - SENSORS_RM3100_I2C=n
  - SENSORS_RM3100_SPI=n
  - MCP41010=m
  - PHY:
  - PHY_CADENCE_SIERRA=m
  - PHY_FSL_IMX8MQ_USB=m
  - misc drivers:
  - MTD_PHYSMAP_GPIO_ADDR=y
  - SPI_MXIC=n
  - MISC_ALCOR_PCI=m
  - RC_XBOX_DVD=m
  - PINCTRL_OCELOT=n
  - GPIO_CADENCE=m
  - SENSORS_OCC_P8_I2C=m
  - TQMX86_WDT=m
  - MMC_ALCOR=m
  - MMC_SDHCI_AM654=m
  - LEDS_TRIGGER_AUDIO=m
  - SERIO_OLPC_APSP=m
  - Security:
  - INTEGRITY_PLATFORM_KEYRING=y
  - IMA_ARCH_POLICY=y
  - Crypto:
  - CRYPTO_ADIANTUM=m
  - CRYPTO_STREEBOG=m
  - CRYPTO_STATS=n
  - Library:
  - RAID6_PQ_BENCHMARK=y (preserve current behaviour)
  - Testing:
  - TEST_OBJAGG=n
  - x86:
  - RESCTRL=y
  - HUAWEI_WMI=m
  - i386:
  - PVH=y
  - MTD_PHYSMAP_OF=m
  - ppc*:
  - PVPANIC=m
  - FB_LOGO_CENTER=n
  - FSI_OCC=m
  - DEBUG_VIRTUAL=n
  - SENSORS_OCC_P9_SBE=m
  - s390x:
  - PCCARD=n
  - RAPIDIO
  - other RapidIO options copy other architectures
  - DMADEVICES related options copy other architectures
  - */debug:
  - CRYPTO_STATS=y
  - TTY_PRINTK_LEVEL=6
- commit 6a4ceaa
* Mon Dec 24 2018 mkubecek@suse.cz
- Update to 4.20 final
- Eliminated 1 patch
- Refresh configs
- commit ba5c149
* Sat Dec 22 2018 jslaby@suse.cz
- Linux 4.19.12 (bnc#1012628).
- Btrfs: fix missing delayed iputs on unmount (bnc#1012628).
- nvmet-rdma: fix response use after free (bnc#1012628).
- nvme: validate controller state before rescheduling keep alive
  (bnc#1012628).
- i2c: uniphier-f: fix violation of tLOW requirement for Fast-mode
  (bnc#1012628).
- i2c: uniphier: fix violation of tLOW requirement for Fast-mode
  (bnc#1012628).
- i2c: scmi: Fix probe error on devices with an empty SMB0001
  ACPI device node (bnc#1012628).
- i2c: axxia: properly handle master timeout (bnc#1012628).
- mlxsw: spectrum_switchdev: Fix VLAN device deletion via ioctl
  (bnc#1012628).
- vhost/vsock: fix reset orphans race with close timeout
  (bnc#1012628).
- cifs: In Kconfig CONFIG_CIFS_POSIX needs depends on legacy
  (insecure cifs) (bnc#1012628).
- drm/ast: Fix connector leak during driver unload (bnc#1012628).
- acpi/nfit: Fix user-initiated ARS to be "ARS-long" rather than
  "ARS-short" (bnc#1012628).
- tools/testing/nvdimm: Align test resources to 128M
  (bnc#1012628).
- drm/amdgpu/vcn: Update vcn.cur_state during suspend
  (bnc#1012628).
- net: mvpp2: fix phylink handling of invalid PHY modes
  (bnc#1012628).
- net: mvpp2: fix detection of 10G SFP modules (bnc#1012628).
- thermal: armada: fix legacy validity test sense (bnc#1012628).
- ethernet: fman: fix wrong of_node_put() in probe function
  (bnc#1012628).
- ARM: 8816/1: dma-mapping: fix potential uninitialized return
  (bnc#1012628).
- ARM: 8815/1: V7M: align v7m_dma_inv_range() with v7 counterpart
  (bnc#1012628).
- ARM: 8814/1: mm: improve/fix ARM v7_dma_inv_range() unaligned
  address handling (bnc#1012628).
- bpf: check pending signals while verifying programs
  (bnc#1012628).
- net/mlx4_en: Fix build break when CONFIG_INET is off
  (bnc#1012628).
- mv88e6060: disable hardware level MAC learning (bnc#1012628).
- macvlan: return correct error value (bnc#1012628).
- libata: whitelist all SAMSUNG MZ7KM* solid-state disks
  (bnc#1012628).
- Input: omap-keypad - fix keyboard debounce configuration
  (bnc#1012628).
- Input: synaptics - enable SMBus for HP 15-ay000 (bnc#1012628).
- clk: mmp: Off by one in mmp_clk_add() (bnc#1012628).
- clk: mvebu: Off by one bugs in cp110_of_clk_get() (bnc#1012628).
- drm/amd/powerplay: issue pre-display settings for display
  change event (bnc#1012628).
- drm/msm: Fix error return checking (bnc#1012628).
- drm/msm: dpu: Fix "WARNING: invalid free of devm_ allocated
  data" (bnc#1012628).
- drm/msm: dpu: Don't set legacy plane->crtc pointer
  (bnc#1012628).
- drm/msm/hdmi: Enable HPD after HDMI IRQ is set up (bnc#1012628).
- ide: pmac: add of_node_put() (bnc#1012628).
- drivers/tty: add missing of_node_put() (bnc#1012628).
- drivers/sbus/char: add of_node_put() (bnc#1012628).
- sbus: char: add of_node_put() (bnc#1012628).
- SUNRPC: Fix a potential race in xprt_connect() (bnc#1012628).
- nfs: don't dirty kernel pages read by direct-io (bnc#1012628).
- liquidio: read sc->iq_no before release sc (bnc#1012628).
- bpf: Fix verifier log string check for bad alignment
  (bnc#1012628).
- bonding: fix 802.3ad state sent to partner when unbinding slave
  (bnc#1012628).
- net: aquantia: fix rx checksum offload bits (bnc#1012628).
- net: stmmac: Move debugfs init/exit to ->probe()/->remove()
  (bnc#1012628).
- ARC: io.h: Implement reads{x}()/writes{x}() (bnc#1012628).
- drm/amdgpu: wait for IB test on first device open (bnc#1012628).
- drm/ttm: fix LRU handling in ttm_buffer_object_transfer
  (bnc#1012628).
- drm/msm: Grab a vblank reference when waiting for commit_done
  (bnc#1012628).
- drm/msm/dsi: configure VCO rate for 10nm PLL driver
  (bnc#1012628).
- drm/msm: fix handling of cmdstream offset (bnc#1012628).
- drm/msm/gpu: Fix a couple memory leaks in debugfs (bnc#1012628).
- drm/msm: Fix task dump in gpu recovery (bnc#1012628).
- x86/earlyprintk/efi: Fix infinite loop on some screen widths
  (bnc#1012628).
- drm/amd/display: Fix 6x4K displays light-up on Vega20 (v2)
  (bnc#1012628).
- net: ethernet: ave: Replace NET_IP_ALIGN with AVE_FRAME_HEADROOM
  (bnc#1012628).
- tools/bpf: add addition type tests to test_btf (bnc#1012628).
- tools/bpf: fix two test_btf unit test cases (bnc#1012628).
- scsi: vmw_pscsi: Rearrange code to avoid multiple calls to
  free_irq during unload (bnc#1012628).
- scsi: libiscsi: Fix NULL pointer dereference in
  iscsi_eh_session_reset (bnc#1012628).
- i2c: rcar: check bus state before reinitializing (bnc#1012628).
- Input: hyper-v - fix wakeup from suspend-to-idle (bnc#1012628).
- mac80211_hwsim: fix module init error paths for netlink
  (bnc#1012628).
- IB/hfi1: Remove race conditions in user_sdma send path
  (bnc#1012628).
- locking/qspinlock, x86: Provide liveness guarantee
  (bnc#1012628).
- locking/qspinlock: Re-order code (bnc#1012628).
- commit c634493
* Fri Dec 21 2018 mkubecek@suse.cz
- rtlwifi: Fix leak of skb when processing C2H_BT_INFO
  (bsc#1116448).
- commit 9d82d20
* Thu Dec 20 2018 msuchanek@suse.de
- mm: add mm_pxd_folded checks to pgtable_bytes accounting
  functions (s390/mm: fix mis-accounting of pgtable_bytes).
- mm: introduce mm_[p4d|pud|pmd]_folded (s390/mm: fix
  mis-accounting of pgtable_bytes).
- mm: make the __PAGETABLE_PxD_FOLDED defines non-empty (s390/mm:
  fix mis-accounting of pgtable_bytes).
- commit c005ee0
* Thu Dec 20 2018 jslaby@suse.cz
- Linux 4.19.11 (bnc#1012628).
- sched/pelt: Fix warning and clean up IRQ PELT config
  (bnc#1012628).
- scsi: raid_attrs: fix unused variable warning (bnc#1012628).
- staging: olpc_dcon: add a missing dependency (bnc#1012628).
- slimbus: ngd: mark PM functions as __maybe_unused (bnc#1012628).
- i2c: aspeed: fix build warning (bnc#1012628).
- ARM: dts: qcom-apq8064-arrow-sd-600eval fix graph_endpoint
  warning (bnc#1012628).
- drm/msm: fix address space warning (bnc#1012628).
- pinctrl: sunxi: a83t: Fix IRQ offset typo for PH11
  (bnc#1012628).
- aio: fix spectre gadget in lookup_ioctx (bnc#1012628).
- scripts/spdxcheck.py: always open files in binary mode
  (bnc#1012628).
- fs/iomap.c: get/put the page in iomap_page_create/release()
  (bnc#1012628).
- userfaultfd: check VM_MAYWRITE was set after verifying the
  uffd is registered (bnc#1012628).
- arm64: dma-mapping: Fix FORCE_CONTIGUOUS buffer clearing
  (bnc#1012628).
- block/bio: Do not zero user pages (bnc#1012628).
- ovl: fix decode of dir file handle with multi lower layers
  (bnc#1012628).
- ovl: fix missing override creds in link of a metacopy upper
  (bnc#1012628).
- MMC: OMAP: fix broken MMC on OMAP15XX/OMAP5910/OMAP310
  (bnc#1012628).
- mmc: core: use mrq->sbc when sending CMD23 for RPMB
  (bnc#1012628).
- mmc: sdhci-omap: Fix DCRC error handling during tuning
  (bnc#1012628).
- mmc: sdhci: fix the timeout check window for clock and reset
  (bnc#1012628).
- fuse: continue to send FUSE_RELEASEDIR when FUSE_OPEN returns
  ENOSYS (bnc#1012628).
- ARM: mmp/mmp2: fix cpu_is_mmp2() on mmp2-dt (bnc#1012628).
- ARM: dts: bcm2837: Fix polarity of wifi reset GPIOs
  (bnc#1012628).
- dm thin: send event about thin-pool state change _after_
  making it (bnc#1012628).
- dm cache metadata: verify cache has blocks in
  blocks_are_clean_separate_dirty() (bnc#1012628).
- dm: call blk_queue_split() to impose device limits on bios
  (bnc#1012628).
- tracing: Fix memory leak in create_filter() (bnc#1012628).
- tracing: Fix memory leak in set_trigger_filter() (bnc#1012628).
- tracing: Fix memory leak of instance function hash filters
  (bnc#1012628).
- media: vb2: don't call __vb2_queue_cancel if vb2_start_streaming
  failed (bnc#1012628).
- powerpc/msi: Fix NULL pointer access in teardown code
  (bnc#1012628).
- powerpc: Look for "stdout-path" when setting up legacy consoles
  (bnc#1012628).
- drm/nouveau/kms: Fix memory leak in nv50_mstm_del()
  (bnc#1012628).
- drm/nouveau/kms/nv50-: also flush fb writes when rewinding
  push buffer (bnc#1012628).
- Revert "drm/rockchip: Allow driver to be shutdown on
  reboot/kexec" (bnc#1012628).
- drm/i915/gvt: Fix tiled memory decoding bug on BDW
  (bnc#1012628).
- drm/i915/execlists: Apply a full mb before execution for
  Braswell (bnc#1012628).
- drm/amdgpu/powerplay: Apply avfs cks-off voltages on VI
  (bnc#1012628).
- drm/amdkfd: add new vega10 pci ids (bnc#1012628).
- drm/amdgpu: add some additional vega10 pci ids (bnc#1012628).
- drm/amdgpu: update smu firmware images for VI variants (v2)
  (bnc#1012628).
- drm/amdgpu: update SMC firmware image for polaris10 variants
  (bnc#1012628).
- dm zoned: Fix target BIO completion handling (bnc#1012628).
- commit 096f733
* Mon Dec 17 2018 jslaby@suse.cz
- Linux 4.19.10 (bnc#1012628).
- tcp: lack of available data can also cause TSO defer
  (bnc#1012628).
- bpf: fix off-by-one error in adjust_subprog_starts
  (bnc#1012628).
- IB/hfi1: Fix an out-of-bounds access in get_hw_stats
  (bnc#1012628).
- ALSA: hda/realtek - Fix the mute LED regresion on Lenovo X1
  Carbon (bnc#1012628).
- ALSA: hda/realtek: Enable audio jacks of ASUS UX433FN/UX333FA
  with ALC294 (bnc#1012628).
- ALSA: hda/realtek: Enable audio jacks of ASUS UX533FD with
  ALC294 (bnc#1012628).
- ALSA: hda/realtek: ALC294 mic and headset-mode fixups for ASUS
  X542UN (bnc#1012628).
- ALSA: hda/realtek - Fixed headphone issue for ALC700
  (bnc#1012628).
- ALSA: fireface: fix reference to wrong register for clock
  configuration (bnc#1012628).
- dax: Check page->mapping isn't NULL (bnc#1012628).
- flexfiles: enforce per-mirror stateid only for v4 DSes
  (bnc#1012628).
- ocfs2: fix potential use after free (bnc#1012628).
- initramfs: clean old path before creating a hardlink
  (bnc#1012628).
- kernel/kcov.c: mark funcs in __sanitizer_cov_trace_pc() as
  notrace (bnc#1012628).
- proc: fixup map_files test on arm (bnc#1012628).
- debugobjects: avoid recursive calls with kmemleak (bnc#1012628).
- hfsplus: do not free node before using (bnc#1012628).
- hfs: do not free node before using (bnc#1012628).
- mm/page_alloc.c: fix calculation of pgdat->nr_zones
  (bnc#1012628).
- ocfs2: fix deadlock caused by ocfs2_defrag_extent()
  (bnc#1012628).
- ACPI/IORT: Fix iort_get_platform_device_domain() uninitialized
  pointer value (bnc#1012628).
- nvme-rdma: fix double freeing of async event data (bnc#1012628).
- nvme: flush namespace scanning work just before removing
  namespaces (bnc#1012628).
- nvme: warn when finding multi-port subsystems without
  multipathing enabled (bnc#1012628).
- fscache, cachefiles: remove redundant variable 'cache'
  (bnc#1012628).
- cachefiles: Explicitly cast enumerated type in put_object
  (bnc#1012628).
- fscache: fix race between enablement and dropping of object
  (bnc#1012628).
- afs: Fix validation/callback interaction (bnc#1012628).
- pstore/ram: Correctly calculate usable PRZ bytes (bnc#1012628).
- pvcalls-front: fixes incorrect error handling (bnc#1012628).
- Revert "xen/balloon: Mark unallocated host memory as UNUSABLE"
  (bnc#1012628).
- xen: xlate_mmu: add missing header to fix 'W=1' warning
  (bnc#1012628).
- drm/ast: fixed reading monitor EDID not stable issue
  (bnc#1012628).
- drm/amdgpu: Add delay after enable RLC ucode (bnc#1012628).
- net: hisilicon: remove unexpected free_netdev (bnc#1012628).
- ixgbe: recognize 1000BaseLX SFP modules as 1Gbps (bnc#1012628).
- igb: fix uninitialized variables (bnc#1012628).
- cachefiles: Fix page leak in cachefiles_read_backing_file
  while vmscan is active (bnc#1012628).
- fscache: Fix race in fscache_op_complete() due to split
  atomic_sub & read (bnc#1012628).
- cachefiles: Fix an assertion failure when trying to update a
  failed object (bnc#1012628).
- ALSA: usb-audio: Add vendor and product name for Dell WD19 Dock
  (bnc#1012628).
- netfilter: nf_tables: deactivate expressions in rule replecement
  routine (bnc#1012628).
- usb: gadget: u_ether: fix unsafe list iteration (bnc#1012628).
- net: thunderx: fix NULL pointer dereference in nic_remove
  (bnc#1012628).
- x86/kvm/vmx: fix old-style function declaration (bnc#1012628).
- KVM: x86: fix empty-body warnings (bnc#1012628).
- KVM: VMX: Update shared MSRs to be saved/restored on
  MSR_EFER.LMA changes (bnc#1012628).
- netfilter: nf_conncount: remove wrong condition check routine
  (bnc#1012628).
- netfilter: nat: fix double register in masquerade modules
  (bnc#1012628).
- netfilter: add missing error handling code for register
  functions (bnc#1012628).
- IB/mlx5: Fix page fault handling for MW (bnc#1012628).
- netfilter: ipv6: Preserve link scope traffic original oif
  (bnc#1012628).
- drm/meson: add support for 1080p25 mode (bnc#1012628).
- thunderbolt: Prevent root port runtime suspend during NVM
  upgrade (bnc#1012628).
- USB: omap_udc: fix rejection of out transfers when DMA is used
  (bnc#1012628).
- USB: omap_udc: fix USB gadget functionality on Palm Tungsten E
  (bnc#1012628).
- USB: omap_udc: fix omap_udc_start() on 15xx machines
  (bnc#1012628).
- USB: omap_udc: fix crashes on probe error and module removal
  (bnc#1012628).
- USB: omap_udc: use devm_request_irq() (bnc#1012628).
- ipvs: call ip_vs_dst_notifier earlier than ipv6_dev_notf
  (bnc#1012628).
- fsi: master-ast-cf: select GENERIC_ALLOCATOR (bnc#1012628).
- bpf: fix check of allowed specifiers in bpf_trace_printk
  (bnc#1012628).
- RDMA/hns: Bugfix pbl configuration for rereg mr (bnc#1012628).
- exportfs: do not read dentry after free (bnc#1012628).
- ASoC: omap-dmic: Add pm_qos handling to avoid overruns with
  CPU_IDLE (bnc#1012628).
- ASoC: omap-mcpdm: Add pm_qos handling to avoid under/overruns
  with CPU_IDLE (bnc#1012628).
- ASoC: omap-mcbsp: Fix latency value calculation for pm_qos
  (bnc#1012628).
- tools: bpftool: fix potential NULL pointer dereference in
  do_load (bnc#1012628).
- RDMA/rdmavt: Fix rvt_create_ah function signature (bnc#1012628).
- RDMA/bnxt_re: Avoid accessing the device structure after it
  is freed (bnc#1012628).
- RDMA/bnxt_re: Fix system hang when registration with L2 driver
  fails (bnc#1012628).
- RDMA/core: Add GIDs while changing MAC addr only for registered
  ndev (bnc#1012628).
- RDMA/mlx5: Fix fence type for IB_WR_LOCAL_INV WR (bnc#1012628).
- Btrfs: send, fix infinite loop due to directory rename
  dependencies (bnc#1012628).
- ARM: dts: at91: sama5d2: use the divided clock for SMC
  (bnc#1012628).
- phy: qcom-qusb2: Fix HSTX_TRIM tuning with fused value for
  SDM845 (bnc#1012628).
- phy: qcom-qusb2: Use HSTX_TRIM fused value as is (bnc#1012628).
- objtool: Fix segfault in .cold detection with
  - ffunction-sections (bnc#1012628).
- objtool: Fix double-free in .cold detection error path
  (bnc#1012628).
- ASoC: acpi: fix: continue searching when machine is ignored
  (bnc#1012628).
- PCI: imx6: Fix link training status detection in link up check
  (bnc#1012628).
- perf tools: Restore proper cwd on return from mnt namespace
  (bnc#1012628).
- hwmon: (w83795) temp4_type has writable permission
  (bnc#1012628).
- netfilter: xt_hashlimit: fix a possible memory leak in
  htable_create() (bnc#1012628).
- aio: fix failure to put the file pointer (bnc#1012628).
- bpf: allocate local storage buffers using GFP_ATOMIC
  (bnc#1012628).
- hwmon: (mlxreg-fan) Fix macros for tacho fault reading
  (bnc#1012628).
- spi: omap2-mcspi: Add missing suspend and resume calls
  (bnc#1012628).
- ASoC: dapm: Recalculate audio map forcely when card instantiated
  (bnc#1012628).
- ASoC: omap-abe-twl6040: Fix missing audio card caused by
  deferred probing (bnc#1012628).
- hwmon: (ina2xx) Fix current value calculation (bnc#1012628).
- s390/cpum_cf: Reject request for sampling in event
  initialization (bnc#1012628).
- ASoC: qcom: Set dai_link id to each dai_link (bnc#1012628).
- ASoC: Intel: Power down links before turning off display audio
  power (bnc#1012628).
- ASoC: wm_adsp: Fix dma-unsafe read of scratch registers
  (bnc#1012628).
- ASoC: rockchip: add missing slave_config setting for I2S
  (bnc#1012628).
- hwmon: (raspberrypi) Fix initial notify (bnc#1012628).
- hwmon (ina2xx) Fix NULL id pointer in probe() (bnc#1012628).
- s390/cio: Fix cleanup when unsupported IDA format is used
  (bnc#1012628).
- s390/cio: Fix cleanup of pfn_array alloc failure (bnc#1012628).
- netfilter: nf_tables: fix use-after-free when deleting compat
  expressions (bnc#1012628).
- netfilter: xt_RATEEST: remove netns exit routine (bnc#1012628).
- perf tools: Fix crash on synthesizing the unit (bnc#1012628).
- selftests: add script to stress-test nft packet path vs. control
  plane (bnc#1012628).
- netfilter: nf_tables: don't skip inactive chains during update
  (bnc#1012628).
- netfilter: nf_conncount: fix unexpected permanent node of list
  (bnc#1012628).
- netfilter: nf_conncount: fix list_del corruption in conn_free
  (bnc#1012628).
- netfilter: nf_conncount: use spin_lock_bh instead of spin_lock
  (bnc#1012628).
- sysv: return 'err' instead of 0 in __sysv_write_inode
  (bnc#1012628).
- arm64: dts: sdm845-mtp: Reserve reserved gpios (bnc#1012628).
- ASoC: sun8i-codec: fix crash on module removal (bnc#1012628).
- tools: bpftool: prevent infinite loop in get_fdinfo()
  (bnc#1012628).
- ARM: OMAP1: ams-delta: Fix possible use of uninitialized field
  (bnc#1012628).
- ARM: dts: am3517-som: Fix WL127x Wifi interrupt (bnc#1012628).
- ARM: dts: logicpd-somlv: Fix interrupt on mmc3_dat1
  (bnc#1012628).
- ARM: dts: LogicPD Torpedo: Fix mmc3_dat1 interrupt
  (bnc#1012628).
- ARM: dts: am3517: Fix pinmuxing for CD on MMC1 (bnc#1012628).
- staging: rtl8723bs: Fix the return value in case of error in
  'rtw_wx_read32()' (bnc#1012628).
- ASoC: qdsp6: q6afe-dai: Fix the dai widgets (bnc#1012628).
- ASoC: qdsp6: q6afe: Fix wrong MI2S SD line mask (bnc#1012628).
- ASoC: rsnd: fixup clock start checker (bnc#1012628).
- ARM: OMAP2+: prm44xx: Fix section annotation on
  omap44xx_prm_enable_io_wakeup (bnc#1012628).
- net: fix XPS static_key accounting (bnc#1012628).
- net: restore call to netdev_queue_numa_node_write when resetting
  XPS (bnc#1012628).
- sctp: update frag_point when stream_interleave is set
  (bnc#1012628).
- net: phy: sfp: correct store of detected link modes
  (bnc#1012628).
- virtio-net: keep vnet header zeroed after processing XDP
  (bnc#1012628).
- tun: forbid iface creation with rtnl ops (bnc#1012628).
- tcp: fix NULL ref in tail loss probe (bnc#1012628).
- tcp: Do not underestimate rwnd_limited (bnc#1012628).
- sctp: kfree_rcu asoc (bnc#1012628).
- rtnetlink: ndo_dflt_fdb_dump() only work for ARPHRD_ETHER
  devices (bnc#1012628).
- Revert "net/ibm/emac: wrong bit is used for STA control"
  (bnc#1012628).
- net: use skb_list_del_init() to remove from RX sublists
  (bnc#1012628).
- net: Prevent invalid access to skb->prev in __qdisc_drop_all
  (bnc#1012628).
- net: phy: don't allow __set_phy_supported to add unsupported
  modes (bnc#1012628).
- net/mlx4_en: Change min MTU size to ETH_MIN_MTU (bnc#1012628).
- net/mlx4_core: Correctly set PFC param if global pause is
  turned off (bnc#1012628).
- net: 8139cp: fix a BUG triggered by changing mtu with network
  traffic (bnc#1012628).
- ipv6: sr: properly initialize flowi6 prior passing to
  ip6_route_output (bnc#1012628).
- neighbour: Avoid writing before skb->head in neigh_hh_output()
  (bnc#1012628).
- ipv6: Check available headroom in ip6_xmit() even without
  options (bnc#1012628).
- ipv4: ipv6: netfilter: Adjust the frag mem limit when truesize
  changes (bnc#1012628).
- commit 9284d89
* Mon Dec 17 2018 mkubecek@suse.cz
- Update to 4.20-rc7
- Config changes:
  - ARM:
  - MEDIA_CONTROLLER_REQUEST_API=y
- commit 4731528
* Thu Dec 13 2018 jslaby@suse.cz
- Linux 4.19.9 (bnc#1012628).
- media: vicodec: lower minimum height to 360 (bnc#1012628).
- media: cec: check for non-OK/NACK conditions while claiming a LA
  (bnc#1012628).
- media: omap3isp: Unregister media device as first (bnc#1012628).
- media: ipu3-cio2: Unregister device nodes first, then release
  resources (bnc#1012628).
- iommu/vt-d: Fix NULL pointer dereference in prq_event_thread()
  (bnc#1012628).
- brcmutil: really fix decoding channel info for 160 MHz bandwidth
  (bnc#1012628).
- mt76: fix building without CONFIG_LEDS_CLASS (bnc#1012628).
- iommu/ipmmu-vmsa: Fix crash on early domain free (bnc#1012628).
- scsi: ufs: Fix hynix ufs bug with quirk on hi36xx SoC
  (bnc#1012628).
- can: ucan: remove set but not used variable 'udev'
  (bnc#1012628).
- can: rcar_can: Fix erroneous registration (bnc#1012628).
- test_firmware: fix error return getting clobbered (bnc#1012628).
- HID: input: Ignore battery reported by Symbol DS4308
  (bnc#1012628).
- batman-adv: Use explicit tvlv padding for ELP packets
  (bnc#1012628).
- batman-adv: Expand merged fragment buffer for full packet
  (bnc#1012628).
- amd/iommu: Fix Guest Virtual APIC Log Tail Address Register
  (bnc#1012628).
- bnx2x: Assign unique DMAE channel number for FW DMAE
  transactions (bnc#1012628).
- qed: Fix PTT leak in qed_drain() (bnc#1012628).
- qed: Fix overriding offload_tc by protocols without APP TLV
  (bnc#1012628).
- qed: Fix rdma_info structure allocation (bnc#1012628).
- qed: Fix reading wrong value in loop condition (bnc#1012628).
- usb: dwc2: pci: Fix an error code in probe (bnc#1012628).
- Revert "usb: gadget: ffs: Fix BUG when userland exits with
  submitted AIO transfers" (bnc#1012628).
- s390/ism: clear dmbe_mask bit before SMC IRQ handling
  (bnc#1012628).
- nvme-fc: resolve io failures during connect (bnc#1012628).
- bnxt_en: Fix filling time in bnxt_fill_coredump_record()
  (bnc#1012628).
- drm/amdgpu: Add amdgpu "max bpc" connector property (v2)
  (bnc#1012628).
- drm/amd/display: Support amdgpu "max bpc" connector property
  (v2) (bnc#1012628).
- net/mlx4_core: Zero out lkey field in SW2HW_MPT fw command
  (bnc#1012628).
- net/mlx4_core: Fix uninitialized variable compilation warning
  (bnc#1012628).
- net/mlx4: Fix UBSAN warning of signed integer overflow
  (bnc#1012628).
- drivers/net/ethernet/qlogic/qed/qed_rdma.h: fix typo
  (bnc#1012628).
- gpio: pxa: fix legacy non pinctrl aware builds again
  (bnc#1012628).
- gpio: mockup: fix indicated direction (bnc#1012628).
- tc-testing: tdc.py: ignore errors when decoding stdout/stderr
  (bnc#1012628).
- tc-testing: tdc.py: Guard against lack of returncode in executed
  command (bnc#1012628).
- mtd: rawnand: qcom: Namespace prefix some commands
  (bnc#1012628).
- cpufreq: ti-cpufreq: Only register platform_device when
  supported (bnc#1012628).
- Revert "HID: uhid: use strlcpy() instead of strncpy()"
  (bnc#1012628).
- HID: multitouch: Add pointstick support for Cirque Touchpad
  (bnc#1012628).
- mtd: spi-nor: Fix Cadence QSPI page fault kernel panic
  (bnc#1012628).
- net: ena: fix crash during failed resume from hibernation
  (bnc#1012628).
- NFSv4: Fix a NFSv4 state manager deadlock (bnc#1012628).
- qed: Fix bitmap_weight() check (bnc#1012628).
- qed: Fix QM getters to always return a valid pq (bnc#1012628).
- net/ibmnvic: Fix deadlock problem in reset (bnc#1012628).
- riscv: fix warning in arch/riscv/include/asm/module.h
  (bnc#1012628).
- net: faraday: ftmac100: remove netif_running(netdev) check
  before disabling interrupts (bnc#1012628).
- iommu/vt-d: Use memunmap to free memremap (bnc#1012628).
- NFSv4.2 copy do not allocate memory under the lock
  (bnc#1012628).
- flexfiles: use per-mirror specified stateid for IO
  (bnc#1012628).
- ibmvnic: Fix RX queue buffer cleanup (bnc#1012628).
- ibmvnic: Update driver queues after change in ring size support
  (bnc#1012628).
- team: no need to do team_notify_peers or team_mcast_rejoin
  when disabling port (bnc#1012628).
- net: amd: add missing of_node_put() (bnc#1012628).
- usb: quirk: add no-LPM quirk on SanDisk Ultra Flair device
  (bnc#1012628).
- usb: appledisplay: Add 27" Apple Cinema Display (bnc#1012628).
- USB: check usb_get_extra_descriptor for proper size
  (bnc#1012628).
- USB: serial: console: fix reported terminal settings
  (bnc#1012628).
- ALSA: usb-audio: Add SMSL D1 to quirks for native DSD support
  (bnc#1012628).
- ALSA: hda: Add support for AMD Stoney Ridge (bnc#1012628).
- ALSA: pcm: Fix starvation on down_write_nonblock()
  (bnc#1012628).
- ALSA: pcm: Call snd_pcm_unlink() conditionally at closing
  (bnc#1012628).
- ALSA: pcm: Fix interval evaluation with openmin/max
  (bnc#1012628).
- ALSA: hda/realtek - Fix speaker output regression on Thinkpad
  T570 (bnc#1012628).
- ALSA: hda/realtek: ALC286 mic and headset-mode fixups for Acer
  Aspire U27-880 (bnc#1012628).
- ALSA: hda/realtek - Add support for Acer Aspire C24-860 headset
  mic (bnc#1012628).
- ALSA: hda/realtek: Fix mic issue on Acer AIO Veriton Z4660G
  (bnc#1012628).
- ALSA: hda/realtek: Fix mic issue on Acer AIO Veriton
  Z4860G/Z6860G (bnc#1012628).
- media: gspca: fix frame overflow error (bnc#1012628).
- media: vicodec: fix memchr() kernel oops (bnc#1012628).
- Revert "mfd: cros_ec: Use devm_kzalloc for private data"
  (bnc#1012628).
- parisc: Enable -ffunction-sections for modules on 32-bit kernel
  (bnc#1012628).
- virtio/s390: avoid race on vcdev->config (bnc#1012628).
- virtio/s390: fix race in ccw_io_helper() (bnc#1012628).
- vhost/vsock: fix use-after-free in network stack callers
  (bnc#1012628).
- arm64: hibernate: Avoid sending cross-calling with interrupts
  disabled (bnc#1012628).
- SUNRPC: Fix leak of krb5p encode pages (bnc#1012628).
- dmaengine: dw: Fix FIFO size for Intel Merrifield (bnc#1012628).
- Revert "dmaengine: imx-sdma: Use GFP_NOWAIT for dma allocations"
  (bnc#1012628).
- Revert "dmaengine: imx-sdma: alloclate bd memory from dma pool"
  (bnc#1012628).
- dmaengine: imx-sdma: implement channel termination via worker
  (bnc#1012628).
- dmaengine: imx-sdma: use GFP_NOWAIT for dma descriptor
  allocations (bnc#1012628).
- dmaengine: cppi41: delete channel from pending list when stop
  channel (bnc#1012628).
- ARM: 8806/1: kprobes: Fix false positive with FORTIFY_SOURCE
  (bnc#1012628).
- xhci: workaround CSS timeout on AMD SNPS 3.0 xHC (bnc#1012628).
- xhci: Prevent U1/U2 link pm states if exit latency is too long
  (bnc#1012628).
- arm64: dts: rockchip: remove vdd_log from rock960 to fix a
  stability issues (bnc#1012628).
- Revert "x86/e820: put !E820_TYPE_RAM regions into
  memblock.reserved" (bnc#1012628).
- cifs: Fix separator when building path from dentry
  (bnc#1012628).
- staging: rtl8712: Fix possible buffer overrun (bnc#1012628).
- Revert commit ef9209b642f "staging: rtl8723bs: Fix indenting
  errors and an off-by-one mistake in core/rtw_mlme_ext.c"
  (bnc#1012628).
- crypto: do not free algorithm before using (bnc#1012628).
- drm/amdgpu: update mc firmware image for polaris12 variants
  (bnc#1012628).
- drm/lease: Send a distinct uevent (bnc#1012628).
- drm/msm: Move fence put to where failure occurs (bnc#1012628).
- drm/amdgpu/gmc8: update MC firmware for polaris (bnc#1012628).
- drm/amdgpu/gmc8: always load MC firmware in the driver
  (bnc#1012628).
- drm/i915: Downgrade Gen9 Plane WM latency error (bnc#1012628).
- kprobes/x86: Fix instruction patching corruption when copying
  more than one RIP-relative instruction (bnc#1012628).
- x86/efi: Allocate e820 buffer before calling
  efi_exit_boot_service (bnc#1012628).
- Drivers: hv: vmbus: Offload the handling of channels to two
  workqueues (bnc#1012628).
- tty: serial: 8250_mtk: always resume the device in probe
  (bnc#1012628).
- tty: do not set TTY_IO_ERROR flag if console port (bnc#1012628).
- gnss: sirf: fix activation retry handling (bnc#1012628).
- kgdboc: fix KASAN global-out-of-bounds bug in
  param_set_kgdboc_var() (bnc#1012628).
- libnvdimm, pfn: Pad pfn namespaces relative to other regions
  (bnc#1012628).
- cfg80211: Fix busy loop regression in ieee80211_ie_split_ric()
  (bnc#1012628).
- mac80211_hwsim: Timer should be initialized before device
  registered (bnc#1012628).
- mac80211: fix GFP_KERNEL under tasklet context (bnc#1012628).
- mac80211: Clear beacon_int in ieee80211_do_stop (bnc#1012628).
- mac80211: ignore tx status for PS stations in
  ieee80211_tx_status_ext (bnc#1012628).
- mac80211: fix reordering of buffered broadcast packets
  (bnc#1012628).
- mac80211: ignore NullFunc frames in the duplicate detection
  (bnc#1012628).
- HID: quirks: fix RetroUSB.com devices (bnc#1012628).
- Update config files.
- commit 2f28da6
* Mon Dec 10 2018 afaerber@suse.de
- config: arm: Enable EFI support (boo#1104833)
- commit 7050650
* Mon Dec 10 2018 afaerber@suse.de
- config: armv7hl: Update to 4.20-rc5
- commit f01387b
* Mon Dec 10 2018 jslaby@suse.cz
- Delete
  patches.suse/blk-mq-fix-corruption-with-direct-issue.patch.
  It is in 4.20-rc6 as ffe81d45322c but was partially reverted by
  c616cbee97ae, so this patch still applies cleanly, but is unwanted.
  Drop it.
- commit 7670339
* Mon Dec 10 2018 jslaby@suse.cz
- Refresh
  patches.rpmify/x86-build-Fix-compiler-support-check-for-CONFIG_RETP.patch.
  Update upstream status.
- commit ceaabb8
* Mon Dec 10 2018 mkubecek@suse.cz
- Update to 4.20-rc6
- Eliminated 1 patch
- Refresh configs
- commit 93f10c3
* Sun Dec  9 2018 jslaby@suse.cz
- Linux 4.19.8 (bnc#1012628).
- blk-mq: punt failed direct issue to dispatch list (bnc#1012628).
- tipc: use destination length for copy string (bnc#1012628).
- arc: [devboards] Add support of NFSv3 ACL (bnc#1012628).
- ARC: change defconfig defaults to ARCv2 (bnc#1012628).
- btrfs: tree-checker: Don't check max block group size as
  current max chunk size limit is unreliable (bnc#1012628).
- Input: elan_i2c - add support for ELAN0621 touchpad
  (bnc#1012628).
- Input: elan_i2c - add ACPI ID for Lenovo IdeaPad 330-15ARR
  (bnc#1012628).
- Input: elan_i2c - add ELAN0620 to the ACPI table (bnc#1012628).
- Input: cros_ec_keyb - fix button/switch capability reports
  (bnc#1012628).
- Input: matrix_keypad - check for errors from of_get_named_gpio()
  (bnc#1012628).
- Input: synaptics - add PNP ID for ThinkPad P50 to SMBus
  (bnc#1012628).
- Input: xpad - quirk all PDP Xbox One gamepads (bnc#1012628).
- scsi: lpfc: fix block guard enablement on SLI3 adapters
  (bnc#1012628).
- i40e: Fix deletion of MAC filters (bnc#1012628).
- selinux: add support for RTM_NEWCHAIN, RTM_DELCHAIN, and
  RTM_GETCHAIN (bnc#1012628).
- svm: Add mutex_lock to protect apic_access_page_done on AMD
  systems (bnc#1012628).
- kgdboc: Fix warning with module build (bnc#1012628).
- kgdboc: Fix restrict error (bnc#1012628).
- userfaultfd: shmem: UFFDIO_COPY: set the page dirty if VM_WRITE
  is not set (bnc#1012628).
- userfaultfd: shmem: add i_size checks (bnc#1012628).
- userfaultfd: shmem: allocate anonymous memory for MAP_PRIVATE
  shmem (bnc#1012628).
- userfaultfd: use ENOENT instead of EFAULT if the atomic copy
  user fails (bnc#1012628).
- drm/meson: Fix OOB memory accesses in meson_viu_set_osd_lut()
  (bnc#1012628).
- drm/meson: Enable fast_io in meson_dw_hdmi_regmap_config
  (bnc#1012628).
- drm/meson: Fixes for drm_crtc_vblank_on/off support
  (bnc#1012628).
- drm: set is_master to 0 upon drm_new_set_master() failure
  (bnc#1012628).
- drm/amd/dm: Don't forget to attach MST encoders (bnc#1012628).
- drm/ast: Fix incorrect free on ioregs (bnc#1012628).
- tracing/fgraph: Fix set_graph_function from showing interrupts
  (bnc#1012628).
- IB/mlx5: Avoid load failure due to unknown link width
  (bnc#1012628).
- mips: fix mips_get_syscall_arg o32 check (bnc#1012628).
- MIPS: ralink: Fix mt7620 nd_sd pinmux (bnc#1012628).
- tracepoint: Use __idx instead of idx in DO_TRACE macro to make
  it unique (bnc#1012628).
- sched, trace: Fix prev_state output in sched_switch tracepoint
  (bnc#1012628).
- arm64: ftrace: Fix to enable syscall events on arm64
  (bnc#1012628).
- mtd: nand: Fix memory allocation in nanddev_bbt_init()
  (bnc#1012628).
- uprobes: Fix handle_swbp() vs. unregister() + register()
  race once more (bnc#1012628).
- iser: set sector for ambiguous mr status errors (bnc#1012628).
- unifdef: use memcpy instead of strncpy (bnc#1012628).
- test_hexdump: use memcpy instead of strncpy (bnc#1012628).
- blk-mq: fix corruption with direct issue (bnc#1012628).
- Delete
  patches.suse/blk-mq-fix-corruption-with-direct-issue.patch.
- commit 9cae63f
* Sat Dec  8 2018 msuchanek@suse.de
- Include modules.fips in kernel-binary as well as kernel-binary-base
  (FATE#323247).
- commit e42315d
* Fri Dec  7 2018 jslaby@suse.cz
- x86/build: Fix compiler support check for CONFIG_RETPOLINE
  (KMP build).
- commit fb5fd39
* Wed Dec  5 2018 mkubecek@suse.cz
- blk-mq: fix corruption with direct issue (bko#201685).
- commit 8970eff
* Wed Dec  5 2018 jslaby@suse.cz
- Linux 4.19.7 (bnc#1012628).
- mm/huge_memory: rename freeze_page() to unmap_page()
  (bnc#1012628).
- mm/huge_memory: splitting set mapping+index before unfreeze
  (bnc#1012628).
- mm/huge_memory: fix lockdep complaint on 32-bit i_size_read()
  (bnc#1012628).
- mm/khugepaged: collapse_shmem() stop if punched or truncated
  (bnc#1012628).
- mm/khugepaged: fix crashes due to misaccounted holes
  (bnc#1012628).
- mm/khugepaged: collapse_shmem() remember to clear holes
  (bnc#1012628).
- mm/khugepaged: minor reorderings in collapse_shmem()
  (bnc#1012628).
- mm/khugepaged: collapse_shmem() without freezing new_page
  (bnc#1012628).
- mm/khugepaged: collapse_shmem() do not crash on Compound
  (bnc#1012628).
- lan743x: Enable driver to work with LAN7431 (bnc#1012628).
- lan743x: fix return value for lan743x_tx_napi_poll
  (bnc#1012628).
- net: don't keep lonely packets forever in the gro hash
  (bnc#1012628).
- net: gemini: Fix copy/paste error (bnc#1012628).
- net: thunderx: set tso_hdrs pointer to NULL in
  nicvf_free_snd_queue (bnc#1012628).
- packet: copy user buffers before orphan or clone (bnc#1012628).
- rapidio/rionet: do not free skb before reading its length
  (bnc#1012628).
- s390/qeth: fix length check in SNMP processing (bnc#1012628).
- usbnet: ipheth: fix potential recvmsg bug and recvmsg bug 2
  (bnc#1012628).
- net: thunderx: set xdp_prog to NULL if bpf_prog_add fails
  (bnc#1012628).
- net: skb_scrub_packet(): Scrub offload_fwd_mark (bnc#1012628).
- virtio-net: disable guest csum during XDP set (bnc#1012628).
- virtio-net: fail XDP set if guest csum is negotiated
  (bnc#1012628).
- net/dim: Update DIM start sample after each DIM iteration
  (bnc#1012628).
- tcp: defer SACK compression after DupThresh (bnc#1012628).
- net: phy: add workaround for issue where PHY driver doesn't
  bind to the device (bnc#1012628).
- tipc: fix lockdep warning during node delete (bnc#1012628).
- x86/speculation: Enable cross-hyperthread spectre v2 STIBP
  mitigation (bnc#1012628).
- x86/speculation: Apply IBPB more strictly to avoid cross-process
  data leak (bnc#1012628).
- x86/speculation: Propagate information about RSB filling
  mitigation to sysfs (bnc#1012628).
- x86/speculation: Add RETPOLINE_AMD support to the inline asm
  CALL_NOSPEC variant (bnc#1012628).
- x86/retpoline: Make CONFIG_RETPOLINE depend on compiler support
  (bnc#1012628).
- x86/retpoline: Remove minimal retpoline support (bnc#1012628).
- x86/speculation: Update the TIF_SSBD comment (bnc#1012628).
- x86/speculation: Clean up spectre_v2_parse_cmdline()
  (bnc#1012628).
- x86/speculation: Remove unnecessary ret variable in
  cpu_show_common() (bnc#1012628).
- x86/speculation: Move STIPB/IBPB string conditionals out of
  cpu_show_common() (bnc#1012628).
- x86/speculation: Disable STIBP when enhanced IBRS is in use
  (bnc#1012628).
- x86/speculation: Rename SSBD update functions (bnc#1012628).
- x86/speculation: Reorganize speculation control MSRs update
  (bnc#1012628).
- sched/smt: Make sched_smt_present track topology (bnc#1012628).
- x86/Kconfig: Select SCHED_SMT if SMP enabled (bnc#1012628).
- sched/smt: Expose sched_smt_present static key (bnc#1012628).
- x86/speculation: Rework SMT state change (bnc#1012628).
- x86/l1tf: Show actual SMT state (bnc#1012628).
- x86/speculation: Reorder the spec_v2 code (bnc#1012628).
- x86/speculation: Mark string arrays const correctly
  (bnc#1012628).
- x86/speculataion: Mark command line parser data __initdata
  (bnc#1012628).
- x86/speculation: Unify conditional spectre v2 print functions
  (bnc#1012628).
- x86/speculation: Add command line control for indirect branch
  speculation (bnc#1012628).
- x86/speculation: Prepare for per task indirect branch
  speculation control (bnc#1012628).
- x86/process: Consolidate and simplify switch_to_xtra() code
  (bnc#1012628).
- x86/speculation: Avoid __switch_to_xtra() calls (bnc#1012628).
- x86/speculation: Prepare for conditional IBPB in switch_mm()
  (bnc#1012628).
- ptrace: Remove unused ptrace_may_access_sched() and MODE_IBRS
  (bnc#1012628).
- x86/speculation: Split out TIF update (bnc#1012628).
- x86/speculation: Prevent stale SPEC_CTRL msr content
  (bnc#1012628).
- x86/speculation: Prepare arch_smt_update() for PRCTL mode
  (bnc#1012628).
- x86/speculation: Add prctl() control for indirect branch
  speculation (bnc#1012628).
- x86/speculation: Enable prctl mode for spectre_v2_user
  (bnc#1012628).
- x86/speculation: Add seccomp Spectre v2 user space protection
  mode (bnc#1012628).
- x86/speculation: Provide IBPB always command line options
  (bnc#1012628).
- userfaultfd: shmem/hugetlbfs: only allow to register VM_MAYWRITE
  vmas (bnc#1012628).
- kvm: mmu: Fix race in emulated page table writes (bnc#1012628).
- kvm: svm: Ensure an IBPB on all affected CPUs when freeing a
  vmcb (bnc#1012628).
- KVM: nVMX/nSVM: Fix bug which sets vcpu->arch.tsc_offset to
  L1 tsc_offset (bnc#1012628).
- KVM: x86: Fix kernel info-leak in KVM_HC_CLOCK_PAIRING hypercall
  (bnc#1012628).
- KVM: LAPIC: Fix pv ipis use-before-initialization (bnc#1012628).
- KVM: X86: Fix scan ioapic use-before-initialization
  (bnc#1012628).
- KVM: VMX: re-add ple_gap module parameter (bnc#1012628).
- xtensa: enable coprocessors that are being flushed
  (bnc#1012628).
- xtensa: fix coprocessor context offset definitions
  (bnc#1012628).
- xtensa: fix coprocessor part of ptrace_{get,set}xregs
  (bnc#1012628).
- udf: Allow mounting volumes with incorrect identification
  strings (bnc#1012628).
- btrfs: Always try all copies when reading extent buffers
  (bnc#1012628).
- Btrfs: ensure path name is null terminated at
  btrfs_control_ioctl (bnc#1012628).
- Btrfs: fix rare chances for data loss when doing a fast fsync
  (bnc#1012628).
- Btrfs: fix race between enabling quotas and subvolume creation
  (bnc#1012628).
- btrfs: relocation: set trans to be NULL after ending transaction
  (bnc#1012628).
- PCI: layerscape: Fix wrong invocation of outbound window
  disable accessor (bnc#1012628).
- PCI: dwc: Fix MSI-X EP framework address calculation bug
  (bnc#1012628).
- PCI: Fix incorrect value returned from pcie_get_speed_cap()
  (bnc#1012628).
- arm64: dts: rockchip: Fix PCIe reset polarity for
  rk3399-puma-haikou (bnc#1012628).
- x86/MCE/AMD: Fix the thresholding machinery initialization order
  (bnc#1012628).
- x86/fpu: Disable bottom halves while loading FPU registers
  (bnc#1012628).
- perf/x86/intel: Move branch tracing setup to the Intel-specific
  source file (bnc#1012628).
- perf/x86/intel: Add generic branch tracing check to
  intel_pmu_has_bts() (bnc#1012628).
- perf/x86/intel: Disallow precise_ip on BTS events (bnc#1012628).
- fs: fix lost error code in dio_complete (bnc#1012628).
- ALSA: wss: Fix invalid snd_free_pages() at error path
  (bnc#1012628).
- ALSA: ac97: Fix incorrect bit shift at AC97-SPSA control write
  (bnc#1012628).
- ALSA: control: Fix race between adding and removing a user
  element (bnc#1012628).
- ALSA: sparc: Fix invalid snd_free_pages() at error path
  (bnc#1012628).
- ALSA: hda: Add ASRock N68C-S UCC the power_save blacklist
  (bnc#1012628).
- ALSA: hda/realtek - Support ALC300 (bnc#1012628).
- ALSA: hda/realtek - fix headset mic detection for MSI MS-B171
  (bnc#1012628).
- ALSA: hda/realtek - fix the pop noise on headphone for lenovo
  laptops (bnc#1012628).
- ALSA: hda/realtek - Add auto-mute quirk for HP Spectre x360
  laptop (bnc#1012628).
- function_graph: Create function_graph_enter() to consolidate
  architecture code (bnc#1012628).
- ARM: function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- microblaze: function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- x86/function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- nds32: function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- powerpc/function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- sh/function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- sparc/function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- parisc: function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- riscv/function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- s390/function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- arm64: function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- MIPS: function_graph: Simplify with function_graph_enter()
  (bnc#1012628).
- function_graph: Make ftrace_push_return_trace() static
  (bnc#1012628).
- function_graph: Use new curr_ret_depth to manage depth instead
  of curr_ret_stack (bnc#1012628).
- function_graph: Have profiler use curr_ret_stack and not depth
  (bnc#1012628).
- function_graph: Move return callback before update of
  curr_ret_stack (bnc#1012628).
- function_graph: Reverse the order of pushing the ret_stack
  and the callback (bnc#1012628).
- binder: fix race that allows malicious free of live buffer
  (bnc#1012628).
- ext2: initialize opts.s_mount_opt as zero before using it
  (bnc#1012628).
- ext2: fix potential use after free (bnc#1012628).
- ASoC: intel: cht_bsw_max98090_ti: Add quirk for boards using
  pmc_plt_clk_0 (bnc#1012628).
- ASoC: pcm186x: Fix device reset-registers trigger value
  (bnc#1012628).
- ARM: dts: rockchip: Remove @0 from the veyron memory node
  (bnc#1012628).
- dmaengine: at_hdmac: fix memory leak in at_dma_xlate()
  (bnc#1012628).
- dmaengine: at_hdmac: fix module unloading (bnc#1012628).
- staging: most: use format specifier "%%s" in snprintf
  (bnc#1012628).
- staging: vchiq_arm: fix compat VCHIQ_IOC_AWAIT_COMPLETION
  (bnc#1012628).
- staging: mt7621-dma: fix potentially dereferencing uninitialized
  'tx_desc' (bnc#1012628).
- staging: mt7621-pinctrl: fix uninitialized variable ngroups
  (bnc#1012628).
- staging: rtl8723bs: Fix incorrect sense of ether_addr_equal
  (bnc#1012628).
- staging: rtl8723bs: Add missing return for
  cfg80211_rtw_get_station (bnc#1012628).
- USB: usb-storage: Add new IDs to ums-realtek (bnc#1012628).
- usb: core: quirks: add RESET_RESUME quirk for Cherry G230
  Stream series (bnc#1012628).
- Revert "usb: dwc3: gadget: skip Set/Clear Halt when invalid"
  (bnc#1012628).
- iio/hid-sensors: Fix IIO_CHAN_INFO_RAW returning wrong values
  for signed numbers (bnc#1012628).
- iio:st_magn: Fix enable device after trigger (bnc#1012628).
- lib/test_kmod.c: fix rmmod double free (bnc#1012628).
- mm: cleancache: fix corruption on missed inode invalidation
  (bnc#1012628).
- mm: use swp_offset as key in shmem_replace_page() (bnc#1012628).
- Drivers: hv: vmbus: check the creation_status in
  vmbus_establish_gpadl() (bnc#1012628).
- misc: mic/scif: fix copy-paste error in
  scif_create_remote_lookup (bnc#1012628).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Refresh
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- commit 745e582
* Wed Dec  5 2018 jslaby@suse.cz
- blk-mq: fix corruption with direct issue (ext4 corruption).
- commit 34177d9
* Tue Dec  4 2018 jroedel@suse.de
- blacklist.conf: Blacklist MAINTAINERS file
- commit c4b3c90
* Mon Dec  3 2018 tiwai@suse.de
- ALSA: usb-audio: Fix UAF decrement if card has no live
  interfaces in card.c (CVE-2018-19824,bsc#1118152).
- commit 8ad46ce
* Mon Dec  3 2018 afaerber@suse.de
- config: armv6hl: Update to 4.20-rc5
- commit c85b385
* Mon Dec  3 2018 guillaume.gardet@free.fr
- config: armv7hl: Build some options as modules (boo#1104833)
  Enable HISI_THERMAL=m while at it.
  (cherry picked from commit c9b9dd67316b831b4cddb2fb439c96767d6cee14)
- config: armv7hl: Build some options as modules (boo#1104833)
  Enable HISI_THERMAL=m while at it.
- commit f931328
* Mon Dec  3 2018 guillaume.gardet@free.fr
- config: arm: Update to 4.19.5
- commit f7aa38e
* Mon Dec  3 2018 mkubecek@suse.cz
- Update to 4.20-rc5
- Config changes:
  - General:
  - PSI_DEFAULT_DISABLED=y
  - Sound:
  - SND_SOC_INTEL_SKYLAKE_HDAUDIO_CODEC=y
  - ARM:
  - ARM64_ERRATUM_1286807=y
- commit 2ccaf30
* Sun Dec  2 2018 jslaby@suse.cz
- Linux 4.19.6 (bnc#1012628).
- HID: steam: remove input device when a hid client is running
  (bnc#1012628).
- efi/libstub: arm: support building with clang (bnc#1012628).
- usb: core: Fix hub port connection events lost (bnc#1012628).
- usb: dwc3: gadget: fix ISOC TRB type on unaligned transfers
  (bnc#1012628).
- usb: dwc3: gadget: Properly check last unaligned/zero chain TRB
  (bnc#1012628).
- usb: dwc3: core: Clean up ULPI device (bnc#1012628).
- usb: dwc3: Fix NULL pointer exception in dwc3_pci_remove()
  (bnc#1012628).
- xhci: Fix leaking USB3 shared_hcd at xhci removal (bnc#1012628).
- xhci: handle port status events for removed USB3 hcd
  (bnc#1012628).
- xhci: Add check for invalid byte size error when UAS devices
  are connected (bnc#1012628).
- usb: xhci: fix uninitialized completion when USB3 port got
  wrong status (bnc#1012628).
- usb: xhci: fix timeout for transition from RExit to U0
  (bnc#1012628).
- xhci: Add quirk to workaround the errata seen on Cavium
  Thunder-X2 Soc (bnc#1012628).
- usb: xhci: Prevent bus suspend if a port connect change or
  polling state is detected (bnc#1012628).
- ALSA: oss: Use kvzalloc() for local buffer allocations
  (bnc#1012628).
- MAINTAINERS: Add Sasha as a stable branch maintainer
  (bnc#1012628).
- Documentation/security-bugs: Clarify treatment of embargoed
  information (bnc#1012628).
- Documentation/security-bugs: Postpone fix publication in
  exceptional cases (bnc#1012628).
- mmc: sdhci-pci: Try "cd" for card-detect lookup before using
  NULL (bnc#1012628).
- mmc: sdhci-pci: Workaround GLK firmware failing to restore
  the tuning value (bnc#1012628).
- gpio: don't free unallocated ida on gpiochip_add_data_with_key()
  error path (bnc#1012628).
- iwlwifi: fix wrong WGDS_WIFI_DATA_SIZE (bnc#1012628).
- iwlwifi: mvm: support sta_statistics() even on older firmware
  (bnc#1012628).
- iwlwifi: mvm: fix regulatory domain update when the firmware
  starts (bnc#1012628).
- iwlwifi: mvm: don't use SAR Geo if basic SAR is not used
  (bnc#1012628).
- brcmfmac: fix reporting support for 160 MHz channels
  (bnc#1012628).
- opp: ti-opp-supply: Dynamically update u_volt_min (bnc#1012628).
- opp: ti-opp-supply: Correct the supply in
  _get_optimal_vdd_voltage call (bnc#1012628).
- tools/power/cpupower: fix compilation with STATIC=true
  (bnc#1012628).
- v9fs_dir_readdir: fix double-free on p9stat_read error
  (bnc#1012628).
- selinux: Add __GFP_NOWARN to allocation at str_read()
  (bnc#1012628).
- Input: synaptics - avoid using uninitialized variable when
  probing (bnc#1012628).
- bfs: add sanity check at bfs_fill_super() (bnc#1012628).
- sctp: clear the transport of some out_chunk_list chunks in
  sctp_assoc_rm_peer (bnc#1012628).
- gfs2: Don't leave s_fs_info pointing to freed memory in init_sbd
  (bnc#1012628).
- llc: do not use sk_eat_skb() (bnc#1012628).
- mm: don't warn about large allocations for slab (bnc#1012628).
- mm/memory.c: recheck page table entry with page table lock held
  (bnc#1012628).
- tcp: do not release socket ownership in tcp_close()
  (bnc#1012628).
- drm/fb-helper: Blacklist writeback when adding connectors to
  fbdev (bnc#1012628).
- drm/vc4: Set ->legacy_cursor_update to false when doing
  non-async updates (bnc#1012628).
- drm/amdgpu: Fix oops when pp_funcs->switch_power_profile is
  unset (bnc#1012628).
- drm/i915: Disable LP3 watermarks on all SNB machines
  (bnc#1012628).
- drm/ast: change resolution may cause screen blurred
  (bnc#1012628).
- drm/ast: fixed cursor may disappear sometimes (bnc#1012628).
- drm/ast: Remove existing framebuffers before loading driver
  (bnc#1012628).
- can: flexcan: Unlock the MB unconditionally (bnc#1012628).
- can: dev: can_get_echo_skb(): factor out non sending code to
  __can_get_echo_skb() (bnc#1012628).
- can: dev: __can_get_echo_skb(): replace struct can_frame by
  canfd_frame to access frame length (bnc#1012628).
- can: dev: __can_get_echo_skb(): Don't crash the kernel if
  can_priv::echo_skb is accessed out of bounds (bnc#1012628).
- can: dev: __can_get_echo_skb(): print error message, if trying
  to echo non existing skb (bnc#1012628).
- can: rx-offload: introduce can_rx_offload_get_echo_skb()
  and can_rx_offload_queue_sorted() functions (bnc#1012628).
- can: rx-offload: rename can_rx_offload_irq_queue_err_skb()
  to can_rx_offload_queue_tail() (bnc#1012628).
- can: flexcan: use can_rx_offload_queue_sorted() for
  flexcan_irq_bus_*() (bnc#1012628).
- can: flexcan: handle tx-complete CAN frames via rx-offload
  infrastructure (bnc#1012628).
- can: raw: check for CAN FD capable netdev in raw_sendmsg()
  (bnc#1012628).
- can: hi311x: Use level-triggered interrupt (bnc#1012628).
- can: flexcan: Always use last mailbox for TX (bnc#1012628).
- can: flexcan: remove not needed struct flexcan_priv::tx_mb
  and struct flexcan_priv::tx_mb_idx (bnc#1012628).
- ACPICA: AML interpreter: add region addresses in global list
  during initialization (bnc#1012628).
- IB/hfi1: Eliminate races in the SDMA send error path
  (bnc#1012628).
- fsnotify: generalize handling of extra event flags
  (bnc#1012628).
- fanotify: fix handling of events on child sub-directory
  (bnc#1012628).
- pinctrl: meson: fix pinconf bias disable (bnc#1012628).
- pinctrl: meson: fix gxbb ao pull register bits (bnc#1012628).
- pinctrl: meson: fix gxl ao pull register bits (bnc#1012628).
- pinctrl: meson: fix meson8 ao pull register bits (bnc#1012628).
- pinctrl: meson: fix meson8b ao pull register bits (bnc#1012628).
- tools/testing/nvdimm: Fix the array size for dimm devices
  (bnc#1012628).
- scsi: lpfc: fix remoteport access (bnc#1012628).
- scsi: hisi_sas: Remove set but not used variable 'dq_list'
  (bnc#1012628).
- KVM: PPC: Move and undef TRACE_INCLUDE_PATH/FILE (bnc#1012628).
- cpufreq: imx6q: add return value check for voltage scale
  (bnc#1012628).
- rtc: cmos: Do not export alarm rtc_ops when we do not support
  alarms (bnc#1012628).
- rtc: pcf2127: fix a kmemleak caused in pcf2127_i2c_gather_write
  (bnc#1012628).
- crypto: simd - correctly take reqsize of wrapped skcipher into
  account (bnc#1012628).
- floppy: fix race condition in __floppy_read_block_0()
  (bnc#1012628).
- powerpc/io: Fix the IO workarounds code to work with Radix
  (bnc#1012628).
- sched/fair: Fix cpu_util_wake() for 'execl' type workloads
  (bnc#1012628).
- perf/x86/intel/uncore: Add more IMC PCI IDs for KabyLake and
  CoffeeLake CPUs (bnc#1012628).
- block: copy ioprio in __bio_clone_fast() and bounce
  (bnc#1012628).
- SUNRPC: Fix a bogus get/put in generic_key_to_expire()
  (bnc#1012628).
- riscv: add missing vdso_install target (bnc#1012628).
- RISC-V: Silence some module warnings on 32-bit (bnc#1012628).
- drm/amdgpu: fix bug with IH ring setup (bnc#1012628).
- kdb: Use strscpy with destination buffer size (bnc#1012628).
- NFSv4: Fix an Oops during delegation callbacks (bnc#1012628).
- powerpc/numa: Suppress "VPHN is not supported" messages
  (bnc#1012628).
- efi/arm: Revert deferred unmap of early memmap mapping
  (bnc#1012628).
- z3fold: fix possible reclaim races (bnc#1012628).
- mm, memory_hotplug: check zone_movable in has_unmovable_pages
  (bnc#1012628).
- tmpfs: make lseek(SEEK_DATA/SEK_HOLE) return ENXIO with a
  negative offset (bnc#1012628).
- mm, page_alloc: check for max order in hot path (bnc#1012628).
- dax: Avoid losing wakeup in dax_lock_mapping_entry
  (bnc#1012628).
- include/linux/pfn_t.h: force '~' to be parsed as an unary
  operator (bnc#1012628).
- tty: wipe buffer (bnc#1012628).
- tty: wipe buffer if not echoing data (bnc#1012628).
- gfs2: Fix iomap buffer head reference counting bug
  (bnc#1012628).
- rcu: Make need_resched() respond to urgent RCU-QS needs
  (bnc#1012628).
- media: ov5640: Re-work MIPI startup sequence (bnc#1012628).
- media: ov5640: Fix timings setup code (bnc#1012628).
- media: ov5640: fix exposure regression (bnc#1012628).
- media: ov5640: fix auto gain & exposure when changing mode
  (bnc#1012628).
- media: ov5640: fix wrong binning value in exposure calculation
  (bnc#1012628).
- media: ov5640: fix auto controls values when switching to
  manual mode (bnc#1012628).
- commit e8181d1
* Tue Nov 27 2018 jslaby@suse.cz
- Linux 4.19.5 (bnc#1012628).
- drm/i915: Replace some PAGE_SIZE with I915_GTT_PAGE_SIZE
  (bnc#1012628).
- cifs: don't dereference smb_file_target before null check
  (bnc#1012628).
- cifs: fix return value for cifs_listxattr (bnc#1012628).
- arm64: kprobe: make page to RO mode when allocate it
  (bnc#1012628).
- block: brd: associate with queue until adding disk
  (bnc#1012628).
- net: hns3: bugfix for rtnl_lock's range in the hclgevf_reset()
  (bnc#1012628).
- net: hns3: bugfix for rtnl_lock's range in the hclge_reset()
  (bnc#1012628).
- net: hns3: bugfix for handling mailbox while the command queue
  reinitialized (bnc#1012628).
- net: hns3: bugfix for the initialization of command queue's
  spin lock (bnc#1012628).
- ixgbe: fix MAC anti-spoofing filter after VFLR (bnc#1012628).
- reiserfs: propagate errors from fill_with_dentries() properly
  (bnc#1012628).
- hfs: prevent btree data loss on root split (bnc#1012628).
- hfsplus: prevent btree data loss on root split (bnc#1012628).
- perf unwind: Take pgoff into account when reporting elf to
  libdwfl (bnc#1012628).
- um: Give start_idle_thread() a return code (bnc#1012628).
- drm/edid: Add 6 bpc quirk for BOE panel (bnc#1012628).
- afs: Handle EIO from delivery function (bnc#1012628).
- platform/x86: intel_telemetry: report debugfs failure
  (bnc#1012628).
- clk: fixed-rate: fix of_node_get-put imbalance (bnc#1012628).
- perf symbols: Set PLT entry/header sizes properly on Sparc
  (bnc#1012628).
- fs/exofs: fix potential memory leak in mount option parsing
  (bnc#1012628).
- clk: samsung: exynos5420: Enable PERIS clocks for suspend
  (bnc#1012628).
- apparmor: Fix uninitialized value in aa_split_fqname
  (bnc#1012628).
- x86/earlyprintk: Add a force option for pciserial device
  (bnc#1012628).
- platform/x86: acerhdf: Add BIOS entry for Gateway LT31 v1.3307
  (bnc#1012628).
- clk: meson-axg: pcie: drop the mpll3 clock parent (bnc#1012628).
- arm64: percpu: Initialize ret in the default case (bnc#1012628).
- clk: meson: clk-pll: drop CLK_GET_RATE_NOCACHE where unnecessary
  (bnc#1012628).
- clk: renesas: r9a06g032: Fix UART34567 clock rate (bnc#1012628).
- clk: ti: fix OF child-node lookup (bnc#1012628).
- serial: sh-sci: Fix receive on SCIFA/SCIFB variants with DMA
  (bnc#1012628).
- netfilter: ipv6: fix oops when defragmenting locally generated
  fragments (bnc#1012628).
- s390/decompressor: add missing FORCE to build targets
  (bnc#1012628).
- s390/vdso: add missing FORCE to build targets (bnc#1012628).
- HID: i2c-hid: Add a small delay after sleep command for Raydium
  touchpanel (bnc#1012628).
- Revert "HID: add NOGET quirk for Eaton Ellipse MAX UPS"
  (bnc#1012628).
- HID: alps: allow incoming reports when only the trackstick is
  opened (bnc#1012628).
- Revert "netfilter: nft_numgen: add map lookups for numgen
  random operations" (bnc#1012628).
- netfilter: ipset: list:set: Decrease refcount synchronously
  on deletion and replace (bnc#1012628).
- netfilter: ipset: actually allow allowable CIDR 0 in
  hash:net,port,net (bnc#1012628).
- netfilter: ipset: fix ip_set_list allocation failure
  (bnc#1012628).
- s390/mm: fix mis-accounting of pgtable_bytes (bnc#1012628).
- s390/mm: Fix ERROR: "__node_distance" undefined! (bnc#1012628).
- bpf: fix bpf_prog_get_info_by_fd to return 0 func_lens for
  unpriv (bnc#1012628).
- netfilter: ipset: Correct rcu_dereference() call in
  ip_set_put_comment() (bnc#1012628).
- netfilter: xt_IDLETIMER: add sysfs filename checking routine
  (bnc#1012628).
- netfilter: ipset: Fix calling ip_set() macro at dumping
  (bnc#1012628).
- netfilter: nft_compat: ebtables 'nat' table is normal chain type
  (bnc#1012628).
- s390/qeth: fix HiperSockets sniffer (bnc#1012628).
- s390/qeth: unregister netdevice only when registered
  (bnc#1012628).
- net: hns3: Fix for out-of-bounds access when setting pfc back
  pressure (bnc#1012628).
- hwmon: (ibmpowernv) Remove bogus __init annotations
  (bnc#1012628).
- ARM: dts: imx6sll: fix typo for fsl,imx6sll-i2c node
  (bnc#1012628).
- ARM: dts: fsl: Fix improperly quoted stdout-path values
  (bnc#1012628).
- Revert "drm/exynos/decon5433: implement frame counter"
  (bnc#1012628).
- arm64: dts: renesas: r8a7795: add missing dma-names on hscif2
  (bnc#1012628).
- arm64: dts: renesas: condor: switch from EtherAVB to GEther
  (bnc#1012628).
- xen/grant-table: Fix incorrect gnttab_dma_free_pages() pr_debug
  message (bnc#1012628).
- clk: fixed-factor: fix of_node_get-put imbalance (bnc#1012628).
- mtd: nand: Fix nanddev_pos_next_page() kernel-doc header
  (bnc#1012628).
- lib/raid6: Fix arm64 test build (bnc#1012628).
- drm/amd/display: Stop leaking planes (bnc#1012628).
- block: Clear kernel memory before copying to user (bnc#1012628).
- drm/amd/display: Drop reusing drm connector for MST
  (bnc#1012628).
- drm/amd/amdgpu/dm: Fix dm_dp_create_fake_mst_encoder()
  (bnc#1012628).
- s390/perf: Change CPUM_CF return code in event init function
  (bnc#1012628).
- ceph: quota: fix null pointer dereference in quota check
  (bnc#1012628).
- of/device: Really only set bus DMA mask when appropriate
  (bnc#1012628).
- nvme: make sure ns head inherits underlying device limits
  (bnc#1012628).
- i2c: omap: Enable for ARCH_K3 (bnc#1012628).
- i2c: qcom-geni: Fix runtime PM mismatch with child devices
  (bnc#1012628).
- sched/core: Take the hotplug lock in sched_init_smp()
  (bnc#1012628).
- perf tools: Fix undefined symbol scnprintf in libperf-jvmti.so
  (bnc#1012628).
- perf tools: Do not zero sample_id_all for group members
  (bnc#1012628).
- ice: Fix dead device link issue with flow control (bnc#1012628).
- ice: Fix the bytecount sent to netdev_tx_sent_queue
  (bnc#1012628).
- ice: Change req_speeds to be u16 (bnc#1012628).
- i40e: restore NETIF_F_GSO_IPXIP[46] to netdev features
  (bnc#1012628).
- qed: Fix memory/entry leak in qed_init_sp_request()
  (bnc#1012628).
- qed: Fix blocking/unlimited SPQ entries leak (bnc#1012628).
- qed: Fix SPQ entries not returned to pool in error flows
  (bnc#1012628).
- qed: Fix potential memory corruption (bnc#1012628).
- net: stmmac: Fix RX packet size > 8191 (bnc#1012628).
- net: aquantia: fix potential IOMMU fault after driver unbind
  (bnc#1012628).
- net: aquantia: fixed enable unicast on 32 macvlan (bnc#1012628).
- net: aquantia: invalid checksumm offload implementation
  (bnc#1012628).
- kbuild: deb-pkg: fix too low build version number (bnc#1012628).
- Revert "scripts/setlocalversion: git: Make -dirty check more
  robust" (bnc#1012628).
- SUNRPC: drop pointless static qualifier in
  xdr_get_next_encode_buffer() (bnc#1012628).
- x86/mm: Move LDT remap out of KASLR region on 5-level paging
  (bnc#1012628).
- x86/ldt: Unmap PTEs for the slot before freeing LDT pages
  (bnc#1012628).
- x86/ldt: Remove unused variable in map_ldt_struct()
  (bnc#1012628).
- media: v4l: event: Add subscription to list before calling
  "add" operation (bnc#1012628).
- MIPS: OCTEON: cavium_octeon_defconfig: re-enable OCTEON USB
  driver (bnc#1012628).
- RISC-V: Fix raw_copy_{to,from}_user() (bnc#1012628).
- uio: Fix an Oops on load (bnc#1012628).
- ALSA: hda/realtek - Add quirk entry for HP Pavilion 15
  (bnc#1012628).
- ALSA: hda/ca0132 - Call pci_iounmap() instead of iounmap()
  (bnc#1012628).
- can: kvaser_usb: Fix accessing freed memory in
  kvaser_usb_start_xmit() (bnc#1012628).
- can: kvaser_usb: Fix potential uninitialized variable use
  (bnc#1012628).
- usb: cdc-acm: add entry for Hiro (Conexant) modem (bnc#1012628).
- USB: quirks: Add no-lpm quirk for Raydium touchscreens
  (bnc#1012628).
- USB: Wait for extra delay time after USB_PORT_FEAT_RESET for
  quirky hub (bnc#1012628).
- usb: quirks: Add delay-init quirk for Corsair K70 LUX RGB
  (bnc#1012628).
- misc: atmel-ssc: Fix section annotation on
  atmel_ssc_get_driver_data (bnc#1012628).
- USB: misc: appledisplay: add 20" Apple Cinema Display
  (bnc#1012628).
- gnss: serial: fix synchronous write timeout (bnc#1012628).
- gnss: sirf: fix synchronous write timeout (bnc#1012628).
- mtd: rawnand: atmel: fix OF child-node lookup (bnc#1012628).
- drivers/misc/sgi-gru: fix Spectre v1 vulnerability
  (bnc#1012628).
- ACPI / platform: Add SMB0001 HID to forbidden_id_list
  (bnc#1012628).
- HID: uhid: forbid UHID_CREATE under KERNEL_DS or elevated
  privileges (bnc#1012628).
- HID: Add quirk for Primax PIXART OEM mice (bnc#1012628).
- HID: Add quirk for Microsoft PIXART OEM mouse (bnc#1012628).
- libceph: fall back to sendmsg for slab pages (bnc#1012628).
- mt76x0: run vco calibration for each channel configuration
  (bnc#1012628).
- commit 6210279
* Tue Nov 27 2018 tiwai@suse.de
- media: dvb-pll: don't re-validate tuner frequencies
  (bsc#1116374).
- commit 3debe43
* Mon Nov 26 2018 mkubecek@suse.cz
- Update to 4.20-rc4
- Config changes:
  - Networking:
  - MT76_LEDS=y (split from MT76_CORE)
- commit 1ac69b7
* Fri Nov 23 2018 msuchanek@suse.de
- Build ppc64le for POWER8+ (FATE#325617).
- commit f6da51b
* Fri Nov 23 2018 jslaby@suse.cz
- Linux 4.19.4 (bnc#1012628).
- flow_dissector: do not dissect l4 ports for fragments
  (bnc#1012628).
- ibmvnic: fix accelerated VLAN handling (bnc#1012628).
- ip_tunnel: don't force DF when MTU is locked (bnc#1012628).
- ipv6: fix a dst leak when removing its exception (bnc#1012628).
- ipv6: Fix PMTU updates for UDP/raw sockets in presence of VRF
  (bnc#1012628).
- net: bcmgenet: protect stop from timeout (bnc#1012628).
- net-gro: reset skb->pkt_type in napi_reuse_skb() (bnc#1012628).
- sctp: not allow to set asoc prsctp_enable by sockopt
  (bnc#1012628).
- tcp: Fix SOF_TIMESTAMPING_RX_HARDWARE to use the latest
  timestamp during TCP coalescing (bnc#1012628).
- tg3: Add PHY reset for 5717/5719/5720 in change ring and flow
  control paths (bnc#1012628).
- tipc: don't assume linear buffer when reading ancillary data
  (bnc#1012628).
- tipc: fix lockdep warning when reinitilaizing sockets
  (bnc#1012628).
- tuntap: fix multiqueue rx (bnc#1012628).
- net: systemport: Protect stop from timeout (bnc#1012628).
- net/sched: act_pedit: fix memory leak when IDR allocation fails
  (bnc#1012628).
- net: sched: cls_flower: validate nested enc_opts_policy to
  avoid warning (bnc#1012628).
- tipc: fix link re-establish failure (bnc#1012628).
- net/mlx5e: Don't match on vlan non-existence if ethertype is
  wildcarded (bnc#1012628).
- net/mlx5e: Claim TC hw offloads support only under a proper
  build config (bnc#1012628).
- net/mlx5e: Adjust to max number of channles when re-attaching
  (bnc#1012628).
- net/mlx5e: RX, verify received packet size in Linear Striding RQ
  (bnc#1012628).
- Revert "sctp: remove sctp_transport_pmtu_check" (bnc#1012628).
- net/mlx5e: Always use the match level enum when parsing TC
  rule match (bnc#1012628).
- net/mlx5e: Fix selftest for small MTUs (bnc#1012628).
- net/mlx5e: Removed unnecessary warnings in FEC caps query
  (bnc#1012628).
- inet: frags: better deal with smp races (bnc#1012628).
- l2tp: fix a sock refcnt leak in l2tp_tunnel_register
  (bnc#1012628).
- net/mlx5: IPSec, Fix the SA context hash key (bnc#1012628).
- net/mlx5e: IPoIB, Reset QP after channels are closed
  (bnc#1012628).
- net: dsa: mv88e6xxx: Fix clearing of stats counters
  (bnc#1012628).
- net: phy: realtek: fix RTL8201F sysfs name (bnc#1012628).
- sctp: define SCTP_SS_DEFAULT for Stream schedulers
  (bnc#1012628).
- net: qualcomm: rmnet: Fix incorrect assignment of real_dev
  (bnc#1012628).
- net: dsa: microchip: initialize mutex before use (bnc#1012628).
- sctp: fix strchange_flags name for Stream Change Event
  (bnc#1012628).
- net: phy: mdio-gpio: Fix working over slow can_sleep GPIOs
  (bnc#1012628).
- sctp: not increase stream's incnt before sending addstrm_in
  request (bnc#1012628).
- mlxsw: spectrum: Fix IP2ME CPU policer configuration
  (bnc#1012628).
- net: smsc95xx: Fix MTU range (bnc#1012628).
- rxrpc: Fix lockup due to no error backoff after ack transmit
  error (bnc#1012628).
- usbnet: smsc95xx: disable carrier check while suspending
  (bnc#1012628).
- Revert "x86/speculation: Enable cross-hyperthread spectre v2
  STIBP mitigation" (bnc#1012628).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- commit 2f38375
* Fri Nov 23 2018 msuchanek@suse.de
- Revert "Remove Cell/PS3 support from ppc64 kernel (boo#1114846)"
  This reverts commit fd6aaf7f98693355e7dcc5e4e1926fb1664d803b.
  Fixed upstream in 43c6494fa149 ("powerpc/io: Fix the IO workarounds code
  to work with Radix")
- commit 4f86993
* Thu Nov 22 2018 tiwai@suse.de
- media: dvb-pll: fix tuner frequency ranges (bsc#1116374).
- commit edac906
* Wed Nov 21 2018 jslaby@suse.cz
- Linux 4.19.3 (bnc#1012628).
- powerpc/traps: restore recoverability of machine_check
  interrupts (bnc#1012628).
- powerpc/64/module: REL32 relocation range check (bnc#1012628).
- powerpc/mm: Fix page table dump to work on Radix (bnc#1012628).
- powerpc/mm: fix always true/false warning in slice.c
  (bnc#1012628).
- drm/amd/display: fix bug of accessing invalid memory
  (bnc#1012628).
- Input: wm97xx-ts - fix exit path (bnc#1012628).
- powerpc/Makefile: Fix PPC_BOOK3S_64 ASFLAGS (bnc#1012628).
- powerpc/eeh: Fix possible null deref in eeh_dump_dev_log()
  (bnc#1012628).
- tty: check name length in tty_find_polling_driver()
  (bnc#1012628).
- tracing/kprobes: Check the probe on unloaded module correctly
  (bnc#1012628).
- drm/nouveau/secboot/acr: fix memory leak (bnc#1012628).
- drm/amdgpu/powerplay: fix missing break in switch statements
  (bnc#1012628).
- ARM: imx_v6_v7_defconfig: Select CONFIG_TMPFS_POSIX_ACL
  (bnc#1012628).
- powerpc/nohash: fix undefined behaviour when testing page size
  support (bnc#1012628).
- drm/msm/gpu: fix parameters in function
  msm_gpu_crashstate_capture (bnc#1012628).
- drm/msm/disp/dpu: Use proper define for drm_encoder_init()
  'encoder_type' (bnc#1012628).
- drm/msm: dpu: Allow planes to extend past active display
  (bnc#1012628).
- powerpc/mm: Don't report hugepage tables as memory leaks when
  using kmemleak (bnc#1012628).
- drm/omap: fix memory barrier bug in DMM driver (bnc#1012628).
- drm/amd/display: Raise dispclk value for dce120 by 15%%
  (bnc#1012628).
- drm/amd/display: fix gamma not being applied (bnc#1012628).
- drm/hisilicon: hibmc: Do not carry error code in HiBMC
  framebuffer pointer (bnc#1012628).
- media: pci: cx23885: handle adding to list failure
  (bnc#1012628).
- media: coda: don't overwrite h.264 profile_idc on decoder
  instance (bnc#1012628).
- MIPS: kexec: Mark CPU offline before disabling local IRQ
  (bnc#1012628).
- powerpc/boot: Ensure _zimage_start is a weak symbol
  (bnc#1012628).
- powerpc/memtrace: Remove memory in chunks (bnc#1012628).
- MIPS/PCI: Call pcie_bus_configure_settings() to set MPS/MRRS
  (bnc#1012628).
- staging: erofs: fix a missing endian conversion (bnc#1012628).
- serial: 8250_of: Fix for lack of interrupt support
  (bnc#1012628).
- sc16is7xx: Fix for multi-channel stall (bnc#1012628).
- media: tvp5150: fix width alignment during set_selection()
  (bnc#1012628).
- powerpc/selftests: Wait all threads to join (bnc#1012628).
- staging:iio:ad7606: fix voltage scales (bnc#1012628).
- drm: rcar-du: Update Gen3 output limitations (bnc#1012628).
- drm/amdgpu: Fix SDMA TO after GPU reset v3 (bnc#1012628).
- staging: most: video: fix registration of an empty comp
  core_component (bnc#1012628).
- 9p locks: fix glock.client_id leak in do_lock (bnc#1012628).
- udf: Prevent write-unsupported filesystem to be remounted
  read-write (bnc#1012628).
- ARM: dts: imx6ull: keep IMX6UL_ prefix for signals on both
  i.MX6UL and i.MX6ULL (bnc#1012628).
- media: ov5640: fix mode change regression (bnc#1012628).
- 9p: clear dangling pointers in p9stat_free (bnc#1012628).
- drm/amdgpu: fix integer overflow test in amdgpu_bo_list_create()
  (bnc#1012628).
- media: ov5640: fix restore of last mode set (bnc#1012628).
- ovl: fix error handling in ovl_verify_set_fh() (bnc#1012628).
- ovl: fix recursive oi->lock in ovl_link() (bnc#1012628).
- ovl: check whiteout in ovl_create_over_whiteout() (bnc#1012628).
- ovl: automatically enable redirect_dir on metacopy=on
  (bnc#1012628).
- serial: sh-sci: Fix could not remove dev_attr_rx_fifo_timeout
  (bnc#1012628).
- scsi: qla2xxx: Fix incorrect port speed being set for FC
  adapters (bnc#1012628).
- scsi: qla2xxx: Fix process response queue for ISP26XX and above
  (bnc#1012628).
- scsi: qla2xxx: Remove stale debug trace message from tcm_qla2xxx
  (bnc#1012628).
- scsi: qla2xxx: Fix early srb free on abort (bnc#1012628).
- scsi: qla2xxx: shutdown chip if reset fail (bnc#1012628).
- scsi: qla2xxx: Reject bsg request if chip is down (bnc#1012628).
- scsi: qla2xxx: Fix re-using LoopID when handle is in use
  (bnc#1012628).
- scsi: qla2xxx: Fix for double free of SRB structure
  (bnc#1012628).
- scsi: qla2xxx: Fix NVMe session hang on unload (bnc#1012628).
- scsi: qla2xxx: Fix NVMe Target discovery (bnc#1012628).
- scsi: qla2xxx: Fix duplicate switch database entries
  (bnc#1012628).
- scsi: qla2xxx: Fix driver hang when FC-NVMe LUNs are configured
  (bnc#1012628).
- vfs: fix FIGETBSZ ioctl on an overlayfs file (bnc#1012628).
- fuse: Fix use-after-free in fuse_dev_do_read() (bnc#1012628).
- fuse: Fix use-after-free in fuse_dev_do_write() (bnc#1012628).
- fuse: fix blocked_waitq wakeup (bnc#1012628).
- fuse: set FR_SENT while locked (bnc#1012628).
- drm/msm: fix OF child-node lookup (bnc#1012628).
- arm64: dts: stratix10: Support Ethernet Jumbo frame
  (bnc#1012628).
- arm64: dts: stratix10: fix multicast filtering (bnc#1012628).
- clk: meson-gxbb: set fclk_div3 as CLK_IS_CRITICAL (bnc#1012628).
- clk: meson: axg: mark fdiv2 and fdiv3 as critical (bnc#1012628).
- zram: close udev startup race condition as default groups
  (bnc#1012628).
- MIPS: Loongson-3: Fix CPU UART irq delivery problem
  (bnc#1012628).
- MIPS: Loongson-3: Fix BRIDGE irq delivery problem (bnc#1012628).
- xtensa: add NOTES section to the linker script (bnc#1012628).
- xtensa: make sure bFLT stack is 16 byte aligned (bnc#1012628).
- xtensa: fix boot parameters address translation (bnc#1012628).
- um: Drop own definition of PTRACE_SYSEMU/_SINGLESTEP
  (bnc#1012628).
- clk: s2mps11: Fix matching when built as module and DT node
  contains compatible (bnc#1012628).
- clk: at91: Fix division by zero in PLL recalc_rate()
  (bnc#1012628).
- clk: sunxi-ng: h6: fix bus clocks' divider position
  (bnc#1012628).
- clk: rockchip: fix wrong mmc sample phase shift for rk3328
  (bnc#1012628).
- clk: rockchip: Fix static checker warning in
  rockchip_ddrclk_get_parent call (bnc#1012628).
- libceph: bump CEPH_MSG_MAX_DATA_LEN (bnc#1012628).
- Revert "ceph: fix dentry leak in splice_dentry()" (bnc#1012628).
- thermal: core: Fix use-after-free in
  thermal_cooling_device_destroy_sysfs (bnc#1012628).
- mach64: fix display corruption on big endian machines
  (bnc#1012628).
- mach64: fix image corruption due to reading accelerator
  registers (bnc#1012628).
- acpi/nfit, x86/mce: Handle only uncorrectable machine checks
  (bnc#1012628).
- acpi/nfit, x86/mce: Validate a MCE's address before using it
  (bnc#1012628).
- acpi, nfit: Fix ARS overflow continuation (bnc#1012628).
- reset: hisilicon: fix potential NULL pointer dereference
  (bnc#1012628).
- crypto: hisilicon - Fix NULL dereference for same dst and src
  (bnc#1012628).
- crypto: hisilicon - Fix reference after free of memories on
  error path (bnc#1012628).
- vhost/scsi: truncate T10 PI iov_iter to prot_bytes
  (bnc#1012628).
- scsi: qla2xxx: Initialize port speed to avoid setting lower
  speed (bnc#1012628).
- SCSI: fix queue cleanup race before queue initialization is done
  (bnc#1012628).
- Revert "powerpc/8xx: Use L1 entry APG to handle _PAGE_ACCESSED
  for CONFIG_SWAP" (bnc#1012628).
- soc: ti: QMSS: Fix usage of irq_set_affinity_hint (bnc#1012628).
- ocfs2: fix a misuse a of brelse after failing
  ocfs2_check_dir_entry (bnc#1012628).
- ocfs2: free up write context when direct IO failed
  (bnc#1012628).
- mm: thp: relax __GFP_THISNODE for MADV_HUGEPAGE mappings
  (bnc#1012628).
- memory_hotplug: cond_resched in __remove_pages (bnc#1012628).
- netfilter: conntrack: fix calculation of next bucket number
  in early_drop (bnc#1012628).
- ARM: 8809/1: proc-v7: fix Thumb annotation of
  cpu_v7_hvc_switch_mm (bnc#1012628).
- bonding/802.3ad: fix link_failure_count tracking (bnc#1012628).
- mtd: spi-nor: cadence-quadspi: Return error code in
  cqspi_direct_read_execute() (bnc#1012628).
- mtd: nand: Fix nanddev_neraseblocks() (bnc#1012628).
- mtd: docg3: don't set conflicting BCH_CONST_PARAMS option
  (bnc#1012628).
- hwmon: (core) Fix double-free in __hwmon_device_register()
  (bnc#1012628).
- perf cs-etm: Correct CPU mode for samples (bnc#1012628).
- perf stat: Handle different PMU names with common prefix
  (bnc#1012628).
- perf callchain: Honour the ordering of
  PERF_CONTEXT_{USER,KERNEL,etc} (bnc#1012628).
- perf intel-pt/bts: Calculate cpumode for synthesized samples
  (bnc#1012628).
- perf intel-pt: Insert callchain context into synthesized
  callchains (bnc#1012628).
- of, numa: Validate some distance map rules (bnc#1012628).
- x86/cpu/vmware: Do not trace vmware_sched_clock() (bnc#1012628).
- x86/hyper-v: Enable PIT shutdown quirk (bnc#1012628).
- termios, tty/tty_baudrate.c: fix buffer overrun (bnc#1012628).
- arch/alpha, termios: implement BOTHER, IBSHIFT and termios2
  (bnc#1012628).
- watchdog/core: Add missing prototypes for weak functions
  (bnc#1012628).
- btrfs: fix pinned underflow after transaction aborted
  (bnc#1012628).
- Btrfs: fix missing data checksums after a ranged fsync (msync)
  (bnc#1012628).
- Btrfs: fix cur_offset in the error case for nocow (bnc#1012628).
- Btrfs: fix infinite loop on inode eviction after deduplication
  of eof block (bnc#1012628).
- Btrfs: fix data corruption due to cloning of eof block
  (bnc#1012628).
- btrfs: tree-checker: Fix misleading group system information
  (bnc#1012628).
- clockevents/drivers/i8253: Add support for PIT shutdown quirk
  (bnc#1012628).
- ext4: add missing brelse() update_backups()'s error path
  (bnc#1012628).
- ext4: add missing brelse() in set_flexbg_block_bitmap()'s
  error path (bnc#1012628).
- ext4: add missing brelse() add_new_gdb_meta_bg()'s error path
  (bnc#1012628).
- ext4: avoid potential extra brelse in
  setup_new_flex_group_blocks() (bnc#1012628).
- ext4: missing !bh check in ext4_xattr_inode_write()
  (bnc#1012628).
- ext4: fix possible inode leak in the retry loop of
  ext4_resize_fs() (bnc#1012628).
- ext4: avoid buffer leak on shutdown in ext4_mark_iloc_dirty()
  (bnc#1012628).
- ext4: avoid buffer leak in ext4_orphan_add() after prior errors
  (bnc#1012628).
- ext4: fix missing cleanup if ext4_alloc_flex_bg_array() fails
  while resizing (bnc#1012628).
- ext4: avoid possible double brelse() in add_new_gdb() on error
  path (bnc#1012628).
- ext4: fix possible leak of sbi->s_group_desc_leak in error path
  (bnc#1012628).
- ext4: fix possible leak of s_journal_flag_rwsem in error path
  (bnc#1012628).
- ext4: fix buffer leak in ext4_xattr_get_block() on error path
  (bnc#1012628).
- ext4: release bs.bh before re-using in ext4_xattr_block_find()
  (bnc#1012628).
- ext4: fix buffer leak in ext4_xattr_move_to_block() on error
  path (bnc#1012628).
- ext4: fix buffer leak in ext4_expand_extra_isize_ea() on error
  path (bnc#1012628).
- ext4: fix buffer leak in __ext4_read_dirblock() on error path
  (bnc#1012628).
- mount: Retest MNT_LOCKED in do_umount (bnc#1012628).
- mount: Don't allow copying MNT_UNBINDABLE|MNT_LOCKED mounts
  (bnc#1012628).
- mount: Prevent MNT_DETACH from disconnecting locked mounts
  (bnc#1012628).
- mnt: fix __detach_mounts infinite loop (bnc#1012628).
- uapi: fix linux/kfd_ioctl.h userspace compilation errors
  (bnc#1012628).
- ARM: cpuidle: Don't register the driver when back-end init
  returns -ENXIO (bnc#1012628).
- kdb: use correct pointer when 'btc' calls 'btt' (bnc#1012628).
- kdb: print real address of pointers instead of hashed addresses
  (bnc#1012628).
- sunrpc: correct the computation for page_ptr when truncating
  (bnc#1012628).
- NFSv4: Don't exit the state manager without clearing
  NFS4CLNT_MANAGER_RUNNING (bnc#1012628).
- nfsd: COPY and CLONE operations require the saved filehandle
  to be set (bnc#1012628).
- rtc: hctosys: Add missing range error reporting (bnc#1012628).
- fuse: fix use-after-free in fuse_direct_IO() (bnc#1012628).
- fuse: fix leaked notify reply (bnc#1012628).
- fuse: fix possibly missed wake-up after abort (bnc#1012628).
- selinux: check length properly in SCTP bind hook (bnc#1012628).
- gfs2: Put bitmap buffers in put_super (bnc#1012628).
- gfs2: Fix metadata read-ahead during truncate (2) (bnc#1012628).
- libata: blacklist SAMSUNG MZ7TD256HAFV-000L9 SSD (bnc#1012628).
- crypto: user - fix leaking uninitialized memory to userspace
  (bnc#1012628).
- lib/ubsan.c: don't mark __ubsan_handle_builtin_unreachable as
  noreturn (bnc#1012628).
- hugetlbfs: fix kernel BUG at
  fs/hugetlbfs/inode.c:444! (bnc#1012628).
- mm/swapfile.c: use kvzalloc for swap_info_struct allocation
  (bnc#1012628).
- efi/arm/libstub: Pack FDT after populating it (bnc#1012628).
- mm: don't reclaim inodes with many attached pages (bnc#1012628).
- scripts/spdxcheck.py: make python3 compliant (bnc#1012628).
- drm/rockchip: Allow driver to be shutdown on reboot/kexec
  (bnc#1012628).
- drm/amdgpu: Fix typo in amdgpu_vmid_mgr_init (bnc#1012628).
- drm/amdgpu: add missing CHIP_HAINAN in
  amdgpu_ucode_get_load_type (bnc#1012628).
- drm/amdgpu: Suppress keypresses from ACPI_VIDEO events
  (bnc#1012628).
- drm/nouveau: Check backlight IDs are >= 0, not > 0
  (bnc#1012628).
- drm/nouveau: Fix nv50_mstc->best_encoder() (bnc#1012628).
- drm/amd/powerplay: Enable/Disable NBPSTATE on On/OFF of UVD
  (bnc#1012628).
- drm/etnaviv: fix bogus fence complete check in timeout handler
  (bnc#1012628).
- drm/dp_mst: Check if primary mstb is null (bnc#1012628).
- drm: panel-orientation-quirks: Add quirk for Acer One 10 (S1003)
  (bnc#1012628).
- drm/i915/dp: Link train Fallback on eDP only if fallback link
  BW can fit panel's native mode (bnc#1012628).
- drm/i915: Use the correct crtc when sanitizing plane mapping
  (bnc#1012628).
- drm/i915: Restore vblank interrupts earlier (bnc#1012628).
- drm/i915: Don't unset intel_connector->mst_port (bnc#1012628).
- drm/i915: Skip vcpi allocation for MSTB ports that are gone
  (bnc#1012628).
- drm/i915: Large page offsets for pread/pwrite (bnc#1012628).
- drm/i915/dp: Fix link retraining comment in
  intel_dp_long_pulse() (bnc#1012628).
- drm/i915/dp: Restrict link retrain workaround to external
  monitors (bnc#1012628).
- drm/i915/icl: Fix the macros for DFLEXDPMLE register bits
  (bnc#1012628).
- drm/i915/hdmi: Add HDMI 2.0 audio clock recovery N values
  (bnc#1012628).
- drm/i915: Mark up GTT sizes as u64 (bnc#1012628).
- drm/i915: Fix error handling for the NV12 fb dimensions check
  (bnc#1012628).
- drm/i915: Fix ilk+ watermarks when disabling pipes
  (bnc#1012628).
- drm/i915: Compare user's 64b GTT offset even on 32b
  (bnc#1012628).
- drm/i915: Don't oops during modeset shutdown after lpe audio
  deinit (bnc#1012628).
- drm/i915: Mark pin flags as u64 (bnc#1012628).
- drm/i915/ringbuffer: Delay after EMIT_INVALIDATE for gen4/gen5
  (bnc#1012628).
- drm/i915/execlists: Force write serialisation into context
  image vs execution (bnc#1012628).
- drm/i915: Fix possible race in intel_dp_add_mst_connector()
  (bnc#1012628).
- drm/i915: Fix NULL deref when re-enabling HPD IRQs on systems
  with MST (bnc#1012628).
- drm/i915: Fix hpd handling for pins with two encoders
  (bnc#1012628).
- CONFIG_XEN_PV breaks xen_create_contiguous_region on ARM
  (bnc#1012628).
- Revert "ACPICA: AML interpreter: add region addresses in global
  list during initialization" (bnc#1012628).
- commit fc4ca8a
* Tue Nov 20 2018 rgoldwyn@suse.com
- apparmor: fix unnecessary creation of net-compat (bsc#1116724).
- commit f5cf767
* Mon Nov 19 2018 tiwai@suse.de
- drm/amdgpu: Add missing firmware entry for HAINAN (bsc#1116239).
- commit 21d18c9
* Mon Nov 19 2018 mkubecek@suse.cz
- Update to 4.20-rc3
- Refresh configs
- commit 81d20d2
* Tue Nov 13 2018 jslaby@suse.cz
- Linux 4.19.2 (bnc#1012628).
- bpf: fix partial copy of map_ptr when dst is scalar
  (bnc#1012628).
- MIPS: VDSO: Reduce VDSO_RANDOMIZE_SIZE to 64MB for 64bit
  (bnc#1012628).
- gpio: mxs: Get rid of external API call (bnc#1012628).
- mtd: rawnand: marvell: fix the IRQ handler complete() condition
  (bnc#1012628).
- mtd: maps: gpio-addr-flash: Fix ioremapped size (bnc#1012628).
- mtd: spi-nor: fsl-quadspi: fix read error for flash size larger
  than 16MB (bnc#1012628).
- mtd: spi-nor: intel-spi: Add support for Intel Ice Lake SPI
  serial flash (bnc#1012628).
- mtd: spi-nor: fsl-quadspi: Don't let -EINVAL on the bus
  (bnc#1012628).
- spi: spi-mem: Adjust op len based on message/transfer size
  limitations (bnc#1012628).
- spi: bcm-qspi: switch back to reading flash using smaller chunks
  (bnc#1012628).
- spi: bcm-qspi: fix calculation of address length (bnc#1012628).
- bcache: trace missed reading by cache_missed (bnc#1012628).
- bcache: fix ioctl in flash device (bnc#1012628).
- bcache: correct dirty data statistics (bnc#1012628).
- bcache: fix miss key refill->end in writeback (bnc#1012628).
- hwmon: (pmbus) Fix page count auto-detection (bnc#1012628).
- jffs2: free jffs2_sb_info through jffs2_kill_sb() (bnc#1012628).
- block: setup bounce bio_sets properly (bnc#1012628).
- block: make sure discard bio is aligned with logical block size
  (bnc#1012628).
- block: make sure writesame bio is aligned with logical block
  size (bnc#1012628).
- cpufreq: conservative: Take limits changes into account properly
  (bnc#1012628).
- dma-mapping: fix panic caused by passing empty cma command
  line argument (bnc#1012628).
- pcmcia: Implement CLKRUN protocol disabling for Ricoh bridges
  (bnc#1012628).
- ACPI / OSL: Use 'jiffies' as the time bassis for
  acpi_os_get_timer() (bnc#1012628).
- ACPICA: AML interpreter: add region addresses in global list
  during initialization (bnc#1012628).
- ACPICA: AML Parser: fix parse loop to correctly skip erroneous
  extended opcodes (bnc#1012628).
- acpi, nfit: Fix Address Range Scrub completion tracking
  (bnc#1012628).
- kprobes/x86: Use preempt_enable() in optimized_callback()
  (bnc#1012628).
- ipmi: Fix timer race with module unload (bnc#1012628).
- mailbox: PCC: handle parse error (bnc#1012628).
- parisc: Fix address in HPMC IVA (bnc#1012628).
- parisc: Fix map_pages() to not overwrite existing pte entries
  (bnc#1012628).
- parisc: Fix exported address of os_hpmc handler (bnc#1012628).
- ALSA: hda - Add quirk for ASUS G751 laptop (bnc#1012628).
- ALSA: hda - Fix headphone pin config for ASUS G751
  (bnc#1012628).
- ALSA: hda/realtek - Fix the problem of the front MIC on the
  Lenovo M715 (bnc#1012628).
- ALSA: hda - Add mic quirk for the Lenovo G50-30 (17aa:3905)
  (bnc#1012628).
- ALSA: hda: Add 2 more models to the power_save blacklist
  (bnc#1012628).
- ALSA: ca0106: Disable IZD on SB0570 DAC to fix audio pops
  (bnc#1012628).
- ALSA: hda - Fix incorrect clearance of thinkpad_acpi hooks
  (bnc#1012628).
- x86/speculation: Enable cross-hyperthread spectre v2 STIBP
  mitigation (bnc#1012628).
- x86/xen: Fix boot loader version reported for PVH guests
  (bnc#1012628).
- x86/corruption-check: Fix panic in memory_corruption_check()
  when boot option without value is provided (bnc#1012628).
- x86/kvm/nVMX: allow bare VMXON state migration (bnc#1012628).
- x86/mm/pat: Disable preemption around __flush_tlb_all()
  (bnc#1012628).
- x86/numa_emulation: Fix uniform-split numa emulation
  (bnc#1012628).
- ARM: dts: exynos: Disable pull control for MAX8997 interrupts
  on Origen (bnc#1012628).
- net: socionext: Reset tx queue in ndo_stop (bnc#1012628).
- net: loopback: clear skb->tstamp before netif_rx()
  (bnc#1012628).
- locking/lockdep: Fix debug_locks off performance problem
  (bnc#1012628).
- netfilter: xt_nat: fix DNAT target for shifted portmap ranges
  (bnc#1012628).
- ataflop: fix error handling during setup (bnc#1012628).
- swim: fix cleanup on setup error (bnc#1012628).
- arm64: cpufeature: ctr: Fix cpu capability check for late CPUs
  (bnc#1012628).
- hv_netvsc: fix vf serial matching with pci slot info
  (bnc#1012628).
- nfp: devlink port split support for 1x100G CXP NIC
  (bnc#1012628).
- tun: Consistently configure generic netdev params via rtnetlink
  (bnc#1012628).
- s390/sthyi: Fix machine name validity indication (bnc#1012628).
- hwmon: (pwm-fan) Set fan speed to 0 on suspend (bnc#1012628).
- lightnvm: pblk: fix race on sysfs line state (bnc#1012628).
- lightnvm: pblk: fix two sleep-in-atomic-context bugs
  (bnc#1012628).
- lightnvm: pblk: fix race condition on metadata I/O
  (bnc#1012628).
- spi: spi-ep93xx: Use dma_data_direction for
  ep93xx_spi_dma_{finish,prepare} (bnc#1012628).
- perf tools: Free temporary 'sys' string in read_event_files()
  (bnc#1012628).
- perf tools: Cleanup trace-event-info 'tdata' leak (bnc#1012628).
- perf tools: Free 'printk' string in parse_ftrace_printk()
  (bnc#1012628).
- perf strbuf: Match va_{add,copy} with va_end (bnc#1012628).
- cpupower: Fix coredump on VMWare (bnc#1012628).
- bcache: Populate writeback_rate_minimum attribute (bnc#1012628).
- mmc: sdhci-pci-o2micro: Add quirk for O2 Micro dev 0x8620 rev
  0x01 (bnc#1012628).
- sdhci: acpi: add free_slot callback (bnc#1012628).
- mtd: rawnand: denali: set SPARE_AREA_SKIP_BYTES register to
  8 if unset (bnc#1012628).
- iwlwifi: pcie: avoid empty free RB queue (bnc#1012628).
- iwlwifi: mvm: clear HW_RESTART_REQUESTED when stopping the
  interface (bnc#1012628).
- iwlwifi: mvm: check for n_profiles validity in EWRD ACPI
  (bnc#1012628).
- x86/olpc: Indicate that legacy PC XO-1 platform should not
  register RTC (bnc#1012628).
- wlcore: Fix BUG with clear completion on timeout (bnc#1012628).
- ACPI/PPTT: Handle architecturally unknown cache types
  (bnc#1012628).
- ACPI / PM: LPIT: Register sysfs attributes based on FADT
  (bnc#1012628).
- ACPI / processor: Fix the return value of
  acpi_processor_ids_walk() (bnc#1012628).
- cpufreq: dt: Try freeing static OPPs only if we have added them
  (bnc#1012628).
- x86/intel_rdt: Show missing resctrl mount options (bnc#1012628).
- mtd: rawnand: atmel: Fix potential NULL pointer dereference
  (bnc#1012628).
- nvme: call nvme_complete_rq when nvmf_check_ready fails for
  mpath I/O (bnc#1012628).
- ath10k: fix tx status flag setting for management frames
  (bnc#1012628).
- signal: Introduce COMPAT_SIGMINSTKSZ for use in
  compat_sys_sigaltstack (bnc#1012628).
- ice: fix changing of ring descriptor size (ethtool -G)
  (bnc#1012628).
- ice: update fw version check logic (bnc#1012628).
- net: hns3: Fix for packet buffer setting bug (bnc#1012628).
- Bluetooth: btbcm: Add entry for BCM4335C0 UART bluetooth
  (bnc#1012628).
- Bluetooth: hci_qca: Remove hdev dereference in qca_close()
  (bnc#1012628).
- efi/x86: Call efi_parse_options() from efi_main() (bnc#1012628).
- x86: boot: Fix EFI stub alignment (bnc#1012628).
- net: hns3: Add nic state check before calling
  netif_tx_wake_queue (bnc#1012628).
- net: hns3: Fix ets validate issue (bnc#1012628).
- pinctrl: sunxi: fix 'pctrl->functions' allocation in
  sunxi_pinctrl_build_state (bnc#1012628).
- pinctrl: qcom: spmi-mpp: Fix err handling of pmic_mpp_set_mux
  (bnc#1012628).
- brcmfmac: fix for proper support of 160MHz bandwidth
  (bnc#1012628).
- net: hns3: Check hdev state when getting link status
  (bnc#1012628).
- net: hns3: Set STATE_DOWN bit of hdev state when stopping net
  (bnc#1012628).
- net: phy: phylink: ensure the carrier is off when starting
  phylink (bnc#1012628).
- block, bfq: correctly charge and reset entity service in all
  cases (bnc#1012628).
- arm64: entry: Allow handling of undefined instructions from EL1
  (bnc#1012628).
- kprobes: Return error if we fail to reuse kprobe instead of
  BUG_ON() (bnc#1012628).
- spi: gpio: No MISO does not imply no RX (bnc#1012628).
- ACPI / LPSS: Add alternative ACPI HIDs for Cherry Trail DMA
  controllers (bnc#1012628).
- pinctrl: qcom: spmi-mpp: Fix drive strength setting
  (bnc#1012628).
- bpf/verifier: fix verifier instability (bnc#1012628).
- failover: Add missing check to validate 'slave_dev' in
  net_failover_slave_unregister (bnc#1012628).
- perf tests: Fix record+probe_libc_inet_pton.sh without ping's
  debuginfo (bnc#1012628).
- pinctrl: spmi-mpp: Fix pmic_mpp_config_get() to be compliant
  (bnc#1012628).
- pinctrl: ssbi-gpio: Fix pm8xxx_pin_config_get() to be compliant
  (bnc#1012628).
- net: hns3: Preserve vlan 0 in hardware table (bnc#1012628).
- net: hns3: Fix ping exited problem when doing lp selftest
  (bnc#1012628).
- net: hns3: Fix for vf vlan delete failed problem (bnc#1012628).
- net: dsa: mv88e6xxx: Fix writing to a PHY page (bnc#1012628).
- mt76x2u: run device cleanup routine if resume fails
  (bnc#1012628).
- rsi: fix memory alignment issue in ARM32 platforms
  (bnc#1012628).
- libertas_tf: prevent underflow in process_cmdrequest()
  (bnc#1012628).
- iwlwifi: mvm: fix BAR seq ctrl reporting (bnc#1012628).
- gpio: brcmstb: allow 0 width GPIO banks (bnc#1012628).
- ixgbe: disallow IPsec Tx offload when in SR-IOV mode
  (bnc#1012628).
- ixgbevf: VF2VF TCP RSS (bnc#1012628).
- wil6210: fix RX buffers release and unmap (bnc#1012628).
- ath10k: schedule hardware restart if WMI command times out
  (bnc#1012628).
- libata: Apply NOLPM quirk for SAMSUNG MZ7TD256HAFV-000L9
  (bnc#1012628).
- thermal: rcar_thermal: Prevent doing work after unbind
  (bnc#1012628).
- thermal: da9062/61: Prevent hardware access during system
  suspend (bnc#1012628).
- cifs: fix a credits leak for compund commands (bnc#1012628).
- cgroup, netclassid: add a preemption point to write_classid
  (bnc#1012628).
- net: stmmac: dwmac-sun8i: fix OF child-node lookup
  (bnc#1012628).
- f2fs: fix to account IO correctly for cgroup writeback
  (bnc#1012628).
- MD: Memory leak when flush bio size is zero (bnc#1012628).
- md: fix memleak for mempool (bnc#1012628).
- of: Add missing exports of node name compare functions
  (bnc#1012628).
- scsi: esp_scsi: Track residual for PIO transfers (bnc#1012628).
- scsi: ufs: Schedule clk gating work on correct queue
  (bnc#1012628).
- UAPI: ndctl: Fix g++-unsupported initialisation in headers
  (bnc#1012628).
- KVM: nVMX: Clear reserved bits of #DB exit qualification
  (bnc#1012628).
- scsi: megaraid_sas: fix a missing-check bug (bnc#1012628).
- RDMA/core: Do not expose unsupported counters (bnc#1012628).
- RDMA/cm: Respect returned status of cm_init_av_by_path
  (bnc#1012628).
- IB/ipoib: Clear IPCB before icmp_send (bnc#1012628).
- RDMA/bnxt_re: Avoid accessing nq->bar_reg_iomem in failure case
  (bnc#1012628).
- RDMA/bnxt_re: Fix recursive lock warning in debug kernel
  (bnc#1012628).
- usb: host: ohci-at91: fix request of irq for optional gpio
  (bnc#1012628).
- PCI: mediatek: Fix mtk_pcie_find_port() endpoint/port matching
  logic (bnc#1012628).
- PCI: cadence: Use AXI region 0 to signal interrupts from EP
  (bnc#1012628).
- usb: typec: tcpm: Report back negotiated PPS voltage and current
  (bnc#1012628).
- tpm: suppress transmit cmd error logs when TPM 1.2 is
  disabled/deactivated (bnc#1012628).
- f2fs: clear PageError on the read path (bnc#1012628).
- Drivers: hv: vmbus: Use cpumask_var_t for on-stack cpu mask
  (bnc#1012628).
- VMCI: Resource wildcard match fixed (bnc#1012628).
- PCI / ACPI: Enable wake automatically for power managed bridges
  (bnc#1012628).
- xprtrdma: Reset credit grant properly after a disconnect
  (bnc#1012628).
- irqchip/pdc: Setup all edge interrupts as rising edge at GIC
  (bnc#1012628).
- usb: dwc2: fix call to vbus supply exit routine, call it
  unlocked (bnc#1012628).
- usb: dwc2: fix a race with external vbus supply (bnc#1012628).
- usb: gadget: udc: atmel: handle at91sam9rl PMC (bnc#1012628).
- ext4: fix argument checking in EXT4_IOC_MOVE_EXT (bnc#1012628).
- MD: fix invalid stored role for a disk (bnc#1012628).
- PCI: cadence: Correct probe behaviour when failing to get PHY
  (bnc#1012628).
- nvmem: check the return value of nvmem_add_cells()
  (bnc#1012628).
- xhci: Avoid USB autosuspend when resuming USB2 ports
  (bnc#1012628).
- scsi: qla2xxx: Fix recursive mailbox timeout (bnc#1012628).
- f2fs: fix to recover inode's crtime during POR (bnc#1012628).
- f2fs: fix to recover inode's i_flags during POR (bnc#1012628).
- PCI/MSI: Warn and return error if driver enables MSI/MSI-X twice
  (bnc#1012628).
- coresight: etb10: Fix handling of perf mode (bnc#1012628).
- PCI: dwc: pci-dra7xx: Enable errata i870 for both EP and RC mode
  (bnc#1012628).
- crypto: caam - fix implicit casts in endianness helpers
  (bnc#1012628).
- usb: chipidea: Prevent unbalanced IRQ disable (bnc#1012628).
- Smack: ptrace capability use fixes (bnc#1012628).
- driver/dma/ioat: Call del_timer_sync() without holding prep_lock
  (bnc#1012628).
- ASoC: AMD: Fix capture unstable in beginning for some runs
  (bnc#1012628).
- firmware: coreboot: Unmap ioregion after device population
  (bnc#1012628).
- IB/ipoib: Use dev_port to expose network interface port numbers
  (bnc#1012628).
- IB/mlx5: Allow transition of DCI QP to reset (bnc#1012628).
- uio: ensure class is registered before devices (bnc#1012628).
- scsi: lpfc: Correct soft lockup when running mds diagnostics
  (bnc#1012628).
- scsi: lpfc: Correct race with abort on completion path
  (bnc#1012628).
- f2fs: avoid sleeping under spin_lock (bnc#1012628).
- f2fs: report error if quota off error during umount
  (bnc#1012628).
- signal: Always deliver the kernel's SIGKILL and SIGSTOP to a
  pid namespace init (bnc#1012628).
- f2fs: fix to flush all dirty inodes recovered in readonly fs
  (bnc#1012628).
- mfd: menelaus: Fix possible race condition and leak
  (bnc#1012628).
- dmaengine: dma-jz4780: Return error if not probed from DT
  (bnc#1012628).
- IB/rxe: fix for duplicate request processing and ack psns
  (bnc#1012628).
- ALSA: hda: Check the non-cached stream buffers more explicitly
  (bnc#1012628).
- cpupower: Fix AMD Family 0x17 msr_pstate size (bnc#1012628).
- Revert "f2fs: fix to clear PG_checked flag in set_page_dirty()"
  (bnc#1012628).
- f2fs: fix missing up_read (bnc#1012628).
- f2fs: fix to recover cold bit of inode block during POR
  (bnc#1012628).
- f2fs: fix to account IO correctly (bnc#1012628).
- OPP: Free OPP table properly on performance state irregularities
  (bnc#1012628).
- ARM: dts: exynos: Convert exynos5250.dtsi to opp-v2 bindings
  (bnc#1012628).
- ARM: dts: exynos: Mark 1 GHz CPU OPP as suspend OPP on
  Exynos5250 (bnc#1012628).
- xen-swiotlb: use actually allocated size on check physical
  continuous (bnc#1012628).
- tpm: Restore functionality to xen vtpm driver (bnc#1012628).
- xen/blkfront: avoid NULL blkfront_info dereference on device
  removal (bnc#1012628).
- xen/balloon: Support xend-based toolstack (bnc#1012628).
- xen: fix race in xen_qlock_wait() (bnc#1012628).
- xen: make xen_qlock_wait() nestable (bnc#1012628).
- xen/pvh: increase early stack size (bnc#1012628).
- xen/pvh: don't try to unplug emulated devices (bnc#1012628).
- libertas: don't set URB_ZERO_PACKET on IN USB transfer
  (bnc#1012628).
- usbip:vudc: BUG kmalloc-2048 (Not tainted): Poison overwritten
  (bnc#1012628).
- usb: typec: tcpm: Fix APDO PPS order checking to be based on
  voltage (bnc#1012628).
- usb: gadget: udc: renesas_usb3: Fix b-device mode for
  "workaround" (bnc#1012628).
- mt76: mt76x2: fix multi-interface beacon configuration
  (bnc#1012628).
- iwlwifi: mvm: check return value of rs_rate_from_ucode_rate()
  (bnc#1012628).
- net/ipv4: defensive cipso option parsing (bnc#1012628).
- dmaengine: ppc4xx: fix off-by-one build failure (bnc#1012628).
- scsi: sched/wait: Add wait_event_lock_irq_timeout for
  TASK_UNINTERRUPTIBLE usage (bnc#1012628).
- scsi: target: Fix target_wait_for_sess_cmds breakage with
  active signals (bnc#1012628).
- libnvdimm: Hold reference on parent while scheduling async init
  (bnc#1012628).
- libnvdimm, region: Fail badblocks listing for inactive regions
  (bnc#1012628).
- libnvdimm, pmem: Fix badblocks population for 'raw' namespaces
  (bnc#1012628).
- ASoC: intel: skylake: Add missing break in skl_tplg_get_token()
  (bnc#1012628).
- ASoC: sta32x: set ->component pointer in private struct
  (bnc#1012628).
- IB/mlx5: Fix MR cache initialization (bnc#1012628).
- IB/rxe: Revise the ib_wr_opcode enum (bnc#1012628).
- jbd2: fix use after free in jbd2_log_do_checkpoint()
  (bnc#1012628).
- gfs2_meta: ->mount() can get NULL dev_name (bnc#1012628).
- ext4: fix EXT4_IOC_SWAP_BOOT (bnc#1012628).
- ext4: initialize retries variable in
  ext4_da_write_inline_data_begin() (bnc#1012628).
- ext4: fix setattr project check in fssetxattr ioctl
  (bnc#1012628).
- ext4: propagate error from dquot_initialize() in
  EXT4_IOC_FSSETXATTR (bnc#1012628).
- ext4: fix use-after-free race in ext4_remount()'s error path
  (bnc#1012628).
- selinux: fix mounting of cgroup2 under older policies
  (bnc#1012628).
- HID: wacom: Work around HID descriptor bug in DTK-2451 and
  DTH-2452 (bnc#1012628).
- HID: hiddev: fix potential Spectre v1 (bnc#1012628).
- EDAC, amd64: Add Family 17h, models 10h-2fh support
  (bnc#1012628).
- EDAC, {i7core,sb,skx}_edac: Fix uncorrected error counting
  (bnc#1012628).
- EDAC, skx_edac: Fix logical channel intermediate decoding
  (bnc#1012628).
- ARM: dts: dra7: Fix up unaligned access setting for PCIe EP
  (bnc#1012628).
- PCI/ASPM: Fix link_state teardown on device removal
  (bnc#1012628).
- PCI: Add Device IDs for Intel GPU "spurious interrupt" quirk
  (bnc#1012628).
- signal/GenWQE: Fix sending of SIGKILL (bnc#1012628).
- signal: Guard against negative signal numbers in
  copy_siginfo_from_user32 (bnc#1012628).
- crypto: lrw - Fix out-of bounds access on counter overflow
  (bnc#1012628).
- crypto: tcrypt - fix ghash-generic speed test (bnc#1012628).
- crypto: aesni - don't use GFP_ATOMIC allocation if the request
  doesn't cross a page in gcm (bnc#1012628).
- crypto: morus/generic - fix for big endian systems
  (bnc#1012628).
- crypto: aegis/generic - fix for big endian systems
  (bnc#1012628).
- crypto: speck - remove Speck (bnc#1012628).
- mm: /proc/pid/smaps_rollup: fix NULL pointer deref in
  smaps_pte_range() (bnc#1012628).
- userfaultfd: disable irqs when taking the waitqueue lock
  (bnc#1012628).
- ima: fix showing large 'violations' or
  'runtime_measurements_count' (bnc#1012628).
- ima: open a new file instance if no read permissions
  (bnc#1012628).
- hugetlbfs: dirty pages as they are added to pagecache
  (bnc#1012628).
- mm/rmap: map_pte() was not handling private ZONE_DEVICE page
  properly (bnc#1012628).
- mm/hmm: fix race between hmm_mirror_unregister() and
  mmu_notifier callback (bnc#1012628).
- KVM: arm/arm64: Ensure only THP is candidate for adjustment
  (bnc#1012628).
- KVM: arm64: Fix caching of host MDCR_EL2 value (bnc#1012628).
- kbuild: fix kernel/bounds.c 'W=1' warning (bnc#1012628).
- iio: ad5064: Fix regulator handling (bnc#1012628).
- iio: adc: imx25-gcq: Fix leak of device_node in
  mx25_gcq_setup_cfgs() (bnc#1012628).
- iio: adc: at91: fix acking DRDY irq on simple conversions
  (bnc#1012628).
- iio: adc: at91: fix wrong channel number in triggered buffer
  mode (bnc#1012628).
- w1: omap-hdq: fix missing bus unregister at removal
  (bnc#1012628).
- smb3: allow stats which track session and share reconnects to
  be reset (bnc#1012628).
- smb3: do not attempt cifs operation in smb3 query info error
  path (bnc#1012628).
- smb3: on kerberos mount if server doesn't specify auth type
  use krb5 (bnc#1012628).
- printk: Fix panic caused by passing log_buf_len to command line
  (bnc#1012628).
- genirq: Fix race on spurious interrupt detection (bnc#1012628).
- tpm: fix response size validation in tpm_get_random()
  (bnc#1012628).
- NFC: nfcmrvl_uart: fix OF child-node lookup (bnc#1012628).
- NFSv4.1: Fix the r/wsize checking (bnc#1012628).
- nfs: Fix a missed page unlock after pg_doio() (bnc#1012628).
- nfsd: correctly decrement odstate refcount in error path
  (bnc#1012628).
- nfsd: Fix an Oops in free_session() (bnc#1012628).
- lockd: fix access beyond unterminated strings in prints
  (bnc#1012628).
- dm ioctl: harden copy_params()'s copy_from_user() from malicious
  users (bnc#1012628).
- dm zoned: fix metadata block ref counting (bnc#1012628).
- dm zoned: fix various dmz_get_mblock() issues (bnc#1012628).
- media: ov7670: make "xclk" clock optional (bnc#1012628).
- fsnotify: Fix busy inodes during unmount (bnc#1012628).
- powerpc64/module elfv1: Set opd addresses after module
  relocation (bnc#1012628).
- powerpc/msi: Fix compile error on mpc83xx (bnc#1012628).
- powerpc/tm: Fix HFSCR bit for no suspend case (bnc#1012628).
- powerpc/64s/hash: Do not use PPC_INVALIDATE_ERAT on CPUs before
  POWER9 (bnc#1012628).
- MIPS: OCTEON: fix out of bounds array access on CN68XX
  (bnc#1012628).
- rtc: ds1307: fix ds1339 wakealarm support (bnc#1012628).
- rtc: cmos: Fix non-ACPI undefined reference to
  `hpet_rtc_interrupt' (bnc#1012628).
- rtc: cmos: Remove the `use_acpi_alarm' module parameter for
  !ACPI (bnc#1012628).
- power: supply: twl4030-charger: fix OF sibling-node lookup
  (bnc#1012628).
- ocxl: Fix access to the AFU Descriptor Data (bnc#1012628).
- iommu/arm-smmu: Ensure that page-table updates are visible
  before TLBI (bnc#1012628).
- TC: Set DMA masks for devices (bnc#1012628).
- net: bcmgenet: fix OF child-node lookup (bnc#1012628).
- media: v4l2-tpg: fix kernel oops when enabling HFLIP and OSD
  (bnc#1012628).
- Revert "media: dvbsky: use just one mutex for serializing
  device R/W ops" (bnc#1012628).
- kgdboc: Passing ekgdboc to command line causes panic
  (bnc#1012628).
- remoteproc: qcom: q6v5: Propagate EPROBE_DEFER (bnc#1012628).
- media: cec: make cec_get_edid_spa_location() an inline function
  (bnc#1012628).
- media: cec: integrate cec_validate_phys_addr() in cec-api.c
  (bnc#1012628).
- xen: fix xen_qlock_wait() (bnc#1012628).
- xen: remove size limit of privcmd-buf mapping interface
  (bnc#1012628).
- xen-blkfront: fix kernel panic with negotiate_mq error path
  (bnc#1012628).
- media: cec: add new tx/rx status bits to detect aborts/timeouts
  (bnc#1012628).
- media: cec: fix the Signal Free Time calculation (bnc#1012628).
- media: cec: forgot to cancel delayed work (bnc#1012628).
- media: em28xx: use a default format if TRY_FMT fails
  (bnc#1012628).
- media: tvp5150: avoid going past array on v4l2_querymenu()
  (bnc#1012628).
- media: em28xx: fix input name for Terratec AV 350 (bnc#1012628).
- media: em28xx: make v4l2-compliance happier by starting sequence
  on zero (bnc#1012628).
- media: em28xx: fix handler for vidioc_s_input() (bnc#1012628).
- media: adv7604: when the EDID is cleared, unconfigure CEC as
  well (bnc#1012628).
- media: adv7842: when the EDID is cleared, unconfigure CEC as
  well (bnc#1012628).
- drm/mediatek: fix OF sibling-node lookup (bnc#1012628).
- media: media colorspaces*.rst: rename AdobeRGB to opRGB
  (bnc#1012628).
- media: replace ADOBERGB by OPRGB (bnc#1012628).
- media: hdmi.h: rename ADOBE_RGB to OPRGB and ADOBE_YCC to OPYCC
  (bnc#1012628).
- arm64: lse: remove -fcall-used-x0 flag (bnc#1012628).
- rpmsg: smd: fix memory leak on channel create (bnc#1012628).
- Cramfs: fix abad comparison when wrap-arounds occur
  (bnc#1012628).
- ARM: dts: socfpga: Fix SDRAM node address for Arria10
  (bnc#1012628).
- arm64: dts: stratix10: Correct System Manager register size
  (bnc#1012628).
- soc: qcom: rmtfs-mem: Validate that scm is available
  (bnc#1012628).
- soc/tegra: pmc: Fix child-node lookup (bnc#1012628).
- selftests/ftrace: Fix synthetic event test to delete event
  correctly (bnc#1012628).
- selftests/powerpc: Fix ptrace tm failure (bnc#1012628).
- tracing: Return -ENOENT if there is no target synthetic event
  (bnc#1012628).
- btrfs: qgroup: Avoid calling qgroup functions if qgroup is
  not enabled (bnc#1012628).
- btrfs: Handle owner mismatch gracefully when walking up tree
  (bnc#1012628).
- btrfs: locking: Add extra check in btrfs_init_new_buffer()
  to avoid deadlock (bnc#1012628).
- btrfs: fix error handling in free_log_tree (bnc#1012628).
- btrfs: fix error handling in btrfs_dev_replace_start
  (bnc#1012628).
- btrfs: Enhance btrfs_trim_fs function to handle error better
  (bnc#1012628).
- btrfs: Ensure btrfs_trim_fs can trim the whole filesystem
  (bnc#1012628).
- btrfs: iterate all devices during trim, instead of
  fs_devices::alloc_list (bnc#1012628).
- btrfs: don't attempt to trim devices that don't support it
  (bnc#1012628).
- btrfs: keep trim from interfering with transaction commits
  (bnc#1012628).
- btrfs: wait on caching when putting the bg cache (bnc#1012628).
- Btrfs: don't clean dirty pages during buffered writes
  (bnc#1012628).
- btrfs: release metadata before running delayed refs
  (bnc#1012628).
- btrfs: protect space cache inode alloc with GFP_NOFS
  (bnc#1012628).
- btrfs: reset max_extent_size on clear in a bitmap (bnc#1012628).
- btrfs: make sure we create all new block groups (bnc#1012628).
- Btrfs: fix warning when replaying log after fsync of a tmpfile
  (bnc#1012628).
- Btrfs: fix wrong dentries after fsync of file that got its
  parent replaced (bnc#1012628).
- btrfs: qgroup: Dirty all qgroups before rescan (bnc#1012628).
- Btrfs: fix null pointer dereference on compressed write path
  error (bnc#1012628).
- Btrfs: fix assertion on fsync of regular file when using
  no-holes feature (bnc#1012628).
- Btrfs: fix deadlock when writing out free space caches
  (bnc#1012628).
- btrfs: reset max_extent_size properly (bnc#1012628).
- btrfs: set max_extent_size properly (bnc#1012628).
- btrfs: don't use ctl->free_space for max_extent_size
  (bnc#1012628).
- btrfs: only free reserved extent if we didn't insert it
  (bnc#1012628).
- btrfs: fix insert_reserved error handling (bnc#1012628).
- btrfs: don't run delayed_iputs in commit (bnc#1012628).
- btrfs: move the dio_sem higher up the callchain (bnc#1012628).
- Btrfs: fix use-after-free during inode eviction (bnc#1012628).
- Btrfs: fix use-after-free when dumping free space (bnc#1012628).
- net: sched: Remove TCA_OPTIONS from policy (bnc#1012628).
- userns: also map extents in the reverse map to kernel IDs
  (bnc#1012628).
- bpf: wait for running BPF programs when updating map-in-map
  (bnc#1012628).
- vga_switcheroo: Fix missing gpu_bound call at audio client
  registration (bnc#1012628).
- MD: fix invalid stored role for a disk - try2 (bnc#1012628).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- commit 8adee6e
* Tue Nov 13 2018 msuchanek@suse.de
- Add kernel-subpackage-build.spec (FATE#326579).
  - add kernel-subpackage-build.spec.in and support scripts
  - hook it in mkspec
  - extend the mechanism that copies dependencies inside
  kernel-binary.spec.in from kernel-%%build_flavor to
  kernel-%%build_flavor-base to also handle
  kernel-subpackage-build.spec.in using BINARY DEPS marker.
  - expand %%name in kernel-%%build_flavor so the dependencies are expanded
  correctly in kernel-subpackage-build.spec.in
- commit 9b3ca32
* Mon Nov 12 2018 mkubecek@suse.cz
- Update to 4.20-rc2
- Eliminated 1 patch
- Config changes:
  - I2C:
    I2C_NVIDIA_GPU=m
  - USB:
    UCSI_CCG=m
- commit 1c08d7f
* Sun Nov 11 2018 afaerber@suse.de
- config: arm64: Update to 4.20-rc1
- commit 2d02cd8
* Sun Nov 11 2018 jslaby@suse.cz
- vt: fix broken display when running aptitude (bnc#1114836).
- commit 5bec309
* Thu Nov  8 2018 tiwai@suse.de
- rpm/kernel-source.spec.in: Add patches.drm for moved DRM patches
- commit 8592674
* Thu Nov  8 2018 jslaby@suse.cz
- doc/README.SUSE: correct GIT url
  No more gitorious, github we use.
- commit 31864f3
* Tue Nov  6 2018 mkubecek@suse.cz
- config: reenable BPFILTER_UMH on ppc64
- commit 46cb36e
* Tue Nov  6 2018 agraf@suse.de
- Remove Cell/PS3 support from ppc64 kernel (boo#1114846)
- commit c336d64
* Mon Nov  5 2018 mkubecek@suse.cz
- scripts/mkmakefile: honor second argument.
- commit 78325a6
* Mon Nov  5 2018 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: add macros.s into kernel-*-devel
  Starting with 4.20-rc1, file arch/*/kernel/macros.s is needed to build out
  of tree modules. Add it to kernel-${flavor}-devel packages if it exists.
- commit 09d14c8
* Mon Nov  5 2018 mkubecek@suse.cz
- series.conf: delete an obsolete comment
- commit c3bd57d
* Mon Nov  5 2018 jslaby@suse.cz
- Refresh
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
  Adapt to 4.20.
- commit dcaec93
* Mon Nov  5 2018 jslaby@suse.cz
- Linux 4.19.1 (bnc#1012628).
- net: bridge: remove ipv6 zero address check in mcast queries
  (bnc#1012628).
- sparc64: Wire up compat getpeername and getsockname
  (bnc#1012628).
- sparc64: Make corrupted user stacks more debuggable
  (bnc#1012628).
- sparc64: Export __node_distance (bnc#1012628).
- sctp: check policy more carefully when getting pr status
  (bnc#1012628).
- Revert "be2net: remove desc field from be_eq_obj" (bnc#1012628).
- r8169: fix broken Wake-on-LAN from S5 (poweroff) (bnc#1012628).
- net: Properly unlink GRO packets on overflow (bnc#1012628).
- net: drop skb on failure in ip_check_defrag() (bnc#1012628).
- mlxsw: core: Fix devlink unregister flow (bnc#1012628).
- mlxsw: spectrum_switchdev: Don't ignore deletions of learned
  MACs (bnc#1012628).
- net/smc: fix smc_buf_unuse to use the lgr pointer (bnc#1012628).
- net/ipv6: Allow onlink routes to have a device mismatch if it
  is the default route (bnc#1012628).
- openvswitch: Fix push/pop ethernet validation (bnc#1012628).
- bonding: fix length of actor system (bnc#1012628).
- vhost: Fix Spectre V1 vulnerability (bnc#1012628).
- rtnetlink: Disallow FDB configuration for non-Ethernet device
  (bnc#1012628).
- Revert "net: simplify sock_poll_wait" (bnc#1012628).
- net: udp: fix handling of CHECKSUM_COMPLETE packets
  (bnc#1012628).
- net: stmmac: Fix stmmac_mdio_reset() when building stmmac as
  modules (bnc#1012628).
- net: sched: gred: pass the right attribute to
  gred_change_table_def() (bnc#1012628).
- net/mlx5e: fix csum adjustments caused by RXFCS (bnc#1012628).
- ipv6/ndisc: Preserve IPv6 control buffer if protocol error
  handlers are called (bnc#1012628).
- bridge: do not add port to router list when receives query
  with source 0.0.0.0 (bnc#1012628).
- commit 57135d7
* Mon Nov  5 2018 mkubecek@suse.cz
- Update to 4.20-rc1
- ARM configs need updating
- disabled (needs refresh):
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch
- Config changes:
  - General:
  - PSI=y
  - Networking:
  - NFT_XFRM=m
  - NET_SCH_TAPRIO=m
  - BATMAN_ADV_TRACING=n
  - NCSI_OEM_CMD_GET_MAC=y
  - EEPROM_EE1004=m
  - SCSI_UFS_BSG=y
  - SCSI_MYRB=m
  - SCSI_MYRS=m
  - IXGBE_IPSEC=y
  - IXGBEVF_IPSEC=y
  - IGC=m
  - NI_XGE_MANAGEMENT_ENET=m
  - MT76x0E=m
  - File systems:
  - EROFS_FS_IO_MAX_RETRIES=5 (default)
  - AFS_DEBUG_CURSOR=n
  - CONFIG_UBIFS_FS_AUTHENTICATION=y
  - Crypto:
  - CRYPTO_OFB=m
  - CRYPTO_STATS=n
  - ASYMMETRIC_TPM_KEY_SUBTYPE=m
  - PKCS8_PRIVATE_KEY_PARSER=m
  - TPM_KEY_PARSER=m
  - Graphics:
  - VIDEO_VICODEC=m
  - DRM_FBDEV_LEAK_PHYS_SMEM=n
  - DRM_I915_DEBUG_RUNTIME_PM=n
  - DRM_TOSHIBA_TC358764=n
  - DRM_TI_SN65DSI86=n
  - Sound:
  - SND_SOC_INTEL_KBL_DA7219_MAX98927_MACH=m
  - SND_SOC_INTEL_SKL_HDA_DSP_GENERIC_MACH=m
  - SND_SOC_MAX98088=n
  - SND_SOC_PCM3060_I2C=n
  - SND_SOC_PCM3060_SPI=n
  - SND_SOC_NAU8822=n
  - Input devices:
  - HID_BIGBEN_FF=m
  - Platform:
  - LG_LAPTOP=m
  - INTEL_ATOMISP2_PM=m
  - IIO:
  - ADXL372_SPI=n
  - ADXL372_I2C=n
  - MCP3911=n
  - QCOM_SPMI_ADC5=n
  - LTC1660=n
  - VL53L0X_I2C=m
  - Misc drivers:
  - UDMABUF=y
  - MFD_AT91_USART=n
  - LEDS_AN30259A=n
  - LEDS_TRIGGER_PATTERN=m
  - PHY_CADENCE_DP=m
  - STM_PROTO_BASIC=m
  - STM_PROTO_SYS_T=m
  - Testing:
  - TEST_XARRAY=n
  - TEST_MEMCAT_P=n
  - x86:
  - X86_CPA_STATISTICS=n (y for -debug)
  - i386:
  - MSCC_OCELOT_SWITCH_OCELOT=m
  - ppc64, ppc64le:
  - PAPR_SCM=m
  - PCI_P2PDMA=y
  - STACKPROTECTOR=y
  - STACKPROTECTOR_STRONG=n
  - BLK_DEV_PMEM=m
  - ND_BLK=m
  - BTT=y
  - NVDIMM_PFN=y
  - NVDIMM_DAX=y
  - OF_PMEM=m
  - DEV_DAX_PMEM=m
  - FAIL_FUNCTION=n
  - ENA_ETHERNET=m
  - s390:
  - VMAP_STACK=y
  - S390_AP_IOMMU=n
  - ZCRYPT_MULTIDEVNODES=y
  - KASAN=n
  - */debug:
  - INTEL_IOMMU_DEBUGFS=y
  - BPF_KPROBE_OVERRIDE=y
  - CONFIG_X86_CPA_STATISTICS=y
  - CONFIG_CRYPTO_STATS=y
- commit f29310b
* Sun Nov  4 2018 mkubecek@suse.cz
- rpm: use syncconfig instead of silentoldconfig where available
  Since mainline commit 0085b4191f3e ("kconfig: remove silentoldconfig
  target"), "make silentoldconfig" can be no longer used. Use "make
  syncconfig" instead if available.
- commit a239c6e
* Fri Nov  2 2018 mkubecek@suse.cz
- series.conf: more descriptive name for network driver section
  We have two networking sections in series.conf: one for networking core and
  one for network drivers. The latter is among other driver related sections
  but it may not be obvious that it is not intended for core networking
  patches. Change the label to "Network drivers" to make its purpose more
  apparent.
- commit 7968e32
* Fri Nov  2 2018 mkubecek@suse.cz
- config: enable SCSI_AACRAID on ppc64le and ppc64 (bsc#1114523)
- commit 5f3762b
* Tue Oct 30 2018 jslaby@suse.cz
- Refresh
  patches.suse/netfilter-bridge-define-INT_MIN-INT_MAX-in-userspace.patch.
  Update upstream status.
- commit 37417fa
* Tue Oct 30 2018 jmoreira@suse.de
- Add version information to KLP_SYMBOLS file
- commit f77f8d2
* Mon Oct 29 2018 tiwai@suse.de
- cdrom: fix improper type cast, which can leat to information
  leak (CVE-2018-18710,bsc#1113751).
- commit 6216efb
* Thu Oct 25 2018 mwilck@suse.com
- rpm/kernel-binary.spec.in: allow unsupported modules for -extra
  (bsc#1111183). SLE-15 and later only.
- commit 0d585a8
* Wed Oct 24 2018 mkubecek@suse.cz
- series.conf: move patches.suse/netfilter-bridge-define-INT_MIN-INT_MAX-in-userspace.patch to netfilter section
- commit 7656685
* Wed Oct 24 2018 jslaby@suse.cz
- netfilter: bridge: define INT_MIN & INT_MAX in userspace
  (4.19 fixes).
- commit e7213f6
* Mon Oct 22 2018 mkubecek@suse.cz
- Update to 4.19 final
- Refresh configs
- commit b4c35bb
* Sat Oct 20 2018 jslaby@suse.cz
- Linux 4.18.16 (bnc#1012628).
- ARC: build: Don't set CROSS_COMPILE in arch's Makefile
  (bnc#1012628).
- ARC: build: Get rid of toolchain check (bnc#1012628).
- mremap: properly flush TLB before releasing the page
  (bnc#1012628).
- Revert "vfs: fix freeze protection in mnt_want_write_file()
  for overlayfs" (bnc#1012628).
- x86/boot: Fix kexec booting failure in the SEV bit detection
  code (bnc#1012628).
- iommu/amd: Return devid as alias for ACPI HID devices
  (bnc#1012628).
- powerpc/numa: Use associativity if VPHN hcall is successful
  (bnc#1012628).
- powerpc/tm: Avoid possible userspace r1 corruption on reclaim
  (bnc#1012628).
- powerpc/tm: Fix userspace r13 corruption (bnc#1012628).
- pinctrl/amd: poll InterruptEnable bits in amd_gpio_irq_set_type
  (bnc#1012628).
- iommu/rockchip: Free irqs in shutdown handler (bnc#1012628).
- RISC-V: include linux/ftrace.h in asm-prototypes.h
  (bnc#1012628).
- RDMA/bnxt_re: Fix system crash during RDMA resource
  initialization (bnc#1012628).
- clocksource/drivers/fttmr010: Fix set_next_event handler
  (bnc#1012628).
- net/mlx4: Use cpumask_available for eq->affinity_mask
  (bnc#1012628).
- bpf: test_maps, only support ESTABLISHED socks (bnc#1012628).
- bpf: sockmap, fix transition through disconnect without close
  (bnc#1012628).
- bpf: sockmap only allow ESTABLISHED sock state (bnc#1012628).
- scsi: sd: don't crash the host on invalid commands
  (bnc#1012628).
- scsi: ipr: System hung while dlpar adding primary ipr adapter
  back (bnc#1012628).
- drm: mali-dp: Call drm_crtc_vblank_reset on device init
  (bnc#1012628).
- scsi: lpfc: Synchronize access to remoteport via rport
  (bnc#1012628).
- RDMA/uverbs: Fix validity check for modify QP (bnc#1012628).
- PCI: dwc: Fix scheduling while atomic issues (bnc#1012628).
- qed: Do not add VLAN 0 tag to untagged frames in multi-function
  mode (bnc#1012628).
- qed: Fix populating the invalid stag value in multi function
  mode (bnc#1012628).
- net/smc: fix sizeof to int comparison (bnc#1012628).
- net/smc: fix non-blocking connect problem (bnc#1012628).
- ravb: do not write 1 to reserved bits (bnc#1012628).
- net: emac: fix fixed-link setup for the RTL8363SB switch
  (bnc#1012628).
- selftests: pmtu: properly redirect stderr to /dev/null
  (bnc#1012628).
- Input: atakbd - fix Atari CapsLock behaviour (bnc#1012628).
- Input: atakbd - fix Atari keymap (bnc#1012628).
- intel_th: pci: Add Ice Lake PCH support (bnc#1012628).
- scsi: ibmvscsis: Ensure partition name is properly NUL
  terminated (bnc#1012628).
- scsi: ibmvscsis: Fix a stringop-overflow warning (bnc#1012628).
- clocksource/drivers/ti-32k: Add CLOCK_SOURCE_SUSPEND_NONSTOP
  flag for non-am43 SoCs (bnc#1012628).
- cxgb4: fix abort_req_rss6 struct (bnc#1012628).
- batman-adv: fix hardif_neigh refcount on queue_work() failure
  (bnc#1012628).
- batman-adv: fix backbone_gw refcount on queue_work() failure
  (bnc#1012628).
- batman-adv: Prevent duplicated tvlv handler (bnc#1012628).
- batman-adv: Prevent duplicated global TT entry (bnc#1012628).
- batman-adv: Prevent duplicated softif_vlan entry (bnc#1012628).
- batman-adv: Prevent duplicated nc_node entry (bnc#1012628).
- batman-adv: Prevent duplicated gateway_node entry (bnc#1012628).
- batman-adv: Fix segfault when writing to sysfs elp_interval
  (bnc#1012628).
- batman-adv: Fix segfault when writing to throughput_override
  (bnc#1012628).
- batman-adv: Avoid probe ELP information leak (bnc#1012628).
- spi: gpio: Fix copy-and-paste error (bnc#1012628).
- media: af9035: prevent buffer overflow on write (bnc#1012628).
- soundwire: Fix acquiring bus lock twice during master release
  (bnc#1012628).
- soundwire: Fix incorrect exit after configuring stream
  (bnc#1012628).
- soundwire: Fix duplicate stream state assignment (bnc#1012628).
- commit bd19c86
* Thu Oct 18 2018 jslaby@suse.cz
- Linux 4.18.15 (bnc#1012628).
- KVM: PPC: Book3S HV: Avoid crash from THP collapse during
  radix page fault (bnc#1012628).
- i2c: i2c-scmi: fix for i2c_smbus_write_block_data (bnc#1012628).
- mm: Preserve _PAGE_DEVMAP across mprotect() calls (bnc#1012628).
- filesystem-dax: Fix dax_layout_busy_page() livelock
  (bnc#1012628).
- mm/thp: fix call to mmu_notifier in set_pmd_migration_entry()
  v2 (bnc#1012628).
- mm/mmap.c: don't clobber partially overlapping VMA with
  MAP_FIXED_NOREPLACE (bnc#1012628).
- arm64: perf: Reject stand-alone CHAIN events for PMUv3
  (bnc#1012628).
- pinctrl: mcp23s08: fix irq and irqchip setup order
  (bnc#1012628).
- mmc: block: avoid multiblock reads for the last sector in SPI
  mode (bnc#1012628).
- drm/nouveau/drm/nouveau: Grab runtime PM ref in
  nv50_mstc_detect() (bnc#1012628).
- Input: xpad - add support for Xbox1 PDP Camo series gamepad
  (bnc#1012628).
- cgroup: Fix dom_cgrp propagation when enabling threaded mode
  (bnc#1012628).
- dm linear: fix linear_end_io conditional definition
  (bnc#1012628).
- dm linear: eliminate linear_end_io call if CONFIG_DM_ZONED
  disabled (bnc#1012628).
- dm: fix report zone remapping to account for partition offset
  (bnc#1012628).
- dm cache: destroy migration_cache if cache target registration
  failed (bnc#1012628).
- s390/cio: Fix how vfio-ccw checks pinned pages (bnc#1012628).
- perf script python: Fix export-to-sqlite.py sample columns
  (bnc#1012628).
- perf script python: Fix export-to-postgresql.py occasional
  failure (bnc#1012628).
- percpu: stop leaking bitmap metadata blocks (bnc#1012628).
- vsprintf: Fix off-by-one bug in bstr_printf() processing
  dereferenced pointers (bnc#1012628).
- mach64: detect the dot clock divider correctly on sparc
  (bnc#1012628).
- MIPS: VDSO: Always map near top of user memory (bnc#1012628).
- MIPS: Fix CONFIG_CMDLINE handling (bnc#1012628).
- afs: Fix clearance of reply (bnc#1012628).
- afs: Fix afs_server struct leak (bnc#1012628).
- mm/vmstat.c: fix outdated vmstat_text (bnc#1012628).
- mm: slowly shrink slabs with a relatively small number of
  objects (bnc#1012628).
- drm/amdkfd: Fix ATS capablity was not reported correctly on
  some APUs (bnc#1012628).
- drm/amdkfd: Change the control stack MTYPE from UC to NC on GFX9
  (bnc#1012628).
- drm/amdgpu: Fix SDMA HQD destroy error on gfx_v7 (bnc#1012628).
- x86/kvm/lapic: always disable MMIO interface in x2APIC mode
  (bnc#1012628).
- pinctrl: cannonlake: Fix gpio base for GPP-E (bnc#1012628).
- clk: x86: Stop marking clocks as CLK_IS_CRITICAL (bnc#1012628).
- clk: x86: add "ether_clk" alias for Bay Trail / Cherry Trail
  (bnc#1012628).
- PCI: hv: support reporting serial number as slot information
  (bnc#1012628).
- ARM: dts: at91: add new compatibility string for macb on sama5d3
  (bnc#1012628).
- net: macb: disable scatter-gather for macb on sama5d3
  (bnc#1012628).
- net: ethernet: ti: add missing GENERIC_ALLOCATOR dependency
  (bnc#1012628).
- hwmon: (nct6775) Use different register to get fan RPM for fan7
  (bnc#1012628).
- stmmac: fix valid numbers of unicast filter entries
  (bnc#1012628).
- hwmon: (nct6775) Fix RPM output for fan7 on NCT6796D
  (bnc#1012628).
- hwmon: (nct6775) Fix virtual temperature sources for NCT6796D
  (bnc#1012628).
- bpf: use __GFP_COMP while allocating page (bnc#1012628).
- bpf: btf: Fix end boundary calculation for type section
  (bnc#1012628).
- sound: don't call skl_init_chip() to reset intel skl soc
  (bnc#1012628).
- sound: enable interrupt after dma buffer initialization
  (bnc#1012628).
- scsi: qla2xxx: Fix an endian bug in fcpcmd_is_corrupted()
  (bnc#1012628).
- scsi: iscsi: target: Don't use stack buffer for scatterlist
  (bnc#1012628).
- KVM: PPC: Book3S HV: Don't use compound_order to determine
  host mapping size (bnc#1012628).
- mfd: omap-usb-host: Fix dts probe of children (bnc#1012628).
- Bluetooth: hci_ldisc: Free rw_semaphore on close (bnc#1012628).
- Bluetooth: Use correct tfm to generate OOB data (bnc#1012628).
- Bluetooth: SMP: Fix trying to use non-existent local OOB data
  (bnc#1012628).
- drm/pl111: Make sure of_device_id tables are NULL terminated
  (bnc#1012628).
- ASoC: AMD: Ensure reset bit is cleared before configuring
  (bnc#1012628).
- Fix cg_read_strcmp() (bnc#1012628).
- hwmon: (nct6775) Fix access to fan pulse registers
  (bnc#1012628).
- ASoC: rsnd: don't fallback to PIO mode when -EPROBE_DEFER
  (bnc#1012628).
- ASoC: rsnd: adg: care clock-frequency size (bnc#1012628).
- selftests: memory-hotplug: add required configs (bnc#1012628).
- selftests/efivarfs: add required kernel configs (bnc#1012628).
- selftests: add headers_install to lib.mk (bnc#1012628).
- ASoC: q6routing: initialize data correctly (bnc#1012628).
- ASoC: sigmadsp: safeload should not have lower byte limit
  (bnc#1012628).
- ASoC: wm8804: Add ACPI support (bnc#1012628).
- ASoC: max98373: Added 10ms sleep after amp software reset
  (bnc#1012628).
- selftests: kselftest: Remove outdated comment (bnc#1012628).
- selftests: android: move config up a level (bnc#1012628).
- ASoC: rt5514: Fix the issue of the delay volume applied again
  (bnc#1012628).
- ASoC: max98373: Added speaker FS gain cotnrol register to
  volatile (bnc#1012628).
- ASoC: dapm: Fix NULL pointer deference on CODEC to CODEC DAIs
  (bnc#1012628).
- vxlan: fill ttl inherit info (bnc#1012628).
- r8169: set RX_MULTI_EN bit in RxConfig for 8168F-family chips
  (bnc#1012628).
- r8169: fix network stalls due to missing bit TXCFG_AUTO_FIFO
  (bnc#1012628).
- qed: Fix shmem structure inconsistency between driver and the
  mfw (bnc#1012628).
- net: mscc: fix the frame extraction into the skb (bnc#1012628).
- net/ipv6: stop leaking percpu memory in fib6 info (bnc#1012628).
- net/ipv6: Remove extra call to ip6_convert_metrics for multipath
  case (bnc#1012628).
- bnxt_en: get the reduced max_irqs by the ones used by RDMA
  (bnc#1012628).
- bnxt_en: Fix enables field in HWRM_QUEUE_COS2BW_CFG request
  (bnc#1012628).
- net/mlx5: Check for SQ and not RQ state when modifying hairpin
  SQ (bnc#1012628).
- net: ipv4: don't let PMTU updates increase route MTU
  (bnc#1012628).
- bnxt_en: Fix VNIC reservations on the PF (bnc#1012628).
- rtnetlink: Fail dump if target netnsid is invalid (bnc#1012628).
- net: dsa: b53: Keep CPU port as tagged in all VLANs
  (bnc#1012628).
- inet: make sure to grab rcu_read_lock before using
  ireq->ireq_opt (bnc#1012628).
- tcp/dccp: fix lockdep issue when SYN is backlogged
  (bnc#1012628).
- sfp: fix oops with ethtool -m (bnc#1012628).
- net: phy: phylink: fix SFP interface autodetection
  (bnc#1012628).
- net-ethtool: ETHTOOL_GUFO did not and should not require
  CAP_NET_ADMIN (bnc#1012628).
- bnxt_en: don't try to offload VLAN 'modify' action
  (bnc#1012628).
- nfp: avoid soft lockups under control message storm
  (bnc#1012628).
- net: stmmac: Rework coalesce timer and fix multi-queue races
  (bnc#1012628).
- bonding: fix warning message (bnc#1012628).
- bonding: pass link-local packets to bonding master also
  (bnc#1012628).
- net/mlx5: E-Switch, Fix out of bound access when setting vport
  rate (bnc#1012628).
- net: aquantia: memory corruption on jumbo frames (bnc#1012628).
- net/mlx5e: Set vlan masks for all offloaded TC rules
  (bnc#1012628).
- net: dsa: bcm_sf2: Fix unbind ordering (bnc#1012628).
- net/packet: fix packet drop as of virtio gso (bnc#1012628).
- net: stmmac: Fixup the tail addr setting in xmit path
  (bnc#1012628).
- tun: napi flags belong to tfile (bnc#1012628).
- tun: initialize napi_mutex unconditionally (bnc#1012628).
- tun: remove unused parameters (bnc#1012628).
- net: qualcomm: rmnet: Fix incorrect allocation flag in receive
  path (bnc#1012628).
- net: qualcomm: rmnet: Fix incorrect allocation flag in transmit
  (bnc#1012628).
- net: qualcomm: rmnet: Skip processing loopback packets
  (bnc#1012628).
- udp: Unbreak modules that rely on external __skb_recv_udp()
  availability (bnc#1012628).
- tipc: fix flow control accounting for implicit connect
  (bnc#1012628).
- team: Forbid enslaving team device to itself (bnc#1012628).
- sctp: update dst pmtu with the correct daddr (bnc#1012628).
- rtnl: limit IFLA_NUM_TX_QUEUES and IFLA_NUM_RX_QUEUES to 4096
  (bnc#1012628).
- rtnetlink: fix rtnl_fdb_dump() for ndmsg header (bnc#1012628).
- commit 5a53676
* Thu Oct 18 2018 jslaby@suse.cz
- qmi_wwan: Added support for Gemalto's Cinterion ALASxx WWAN
  interface (bnc#1012628).
- qlcnic: fix Tx descriptor corruption on 82xx devices
  (bnc#1012628).
- net/usb: cancel pending work when unbinding smsc75xx
  (bnc#1012628).
- net: systemport: Fix wake-up interrupt race during resume
  (bnc#1012628).
- net: sched: cls_u32: fix hnode refcounting (bnc#1012628).
- net: sched: Add policy validation for tc attributes
  (bnc#1012628).
- net: mvpp2: fix a txq_done race condition (bnc#1012628).
- net: mvpp2: Extract the correct ethtype from the skb for tx
  csum offload (bnc#1012628).
- netlabel: check for IPV4MASK in addrinfo_get (bnc#1012628).
- net/ipv6: Display all addresses in output of /proc/net/if_inet6
  (bnc#1012628).
- net: ipv4: update fnhe_pmtu when first hop's MTU changes
  (bnc#1012628).
- net: hns: fix for unmapping problem when SMMU is on
  (bnc#1012628).
- net: dsa: bcm_sf2: Call setup during switch resume
  (bnc#1012628).
- ipv6: take rcu lock in rawv6_send_hdrinc() (bnc#1012628).
- ipv4: fix use-after-free in ip_cmsg_recv_dstaddr()
  (bnc#1012628).
- ip_tunnel: be careful when accessing the inner header
  (bnc#1012628).
- ip6_tunnel: be careful when accessing the inner header
  (bnc#1012628).
- bonding: avoid possible dead-lock (bnc#1012628).
- bnxt_en: free hwrm resources, if driver probe fails
  (bnc#1012628).
- bnxt_en: Fix TX timeout during netpoll (bnc#1012628).
- commit ee9d247
* Mon Oct 15 2018 mkubecek@suse.cz
- Update to 4.19-rc8
- commit 2e61ca8
* Sat Oct 13 2018 jslaby@suse.cz
- Linux 4.18.14 (bnc#1012628).
- ath10k: fix scan crash due to incorrect length calculation
  (bnc#1012628).
- rds: rds_ib_recv_alloc_cache() should call alloc_percpu_gfp()
  instead (bnc#1012628).
- ubifs: Check for name being NULL while mounting (bnc#1012628).
- ucma: fix a use-after-free in ucma_resolve_ip() (bnc#1012628).
- tipc: call start and done ops directly in
  __tipc_nl_compat_dumpit() (bnc#1012628).
- f2fs: fix invalid memory access (bnc#1012628).
- ARC: clone syscall to setp r25 as thread pointer (bnc#1012628).
- powerpc/lib: fix book3s/32 boot failure due to code patching
  (bnc#1012628).
- powerpc: Avoid code patching freed init sections (bnc#1012628).
- of: unittest: Disable interrupt node tests for old world MAC
  systems (bnc#1012628).
- tty: Drop tty->count on tty_reopen() failure (bnc#1012628).
- usb: cdc_acm: Do not leak URB buffers (bnc#1012628).
- USB: serial: option: add two-endpoints device-id flag
  (bnc#1012628).
- USB: serial: option: improve Quectel EP06 detection
  (bnc#1012628).
- USB: serial: simple: add Motorola Tetra MTP6550 id
  (bnc#1012628).
- usb: xhci-mtk: resume USB3 roothub first (bnc#1012628).
- xhci: Add missing CAS workaround for Intel Sunrise Point xHCI
  (bnc#1012628).
- dm cache: fix resize crash if user doesn't reload cache table
  (bnc#1012628).
- dm cache metadata: ignore hints array being too small during
  resize (bnc#1012628).
- dm mpath: fix attached_handler_name leak and dangling
  hw_handler_name pointer (bnc#1012628).
- PM / core: Clear the direct_complete flag on errors
  (bnc#1012628).
- mac80211: fix setting IEEE80211_KEY_FLAG_RX_MGMT for AP mode
  keys (bnc#1012628).
- PCI: Reprogram bridge prefetch registers on resume
  (bnc#1012628).
- x86/vdso: Fix vDSO syscall fallback asm constraint regression
  (bnc#1012628).
- x86/vdso: Only enable vDSO retpolines when enabled and supported
  (bnc#1012628).
- selftests/x86: Add clock_gettime() tests to test_vdso
  (bnc#1012628).
- x86/vdso: Fix asm constraints on vDSO syscall fallbacks
  (bnc#1012628).
- drm: fix use-after-free read in drm_mode_create_lease_ioctl()
  (bnc#1012628).
- drm/syncobj: Don't leak fences when WAIT_FOR_SUBMIT is set
  (bnc#1012628).
- drm/amdgpu: Fix vce work queue was not cancelled when suspend
  (bnc#1012628).
- mac80211: allocate TXQs for active monitor interfaces
  (bnc#1012628).
- mmc: slot-gpio: Fix debounce time to use miliseconds again
  (bnc#1012628).
- mmc: core: Fix debounce time to use microseconds (bnc#1012628).
- xen-netback: fix input validation in xenvif_set_hash_mapping()
  (bnc#1012628).
- fbdev/omapfb: fix omapfb_memory_read infoleak (bnc#1012628).
- clocksource/drivers/timer-atmel-pit: Properly handle error cases
  (bnc#1012628).
- pstore/ram: Fix failure-path memory leak in ramoops_init
  (bnc#1012628).
- blk-mq: I/O and timer unplugs are inverted in blktrace
  (bnc#1012628).
- KVM: VMX: check for existence of secondary exec controls before
  accessing (bnc#1012628).
- KVM: x86: fix L1TF's MMIO GFN calculation (bnc#1012628).
- mm/vmstat.c: skip NR_TLB_REMOTE_FLUSH* properly (bnc#1012628).
- mm, thp: fix mlocking THP page with migration enabled
  (bnc#1012628).
- mm: migration: fix migration of huge PMD shared pages
  (bnc#1012628).
- perf/core: Add sanity check to deal with pinned event failure
  (bnc#1012628).
- commit ce1c446
* Fri Oct 12 2018 tzimmermann@suse.de
- README: Clean-up trailing whitespace
- commit 06542f9
* Thu Oct 11 2018 tzimmermann@suse.de
- README: Update documentation wrt. Patch-mainline
  Common practice is to set Patch-mainline to a Linux release tag. More
  than 95%% of all patches follow this convention. The remaining 5%% have
  been fixed accordingly in SLE15.
  The README file is inconsistent wrt. to the content of Patch-mainline.
  In some places it refers to a release tag, in others it refers to a version
  number. With this cleanup, it refers to release tags everywhere.
  This change is a follow-up for commit 1d81d2699cd3.
- commit 57326f5
* Wed Oct 10 2018 jslaby@suse.cz
- Linux 4.18.13 (bnc#1012628).
- Revert "drm/amd/pp: Send khz clock values to DC for smu7/8"
  (bnc#1012628).
- dm thin metadata: fix __udivdi3 undefined on 32-bit
  (bnc#1012628).
- ixgbe: check return value of napi_complete_done() (bnc#1012628).
- HID: i2c-hid: disable runtime PM operations on hantick touchpad
  (bnc#1012628).
- ocfs2: fix locking for res->tracking and dlm->tracking_list
  (bnc#1012628).
- proc: restrict kernel stack dumps to root (bnc#1012628).
- tools: hv: fcopy: set 'error' in case an unknown operation
  was requested (bnc#1012628).
- Drivers: hv: vmbus: Use get/put_cpu() in vmbus_connect()
  (bnc#1012628).
- gpiolib: Free the last requested descriptor (bnc#1012628).
- crypto: caam/jr - fix ablkcipher_edesc pointer arithmetic
  (bnc#1012628).
- crypto: mxs-dcp - Fix wait logic on chan threads (bnc#1012628).
- crypto: chelsio - Fix memory corruption in DMA Mapped buffers
  (bnc#1012628).
- crypto: qat - Fix KASAN stack-out-of-bounds bug in adf_probe()
  (bnc#1012628).
- ALSA: hda/realtek - Cannot adjust speaker's volume on Dell
  XPS 27 7760 (bnc#1012628).
- iommu/amd: Clear memory encryption mask from physical address
  (bnc#1012628).
- smb2: fix missing files in root share directory listing
  (bnc#1012628).
- cpufreq: qcom-kryo: Fix section annotations (bnc#1012628).
- firmware: Always initialize the fw_priv list object
  (bnc#1012628).
- firmware: Fix security issue with request_firmware_into_buf()
  (bnc#1012628).
- b43: fix DMA error related regression with proprietary firmware
  (bnc#1012628).
- sysfs: Do not return POSIX ACL xattrs via listxattr
  (bnc#1012628).
- ovl: fix format of setxattr debug (bnc#1012628).
- ovl: fix memory leak on unlink of indexed file (bnc#1012628).
- ovl: fix access beyond unterminated strings (bnc#1012628).
- ovl: set I_CREATING on inode being created (bnc#1012628).
- vfs: don't evict uninitialized inode (bnc#1012628).
- new primitive: discard_new_inode() (bnc#1012628).
- x86/APM: Fix build warning when PROC_FS is not enabled
  (bnc#1012628).
- xen: fix GCC warning and remove duplicate EVTCHN_ROW/EVTCHN_COL
  usage (bnc#1012628).
- xen: avoid crash in disable_hotplug_cpu (bnc#1012628).
- xen/manage: don't complain about an empty value in control/sysrq
  node (bnc#1012628).
- asm-generic: io: Fix ioport_map() for !CONFIG_GENERIC_IOMAP &&
  CONFIG_INDIRECT_PIO (bnc#1012628).
- cifs: read overflow in is_valid_oplock_break() (bnc#1012628).
- s390/qeth: don't dump past end of unknown HW header
  (bnc#1012628).
- s390/qeth: use vzalloc for QUERY OAT buffer (bnc#1012628).
- r8169: Clear RTL_FLAG_TASK_*_PENDING when clearing
  RTL_FLAG_TASK_ENABLED (bnc#1012628).
- drm/amdgpu: fix error handling in amdgpu_cs_user_fence_chunk
  (bnc#1012628).
- arm64: jump_label.h: use asm_volatile_goto macro instead of
  "asm goto" (bnc#1012628).
- drm/amdgpu: Fix SDMA hang in prt mode v2 (bnc#1012628).
- hexagon: modify ffs() and fls() to return int (bnc#1012628).
- commit c434d5c
* Wed Oct 10 2018 jslaby@suse.cz
- arch/hexagon: fix kernel/dma.c build warning (bnc#1012628).
- commit b07518e
* Wed Oct 10 2018 jslaby@suse.cz
- netfilter: xt_hashlimit: use s->file instead of s->private
  (bnc#1012628).
- netfilter: nfnetlink_queue: Solve the NFQUEUE/conntrack clash
  for NF_REPEAT (bnc#1012628).
- dm thin metadata: try to avoid ever aborting transactions
  (bnc#1012628).
- sched/topology: Set correct NUMA topology type (bnc#1012628).
- perf/x86/intel: Add support/quirk for the MISPREDICT bit on
  Knights Landing CPUs (bnc#1012628).
- net: ena: fix missing calls to READ_ONCE (bnc#1012628).
- net: ena: fix missing lock during device destruction
  (bnc#1012628).
- net: ena: fix potential double ena_destroy_device()
  (bnc#1012628).
- net: ena: fix device destruction to gracefully free resources
  (bnc#1012628).
- net: ena: fix driver when PAGE_SIZE == 64kB (bnc#1012628).
- net: ena: fix surprise unplug NULL dereference kernel crash
  (bnc#1012628).
- fs/cifs: suppress a string overflow warning (bnc#1012628).
- r8169: set TxConfig register after TX / RX is enabled, just
  like RxConfig (bnc#1012628).
- dm raid: fix RAID leg rebuild errors (bnc#1012628).
- dm raid: fix rebuild of specific devices by updating superblock
  (bnc#1012628).
- dm raid: fix stripe adding reshape deadlock (bnc#1012628).
- drm/nouveau/disp/gm200-: enforce identity-mapped SOR assignment
  for LVDS/eDP panels (bnc#1012628).
- drm/nouveau/disp: fix DP disable race (bnc#1012628).
- drm/nouveau/TBDdevinit: don't fail when PMU/PRE_OS is missing
  from VBIOS (bnc#1012628).
- drm/nouveau/mmu: don't attempt to dereference vmm without
  valid instance pointer (bnc#1012628).
- drm/nouveau: fix oops in client init failure path (bnc#1012628).
- dm raid: fix reshape race on small devices (bnc#1012628).
- HID: i2c-hid: Don't reset device upon system resume
  (bnc#1012628).
- net/mlx5: Consider PCI domain in search for next dev
  (bnc#1012628).
- bnxt_re: Fix couple of memory leaks that could lead to IOMMU
  call traces (bnc#1012628).
- nvmet-rdma: fix possible bogus dereference under heavy load
  (bnc#1012628).
- USB: yurex: Check for truncation in yurex_read() (bnc#1012628).
- usb: host: xhci-plat: Iterate over parent nodes for finding
  quirks (bnc#1012628).
- HID: sensor-hub: Restore fixup for Lenovo ThinkPad Helix 2
  sensor hub report (bnc#1012628).
- riscv: Do not overwrite initrd_start and initrd_end
  (bnc#1012628).
- RDMA/ucma: check fd type in ucma_migrate_id() (bnc#1012628).
- iio: imu: st_lsm6dsx: take into account ts samples in wm
  configuration (bnc#1012628).
- Revert "iio: temperature: maxim_thermocouple: add MAX31856 part"
  (bnc#1012628).
- netfilter: nf_tables: release chain in flushing set
  (bnc#1012628).
- netfilter: kconfig: nat related expression depend on nftables
  core (bnc#1012628).
- perf annotate: Fix parsing aarch64 branch instructions after
  objdump update (bnc#1012628).
- perf probe powerpc: Ignore SyS symbols irrespective of
  endianness (bnc#1012628).
- perf util: Fix bad memory access in trace info (bnc#1012628).
- perf evsel: Fix potential null pointer dereference in
  perf_evsel__new_idx() (bnc#1012628).
- perf annotate: Properly interpret indirect call (bnc#1012628).
- commit 342ac1f
* Wed Oct 10 2018 jslaby@suse.cz
- scsi: qedi: Add the CRC size within iSCSI NVM image
  (bnc#1012628).
- scsi: iscsi: target: Fix conn_ops double free (bnc#1012628).
- scsi: iscsi: target: Set conn->sess to NULL when
  iscsi_login_set_conn_values fails (bnc#1012628).
- HID: hid-saitek: Add device ID for RAT 7 Contagion
  (bnc#1012628).
- usb: gadget: fotg210-udc: Fix memory leak of fotg210->ep[i]
  (bnc#1012628).
- HID: add support for Apple Magic Keyboards (bnc#1012628).
- HID: intel-ish-hid: Enable Sunrise Point-H ish driver
  (bnc#1012628).
- netfilter: xt_checksum: ignore gso skbs (bnc#1012628).
- netfilter: xt_cluster: add dependency on conntrack module
  (bnc#1012628).
- bpf: 32-bit RSH verification must truncate input before the
  ALU op (bnc#1012628).
- mm: madvise(MADV_DODUMP): allow hugetlbfs pages (bnc#1012628).
- afs: Fix cell specification to permit an empty address list
  (bnc#1012628).
- firmware: arm_scmi: fix divide by zero when sustained_perf_level
  is zero (bnc#1012628).
- ceph: avoid a use-after-free in ceph_destroy_options()
  (bnc#1012628).
- nds32: linker script: GCOV kernel may refers data in __exit
  (bnc#1012628).
- tools/vm/page-types.c: fix "defined but not used" warning
  (bnc#1012628).
- tools/vm/slabinfo.c: fix sign-compare warning (bnc#1012628).
- nds32: fix build error because of wrong semicolon (bnc#1012628).
- nds32: Fix get_user/put_user macro expand pointer problem
  (bnc#1012628).
- nds32: Fix empty call trace (bnc#1012628).
- nds32: add NULL entry to the end of_device_id array
  (bnc#1012628).
- nds32: fix logic for module (bnc#1012628).
- net/ibm/emac: wrong emac_calc_base call was used by typo
  (bnc#1012628).
- fsnotify: fix ignore mask logic in fsnotify() (bnc#1012628).
- mac80211: shorten the IBSS debug messages (bnc#1012628).
- mac80211: don't Tx a deauth frame if the AP forbade Tx
  (bnc#1012628).
- mac80211: Fix station bandwidth setting after channel switch
  (bnc#1012628).
- mac80211: fix a race between restart and CSA flows
  (bnc#1012628).
- mac80211: fix WMM TXOP calculation (bnc#1012628).
- cfg80211: fix a type issue in
  ieee80211_chandef_to_operating_class() (bnc#1012628).
- mac80211: fix an off-by-one issue in A-MSDU max_subframe
  computation (bnc#1012628).
- fs/cifs: don't translate SFM_SLASH (U+F026) to backslash
  (bnc#1012628).
- net: cadence: Fix a sleep-in-atomic-context bug in
  macb_halt_tx() (bnc#1012628).
- i2c: uniphier-f: issue STOP only for last message or I2C_M_STOP
  (bnc#1012628).
- i2c: uniphier: issue STOP only for last message or I2C_M_STOP
  (bnc#1012628).
- bpf: avoid misuse of psock when TCP_ULP_BPF collides with
  another ULP (bnc#1012628).
- bpf: Fix bpf_msg_pull_data() (bnc#1012628).
- ibmvnic: Include missing return code checks in reset function
  (bnc#1012628).
- selftests: pmtu: detect correct binary to ping ipv6 addresses
  (bnc#1012628).
- selftests: pmtu: maximum MTU for vti4 is 2^16-1-20
  (bnc#1012628).
- RAID10 BUG_ON in raise_barrier when force is true and
  conf->barrier is 0 (bnc#1012628).
- md/raid5-cache: disable reshape completely (bnc#1012628).
- Revert "blk-throttle: fix race between blkcg_bio_issue_check()
  and cgroup_rmdir()" (bnc#1012628).
- ARC: atomics: unbork atomic_fetch_##op() (bnc#1012628).
- gpio: Fix crash due to registration race (bnc#1012628).
- tools/kvm_stat: fix updates for dead guests (bnc#1012628).
- tools/kvm_stat: fix handling of invalid paths in debugfs
  provider (bnc#1012628).
- tools/kvm_stat: fix python3 issues (bnc#1012628).
- mac80211: always account for A-MSDU header changes
  (bnc#1012628).
- mac80211: do not convert to A-MSDU if frag/subframe limited
  (bnc#1012628).
- cfg80211: nl80211_update_ft_ies() to validate NL80211_ATTR_IE
  (bnc#1012628).
- tc-testing: add test-cases for numeric and invalid control
  action (bnc#1012628).
- net: mvpp2: initialize port of_node pointer (bnc#1012628).
- sh_eth: Add R7S9210 support (bnc#1012628).
- net: hns: add netif_carrier_off before change speed and duplex
  (bnc#1012628).
- net: hns: add the code for cleaning pkt in chip (bnc#1012628).
- tipc: switch to rhashtable iterator (bnc#1012628).
- bpf: fix sg shift repair start offset in bpf_msg_pull_data
  (bnc#1012628).
- bpf: fix shift upon scatterlist ring wrap-around in
  bpf_msg_pull_data (bnc#1012628).
- bpf: fix msg->data/data_end after sg shift repair in
  bpf_msg_pull_data (bnc#1012628).
- gpio: dwapb: Fix error handling in dwapb_gpio_probe()
  (bnc#1012628).
- gpiolib-acpi: Register GpioInt ACPI event handlers from a
  late_initcall (bnc#1012628).
- gpiolib: acpi: Switch to cansleep version of GPIO library call
  (bnc#1012628).
- mac80211: avoid kernel panic when building AMSDU from non-linear
  SKB (bnc#1012628).
- mac80211: mesh: fix HWMP sequence numbering to follow standard
  (bnc#1012628).
- gpio: adp5588: Fix sleep-in-atomic-context bug (bnc#1012628).
- bpf: fix several offset tests in bpf_msg_pull_data
  (bnc#1012628).
- nl80211: Pass center frequency in kHz instead of MHz
  (bnc#1012628).
- nl80211: Fix nla_put_u8 to u16 for NL80211_WMMR_TXOP
  (bnc#1012628).
- mac80211_hwsim: Fix possible Spectre-v1 for
  hwsim_world_regdom_custom (bnc#1012628).
- cfg80211: make wmm_rule part of the reg_rule structure
  (bnc#1012628).
- mac80211_hwsim: correct use of IEEE80211_VHT_CAP_RXSTBC_X
  (bnc#1012628).
- mac80211: correct use of IEEE80211_VHT_CAP_RXSTBC_X
  (bnc#1012628).
- bpf: sockmap, decrement copied count correctly in redirect
  error case (bnc#1012628).
- bpf, sockmap: fix psock refcount leak in bpf_tcp_recvmsg
  (bnc#1012628).
- bpf, sockmap: fix potential use after free in bpf_tcp_close
  (bnc#1012628).
- scsi: aacraid: fix a signedness bug (bnc#1012628).
- scsi: libata: Add missing newline at end of file (bnc#1012628).
- scsi: csiostor: fix incorrect port capabilities (bnc#1012628).
- scsi: csiostor: add a check for NULL pointer after kmalloc()
  (bnc#1012628).
- btrfs: btrfs_shrink_device should call commit transaction at
  the end (bnc#1012628).
- cfg80211: remove division by size of sizeof(struct
  ieee80211_wmm_rule) (bnc#1012628).
- KVM: PPC: Book3S HV: Don't truncate HPTE index in xlate function
  (bnc#1012628).
- Btrfs: fix unexpected failure of nocow buffered writes after
  snapshotting when low on space (bnc#1012628).
- mac80211_hwsim: require at least one channel (bnc#1012628).
- mac80211: Run TXQ teardown code before de-registering interfaces
  (bnc#1012628).
- rseq/selftests: fix parametrized test with -fpie (bnc#1012628).
- commit 37173f2
* Tue Oct  9 2018 msuchanek@suse.de
- Revert "Limit kernel-source build to architectures for which we build binaries"
  This reverts commit d6435125446d740016904abe30a60611549ae812.
- commit 48b03c4
* Mon Oct  8 2018 mkubecek@suse.cz
- Update to 4.19-rc7
- commit 63b130b
* Thu Oct  4 2018 mbrugger@suse.com
- arm64: Update config files. (bsc#1110716)
  Enable ST LPS25H pressure sensor.
- commit 9882f33
* Thu Oct  4 2018 jslaby@suse.cz
- Linux 4.18.12 (bnc#1012628).
- crypto: skcipher - Fix -Wstringop-truncation warnings
  (bnc#1012628).
- iio: adc: ina2xx: avoid kthread_stop() with stale task_struct
  (bnc#1012628).
- tsl2550: fix lux1_input error in low light (bnc#1012628).
- misc: ibmvmc: Use GFP_ATOMIC under spin lock (bnc#1012628).
- vmci: type promotion bug in qp_host_get_user_memory()
  (bnc#1012628).
- siox: don't create a thread without starting it (bnc#1012628).
- net: hns3: Fix for mailbox message truncated problem
  (bnc#1012628).
- net: hns3: Fix for mac pause not disable in pfc mode
  (bnc#1012628).
- net: hns3: Fix warning bug when doing lp selftest (bnc#1012628).
- net: hns3: Fix get_vector ops in hclgevf_main module
  (bnc#1012628).
- x86/numa_emulation: Fix emulated-to-physical node mapping
  (bnc#1012628).
- staging: rts5208: fix missing error check on call to
  rtsx_write_register (bnc#1012628).
- power: supply: axp288_charger: Fix initial
  constant_charge_current value (bnc#1012628).
- misc: sram: enable clock before registering regions
  (bnc#1012628).
- serial: sh-sci: Stop RX FIFO timer during port shutdown
  (bnc#1012628).
- uwb: hwa-rc: fix memory leak at probe (bnc#1012628).
- power: vexpress: fix corruption in notifier registration
  (bnc#1012628).
- iommu/amd: make sure TLB to be flushed before IOVA freed
  (bnc#1012628).
- Bluetooth: Add a new Realtek 8723DE ID 0bda:b009 (bnc#1012628).
- USB: serial: kobil_sct: fix modem-status error handling
  (bnc#1012628).
- 6lowpan: iphc: reset mac_header after decompress to fix panic
  (bnc#1012628).
- iommu/msm: Don't call iommu_device_{,un}link from atomic context
  (bnc#1012628).
- s390/mm: correct allocate_pgste proc_handler callback
  (bnc#1012628).
- power: remove possible deadlock when unregistering power_supply
  (bnc#1012628).
- drm/amd/display/dc/dce: Fix multiple potential integer overflows
  (bnc#1012628).
- drm/amd/display: fix use of uninitialized memory (bnc#1012628).
- md-cluster: clear another node's suspend_area after the copy
  is finished (bnc#1012628).
- cxgb4: Fix the condition to check if the card is T5
  (bnc#1012628).
- RDMA/bnxt_re: Fix a couple off by one bugs (bnc#1012628).
- RDMA/i40w: Hold read semaphore while looking after VMA
  (bnc#1012628).
- RDMA/bnxt_re: Fix a bunch of off by one bugs in qplib_fp.c
  (bnc#1012628).
- IB/core: type promotion bug in rdma_rw_init_one_mr()
  (bnc#1012628).
- media: exynos4-is: Prevent NULL pointer dereference in
  __isp_video_try_fmt() (bnc#1012628).
- IB/mlx4: Test port number before querying type (bnc#1012628).
- powerpc/kdump: Handle crashkernel memory reservation failure
  (bnc#1012628).
- media: fsl-viu: fix error handling in viu_of_probe()
  (bnc#1012628).
- vhost_net: Avoid tx vring kicks during busyloop (bnc#1012628).
- media: staging/imx: fill vb2_v4l2_buffer field entry
  (bnc#1012628).
- IB/mlx5: Fix GRE flow specification (bnc#1012628).
- include/rdma/opa_addr.h: Fix an endianness issue (bnc#1012628).
- x86/tsc: Add missing header to tsc_msr.c (bnc#1012628).
- ARM: hwmod: RTC: Don't assume lock/unlock will be called with
  irq enabled (bnc#1012628).
- x86/entry/64: Add two more instruction suffixes (bnc#1012628).
- ARM: dts: ls1021a: Add missing cooling device properties for
  CPUs (bnc#1012628).
- scsi: target/iscsi: Make iscsit_ta_authentication() respect
  the output buffer size (bnc#1012628).
- thermal: i.MX: Allow thermal probe to fail gracefully in case
  of bad calibration (bnc#1012628).
- scsi: klist: Make it safe to use klists in atomic context
  (bnc#1012628).
- scsi: ibmvscsi: Improve strings handling (bnc#1012628).
- scsi: target: Avoid that EXTENDED COPY commands trigger lock
  inversion (bnc#1012628).
- usb: wusbcore: security: cast sizeof to int for comparison
  (bnc#1012628).
- ath10k: sdio: use same endpoint id for all packets in a bundle
  (bnc#1012628).
- ath10k: sdio: set skb len for all rx packets (bnc#1012628).
- powerpc/powernv/ioda2: Reduce upper limit for DMA window size
  (bnc#1012628).
- platform/x86: asus-wireless: Fix uninitialized symbol usage
  (bnc#1012628).
- ACPI / button: increment wakeup count only when notified
  (bnc#1012628).
- s390/sysinfo: add missing #ifdef CONFIG_PROC_FS (bnc#1012628).
- s390/dasd: correct numa_node in dasd_alloc_queue (bnc#1012628).
- s390/scm_blk: correct numa_node in scm_blk_dev_setup
  (bnc#1012628).
- s390/extmem: fix gcc 8 stringop-overflow warning (bnc#1012628).
- mtd: rawnand: atmel: add module param to avoid using dma
  (bnc#1012628).
- iio: accel: adxl345: convert address field usage in
  iio_chan_spec (bnc#1012628).
- posix-timers: Make forward callback return s64 (bnc#1012628).
- posix-timers: Sanitize overrun handling (bnc#1012628).
- ALSA: snd-aoa: add of_node_put() in error path (bnc#1012628).
- selftests: forwarding: Tweak tc filters for mirror-to-gretap
  tests (bnc#1012628).
- ath10k: use locked skb_dequeue for rx completions (bnc#1012628).
- media: s3c-camif: ignore -ENOIOCTLCMD from v4l2_subdev_call
  for s_power (bnc#1012628).
- media: soc_camera: ov772x: correct setting of banding filter
  (bnc#1012628).
- media: omap3isp: zero-initialize the isp cam_xclk{a,b} initial
  data (bnc#1012628).
- media: ov772x: add checks for register read errors
  (bnc#1012628).
- staging: android: ashmem: Fix mmap size validation
  (bnc#1012628).
- media: ov772x: allow i2c controllers without
  I2C_FUNC_PROTOCOL_MANGLING (bnc#1012628).
- staging: mt7621-eth: Fix memory leak in mtk_add_mac() error path
  (bnc#1012628).
- drivers/tty: add error handling for pcmcia_loop_config
  (bnc#1012628).
- arm64: dts: renesas: salvator-common: Fix adv7482 decimal unit
  addresses (bnc#1012628).
- serial: pxa: Fix an error handling path in 'serial_pxa_probe()'
  (bnc#1012628).
- staging: mt7621-dts: Fix remaining pcie warnings (bnc#1012628).
- media: tm6000: add error handling for dvb_register_adapter
  (bnc#1012628).
- ASoC: qdsp6: qdafe: fix some off by one bugs (bnc#1012628).
- ALSA: hda: Add AZX_DCAPS_PM_RUNTIME for AMD Raven Ridge
  (bnc#1012628).
- net: phy: xgmiitorgmii: Check read_status results (bnc#1012628).
- ath10k: protect ath10k_htt_rx_ring_free with rx_ring.lock
  (bnc#1012628).
- drm/sun4i: Enable DW HDMI PHY clock (bnc#1012628).
- net: phy: xgmiitorgmii: Check phy_driver ready before accessing
  (bnc#1012628).
- drm/sun4i: Fix releasing node when enumerating enpoints
  (bnc#1012628).
- ath10k: transmit queued frames after processing rx packets
  (bnc#1012628).
- mt76x2: fix mrr idx/count estimation in
  mt76x2_mac_fill_tx_status() (bnc#1012628).
- rndis_wlan: potential buffer overflow in
  rndis_wlan_auth_indication() (bnc#1012628).
- brcmsmac: fix wrap around in conversion from constant to s16
  (bnc#1012628).
- bitfield: fix *_encode_bits() (bnc#1012628).
- wlcore: Add missing PM call for
  wlcore_cmd_wait_for_event_or_timeout() (bnc#1012628).
- drm/omap: gem: Fix mm_list locking (bnc#1012628).
- ARM: mvebu: declare asm symbols as character arrays in pmsu.c
  (bnc#1012628).
- RDMA/uverbs: Don't overwrite NULL pointer with ZERO_SIZE_PTR
  (bnc#1012628).
- Documentation/process: fix reST table border error
  (bnc#1012628).
- perf/hw_breakpoint: Split attribute parse and commit
  (bnc#1012628).
- arm: dts: mediatek: Add missing cooling device properties for
  CPUs (bnc#1012628).
- HID: hid-ntrig: add error handling for sysfs_create_group
  (bnc#1012628).
- HID: i2c-hid: Use devm to allocate i2c_hid struct (bnc#1012628).
- MIPS: boot: fix build rule of vmlinux.its.S (bnc#1012628).
- arm64: dts: renesas: Fix VSPD registers range (bnc#1012628).
- drm/v3d: Take a lock across GPU scheduler job creation and
  queuing (bnc#1012628).
- perf/x86/intel/lbr: Fix incomplete LBR call stack (bnc#1012628).
- scsi: bnx2i: add error handling for ioremap_nocache
  (bnc#1012628).
- iomap: complete partial direct I/O writes synchronously
  (bnc#1012628).
- scsi: hisi_sas: Fix the conflict between dev gone and host reset
  (bnc#1012628).
- spi: orion: fix CS GPIO handling again (bnc#1012628).
- scsi: megaraid_sas: Update controller info during resume
  (bnc#1012628).
- ASoC: Intel: bytcr_rt5640: Fix Acer Iconia 8 over-current
  detect threshold (bnc#1012628).
- ASoC: rt1305: Use ULL suffixes for 64-bit constants
  (bnc#1012628).
- ASoC: rsnd: SSI parent cares SWSP bit (bnc#1012628).
- EDAC, i7core: Fix memleaks and use-after-free on probe and
  remove (bnc#1012628).
- ASoC: dapm: Fix potential DAI widget pointer deref when linking
  DAIs (bnc#1012628).
- module: exclude SHN_UNDEF symbols from kallsyms api
  (bnc#1012628).
- gpio: Fix wrong rounding in gpio-menz127 (bnc#1012628).
- nfsd: fix corrupted reply to badly ordered compound
  (bnc#1012628).
- EDAC: Fix memleak in module init error path (bnc#1012628).
- EDAC, altera: Fix an error handling path in
  altr_s10_sdram_probe() (bnc#1012628).
- staging: pi433: fix race condition in pi433_ioctl (bnc#1012628).
- ath10k: fix incorrect size of dma_free_coherent in
  ath10k_ce_alloc_src_ring_64 (bnc#1012628).
- ath10k: snoc: use correct bus-specific pointer in RX retry
  (bnc#1012628).
- fs/lock: skip lock owner pid translation in case we are in
  init_pid_ns (bnc#1012628).
- ath10k: fix memory leak of tpc_stats (bnc#1012628).
- Input: xen-kbdfront - fix multi-touch XenStore node's locations
  (bnc#1012628).
- iio: 104-quad-8: Fix off-by-one error in register selection
  (bnc#1012628).
- drm/vc4: Add missing formats to vc4_format_mod_supported()
  (bnc#1012628).
- ARM: dts: dra7: fix DCAN node addresses (bnc#1012628).
- drm/vc4: plane: Expand the lower bits by repeating the higher
  bits (bnc#1012628).
- perf tests: Fix indexing when invoking subtests (bnc#1012628).
- gpio: tegra: Fix tegra_gpio_irq_set_type() (bnc#1012628).
- floppy: Do not copy a kernel pointer to user memory in FDGETPRM
  ioctl (bnc#1012628).
- block: fix deadline elevator drain for zoned block devices
  (bnc#1012628).
- x86/mm: Expand static page table for fixmap space (bnc#1012628).
- tty: serial: lpuart: avoid leaking struct tty_struct
  (bnc#1012628).
- serial: imx: restore handshaking irq for imx1 (bnc#1012628).
- serial: mvebu-uart: Fix reporting of effective CSIZE to
  userspace (bnc#1012628).
- serial: cpm_uart: return immediately from console poll
  (bnc#1012628).
- intel_th: Fix device removal logic (bnc#1012628).
- intel_th: Fix resource handling for ACPI glue layer
  (bnc#1012628).
- spi: tegra20-slink: explicitly enable/disable clock
  (bnc#1012628).
- spi: sh-msiof: Fix invalid SPI use during system suspend
  (bnc#1012628).
- spi: sh-msiof: Fix handling of write value for SISTR register
  (bnc#1012628).
- spi: rspi: Fix invalid SPI use during system suspend
  (bnc#1012628).
- spi: rspi: Fix interrupted DMA transfers (bnc#1012628).
- regulator: fix crash caused by null driver data (bnc#1012628).
- regulator: Fix 'do-nothing' value for regulators without
  suspend state (bnc#1012628).
- USB: fix error handling in usb_driver_claim_interface()
  (bnc#1012628).
- USB: handle NULL config in usb_find_alt_setting() (bnc#1012628).
- usb: roles: Take care of driver module reference counting
  (bnc#1012628).
- usb: core: safely deal with the dynamic quirk lists
  (bnc#1012628).
- usb: musb: dsps: do not disable CPPI41 irq in driver teardown
  (bnc#1012628).
- USB: usbdevfs: sanitize flags more (bnc#1012628).
- USB: usbdevfs: restore warning for nonsensical flags
  (bnc#1012628).
- Revert "usb: cdc-wdm: Fix a sleep-in-atomic-context bug in
  service_outstanding_interrupt()" (bnc#1012628).
- USB: remove LPM management from usb_driver_claim_interface()
  (bnc#1012628).
- uaccess: Fix is_source param for check_copy_size() in
  copy_to_iter_mcsafe() (bnc#1012628).
- ext2, dax: set ext2_dax_aops for dax files (bnc#1012628).
- filesystem-dax: Fix use of zero page (bnc#1012628).
- Input: elantech - enable middle button of touchpad on ThinkPad
  P72 (bnc#1012628).
- IB/srp: Avoid that sg_reset -d ${srp_device} triggers an
  infinite loop (bnc#1012628).
- IB/hfi1: Fix SL array bounds check (bnc#1012628).
- IB/hfi1: Invalid user input can result in crash (bnc#1012628).
- IB/hfi1: Fix context recovery when PBC has an UnsupportedVL
  (bnc#1012628).
- IB/hfi1: Fix destroy_qp hang after a link down (bnc#1012628).
- ACPI / hotplug / PCI: Don't scan for non-hotplug bridges if
  slot is not bridge (bnc#1012628).
- RDMA/uverbs: Atomically flush and mark closed the comp event
  queue (bnc#1012628).
- arm64: KVM: Tighten guest core register access from userspace
  (bnc#1012628).
- ARM: OMAP2+: Fix null hwmod for ti-sysc debug (bnc#1012628).
- ARM: OMAP2+: Fix module address for modules using mpu_rt_idx
  (bnc#1012628).
- bus: ti-sysc: Fix module register ioremap for larger offsets
  (bnc#1012628).
- qed: Wait for ready indication before rereading the shmem
  (bnc#1012628).
- qed: Wait for MCP halt and resume commands to take place
  (bnc#1012628).
- qed: Prevent a possible deadlock during driver load and unload
  (bnc#1012628).
- qed: Avoid sending mailbox commands when MFW is not responsive
  (bnc#1012628).
- thermal: of-thermal: disable passive polling when thermal zone
  is disabled (bnc#1012628).
- isofs: reject hardware sector size > 2048 bytes (bnc#1012628).
- mmc: atmel-mci: fix bad logic of sg_copy_{from,to}_buffer
  conversion (bnc#1012628).
- mmc: android-goldfish: fix bad logic of sg_copy_{from,to}_buffer
  conversion (bnc#1012628).
- bus: ti-sysc: Fix no_console_suspend handling (bnc#1012628).
- ARM: dts: omap4-droid4: fix vibrations on Droid 4 (bnc#1012628).
- bpf, sockmap: fix sock_hash_alloc and reject zero-sized keys
  (bnc#1012628).
- bpf, sockmap: fix sock hash count in alloc_sock_hash_elem
  (bnc#1012628).
- tls: possible hang when do_tcp_sendpages hits sndbuf is full
  case (bnc#1012628).
- bpf: sockmap: write_space events need to be passed to TCP
  handler (bnc#1012628).
- drm/amdgpu: fix VM clearing for the root PD (bnc#1012628).
- drm/amdgpu: fix preamble handling (bnc#1012628).
- amdgpu: fix multi-process hang issue (bnc#1012628).
- net/ncsi: Fixup .dumpit message flags and ID check in Netlink
  handler (bnc#1012628).
- tcp_bbr: add bbr_check_probe_rtt_done() helper (bnc#1012628).
- tcp_bbr: in restart from idle, see if we should exit PROBE_RTT
  (bnc#1012628).
- net: hns: fix length and page_offset overflow when
  CONFIG_ARM64_64K_PAGES (bnc#1012628).
- net: hns: fix skb->truesize underestimation (bnc#1012628).
- net: hns3: fix page_offset overflow when CONFIG_ARM64_64K_PAGES
  (bnc#1012628).
- ice: Fix multiple static analyser warnings (bnc#1012628).
- ice: Report stats for allocated queues via ethtool stats
  (bnc#1012628).
- ice: Clean control queues only when they are initialized
  (bnc#1012628).
- ice: Fix bugs in control queue processing (bnc#1012628).
- ice: Use order_base_2 to calculate higher power of 2
  (bnc#1012628).
- ice: Set VLAN flags correctly (bnc#1012628).
- tools: bpftool: return from do_event_pipe() on bad arguments
  (bnc#1012628).
- ice: Fix a few null pointer dereference issues (bnc#1012628).
- ice: Fix potential return of uninitialized value (bnc#1012628).
- e1000: check on netif_running() before calling e1000_up()
  (bnc#1012628).
- e1000: ensure to free old tx/rx rings in set_ringparam()
  (bnc#1012628).
- ixgbe: fix driver behaviour after issuing VFLR (bnc#1012628).
- i40e: Fix for Tx timeouts when interface is brought up if DCB
  is enabled (bnc#1012628).
- i40e: fix condition of WARN_ONCE for stat strings (bnc#1012628).
- crypto: chtls - fix null dereference chtls_free_uld()
  (bnc#1012628).
- crypto: cavium/nitrox - fix for command corruption in queue
  full case with backlog submissions (bnc#1012628).
- hwmon: (ina2xx) fix sysfs shunt resistor read access
  (bnc#1012628).
- hwmon: (adt7475) Make adt7475_read_word() return errors
  (bnc#1012628).
- Revert "ARM: dts: imx7d: Invert legacy PCI irq mapping"
  (bnc#1012628).
- drm/amdgpu: Enable/disable gfx PG feature in rlc safe mode
  (bnc#1012628).
- drm/amdgpu: Update power state at the end of smu hw_init
  (bnc#1012628).
- ata: ftide010: Add a quirk for SQ201 (bnc#1012628).
- nvme-fcloop: Fix dropped LS's to removed target port
  (bnc#1012628).
- ARM: dts: omap4-droid4: Fix emmc errors seen on some devices
  (bnc#1012628).
- drm/amdgpu: Need to set moved to true when evict bo
  (bnc#1012628).
- arm/arm64: smccc-1.1: Make return values unsigned long
  (bnc#1012628).
- arm/arm64: smccc-1.1: Handle function result as parameters
  (bnc#1012628).
- i2c: i801: Allow ACPI AML access I/O ports not reserved for
  SMBus (bnc#1012628).
- clk: x86: Set default parent to 48Mhz (bnc#1012628).
- x86/pti: Fix section mismatch warning/error (bnc#1012628).
- KVM: PPC: Book3S HV: Fix guest r11 corruption with POWER9 TM
  workarounds (bnc#1012628).
- powerpc: fix csum_ipv6_magic() on little endian platforms
  (bnc#1012628).
- powerpc/pkeys: Fix reading of ibm, processor-storage-keys
  property (bnc#1012628).
- powerpc/pseries: Fix unitialized timer reset on migration
  (bnc#1012628).
- arm64: KVM: Sanitize PSTATE.M when being set from userspace
  (bnc#1012628).
- media: v4l: event: Prevent freeing event subscriptions while
  accessed (bnc#1012628).
- commit a880bd8
* Tue Oct  2 2018 nborisov@suse.com
- Update config files. (boo##1109665)
- commit 76516eb
* Mon Oct  1 2018 msuchanek@suse.de
- rpm/mkspec: fix ppc64 kernel-source build.
- commit 85c9272
* Sun Sep 30 2018 mkubecek@suse.cz
- Update to 4.19-rc6
- Eliminated 2 patches
- commit 80aa112
* Sat Sep 29 2018 jslaby@suse.cz
- Linux 4.18.11 (bnc#1012628).
- spi: Fix double IDR allocation with DT aliases (bnc#1012628).
- iw_cxgb4: only allow 1 flush on user qps (bnc#1012628).
- vmw_balloon: include asm/io.h (bnc#1012628).
- sched/fair: Fix vruntime_normalized() for remote non-migration
  wakeup (bnc#1012628).
- ext4, dax: set ext4_dax_aops for dax files (bnc#1012628).
- ext4, dax: add ext4_bmap to ext4_dax_aops (bnc#1012628).
- ext4: show test_dummy_encryption mount option in /proc/mounts
  (bnc#1012628).
- ext4: don't mark mmp buffer head dirty (bnc#1012628).
- ext4: fix online resizing for bigalloc file systems with a 1k
  block size (bnc#1012628).
- ext4: fix online resize's handling of a too-small final block
  group (bnc#1012628).
- ext4: recalucate superblock checksum after updating free
  blocks/inodes (bnc#1012628).
- ext4: avoid arithemetic overflow that can trigger a BUG
  (bnc#1012628).
- ext4: avoid divide by zero fault when deleting corrupted inline
  directories (bnc#1012628).
- ext4: check to make sure the rename(2)'s destination is not
  freed (bnc#1012628).
- tty: vt_ioctl: fix potential Spectre v1 (bnc#1012628).
- drm/amdgpu: add new polaris pci id (bnc#1012628).
- drm: udl: Destroy framebuffer only if it was initialized
  (bnc#1012628).
- drm/vc4: Fix the "no scaling" case on multi-planar YUV formats
  (bnc#1012628).
- drm/nouveau/drm/nouveau: Prevent handling ACPI HPD events too
  early (bnc#1012628).
- drm/nouveau/drm/nouveau: Use pm_runtime_get_noresume() in
  connector_detect() (bnc#1012628).
- drm/nouveau/drm/nouveau: Fix deadlock with fb_helper with
  async RPM requests (bnc#1012628).
- drm/nouveau/drm/nouveau: Fix bogus drm_kms_helper_poll_enable()
  placement (bnc#1012628).
- drm/nouveau/drm/nouveau: Don't forget to cancel hpd_work on
  suspend/unload (bnc#1012628).
- drm/nouveau: Fix deadlocks in nouveau_connector_detect()
  (bnc#1012628).
- drm/nouveau: Remove duplicate poll_enable() in
  pmops_runtime_suspend() (bnc#1012628).
- drm/nouveau: Only write DP_MSTM_CTRL when needed (bnc#1012628).
- drm/nouveau: Reset MST branching unit before enabling
  (bnc#1012628).
- drm/i915/bdw: Increase IPS disable timeout to 100ms
  (bnc#1012628).
- ocfs2: fix ocfs2 read block panic (bnc#1012628).
- libata: mask swap internal and hardware tag (bnc#1012628).
- Revert "ubifs: xattr: Don't operate on deleted inodes"
  (bnc#1012628).
- scsi: target: iscsi: Use bin2hex instead of a re-implementation
  (bnc#1012628).
- scsi: target: iscsi: Use hex2bin instead of a re-implementation
  (bnc#1012628).
- Revert "uapi/linux/keyctl.h: don't use C++ reserved keyword
  as a struct member name" (bnc#1012628).
- bpf/verifier: disallow pointer subtraction (bnc#1012628).
- Revert "rpmsg: core: add support to power domains for devices"
  (bnc#1012628).
- mm: shmem.c: Correctly annotate new inodes for lockdep
  (bnc#1012628).
- mm: disable deferred struct page for 32-bit arches
  (bnc#1012628).
- fork: report pid exhaustion correctly (bnc#1012628).
- crypto: x86/aegis,morus - Do not require OSXSAVE for SSE2
  (bnc#1012628).
- ring-buffer: Allow for rescheduling when removing pages
  (bnc#1012628).
- Revert "PCI: Add ACS quirk for Intel 300 series" (bnc#1012628).
- spi: fix IDR collision on systems with both fixed and dynamic
  SPI bus numbers (bnc#1012628).
- xen/x86/vpmu: Zero struct pt_regs before calling into sample
  handling code (bnc#1012628).
- xen/netfront: don't bug in case of too many frags (bnc#1012628).
- platform/x86: alienware-wmi: Correct a memory leak
  (bnc#1012628).
- platform/x86: dell-smbios-wmi: Correct a memory leak
  (bnc#1012628).
- mtd: rawnand: denali: fix a race condition when DMA is kicked
  (bnc#1012628).
- mtd: devices: m25p80: Make sure the buffer passed in op is
  DMA-able (bnc#1012628).
- ALSA: oxfw: fix memory leak of private data (bnc#1012628).
- ALSA: oxfw: fix memory leak of discovered stream formats at
  error path (bnc#1012628).
- ALSA: oxfw: fix memory leak for model-dependent data at error
  path (bnc#1012628).
- ALSA: fireworks: fix memory leak of response buffer at error
  path (bnc#1012628).
- ALSA: firewire-tascam: fix memory leak of private data
  (bnc#1012628).
- ALSA: firewire-digi00x: fix memory leak of private data
  (bnc#1012628).
- ALSA: fireface: fix memory leak in ff400_switch_fetching_mode()
  (bnc#1012628).
- ALSA: emu10k1: fix possible info leak to userspace on
  SNDRV_EMU10K1_IOCTL_INFO (bnc#1012628).
- ALSA: bebob: use address returned by kmalloc() instead of
  kernel stack for streaming DMA mapping (bnc#1012628).
- ALSA: bebob: fix memory leak for M-Audio FW1814 and ProjectMix
  I/O at error path (bnc#1012628).
- ASoC: uapi: fix sound/skl-tplg-interface.h userspace compilation
  errors (bnc#1012628).
- ASoC: rsnd: fixup not to call clk_get/set under non-atomic
  (bnc#1012628).
- ASoC: tas6424: Save last fault register even when clear
  (bnc#1012628).
- ASoC: cs4265: fix MMTLR Data switch control (bnc#1012628).
- ASoC: wm9712: fix replace codec to component (bnc#1012628).
- NFC: Fix the number of pipes (bnc#1012628).
- NFC: Fix possible memory corruption when handling SHDLC I-Frame
  commands (bnc#1012628).
- net: rtnl_configure_link: fix dev flags changes arg to
  __dev_notify_flags (bnc#1012628).
- net: mvpp2: let phylink manage the carrier state (bnc#1012628).
- net/ipv6: do not copy dst flags on rt init (bnc#1012628).
- ipv6: use rt6_info members when dst is set in rt6_fill_node
  (bnc#1012628).
- bnxt_en: Fix VF mac address regression (bnc#1012628).
- tls: fix currently broken MSG_PEEK behavior (bnc#1012628).
- socket: fix struct ifreq size in compat ioctl (bnc#1012628).
- net: dsa: mv88e6xxx: Fix ATU Miss Violation (bnc#1012628).
- hv_netvsc: fix schedule in RCU context (bnc#1012628).
- net/sched: act_sample: fix NULL dereference in the data path
  (bnc#1012628).
- udp6: add missing checks on edumux packet processing
  (bnc#1012628).
- neighbour: confirm neigh entries when ARP packet is received
  (bnc#1012628).
- tls: clear key material from kernel memory when
  do_tls_setsockopt_conf fails (bnc#1012628).
- tls: zero the crypto information from tls_context before freeing
  (bnc#1012628).
- tls: don't copy the key out of tls12_crypto_info_aes_gcm_128
  (bnc#1012628).
- udp4: fix IP_CMSG_CHECKSUM for connected sockets (bnc#1012628).
- qmi_wwan: set DTR for modems in forced USB2 mode (bnc#1012628).
- pppoe: fix reception of frames with no mac header (bnc#1012628).
- net: hp100: fix always-true check for link up state
  (bnc#1012628).
- net/appletalk: fix minor pointer leak to userspace in
  SIOCFINDIPDDPRT (bnc#1012628).
- ipv6: fix possible use-after-free in ip6_xmit() (bnc#1012628).
- gso_segment: Reset skb->mac_len after modifying network header
  (bnc#1012628).
- commit 4a5c1c1
* Sat Sep 29 2018 lduncan@suse.com
- Added CVE numbers for two patches (bsc#1107829)
- commit e3ac2a8
* Fri Sep 28 2018 lduncan@suse.com
- scsi: target: iscsi: Use bin2hex instead of a re-implementation
  (bsc#1107829).
- scsi: target: iscsi: Use hex2bin instead of a re-implementation
  (bsc#1107829).
- commit 8791706
* Thu Sep 27 2018 msuchanek@suse.de
- rpm/mkspec: build dtbs for architectures marked -!needs_updating
- commit 2d47640
* Thu Sep 27 2018 msuchanek@suse.de
- Limit kernel-source build to architectures for which we build binaries
  (bsc#1108281).
- commit d643512
* Wed Sep 26 2018 jslaby@suse.cz
- Linux 4.18.10 (bnc#1012628).
- crypto: ccp - add timeout support in the SEV command
  (bnc#1012628).
- mei: bus: type promotion bug in mei_nfc_if_version()
  (bnc#1012628).
- clk: tegra: bpmp: Don't crash when a clock fails to register
  (bnc#1012628).
- pinctrl: qcom: spmi-gpio: Fix pmic_gpio_config_get() to be
  compliant (bnc#1012628).
- pinctrl: msm: Fix msm_config_group_get() to be compliant
  (bnc#1012628).
- blk-mq: avoid to synchronize rcu inside blk_cleanup_queue()
  (bnc#1012628).
- blk-mq: only attempt to merge bio if there is rq in sw queue
  (bnc#1012628).
- IB/mlx5: fix uaccess beyond "count" in debugfs read/write
  handlers (bnc#1012628).
- block/DAC960.c: fix defined but not used build warnings
  (bnc#1012628).
- staging: fsl-dpaa2/eth: Fix DMA mapping direction (bnc#1012628).
- dmaengine: sh: rcar-dmac: avoid to write CHCR.TE to 1 if TCR
  is set to 0 (bnc#1012628).
- drm/amd/pp: Send khz clock values to DC for smu7/8
  (bnc#1012628).
- arm64: perf: Disable PMU while processing counter overflows
  (bnc#1012628).
- drm/panel: type promotion bug in s6e8aa0_read_mtp_id()
  (bnc#1012628).
- ASoC: rt5651: Fix workqueue cancel vs irq free race on remove
  (bnc#1012628).
- selftest: timers: Tweak raw_skew to SKIP when ADJ_OFFSET/other
  clock adjustments are in progress (bnc#1012628).
- remoteproc: qcom: q6v5-pil: fix modem hang on SDM845 after
  axis2 clk unvote (bnc#1012628).
- scsi: lpfc: Fix panic if driver unloaded when port is offline
  (bnc#1012628).
- scsi: lpfc: Fix NVME Target crash in defer rcv logic
  (bnc#1012628).
- scsi: libfc: fixup 'sleeping function called from invalid
  context' (bnc#1012628).
- ALSA: pcm: Fix snd_interval_refine first/last with open min/max
  (bnc#1012628).
- selftests/android: initialize heap_type to avoid compiling
  warning (bnc#1012628).
- selftests: vDSO - fix to return KSFT_SKIP when test couldn't
  be run (bnc#1012628).
- rtc: bq4802: add error handling for devm_ioremap (bnc#1012628).
- drm/amdkfd: Fix error codes in kfd_get_process (bnc#1012628).
- drm/amdkfd: Fix kernel queue 64 bit doorbell offset calculation
  (bnc#1012628).
- input: rohm_bu21023: switch to i2c_lock_bus(...,
  I2C_LOCK_SEGMENT) (bnc#1012628).
- mfd: 88pm860x-i2c: switch to i2c_lock_bus(..., I2C_LOCK_SEGMENT)
  (bnc#1012628).
- rcutorture: Use monotonic timestamp for stall detection
  (bnc#1012628).
- net: mvpp2: make sure we use single queue mode on PPv2.1
  (bnc#1012628).
- net: gemini: Allow multiple ports to instantiate (bnc#1012628).
- gpiolib: Mark gpio_suffixes array with __maybe_unused
  (bnc#1012628).
- gpio: pxa: Fix potential NULL dereference (bnc#1012628).
- staging: bcm2835-audio: Don't leak workqueue if open fails
  (bnc#1012628).
- lightnvm: pblk: enable line minor version detection
  (bnc#1012628).
- lightnvm: pblk: assume that chunks are closed on 1.2 devices
  (bnc#1012628).
- ASoC: qdsp6: q6afe-dai: fix a range check in
  of_q6afe_parse_dai_data() (bnc#1012628).
- drm/amd/display: support access ddc for mst branch
  (bnc#1012628).
- tools/testing/nvdimm: Fix support for emulating controller
  temperature (bnc#1012628).
- f2fs: do checkpoint in kill_sb (bnc#1012628).
- coresight: ETM: Add support for Arm Cortex-A73 and Cortex-A35
  (bnc#1012628).
- coresight: tpiu: Fix disabling timeouts (bnc#1012628).
- coresight: Handle errors in finding input/output ports
  (bnc#1012628).
- sched/fair: Fix util_avg of new tasks for asymmetric systems
  (bnc#1012628).
- parport: sunbpp: fix error return code (bnc#1012628).
- tls: Fix zerocopy_from_iter iov handling (bnc#1012628).
- drm/nouveau: tegra: Detach from ARM DMA/IOMMU mapping
  (bnc#1012628).
- drm/nouveau/debugfs: Wake up GPU before doing any reclocking
  (bnc#1012628).
- drm/nouveau: Fix runtime PM leak in drm_open() (bnc#1012628).
- mmc: sdhci: do not try to use 3.3V signaling if not supported
  (bnc#1012628).
- mmc: tegra: prevent HS200 on Tegra 3 (bnc#1012628).
- mmc: sdhci-of-esdhc: set proper dma mask for ls104x chips
  (bnc#1012628).
- tty: fix termios input-speed encoding (bnc#1012628).
- tty: fix termios input-speed encoding when using BOTHER
  (bnc#1012628).
- serial: 8250: of: Correct of_platform_serial_setup() error
  handling (bnc#1012628).
- ASoC: hdmi-codec: fix routing (bnc#1012628).
- gpu: ipu-v3: csi: pass back mbus_code_to_bus_cfg error codes
  (bnc#1012628).
- liquidio: fix hang when re-binding VF host drv after running
  DPDK VF driver (bnc#1012628).
- ARM: hisi: check of_iomap and fix missing of_node_put
  (bnc#1012628).
- net: hns3: Fix return value error in hns3_reset_notify_down_enet
  (bnc#1012628).
- ARM: hisi: fix error handling and missing of_node_put
  (bnc#1012628).
- ARM: hisi: handle of_iomap and fix missing of_node_put
  (bnc#1012628).
- net: hns3: Fix for reset_level default assignment probelm
  (bnc#1012628).
- net: hns3: Reset net device with rtnl_lock (bnc#1012628).
- efi/esrt: Only call efi_mem_reserve() for boot services memory
  (bnc#1012628).
- sched/core: Use smp_mb() in wake_woken_function() (bnc#1012628).
- arm64: dts: mt7622: update a clock property for UART0
  (bnc#1012628).
- pinctrl: rza1: Fix selector use for groups and functions
  (bnc#1012628).
- pinctrl: mt7622: Fix probe fail by misuse the selector
  (bnc#1012628).
- configfs: fix registered group removal (bnc#1012628).
- MIPS: loongson64: cs5536: Fix PCI_OHCI_INT_REG reads
  (bnc#1012628).
- KVM: PPC: Book3S: Fix matching of hardware and emulated TCE
  tables (bnc#1012628).
- PM / devfreq: use put_device() instead of kfree() (bnc#1012628).
- security: check for kstrdup() failure in lsm_append()
  (bnc#1012628).
- KVM: PPC: Book3S HV: Add of_node_put() in success path
  (bnc#1012628).
- evm: Don't deadlock if a crypto algorithm is unavailable
  (bnc#1012628).
- Bluetooth: Use lock_sock_nested in bt_accept_enqueue
  (bnc#1012628).
- spi: dw: fix possible race condition (bnc#1012628).
- bpf: fix rcu annotations in compute_effective_progs()
  (bnc#1012628).
- vfs: fix freeze protection in mnt_want_write_file() for
  overlayfs (bnc#1012628).
- mtdchar: fix overflows in adjustment of `count` (bnc#1012628).
- audit: fix use-after-free in audit_add_watch (bnc#1012628).
- arm64: dts: uniphier: Add missing cooling device properties
  for CPUs (bnc#1012628).
- net/mlx5: Add missing SET_DRIVER_VERSION command translation
  (bnc#1012628).
- binfmt_elf: Respect error return from `regset->active'
  (bnc#1012628).
- mmc: meson-mx-sdio: fix OF child-node lookup (bnc#1012628).
- of: add helper to lookup compatible child node (bnc#1012628).
- NFSv4.1 fix infinite loop on I/O (bnc#1012628).
- NFSv4: Fix a tracepoint Oops in initiate_file_draining()
  (bnc#1012628).
- x86/EISA: Don't probe EISA bus for Xen PV guests (bnc#1012628).
- of: fix phandle cache creation for DTs with no phandles
  (bnc#1012628).
- perf tools: Fix maps__find_symbol_by_name() (bnc#1012628).
- perf/core: Force USER_DS when recording user stack data
  (bnc#1012628).
- xtensa: ISS: don't allocate memory in platform_setup
  (bnc#1012628).
- cifs: integer overflow in in SMB2_ioctl() (bnc#1012628).
- CIFS: fix wrapping bugs in num_entries() (bnc#1012628).
- cifs: prevent integer overflow in nxt_dir_entry() (bnc#1012628).
- Revert "cdc-acm: implement put_char() and flush_chars()"
  (bnc#1012628).
- usb: cdc-wdm: Fix a sleep-in-atomic-context bug in
  service_outstanding_interrupt() (bnc#1012628).
- USB: yurex: Fix buffer over-read in yurex_write() (bnc#1012628).
- USB: serial: ti_usb_3410_5052: fix array underflow in completion
  handler (bnc#1012628).
- usb: misc: uss720: Fix two sleep-in-atomic-context bugs
  (bnc#1012628).
- USB: serial: io_ti: fix array underflow in completion handler
  (bnc#1012628).
- USB: net2280: Fix erroneous synchronization change
  (bnc#1012628).
- usb: gadget: udc: renesas_usb3: fix maxpacket size of ep0
  (bnc#1012628).
- USB: add quirk for WORLDE Controller KS49 or Prodipe MIDI 49C
  USB controller (bnc#1012628).
- usb: host: u132-hcd: Fix a sleep-in-atomic-context bug in
  u132_get_frame() (bnc#1012628).
- usb: Avoid use-after-free by flushing endpoints early in
  usb_set_interface() (bnc#1012628).
- usb: uas: add support for more quirk flags (bnc#1012628).
- USB: Add quirk to support DJI CineSSD (bnc#1012628).
- dm verity: fix crash on bufio buffer that was allocated with
  vmalloc (bnc#1012628).
- mei: bus: need to unlink client before freeing (bnc#1012628).
- mei: bus: fix hw module get/put balance (bnc#1012628).
- mei: ignore not found client in the enumeration (bnc#1012628).
- usb: mtu3: fix error of xhci port id when enable U3 dual role
  (bnc#1012628).
- usb: xhci: fix interrupt transfer error happened on MTK
  platforms (bnc#1012628).
- usb: Don't die twice if PCI xhci host is not responding in
  resume (bnc#1012628).
- xhci: Fix use after free for URB cancellation on a reallocated
  endpoint (bnc#1012628).
- misc: hmc6352: fix potential Spectre v1 (bnc#1012628).
- misc: ibmvsm: Fix wrong assignment of return code (bnc#1012628).
- Tools: hv: Fix a bug in the key delete code (bnc#1012628).
- vmbus: don't return values for uninitalized channels
  (bnc#1012628).
- ovl: fix oopses in ovl_fill_super() failure paths (bnc#1012628).
- ipmi: Fix I2C client removal in the SSIF driver (bnc#1012628).
- ipmi: Move BT capabilities detection to the detect call
  (bnc#1012628).
- ipmi: Rework SMI registration failure (bnc#1012628).
- mmc: omap_hsmmc: fix wakeirq handling on removal (bnc#1012628).
- s390/crypto: Fix return code checking in cbc_paes_crypt()
  (bnc#1012628).
- IB/ipoib: Avoid a race condition between start_xmit and
  cm_rep_handler (bnc#1012628).
- xen/netfront: fix waiting for xenbus state change (bnc#1012628).
- pstore: Fix incorrect persistent ram buffer mapping
  (bnc#1012628).
- RDMA/cma: Protect cma dev list with lock (bnc#1012628).
- xen-netfront: fix warn message as irq device name has '/'
  (bnc#1012628).
- PCI/AER: Honor "pcie_ports=native" even if HEST sets
  FIRMWARE_FIRST (bnc#1012628).
- x86/mm/pti: Add an overflow check to pti_clone_pmds()
  (bnc#1012628).
- x86/pti: Check the return value of pti_user_pagetable_walk_pmd()
  (bnc#1012628).
- x86/pti: Check the return value of pti_user_pagetable_walk_p4d()
  (bnc#1012628).
- crypto: sharah - Unregister correct algorithms for SAHARA 3
  (bnc#1012628).
- dmaengine: mv_xor_v2: kill the tasklets upon exit (bnc#1012628).
- iommu/ipmmu-vmsa: IMUCTRn.TTSEL needs a special usage on R-Car
  Gen3 (bnc#1012628).
- regulator: qcom_spmi: Fix warning Bad of_node_put()
  (bnc#1012628).
- regulator: qcom_spmi: Use correct regmap when checking for error
  (bnc#1012628).
- drm/amd/pp: Set Max clock level to display by default
  (bnc#1012628).
- i2c: aspeed: Fix initial values of master and slave state
  (bnc#1012628).
- drivers/base: stop new probing during shutdown (bnc#1012628).
- KVM: arm/arm64: Fix vgic init race (bnc#1012628).
- platform/x86: toshiba_acpi: Fix defined but not used build
  warnings (bnc#1012628).
- s390/qeth: reset layer2 attribute on layer switch (bnc#1012628).
- s390/qeth: fix race in used-buffer accounting (bnc#1012628).
- soc: qcom: smem: Correct check for global partition
  (bnc#1012628).
- ARM: dts: qcom: msm8974-hammerhead: increase load on l20 for
  sdhci (bnc#1012628).
- arm64: dts: qcom: db410c: Fix Bluetooth LED trigger
  (bnc#1012628).
- xen-netfront: fix queue name setting (bnc#1012628).
- nfp: avoid buffer leak when FW communication fails
  (bnc#1012628).
- ALSA: usb-audio: Generic DSD detection for Thesycon-based
  implementations (bnc#1012628).
- efi/arm: preserve early mapping of UEFI memory map longer for
  BGRT (bnc#1012628).
- reset: imx7: Fix always writing bits as 0 (bnc#1012628).
- arm64: fix possible spectre-v1 write in ptrace_hbp_set_event()
  (bnc#1012628).
- wan/fsl_ucc_hdlc: use IS_ERR_VALUE() to check return value of
  qe_muram_alloc (bnc#1012628).
- Smack: Fix handling of IPv4 traffic received by PF_INET6 sockets
  (bnc#1012628).
- mac80211: restrict delayed tailroom needed decrement
  (bnc#1012628).
- MIPS: jz4740: Bump zload address (bnc#1012628).
- ASoC: rt5514: Fix the issue of the delay volume applied
  (bnc#1012628).
- staging: bcm2835-camera: handle wait_for_completion_timeout
  return properly (bnc#1012628).
- staging: bcm2835-camera: fix timeout handling in
  wait_for_completion_timeout (bnc#1012628).
- perf script: Show correct offsets for DWARF-based unwinding
  (bnc#1012628).
- powerpc/powernv: opal_put_chars partial write fix (bnc#1012628).
- KVM: arm/arm64: vgic: Fix possible spectre-v1 write in
  vgic_mmio_write_apr() (bnc#1012628).
- nvme-rdma: unquiesce queues when deleting the controller
  (bnc#1012628).
- nvmet: fix file discard return status (bnc#1012628).
- perf powerpc: Fix callchain ip filtering (bnc#1012628).
- ARM: exynos: Clear global variable on init error path
  (bnc#1012628).
- omapfb: rename omap2 module to omap2fb.ko (bnc#1012628).
- fbdev: Distinguish between interlaced and progressive modes
  (bnc#1012628).
- video: fbdev: pxafb: clear allocated memory for video modes
  (bnc#1012628).
- perf powerpc: Fix callchain ip filtering when return address
  is in a register (bnc#1012628).
- fbdev/via: fix defined but not used warning (bnc#1012628).
- video: goldfishfb: fix memory leak on driver remove
  (bnc#1012628).
- perf tools: Fix struct comm_str removal crash (bnc#1012628).
- fbdev: omapfb: off by one in omapfb_register_client()
  (bnc#1012628).
- perf tests: Fix record+probe_libc_inet_pton.sh to ensure
  cleanups (bnc#1012628).
- perf tests: Fix record+probe_libc_inet_pton.sh when event exists
  (bnc#1012628).
- perf tests: Fix record+probe_libc_inet_pton.sh for powerpc64
  (bnc#1012628).
- perf tools: Synthesize GROUP_DESC feature in pipe mode
  (bnc#1012628).
- gfs2: Don't reject a supposedly full bitmap if we have blocks
  reserved (bnc#1012628).
- perf test: Fix subtest number when showing results
  (bnc#1012628).
- media: ov5645: Supported external clock is 24MHz (bnc#1012628).
- mtd/maps: fix solutionengine.c printk format warnings
  (bnc#1012628).
- IB/ipoib: Fix error return code in ipoib_dev_init()
  (bnc#1012628).
- block: allow max_discard_segments to be stacked (bnc#1012628).
- IB/rxe: Drop QP0 silently (bnc#1012628).
- media: videobuf2-core: check for q->error in vb2_core_qbuf()
  (bnc#1012628).
- MIPS: ath79: fix system restart (bnc#1012628).
- dmaengine: pl330: fix irq race with terminate_all (bnc#1012628).
- media: tw686x: Fix oops on buffer alloc failure (bnc#1012628).
- kbuild: do not update config when running install targets
  (bnc#1012628).
- kbuild: add .DELETE_ON_ERROR special target (bnc#1012628).
- clk: clk-fixed-factor: Clear OF_POPULATED flag in case of
  failure (bnc#1012628).
- clk: core: Potentially free connection id (bnc#1012628).
- Input: pxrc - fix freeing URB on device teardown (bnc#1012628).
- clk: mvebu: armada-37xx-periph: Fix wrong return value in
  get_parent (bnc#1012628).
- clk: imx6sll: fix missing of_node_put() (bnc#1012628).
- clk: imx6ul: fix missing of_node_put() (bnc#1012628).
- gfs2: Special-case rindex for gfs2_grow (bnc#1012628).
- iwlwifi: cancel the injective function between hw pointers to
  tfd entry index (bnc#1012628).
- nfp: don't fail probe on pci_sriov_set_totalvfs() errors
  (bnc#1012628).
- amd-xgbe: use dma_mapping_error to check map errors
  (bnc#1012628).
- xfrm: fix 'passing zero to ERR_PTR()' warning (bnc#1012628).
- ALSA: usb-audio: Fix multiple definitions in AU0828_DEVICE()
  macro (bnc#1012628).
- ALSA: usb-audio: Add support for Encore mDSD USB DAC
  (bnc#1012628).
- ALSA: msnd: Fix the default sample sizes (bnc#1012628).
- iommu/io-pgtable-arm: Fix pgtable allocation in selftest
  (bnc#1012628).
- iommu/io-pgtable-arm-v7s: Abort allocation when table address
  overflows the PTE (bnc#1012628).
- iommu/arm-smmu-v3: sync the OVACKFLG to PRIQ consumer register
  (bnc#1012628).
- usb: dwc3: change stream event enable bit back to 13
  (bnc#1012628).
- net/mlx5: Use u16 for Work Queue buffer fragment size
  (bnc#1012628).
- net/mlx5: Fix possible deadlock from lockdep when adding fte
  to fg (bnc#1012628).
- net/mlx5: Fix not releasing read lock when adding flow rules
  (bnc#1012628).
- tcp: really ignore MSG_ZEROCOPY if no SO_ZEROCOPY (bnc#1012628).
- erspan: return PACKET_REJECT when the appropriate tunnel is
  not found (bnc#1012628).
- erspan: fix error handling for erspan tunnel (bnc#1012628).
- net/mlx5: Fix debugfs cleanup in the device init/remove flow
  (bnc#1012628).
- net/mlx5: Check for error in mlx5_attach_interface
  (bnc#1012628).
- net/tls: Set count of SG entries if sk_alloc_sg returns -ENOSPC
  (bnc#1012628).
- net/mlx5: E-Switch, Fix memory leak when creating switchdev
  mode FDB tables (bnc#1012628).
- tipc: orphan sock in tipc_release() (bnc#1012628).
- rds: fix two RCU related problems (bnc#1012628).
- net: qca_spi: Fix race condition in spi transfers (bnc#1012628).
- net/mlx5: Fix use-after-free in self-healing flow (bnc#1012628).
- be2net: Fix memory leak in be_cmd_get_profile_config()
  (bnc#1012628).
- commit 3aeb311
* Tue Sep 25 2018 mbrugger@suse.com
- arm64: Update config files.
  Increase NR_CPUS to 480 (fate#325592)
- commit d5464c0
* Mon Sep 24 2018 mkubecek@suse.cz
- Update to 4.19-rc5
- commit b44d7bc
* Thu Sep 20 2018 jslaby@suse.cz
- Linux 4.18.9 (bnc#1012628).
- i2c: xiic: Make the start and the byte count write atomic
  (bnc#1012628).
- i2c: i801: fix DNV's SMBCTRL register offset (bnc#1012628).
- HID: multitouch: fix Elan panels with 2 input modes declaration
  (bnc#1012628).
- HID: core: fix grouping by application (bnc#1012628).
- HID: i2c-hid: Fix flooded incomplete report after S3 on Rayd
  touchscreen (bnc#1012628).
- HID: input: fix leaking custom input node name (bnc#1012628).
- mm/hugetlb: filter out hugetlb pages if HUGEPAGE migration is
  not supported (bnc#1012628).
- memory_hotplug: fix kernel_panic on offline page processing
  (bnc#1012628).
- mac80211: don't update the PM state of a peer upon a multicast
  frame (bnc#1012628).
- scsi: lpfc: Correct MDS diag and nvmet configuration
  (bnc#1012628).
- nbd: don't allow invalid blocksize settings (bnc#1012628).
- block: don't warn when doing fsync on read-only devices
  (bnc#1012628).
- block: bfq: swap puts in bfqg_and_blkg_put (bnc#1012628).
- android: binder: fix the race mmap and alloc_new_buf_locked
  (bnc#1012628).
- MIPS: VDSO: Match data page cache colouring when D$ aliases
  (bnc#1012628).
- SMB3: Backup intent flag missing for directory opens with
  backupuid mounts (bnc#1012628).
- smb3: check for and properly advertise directory lease support
  (bnc#1012628).
- cifs: connect to servername instead of IP for IPC$ share
  (bnc#1012628).
- btrfs: fix qgroup_free wrong num_bytes in
  btrfs_subvolume_reserve_metadata (bnc#1012628).
- Btrfs: fix data corruption when deduplicating between different
  files (bnc#1012628).
- KVM: arm/arm64: Clean dcache to PoC when changing PTE due to
  CoW (bnc#1012628).
- KVM: PPC: Book3S HV: Use correct pagesize in kvm_unmap_radix()
  (bnc#1012628).
- KVM: s390: vsie: copy wrapping keys to right place
  (bnc#1012628).
- KVM: x86: SVM: Set EMULTYPE_NO_REEXECUTE for RSM emulation
  (bnc#1012628).
- KVM: VMX: Do not allow reexecute_instruction() when skipping
  MMIO instr (bnc#1012628).
- KVM: x86: Invert emulation re-execute behavior to make it opt-in
  (bnc#1012628).
- KVM: x86: Merge EMULTYPE_RETRY and EMULTYPE_ALLOW_REEXECUTE
  (bnc#1012628).
- KVM: x86: Default to not allowing emulation retry in
  kvm_mmu_page_fault (bnc#1012628).
- KVM: x86: Do not re-{try,execute} after failed emulation in L2
  (bnc#1012628).
- ARC: [plat-axs*/plat-hsdk]: Allow U-Boot to pass MAC-address
  to the kernel (bnc#1012628).
- ACPI / LPSS: Force LPSS quirks on boot (bnc#1012628).
- memory: ti-aemif: fix a potential NULL-pointer dereference
  (bnc#1012628).
- ALSA: hda - Fix cancel_work_sync() stall from jackpoll work
  (bnc#1012628).
- cpu/hotplug: Adjust misplaced smb() in cpuhp_thread_fun()
  (bnc#1012628).
- cpu/hotplug: Prevent state corruption on error rollback
  (bnc#1012628).
- x86/microcode: Make sure boot_cpu_data.microcode is up-to-date
  (bnc#1012628).
- x86/microcode: Update the new microcode revision unconditionally
  (bnc#1012628).
- x86/process: Don't mix user/kernel regs in 64bit __show_regs()
  (bnc#1012628).
- x86/apic/vector: Make error return value negative (bnc#1012628).
- switchtec: Fix Spectre v1 vulnerability (bnc#1012628).
- ARC: [plat-axs*]: Enable SWAP (bnc#1012628).
- tc-testing: flush gact actions on test teardown (bnc#1012628).
- tc-testing: remove duplicate spaces in connmark match patterns
  (bnc#1012628).
- misc: mic: SCIF Fix scif_get_new_port() error handling
  (bnc#1012628).
- ALSA: hda/realtek - Add mute LED quirk for HP Spectre x360
  (bnc#1012628).
- ethtool: Remove trailing semicolon for static inline
  (bnc#1012628).
- i2c: aspeed: Add an explicit type casting for *get_clk_reg_val
  (bnc#1012628).
- Bluetooth: h5: Fix missing dependency on BT_HCIUART_SERDEV
  (bnc#1012628).
- pinctrl: berlin: fix 'pctrl->functions' allocation in
  berlin_pinctrl_build_state (bnc#1012628).
- gpio: tegra: Move driver registration to subsys_init level
  (bnc#1012628).
- powerpc/powernv: Fix concurrency issue with npu->mmio_atsd_usage
  (bnc#1012628).
- powerpc/4xx: Fix error return path in ppc4xx_msi_probe()
  (bnc#1012628).
- selftests/bpf: fix a typo in map in map test (bnc#1012628).
- media: davinci: vpif_display: Mix memory leak on probe error
  path (bnc#1012628).
- media: dw2102: Fix memleak on sequence of probes (bnc#1012628).
- net: phy: Fix the register offsets in Broadcom iProc mdio mux
  driver (bnc#1012628).
- scsi: qla2xxx: Fix unintended Logout (bnc#1012628).
- scsi: qla2xxx: Fix session state stuck in Get Port DB
  (bnc#1012628).
- scsi: qla2xxx: Silent erroneous message (bnc#1012628).
- clk: scmi: Fix the rounding of clock rate (bnc#1012628).
- blk-mq: fix updating tags depth (bnc#1012628).
- scsi: lpfc: Fix driver crash when re-registering NVME rports
  (bnc#1012628).
- scsi: target: fix __transport_register_session locking
  (bnc#1012628).
- md/raid5: fix data corruption of replacements after originals
  dropped (bnc#1012628).
- timers: Clear timer_base::must_forward_clk with timer_base::lock
  held (bnc#1012628).
- media: camss: csid: Configure data type and decode format
  properly (bnc#1012628).
- gpu: ipu-v3: default to id 0 on missing OF alias (bnc#1012628).
- misc: ti-st: Fix memory leak in the error path of probe()
  (bnc#1012628).
- uio: potential double frees if __uio_register_device() fails
  (bnc#1012628).
- firmware: vpd: Fix section enabled flag on vpd_section_destroy
  (bnc#1012628).
- Drivers: hv: vmbus: Cleanup synic memory free path
  (bnc#1012628).
- tty: rocket: Fix possible buffer overwrite on register_PCI
  (bnc#1012628).
- uio: fix possible circular locking dependency (bnc#1012628).
- iwlwifi: pcie: don't access periphery registers when not
  available (bnc#1012628).
- IB/IPoIB: Set ah valid flag in multicast send flow
  (bnc#1012628).
- f2fs: fix to active page in lru list for read path
  (bnc#1012628).
- f2fs: do not set free of current section (bnc#1012628).
- f2fs: Keep alloc_valid_block_count in sync (bnc#1012628).
- f2fs: issue discard align to section in LFS mode (bnc#1012628).
- f2fs: fix defined but not used build warnings (bnc#1012628).
- f2fs: fix to detect looped node chain correctly (bnc#1012628).
- ASoC: soc-pcm: Use delay set in component pointer function
  (bnc#1012628).
- perf tools: Allow overriding MAX_NR_CPUS at compile time
  (bnc#1012628).
- device-dax: avoid hang on error before devm_memremap_pages()
  (bnc#1012628).
- NFSv4.0 fix client reference leak in callback (bnc#1012628).
- perf c2c report: Fix crash for empty browser (bnc#1012628).
- perf evlist: Fix error out while applying initial delay and LBR
  (bnc#1012628).
- powerpc/pseries: fix EEH recovery of some IOV devices
  (bnc#1012628).
- macintosh/via-pmu: Add missing mmio accessors (bnc#1012628).
- perf build: Fix installation directory for eBPF (bnc#1012628).
- ath9k: report tx status on EOSP (bnc#1012628).
- ath9k_hw: fix channel maximum power level test (bnc#1012628).
- ath10k: prevent active scans on potential unusable channels
  (bnc#1012628).
- wlcore: Set rx_status boottime_ns field on rx (bnc#1012628).
- rpmsg: core: add support to power domains for devices
  (bnc#1012628).
- mtd: rawnand: make subop helpers return unsigned values
  (bnc#1012628).
- scsi: tcmu: do not set max_blocks if data_bitmap has been setup
  (bnc#1012628).
- MIPS: Fix ISA virt/bus conversion for non-zero PHYS_OFFSET
  (bnc#1012628).
- ata: libahci: Allow reconfigure of DEVSLP register
  (bnc#1012628).
- ata: libahci: Correct setting of DEVSLP register (bnc#1012628).
- nfs: Referrals not inheriting proto setting from parent
  (bnc#1012628).
- scsi: 3ware: fix return 0 on the error path of probe
  (bnc#1012628).
- tools/testing/nvdimm: kaddr and pfn can be NULL to
  - >direct_access() (bnc#1012628).
- ath10k: disable bundle mgmt tx completion event support
  (bnc#1012628).
- media: em28xx: explicitly disable TS packet filter
  (bnc#1012628).
- PCI: mobiveil: Add missing ../pci.h include (bnc#1012628).
- PCI: mobiveil: Fix struct mobiveil_pcie.pcie_reg_base address
  type (bnc#1012628).
- powerpc/mm: Don't report PUDs as memory leaks when using
  kmemleak (bnc#1012628).
- Bluetooth: hidp: Fix handling of strncpy for hid->name
  information (bnc#1012628).
- x86/mm: Remove in_nmi() warning from vmalloc_fault()
  (bnc#1012628).
- regulator: tps65217: Fix NULL pointer dereference on probe
  (bnc#1012628).
- pinctrl: imx: off by one in imx_pinconf_group_dbg_show()
  (bnc#1012628).
- gpio: pxa: disable pinctrl calls for PXA3xx (bnc#1012628).
- gpio: ml-ioh: Fix buffer underwrite on probe error path
  (bnc#1012628).
- pinctrl/amd: only handle irq if it is pending and unmasked
  (bnc#1012628).
- net: mvneta: fix mtu change on port without link (bnc#1012628).
- f2fs: try grabbing node page lock aggressively in sync scenario
  (bnc#1012628).
- pktcdvd: Fix possible Spectre-v1 for pkt_devs (bnc#1012628).
- f2fs: fix to skip GC if type in SSA and SIT is inconsistent
  (bnc#1012628).
- tpm_tis_spi: Pass the SPI IRQ down to the driver (bnc#1012628).
- tpm/tpm_i2c_infineon: switch to i2c_lock_bus(...,
  I2C_LOCK_SEGMENT) (bnc#1012628).
- f2fs: fix to do sanity check with reserved blkaddr of inline
  inode (bnc#1012628).
- MIPS: Octeon: add missing of_node_put() (bnc#1012628).
- MIPS: generic: fix missing of_node_put() (bnc#1012628).
- thermal: rcar_thermal: avoid NULL dereference in absence of
  IRQ resources (bnc#1012628).
- thermal_hwmon: Sanitize attribute name passed to hwmon
  (bnc#1012628).
- net: dcb: For wild-card lookups, use priority -1, not 0
  (bnc#1012628).
- dm cache: only allow a single io_mode cache feature to be
  requested (bnc#1012628).
- Input: atmel_mxt_ts - only use first T9 instance (bnc#1012628).
- media: s5p-mfc: Fix buffer look up in s5p_mfc_handle_frame_{new,
  copy_time} functions (bnc#1012628).
- partitions/aix: append null character to print data from disk
  (bnc#1012628).
- partitions/aix: fix usage of uninitialized lv_info and lvname
  structures (bnc#1012628).
- media: rcar-csi2: update stream start for V3M (bnc#1012628).
- media: helene: fix xtal frequency setting at power on
  (bnc#1012628).
- drm/amd/display: Prevent PSR from being enabled if
  initialization fails (bnc#1012628).
- media: em28xx: Fix dual transport stream operation
  (bnc#1012628).
- iommu/arm-smmu-v3: Abort all transactions if SMMU is enabled
  in kdump kernel (bnc#1012628).
- f2fs: fix to wait on page writeback before updating page
  (bnc#1012628).
- f2fs: Fix uninitialized return in f2fs_ioc_shutdown()
  (bnc#1012628).
- media: em28xx: Fix DualHD disconnect oops (bnc#1012628).
- f2fs: avoid potential deadlock in f2fs_sbi_store (bnc#1012628).
- f2fs: fix to do sanity check with secs_per_zone (bnc#1012628).
- mfd: rave-sp: Initialize flow control and parity of the port
  (bnc#1012628).
- iommu/ipmmu-vmsa: Fix allocation in atomic context
  (bnc#1012628).
- mfd: ti_am335x_tscadc: Fix struct clk memory leak (bnc#1012628).
- f2fs: fix to do sanity check with {sit,nat}_ver_bitmap_bytesize
  (bnc#1012628).
- f2fs: fix to propagate return value of scan_nat_page()
  (bnc#1012628).
- f2fs: fix to do sanity check with extra_attr feature
  (bnc#1012628).
- RDMA/hns: Add illegal hop_num judgement (bnc#1012628).
- NFSv4.1: Fix a potential layoutget/layoutrecall deadlock
  (bnc#1012628).
- RDMA/hns: Update the data type of immediate data (bnc#1012628).
- MIPS: WARN_ON invalid DMA cache maintenance, not BUG_ON
  (bnc#1012628).
- MIPS: mscc: ocelot: fix length of memory address space for MIIM
  (bnc#1012628).
- RDMA/cma: Do not ignore net namespace for unbound cm_id
  (bnc#1012628).
- clocksource: Revert "Remove kthread" (bnc#1012628).
- autofs: fix autofs_sbi() does not check super block type
  (bnc#1012628).
- mm: get rid of vmacache_flush_all() entirely (bnc#1012628).
- commit 67901ec
* Mon Sep 17 2018 mkubecek@suse.cz
- Update to 4.19-rc4
- Eliminated 1 patch
- Config changes:
  - Filesystems:
  - EROFS_FS=m
  - EROFS_FS_DEBUG=n
  - EROFS_FS_XATTR=y
  - EROFS_FS_POSIX_ACL=y
  - EROFS_FS_SECURITY=y
  - EROFS_FS_USE_VM_MAP_RAM=n
  - EROFS_FAULT_INJECTION=n
  - EROFS_FS_ZIP=n
- commit 625b101
* Sat Sep 15 2018 jslaby@suse.cz
- Linux 4.18.8 (bnc#1012628).
- ASoC: wm8994: Fix missing break in switch (bnc#1012628).
- HID: redragon: fix num lock and caps lock LEDs (bnc#1012628).
- x86: kvm: avoid unused variable warning (bnc#1012628).
- kvm: x86: Set highest physical address bits in
  non-present/reserved SPTEs (bnc#1012628).
- kbuild: make missing $DEPMOD a Warning instead of an Error
  (bnc#1012628).
- x86/xen: don't write ptes directly in 32-bit PV guests
  (bnc#1012628).
- x86/pae: use 64 bit atomic xchg function in
  native_ptep_get_and_clear (bnc#1012628).
- debugobjects: Make stack check warning more informative
  (bnc#1012628).
- drm/amdgpu: Don't warn on destroying a pinned BO (bnc#1012628).
- drm/amdgpu: Warn and update pin_size values when destroying
  a pinned BO (bnc#1012628).
- drm/amdgpu: Make pin_size values atomic (bnc#1012628).
- drm/amdgpu: Keep track of amount of pinned CPU visible VRAM
  (bnc#1012628).
- x86/tsc: Prevent result truncation on 32bit (bnc#1012628).
- drm/i915: set DP Main Stream Attribute for color range on DDI
  platforms (bnc#1012628).
- mm: respect arch_dup_mmap() return value (bnc#1012628).
- uapi/linux/keyctl.h: don't use C++ reserved keyword as a struct
  member name (bnc#1012628).
- drm/i915: Re-apply "Perform link quality check, unconditionally
  during long pulse" (bnc#1012628).
- drm/amdgpu: fix incorrect use of drm_file->pid (bnc#1012628).
- drm/amdgpu: fix incorrect use of fcheck (bnc#1012628).
- drm/amdgpu:add VCN booting with firmware loaded by PSP
  (bnc#1012628).
- drm/amdgpu:add VCN support in PSP driver (bnc#1012628).
- drm/amdgpu:add new firmware id for VCN (bnc#1012628).
- drm/amdgpu:add tmr mc address into amdgpu_firmware_info
  (bnc#1012628).
- drm/amdgpu: update tmr mc address (bnc#1012628).
- drm/amd/display: Check if clock source in use before disabling
  (bnc#1012628).
- drm/amd/display: Pass connector id when executing VBIOS CT
  (bnc#1012628).
- drm/rockchip: vop: fix irq disabled after vop driver probed
  (bnc#1012628).
- drm/rockchip: vop: split out core clock enablement into separate
  functions (bnc#1012628).
- drm/rockchip: lvds: add missing of_node_put (bnc#1012628).
- drm/amd/display: Report non-DP display as disconnected without
  EDID (bnc#1012628).
- drm/amd/display: Use requested HDMI aspect ratio (bnc#1012628).
- drm/amd/display: update clk for various HDMI color depths
  (bnc#1012628).
- drm/amd/display: Don't share clk source between DP and HDMI
  (bnc#1012628).
- drm/amd/display: fix type of variable (bnc#1012628).
- drm/edid: Add 6 bpc quirk for SDC panel in Lenovo B50-80
  (bnc#1012628).
- drm/edid: Quirk Vive Pro VR headset non-desktop (bnc#1012628).
- drm/amd/pp/Polaris12: Fix a chunk of registers missed to program
  (bnc#1012628).
- drm/amd/powerplay: fixed uninitialized value (bnc#1012628).
- drm/amd/pp: Convert voltage unit in mV*4 to mV on CZ/ST
  (bnc#1012628).
- drm/amdgpu: Fix RLC safe mode test in
  gfx_v9_0_enter_rlc_safe_mode (bnc#1012628).
- drm/amdgpu: fix a reversed condition (bnc#1012628).
- drm/amdgpu: update uvd_v6_0_ring_vm_funcs to use new nop packet
  (bnc#1012628).
- drm/i915: Free write_buf that we allocated with kzalloc
  (bnc#1012628).
- drm/i915: Increase LSPCON timeout (bnc#1012628).
- drm/i915: Nuke the LVDS lid notifier (bnc#1012628).
- drm/i915/lpe: Mark LPE audio runtime pm as "no callbacks"
  (bnc#1012628).
- btrfs: fix mount and ioctl device scan ioctl race (bnc#1012628).
- btrfs: reorder initialization before the mount locks uuid_mutex
  (bnc#1012628).
- btrfs: lift uuid_mutex to callers of btrfs_parse_early_options
  (bnc#1012628).
- btrfs: lift uuid_mutex to callers of btrfs_scan_one_device
  (bnc#1012628).
- btrfs: use device_list_mutex when removing stale devices
  (bnc#1012628).
- btrfs: rename local devices for fs_devices in
  btrfs_free_stale_devices( (bnc#1012628).
- btrfs: extend locked section when adding a new device in
  device_list_add (bnc#1012628).
- btrfs: do btrfs_free_stale_devices outside of device_list_add
  (bnc#1012628).
- ARM: rockchip: Force CONFIG_PM on Rockchip systems
  (bnc#1012628).
- arm64: rockchip: Force CONFIG_PM on Rockchip systems
  (bnc#1012628).
- btrfs: Fix a C compliance issue (bnc#1012628).
- btrfs: Don't remove block group that still has pinned down bytes
  (bnc#1012628).
- btrfs: lift uuid_mutex to callers of btrfs_open_devices
  (bnc#1012628).
- btrfs: check-integrity: Fix NULL pointer dereference for
  degraded mount (bnc#1012628).
- btrfs: tree-checker: Detect invalid and empty essential trees
  (bnc#1012628).
- btrfs: relocation: Only remove reloc rb_trees if reloc control
  has been initialized (bnc#1012628).
- btrfs: fix in-memory value of total_devices after seed device
  deletion (bnc#1012628).
- btrfs: replace: Reset on-disk dev stats value after replace
  (bnc#1012628).
- btrfs: Exit gracefully when chunk map cannot be inserted to
  the tree (bnc#1012628).
- drm/etnaviv: fix crash in GPU suspend when init failed due to
  buffer placement (bnc#1012628).
- kvm: nVMX: Fix fault vector for VMX operation at CPL > 0
  (bnc#1012628).
- KVM: vmx: track host_state.loaded using a loaded_vmcs pointer
  (bnc#1012628).
- drm/amd/display: Read back max backlight value at boot
  (bnc#1012628).
- clk: rockchip: Add pclk_rkpwm_pmu to PMU critical clocks in
  rk3399 (bnc#1012628).
- powerpc/pseries: Avoid using the size greater than
  RTAS_ERROR_LOG_MAX (bnc#1012628).
- um: fix parallel building with O= option (bnc#1012628).
- powerpc/64s: Make rfi_flush_fallback a little more robust
  (bnc#1012628).
- powerpc/platforms/85xx: fix t1042rdb_diu.c build errors &
  warning (bnc#1012628).
- smb3: if server does not support posix do not allow posix
  mount option (bnc#1012628).
- SMB3: Number of requests sent should be displayed for SMB3
  not just CIFS (bnc#1012628).
- CIFS: fix memory leak and remove dead code (bnc#1012628).
- smb3: fix reset of bytes read and written stats (bnc#1012628).
- cfq: Suppress compiler warnings about comparisons (bnc#1012628).
- RDS: IB: fix 'passing zero to ERR_PTR()' warning (bnc#1012628).
- selinux: cleanup dentry and inodes on error in selinuxfs
  (bnc#1012628).
- selftests/powerpc: Kill child processes on SIGINT (bnc#1012628).
- iommu/omap: Fix cache flushes on L2 table entries (bnc#1012628).
- ASoC: rt5677: Fix initialization of rt5677_of_match.data
  (bnc#1012628).
- staging: comedi: ni_mio_common: fix subdevice flags for PFI
  subdevice (bnc#1012628).
- dm kcopyd: avoid softlockup in run_complete_job (bnc#1012628).
- PCI: mvebu: Fix I/O space end address calculation (bnc#1012628).
- xen/balloon: fix balloon initialization for PVH Dom0
  (bnc#1012628).
- Input: do not use WARN() in input_alloc_absinfo() (bnc#1012628).
- NFSv4: Fix error handling in nfs4_sp4_select_mode()
  (bnc#1012628).
- scsi: aic94xx: fix an error code in aic94xx_init()
  (bnc#1012628).
- blk-mq: count the hctx as active before allocating tag
  (bnc#1012628).
- ACPI / scan: Initialize status to ACPI_STA_DEFAULT
  (bnc#1012628).
- s390/dasd: fix panic for failed online processing (bnc#1012628).
- s390/dasd: fix hanging offline processing due to canceled worker
  (bnc#1012628).
- brcmfmac: fix brcmf_wiphy_wowl_params() NULL pointer dereference
  (bnc#1012628).
- block: bvec_nr_vecs() returns value for wrong slab
  (bnc#1012628).
- perf probe powerpc: Fix trace event post-processing
  (bnc#1012628).
- powerpc: Fix size calculation using resource_size()
  (bnc#1012628).
- powerpc/uaccess: Enable get_user(u64, *p) on 32-bit
  (bnc#1012628).
- bpf: fix bpffs non-array map seq_show issue (bnc#1012628).
- pinctrl: axp209: Fix NULL pointer dereference after allocation
  (bnc#1012628).
- f2fs: fix to clear PG_checked flag in set_page_dirty()
  (bnc#1012628).
- net/9p: fix error path of p9_virtio_probe (bnc#1012628).
- net/9p/trans_fd.c: fix race by holding the lock (bnc#1012628).
- irqchip/bcm7038-l1: Hide cpu offline callback when building
  for !SMP (bnc#1012628).
- irqchip/stm32: Fix init error handling (bnc#1012628).
- RISC-V: Use KBUILD_CFLAGS instead of KCFLAGS when building
  the vDSO (bnc#1012628).
- f2fs: fix avoid race between truncate and background GC
  (bnc#1012628).
- f2fs: avoid race between zero_range and background GC
  (bnc#1012628).
- perf tools: Check for null when copying nsinfo (bnc#1012628).
- coccicheck: return proper error code on fail (bnc#1012628).
- drm/amd/display: Guard against null crtc in CRC IRQ
  (bnc#1012628).
- PCI: Match Root Port's MPS to endpoint's MPSS as necessary
  (bnc#1012628).
- net: hns3: Fix for phy link issue when using marvell phy driver
  (bnc#1012628).
- block: don't warn for flush on read-only device (bnc#1012628).
- net: hns3: Fix for command format parsing error in
  hclge_is_all_function_id_zero (bnc#1012628).
- perf arm spe: Fix uninitialized record error variable
  (bnc#1012628).
- ACPICA: ACPICA: add status check for acpi_hw_read before
  assigning return value (bnc#1012628).
- RDMA/hns: Fix usage of bitmap allocation functions return values
  (bnc#1012628).
- ubi: Initialize Fastmap checkmapping correctly (bnc#1012628).
- tcp, ulp: add alias for all ulp modules (bnc#1012628).
- netfilter: fix memory leaks on netlink_dump_start error
  (bnc#1012628).
- platform/x86: asus-nb-wmi: Add keymap entry for lid flip action
  on UX360 (bnc#1012628).
- netfilter: x_tables: do not fail xt_alloc_table_info too easilly
  (bnc#1012628).
- mfd: sm501: Set coherent_dma_mask when creating subdevices
  (bnc#1012628).
- ipvs: fix race between ip_vs_conn_new() and ip_vs_del_dest()
  (bnc#1012628).
- s390/kdump: Fix memleak in nt_vmcoreinfo (bnc#1012628).
- netfilter: ip6t_rpfilter: set F_IFACE for linklocal addresses
  (bnc#1012628).
- samples/bpf: all XDP samples should unload xdp/bpf prog on
  SIGTERM (bnc#1012628).
- bpf, sockmap: fix leakage of smap_psock_map_entry (bnc#1012628).
- net/xdp: Fix suspicious RCU usage warning (bnc#1012628).
- bpf, sockmap: fix sock_map_ctx_update_elem race with
  exist/noexist (bnc#1012628).
- tcp, ulp: fix leftover icsk_ulp_ops preventing sock from
  reattach (bnc#1012628).
- bpf, sockmap: fix map elem deletion race with smap_stop_sock
  (bnc#1012628).
- platform/x86: intel_punit_ipc: fix build errors (bnc#1012628).
- fs/dcache.c: fix kmemcheck splat at take_dentry_name_snapshot()
  (bnc#1012628).
- mm: make DEFERRED_STRUCT_PAGE_INIT explicitly depend on
  SPARSEMEM (bnc#1012628).
- mm/fadvise.c: fix signed overflow UBSAN complaint (bnc#1012628).
- powerpc/topology: Get topology for shared processors at boot
  (bnc#1012628).
- pwm: meson: Fix mux clock names (bnc#1012628).
- IB/hfi1: Invalid NUMA node information can cause a divide by
  zero (bnc#1012628).
- i2c: core: ACPI: Make acpi_gsb_i2c_read_bytes() check
  i2c_transfer return value (bnc#1012628).
- x86/mce: Add notifier_block forward declaration (bnc#1012628).
- virtio: pci-legacy: Validate queue pfn (bnc#1012628).
- apparmor: fix an error code in __aa_create_ns() (bnc#1012628).
- scripts: modpost: check memory allocation results (bnc#1012628).
- workqueue: re-add lockdep dependencies for flushing
  (bnc#1012628).
- workqueue: skip lockdep wq dependency in cancel_work_sync()
  (bnc#1012628).
- fat: validate ->i_start before using (bnc#1012628).
- fs/proc/kcore.c: use __pa_symbol() for KCORE_TEXT list entries
  (bnc#1012628).
- iommu/rockchip: Move irq request past pm_runtime_enable
  (bnc#1012628).
- hfsplus: fix NULL dereference in hfsplus_lookup() (bnc#1012628).
- iommu/rockchip: Handle errors returned from PM framework
  (bnc#1012628).
- reiserfs: change j_timestamp type to time64_t (bnc#1012628).
- fs/proc/vmcore.c: hide vmcoredd_mmap_dumps() for nommu builds
  (bnc#1012628).
- fork: don't copy inconsistent signal handler state to child
  (bnc#1012628).
- sunrpc: Don't use stack buffer with scatterlist (bnc#1012628).
- hfs: prevent crash on exit from failed search (bnc#1012628).
- hfsplus: don't return 0 when fill_super() failed (bnc#1012628).
- cifs: check if SMB2 PDU size has been padded and suppress the
  warning (bnc#1012628).
- hv_netvsc: ignore devices that are not PCI (bnc#1012628).
- vhost: correctly check the iova range when waking virtqueue
  (bnc#1012628).
- mlxsw: spectrum_switchdev: Do not leak RIFs when removing bridge
  (bnc#1012628).
- sctp: hold transport before accessing its asoc in
  sctp_transport_get_next (bnc#1012628).
- nfp: wait for posted reconfigs when disabling the device
  (bnc#1012628).
- ip6_vti: fix a null pointer deference when destroy vti6 tunnel
  (bnc#1012628).
- ip6_vti: fix creating fallback tunnel device for vti6
  (bnc#1012628).
- Revert "net: stmmac: Do not keep rearming the coalesce timer
  in stmmac_xmit" (bnc#1012628).
- r8169: set RxConfig after tx/rx is enabled for RTL8169sb/8110sb
  devices (bnc#1012628).
- net/mlx5: Fix SQ offset in QPs with small RQ (bnc#1012628).
- net/ipv6: Put lwtstate when destroying fib6_info (bnc#1012628).
- net/ipv6: Only update MTU metric if it set (bnc#1012628).
- net/ipv6: init ip6 anycast rt->dst.input as ip6_input
  (bnc#1012628).
- ipv6: don't get lwtstate twice in ip6_rt_copy_init()
  (bnc#1012628).
- net: macb: Fix regression breaking non-MDIO fixed-link PHYs
  (bnc#1012628).
- erspan: set erspan_ver to 1 by default when adding an erspan
  dev (bnc#1012628).
- sctp: remove useless start_fail from sctp_ht_iter in proc
  (bnc#1012628).
- tipc: fix the big/little endian issue in tipc_dest
  (bnc#1012628).
- hv_netvsc: Fix a deadlock by getting rtnl lock earlier in
  netvsc_probe() (bnc#1012628).
- tipc: fix a missing rhashtable_walk_exit() (bnc#1012628).
- net/sched: act_pedit: fix dump of extended layered op
  (bnc#1012628).
- bnxt_en: Do not adjust max_cp_rings by the ones used by RDMA
  (bnc#1012628).
- bnxt_en: Clean up unused functions (bnc#1012628).
- net: sched: action_ife: take reference to meta module
  (bnc#1012628).
- act_ife: fix a potential deadlock (bnc#1012628).
- act_ife: move tcfa_lock down to where necessary (bnc#1012628).
- vti6: remove !skb->ignore_df check from vti6_xmit()
  (bnc#1012628).
- tcp: do not restart timewait timer on rst reception
  (bnc#1012628).
- r8169: add support for NCube 8168 network card (bnc#1012628).
- r8152: disable RX aggregation on new Dell TB16 dock
  (bnc#1012628).
- qlge: Fix netdev features configuration (bnc#1012628).
- net: sched: Fix memory exposure from short TCA_U32_SEL
  (bnc#1012628).
- net: macb: do not disable MDIO bus at open/close time
  (bnc#1012628).
- net: bcmgenet: use MAC link status for fixed phy (bnc#1012628).
- ipv4: tcp: send zero IPID for RST and ACK sent in SYN-RECV
  and TIME-WAIT state (bnc#1012628).
- act_ife: fix a potential use-after-free (bnc#1012628).
- commit f486469
* Fri Sep 14 2018 mkubecek@suse.cz
- ip: frags: fix crash in ip_do_fragment() (bsc#1108533).
- commit ba41502
* Fri Sep 14 2018 msuchanek@suse.de
- doc/README.SUSE: Remove mentions of cloneconfig (bsc#1103636).
- commit 3371adc
* Thu Sep 13 2018 jbohac@suse.cz
- Delete patches.suse/x86_64-hpet-64bit-timer.patch.
  We removed the patch from SLE15 in commit
  20efbd0c034fea7c97243120a025587d0dbac1c2
  and we don't need it in future versions of SLE.
- commit aa4eb67
* Mon Sep 10 2018 msuchanek@suse.de
- macros.kernel-source: pass -b properly in kernel module package
  (bsc#1107870).
- commit 66709cd
* Mon Sep 10 2018 mkubecek@suse.cz
- Update to 4.19-rc3
- refresh configs
- commit d3995d7
* Sun Sep  9 2018 jslaby@suse.cz
- Linux 4.18.7 (bnc#1012628).
- rcu: Make expedited GPs handle CPU 0 being offline
  (bnc#1012628).
- net: 6lowpan: fix reserved space for single frames
  (bnc#1012628).
- net: mac802154: tx: expand tailroom if necessary (bnc#1012628).
- 9p/net: Fix zero-copy path in the 9p virtio transport
  (bnc#1012628).
- spi: davinci: fix a NULL pointer dereference (bnc#1012628).
- spi: pxa2xx: Add support for Intel Ice Lake (bnc#1012628).
- spi: spi-fsl-dspi: Fix imprecise abort on VF500 during probe
  (bnc#1012628).
- spi: cadence: Change usleep_range() to udelay(), for atomic
  context (bnc#1012628).
- mmc: block: Fix unsupported parallel dispatch of requests
  (bnc#1012628).
- mmc: renesas_sdhi_internal_dmac: mask DMAC interrupts
  (bnc#1012628).
- mmc: renesas_sdhi_internal_dmac: fix #define RST_RESERVED_BITS
  (bnc#1012628).
- readahead: stricter check for bdi io_pages (bnc#1012628).
- block: fix infinite loop if the device loses discard capability
  (bnc#1012628).
- block: blk_init_allocated_queue() set q->fq as NULL in the
  fail case (bnc#1012628).
- block: really disable runtime-pm for blk-mq (bnc#1012628).
- blkcg: Introduce blkg_root_lookup() (bnc#1012628).
- block: Introduce blk_exit_queue() (bnc#1012628).
- block: Ensure that a request queue is dissociated from the
  cgroup controller (bnc#1012628).
- apparmor: fix bad debug check in apparmor_secid_to_secctx()
  (bnc#1012628).
- dma-buf: Move BUG_ON from _add_shared_fence to
  _add_shared_inplace (bnc#1012628).
- libertas: fix suspend and resume for SDIO connected cards
  (bnc#1012628).
- media: Revert "[media] tvp5150: fix pad format frame height"
  (bnc#1012628).
- mailbox: xgene-slimpro: Fix potential NULL pointer dereference
  (bnc#1012628).
- Replace magic for trusting the secondary keyring with #define
  (bnc#1012628).
- Fix kexec forbidding kernels signed with keys in the secondary
  keyring to boot (bnc#1012628).
- powerpc/fadump: handle crash memory ranges array index overflow
  (bnc#1012628).
- powerpc/64s: Fix page table fragment refcount race vs
  speculative references (bnc#1012628).
- powerpc/pseries: Fix endianness while restoring of r3 in MCE
  handler (bnc#1012628).
- powerpc/pkeys: Give all threads control of their key permissions
  (bnc#1012628).
- powerpc/pkeys: Deny read/write/execute by default (bnc#1012628).
- powerpc/pkeys: key allocation/deallocation must not change
  pkey registers (bnc#1012628).
- powerpc/pkeys: Save the pkey registers before fork
  (bnc#1012628).
- powerpc/pkeys: Fix calculation of total pkeys (bnc#1012628).
- powerpc/pkeys: Preallocate execute-only key (bnc#1012628).
- powerpc/nohash: fix pte_access_permitted() (bnc#1012628).
- powerpc64/ftrace: Include ftrace.h needed for enable/disable
  calls (bnc#1012628).
- powerpc/powernv/pci: Work around races in PCI bridge enabling
  (bnc#1012628).
- cxl: Fix wrong comparison in cxl_adapter_context_get()
  (bnc#1012628).
- ocxl: Fix page fault handler in case of fault on dying process
  (bnc#1012628).
- IB/mlx5: Honor cnt_set_id_valid flag instead of set_id
  (bnc#1012628).
- IB/mlx5: Fix leaking stack memory to userspace (bnc#1012628).
- IB/srpt: Fix srpt_cm_req_recv() error path (1/2) (bnc#1012628).
- IB/srpt: Fix srpt_cm_req_recv() error path (2/2) (bnc#1012628).
- IB/srpt: Support HCAs with more than two ports (bnc#1012628).
- overflow.h: Add arithmetic shift helper (bnc#1012628).
- RDMA/mlx5: Fix shift overflow in mlx5_ib_create_wq
  (bnc#1012628).
- ib_srpt: Fix a use-after-free in srpt_close_ch() (bnc#1012628).
- ib_srpt: Fix a use-after-free in __srpt_close_all_ch()
  (bnc#1012628).
- RDMA/rxe: Set wqe->status correctly if an unexpected response
  is received (bnc#1012628).
- 9p: fix multiple NULL-pointer-dereferences (bnc#1012628).
- fs/9p/xattr.c: catch the error of p9_client_clunk when setting
  xattr failed (bnc#1012628).
- 9p/virtio: fix off-by-one error in sg list bounds check
  (bnc#1012628).
- net/9p/client.c: version pointer uninitialized (bnc#1012628).
- net/9p/trans_fd.c: fix race-condition by flushing workqueue
  before the kfree() (bnc#1012628).
- dm integrity: change 'suspending' variable from bool to int
  (bnc#1012628).
- dm thin: stop no_space_timeout worker when switching to
  write-mode (bnc#1012628).
- dm cache metadata: save in-core policy_hint_size to on-disk
  superblock (bnc#1012628).
- dm cache metadata: set dirty on all cache blocks after a crash
  (bnc#1012628).
- dm crypt: don't decrease device limits (bnc#1012628).
- dm writecache: fix a crash due to reading past end of
  dirty_bitmap (bnc#1012628).
- uart: fix race between uart_put_char() and uart_shutdown()
  (bnc#1012628).
- Drivers: hv: vmbus: Fix the offer_in_progress in
  vmbus_process_offer() (bnc#1012628).
- Drivers: hv: vmbus: Reset the channel callback in
  vmbus_onoffer_rescind() (bnc#1012628).
- iio: sca3000: Fix missing return in switch (bnc#1012628).
- iio: ad9523: Fix displayed phase (bnc#1012628).
- iio: ad9523: Fix return value for ad952x_store() (bnc#1012628).
- extcon: Release locking when sending the notification of
  connector state (bnc#1012628).
- eventpoll.h: wrap casts in () properly (bnc#1012628).
- vmw_balloon: fix inflation of 64-bit GFNs (bnc#1012628).
- vmw_balloon: do not use 2MB without batching (bnc#1012628).
- vmw_balloon: VMCI_DOORBELL_SET does not check status
  (bnc#1012628).
- vmw_balloon: fix VMCI use when balloon built into kernel
  (bnc#1012628).
- rtc: omap: fix resource leak in registration error path
  (bnc#1012628).
- rtc: omap: fix potential crash on power off (bnc#1012628).
- tracing: Do not call start/stop() functions when tracing_on
  does not change (bnc#1012628).
- tracing/blktrace: Fix to allow setting same value (bnc#1012628).
- printk/tracing: Do not trace printk_nmi_enter() (bnc#1012628).
- livepatch: Validate module/old func name length (bnc#1012628).
- uprobes: Use synchronize_rcu() not synchronize_sched()
  (bnc#1012628).
- mfd: hi655x: Fix regmap area declared size for hi655x
  (bnc#1012628).
- ovl: fix wrong use of impure dir cache in ovl_iterate()
  (bnc#1012628).
- ACPICA: AML Parser: skip opcodes that open a scope upon parse
  failure (bnc#1012628).
- drivers/block/zram/zram_drv.c: fix bug storing backing_dev
  (bnc#1012628).
- sched: idle: Avoid retaining the tick when it has been stopped
  (bnc#1012628).
- cpuidle: menu: Handle stopped tick more aggressively
  (bnc#1012628).
- cpufreq: governor: Avoid accessing invalid governor_data
  (bnc#1012628).
- PM / sleep: wakeup: Fix build error caused by missing SRCU
  support (bnc#1012628).
- ALSA: ac97: fix device initialization in the compat layer
  (bnc#1012628).
- ALSA: ac97: fix check of pm_runtime_get_sync failure
  (bnc#1012628).
- ALSA: ac97: fix unbalanced pm_runtime_enable (bnc#1012628).
- i2c: designware: Re-init controllers with pm_disabled set on
  resume (bnc#1012628).
- KVM: VMX: fixes for vmentry_l1d_flush module parameter
  (bnc#1012628).
- KVM: PPC: Book3S: Fix guest DMA when guest partially backed
  by THP pages (bnc#1012628).
- xtensa: limit offsets in __loop_cache_{all,page} (bnc#1012628).
- xtensa: increase ranges in ___invalidate_{i,d}cache_all
  (bnc#1012628).
- block, bfq: return nbytes and not zero from struct cftype
  .write() method (bnc#1012628).
- pnfs/blocklayout: off by one in bl_map_stripe() (bnc#1012628).
- nfsd: fix leaked file lock with nfs exported overlayfs
  (bnc#1012628).
- NFSv4 client live hangs after live data migration recovery
  (bnc#1012628).
- NFSv4: Fix locking in pnfs_generic_recover_commit_reqs
  (bnc#1012628).
- NFSv4: Fix a sleep in atomic context in nfs4_callback_sequence()
  (bnc#1012628).
- ARM: tegra: Fix Tegra30 Cardhu PCA954x reset (bnc#1012628).
- ARM: dts: am57xx-idk: Enable dual role for USB2 port
  (bnc#1012628).
- pwm: omap-dmtimer: Return -EPROBE_DEFER if no dmtimer platform
  data (bnc#1012628).
- mm/tlb: Remove tlb_remove_table() non-concurrent condition
  (bnc#1012628).
- iommu/ipmmu-vmsa: Don't register as BUS IOMMU if machine
  doesn't have IPMMU-VMSA (bnc#1012628).
- iommu/vt-d: Add definitions for PFSID (bnc#1012628).
- iommu/vt-d: Fix dev iotlb pfsid use (bnc#1012628).
- sys: don't hold uts_sem while accessing userspace memory
  (bnc#1012628).
- userns: move user access out of the mutex (bnc#1012628).
- ubifs: Fix memory leak in lprobs self-check (bnc#1012628).
- Revert "UBIFS: Fix potential integer overflow in allocation"
  (bnc#1012628).
- ubifs: Check data node size before truncate (bnc#1012628).
- ubifs: xattr: Don't operate on deleted inodes (bnc#1012628).
- ubifs: Fix directory size calculation for symlinks
  (bnc#1012628).
- ubifs: Fix synced_i_size calculation for xattr inodes
  (bnc#1012628).
- pwm: tiehrpwm: Don't use emulation mode bits to control PWM
  output (bnc#1012628).
- pwm: tiehrpwm: Fix disabling of output of PWMs (bnc#1012628).
- fb: fix lost console when the user unplugs a USB adapter
  (bnc#1012628).
- udlfb: fix semaphore value leak (bnc#1012628).
- udlfb: fix display corruption of the last line (bnc#1012628).
- udlfb: don't switch if we are switching to the same videomode
  (bnc#1012628).
- udlfb: set optimal write delay (bnc#1012628).
- udlfb: make a local copy of fb_ops (bnc#1012628).
- udlfb: handle allocation failure (bnc#1012628).
- udlfb: set line_length in dlfb_ops_set_par (bnc#1012628).
- getxattr: use correct xattr length (bnc#1012628).
- libnvdimm: Use max contiguous area for namespace size
  (bnc#1012628).
- libnvdimm: fix ars_status output length calculation
  (bnc#1012628).
- bcache: release dc->writeback_lock properly in
  bch_writeback_thread() (bnc#1012628).
- kconfig: fix "Can't open ..." in parallel build (bnc#1012628).
- cap_inode_getsecurity: use d_find_any_alias() instead of
  d_find_alias() (bnc#1012628).
- mm, dev_pagemap: Do not clear ->mapping on final put
  (bnc#1012628).
- perf auxtrace: Fix queue resize (bnc#1012628).
- crypto: vmx - Fix sleep-in-atomic bugs (bnc#1012628).
- crypto: aesni - Use unaligned loads from gcm_context_data
  (bnc#1012628).
- crypto: arm64/sm4-ce - check for the right CPU feature bit
  (bnc#1012628).
- crypto: caam - fix DMA mapping direction for RSA forms 2 & 3
  (bnc#1012628).
- crypto: caam/jr - fix descriptor DMA unmapping (bnc#1012628).
- crypto: caam/qi - fix error path in xts setkey (bnc#1012628).
- fs/quota: Fix spectre gadget in do_quotactl (bnc#1012628).
- udf: Fix mounting of Win7 created UDF filesystems (bnc#1012628).
- cpuidle: menu: Retain tick when shallow state is selected
  (bnc#1012628).
- arm64: mm: always enable CONFIG_HOLES_IN_ZONE (bnc#1012628).
- commit 952d850
* Fri Sep  7 2018 jeffm@suse.com
- config: disable HFS_FS
  It has no maintainer and has been a source of fuzzer bugs.  hfsplus handles
  the HFS+ file system that became the default on MacOS in 1998.
- commit 07fd1d6
* Fri Sep  7 2018 tiwai@suse.de
- supported.conf: Add bpfilter to kernel-default-base (bsc#1106751)
- commit 8f1f1b6
* Wed Sep  5 2018 jslaby@suse.cz
- Linux 4.18.6 (bnc#1012628).
- PATCH scripts/kernel-doc (bnc#1012628).
- scripts/kernel-doc: Escape all literal braces in regexes
  (bnc#1012628).
- scsi: libsas: dynamically allocate and free ata host
  (bnc#1012628).
- xprtrdma: Fix disconnect regression (bnc#1012628).
- mei: don't update offset in write (bnc#1012628).
- cifs: add missing support for ACLs in SMB 3.11 (bnc#1012628).
- CIFS: fix uninitialized ptr deref in smb2 signing (bnc#1012628).
- cifs: add missing debug entries for kconfig options
  (bnc#1012628).
- cifs: use a refcount to protect open/closing the cached file
  handle (bnc#1012628).
- cifs: check kmalloc before use (bnc#1012628).
- smb3: enumerating snapshots was leaving part of the data off
  end (bnc#1012628).
- smb3: Do not send SMB3 SET_INFO if nothing changed
  (bnc#1012628).
- smb3: don't request leases in symlink creation and query
  (bnc#1012628).
- smb3: fill in statfs fsid and correct namelen (bnc#1012628).
- btrfs: use correct compare function of dirty_metadata_bytes
  (bnc#1012628).
- btrfs: don't leak ret from do_chunk_alloc (bnc#1012628).
- Btrfs: fix mount failure after fsync due to hard link recreation
  (bnc#1012628).
- Btrfs: fix btrfs_write_inode vs delayed iput deadlock
  (bnc#1012628).
- Btrfs: fix send failure when root has deleted files still open
  (bnc#1012628).
- Btrfs: send, fix incorrect file layout after hole punching
  beyond eof (bnc#1012628).
- hwmon: (k10temp) 27C Offset needed for Threadripper2
  (bnc#1012628).
- bpf, arm32: fix stack var offset in jit (bnc#1012628).
- regulator: arizona-ldo1: Use correct device to get enable GPIO
  (bnc#1012628).
- iommu/arm-smmu: Error out only if not enough context interrupts
  (bnc#1012628).
- printk: Split the code for storing a message into the log buffer
  (bnc#1012628).
- printk: Create helper function to queue deferred console
  handling (bnc#1012628).
- printk/nmi: Prevent deadlock when accessing the main log buffer
  in NMI (bnc#1012628).
- kprobes/arm64: Fix %%p uses in error messages (bnc#1012628).
- arm64: Fix mismatched cache line size detection (bnc#1012628).
- arm64: Handle mismatched cache type (bnc#1012628).
- arm64: mm: check for upper PAGE_SHIFT bits in pfn_valid()
  (bnc#1012628).
- arm64: dts: rockchip: corrected uart1 clock-names for rk3328
  (bnc#1012628).
- KVM: arm/arm64: Fix potential loss of ptimer interrupts
  (bnc#1012628).
- KVM: arm/arm64: Fix lost IRQs from emulated physcial timer
  when blocked (bnc#1012628).
- KVM: arm/arm64: Skip updating PMD entry if no change
  (bnc#1012628).
- KVM: arm/arm64: Skip updating PTE entry if no change
  (bnc#1012628).
- s390/kvm: fix deadlock when killed by oom (bnc#1012628).
- perf kvm: Fix subcommands on s390 (bnc#1012628).
- stop_machine: Reflow cpu_stop_queue_two_works() (bnc#1012628).
- stop_machine: Atomically queue and wake stopper threads
  (bnc#1012628).
- ext4: check for NUL characters in extended attribute's name
  (bnc#1012628).
- ext4: use ext4_warning() for sb_getblk failure (bnc#1012628).
- ext4: sysfs: print ext4_super_block fields as little-endian
  (bnc#1012628).
- ext4: reset error code in ext4_find_entry in fallback
  (bnc#1012628).
- ext4: fix race when setting the bitmap corrupted flag
  (bnc#1012628).
- nvme-pci: add a memory barrier to
  nvme_dbbuf_update_and_check_event (bnc#1012628).
- x86/gpu: reserve ICL's graphics stolen memory (bnc#1012628).
- platform/x86: wmi: Do not mix pages and kmalloc (bnc#1012628).
- mm: move tlb_table_flush to tlb_flush_mmu_free (bnc#1012628).
- mm/tlb, x86/mm: Support invalidating TLB caches for
  RCU_TABLE_FREE (bnc#1012628).
- x86/vdso: Fix vDSO build if a retpoline is emitted
  (bnc#1012628).
- x86/process: Re-export start_thread() (bnc#1012628).
- KVM: x86: ensure all MSRs can always be KVM_GET/SET_MSR'd
  (bnc#1012628).
- KVM: x86: SVM: Call x86_spec_ctrl_set_guest/host() with
  interrupts disabled (bnc#1012628).
- fuse: Don't access pipe->buffers without pipe_lock()
  (bnc#1012628).
- fuse: fix initial parallel dirops (bnc#1012628).
- fuse: fix double request_end() (bnc#1012628).
- fuse: fix unlocked access to processing queue (bnc#1012628).
- fuse: umount should wait for all requests (bnc#1012628).
- fuse: Fix oops at process_init_reply() (bnc#1012628).
- fuse: Add missed unlock_page() to fuse_readpages_fill()
  (bnc#1012628).
- lib/vsprintf: Do not handle %%pO[^F] as %%px (bnc#1012628).
- udl-kms: change down_interruptible to down (bnc#1012628).
- udl-kms: handle allocation failure (bnc#1012628).
- udl-kms: fix crash due to uninitialized memory (bnc#1012628).
- udl-kms: avoid division (bnc#1012628).
- b43legacy/leds: Ensure NUL-termination of LED name string
  (bnc#1012628).
- b43/leds: Ensure NUL-termination of LED name string
  (bnc#1012628).
- ASoC: dpcm: don't merge format from invalid codec dai
  (bnc#1012628).
- ASoC: zte: Fix incorrect PCM format bit usages (bnc#1012628).
- ASoC: sirf: Fix potential NULL pointer dereference
  (bnc#1012628).
- ASoC: wm_adsp: Correct DSP pointer for preloader control
  (bnc#1012628).
- soc: qcom: rmtfs-mem: fix memleak in probe error paths
  (bnc#1012628).
- pinctrl: freescale: off by one in imx1_pinconf_group_dbg_show()
  (bnc#1012628).
- scsi: qla2xxx: Fix stalled relogin (bnc#1012628).
- x86/vdso: Fix lsl operand order (bnc#1012628).
- x86/nmi: Fix NMI uaccess race against CR3 switching
  (bnc#1012628).
- x86/irqflags: Mark native_restore_fl extern inline
  (bnc#1012628).
- x86/spectre: Add missing family 6 check to microcode check
  (bnc#1012628).
- x86/speculation/l1tf: Increase l1tf memory limit for Nehalem+
  (bnc#1012628).
- hwmon: (nct6775) Fix potential Spectre v1 (bnc#1012628).
- x86/entry/64: Wipe KASAN stack shadow before
  rewind_stack_do_exit() (bnc#1012628).
- x86: Allow generating user-space headers without a compiler
  (bnc#1012628).
- s390/mm: fix addressing exception after suspend/resume
  (bnc#1012628).
- s390/lib: use expoline for all bcr instructions (bnc#1012628).
- s390: fix br_r1_trampoline for machines without exrl
  (bnc#1012628).
- s390/qdio: reset old sbal_state flags (bnc#1012628).
- s390/numa: move initial setup of node_to_cpumask_map
  (bnc#1012628).
- s390/pci: fix out of bounds access during irq setup
  (bnc#1012628).
- s390/purgatory: Fix crash with expoline enabled (bnc#1012628).
- s390/purgatory: Add missing FORCE to Makefile targets
  (bnc#1012628).
- kprobes: Show blacklist addresses as same as kallsyms does
  (bnc#1012628).
- kprobes: Replace %%p with other pointer types (bnc#1012628).
- kprobes/arm: Fix %%p uses in error messages (bnc#1012628).
- kprobes: Make list and blacklist root user read only
  (bnc#1012628).
- MIPS: Correct the 64-bit DSP accumulator register size
  (bnc#1012628).
- MIPS: memset.S: Fix byte_fixup for MIPSr6 (bnc#1012628).
- MIPS: Always use -march=<arch>, not -<arch> shortcuts
  (bnc#1012628).
- MIPS: Change definition of cpu_relax() for Loongson-3
  (bnc#1012628).
- MIPS: lib: Provide MIPS64r6 __multi3() for GCC < 7
  (bnc#1012628).
- tpm: Return the actual size when receiving an unsupported
  command (bnc#1012628).
- tpm: separate cmd_ready/go_idle from runtime_pm (bnc#1012628).
- scsi: mpt3sas: Fix calltrace observed while running IO & reset
  (bnc#1012628).
- scsi: mpt3sas: Fix _transport_smp_handler() error path
  (bnc#1012628).
- scsi: sysfs: Introduce sysfs_{un,}break_active_protection()
  (bnc#1012628).
- scsi: core: Avoid that SCSI device removal through sysfs
  triggers a deadlock (bnc#1012628).
- iscsi target: fix session creation failure handling
  (bnc#1012628).
- mtd: rawnand: hynix: Use ->exec_op() in
  hynix_nand_reg_write_op() (bnc#1012628).
- mtd: rawnand: fsmc: Stop using chip->read_buf() (bnc#1012628).
- mtd: rawnand: marvell: add suspend and resume hooks
  (bnc#1012628).
- mtd: rawnand: qcom: wait for desc completion in all BAM channels
  (bnc#1012628).
- clk: rockchip: fix clk_i2sout parent selection bits on rk3399
  (bnc#1012628).
- clk: npcm7xx: fix memory allocation (bnc#1012628).
- PM / clk: signedness bug in of_pm_clk_add_clks() (bnc#1012628).
- power: generic-adc-battery: fix out-of-bounds write when
  copying channel properties (bnc#1012628).
- power: generic-adc-battery: check for duplicate properties
  copied from iio channels (bnc#1012628).
- watchdog: Mark watchdog touch functions as notrace
  (bnc#1012628).
- cdrom: Fix info leak/OOB read in cdrom_ioctl_drive_status
  (bnc#1012628).
- x86/dumpstack: Don't dump kernel memory based on usermode RIP
  (bnc#1012628).
- Refresh
  patches.suse/0006-x86-stacktrace-Enable-HAVE_RELIABLE_STACKTRACE-for-t.patch.
- Update config files.
- commit 70ab8ae
* Mon Sep  3 2018 jslaby@suse.cz
- rpm/kernel-binary.spec.in: fix call of split-modules
  split-modules is called with some parameters depending on config
  options. But since we do not use backslash consistelny, the call to
  split-modules might be evaluated so that also the following cat
  command is appended. Avoid this behaviour by using backslashes
  everywhere and add %%nil to the end.
  This perhaps never happens, but stay on the safe side.
- commit 32df888
* Mon Sep  3 2018 mkubecek@suse.cz
- Update to 4.19-rc2
- refresh configs
- commit a9462db
* Sun Sep  2 2018 agraf@suse.de
- arm64: KVM: Only force FPEXC32_EL2.EN if trapping FPSIMD
  (bsc#1106841).
- commit dd0155c
* Sat Sep  1 2018 afaerber@suse.de
- config: arm64: Increase SERIAL_8250_RUNTIME_UARTS to 32 (boo#1073193)
  (cherry picked from commit 0dbc49ba128ef0931ca04cf22ec5c638534f5b23)
- config: arm64: Increase SERIAL_8250_RUNTIME_UARTS to 32 (boo#1073193)
- commit 6aae50e
* Sat Sep  1 2018 afaerber@suse.de
- config: Enable SERIAL_SC16IS7XX_SPI on arm and x86 (bsc#1105672, fate#326668)
  (cherry picked from commit cdc9eced6d892ff77abbeef5f0d5eb38c114602c)
- config: Enable SERIAL_SC16IS7XX_SPI on arm and x86 (bsc#1105672, fate#326668)
- commit 22a4d36
* Sat Sep  1 2018 afaerber@suse.de
- config: Consistently increase SERIAL_8250_NR_UARTS to 32 (boo#1073193)
  (cherry picked from commit acb36abf212a3a7428d958798d678d82351f4658)
- config: Consistently increase SERIAL_8250_NR_UARTS to 32 (boo#1073193)
- commit 090b553
* Sat Sep  1 2018 afaerber@suse.de
- config: armv7hl: Update to 4.19-rc1
- commit d1f42dc
* Sat Sep  1 2018 afaerber@suse.de
- config: armv7hl: Update to 4.18.5 (bsc#1012628)
  (cherry picked from commit fa0ebc5508eedec2c9108cafdf854a8c53a28a83)
  [AF: Don't re-enable the configs yet]
- config: armv7hl: Update to 4.18.5 (bsc#1012628)
- commit f2722e4
* Sat Sep  1 2018 afaerber@suse.de
- config: armv6hl: Update to 4.19-rc1
- commit 2f56919
* Fri Aug 31 2018 afaerber@suse.de
- config: armv6hl: Update to 4.18.5 (bsc#1012628)
  (cherry picked from commit e9071067714392290f6b0d525c77c8abfa8cf075)
  [AF: Don't re-enable configs yet]
- config: armv6hl: Update to 4.18.5 (bsc#1012628)
- commit d01db43
* Fri Aug 31 2018 afaerber@suse.de
- config: arm64: Update to 4.19-rc1
- commit a6a88d1
* Wed Aug 29 2018 mkubecek@suse.cz
- powerpc/boot: Fix missing crc32poly.h when building with
  KERNEL_XZ.
- Delete
  patches.rpmify/Revert-lib-Use-existing-define-with-polynomial.patch.
- commit cba84f7
* Wed Aug 29 2018 mkubecek@suse.cz
- kernel-binary: check also bzImage on s390/s390x
  Starting with 4.19-rc1, uncompressed image is no longer built on s390x.
  If file "image" is not found in arch/s390/boot after the build, try bzImage
  instead.
  For now, install bzImage under the name image-* until we know grub2 and our
  grub2 scripts can handle correct name.
- commit 92b52c6
* Tue Aug 28 2018 jbeulich@suse.com
- Refresh patches.suse/supported-flag after upstream commit b2c5cdcfd4.
- Refresh
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch.
- commit 8b0e2e5
* Mon Aug 27 2018 mkubecek@suse.cz
- Revert "lib: Use existing define with polynomial".
- commit 1dc6366
* Mon Aug 27 2018 mkubecek@suse.cz
- Update to 4.19-rc1
- Eliminated 179 patches (167 stable, 12 other)
- ARM configs need updating
- Config changes:
  - Block:
  - BLK_CGROUP_IOLATENCY=y
  - Networking:
  - XFRM_INTERFACE=m
  - NETFILTER_NETLINK_OSF=m
  - NFT_TUNNEL=m
  - NFT_OSF=m
  - NFT_TPROXY=m
  - NET_SCH_ETF=m
  - NET_SCH_SKBPRIO=m
  - NET_SCH_CAKE=m
  - CAN_UCAN=m
  - BT_HCIUART_RTL=y
  - BT_MTKUART=m
  - BCMGENET=m
  - SYSTEMPORT=m
  - BNXT_HWMON=y
  - NET_VENDOR_CADENCE=y	(rename)
  - BE2NET_BE2=y
  - BE2NET_BE3=y
  - BE2NET_LANCER=y
  - BE2NET_SKYHAWK=y
  - MLX5_EN_ARFS=y
  - MLX5_EN_RXNFC=y
  - NET_VENDOR_NETERION=y
  - NET_VENDOR_PACKET_ENGINES=y
  - MT76x0U=m
  - MT76x2U=m
  - IEEE802154_HWSIM=m
  - File systems:
  - OVERLAY_FS_METACOPY=n
  - UBIFS_FS_XATTR=y
  - PSTORE_ZSTD_COMPRESS=y
  - CIFS_ALLOW_INSECURE_LEGACY=y
  - Security:
  - RANDOM_TRUST_CPU=n
  - IMA_APPRAISE_BUILD_POLICY=n
  - Hacking:
  - CONSOLE_LOGLEVEL_QUIET=4
  - KPROBE_EVENTS_ON_NOTRACE=n
  - TEST_BITFIELD=n
  - TEST_IDA=n
  - Library:
  - CRC64=m
  - Graphics:
  - VIDEO_CROS_EC_CEC=m
  - DRM_DP_CEC=y
  - DRM_VKMS=m
  - TINYDRM_ILI9341=n
  - FRAMEBUFFER_CONSOLE_DEFERRED_TAKEOVER=y
  - Sound:
  - SND_SOC_INTEL_GLK_RT5682_MAX98357A_MACH=m
  - SND_SOC_ES7241=n
  - SND_SOC_SIMPLE_AMPLIFIER=n
  - Input:
  - TOUCHSCREEN_ADC=m
  - TOUCHSCREEN_BU21029=m
  - HID_COUGAR=m
  - USB:
  - TYPEC_DP_ALTMODE=m
  - Multifunction:
  - MFD_MADERA=m
  - MFD_MADERA_I2C=m
  - MFD_MADERA_SPI=m
  - GPIO_MADERA=m
  - MFD_CS47L35=y
  - MFD_CS47L85=y
  - MFD_CS47L90=y
  - IIO:
  - BME680=m
  - AD5758=n
  - SI1133=n
  - ISL29501=m
  - FPGA:
  - FPGA_DFL=m
  - FPGA_DFL_FME=m
  - FPGA_DFL_FME_MGR=m
  - FPGA_DFL_FME_BRIDGE=m
  - FPGA_DFL_FME_REGION=m
  - FPGA_DFL_AFU=m
  - FPGA_DFL_PCI=m
  - XILINX_PR_DECOUPLER=m
  - Power management:
  - IDLE_INJECT=y
  - CHARGER_ADP5061=m
  - CHARGER_CROS_USBPD=m
  - SENSORS_MLXREG_FAN=m
  - SENSORS_NPCM7XX=m
  - Misc drivers:
  - GNSS=m
  - GNSS_SERIAL=m
  - GNSS_SIRF_SERIAL=m
  - GNSS_UBX_SERIAL=m
  - MTD_SPI_NAND=m
  - NVM_PBLK_DEBUG=n
  - PINCTRL_ICELAKE=m
  - COMMON_CLK_MAX9485=n
  - IOMMU_DEFAULT_PASSTHROUGH=n
  - XEN:
  - XEN_GRANT_DMA_ALLOC=y
  - XEN_GNTDEV_DMABUF=y
  - x86:
  - STAGING_GASKET_FRAMEWORK=m
  - STAGING_APEX_DRIVER=m
  - XIL_AXIS_FIFO=m
  - TOUCHSCREEN_DMI=y
  - I2C_MULTI_INSTANTIATE=m
  - CROS_EC_I2C=m
  - CROS_EC_SPI=m
  - MLXREG_IO=m
  - i386:
  - PCIE_XILINX=y
  - MFD_ROHM_BD718XX=n
  - DRM_PANEL_ILITEK_ILI9881C=n
  - MMC_SDHCI_OF_DWCMSHC=n
  - PAGE_TABLE_ISOLATION=y
  - PowerPC:
  - I2C_MUX_PINCTRL=m
  - I2C_DEMUX_PINCTRL=m
  - I2C_FSI=m
  - DEBUG_PINCTRL=n
  - PINCTRL_AMD=m
  - PINCTRL_MCP23S08=n
  - PINCTRL_SINGLE=n
  - PINCTRL_SX150X=n
  - LEDS_AAT1290=n
  - FSI_NEW_DEV_NODE=n
  - FSI_SBEFIFO=m
  - S/390:
  - KERNEL_GZIP=y
  - S2IO=m
  - VXGE=m
  - VXGE_DEBUG_TRACE_ALL=n
  - HAMACHI=m
  - YELLOWFIN=m
  - MDIO_BCM_UNIMAC=m
  - ISM=m
  - */debug:
  - NVM_PBLK_DEBUG=y
  - IOMMU_DEBUGFS=y
  - PREEMPTIRQ_DELAY_TEST=m
- commit a3b9cac
* Fri Aug 24 2018 jslaby@suse.cz
- Linux 4.18.5 (bnc#1012628).
- reiserfs: fix broken xattr handling (heap corruption, bad
  retval) (bnc#1012628).
- i2c: imx: Fix race condition in dma read (bnc#1012628).
- i2c: core: ACPI: Properly set status byte to 0 for multi-byte
  writes (bnc#1012628).
- PCI: pciehp: Fix unprotected list iteration in IRQ handler
  (bnc#1012628).
- PCI: pciehp: Fix use-after-free on unplug (bnc#1012628).
- PCI: Skip MPS logic for Virtual Functions (VFs) (bnc#1012628).
- PCI: aardvark: Size bridges before resources allocation
  (bnc#1012628).
- PCI: hotplug: Don't leak pci_slot on registration failure
  (bnc#1012628).
- PCI / ACPI / PM: Resume all bridges on suspend-to-RAM
  (bnc#1012628).
- PCI: Restore resized BAR state on resume (bnc#1012628).
- parisc: Remove ordered stores from syscall.S (bnc#1012628).
- parisc: Remove unnecessary barriers from spinlock.h
  (bnc#1012628).
- drm/amdgpu/pm: Fix potential Spectre v1 (bnc#1012628).
- drm/i915/kvmgt: Fix potential Spectre v1 (bnc#1012628).
- ext4: fix spectre gadget in ext4_mb_regular_allocator()
  (bnc#1012628).
- powerpc64s: Show ori31 availability in spectre_v1 sysfs file
  not v2 (bnc#1012628).
- x86/mm/init: Remove freed kernel image areas from alias mapping
  (bnc#1012628).
- x86/mm/init: Add helper for freeing kernel image pages
  (bnc#1012628).
- x86/mm/init: Pass unconverted symbol addresses to
  free_init_pages() (bnc#1012628).
- mm: Allow non-direct-map arguments to free_reserved_area()
  (bnc#1012628).
- pty: fix O_CLOEXEC for TIOCGPTPEER (bnc#1012628).
- EDAC: Add missing MEM_LRDDR4 entry in edac_mem_types[]
  (bnc#1012628).
- commit d918293
* Fri Aug 24 2018 vbabka@suse.cz
- x86/speculation/l1tf: Suggest what to do on systems with too
  much RAM (bsc#1105536).
- x86/speculation/l1tf: Fix off-by-one error when warning that
  system has too much RAM (bsc#1105536).
- x86/speculation/l1tf: Fix overflow in l1tf_pfn_limit() on 32bit
  (OBS failures reported on IRC).
- commit f3b24ad
* Fri Aug 24 2018 jslaby@suse.cz
- Update config files.
- Delete
  patches.suse/revert-mm-relax-deferred-struct-page-requirements.patch.
  We actually do not this non-upstream revert. We only need the config
  change. That is: leave DEFERRED_STRUCT_PAGE_INIT=n for i386 as it was
  before 4.16.
- commit 161b8ee
* Wed Aug 22 2018 jslaby@suse.cz
- Linux 4.18.4 (bnc#1012628).
- l2tp: use sk_dst_check() to avoid race on sk->sk_dst_cache
  (bnc#1012628).
- net_sched: fix NULL pointer dereference when delete tcindex
  filter (bnc#1012628).
- net_sched: Fix missing res info when create new tc_index filter
  (bnc#1012628).
- r8169: don't use MSI-X on RTL8168g (bnc#1012628).
- ALSA: hda - Sleep for 10ms after entering D3 on Conexant codecs
  (bnc#1012628).
- ALSA: hda - Turn CX8200 into D3 as well upon reboot
  (bnc#1012628).
- ALSA: vx222: Fix invalid endian conversions (bnc#1012628).
- ALSA: virmidi: Fix too long output trigger loop (bnc#1012628).
- ALSA: cs5535audio: Fix invalid endian conversion (bnc#1012628).
- ALSA: dice: fix wrong copy to rx parameters for Alesis iO26
  (bnc#1012628).
- ALSA: hda: Correct Asrock B85M-ITX power_save blacklist entry
  (bnc#1012628).
- ALSA: memalloc: Don't exceed over the requested size
  (bnc#1012628).
- ALSA: vxpocket: Fix invalid endian conversions (bnc#1012628).
- ALSA: seq: Fix poll() error return (bnc#1012628).
- media: gl861: fix probe of dvb_usb_gl861 (bnc#1012628).
- USB: serial: sierra: fix potential deadlock at close
  (bnc#1012628).
- USB: serial: pl2303: add a new device id for ATEN (bnc#1012628).
- USB: option: add support for DW5821e (bnc#1012628).
- ACPI / PM: save NVS memory for ASUS 1025C laptop (bnc#1012628).
- tty: serial: 8250: Revert NXP SC16C2552 workaround
  (bnc#1012628).
- serial: 8250_exar: Read INT0 from slave device, too
  (bnc#1012628).
- serial: 8250_dw: always set baud rate in dw8250_set_termios
  (bnc#1012628).
- serial: 8250_dw: Add ACPI support for uart on Broadcom SoC
  (bnc#1012628).
- uio: fix wrong return value from uio_mmap() (bnc#1012628).
- misc: sram: fix resource leaks in probe error path
  (bnc#1012628).
- Revert "uio: use request_threaded_irq instead" (bnc#1012628).
- Bluetooth: avoid killing an already killed socket (bnc#1012628).
- isdn: Disable IIOCDBGVAR (bnc#1012628).
- net: sock_diag: Fix spectre v1 gadget in __sock_diag_cmd()
  (bnc#1012628).
- r8169: don't use MSI-X on RTL8106e (bnc#1012628).
- ip_vti: fix a null pointer deferrence when create vti fallback
  tunnel (bnc#1012628).
- net: ethernet: mvneta: Fix napi structure mixup on armada 3700
  (bnc#1012628).
- net: mvneta: fix mvneta_config_rss on armada 3700 (bnc#1012628).
- cls_matchall: fix tcf_unbind_filter missing (bnc#1012628).
- commit a7b92e4
* Wed Aug 22 2018 jslaby@suse.cz
- Linux 4.18.3 (bnc#1012628).
- x86/speculation/l1tf: Exempt zeroed PTEs from inversion
  (bnc#1012628).
- commit a14f6a3
* Wed Aug 22 2018 jslaby@suse.cz
- Linux 4.18.2 (bnc#1012628).
- x86/mm: Add TLB purge to free pmd/pte page interfaces
  (bnc#1012628).
- ioremap: Update pgtable free interfaces with addr (bnc#1012628).
- Bluetooth: hidp: buffer overflow in hidp_process_report
  (bnc#1012628).
- crypto: skcipher - fix crash flushing dcache in error path
  (bnc#1012628).
- crypto: skcipher - fix aligning block size in skcipher_copy_iv()
  (bnc#1012628).
- crypto: ablkcipher - fix crash flushing dcache in error path
  (bnc#1012628).
- crypto: blkcipher - fix crash flushing dcache in error path
  (bnc#1012628).
- crypto: vmac - separate tfm and request context (bnc#1012628).
- crypto: vmac - require a block cipher with 128-bit block size
  (bnc#1012628).
- crypto: x86/sha256-mb - fix digest copy in
  sha256_mb_mgr_get_comp_job_avx2() (bnc#1012628).
- crypto: ccp - Fix command completion detection race
  (bnc#1012628).
- crypto: ccp - Check for NULL PSP pointer at module unload
  (bnc#1012628).
- crypto: ccree - fix iv handling (bnc#1012628).
- crypto: ccree - fix finup (bnc#1012628).
- kbuild: verify that $DEPMOD is installed (bnc#1012628).
- x86/mm: Disable ioremap free page handling on x86-PAE
  (bnc#1012628).
- xen/pv: Call get_cpu_address_sizes to set x86_virt/phys_bits
  (bnc#1012628).
- x86/mm/pti: Clear Global bit more aggressively (bnc#1012628).
- x86/platform/UV: Mark memblock related init code and data
  correctly (bnc#1012628).
- x86/hyper-v: Check for VP_INVAL in hyperv_flush_tlb_others()
  (bnc#1012628).
- x86: i8259: Add missing include file (bnc#1012628).
- x86/l1tf: Fix build error seen if CONFIG_KVM_INTEL is disabled
  (bnc#1012628).
- commit 51ef786
* Wed Aug 22 2018 jslaby@suse.cz
- Linux 4.18.1 (bnc#1012628).
- x86/init: fix build with CONFIG_SWAP=n (bnc#1012628).
- cpu/hotplug: Non-SMP machines do not make use of booted_once
  (bnc#1012628).
- x86/smp: fix non-SMP broken build due to redefinition of
  apic_id_is_primary_thread (bnc#1012628).
- commit 7e40689
* Wed Aug 22 2018 jslaby@suse.cz
- Linux 4.18.4 (bnc#1012628).
- l2tp: use sk_dst_check() to avoid race on sk->sk_dst_cache
  (bnc#1012628).
- net_sched: fix NULL pointer dereference when delete tcindex
  filter (bnc#1012628).
- net_sched: Fix missing res info when create new tc_index filter
  (bnc#1012628).
- r8169: don't use MSI-X on RTL8168g (bnc#1012628).
- ALSA: hda - Sleep for 10ms after entering D3 on Conexant codecs
  (bnc#1012628).
- ALSA: hda - Turn CX8200 into D3 as well upon reboot
  (bnc#1012628).
- ALSA: vx222: Fix invalid endian conversions (bnc#1012628).
- ALSA: virmidi: Fix too long output trigger loop (bnc#1012628).
- ALSA: cs5535audio: Fix invalid endian conversion (bnc#1012628).
- ALSA: dice: fix wrong copy to rx parameters for Alesis iO26
  (bnc#1012628).
- ALSA: hda: Correct Asrock B85M-ITX power_save blacklist entry
  (bnc#1012628).
- ALSA: memalloc: Don't exceed over the requested size
  (bnc#1012628).
- ALSA: vxpocket: Fix invalid endian conversions (bnc#1012628).
- ALSA: seq: Fix poll() error return (bnc#1012628).
- media: gl861: fix probe of dvb_usb_gl861 (bnc#1012628).
- USB: serial: sierra: fix potential deadlock at close
  (bnc#1012628).
- USB: serial: pl2303: add a new device id for ATEN (bnc#1012628).
- USB: option: add support for DW5821e (bnc#1012628).
- ACPI / PM: save NVS memory for ASUS 1025C laptop (bnc#1012628).
- tty: serial: 8250: Revert NXP SC16C2552 workaround
  (bnc#1012628).
- serial: 8250_exar: Read INT0 from slave device, too
  (bnc#1012628).
- serial: 8250_dw: always set baud rate in dw8250_set_termios
  (bnc#1012628).
- serial: 8250_dw: Add ACPI support for uart on Broadcom SoC
  (bnc#1012628).
- uio: fix wrong return value from uio_mmap() (bnc#1012628).
- misc: sram: fix resource leaks in probe error path
  (bnc#1012628).
- Revert "uio: use request_threaded_irq instead" (bnc#1012628).
- Bluetooth: avoid killing an already killed socket (bnc#1012628).
- isdn: Disable IIOCDBGVAR (bnc#1012628).
- net: sock_diag: Fix spectre v1 gadget in __sock_diag_cmd()
  (bnc#1012628).
- r8169: don't use MSI-X on RTL8106e (bnc#1012628).
- ip_vti: fix a null pointer deferrence when create vti fallback
  tunnel (bnc#1012628).
- net: ethernet: mvneta: Fix napi structure mixup on armada 3700
  (bnc#1012628).
- net: mvneta: fix mvneta_config_rss on armada 3700 (bnc#1012628).
- cls_matchall: fix tcf_unbind_filter missing (bnc#1012628).
- commit 06f7c50
* Tue Aug 21 2018 msuchanek@suse.de
- ACPICA: Clear status of all events when entering sleep states
  (boo#1104529).
- commit 5d7a9a7
* Tue Aug 21 2018 msuchanek@suse.de
- Delete patches.suse/Revert-ACPICA-Events-Stop-unconditionally-clearing-A.patch.
- commit fb1dc2b
* Mon Aug 20 2018 jslaby@suse.cz
- Linux 4.18.3 (bnc#1012628).
- x86/speculation/l1tf: Exempt zeroed PTEs from inversion
  (bnc#1012628).
- commit 3914d9b
* Mon Aug 20 2018 jslaby@suse.cz
- Linux 4.18.2 (bnc#1012628).
- x86/mm: Add TLB purge to free pmd/pte page interfaces
  (bnc#1012628).
- ioremap: Update pgtable free interfaces with addr (bnc#1012628).
- Bluetooth: hidp: buffer overflow in hidp_process_report
  (bnc#1012628).
- crypto: skcipher - fix crash flushing dcache in error path
  (bnc#1012628).
- crypto: skcipher - fix aligning block size in skcipher_copy_iv()
  (bnc#1012628).
- crypto: ablkcipher - fix crash flushing dcache in error path
  (bnc#1012628).
- crypto: blkcipher - fix crash flushing dcache in error path
  (bnc#1012628).
- crypto: vmac - separate tfm and request context (bnc#1012628).
- crypto: vmac - require a block cipher with 128-bit block size
  (bnc#1012628).
- crypto: x86/sha256-mb - fix digest copy in
  sha256_mb_mgr_get_comp_job_avx2() (bnc#1012628).
- crypto: ccp - Fix command completion detection race
  (bnc#1012628).
- crypto: ccp - Check for NULL PSP pointer at module unload
  (bnc#1012628).
- crypto: ccree - fix iv handling (bnc#1012628).
- crypto: ccree - fix finup (bnc#1012628).
- kbuild: verify that $DEPMOD is installed (bnc#1012628).
- x86/mm: Disable ioremap free page handling on x86-PAE
  (bnc#1012628).
- xen/pv: Call get_cpu_address_sizes to set x86_virt/phys_bits
  (bnc#1012628).
- x86/mm/pti: Clear Global bit more aggressively (bnc#1012628).
- x86/platform/UV: Mark memblock related init code and data
  correctly (bnc#1012628).
- x86/hyper-v: Check for VP_INVAL in hyperv_flush_tlb_others()
  (bnc#1012628).
- x86: i8259: Add missing include file (bnc#1012628).
- x86/l1tf: Fix build error seen if CONFIG_KVM_INTEL is disabled
  (bnc#1012628).
- commit 403355b
* Fri Aug 17 2018 mkubecek@suse.cz
- rpm/constraints.in: raise memory constraints
  Build statistics show that most architectures already need more than 2 GB.
  Require 4 GB except s390x where the memory usage is much lower and we might
  have trouble finding any compliant worker.
- commit 71aefb3
* Thu Aug 16 2018 msuchanek@suse.de
- Revert "ACPICA: Events: Stop unconditionally clearing ACPI
  IRQs during suspend/resume" (boo#1104529, bko#196249).
- commit 5dac824
* Thu Aug 16 2018 jslaby@suse.cz
- Linux 4.18.1 (bnc#1012628).
- x86/init: fix build with CONFIG_SWAP=n (bnc#1012628).
- cpu/hotplug: Non-SMP machines do not make use of booted_once
  (bnc#1012628).
- x86/smp: fix non-SMP broken build due to redefinition of
  apic_id_is_primary_thread (bnc#1012628).
- commit 2f1304f
* Wed Aug 15 2018 mkubecek@suse.cz
- Update config files.
- commit 07db4aa
* Wed Aug 15 2018 jslaby@suse.cz
- Linux 4.18.1-rc1
  It contains the L1TF fixes, so push the rc1 for now.
- x86/paravirt: Fix spectre-v2 mitigations for paravirt guests
  (bnc#1012628).
- x86/speculation: Protect against userspace-userspace spectreRSB
  (bnc#1012628).
- kprobes/x86: Fix %%p uses in error messages (bnc#1012628).
- x86/irqflags: Provide a declaration for native_save_fl
  (bnc#1012628).
- x86/speculation/l1tf: Increase 32bit PAE __PHYSICAL_PAGE_SHIFT
  (bnc#1012628).
- x86/speculation/l1tf: Change order of offset/type in swap entry
  (bnc#1012628).
- x86/speculation/l1tf: Protect swap entries against L1TF
  (bnc#1012628).
- x86/speculation/l1tf: Protect PROT_NONE PTEs against speculation
  (bnc#1012628).
- x86/speculation/l1tf: Make sure the first page is always
  reserved (bnc#1012628).
- x86/speculation/l1tf: Add sysfs reporting for l1tf
  (bnc#1012628).
- x86/speculation/l1tf: Disallow non privileged high MMIO
  PROT_NONE mappings (bnc#1012628).
- x86/speculation/l1tf: Limit swap file size to MAX_PA/2
  (bnc#1012628).
- x86/bugs: Move the l1tf function and define pr_fmt properly
  (bnc#1012628).
- sched/smt: Update sched_smt_present at runtime (bnc#1012628).
- x86/smp: Provide topology_is_primary_thread() (bnc#1012628).
- x86/topology: Provide topology_smt_supported() (bnc#1012628).
- cpu/hotplug: Make bringup/teardown of smp threads symmetric
  (bnc#1012628).
- cpu/hotplug: Split do_cpu_down() (bnc#1012628).
- cpu/hotplug: Provide knobs to control SMT (bnc#1012628).
- x86/cpu: Remove the pointless CPU printout (bnc#1012628).
- x86/cpu/AMD: Remove the pointless detect_ht() call
  (bnc#1012628).
- x86/cpu/common: Provide detect_ht_early() (bnc#1012628).
- x86/cpu/topology: Provide detect_extended_topology_early()
  (bnc#1012628).
- x86/cpu/intel: Evaluate smp_num_siblings early (bnc#1012628).
- x86/CPU/AMD: Do not check CPUID max ext level before parsing
  SMP info (bnc#1012628).
- x86/cpu/AMD: Evaluate smp_num_siblings early (bnc#1012628).
- x86/apic: Ignore secondary threads if nosmt=force (bnc#1012628).
- x86/speculation/l1tf: Extend 64bit swap file size limit
  (bnc#1012628).
- x86/cpufeatures: Add detection of L1D cache flush support
  (bnc#1012628).
- x86/CPU/AMD: Move TOPOEXT reenablement before reading
  smp_num_siblings (bnc#1012628).
- x86/speculation/l1tf: Protect PAE swap entries against L1TF
  (bnc#1012628).
- x86/speculation/l1tf: Fix up pte->pfn conversion for PAE
  (bnc#1012628).
- Revert "x86/apic: Ignore secondary threads if nosmt=force"
  (bnc#1012628).
- cpu/hotplug: Boot HT siblings at least once (bnc#1012628).
- x86/KVM: Warn user if KVM is loaded SMT and L1TF CPU bug being
  present (bnc#1012628).
- x86/KVM/VMX: Add module argument for L1TF mitigation
  (bnc#1012628).
- x86/KVM/VMX: Add L1D flush algorithm (bnc#1012628).
- x86/KVM/VMX: Add L1D MSR based flush (bnc#1012628).
- x86/KVM/VMX: Add L1D flush logic (bnc#1012628).
- x86/KVM/VMX: Split the VMX MSR LOAD structures to have an
  host/guest numbers (bnc#1012628).
- x86/KVM/VMX: Add find_msr() helper function (bnc#1012628).
- x86/KVM/VMX: Separate the VMX AUTOLOAD guest/host number
  accounting (bnc#1012628).
- x86/KVM/VMX: Extend add_atomic_switch_msr() to allow VMENTER
  only MSRs (bnc#1012628).
- x86/KVM/VMX: Use MSR save list for IA32_FLUSH_CMD if required
  (bnc#1012628).
- cpu/hotplug: Online siblings when SMT control is turned on
  (bnc#1012628).
- x86/litf: Introduce vmx status variable (bnc#1012628).
- x86/kvm: Drop L1TF MSR list approach (bnc#1012628).
- x86/l1tf: Handle EPT disabled state proper (bnc#1012628).
- x86/kvm: Move l1tf setup function (bnc#1012628).
- x86/kvm: Add static key for flush always (bnc#1012628).
- x86/kvm: Serialize L1D flush parameter setter (bnc#1012628).
- x86/kvm: Allow runtime control of L1D flush (bnc#1012628).
- cpu/hotplug: Expose SMT control init function (bnc#1012628).
- cpu/hotplug: Set CPU_SMT_NOT_SUPPORTED early (bnc#1012628).
- x86/bugs, kvm: Introduce boot-time control of L1TF mitigations
  (bnc#1012628).
- Documentation: Add section about CPU vulnerabilities
  (bnc#1012628).
- x86/speculation/l1tf: Unbreak !__HAVE_ARCH_PFN_MODIFY_ALLOWED
  architectures (bnc#1012628).
- x86/KVM/VMX: Initialize the vmx_l1d_flush_pages' content
  (bnc#1012628).
- Documentation/l1tf: Fix typos (bnc#1012628).
- cpu/hotplug: detect SMT disabled by BIOS (bnc#1012628).
- x86/KVM/VMX: Don't set l1tf_flush_l1d to true from
  vmx_l1d_flush() (bnc#1012628).
- x86/KVM/VMX: Replace 'vmx_l1d_flush_always' with
  'vmx_l1d_flush_cond' (bnc#1012628).
- x86/KVM/VMX: Move the l1tf_flush_l1d test to vmx_l1d_flush()
  (bnc#1012628).
- x86/irq: Demote irq_cpustat_t::__softirq_pending to u16
  (bnc#1012628).
- x86/KVM/VMX: Introduce per-host-cpu analogue of l1tf_flush_l1d
  (bnc#1012628).
- x86: Don't include linux/irq.h from asm/hardirq.h (bnc#1012628).
- x86/irq: Let interrupt handlers set kvm_cpu_l1tf_flush_l1d
  (bnc#1012628).
- x86/KVM/VMX: Don't set l1tf_flush_l1d from
  vmx_handle_external_intr() (bnc#1012628).
- Documentation/l1tf: Remove Yonah processors from not vulnerable
  list (bnc#1012628).
- x86/speculation: Simplify sysfs report of VMX L1TF vulnerability
  (bnc#1012628).
- x86/speculation: Use ARCH_CAPABILITIES to skip L1D flush on
  vmentry (bnc#1012628).
- KVM: VMX: Tell the nested hypervisor to skip L1D flush on
  vmentry (bnc#1012628).
- cpu/hotplug: Fix SMT supported evaluation (bnc#1012628).
- x86/speculation/l1tf: Invert all not present mappings
  (bnc#1012628).
- x86/speculation/l1tf: Make pmd/pud_mknotpresent() invert
  (bnc#1012628).
- x86/mm/pat: Make set_memory_np() L1TF safe (bnc#1012628).
- x86/mm/kmmio: Make the tracer robust against L1TF (bnc#1012628).
- tools headers: Synchronise x86 cpufeatures.h for L1TF additions
  (bnc#1012628).
- x86/microcode: Allow late microcode loading with SMT disabled
  (bnc#1012628).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Update config files.
- commit a23e15c
* Tue Aug 14 2018 mkubecek@suse.cz
- Update upstream reference:
  patches.suse/hv-netvsc-Fix-NULL-dereference-at-single-queue-mode-.patch.
- commit 0425184
* Tue Aug 14 2018 tiwai@suse.de
- hv/netvsc: Fix NULL dereference at single queue mode fallback
  (bsc#1104708).
- commit a0cb9f6
* Mon Aug 13 2018 jslaby@suse.cz
- Refresh
  patches.suse/platform-x86-ideapad-laptop-Apply-no_hw_rfkill-to-Y2.
  Update upstream info.
- commit 799dc2a
* Mon Aug 13 2018 mkubecek@suse.cz
- Update to 4.18-final.
- Refresh configs
- commit 06ab9b3
* Thu Aug  9 2018 jslaby@suse.cz
- Linux 4.17.14 (bnc#1012628).
- jfs: Fix inconsistency between memory allocation and
  ea_buf->max_size (bnc#1012628).
- xfs: validate cached inodes are free when allocated
  (bnc#1012628).
- xfs: don't call xfs_da_shrink_inode with NULL bp (bnc#1012628).
- Partially revert "block: fail op_is_write() requests to
  read-only partitions" (bnc#1012628).
- Btrfs: fix file data corruption after cloning a range and fsync
  (bnc#1012628).
- i2c: imx: Fix reinit_completion() use (bnc#1012628).
- ring_buffer: tracing: Inherit the tracing setting to next ring
  buffer (bnc#1012628).
- netlink: Don't shift on 64 for ngroups (bnc#1012628).
- nohz: Fix missing tick reprogram when interrupting an inline
  softirq (bnc#1012628).
- nohz: Fix local_timer_softirq_pending() (bnc#1012628).
- perf/x86/intel/uncore: Fix hardcoded index of Broadwell extra
  PCI devices (bnc#1012628).
- genirq: Make force irq threading setup more robust
  (bnc#1012628).
- jfs: Fix usercopy whitelist for inline inode data (bnc#1012628).
- scsi: qla2xxx: Return error when TMF returns (bnc#1012628).
- scsi: qla2xxx: Fix ISP recovery on unload (bnc#1012628).
- scsi: qla2xxx: Fix driver unload by shutting down chip
  (bnc#1012628).
- scsi: qla2xxx: Fix NPIV deletion by calling
  wait_for_sess_deletion (bnc#1012628).
- scsi: qla2xxx: Fix unintialized List head crash (bnc#1012628).
- commit dc49b43
* Tue Aug  7 2018 mkubecek@suse.cz
- config: refresh s390x/vanilla
  Add new option CONFIG_SYSTEM_DATA_VERIFICATION=n
- commit 3ee2023
* Mon Aug  6 2018 jslaby@suse.cz
- Linux 4.17.13 (bnc#1012628).
- scsi: sg: fix minor memory leak in error path (bnc#1012628).
- drm/atomic: Initialize variables in
  drm_atomic_helper_async_check() to make gcc happy (bnc#1012628).
- drm/atomic: Check old_plane_state->crtc in
  drm_atomic_helper_async_check() (bnc#1012628).
- drm/vc4: Reset ->{x, y}_scaling[1] when dealing with uniplanar
  formats (bnc#1012628).
- crypto: padlock-aes - Fix Nano workaround data corruption
  (bnc#1012628).
- RDMA/uverbs: Expand primary and alt AV port checks
  (bnc#1012628).
- brcmfmac: fix regression in parsing NVRAM for multiple devices
  (bnc#1012628).
- iwlwifi: add more card IDs for 9000 series (bnc#1012628).
- userfaultfd: remove uffd flags from vma->vm_flags if
  UFFD_EVENT_FORK fails (bnc#1012628).
- ipc/shm.c add ->pagesize function to shm_vm_ops (bnc#1012628).
- audit: fix potential null dereference 'context->module.name'
  (bnc#1012628).
- kvm: x86: vmx: fix vpid leak (bnc#1012628).
- x86/entry/64: Remove %%ebx handling from error_entry/exit
  (bnc#1012628).
- x86/apic: Future-proof the TSC_DEADLINE quirk for SKX
  (bnc#1012628).
- x86/efi: Access EFI MMIO data as unencrypted when SEV is active
  (bnc#1012628).
- virtio_balloon: fix another race between migration and
  ballooning (bnc#1012628).
- net: socket: Fix potential spectre v1 gadget in
  sock_is_registered (bnc#1012628).
- net: socket: fix potential spectre v1 gadget in socketcall
  (bnc#1012628).
- can: ems_usb: Fix memory leak on ems_usb_disconnect()
  (bnc#1012628).
- squashfs: more metadata hardenings (bnc#1012628).
- squashfs: more metadata hardening (bnc#1012628).
- net/mlx5e: IPoIB, Set the netdevice sw mtu in ipoib enhanced
  flow (bnc#1012628).
- net/mlx5e: Set port trust mode to PCP as default (bnc#1012628).
- net/mlx5e: E-Switch, Initialize eswitch only if eswitch manager
  (bnc#1012628).
- rxrpc: Fix user call ID check in rxrpc_service_prealloc_one
  (bnc#1012628).
- net: stmmac: Fix WoL for PCI-based setups (bnc#1012628).
- netlink: Fix spectre v1 gadget in netlink_create()
  (bnc#1012628).
- net: dsa: Do not suspend/resume closed slave_dev (bnc#1012628).
- ipv4: frags: handle possible skb truesize change (bnc#1012628).
- inet: frag: enforce memory limits earlier (bnc#1012628).
- bonding: avoid lockdep confusion in bond_get_stats()
  (bnc#1012628).
- commit 9079348
* Mon Aug  6 2018 mkubecek@suse.cz
- Update to 4.18-rc8
- commit 9928e10
* Fri Aug  3 2018 jslaby@suse.cz
- Linux 4.17.12 (bnc#1012628).
- ACPICA: AML Parser: ignore control method status in module-level
  code (bnc#1012628).
- ACPI / LPSS: Avoid PM quirks on suspend and resume from
  hibernation (bnc#1012628).
- tcp: ack immediately when a cwr packet arrives (bnc#1012628).
- tcp: add one more quick ack after after ECN events
  (bnc#1012628).
- tcp: refactor tcp_ecn_check_ce to remove sk type cast
  (bnc#1012628).
- tcp: do not aggressively quick ack after ECN events
  (bnc#1012628).
- tcp: add max_quickacks param to tcp_incr_quickack and
  tcp_enter_quickack_mode (bnc#1012628).
- tcp: do not force quickack when receiving out-of-order packets
  (bnc#1012628).
- netlink: Don't shift with UB on nlk->ngroups (bnc#1012628).
- netlink: Do not subscribe to non-existent groups (bnc#1012628).
- net: rollback orig value on failure of
  dev_qdisc_change_tx_queue_len (bnc#1012628).
- cxgb4: Added missing break in ndo_udp_tunnel_{add/del}
  (bnc#1012628).
- xen-netfront: wait xenbus state change when load module manually
  (bnc#1012628).
- virtio_net: Fix incosistent received bytes counter
  (bnc#1012628).
- tcp_bbr: fix bw probing to raise in-flight data for very small
  BDPs (bnc#1012628).
- RDS: RDMA: Fix the NULL-ptr deref in rds_ib_get_mr
  (bnc#1012628).
- NET: stmmac: align DMA stuff to largest cache line length
  (bnc#1012628).
- net: mdio-mux: bcm-iproc: fix wrong getter and setter pair
  (bnc#1012628).
- net: lan78xx: fix rx handling before first packet is send
  (bnc#1012628).
- net: fix amd-xgbe flow-control issue (bnc#1012628).
- net: ena: Fix use of uninitialized DMA address bits field
  (bnc#1012628).
- netdevsim: don't leak devlink resources (bnc#1012628).
- ipv4: remove BUG_ON() from fib_compute_spec_dst (bnc#1012628).
- net: dsa: qca8k: Allow overwriting CPU port setting
  (bnc#1012628).
- net: dsa: qca8k: Add QCA8334 binding documentation
  (bnc#1012628).
- net: dsa: qca8k: Enable RXMAC when bringing up a port
  (bnc#1012628).
- net: dsa: qca8k: Force CPU port to its highest bandwidth
  (bnc#1012628).
- RDMA/uverbs: Protect from attempts to create flows on
  unsupported QP (bnc#1012628).
- gpio: uniphier: set legitimate irq trigger type in .to_irq hook
  (bnc#1012628).
- gpio: of: Handle fixed regulator flags properly (bnc#1012628).
- ext4: fix check to prevent initializing reserved inodes
  (bnc#1012628).
- ext4: check for allocation block validity with block group
  locked (bnc#1012628).
- ext4: fix inline data updates with checksums enabled
  (bnc#1012628).
- ext4: fix false negatives *and* false positives in
  ext4_check_descriptors() (bnc#1012628).
- squashfs: be more careful about metadata corruption
  (bnc#1012628).
- random: mix rdrand with entropy sent in from userspace
  (bnc#1012628).
- i2c: rcar: handle RXDMA HW behaviour on Gen3 (bnc#1012628).
- nvmet-fc: fix target sgl list on large transfers (bnc#1012628).
- block: reset bi_iter.bi_done after splitting bio (bnc#1012628).
- blkdev: __blkdev_direct_IO_simple: fix leak in error case
  (bnc#1012628).
- block: bio_iov_iter_get_pages: fix size of last iovec
  (bnc#1012628).
- drm/amdgpu: Avoid reclaim while holding locks taken in MMU
  notifier (bnc#1012628).
- drm/dp/mst: Fix off-by-one typo when dump payload table
  (bnc#1012628).
- drm/atomic-helper: Drop plane->fb references only for
  drm_atomic_helper_shutdown() (bnc#1012628).
- drm: Add DP PSR2 sink enable bit (bnc#1012628).
- ARM: dts: imx6qdl-wandboard: Let the codec control MCLK pinctrl
  (bnc#1012628).
- ASoC: topology: Add missing clock gating parameter when parsing
  hw_configs (bnc#1012628).
- ASoC: topology: Fix bclk and fsync inversion in
  set_link_hw_format() (bnc#1012628).
- net: socionext: reset hardware in ndo_stop (bnc#1012628).
- media: si470x: fix __be16 annotations (bnc#1012628).
- media: cec: fix smatch error (bnc#1012628).
- media: atomisp: compat32: fix __user annotations (bnc#1012628).
- PCI/ASPM: Disable ASPM L1.2 Substate if we don't have LTR
  (bnc#1012628).
- scsi: cxlflash: Avoid clobbering context control register value
  (bnc#1012628).
- scsi: cxlflash: Synchronize reset and remove ops (bnc#1012628).
- scsi: megaraid_sas: Increase timeout by 1 sec for non-RAID
  fastpath IOs (bnc#1012628).
- scsi: scsi_dh: replace too broad "TP9" string with the exact
  models (bnc#1012628).
- drm/stm: ltdc: fix warning in ltdc_crtc_update_clut()
  (bnc#1012628).
- ath10k: search all IEs for variant before falling back
  (bnc#1012628).
- regulator: Don't return or expect -errno from of_map_mode()
  (bnc#1012628).
- media: omap3isp: fix unbalanced dma_iommu_mapping (bnc#1012628).
- media: rc: mce_kbd decoder: low timeout values cause double
  keydowns (bnc#1012628).
- y2038: ipc: Use ktime_get_real_seconds consistently
  (bnc#1012628).
- crypto: authenc - don't leak pointers to authenc keys
  (bnc#1012628).
- crypto: authencesn - don't leak pointers to authenc keys
  (bnc#1012628).
- usb: hub: Don't wait for connect state at resume for powered-off
  ports (bnc#1012628).
- microblaze: Fix simpleImage format generation (bnc#1012628).
- soc: imx: gpcv2: Do not pass static memory as platform data
  (bnc#1012628).
- serial: core: Make sure compiler barfs for 16-byte earlycon
  names (bnc#1012628).
- staging: ks7010: fix error handling in ks7010_upload_firmware
  (bnc#1012628).
- staging: lustre: ldlm: free resource when ldlm_lock_create()
  fails (bnc#1012628).
- staging: lustre: llite: correct removexattr detection
  (bnc#1012628).
- staging: vchiq_core: Fix missing semaphore release in error case
  (bnc#1012628).
- platform/x86: dell-smbios: Match on www.dell.com in OEM strings
  too (bnc#1012628).
- drm/rockchip: analogix_dp: Do not call Analogix code before bind
  (bnc#1012628).
- audit: allow not equal op for audit by executable (bnc#1012628).
- rsi: fix nommu_map_sg overflow kernel panic (bnc#1012628).
- rsi: Fix 'invalid vdd' warning in mmc (bnc#1012628).
- ipconfig: Correctly initialise ic_nameservers (bnc#1012628).
- drm/gma500: fix psb_intel_lvds_mode_valid()'s return type
  (bnc#1012628).
- qtnfmac: pearl: pcie: fix memory leak in qtnf_fw_work_handler
  (bnc#1012628).
- igb: Fix queue selection on MAC filters on i210 (bnc#1012628).
- ASoC: compress: Only call free for components which have been
  opened (bnc#1012628).
- arm64: defconfig: Enable Rockchip io-domain driver
  (bnc#1012628).
- ASoC: fsl_ssi: Use u32 variable type when using regmap_read()
  (bnc#1012628).
- nvme: lightnvm: add granby support (bnc#1012628).
- memory: tegra: Apply interrupts mask per SoC (bnc#1012628).
- memory: tegra: Do not handle spurious interrupts (bnc#1012628).
- ath10k: fix kernel panic while reading tpc_stats (bnc#1012628).
- delayacct: Use raw_spinlocks (bnc#1012628).
- stop_machine: Use raw spinlocks (bnc#1012628).
- backlight: pwm_bl: Don't use GPIOF_* with gpiod_get_direction
  (bnc#1012628).
- mt76: add rcu locking around tx scheduling (bnc#1012628).
- i40e: avoid overflow in i40e_ptp_adjfreq() (bnc#1012628).
- i40e: Add advertising 10G LR mode (bnc#1012628).
- dt-bindings: net: meson-dwmac: new compatible name for AXG SoC
  (bnc#1012628).
- net: hns3: Fixes the out of bounds access in hclge_map_tqp
  (bnc#1012628).
- spi: meson-spicc: Fix error handling in meson_spicc_probe()
  (bnc#1012628).
- dt-bindings: pinctrl: meson: add support for the Meson8m2 SoC
  (bnc#1012628).
- mmc: pwrseq: Use kmalloc_array instead of stack VLA
  (bnc#1012628).
- mmc: dw_mmc: update actual clock for mmc debugfs (bnc#1012628).
- ALSA: hda/ca0132: fix build failure when a local macro is
  defined (bnc#1012628).
- mlxsw: spectrum_router: Return an error for non-default FIB
  rules (bnc#1012628).
- f2fs: check cap_resource only for data blocks (bnc#1012628).
- mmc: sdhci-omap: Fix when capabilities are obtained from
  SDHCI_CAPABILITIES reg (bnc#1012628).
- drm/atomic: Handling the case when setting old crtc for plane
  (bnc#1012628).
- mt76x2: fix avg_rssi estimation (bnc#1012628).
- media: siano: get rid of __le32/__le16 cast warnings
  (bnc#1012628).
- media: em28xx: fix a regression with HVR-950 (bnc#1012628).
- f2fs: avoid fsync() failure caused by EAGAIN in writepage()
  (bnc#1012628).
- bpf: fix references to free_bpf_prog_info() in comments
  (bnc#1012628).
- regulator: add dummy function of_find_regulator_by_node
  (bnc#1012628).
- thermal: exynos: fix setting rising_threshold for Exynos5433
  (bnc#1012628).
- staging: lustre: o2iblnd: Fix FastReg map/unmap for MLX5
  (bnc#1012628).
- staging: lustre: o2iblnd: fix race at kiblnd_connect_peer
  (bnc#1012628).
- dma-direct: try reallocation with GFP_DMA32 if possible
  (bnc#1012628).
- scsi: qedf: Set the UNLOADING flag when removing a vport
  (bnc#1012628).
- soc/tegra: pmc: Don't allocate struct tegra_powergate on stack
  (bnc#1012628).
- scsi: hisi_sas: config ATA de-reset as an constrained command
  for v3 hw (bnc#1012628).
- scsi: megaraid: silence a static checker bug (bnc#1012628).
- scsi: 3w-xxxx: fix a missing-check bug (bnc#1012628).
- scsi: 3w-9xxx: fix a missing-check bug (bnc#1012628).
- staging: most: cdev: fix chrdev_region leak (bnc#1012628).
- mm, powerpc, x86: define VM_PKEY_BITx bits if
  CONFIG_ARCH_HAS_PKEYS is enabled (bnc#1012628).
- bnxt_en: Always forward VF MAC address to the PF (bnc#1012628).
- bnxt_en: Check unsupported speeds in bnxt_update_link() on PF
  only (bnc#1012628).
- net: phy: sfp: handle cases where neither BR, min nor BR,
  max is given (bnc#1012628).
- perf: fix invalid bit in diagnostic entry (bnc#1012628).
- s390/cpum_sf: Add data entry sizes to sampling trailer entry
  (bnc#1012628).
- brcmfmac: Add support for bcm43364 wireless chipset
  (bnc#1012628).
- mtd: rawnand: fsl_ifc: fix FSL NAND driver to read all ONFI
  parameter pages (bnc#1012628).
- media: em28xx: Fix DualHD broken second tuner (bnc#1012628).
- media: renesas-ceu: Set mbus_fmt on subdev operations
  (bnc#1012628).
- media: saa7164: Fix driver name in debug output (bnc#1012628).
- media: media-device: fix ioctl function types (bnc#1012628).
- ACPI / LPSS: Only call pwm_add_table() for Bay Trail PWM if
  PMIC HRV is 2 (bnc#1012628).
- libata: Fix command retry decision (bnc#1012628).
- media: rcar_jpu: Add missing clk_disable_unprepare() on error
  in jpu_open() (bnc#1012628).
- net: phy: phylink: Release link GPIO (bnc#1012628).
- dma-iommu: Fix compilation when !CONFIG_IOMMU_DMA (bnc#1012628).
- tty: Fix data race in tty_insert_flip_string_fixed_flag
  (bnc#1012628).
- i40e: free the skb after clearing the bitlock (bnc#1012628).
- ARM: dts: imx53: Fix LDB OF graph warning (bnc#1012628).
- nvmem: properly handle returned value nvmem_reg_read
  (bnc#1012628).
- ARM: dts: sh73a0: Add missing interrupt-affinity to PMU node
  (bnc#1012628).
- ARM: dts: emev2: Add missing interrupt-affinity to PMU node
  (bnc#1012628).
- ARM: dts: stih407-pinctrl: Fix complain about IRQ_TYPE_NONE
  usage (bnc#1012628).
- ARM: dts: stih410: Fix complain about IRQ_TYPE_NONE usage
  (bnc#1012628).
- rsi: Add null check for virtual interfaces in wowlan config
  (bnc#1012628).
- EDAC, altera: Fix ARM64 build warning (bnc#1012628).
- HID: i2c-hid: check if device is there before really probing
  (bnc#1012628).
- powerpc/embedded6xx/hlwd-pic: Prevent interrupts from being
  handled by Starlet (bnc#1012628).
- IB: Fix RDMA_RXE and INFINIBAND_RDMAVT dependencies for
  DMA_VIRT_OPS (bnc#1012628).
- drm/amd/display: Fix dim display on DCE11 (bnc#1012628).
- drm/amdgpu: Remove VRAM from shared bo domains (bnc#1012628).
- drm/radeon: fix mode_valid's return type (bnc#1012628).
- drm/amd/display: remove need of modeset flag for overlay planes
  (V2) (bnc#1012628).
- arm64: dts: renesas: salvator-common: use audio-graph-card
  for Sound (bnc#1012628).
- HID: hid-plantronics: Re-resend Update to map button for PTT
  products (bnc#1012628).
- arm64: cmpwait: Clear event register before arming exclusive
  monitor (bnc#1012628).
- media: staging: atomisp: Comment out several unused sensor
  resolutions (bnc#1012628).
- media: atomisp: ov2680: don't declare unused vars (bnc#1012628).
- net: hns3: Fix for fiber link up problem (bnc#1012628).
- ALSA: usb-audio: Apply rate limit to warning messages in URB
  complete callback (bnc#1012628).
- net: ethernet: ti: cpsw-phy-sel: check bus_find_device()
  ret value (bnc#1012628).
- clocksource: Move inline keyword to the beginning of function
  declarations (bnc#1012628).
- PCI/DPC: Clear interrupt status in interrupt handler top half
  (bnc#1012628).
- media: smiapp: fix timeout checking in smiapp_read_nvm
  (bnc#1012628).
- gpu: host1x: Acquire a reference to the IOVA cache
  (bnc#1012628).
- ixgbevf: fix MAC address changes through ixgbevf_set_mac()
  (bnc#1012628).
- md: fix NULL dereference of mddev->pers in
  remove_and_add_spares() (bnc#1012628).
- md/raid1: add error handling of read error from FailFast device
  (bnc#1012628).
- regulator: pfuze100: add .is_enable() for
  pfuze100_swb_regulator_ops (bnc#1012628).
- ALSA: emu10k1: Rate-limit error messages about page errors
  (bnc#1012628).
- rtc: tps65910: fix possible race condition (bnc#1012628).
- rtc: vr41xx: fix possible race condition (bnc#1012628).
- rtc: tps6586x: fix possible race condition (bnc#1012628).
- Bluetooth: btusb: add ID for LiteOn 04ca:301a (bnc#1012628).
- drm/nouveau/fifo/gk104-: poll for runlist update completion
  (bnc#1012628).
- drm/nouveau/gem: lookup VMAs for buffers referenced by pushbuf
  ioctl (bnc#1012628).
- drm/nouveau: remove fence wait code from deferred client work
  handler (bnc#1012628).
- scsi: zfcp: assert that the ERP lock is held when tracing a
  recovery trigger (bnc#1012628).
- scsi: ufs: fix exception event handling (bnc#1012628).
- scsi: ufs: ufshcd: fix possible unclocked register access
  (bnc#1012628).
- net: mvpp2: Add missing VLAN tag detection (bnc#1012628).
- fscrypt: use unbound workqueue for decryption (bnc#1012628).
- net: hns3: Fix for hns3 module is loaded multiple times problem
  (bnc#1012628).
- net: hns3: Fix the missing client list node initialization
  (bnc#1012628).
- net: hns3: Fix for CMDQ and Misc. interrupt init order problem
  (bnc#1012628).
- spi: Add missing pm_runtime_put_noidle() after failed get
  (bnc#1012628).
- drivers/perf: arm-ccn: don't log to dmesg in event_init
  (bnc#1012628).
- watchdog: renesas-wdt: Add support for the R8A77965 WDT
  (bnc#1012628).
- ima: based on policy verify firmware signatures (pre-allocated
  buffer) (bnc#1012628).
- mt76x2: apply coverage class on slot time too (bnc#1012628).
- mwifiex: correct histogram data with appropriate index
  (bnc#1012628).
- net: dsa: qca8k: Add support for QCA8334 switch (bnc#1012628).
- PCI: pciehp: Request control of native hotplug only if supported
  (bnc#1012628).
- bpf: powerpc64: pad function address loads with NOPs
  (bnc#1012628).
- bpf: fix multi-function JITed dump obtained via syscall
  (bnc#1012628).
- pinctrl: msm: fix gpio-hog related boot issues (bnc#1012628).
- pinctrl: at91-pio4: add missing of_node_put (bnc#1012628).
- powerpc/8xx: fix invalid register expression in head_8xx.S
  (bnc#1012628).
- spi: sh-msiof: Fix setting SIRMDR1.SYNCAC to match
  SITMDR1.SYNCAC (bnc#1012628).
- KVM: x86: prevent integer overflows in
  KVM_MEMORY_ENCRYPT_REG_REGION (bnc#1012628).
- powerpc: Add __printf verification to prom_printf (bnc#1012628).
- powerpc/powermac: Mark variable x as unused (bnc#1012628).
- powerpc/powermac: Add missing prototype for note_bootable_part()
  (bnc#1012628).
- powerpc/chrp/time: Make some functions static, add missing
  header include (bnc#1012628).
- powerpc/32: Add a missing include header (bnc#1012628).
- sched/cpufreq: Modify aggregate utilization to always include
  blocked FAIR utilization (bnc#1012628).
- ath: Add regulatory mapping for Bahamas (bnc#1012628).
- ath: Add regulatory mapping for Bermuda (bnc#1012628).
- ath: Add regulatory mapping for Serbia (bnc#1012628).
- ath: Add regulatory mapping for Tanzania (bnc#1012628).
- ath: Add regulatory mapping for Uganda (bnc#1012628).
- ath: Add regulatory mapping for APL2_FCCA (bnc#1012628).
- ath: Add regulatory mapping for APL13_WORLD (bnc#1012628).
- ath: Add regulatory mapping for ETSI8_WORLD (bnc#1012628).
- ath: Add regulatory mapping for FCC3_ETSIC (bnc#1012628).
- nvme-pci: Fix AER reset handling (bnc#1012628).
- nvme-rdma: stop admin queue before freeing it (bnc#1012628).
- soc: qcom: smem: byte swap values properly (bnc#1012628).
- soc: qcom: smem: fix qcom_smem_set_global_partition()
  (bnc#1012628).
- soc: qcom: qmi: fix a buffer sizing bug (bnc#1012628).
- PCI: Prevent sysfs disable of device while driver is attached
  (bnc#1012628).
- PM / wakeup: Make s2idle_lock a RAW_SPINLOCK (bnc#1012628).
- x86/microcode: Make the late update update_lock a raw lock
  for RT (bnc#1012628).
- btrfs: qgroup: Finish rescan when hit the last leaf of extent
  tree (bnc#1012628).
- btrfs: add barriers to btrfs_sync_log before log_commit_wait
  wakeups (bnc#1012628).
- Btrfs: don't BUG_ON() in btrfs_truncate_inode_items()
  (bnc#1012628).
- Btrfs: don't return ino to ino cache if inode item removal fails
  (bnc#1012628).
- media: videobuf2-core: don't call memop 'finish' when queueing
  (bnc#1012628).
- media: cec-pin-error-inj: avoid a false-positive Spectre
  detection (bnc#1012628).
- media: tw686x: Fix incorrect vb2_mem_ops GFP flags
  (bnc#1012628).
- net: hns3: Fixes the init of the VALID BD info in the descriptor
  (bnc#1012628).
- net: hns3: Fixes initalization of RoCE handle and makes it
  conditional (bnc#1012628).
- wlcore: sdio: check for valid platform device data before
  suspend (bnc#1012628).
- mwifiex: handle race during mwifiex_usb_disconnect
  (bnc#1012628).
- mfd: cros_ec: Fail early if we cannot identify the EC
  (bnc#1012628).
- ASoC: dpcm: fix BE dai not hw_free and shutdown (bnc#1012628).
- Bluetooth: btusb: Add a new Realtek 8723DE ID 2ff8:b011
  (bnc#1012628).
- drivers/bus: arm-cci: fix build warnings (bnc#1012628).
- drm/amd/display: Do not program interrupt status on disabled
  crtc (bnc#1012628).
- Bluetooth: hci_qca: Fix "Sleep inside atomic section" warning
  (bnc#1012628).
- iwlwifi: mvm: open BA session only when sta is authorized
  (bnc#1012628).
- iwlwifi: pcie: fix race in Rx buffer allocator (bnc#1012628).
- btrfs: balance dirty metadata pages in btrfs_finish_ordered_io
  (bnc#1012628).
- PCI: Fix devm_pci_alloc_host_bridge() memory leak (bnc#1012628).
- qtnfmac: fix invalid STA state on EAPOL failure (bnc#1012628).
- selftests/filesystems: devpts_pts included wrong header
  (bnc#1012628).
- selftests: filesystems: return Kselftest Skip code for skipped
  tests (bnc#1012628).
- selftests: intel_pstate: return Kselftest Skip code for skipped
  tests (bnc#1012628).
- selftests: kvm: return Kselftest Skip code for skipped tests
  (bnc#1012628).
- selftests: memfd: return Kselftest Skip code for skipped tests
  (bnc#1012628).
- selftests/intel_pstate: Improve test, minor fixes (bnc#1012628).
- perf/x86/intel/uncore: Correct fixed counter index check for
  NHM (bnc#1012628).
- perf/x86/intel/uncore: Correct fixed counter index check in
  generic code (bnc#1012628).
- usbip: dynamically allocate idev by nports found in sysfs
  (bnc#1012628).
- usbip: usbip_detach: Fix memory, udev context and udev leak
  (bnc#1012628).
- block, bfq: remove wrong lock in bfq_requests_merged
  (bnc#1012628).
- f2fs: fix race in between GC and atomic open (bnc#1012628).
- f2fs: fix to detect failure of dquot_initialize (bnc#1012628).
- f2fs: fix missing clear FI_NO_PREALLOC in some error case
  (bnc#1012628).
- f2fs: Fix deadlock in shutdown ioctl (bnc#1012628).
- f2fs: fix to wait page writeback during revoking atomic write
  (bnc#1012628).
- f2fs: fix to don't trigger writeback during recovery
  (bnc#1012628).
- f2fs: don't drop dentry pages after fs shutdown (bnc#1012628).
- f2fs: fix error path of move_data_page (bnc#1012628).
- disable loading f2fs module on PAGE_SIZE > 4KB (bnc#1012628).
- NFS: Fix up nfs_post_op_update_inode() to force ctime updates
  (bnc#1012628).
- pnfs: Don't release the sequence slot until we've processed
  layoutget on open (bnc#1012628).
- netfilter: nf_tables: check msg_type before nft_trans_set(trans)
  (bnc#1012628).
- lightnvm: pblk: warn in case of corrupted write buffer
  (bnc#1012628).
- lightnvm: proper error handling for pblk_bio_add_pages
  (bnc#1012628).
- lightnvm: fix partial read error path (bnc#1012628).
- RDMA/mad: Convert BUG_ONs to error flows (bnc#1012628).
- net: hns3: Fix for service_task not running problem after
  resetting (bnc#1012628).
- net: hns3: Fix for phy not link up problem after resetting
  (bnc#1012628).
- clk: ingenic: jz4770: Modify C1CLK clock to disable CPU clock
  stop on idle (bnc#1012628).
- clk-si544: Properly round requested frequency to nearest match
  (bnc#1012628).
- powerpc/64s: Fix compiler store ordering to SLB shadow area
  (bnc#1012628).
- hvc_opal: don't set tb_ticks_per_usec in udbg_init_opal_common()
  (bnc#1012628).
- powerpc/eeh: Fix use-after-release of EEH driver (bnc#1012628).
- powerpc/64s: Add barrier_nospec (bnc#1012628).
- powerpc/lib: Adjust .balign inside string functions for PPC32
  (bnc#1012628).
- infiniband: fix a possible use-after-free bug (bnc#1012628).
- e1000e: Ignore TSYNCRXCTL when getting I219 clock attributes
  (bnc#1012628).
- ceph: fix use-after-free in ceph_statfs() (bnc#1012628).
- ceph: fix alignment of rasize (bnc#1012628).
- bpf, arm32: fix inconsistent naming about emit_a32_lsr_{r64,i64}
  (bnc#1012628).
- printk: drop in_nmi check from printk_safe_flush_on_panic()
  (bnc#1012628).
- media: arch: sh: migor: Fix TW9910 PDN gpio (bnc#1012628).
- watchdog: da9063: Fix updating timeout value (bnc#1012628).
- irqchip/ls-scfg-msi: Map MSIs in the iommu (bnc#1012628).
- netfilter: ipset: List timing out entries with "timeout 1"
  instead of zero (bnc#1012628).
- netfilter: ipset: forbid family for hash:mac sets (bnc#1012628).
- perf tools: Fix pmu events parsing rule (bnc#1012628).
- net: hns3: Fix for VF mailbox cannot receiving PF response
  (bnc#1012628).
- rxrpc: Fix terminal retransmission connection ID to include
  the channel (bnc#1012628).
- rtc: ensure rtc_set_alarm fails when alarms are not supported
  (bnc#1012628).
- mm/slub.c: add __printf verification to slab_err()
  (bnc#1012628).
- mm: vmalloc: avoid racy handling of debugobjects in vunmap
  (bnc#1012628).
- mm: /proc/pid/pagemap: hide swap entries from unprivileged users
  (bnc#1012628).
- mem_cgroup: make sure moving_account, move_lock_task and
  stat_cpu in the same cacheline (bnc#1012628).
- kernel/hung_task.c: show all hung tasks before panic
  (bnc#1012628).
- vfio/type1: Fix task tracking for QEMU vCPU hotplug
  (bnc#1012628).
- vfio/mdev: Check globally for duplicate devices (bnc#1012628).
- vfio: platform: Fix reset module leak in error path
  (bnc#1012628).
- nfsd: fix potential use-after-free in nfsd4_decode_getdeviceinfo
  (bnc#1012628).
- nfsd: fix error handling in nfs4_set_delegation() (bnc#1012628).
- NFSv4.1: Fix the client behaviour on NFS4ERR_SEQ_FALSE_RETRY
  (bnc#1012628).
- ALSA: fm801: add error handling for snd_ctl_add (bnc#1012628).
- ALSA: emu10k1: add error handling for snd_ctl_add (bnc#1012628).
- ixgbe: Fix setting of TC configuration for macvlan case
  (bnc#1012628).
- skip LAYOUTRETURN if layout is invalid (bnc#1012628).
- hv_netvsc: fix network namespace issues with VF support
  (bnc#1012628).
- xen/netfront: raise max number of slots in
  xennet_get_responses() (bnc#1012628).
- drm/amd/powerplay: Set higher SCLK&MCLK frequency than dpm7
  in OD (v2) (bnc#1012628).
- mm: check for SIGKILL inside dup_mmap() loop (bnc#1012628).
- kcov: ensure irq code sees a valid area (bnc#1012628).
- mlxsw: spectrum_switchdev: Fix port_vlan refcounting
  (bnc#1012628).
- drm/i915/glk: Add Quirk for GLK NUC HDMI port issues
  (bnc#1012628).
- arm64: fix vmemmap BUILD_BUG_ON() triggering on !vmemmap setups
  (bnc#1012628).
- tracing: Quiet gcc warning about maybe unused link variable
  (bnc#1012628).
- tracing/kprobes: Fix trace_probe flags on enable_trace_kprobe()
  failure (bnc#1012628).
- kthread, tracing: Don't expose half-written comm when creating
  kthreads (bnc#1012628).
- tracing: Fix possible double free in event_enable_trigger_func()
  (bnc#1012628).
- tracing: Fix double free of event_trigger_data (bnc#1012628).
- delayacct: fix crash in delayacct_blkio_end() after delayacct
  init failure (bnc#1012628).
- kvm, mm: account shadow page tables to kmemcg (bnc#1012628).
- mm: disallow mappings that conflict for devm_memremap_pages()
  (bnc#1012628).
- Input: elan_i2c - add another ACPI ID for Lenovo Ideapad
  330-15AST (bnc#1012628).
- Input: i8042 - add Lenovo LaVie Z to the i8042 reset list
  (bnc#1012628).
- Input: elan_i2c - add ACPI ID for lenovo ideapad 330
  (bnc#1012628).
- spi: spi-s3c64xx: Fix system resume support (bnc#1012628).
- commit ef4920c
* Mon Jul 30 2018 jslaby@suse.cz
- Update config files.
  Run oldconfig on s390x's vanilla.
- commit 6676306
* Mon Jul 30 2018 mkubecek@suse.cz
- Update to 4.18-rc7
- commit 68c9705
* Sun Jul 29 2018 jslaby@suse.cz
- Linux 4.17.11 (bnc#1012628).
- can: m_can.c: fix setup of CCCR register: clear CCCR NISO bit
  before checking can.ctrlmode (bnc#1012628).
- can: m_can: Fix runtime resume call (bnc#1012628).
- can: peak_canfd: fix firmware < v3.3.0: limit allocation to
  32-bit DMA addr only (bnc#1012628).
- can: xilinx_can: fix RX overflow interrupt not being enabled
  (bnc#1012628).
- can: xilinx_can: fix incorrect clear of non-processed interrupts
  (bnc#1012628).
- can: xilinx_can: keep only 1-2 frames in TX FIFO to fix TX
  accounting (bnc#1012628).
- can: xilinx_can: fix device dropping off bus on RX overrun
  (bnc#1012628).
- can: xilinx_can: fix recovery from error states not being
  propagated (bnc#1012628).
- can: xilinx_can: fix power management handling (bnc#1012628).
- can: xilinx_can: fix RX loop if RXNEMP is asserted without RXOK
  (bnc#1012628).
- driver core: Partially revert "driver core: correct device's
  shutdown order" (bnc#1012628).
- ACPICA: AML Parser: ignore dispatcher error status during
  table load (bnc#1012628).
- usb: gadget: f_fs: Only return delayed status when len is 0
  (bnc#1012628).
- usb: gadget: Fix OS descriptors support (bnc#1012628).
- usb: xhci: Fix memory leak in xhci_endpoint_reset()
  (bnc#1012628).
- usb: dwc2: Fix DMA alignment to start at allocated boundary
  (bnc#1012628).
- usb: core: handle hub C_PORT_OVER_CURRENT condition
  (bnc#1012628).
- usb: cdc_acm: Add quirk for Castles VEGA3000 (bnc#1012628).
- staging: speakup: fix wraparound in uaccess length check
  (bnc#1012628).
- Revert "staging:r8188eu: Use lib80211 to support TKIP"
  (bnc#1012628).
- tcp: add tcp_ooo_try_coalesce() helper (bnc#1012628).
- tcp: call tcp_drop() from tcp_data_queue_ofo() (bnc#1012628).
- tcp: detect malicious patterns in tcp_collapse_ofo_queue()
  (bnc#1012628).
- tcp: avoid collapses in tcp_prune_queue() if possible
  (bnc#1012628).
- tcp: free batches of packets in tcp_prune_ofo_queue()
  (bnc#1012628).
- vxlan: fix default fdb entry netlink notify ordering during
  netdev create (bnc#1012628).
- vxlan: make netlink notify in vxlan_fdb_destroy optional
  (bnc#1012628).
- vxlan: add new fdb alloc and create helpers (bnc#1012628).
- rtnetlink: add rtnl_link_state check in rtnl_configure_link
  (bnc#1012628).
- net/mlx5: Adjust clock overflow work period (bnc#1012628).
- net/mlx5e: Fix quota counting in aRFS expire flow (bnc#1012628).
- net/mlx5e: Don't allow aRFS for encapsulated packets
  (bnc#1012628).
- net/ipv6: Fix linklocal to global address with VRF
  (bnc#1012628).
- multicast: do not restore deleted record source filter mode
  to new one (bnc#1012628).
- net: phy: consider PHY_IGNORE_INTERRUPT in phy_start_aneg_priv
  (bnc#1012628).
- sock: fix sg page frag coalescing in sk_alloc_sg (bnc#1012628).
- nfp: flower: ensure dead neighbour entries are not offloaded
  (bnc#1012628).
- net/mlx5e: Refine ets validation function (bnc#1012628).
- net/mlx5e: Only allow offloading decap egress (egdev) flows
  (bnc#1012628).
- net/mlx5e: Add ingress/egress indication for offloaded TC flows
  (bnc#1012628).
- tls: check RCV_SHUTDOWN in tls_wait_data (bnc#1012628).
- r8169: restore previous behavior to accept BIOS WoL settings
  (bnc#1012628).
- net/mlx5: E-Switch, UBSAN fix undefined behavior in
  mlx5_eswitch_mode (bnc#1012628).
- tcp: do not delay ACK in DCTCP upon CE status change
  (bnc#1012628).
- tcp: do not cancel delay-AcK on DCTCP special ACK (bnc#1012628).
- tcp: helpers to send special DCTCP ack (bnc#1012628).
- tcp: fix dctcp delayed ACK schedule (bnc#1012628).
- net: skb_segment() should not return NULL (bnc#1012628).
- net-next/hinic: fix a problem in hinic_xmit_frame()
  (bnc#1012628).
- net/mlx4_core: Save the qpn from the input modifier in RST2INIT
  wrapper (bnc#1012628).
- net: dsa: mv88e6xxx: fix races between lock and irq freeing
  (bnc#1012628).
- ip: in cmsg IP(V6)_ORIGDSTADDR call pskb_may_pull (bnc#1012628).
- ip: hash fragments consistently (bnc#1012628).
- bonding: set default miimon value for non-arp modes if not set
  (bnc#1012628).
- clk: meson-gxbb: set fclk_div2 as CLK_IS_CRITICAL (bnc#1012628).
- drm/nouveau: Set DRIVER_ATOMIC cap earlier to fix debugfs
  (bnc#1012628).
- drm/nouveau/drm/nouveau: Fix runtime PM leak in
  nv50_disp_atomic_commit() (bnc#1012628).
- KVM: PPC: Check if IOMMU page is contained in the pinned
  physical page (bnc#1012628).
- xen/PVH: Set up GS segment for stack canary (bnc#1012628).
- clk: aspeed: Support HPLL strapping on ast2400 (bnc#1012628).
- clk: aspeed: Mark bclk (PCIe) and dclk (VGA) as critical
  (bnc#1012628).
- clk: mvebu: armada-37xx-periph: Fix switching CPU rate from
  300Mhz to 1.2GHz (bnc#1012628).
- MIPS: Fix off-by-one in pci_resource_to_user() (bnc#1012628).
- MIPS: ath79: fix register address in ath79_ddr_wb_flush()
  (bnc#1012628).
- Revert "iommu/intel-iommu: Enable CONFIG_DMA_DIRECT_OPS=y and
  clean up intel_{alloc,free}_coherent()" (bnc#1012628).
- KVM: VMX: support MSR_IA32_ARCH_CAPABILITIES as a feature MSR
  (bnc#1012628).
- commit d626dd8
* Thu Jul 26 2018 msuchanek@suse.de
- Revert "Revert "Pass x86 as architecture on x86_64 and i386 (bsc#1093118).""
  This reverts commit f604b8a2baa6f01a438c2d495a34820ed722aef5.
- commit b5ab6f7
* Thu Jul 26 2018 msuchanek@suse.de
- Update config files.
- commit c195a0c
* Thu Jul 26 2018 jslaby@suse.cz
- Revert "Pass x86 as architecture on x86_64 and i386 (bsc#1093118)."
  This reverts commit 5f24fb07e56ac11cd19527c51f5a547f1d0946d4. It
  breaks all i586 builds.
- commit f604b8a
* Wed Jul 25 2018 jslaby@suse.cz
- Linux 4.17.10 (bnc#1012628).
- xhci: Fix perceived dead host due to runtime suspend race with
  event handler (bnc#1012628).
- cxl_getfile(): fix double-iput() on alloc_file() failures
  (bnc#1012628).
- drm_mode_create_lease_ioctl(): fix open-coded filp_clone_open()
  (bnc#1012628).
- alpha: fix osf_wait4() breakage (bnc#1012628).
- net: usb: asix: replace mii_nway_restart in resume path
  (bnc#1012628).
- ipv6: make DAD fail with enhanced DAD when nonce length differs
  (bnc#1012628).
- net: systemport: Fix CRC forwarding check for SYSTEMPORT Lite
  (bnc#1012628).
- net/mlx4_en: Don't reuse RX page when XDP is set (bnc#1012628).
- net: aquantia: vlan unicast address list correct handling
  (bnc#1012628).
- hv_netvsc: Fix napi reschedule while receive completion is busy
  (bnc#1012628).
- sctp: fix the issue that pathmtu may be set lower than
  MINSEGMENT (bnc#1012628).
- sctp: introduce sctp_dst_mtu (bnc#1012628).
- net: ip6_gre: get ipv6hdr after skb_cow_head() (bnc#1012628).
- tg3: Add higher cpu clock for 5762 (bnc#1012628).
- sch_fq_codel: zero q->flows_cnt when fq_codel_init fails
  (bnc#1012628).
- rhashtable: add restart routine in rhashtable_free_and_destroy()
  (bnc#1012628).
- qmi_wwan: add support for Quectel EG91 (bnc#1012628).
- ptp: fix missing break in switch (bnc#1012628).
- net: phy: fix flag masking in __set_phy_supported (bnc#1012628).
- net/ipv6: Do not allow device only routes via the multipath API
  (bnc#1012628).
- net/ipv4: Set oif in fib_compute_spec_dst (bnc#1012628).
- skbuff: Unconditionally copy pfmemalloc in __skb_clone()
  (bnc#1012628).
- net: Don't copy pfmemalloc flag in __copy_skb_header()
  (bnc#1012628).
- net: diag: Don't double-free TCP_NEW_SYN_RECV sockets in
  tcp_abort (bnc#1012628).
- lib/rhashtable: consider param->min_size when setting initial
  table size (bnc#1012628).
- ipv6: ila: select CONFIG_DST_CACHE (bnc#1012628).
- ipv6: fix useless rol32 call on hash (bnc#1012628).
- ipv4: Return EINVAL when ping_group_range sysctl doesn't map
  to user ns (bnc#1012628).
- gen_stats: Fix netlink stats dumping in the presence of padding
  (bnc#1012628).
- drm/nouveau: Avoid looping through fake MST connectors
  (bnc#1012628).
- drm/nouveau: Use drm_connector_list_iter_* for iterating
  connectors (bnc#1012628).
- drm/nouveau: Remove bogus crtc check in pmops_runtime_idle
  (bnc#1012628).
- Revert "drm/amd/display: Don't return ddc result and read_bytes
  in same return value" (bnc#1012628).
- drm/i915: Fix hotplug irq ack on i965/g4x (bnc#1012628).
- drm/amdgpu: Reserve VM root shared fence slot for command
  submission (v3) (bnc#1012628).
- powerpc/powernv: Fix save/restore of SPRG3 on entry/exit from
  stop (idle) (bnc#1012628).
- stop_machine: Disable preemption when waking two stopper threads
  (bnc#1012628).
- vfio/spapr: Use IOMMU pageshift rather than pagesize
  (bnc#1012628).
- vfio/pci: Fix potential Spectre v1 (bnc#1012628).
- cpufreq: intel_pstate: Register when ACPI PCCH is present
  (bnc#1012628).
- mm/huge_memory.c: fix data loss when splitting a file pmd
  (bnc#1012628).
- mm: memcg: fix use after free in mem_cgroup_iter()
  (bnc#1012628).
- ARC: mm: allow mprotect to make stack mappings executable
  (bnc#1012628).
- ARC: configs: Remove CONFIG_INITRAMFS_SOURCE from defconfigs
  (bnc#1012628).
- ARC: Fix CONFIG_SWAP (bnc#1012628).
- ARCv2: [plat-hsdk]: Save accl reg pair by default (bnc#1012628).
- ALSA: hda: add mute led support for HP ProBook 455 G5
  (bnc#1012628).
- ALSA: hda/realtek - Yet another Clevo P950 quirk entry
  (bnc#1012628).
- ALSA: hda/realtek - Add Panasonic CF-SZ6 headset jack quirk
  (bnc#1012628).
- ALSA: rawmidi: Change resized buffers atomically (bnc#1012628).
- fat: fix memory allocation failure handling of match_strdup()
  (bnc#1012628).
- x86/MCE: Remove min interval polling limitation (bnc#1012628).
- x86/events/intel/ds: Fix bts_interrupt_threshold alignment
  (bnc#1012628).
- x86/apm: Don't access __preempt_count with zeroed fs
  (bnc#1012628).
- x86/kvmclock: set pvti_cpu0_va after enabling kvmclock
  (bnc#1012628).
- x86/kvm/vmx: don't read current->thread.{fs,gs}base of legacy
  tasks (bnc#1012628).
- KVM: VMX: Mark VMXArea with revision_id of physical CPU even
  when eVMCS enabled (bnc#1012628).
- KVM: irqfd: fix race between EPOLLHUP and
  irq_bypass_register_consumer (bnc#1012628).
- KVM/Eventfd: Avoid crash when assign and deassign specific
  eventfd in parallel (bnc#1012628).
- scsi: qla2xxx: Fix NULL pointer dereference for fcport search
  (bnc#1012628).
- scsi: qla2xxx: Fix kernel crash due to late workqueue allocation
  (bnc#1012628).
- scsi: qla2xxx: Fix inconsistent DMA mem alloc/free
  (bnc#1012628).
- scsi: sd_zbc: Fix variable type and bogus comment (bnc#1012628).
- commit 0a7f415
* Tue Jul 24 2018 dmueller@suse.com
- Reenable v8.1/v8.2 aarch64 extensions
  These were enabled already in SLE15 and we want to default to the
  upstream defaults, which enable these features.
  Config changes:
  - aarch64:
    HW_AFDBM=y
    PAN=y
    LSE_ATOMICS=y
    VHE=y
    UAO=y
    SVE=y
- commit 7fdc027
* Mon Jul 23 2018 msuchanek@suse.de
- Update config files.
- commit 8efadc7
* Mon Jul 23 2018 tiwai@suse.de
- rpm/kernel-source.spec.in: Add more stuff to Recommends
  ... and move bc to Recommends as well.  All these packages are needed for
  building a kernel manually from scratch with kernel-source files.
- commit 6fcec9a
* Mon Jul 23 2018 jslaby@suse.cz
- Revert "rpm/kernel-source.spec.in: require bc for kernel-source"
  This reverts commit 2fa4028b0f8fcb4b6a9f2bd2a401a71181e0cdcd. Why
  would kernel-source need bc? The discussion is ongoing on
  opensuse-kernel. See:
  7230252.SMnhE4Fjuc@alaris
- commit 7144bb1
* Mon Jul 23 2018 mkubecek@suse.cz
- Update to 4.18-rc6
- Config changes:
  - NF_TABLES_SET=m (replaces NFT_SET_{RBTREE,HASH,BITMAP})
- commit 31ad2a8
* Sun Jul 22 2018 jslaby@suse.cz
- Linux 4.17.9 (bnc#1012628).
- bpf: undo prog rejection on read-only lock failure
  (bnc#1012628).
- bpf, arm32: fix to use bpf_jit_binary_lock_ro api (bnc#1012628).
- bpf: enforce correct alignment for instructions (bnc#1012628).
- arm64: KVM: Add ARCH_WORKAROUND_2 discovery through
  ARCH_FEATURES_FUNC_ID (bnc#1012628).
- arm64: KVM: Handle guest's ARCH_WORKAROUND_2 requests
  (bnc#1012628).
- arm64: KVM: Add ARCH_WORKAROUND_2 support for guests
  (bnc#1012628).
- arm64: KVM: Add HYP per-cpu accessors (bnc#1012628).
- arm64: ssbd: Add prctl interface for per-thread mitigation
  (bnc#1012628).
- arm64: ssbd: Introduce thread flag to control userspace
  mitigation (bnc#1012628).
- arm64: ssbd: Restore mitigation status on CPU resume
  (bnc#1012628).
- arm64: ssbd: Skip apply_ssbd if not using dynamic mitigation
  (bnc#1012628).
- arm64: ssbd: Add global mitigation state accessor (bnc#1012628).
- arm64: Add 'ssbd' command-line option (bnc#1012628).
- arm64: Add ARCH_WORKAROUND_2 probing (bnc#1012628).
  Update config files.
  ARM64_SSBD=y
- arm64: Add per-cpu infrastructure to call ARCH_WORKAROUND_2
  (bnc#1012628).
- arm64: Call ARCH_WORKAROUND_2 on transitions between EL0 and
  EL1 (bnc#1012628).
- arm/arm64: smccc: Add SMCCC-specific return codes (bnc#1012628).
- ipvs: initialize tbl->entries in ip_vs_lblc_init_svc()
  (bnc#1012628).
- ipvs: initialize tbl->entries after allocation (bnc#1012628).
- net/nfc: Avoid stalls when nfc_alloc_send_skb() returned NULL
  (bnc#1012628).
- bpf: don't leave partial mangled prog in jit_subprogs error path
  (bnc#1012628).
- bpf: sockmap, consume_skb in close path (bnc#1012628).
- bpf: sockmap, fix crash when ipv6 sock is added (bnc#1012628).
- block: don't use blocking queue entered for recursive bio
  submits (bnc#1012628).
- rds: avoid unenecessary cong_update in loop transport
  (bnc#1012628).
- bpf: reject any prog that failed read-only lock (bnc#1012628).
- bdi: Fix another oops in wb_workfn() (bnc#1012628).
- netfilter: ipv6: nf_defrag: drop skb dst before queueing
  (bnc#1012628).
- nsh: set mac len based on inner packet (bnc#1012628).
- autofs: fix slab out of bounds read in getname_kernel()
  (bnc#1012628).
- tls: Stricter error checking in zerocopy sendmsg path
  (bnc#1012628).
- KEYS: DNS: fix parsing multiple options (bnc#1012628).
- reiserfs: fix buffer overflow with long warning messages
  (bnc#1012628).
- netfilter: ebtables: reject non-bridge targets (bnc#1012628).
- PCI: hv: Disable/enable IRQs rather than BH in
  hv_compose_msi_msg() (bnc#1012628).
- crypto: af_alg - Initialize sg_num_bytes in error code path
  (bnc#1012628).
- net: lan78xx: Fix race in tx pending skb size calculation
  (bnc#1012628).
- rtlwifi: rtl8821ae: fix firmware is not ready to run
  (bnc#1012628).
- rtlwifi: Fix kernel Oops "Fw download fail!!" (bnc#1012628).
- net: cxgb3_main: fix potential Spectre v1 (bnc#1012628).
- x86/kvm/Kconfig: Ensure CRYPTO_DEV_CCP_DD state at minimum
  matches KVM_AMD (bnc#1012628).
- virtio_net: split XDP_TX kick and XDP_REDIRECT map flushing
  (bnc#1012628).
- sfc: correctly initialise filter rwsem for farch (bnc#1012628).
- s390/qeth: fix race when setting MAC address (bnc#1012628).
- s390/qeth: avoid using is_multicast_ether_addr_64bits on
  (u8 *)[6] (bnc#1012628).
- Revert "s390/qeth: use Read device to query hypervisor for MAC"
  (bnc#1012628).
- IB/mlx5: Avoid dealing with vport representors if not being
  e-switch manager (bnc#1012628).
- i40e: split XDP_TX tail and XDP_REDIRECT map flushing
  (bnc#1012628).
- enic: do not overwrite error code (bnc#1012628).
- xen-netfront: Update features after registering netdev
  (bnc#1012628).
- xen-netfront: Fix mismatched rtnl_unlock (bnc#1012628).
- nfp: reject binding to shared blocks (bnc#1012628).
- net: use dev_change_tx_queue_len() for SIOCSIFTXQLEN
  (bnc#1012628).
- net: macb: initialize bp->queues[0].bp for at91rm9200
  (bnc#1012628).
- nfp: flower: fix mpls ether type detection (bnc#1012628).
- hinic: reset irq affinity before freeing irq (bnc#1012628).
- VSOCK: fix loopback on big-endian systems (bnc#1012628).
- vhost_net: validate sock before trying to put its fd
  (bnc#1012628).
- tcp: prevent bogus FRTO undos with non-SACK flows (bnc#1012628).
- tcp: fix Fast Open key endianness (bnc#1012628).
- strparser: Remove early eaten to fix full tcp receive buffer
  stall (bnc#1012628).
- stmmac: fix DMA channel hang in half-duplex mode (bnc#1012628).
- s390/qeth: don't clobber buffer on async TX completion
  (bnc#1012628).
- r8152: napi hangup fix after disconnect (bnc#1012628).
- qmi_wwan: add support for the Dell Wireless 5821e module
  (bnc#1012628).
- qed: Limit msix vectors in kdump kernel to the minimum required
  count (bnc#1012628).
- qed: Fix use of incorrect size in memcpy call (bnc#1012628).
- qed: Fix setting of incorrect eswitch mode (bnc#1012628).
- qede: Adverstise software timestamp caps when PHC is not
  available (bnc#1012628).
- net/tcp: Fix socket lookups with SO_BINDTODEVICE (bnc#1012628).
- net: sungem: fix rx checksum support (bnc#1012628).
- net_sched: blackhole: tell upper qdisc about dropped packets
  (bnc#1012628).
- net/sched: act_ife: preserve the action control in case of error
  (bnc#1012628).
- net/sched: act_ife: fix recursive lock and idr leak
  (bnc#1012628).
- net/packet: fix use-after-free (bnc#1012628).
- net: mvneta: fix the Rx desc DMA address in the Rx path
  (bnc#1012628).
- net/mlx5: Fix wrong size allocation for QoS ETC TC regitster
  (bnc#1012628).
- net/mlx5: Fix required capability for manipulating MPFS
  (bnc#1012628).
- net/mlx5: Fix incorrect raw command length parsing
  (bnc#1012628).
- net/mlx5: Fix command interface race in polling mode
  (bnc#1012628).
- net/mlx5: E-Switch, Avoid setup attempt if not being e-switch
  manager (bnc#1012628).
- net/mlx5e: Don't attempt to dereference the ppriv struct if
  not being eswitch manager (bnc#1012628).
- net/mlx5e: Avoid dealing with vport representors if not being
  e-switch manager (bnc#1012628).
- net: macb: Fix ptp time adjustment for large negative delta
  (bnc#1012628).
- net: fix use-after-free in GRO with ESP (bnc#1012628).
- net: dccp: switch rx_tstamp_last_feedback to monotonic clock
  (bnc#1012628).
- net: dccp: avoid crash in ccid3_hc_rx_send_feedback()
  (bnc#1012628).
- ixgbe: split XDP_TX tail and XDP_REDIRECT map flushing
  (bnc#1012628).
- ipvlan: fix IFLA_MTU ignored on NEWLINK (bnc#1012628).
- ipv6: sr: fix passing wrong flags to crypto_alloc_shash()
  (bnc#1012628).
- hv_netvsc: split sub-channel setup into async and sync
  (bnc#1012628).
- atm: zatm: Fix potential Spectre v1 (bnc#1012628).
- atm: Preserve value of skb->truesize when accounting to vcc
  (bnc#1012628).
- alx: take rtnl before calling __alx_open from resume
  (bnc#1012628).
- pinctrl: mt7622: fix a kernel panic when gpio-hog is being
  applied (bnc#1012628).
- pinctrl: mt7622: stop using the deprecated
  pinctrl_add_gpio_range (bnc#1012628).
- pinctrl: mt7622: fix error path on failing at groups building
  (bnc#1012628).
- pinctrl: sh-pfc: r8a77970: remove SH_PFC_PIN_CFG_DRIVE_STRENGTH
  flag (bnc#1012628).
- x86/paravirt: Make native_save_fl() extern inline (bnc#1012628).
- x86/asm: Add _ASM_ARG* constants for argument registers to
  <asm/asm.h> (bnc#1012628).
- compiler-gcc.h: Add __attribute__((gnu_inline)) to all inline
  declarations (bnc#1012628).
- commit 059e5b8
* Sun Jul 22 2018 tiwai@suse.de
- rpm/kernel-source.spec.in: require bc for kernel-source
  This is needed for building include/generated/timeconst.h from
  kernel/time/timeconst.bc.
- commit d725e3b
* Wed Jul 18 2018 jslaby@suse.cz
- Linux 4.17.8 (bnc#1012628).
- commit 38e4cdc
* Tue Jul 17 2018 tiwai@suse.de
- Update config files: enable CONFIG_I2C_PXA for arm64 (bsc#1101465)
- commit d02f285
* Tue Jul 17 2018 jslaby@suse.cz
- mm: don't do zero_resv_unavail if memmap is not allocated
  (stable fix).
- commit 9c2de41
* Tue Jul 17 2018 jslaby@suse.cz
- Linux 4.17.7 (bnc#1012628).
- bpf: reject passing modified ctx to helper functions
  (bnc#1012628).
- MIPS: Call dump_stack() from show_regs() (bnc#1012628).
- MIPS: Use async IPIs for arch_trigger_cpumask_backtrace()
  (bnc#1012628).
- MIPS: Fix ioremap() RAM check (bnc#1012628).
- drm/etnaviv: Check for platform_device_register_simple()
  failure (bnc#1012628).
- drm/etnaviv: Fix driver unregistering (bnc#1012628).
- drm/etnaviv: bring back progress check in job timeout handler
  (bnc#1012628).
- mmc: sdhci-esdhc-imx: allow 1.8V modes without 100/200MHz
  pinctrl states (bnc#1012628).
- mmc: dw_mmc: fix card threshold control configuration
  (bnc#1012628).
- mmc: renesas_sdhi_internal_dmac: Cannot clear the RX_IN_USE
  in abort (bnc#1012628).
- ibmasm: don't write out of bounds in read handler (bnc#1012628).
- staging: rtl8723bs: Prevent an underflow in
  rtw_check_beacon_data() (bnc#1012628).
- staging: r8822be: Fix RTL8822be can't find any wireless AP
  (bnc#1012628).
- ata: Fix ZBC_OUT command block check (bnc#1012628).
- ata: Fix ZBC_OUT all bit handling (bnc#1012628).
- mei: discard messages from not connected client during power
  down (bnc#1012628).
- mtd: spi-nor: cadence-quadspi: Fix direct mode write timeouts
  (bnc#1012628).
- tracing/kprobe: Release kprobe print_fmt properly (bnc#1012628).
- vmw_balloon: fix inflation with batching (bnc#1012628).
- ahci: Add Intel Ice Lake LP PCI ID (bnc#1012628).
- ahci: Disable LPM on Lenovo 50 series laptops with a too old
  BIOS (bnc#1012628).
- thunderbolt: Notify userspace when boot_acl is changed
  (bnc#1012628).
- USB: serial: ch341: fix type promotion bug in ch341_control_in()
  (bnc#1012628).
- USB: serial: cp210x: add another USB ID for Qivicon ZigBee stick
  (bnc#1012628).
- USB: serial: keyspan_pda: fix modem-status error handling
  (bnc#1012628).
- USB: yurex: fix out-of-bounds uaccess in read handler
  (bnc#1012628).
- USB: serial: mos7840: fix status-register error handling
  (bnc#1012628).
- usb: quirks: add delay quirks for Corsair Strafe (bnc#1012628).
- xhci: xhci-mem: off by one in xhci_stream_id_to_ring()
  (bnc#1012628).
- Fix up non-directory creation in SGID directories (bnc#1012628).
- mm: zero unavailable pages before memmap init (bnc#1012628).
- ALSA: hda/realtek - two more lenovo models need fixup of
  MIC_LOCATION (bnc#1012628).
- ALSA: hda - Handle pm failure during hotplug (bnc#1012628).
- mm: do not drop unused pages when userfaultd is running
  (bnc#1012628).
- fs/proc/task_mmu.c: fix Locked field in /proc/pid/smaps*
  (bnc#1012628).
- x86/purgatory: add missing FORCE to Makefile target
  (bnc#1012628).
- fs, elf: make sure to page align bss in load_elf_library
  (bnc#1012628).
- mm: do not bug_on on incorrect length in __mm_populate()
  (bnc#1012628).
- tracing: Reorder display of TGID to be after PID (bnc#1012628).
- kbuild: delete INSTALL_FW_PATH from kbuild documentation
  (bnc#1012628).
- acpi, nfit: Fix scrub idle detection (bnc#1012628).
- arm64: neon: Fix function may_use_simd() return error status
  (bnc#1012628).
- tools build: fix # escaping in .cmd files for future Make
  (bnc#1012628).
- IB/hfi1: Fix incorrect mixing of ERR_PTR and NULL return values
  (bnc#1012628).
- i2c: tegra: Fix NACK error handling (bnc#1012628).
- i2c: recovery: if possible send STOP with recovery pulses
  (bnc#1012628).
- iw_cxgb4: correctly enforce the max reg_mr depth (bnc#1012628).
- xen: remove global bit from __default_kernel_pte_mask for pv
  guests (bnc#1012628).
- xen: setup pv irq ops vector earlier (bnc#1012628).
- bsg: fix bogus EINVAL on non-data commands (bnc#1012628).
- crypto: x86/salsa20 - remove x86 salsa20 implementations
  (bnc#1012628).
- uprobes/x86: Remove incorrect WARN_ON() in uprobe_init_insn()
  (bnc#1012628).
- netfilter: nf_queue: augment nfqa_cfg_policy (bnc#1012628).
- crypto: don't optimize keccakf() (bnc#1012628).
- netfilter: x_tables: initialise match/target check parameter
  struct (bnc#1012628).
- loop: add recursion validation to LOOP_CHANGE_FD (bnc#1012628).
- xfs: fix inobt magic number check (bnc#1012628).
- PM / hibernate: Fix oops at snapshot_write() (bnc#1012628).
- RDMA/ucm: Mark UCM interface as BROKEN (bnc#1012628).
- loop: remember whether sysfs_create_group() was done
  (bnc#1012628).
- kvm: vmx: Nested VM-entry prereqs for event inj (bnc#1012628).
- f2fs: give message and set need_fsck given broken node id
  (bnc#1012628).
- f2fs: avoid bug_on on corrupted inode (bnc#1012628).
- f2fs: sanity check on sit entry (bnc#1012628).
- f2fs: sanity check for total valid node blocks (bnc#1012628).
- ARM: dts: armada-38x: use the new thermal binding (bnc#1012628).
- commit 7a74fb0
* Mon Jul 16 2018 rgoldwyn@suse.com
- apparmor: patch to provide compatibility with v2.x net rules (bsc#1100944).
- Delete patches.suse/0001-AppArmor-basic-networking-rules.patch.
- Delete
  patches.suse/0002-apparmor-update-apparmor-basic-networking-rules-for-.patch.
- Delete
  patches.suse/0003-apparmor-Fix-quieting-of-audit-messages-for-network-.patch.
- Delete patches.suse/apparmor-check-all-net-profiles.patch.
- commit 1947b35
* Mon Jul 16 2018 msuchanek@suse.de
- Pass x86 as architecture on x86_64 and i386 (bsc#1093118).
- commit 5f24fb0
* Mon Jul 16 2018 msuchanek@suse.de
- Revert "kconfig: only write '# CONFIG_FOO is not set' for
  visible symbols" (bsc#1093118).
- commit 2b9e26a
* Mon Jul 16 2018 mkubecek@suse.cz
- Update to 4.18-rc5
- commit b3f752f
* Wed Jul 11 2018 jslaby@suse.cz
- Linux 4.17.6 (bnc#1012628).
- userfaultfd: hugetlbfs: fix userfaultfd_huge_must_wait()
  pte access (bnc#1012628).
- mm: hugetlb: yield when prepping struct pages (bnc#1012628).
- mm: teach dump_page() to correctly output poisoned struct pages
  (bnc#1012628).
- PCI / ACPI / PM: Resume bridges w/o drivers on suspend-to-RAM
  (bnc#1012628).
- ACPICA: Drop leading newlines from error messages (bnc#1012628).
- ACPI / battery: Safe unregistering of hooks (bnc#1012628).
- drm/amdgpu: Make struct amdgpu_atif private to amdgpu_acpi.c
  (bnc#1012628).
- tracing: Avoid string overflow (bnc#1012628).
- tracing: Fix missing return symbol in function_graph output
  (bnc#1012628).
- scsi: sg: mitigate read/write abuse (bnc#1012628).
- scsi: aacraid: Fix PD performance regression over incorrect
  qd being set (bnc#1012628).
- scsi: target: Fix truncated PR-in ReadKeys response
  (bnc#1012628).
- drbd: fix access after free (bnc#1012628).
- vfio: Use get_user_pages_longterm correctly (bnc#1012628).
- ARM: dts: imx51-zii-rdu1: fix touchscreen pinctrl (bnc#1012628).
- ARM: dts: omap3: Fix am3517 mdio and emac clock references
  (bnc#1012628).
- ARM: dts: dra7: Disable metastability workaround for USB2
  (bnc#1012628).
- cifs: Fix use after free of a mid_q_entry (bnc#1012628).
- cifs: Fix memory leak in smb2_set_ea() (bnc#1012628).
- cifs: Fix slab-out-of-bounds in send_set_info() on SMB2 ACE
  setting (bnc#1012628).
- cifs: Fix infinite loop when using hard mount option
  (bnc#1012628).
- drm: Use kvzalloc for allocating blob property memory
  (bnc#1012628).
- drm/udl: fix display corruption of the last line (bnc#1012628).
- drm/amdgpu: Add amdgpu_atpx_get_dhandle() (bnc#1012628).
- drm/amdgpu: Dynamically probe for ATIF handle (v2)
  (bnc#1012628).
- jbd2: don't mark block as modified if the handle is out of
  credits (bnc#1012628).
- ext4: add corruption check in ext4_xattr_set_entry()
  (bnc#1012628).
- ext4: always verify the magic number in xattr blocks
  (bnc#1012628).
- ext4: make sure bitmaps and the inode table don't overlap with
  bg descriptors (bnc#1012628).
- ext4: always check block group bounds in
  ext4_init_block_bitmap() (bnc#1012628).
- ext4: only look at the bg_flags field if it is valid
  (bnc#1012628).
- ext4: verify the depth of extent tree in ext4_find_extent()
  (bnc#1012628).
- ext4: include the illegal physical block in the bad map
  ext4_error msg (bnc#1012628).
- ext4: clear i_data in ext4_inode_info when removing inline data
  (bnc#1012628).
- ext4: never move the system.data xattr out of the inode body
  (bnc#1012628).
- ext4: avoid running out of journal credits when appending to
  an inline file (bnc#1012628).
- ext4: add more inode number paranoia checks (bnc#1012628).
- ext4: add more mount time checks of the superblock
  (bnc#1012628).
- ext4: check superblock mapped prior to committing (bnc#1012628).
- HID: i2c-hid: Fix "incomplete report" noise (bnc#1012628).
- HID: hiddev: fix potential Spectre v1 (bnc#1012628).
- HID: debug: check length before copy_to_user() (bnc#1012628).
- HID: core: allow concurrent registration of drivers
  (bnc#1012628).
- i2c: core: smbus: fix a potential missing-check bug
  (bnc#1012628).
- i2c: smbus: kill memory leak on emulated and failed DMA SMBus
  xfers (bnc#1012628).
- fs: allow per-device dax status checking for filesystems
  (bnc#1012628).
- dax: change bdev_dax_supported() to support boolean returns
  (bnc#1012628).
- dax: check for QUEUE_FLAG_DAX in bdev_dax_supported()
  (bnc#1012628).
- dm: prevent DAX mounts if not supported (bnc#1012628).
- mtd: cfi_cmdset_0002: Change definition naming to retry write
  operation (bnc#1012628).
- mtd: cfi_cmdset_0002: Change erase functions to retry for error
  (bnc#1012628).
- mtd: cfi_cmdset_0002: Change erase functions to check chip
  good only (bnc#1012628).
- netfilter: nf_log: don't hold nf_log_mutex during user access
  (bnc#1012628).
- staging: comedi: quatech_daqp_cs: fix no-op loop
  daqp_ao_insn_write() (bnc#1012628).
- Revert mm/vmstat.c: fix vmstat_update() preemption BUG
  (bnc#1012628).
- commit 8a8b6ec
* Mon Jul  9 2018 tiwai@suse.de
- alarmtimer: Prevent overflow for relative nanosleep
  (CVE-2018-13053 bsc#1099924).
- commit e98ba10
* Mon Jul  9 2018 mkubecek@suse.cz
- Update to 4.18-rc4
- Eliminated 1 patch
- Config changes:
  - s390x:
  - RSEQ=y
  - DEBUG_REQ=n
- commit 36e98dd
* Mon Jul  9 2018 jslaby@suse.cz
- Linux 4.17.5 (bnc#1012628).
- ARM: dts: imx6q: Use correct SDMA script for SPI5 core
  (bnc#1012628).
- x86/mm: Don't free P4D table when it is folded at runtime
  (bnc#1012628).
- ARM64: dts: meson-gxl-s905x-p212: Add phy-supply for usb0
  (bnc#1012628).
- netfilter: nf_tables: use WARN_ON_ONCE instead of BUG_ON in
  nft_do_chain() (bnc#1012628).
- netfilter: xt_connmark: fix list corruption on rmmod
  (bnc#1012628).
- netfilter: ip6t_rpfilter: provide input interface for route
  lookup (bnc#1012628).
- drm/i915: Enable provoking vertex fix on Gen9 systems
  (bnc#1012628).
- drm/i915: Turn off g4x DP port in .post_disable() (bnc#1012628).
- drm/i915: Disallow interlaced modes on g4x DP outputs
  (bnc#1012628).
- drm/i915: Fix PIPESTAT irq ack on i965/g4x (bnc#1012628).
- drm/i915: Allow DBLSCAN user modes with eDP/LVDS/DSI
  (bnc#1012628).
- drm/amd/display: release spinlock before committing updates
  to stream (bnc#1012628).
- drm/amdgpu: Count disabled CRTCs in commit tail earlier
  (bnc#1012628).
- drm/amdgpu: GPU vs CPU page size fixes in
  amdgpu_vm_bo_split_mapping (bnc#1012628).
- drm/amdgpu: Update pin_size values before unpinning BO
  (bnc#1012628).
- drm/amdgpu: Make amdgpu_vram_mgr_bo_invisible_size always
  accurate (bnc#1012628).
- drm/amdgpu: Refactor amdgpu_vram_mgr_bo_invisible_size helper
  (bnc#1012628).
- drm/amdgpu: Use kvmalloc_array for allocating VRAM manager
  nodes array (bnc#1012628).
- drm/amdgpu: Don't default to DC support for Kaveri and older
  (bnc#1012628).
- Revert "drm/sun4i: Handle DRM_BUS_FLAG_PIXDATA_*EDGE"
  (bnc#1012628).
- drm/atmel-hlcdc: check stride values in the first plane
  (bnc#1012628).
- drm/qxl: Call qxl_bo_unref outside atomic context (bnc#1012628).
- drm/i915/dp: Send DPCD ON for MST before phy_up (bnc#1012628).
- drm/amd/display: Clear connector's edid pointer (bnc#1012628).
- drm/sti: Depend on OF rather than selecting it (bnc#1012628).
- drm/amdgpu: fix clear_all and replace handling in the VM (v2)
  (bnc#1012628).
- drm/amdgpu: Grab/put runtime PM references in
  atomic_commit_tail() (bnc#1012628).
- drm/amdgpu: fix the missed vcn fw version report (bnc#1012628).
- drm/amdgpu: Add APU support in vi_set_vce_clocks (bnc#1012628).
- drm/amdgpu: Add APU support in vi_set_uvd_clocks (bnc#1012628).
- vt: prevent leaking uninitialized data to userspace via
  /dev/vcs* (bnc#1012628).
- serdev: fix memleak on module unload (bnc#1012628).
- serial: 8250_pci: Remove stalled entries in blacklist
  (bnc#1012628).
- iio: mma8452: Fix ignoring MMA8452_INT_DRDY (bnc#1012628).
- staging: android: ion: Return an ERR_PTR in ion_map_kernel
  (bnc#1012628).
- n_tty: Access echo_* variables carefully (bnc#1012628).
- n_tty: Fix stall at n_tty_receive_char_special() (bnc#1012628).
- xhci: Fix kernel oops in trace_xhci_free_virt_device
  (bnc#1012628).
- usb: typec: ucsi: Fix for incorrect status data issue
  (bnc#1012628).
- usb: typec: ucsi: acpi: Workaround for cache mode issue
  (bnc#1012628).
- acpi: Add helper for deactivating memory region (bnc#1012628).
- usb: typec: tcpm: fix logbuffer index is wrong if _tcpm_log
  is re-entered (bnc#1012628).
- usb: dwc2: fix the incorrect bitmaps for the ports of multi_tt
  hub (bnc#1012628).
- USB: serial: cp210x: add Silicon Labs IDs for Windows Update
  (bnc#1012628).
- USB: serial: cp210x: add CESINEL device ids (bnc#1012628).
- usb: cdc_acm: Add quirk for Uniden UBC125 scanner (bnc#1012628).
- commit 3ff6a16
* Mon Jul  9 2018 tiwai@suse.de
- ACPICA: Clear status of all events when entering S5
  (bsc#1099930).
- commit 0c3e49d
* Wed Jul  4 2018 dsterba@suse.com
- Update patches.suse/btrfs-8447-serialize-subvolume-mounts-with-potentially-mi.patch (bsc#951844 bsc#1024015 bsc#1099745).
  Refresh and update for Tumbleweed. No better patch version yet.
- commit dd5896f
* Tue Jul  3 2018 jslaby@suse.cz
- Linux 4.17.4 (bnc#1012628).
- x86/spectre_v1: Disable compiler optimizations over
  array_index_mask_nospec() (bnc#1012628).
- x86/xen: Add call of speculative_store_bypass_ht_init() to PV
  paths (bnc#1012628).
- x86/platform/UV: Add adjustable set memory block size function
  (bnc#1012628).
- x86/platform/UV: Use new set memory block size function
  (bnc#1012628).
- x86/platform/UV: Add kernel parameter to set memory block size
  (bnc#1012628).
- x86/mce: Improve error message when kernel cannot recover
  (bnc#1012628).
- x86/mce: Check for alternate indication of machine check
  recovery on Skylake (bnc#1012628).
- x86/mce: Fix incorrect "Machine check from unknown source"
  message (bnc#1012628).
- x86/mce: Do not overwrite MCi_STATUS in mce_no_way_out()
  (bnc#1012628).
- x86: Call fixup_exception() before notify_die() in math_error()
  (bnc#1012628).
- m68k/mm: Adjust VM area to be unmapped by gap size for
  __iounmap() (bnc#1012628).
- m68k/mac: Fix SWIM memory resource end address (bnc#1012628).
- platform/chrome: cros_ec_lpc: do not try DMI match when ACPI
  device found (bnc#1012628).
- hwmon: (k10temp) Add support for Stoney Ridge and Bristol
  Ridge CPUs (bnc#1012628).
- serial: sh-sci: Use spin_{try}lock_irqsave instead of open
  coding version (bnc#1012628).
- signal/xtensa: Consistenly use SIGBUS in do_unaligned_user
  (bnc#1012628).
- PM / Domains: Fix error path during attach in genpd
  (bnc#1012628).
- PCI / PM: Do not clear state_saved for devices that remain
  suspended (bnc#1012628).
- ACPI / LPSS: Avoid PM quirks on suspend and resume from S3
  (bnc#1012628).
- PM / core: Fix supplier device runtime PM usage counter
  imbalance (bnc#1012628).
- PM / OPP: Update voltage in case freq == old_freq (bnc#1012628).
- mmc: renesas_sdhi: really fix WP logic regressions
  (bnc#1012628).
- usb: do not reset if a low-speed or full-speed device timed out
  (bnc#1012628).
- 1wire: family module autoload fails because of upper/lower
  case mismatch (bnc#1012628).
- ASoC: dapm: delete dapm_kcontrol_data paths list before freeing
  it (bnc#1012628).
- ASoC: cs35l35: Add use_single_rw to regmap config (bnc#1012628).
- ASoC: mediatek: preallocate pages use platform device
  (bnc#1012628).
- ASoC: cirrus: i2s: Fix LRCLK configuration (bnc#1012628).
- ASoC: cirrus: i2s: Fix {TX|RX}LinCtrlData setup (bnc#1012628).
- thermal: bcm2835: Stop using printk format %%pCr (bnc#1012628).
- clk: renesas: cpg-mssr: Stop using printk format %%pCr
  (bnc#1012628).
- lib/vsprintf: Remove atomic-unsafe support for %%pCr
  (bnc#1012628).
- ftrace/selftest: Have the reset_trigger code be a bit more
  careful (bnc#1012628).
- mips: ftrace: fix static function graph tracing (bnc#1012628).
- branch-check: fix long->int truncation when profiling branches
  (bnc#1012628).
- ipmi:bt: Set the timeout before doing a capabilities check
  (bnc#1012628).
- Bluetooth: hci_qca: Avoid missing rampatch failure with
  userspace fw loader (bnc#1012628).
- printk: fix possible reuse of va_list variable (bnc#1012628).
- fuse: fix congested state leak on aborted connections
  (bnc#1012628).
- fuse: atomic_o_trunc should truncate pagecache (bnc#1012628).
- fuse: don't keep dead fuse_conn at fuse_fill_super()
  (bnc#1012628).
- fuse: fix control dir setup and teardown (bnc#1012628).
- powerpc/mm/hash: Add missing isync prior to kernel stack SLB
  switch (bnc#1012628).
- powerpc/pkeys: Detach execute_only key on !PROT_EXEC
  (bnc#1012628).
- powerpc/ptrace: Fix setting 512B aligned breakpoints with
  PTRACE_SET_DEBUGREG (bnc#1012628).
- powerpc/perf: Fix memory allocation for core-imc based on
  num_possible_cpus() (bnc#1012628).
- powerpc/ptrace: Fix enforcement of DAWR constraints
  (bnc#1012628).
- powerpc/powernv/ioda2: Remove redundant free of TCE pages
  (bnc#1012628).
- powerpc/powernv: copy/paste - Mask SO bit in CR (bnc#1012628).
- powerpc/powernv/cpuidle: Init all present cpus for deep states
  (bnc#1012628).
- cpuidle: powernv: Fix promotion from snooze if next state
  disabled (bnc#1012628).
- powerpc/fadump: Unregister fadump on kexec down path
  (bnc#1012628).
- libnvdimm, pmem: Do not flush power-fail protected CPU caches
  (bnc#1012628).
- soc: rockchip: power-domain: Fix wrong value when power up pd
  with writemask (bnc#1012628).
- powerpc/64s/radix: Fix radix_kvm_prefetch_workaround paca
  access of not possible CPU (bnc#1012628).
- powerpc/e500mc: Set assembler machine type to e500mc
  (bnc#1012628).
- powerpc/64s: Fix DT CPU features Power9 DD2.1 logic
  (bnc#1012628).
- cxl: Configure PSL to not use APC virtual machines
  (bnc#1012628).
- cxl: Disable prefault_mode in Radix mode (bnc#1012628).
- ARM: 8764/1: kgdb: fix NUMREGBYTES so that gdb_regs[] is the
  correct size (bnc#1012628).
- ARM: dts: sun8i: h3: fix ALL-H3-CC H3 ver VDD-CPUX voltage
  (bnc#1012628).
- ARM: dts: sun8i: h3: fix ALL-H3-CC H3 ver VCC-1V2 regulator
  voltage (bnc#1012628).
- ARM: dts: Fix SPI node for Arria10 (bnc#1012628).
- ARM: dts: socfpga: Fix NAND controller node compatible
  (bnc#1012628).
- ARM: dts: socfpga: Fix NAND controller clock supply
  (bnc#1012628).
- ARM: dts: socfpga: Fix NAND controller node compatible for
  Arria10 (bnc#1012628).
- hwrng: core - Always drop the RNG in hwrng_unregister()
  (bnc#1012628).
- softirq: Reorder trace_softirqs_on to prevent lockdep splat
  (bnc#1012628).
- arm64: Fix syscall restarting around signal suppressed by tracer
  (bnc#1012628).
- crypto: arm64/aes-blk - fix and move skcipher_walk_done out
  of kernel_neon_begin, _end (bnc#1012628).
- arm64: kpti: Use early_param for kpti= command-line option
  (bnc#1012628).
- arm64: mm: Ensure writes to swapper are ordered wrt subsequent
  cache maintenance (bnc#1012628).
- arm64: dts: marvell: fix CP110 ICU node size (bnc#1012628).
- arm64: dts: stratix10: Fix SPI nodes for Stratix10
  (bnc#1012628).
- ARM64: dts: meson: disable sd-uhs modes on the libretech-cc
  (bnc#1012628).
- ARM64: dts: meson-gx: fix ATF reserved memory region
  (bnc#1012628).
- of: overlay: validate offset from property fixups (bnc#1012628).
- of: unittest: for strings, account for trailing \0 in property
  length field (bnc#1012628).
- of: platform: stop accessing invalid dev in
  of_platform_device_destroy (bnc#1012628).
- tpm: fix use after free in tpm2_load_context() (bnc#1012628).
- tpm: fix race condition in tpm_common_write() (bnc#1012628).
- efi/libstub/tpm: Initialize efi_physical_addr_t vars to zero
  for mixed mode (bnc#1012628).
- IB/qib: Fix DMA api warning with debug kernel (bnc#1012628).
- IB/{hfi1, qib}: Add handling of kernel restart (bnc#1012628).
- IB/mlx4: Mark user MR as writable if actual virtual memory is
  writable (bnc#1012628).
- IB/core: Make testing MR flags for writability a static inline
  function (bnc#1012628).
- IB/mlx5: Fetch soft WQE's on fatal error state (bnc#1012628).
- IB/isert: Fix for lib/dma_debug check_sync warning
  (bnc#1012628).
- IB/isert: fix T10-pi check mask setting (bnc#1012628).
- IB/hfi1: Fix fault injection init/exit issues (bnc#1012628).
- IB/hfi1: Reorder incorrect send context disable (bnc#1012628).
- IB/hfi1: Optimize kthread pointer locking when queuing CQ
  entries (bnc#1012628).
- IB/hfi1: Fix user context tail allocation for DMA_RTAIL
  (bnc#1012628).
- IB/uverbs: Fix ordering of ucontext check in ib_uverbs_write
  (bnc#1012628).
- RDMA/mlx4: Discard unknown SQP work requests (bnc#1012628).
- xprtrdma: Return -ENOBUFS when no pages are available
  (bnc#1012628).
- RDMA/core: Save kernel caller name when creating CQ using
  ib_create_cq() (bnc#1012628).
- mtd: rawnand: Do not check FAIL bit when executing a
  SET_FEATURES op (bnc#1012628).
- mtd: cfi_cmdset_0002: Change write buffer to check correct value
  (bnc#1012628).
- mtd: rawnand: denali_dt: set clk_x_rate to 200 MHz
  unconditionally (bnc#1012628).
- mtd: rawnand: fix return value check for bad block status
  (bnc#1012628).
- mtd: rawnand: mxc: set spare area size register explicitly
  (bnc#1012628).
- mtd: rawnand: micron: add ONFI_FEATURE_ON_DIE_ECC to supported
  features (bnc#1012628).
- mtd: rawnand: All AC chips have a broken GET_FEATURES(TIMINGS)
  (bnc#1012628).
- mtd: cfi_cmdset_0002: Use right chip in do_ppb_xxlock()
  (bnc#1012628).
- mtd: cfi_cmdset_0002: fix SEGV unlocking multiple chips
  (bnc#1012628).
- mtd: cfi_cmdset_0002: Fix unlocking requests crossing a chip
  boudary (bnc#1012628).
- mtd: cfi_cmdset_0002: Avoid walking all chips when unlocking
  (bnc#1012628).
- MIPS: BCM47XX: Enable 74K Core ExternalSync for PCIe erratum
  (bnc#1012628).
- clk:aspeed: Fix reset bits for PCI/VGA and PECI (bnc#1012628).
- PCI: hv: Make sure the bus domain is really unique
  (bnc#1012628).
- PCI: Add ACS quirk for Intel 7th & 8th Gen mobile (bnc#1012628).
- PCI: Add ACS quirk for Intel 300 series (bnc#1012628).
- PCI: pciehp: Clear Presence Detect and Data Link Layer Status
  Changed on resume (bnc#1012628).
- PCI: Account for all bridges on bus when distributing bus
  numbers (bnc#1012628).
- auxdisplay: fix broken menu (bnc#1012628).
- pinctrl: armada-37xx: Fix spurious irq management (bnc#1012628).
- pinctrl: samsung: Correct EINTG banks order (bnc#1012628).
- pinctrl: devicetree: Fix pctldev pointer overwrite
  (bnc#1012628).
- cpufreq: intel_pstate: Fix scaling max/min limits with Turbo
  3.0 (bnc#1012628).
- MIPS: pb44: Fix i2c-gpio GPIO descriptor table (bnc#1012628).
- MIPS: io: Add barrier after register read in inX()
  (bnc#1012628).
- time: Make sure jiffies_to_msecs() preserves non-zero time
  periods (bnc#1012628).
- irqchip/gic-v3-its: Don't bind LPI to unavailable NUMA node
  (bnc#1012628).
- locking/rwsem: Fix up_read_non_owner() warning with DEBUG_RWSEMS
  (bnc#1012628).
- X.509: unpack RSA signatureValue field from BIT STRING
  (bnc#1012628).
- Btrfs: fix return value on rename exchange failure
  (bnc#1012628).
- iio: adc: ad7791: remove sample freq sysfs attributes
  (bnc#1012628).
- iio: sca3000: Fix an error handling path in 'sca3000_probe()'
  (bnc#1012628).
- mm: fix __gup_device_huge vs unmap (bnc#1012628).
- scsi: scsi_debug: Fix memory leak on module unload
  (bnc#1012628).
- scsi: hpsa: disable device during shutdown (bnc#1012628).
- scsi: qla2xxx: Delete session for nport id change (bnc#1012628).
- scsi: qla2xxx: Fix setting lower transfer speed if GPSC fails
  (bnc#1012628).
- scsi: qla2xxx: Mask off Scope bits in retry delay (bnc#1012628).
- scsi: qla2xxx: Spinlock recursion in qla_target (bnc#1012628).
- scsi: zfcp: fix missing SCSI trace for result of
  eh_host_reset_handler (bnc#1012628).
- scsi: zfcp: fix missing SCSI trace for retry of abort /
  scsi_eh TMF (bnc#1012628).
- scsi: zfcp: fix misleading REC trigger trace where erp_action
  setup failed (bnc#1012628).
- scsi: zfcp: fix missing REC trigger trace on terminate_rport_io
  early return (bnc#1012628).
- scsi: zfcp: fix missing REC trigger trace on terminate_rport_io
  for ERP_FAILED (bnc#1012628).
- scsi: zfcp: fix missing REC trigger trace for all objects in
  ERP_FAILED (bnc#1012628).
- scsi: zfcp: fix missing REC trigger trace on enqueue without
  ERP thread (bnc#1012628).
- linvdimm, pmem: Preserve read-only setting for pmem devices
  (bnc#1012628).
- libnvdimm, pmem: Unconditionally deep flush on *sync
  (bnc#1012628).
- clk: meson: meson8b: mark fclk_div2 gate clocks as
  CLK_IS_CRITICAL (bnc#1012628).
- clk: at91: PLL recalc_rate() now using cached MUL and DIV values
  (bnc#1012628).
- rtc: sun6i: Fix bit_idx value for clk_register_gate
  (bnc#1012628).
- md: fix two problems with setting the "re-add" device state
  (bnc#1012628).
- rpmsg: smd: do not use mananged resources for endpoints and
  channels (bnc#1012628).
- ubi: fastmap: Cancel work upon detach (bnc#1012628).
- ubi: fastmap: Correctly handle interrupted erasures in EBA
  (bnc#1012628).
- UBIFS: Fix potential integer overflow in allocation
  (bnc#1012628).
- backlight: as3711_bl: Fix Device Tree node lookup (bnc#1012628).
- backlight: max8925_bl: Fix Device Tree node lookup
  (bnc#1012628).
- backlight: tps65217_bl: Fix Device Tree node lookup
  (bnc#1012628).
- Revert "iommu/amd_iommu: Use CONFIG_DMA_DIRECT_OPS=y and
  dma_direct_{alloc,free}()" (bnc#1012628).
- f2fs: don't use GFP_ZERO for page caches (bnc#1012628).
- um: Fix initialization of vector queues (bnc#1012628).
- um: Fix raw interface options (bnc#1012628).
- mfd: twl-core: Fix clock initialization (bnc#1012628).
- mfd: intel-lpss: Program REMAP register in PIO mode
  (bnc#1012628).
- mfd: intel-lpss: Fix Intel Cannon Lake LPSS I2C input clock
  (bnc#1012628).
- remoteproc: Prevent incorrect rproc state on xfer mem ownership
  failure (bnc#1012628).
- arm: dts: mt7623: fix invalid memory node being generated
  (bnc#1012628).
- perf tools: Fix symbol and object code resolution for vdso32
  and vdsox32 (bnc#1012628).
- perf intel-pt: Fix sync_switch INTEL_PT_SS_NOT_TRACING
  (bnc#1012628).
- perf intel-pt: Fix decoding to accept CBR between FUP and
  corresponding TIP (bnc#1012628).
- perf intel-pt: Fix MTC timing after overflow (bnc#1012628).
- perf intel-pt: Fix "Unexpected indirect branch" error
  (bnc#1012628).
- perf intel-pt: Fix packet decoding of CYC packets (bnc#1012628).
- media: vsp1: Release buffers for each video node (bnc#1012628).
- media: cx231xx: Ignore an i2c mux adapter (bnc#1012628).
- media: v4l2-compat-ioctl32: prevent go past max size
  (bnc#1012628).
- media: cx231xx: Add support for AverMedia DVD EZMaker 7
  (bnc#1012628).
- media: rc: mce_kbd decoder: fix stuck keys (bnc#1012628).
- media: dvb_frontend: fix locking issues at
  dvb_frontend_get_event() (bnc#1012628).
- nfsd: restrict rd_maxcount to svc_max_payload in
  nfsd_encode_readdir (bnc#1012628).
- NFSv4: Fix possible 1-byte stack overflow in
  nfs_idmap_read_and_verify_message (bnc#1012628).
- NFSv4: Revert commit 5f83d86cf531d ("NFSv4.x: Fix wraparound
  issues..") (bnc#1012628).
- NFSv4: Fix a typo in nfs41_sequence_process (bnc#1012628).
- video: uvesafb: Fix integer overflow in allocation
  (bnc#1012628).
- ACPI / LPSS: Add missing prv_offset setting for byt/cht PWM
  devices (bnc#1012628).
- Input: silead - add MSSL0002 ACPI HID (bnc#1012628).
- Input: elan_i2c - add ELAN0618 (Lenovo v330 15IKB) ACPI ID
  (bnc#1012628).
- pwm: lpss: platform: Save/restore the ctrl register over a
  suspend/resume (bnc#1012628).
- rbd: flush rbd_dev->watch_dwork after watch is unregistered
  (bnc#1012628).
- mm/ksm.c: ignore STABLE_FLAG of rmap_item->address in
  rmap_walk_ksm() (bnc#1012628).
- mm: fix devmem_is_allowed() for sub-page System RAM
  intersections (bnc#1012628).
- xen: Remove unnecessary BUG_ON from __unbind_from_irq()
  (bnc#1012628).
- net: ethernet: fix suspend/resume in davinci_emac (bnc#1012628).
- udf: Detect incorrect directory size (bnc#1012628).
- Input: xpad - fix GPD Win 2 controller name (bnc#1012628).
- Input: elan_i2c_smbus - fix more potential stack buffer
  overflows (bnc#1012628).
- Input: elantech - enable middle button of touchpads on ThinkPad
  P52 (bnc#1012628).
- Input: elantech - fix V4 report decoding for module with middle
  key (bnc#1012628).
- ALSA: timer: Fix UBSAN warning at SNDRV_TIMER_IOCTL_NEXT_DEVICE
  ioctl (bnc#1012628).
- ALSA: hda - Force to link down at runtime suspend on ATI/AMD
  HDMI (bnc#1012628).
- ALSA: hda/realtek - Fix pop noise on Lenovo P50 & co
  (bnc#1012628).
- ALSA: hda/realtek - Add a quirk for FSC ESPRIMO U9210
  (bnc#1012628).
- ALSA: hda/realtek - Fix the problem of two front mics on more
  machines (bnc#1012628).
- Revert "i2c: algo-bit: init the bus to a known state"
  (bnc#1012628).
- i2c: gpio: initialize SCL to HIGH again (bnc#1012628).
- slub: fix failure when we delete and create a slab cache
  (bnc#1012628).
- kasan: depend on CONFIG_SLUB_DEBUG (bnc#1012628).
- dm: use bio_split() when splitting out the already processed
  bio (bnc#1012628).
- pmem: only set QUEUE_FLAG_DAX for fsdax mode (bnc#1012628).
- block: Fix transfer when chunk sectors exceeds max
  (bnc#1012628).
- block: Fix cloning of requests with a special payload
  (bnc#1012628).
- x86/e820: put !E820_TYPE_RAM regions into memblock.reserved
  (bnc#1012628).
- selinux: move user accesses in selinuxfs out of locked regions
  (bnc#1012628).
- x86/entry/64/compat: Fix "x86/entry/64/compat: Preserve r8-r11
  in int $0x80" (bnc#1012628).
- x86/efi: Fix efi_call_phys_epilog() with CONFIG_X86_5LEVEL=y
  (bnc#1012628).
- dm zoned: avoid triggering reclaim from inside dmz_map()
  (bnc#1012628).
- dm thin: handle running out of data space vs concurrent discard
  (bnc#1012628).
- virt: vbox: Only copy_from_user the request-header once
  (bnc#1012628).
- commit 882c99b
* Mon Jul  2 2018 mkubecek@suse.cz
- Update to 4.18-rc3
- Eliminated 6 patches
- Config changes:
  - Input:
  - INPUT_SC27XX_VIBRA=m (aarch64 only)
- commit d44a642
* Fri Jun 29 2018 jslaby@suse.cz
- Refresh
  patches.suse/input-psmouse-fix-button-reporting-for-basic-protoco.patch.
  Update upstream status.
- commit 3037396
* Wed Jun 27 2018 mkubecek@suse.cz
- bpf: enforce correct alignment for instructions (bsc#1099078).
- commit 55e3263
* Tue Jun 26 2018 tiwai@suse.de
- media: uvcvideo: Support realtek's UVC 1.5 device (bsc#1099109).
- commit 7c619f0
* Tue Jun 26 2018 tiwai@suse.de
- tracing: Check for no filter when processing event filters
  (CVE-2018-12714,bsc#1098933).
- commit 5b8d655
* Tue Jun 26 2018 jslaby@suse.cz
- Linux 4.17.3 (bnc#1012628).
- net: aquantia: fix unsigned numvecs comparison with less than
  zero (bnc#1012628).
- bonding: re-evaluate force_primary when the primary slave name
  changes (bnc#1012628).
- cdc_ncm: avoid padding beyond end of skb (bnc#1012628).
- ipv6: allow PMTU exceptions to local routes (bnc#1012628).
- net: dsa: add error handling for pskb_trim_rcsum (bnc#1012628).
- net: phy: dp83822: use BMCR_ANENABLE instead of BMSR_ANEGCAPABLE
  for DP83620 (bnc#1012628).
- net/sched: act_simple: fix parsing of TCA_DEF_DATA
  (bnc#1012628).
- tcp: verify the checksum of the first data segment in a new
  connection (bnc#1012628).
- tls: fix use-after-free in tls_push_record (bnc#1012628).
- tls: fix waitall behavior in tls_sw_recvmsg (bnc#1012628).
- udp: fix rx queue len reported by diag and proc interface
  (bnc#1012628).
- net: in virtio_net_hdr only add VLAN_HLEN to csum_start if
  payload holds vlan (bnc#1012628).
- hv_netvsc: Fix a network regression after ifdown/ifup
  (bnc#1012628).
- ext4: fix hole length detection in ext4_ind_map_blocks()
  (bnc#1012628).
- ext4: update mtime in ext4_punch_hole even if no blocks are
  released (bnc#1012628).
- ext4: do not allow external inodes for inline data
  (bnc#1012628).
- ext4: bubble errors from ext4_find_inline_data_nolock() up to
  ext4_iget() (bnc#1012628).
- ext4: correctly handle a zero-length xattr with a non-zero
  e_value_offs (bnc#1012628).
- ext4: fix fencepost error in check for inode count overflow
  during resize (bnc#1012628).
- driver core: Don't ignore class_dir_create_and_add() failure
  (bnc#1012628).
- Btrfs: allow empty subvol= again (bnc#1012628).
- Btrfs: fix clone vs chattr NODATASUM race (bnc#1012628).
- Btrfs: fix memory and mount leak in btrfs_ioctl_rm_dev_v2()
  (bnc#1012628).
- btrfs: return error value if create_io_em failed in
  cow_file_range (bnc#1012628).
- btrfs: scrub: Don't use inode pages for device replace
  (bnc#1012628).
- ALSA: usb-audio: Disable the quirk for Nura headset
  (bnc#1012628).
- ALSA: hda/realtek - Enable mic-mute hotkey for several Lenovo
  AIOs (bnc#1012628).
- ALSA: hda/conexant - Add fixup for HP Z2 G4 workstation
  (bnc#1012628).
- ALSA: hda - Handle kzalloc() failure in
  snd_hda_attach_pcm_stream() (bnc#1012628).
- ALSA: hda: add dock and led support for HP EliteBook 830 G5
  (bnc#1012628).
- ALSA: hda: add dock and led support for HP ProBook 640 G4
  (bnc#1012628).
- x86/MCE: Fix stack out-of-bounds write in mce-inject.c:
  Flags_read() (bnc#1012628).
- smb3: fix various xid leaks (bnc#1012628).
- smb3: on reconnect set PreviousSessionId field (bnc#1012628).
- CIFS: 511c54a2f69195b28afb9dd119f03787b1625bb4 adds a check
  for session expiry (bnc#1012628).
- cifs: For SMB2 security informaion query, check for minimum
  sized security descriptor instead of sizeof FileAllInformation
  class (bnc#1012628).
- nbd: fix nbd device deletion (bnc#1012628).
- nbd: update size when connected (bnc#1012628).
- nbd: use bd_set_size when updating disk size (bnc#1012628).
- blk-mq: reinit q->tag_set_list entry only after grace period
  (bnc#1012628).
- bdi: Move cgroup bdi_writeback to a dedicated low concurrency
  workqueue (bnc#1012628).
- cpufreq: Fix new policy initialization during limits updates
  via sysfs (bnc#1012628).
- cpufreq: ti-cpufreq: Fix an incorrect error return value
  (bnc#1012628).
- cpufreq: governors: Fix long idle detection logic in load
  calculation (bnc#1012628).
- libata: zpodd: small read overflow in eject_tray()
  (bnc#1012628).
- libata: Drop SanDisk SD7UB3Q*G1001 NOLPM quirk (bnc#1012628).
- nvme/pci: Sync controller reset for AER slot_reset
  (bnc#1012628).
- w1: mxc_w1: Enable clock before calling clk_get_rate() on it
  (bnc#1012628).
- x86/vector: Fix the args of vector_alloc tracepoint
  (bnc#1012628).
- x86/apic/vector: Prevent hlist corruption and leaks
  (bnc#1012628).
- x86/apic: Provide apic_ack_irq() (bnc#1012628).
- x86/ioapic: Use apic_ack_irq() (bnc#1012628).
- x86/platform/uv: Use apic_ack_irq() (bnc#1012628).
- irq_remapping: Use apic_ack_irq() (bnc#1012628).
- genirq/generic_pending: Do not lose pending affinity update
  (bnc#1012628).
- genirq/affinity: Defer affinity setting if irq chip is busy
  (bnc#1012628).
- genirq/migration: Avoid out of line call if pending is not set
  (bnc#1012628).
- x86/intel_rdt: Enable CMT and MBM on new Skylake stepping
  (bnc#1012628).
- media: uvcvideo: Prevent setting unavailable flags
  (bnc#1012628).
- media: rc: ensure input/lirc device can be opened after register
  (bnc#1012628).
- iwlwifi: fw: harden page loading code (bnc#1012628).
- orangefs: set i_size on new symlink (bnc#1012628).
- orangefs: report attributes_mask and attributes for statx
  (bnc#1012628).
- HID: intel_ish-hid: ipc: register more pm callbacks to support
  hibernation (bnc#1012628).
- HID: wacom: Correct logical maximum Y for 2nd-gen Intuos Pro
  large (bnc#1012628).
- fs/binfmt_misc.c: do not allow offset overflow (bnc#1012628).
- mm, page_alloc: do not break __GFP_THISNODE by zonelist reset
  (bnc#1012628).
- commit e8dc1b5
* Tue Jun 26 2018 tiwai@suse.de
- platform/x86: ideapad-laptop: Apply no_hw_rfkill to Y20-15IKBM,
  too (bsc#1098626).
- commit 0d1073f
* Mon Jun 25 2018 jslaby@suse.cz
- Input: psmouse - fix button reporting for basic protocols
  (bnc#1098392).
- commit 7faa585
* Mon Jun 25 2018 msuchanek@suse.de
- rpm/kernel-source.changes.old: Add pre-SLE15 history (bsc#1098995).
- commit 631659e
* Mon Jun 25 2018 msuchanek@suse.de
- Refresh patches.suse/s390-fix-random-crashes-illegal-operation-0001-ilc-1.patch.
- commit ff0a7a4
* Mon Jun 25 2018 bp@suse.de
- vhost: fix info leak due to uninitialized memory (bsc#1092472
  CVE-2018-1118).
- commit 7372950
* Sun Jun 24 2018 mkubecek@suse.cz
- Update to 4.18-rc2
- Eliminated 1 patch
- Config changes:
  - aarch64: reenable DWMAC_SOCFPGA (=m)
- commit cc9e91e
* Sun Jun 24 2018 afaerber@suse.de
- config: arm64: Update to 4.18-rc1
- commit b301d60
* Sat Jun 23 2018 mkubecek@suse.cz
- proc: fix missing final NUL in get_mm_cmdline() rewrite
  (https://www.mail-archive.com/linux-kernel@vger.kernel.org/msg1715032.html).
- commit f348790
* Sat Jun 23 2018 mkubecek@suse.cz
- Documentation: e1000: Fix docs build error.
- Documentation: e100: Fix docs build error.
- Documentation: e1000: Use correct heading adornment.
- Documentation: e100: Use correct heading adornment.
- commit 95284f7
* Sat Jun 23 2018 jslaby@suse.cz
- x86/stacktrace: Do not unwind after user regs (bnc#1058115).
- x86/stacktrace: Remove STACKTRACE_DUMP_ONCE (bnc#1058115).
- x86/stacktrace: Clarify the reliable success paths
  (bnc#1058115).
- x86/stacktrace: Do not fail for ORC with regs on stack
  (bnc#1058115).
- x86/unwind/orc: Detect the end of the stack (bnc#1058115).
- x86/stacktrace: Enable HAVE_RELIABLE_STACKTRACE for the ORC
  unwinder (bnc#1058115).
- Delete
  patches.suse/0001-x86-stacktrace-do-now-unwind-after-user-regs.patch.
- Delete
  patches.suse/0002-x86-stacktrace-make-clear-the-success-paths.patch.
- Delete
  patches.suse/0003-x86-stacktrace-remove-STACKTRACE_DUMP_ONCE-from-__sa.patch.
- Delete
  patches.suse/0004-x86-stacktrace-do-not-fail-for-ORC-with-regs-on-stac.patch.
- Delete
  patches.suse/0005-x86-stacktrace-orc-mark-it-as-reliable.patch.
  Replace the ORC patches by the upstream patches. Finally...
- commit 33a2d86
* Thu Jun 21 2018 msuchanek@suse.de
- s390: Correct register corruption in critical section cleanup
  (boo#1095717).
- commit 4594a9e
* Wed Jun 20 2018 tiwai@suse.de
- ACPICA: AML parser: attempt to continue loading table after
  error (bsc#1098074).
- commit fc39d10
* Mon Jun 18 2018 msuchanek@suse.de
- macros.kernel-source: define linux_arch for KMPs (boo#1098050).
  CONFIG_64BIT is no longer defined so KMP spec files need to include
  %%{?linux_make_arch} in any make call to build modules or descent into
  the kernel directory for any reason.
- commit 5dc40af
* Mon Jun 18 2018 mkubecek@suse.cz
- config: update ppc64le configs
- commit fa9e020
* Mon Jun 18 2018 mkubecek@suse.cz
- config: enable NETDEVSIM (as module)
- commit e218eff
* Mon Jun 18 2018 mkubecek@suse.cz
- Update to 4.18-rc1.
- Eliminated 66 patches (62 stable, 4 other).
- ARM configs need updating.
- Config changes:
  - General:
  - RSEQ=y
  - i386:
  - BPF_JIT=y
  - BPF_JIT_ALWAYS_ON=y
  - powerpc:
  - LD_DEAD_CODE_DATA_ELIMINATION=n (experimental)
  - s390:
  - FW_LOADER_USER_HELPER=y
  - PCI:
  - PCI_HOST_GENERIC=y
  - Network:
  - TLS_DEVICE=y
  - XDP_SOCKETS=y
  - NFT_CONNLIMIT=m
  - NFT_SOCKET=m
  - IP_VS_MH=m
  - IP_VS_MH_TAB_INDEX=12 (default)
  - NF_TPROXY_IPV4=m
  - NF_TPROXY_IPV6=m
  - BPFILTER=y
  - BPFILTER_UMH=m
  - FAILOVER=m
  - MLX5_EN_TLS=y
  - NET_VENDOR_MICROSEMI=y
  - MSCC_OCELOT_SWITCH=m
  - MSCC_OCELOT_SWITCH_OCELOT=m
  - NFP_APP_ABM_NIC=y
  - MDIO_MSCC_MIIM=m
  - ASIX_PHY=m
  - DP83TC811_PHY=m
  - MICROCHIP_T1_PHY=m
  - NET_FAILOVER=m
  - Block:
  - DM_WRITECACHE=m
  - Input:
  - MOUSE_PS2_ELANTECH_SMBUS=y
  - TOUCHSCREEN_CHIPONE_ICN8505=m
  - HID_STEAM=m
  - Misc:
  - SPI_MEM=y
  - GPIOLIB_FASTPATH_LIMIT=512 (default)
  - VIDEO_CADENCE=y
  - LCD_OTM3225A=n
  - CHROMEOS_TBMC=m
  - FPGA_MGR_MACHXO2_SPI=m
  - Graphics:
  - DRM_I2C_NXP_TDA9950=m
  - DRM_I915_DEBUG_GUC=n
  - DRM_CDNS_DSI=n
  - DRM_THINE_THC63LVD1024=n
  - DRM_XEN=y
  - DRM_XEN_FRONTEND=m
  - Sound:
  - SND_SOC_SSM2305=n
  - SND_SOC_TSCS454=n
  - SND_SOC_WM8782=n
  - SND_SOC_MT6351=n
  - SND_XEN_FRONTEND=m
  - LED:
  - LEDS_CR0014114=m
  - LEDS_LM3601X=m
  - USB:
  - TYPEC_RT1711H=m
  - IIO:
  - AD5686_SPI=n
  - AD5696_I2C=n
  - TI_DAC5571=n
  - TSL2772=n
  - IIO_RESCALE=n
  - Filesystems:
  - PROC_VMCORE_DEVICE_DUMP=y
  - EVM_ADD_XATTRS=y
  - Testing:
  - TEST_OVERFLOW=n
  - Crypto:
  - CRYPTO_AEGIS128=m
  - CRYPTO_AEGIS128L=m
  - CRYPTO_AEGIS256=m
  - CRYPTO_AEGIS128_AESNI_SSE2=m
  - CRYPTO_AEGIS128L_AESNI_SSE2=m
  - CRYPTO_AEGIS256_AESNI_SSE2=m
  - CRYPTO_MORUS640=m
  - CRYPTO_MORUS640_SSE2=m
  - CRYPTO_MORUS1280=m
  - CRYPTO_MORUS1280_SSE2=m
  - CRYPTO_MORUS1280_AVX2=m
  - CRYPTO_ZSTD=m
- commit 549a5bb
* Mon Jun 18 2018 mkubecek@suse.cz
- rpm: ignore CONFIG_GCC_VERSION when checking for oldconfig changes
  Since 4.18-rc1, "make oldconfig" writes gcc version and capabilities into
  generated .config. Thus whenever we build the package or run checks with
  different gcc version than used to update config/*/*, check for "outdated
  configs" fails.
  As a quick band-aid, omit the lines with CONFIG_GCC_VERSION from both
  configs before comparing them. This way, the check won't fail unless run
  with newer gcc which would add new capabilities. More robust solution will
  require a wider discussion.
- commit 546ef32
* Sat Jun 16 2018 jslaby@suse.cz
- Revert "mm: relax deferred struct page requirements"
  (bnc#1092466).
- Update config files.
- commit 802b05f
* Sat Jun 16 2018 jslaby@suse.cz
- Linux 4.17.2 (bnc#1012628).
- crypto: omap-sham - fix memleak (bnc#1012628).
- crypto: vmx - Remove overly verbose printk from AES XTS init
  (bnc#1012628).
- crypto: vmx - Remove overly verbose printk from AES init
  routines (bnc#1012628).
- crypto: cavium - Limit result reading attempts (bnc#1012628).
- crypto: cavium - Fix fallout from CONFIG_VMAP_STACK
  (bnc#1012628).
- crypto: caam - fix size of RSA prime factor q (bnc#1012628).
- crypto: caam/qi - fix IV DMA mapping and updating (bnc#1012628).
- crypto: caam - fix IV DMA mapping and updating (bnc#1012628).
- crypto: caam - fix DMA mapping dir for generated IV
  (bnc#1012628).
- crypto: caam - strip input zeros from RSA input buffer
  (bnc#1012628).
- Input: elan_i2c - add ELAN0612 (Lenovo v330 14IKB) ACPI ID
  (bnc#1012628).
- Input: goodix - add new ACPI id for GPD Win 2 touch screen
  (bnc#1012628).
- crypto: ccree - correct host regs offset (bnc#1012628).
- tty: pl011: Avoid spuriously stuck-off interrupts (bnc#1012628).
- arm64: defconfig: Enable CONFIG_PINCTRL_MT7622 by default
  (bnc#1012628).
- doc: fix sysfs ABI documentation (bnc#1012628).
- vmw_balloon: fixing double free when batching mode is off
  (bnc#1012628).
- serial: 8250: omap: Fix idling of clocks for unused uarts
  (bnc#1012628).
- serial: samsung: fix maxburst parameter for DMA transactions
  (bnc#1012628).
- tty/serial: atmel: use port->name as name in request_irq()
  (bnc#1012628).
- serial: sh-sci: Stop using printk format %%pCr (bnc#1012628).
- usb: gadget: udc: renesas_usb3: disable the controller's irqs
  for reconnecting (bnc#1012628).
- usb: gadget: udc: renesas_usb3: should fail if devm_phy_get()
  returns error (bnc#1012628).
- usb: gadget: udc: renesas_usb3: should call devm_phy_get()
  before add udc (bnc#1012628).
- usb: gadget: udc: renesas_usb3: should call pm_runtime_enable()
  before add udc (bnc#1012628).
- usb: gadget: udc: renesas_usb3: should remove debugfs
  (bnc#1012628).
- usb: gadget: udc: renesas_usb3: fix double phy_put()
  (bnc#1012628).
- usb: gadget: function: printer: avoid wrong list handling in
  printer_write() (bnc#1012628).
- usb: typec: wcove: Remove dependency on HW FSM (bnc#1012628).
- usb: core: message: remove extra endianness conversion in
  usb_set_isoch_delay (bnc#1012628).
- phy: qcom-qusb2: Fix crash if nvmem cell not specified
  (bnc#1012628).
- Input: xpad - add GPD Win 2 Controller USB IDs (bnc#1012628).
- usb-storage: Add compatibility quirk flags for G-Technologies
  G-Drive (bnc#1012628).
- usb-storage: Add support for FL_ALWAYS_SYNC flag in the UAS
  driver (bnc#1012628).
- usbip: vhci_sysfs: fix potential Spectre v1 (bnc#1012628).
- NFC: pn533: don't send USB data off of the stack (bnc#1012628).
- staging: android: ion: Switch to pr_warn_once in
  ion_buffer_destroy (bnc#1012628).
- kvm: x86: use correct privilege level for
  sgdt/sidt/fxsave/fxrstor access (bnc#1012628).
- KVM: x86: pass kvm_vcpu to kvm_read_guest_virt and
  kvm_write_guest_virt_system (bnc#1012628).
- kvm: nVMX: Enforce cpl=0 for VMX instructions (bnc#1012628).
- kvm: fix typo in flag name (bnc#1012628).
- KVM: x86: introduce linear_{read,write}_system (bnc#1012628).
- KVM: X86: Fix reserved bits check for MOV to CR3 (bnc#1012628).
- blkdev_report_zones_ioctl(): Use vmalloc() to allocate large
  buffers (bnc#1012628).
- crypto: chelsio - request to HW should wrap (bnc#1012628).
- commit 202985c
* Thu Jun 14 2018 mkubecek@suse.cz
- socket: close race condition between sock_close() and
  sockfs_setattr() (CVE-2018-12232 bsc#1097593).
- commit 94bf968
* Thu Jun 14 2018 jslaby@suse.cz
- config.conf: disable syzkaller
  I doubt anybody else (other than me) uses the flavor, so save a lot of
  build resources by this. Leaving syzkaller configs and stuff in place
  so people still can build it if they want.
  The build is currently broken, so this "fixes" it too:
  ERROR: "__sanitizer_cov_trace_cmpd" [drivers/gpu/drm/amd/amdgpu/amdgpu.ko] undefined!
  ERROR: "__sanitizer_cov_trace_cmpf" [drivers/gpu/drm/amd/amdgpu/amdgpu.ko] undefined!
- commit bdee95f
* Tue Jun 12 2018 jslaby@suse.cz
- Linux 4.17.1 (bnc#1012628).
- netfilter: nf_flow_table: attach dst to skbs (bnc#1012628).
- bnx2x: use the right constant (bnc#1012628).
- ip6mr: only set ip6mr_table from setsockopt when ip6mr_new_table
  succeeds (bnc#1012628).
- ipv6: omit traffic class when calculating flow hash (bnc#1012628
  bsc#1095042).
- l2tp: fix refcount leakage on PPPoL2TP sockets (bnc#1012628).
- netdev-FAQ: clarify DaveM's position for stable backports
  (bnc#1012628).
- net: metrics: add proper netlink validation (bnc#1012628).
- net/packet: refine check for priv area size (bnc#1012628).
- rtnetlink: validate attributes in do_setlink() (bnc#1012628).
- sctp: not allow transport timeout value less than HZ/5 for
  hb_timer (bnc#1012628).
- team: use netdev_features_t instead of u32 (bnc#1012628).
- vrf: check the original netdevice for generating redirect
  (bnc#1012628).
- net: dsa: b53: Fix for brcm tag issue in Cygnus SoC
  (bnc#1012628).
- ipmr: fix error path when ipmr_new_table fails (bnc#1012628).
- PCI: hv: Do not wait forever on a device that has disappeared
  (bnc#1012628).
- Delete
  patches.suse/ipv6-omit-traffic-class-when-calculating-flow-hash.patch.
- commit 17c8abe
* Fri Jun  8 2018 tiwai@suse.de
- mtd: spi-nor: intel-spi: Fix atomic sequence handling
  (bsc#1073836).
- commit c31c53d
* Fri Jun  8 2018 mkubecek@suse.cz
- ipv6: omit traffic class when calculating flow hash
  (bsc#1095042).
- commit 1307c29
* Fri Jun  8 2018 tiwai@suse.de
- Delete patches.suse/iwlwifi-expose-default-fallback-ucode-api.
  The workaround is no longer needed as the upstream driver code catches
  up the actual firmware version
- commit d6e069d
* Fri Jun  8 2018 tiwai@suse.de
- Update patch tag of the upstreamed btusb fix
- commit f531f64
* Mon Jun  4 2018 mkubecek@suse.cz
- config: enable preemption in i386/debug
- commit b181e22
* Mon Jun  4 2018 mkubecek@suse.cz
- Update to 4.17-final
- commit fb45ad0
* Sat Jun  2 2018 mkubecek@suse.cz
- packet: fix reserve calculation (bsc#1095592).
- commit f670a16
* Fri Jun  1 2018 mcgrof@suse.com
- xfs: enhance dinode verifier (bsc#1090749,CVE-2018-10322).
- commit d565016
* Thu May 31 2018 jslaby@suse.cz
- Linux 4.16.13 (bnc#1012628).
- drm/vmwgfx: Set dmabuf_size when vmw_dmabuf_init is successful
  (bnc#1012628).
- kdb: make "mdr" command repeat (bnc#1012628).
- pinctrl: mcp23s08: spi: Fix regmap debugfs entries
  (bnc#1012628).
- pinctrl: msm: Use dynamic GPIO numbering (bnc#1012628).
- regulator: of: Add a missing 'of_node_put()' in an error
  handling path of 'of_regulator_match()' (bnc#1012628).
- ARM: dts: porter: Fix HDMI output routing (bnc#1012628).
- ARM: dts: imx7d: cl-som-imx7: fix pinctrl_enet (bnc#1012628).
- i40e: Add delay after EMP reset for firmware to recover
  (bnc#1012628).
- soc: amlogic: meson-gx-pwrc-vpu: fix error on shutdown when
  domain is powered off (bnc#1012628).
- regmap: Correct comparison in regmap_cached (bnc#1012628).
- ARM: dts: at91: tse850: use the correct compatible for the
  eeprom (bnc#1012628).
- ARM: dts: at91: nattis: use the correct compatible for the
  eeprom (bnc#1012628).
- selftests: Add FIB onlink tests (bnc#1012628).
- drm: rcar-du: lvds: Fix LVDS startup on R-Car Gen2
  (bnc#1012628).
- drm: rcar-du: lvds: Fix LVDS startup on R-Car Gen3
  (bnc#1012628).
- netlabel: If PF_INET6, check sk_buff ip header version
  (bnc#1012628).
- drm/vblank: Data type fixes for 64-bit vblank sequences
  (bnc#1012628).
- selftests/net: fixes psock_fanout eBPF test case (bnc#1012628).
- perf tests: Fix dwarf unwind for stripped binaries
  (bnc#1012628).
- perf report: Fix memory corruption in --branch-history mode
  - -branch-history (bnc#1012628).
- perf tests: Use arch__compare_symbol_names to compare symbols
  (bnc#1012628).
- perf report: Fix wrong jump arrow (bnc#1012628).
- perf test: Fix test case inet_pton to accept inlines
  (bnc#1012628).
- x86/apic: Set up through-local-APIC mode on the boot CPU if
  'noapic' specified (bnc#1012628).
- drm/rockchip: Respect page offset for PRIME mmap calls
  (bnc#1012628).
- soc: renesas: r8a77970-sysc: fix power area parents
  (bnc#1012628).
- MIPS: Octeon: Fix logging messages with spurious periods after
  newlines (bnc#1012628).
- dpaa_eth: fix pause capability advertisement logic
  (bnc#1012628).
- drm/amd/display: Set vsc pack revision when DPCD revision is >=
  1.2 (bnc#1012628).
- dt-bindings: display: msm/dsi: Fix the PHY regulator supply
  props (bnc#1012628).
- pinctrl: sh-pfc: r8a7796: Fix MOD_SEL register pin assignment
  for SSI pins group (bnc#1012628).
- rcu: Call touch_nmi_watchdog() while printing stall warnings
  (bnc#1012628).
- net: stmmac: call correct function in
  stmmac_mac_config_rx_queues_routing() (bnc#1012628).
- audit: return on memory error to avoid null pointer dereference
  (bnc#1012628).
- hwrng: bcm2835 - Handle deferred clock properly (bnc#1012628).
- PCMCIA / PM: Avoid noirq suspend aborts during suspend-to-idle
  (bnc#1012628).
- ARM: dts: bcm283x: Fix pin function of JTAG pins (bnc#1012628).
- ARM: dts: bcm283x: Fix probing of bcm2835-i2s (bnc#1012628).
- power: supply: ltc2941-battery-gauge: Fix temperature units
  (bnc#1012628).
- sh_eth: fix TSU init on SH7734/R8A7740 (bnc#1012628).
- ixgbe: prevent ptp_rx_hang from running when in FILTER_ALL mode
  (bnc#1012628).
- udf: Provide saner default for invalid uid / gid (bnc#1012628).
- PCI: Add function 1 DMA alias quirk for Marvell 88SE9220
  (bnc#1012628).
- dpaa_eth: fix SG mapping (bnc#1012628).
- cpufreq: Reorder cpufreq_online() error code path (bnc#1012628).
- net: stmmac: ensure that the MSS desc is the last desc to set
  the own bit (bnc#1012628).
- net: stmmac: ensure that the device has released ownership
  before reading data (bnc#1012628).
- ibmvnic: Allocate statistics buffers during probe (bnc#1012628).
- drm/amdgpu: adjust timeout for ib_ring_tests(v2) (bnc#1012628).
- drm/amdgpu: disable GFX ring and disable PQ wptr in hw_fini
  (bnc#1012628).
- ARM: dts: dra71-evm: Correct evm_sd regulator max voltage
  (bnc#1012628).
- drm: omapdrm: dss: Move initialization code from component
  bind to probe (bnc#1012628).
- dmaengine: qcom: bam_dma: get num-channels and num-ees from dt
  (bnc#1012628).
- vfio-ccw: fence off transport mode (bnc#1012628).
- pinctrl: artpec6: dt: add missing pin group uart5nocts
  (bnc#1012628).
- pinctrl: devicetree: Fix dt_to_map_one_config handling of hogs
  (bnc#1012628).
- hwrng: stm32 - add reset during probe (bnc#1012628).
- watchdog: asm9260_wdt: fix error handling in asm9260_wdt_probe()
  (bnc#1012628).
- enic: enable rq before updating rq descriptors (bnc#1012628).
- dmaengine: rcar-dmac: Check the done lists in
  rcar_dmac_chan_get_residue() (bnc#1012628).
- powerpc/mm/slice: Fix hugepage allocation at hint address on
  8xx (bnc#1012628).
- powerpc/mm/slice: Enhance for supporting PPC32 (bnc#1012628).
- powerpc/mm/slice: create header files dedicated to slices
  (bnc#1012628).
- powerpc/mm/slice: Remove intermediate bitmap copy (bnc#1012628).
- ARM: dts: keystone-k2e-clocks: Fix missing unit address
  separator (bnc#1012628).
- dmaengine: pl330: fix a race condition in case of threaded irqs
  (bnc#1012628).
- block: null_blk: fix 'Invalid parameters' when loading module
  (bnc#1012628).
- tools: hv: fix compiler warnings about major/target_fname
  (bnc#1012628).
- drm/amdgpu: Clean sdma wptr register when only enable wptr
  polling (bnc#1012628).
- drm/bridge: sii902x: Retry status read after DDI I2C
  (bnc#1012628).
- phy: qcom-qmp: Fix phy pipe clock gating (bnc#1012628).
- ALSA: vmaster: Propagate slave error (bnc#1012628).
- phy: rockchip-emmc: retry calpad busy trimming (bnc#1012628).
- x86/devicetree: Fix device IRQ settings in DT (bnc#1012628).
- x86/devicetree: Initialize device tree before using it
  (bnc#1012628).
- gfs2: Fix fallocate chunk size (bnc#1012628).
- soc: qcom: wcnss_ctrl: Fix increment in NV upload (bnc#1012628).
- arm64: dts: qcom: Fix SPI5 config on MSM8996 (bnc#1012628).
- perf/x86/intel: Fix event update for auto-reload (bnc#1012628).
- perf/x86/intel: Fix large period handling on Broadwell CPUs
  (bnc#1012628).
- efi/arm*: Only register page tables when they exist
  (bnc#1012628).
- cdrom: do not call check_disk_change() inside cdrom_open()
  (bnc#1012628).
- perf/x86/intel: Properly save/restore the PMU state in the
  NMI handler (bnc#1012628).
- hwmon: (pmbus/adm1275) Accept negative page register values
  (bnc#1012628).
- hwmon: (pmbus/max8688) Accept negative page register values
  (bnc#1012628).
- drm/panel: simple: Fix the bus format for the Ontat panel
  (bnc#1012628).
- perf/core: Fix perf_output_read_group() (bnc#1012628).
- max17042: propagate of_node to power supply device
  (bnc#1012628).
- perf/core: Fix installing cgroup events on CPU (bnc#1012628).
- f2fs: fix to check extent cache in f2fs_drop_extent_tree
  (bnc#1012628).
- f2fs: fix to clear CP_TRIMMED_FLAG (bnc#1012628).
- f2fs: fix to set KEEP_SIZE bit in f2fs_zero_range (bnc#1012628).
- cxl: Check if PSL data-cache is available before issue flush
  request (bnc#1012628).
- f2fs: flush cp pack except cp pack 2 page at first
  (bnc#1012628).
- powerpc/powernv/npu: Fix deadlock in mmio_invalidate()
  (bnc#1012628).
- powerpc: Add missing prototype for arch_irq_work_raise()
  (bnc#1012628).
- drm/meson: Fix an un-handled error path in
  'meson_drv_bind_master()' (bnc#1012628).
- drm/meson: Fix some error handling paths in
  'meson_drv_bind_master()' (bnc#1012628).
- ipmi_ssif: Fix kernel panic at msg_done_handler (bnc#1012628).
- watchdog: aspeed: Fix translation of reset mode to ctrl register
  (bnc#1012628).
- watchdog: dw: RMW the control register (bnc#1012628).
- watchdog: sprd_wdt: Fix error handling in sprd_wdt_enable()
  (bnc#1012628).
- PCI: Restore config space on runtime resume despite being
  unbound (bnc#1012628).
- powerpc/vas: Fix cleanup when VAS is not configured
  (bnc#1012628).
- MIPS: ath79: Fix AR724X_PLL_REG_PCIE_CONFIG offset
  (bnc#1012628).
- net/smc: pay attention to MAX_ORDER for CQ entries
  (bnc#1012628).
- spi: bcm-qspi: fIX some error handling paths (bnc#1012628).
- regulator: gpio: Fix some error handling paths in
  'gpio_regulator_probe()' (bnc#1012628).
- ibmvnic: Fix reset return from closed state (bnc#1012628).
- coresight: Use %%px to print pcsr instead of %%p (bnc#1012628).
- drm/amdkfd: add missing include of mm.h (bnc#1012628).
- IB/core: Honor port_num while resolving GID for IB link layer
  (bnc#1012628).
- perf stat: Fix core dump when flag T is used (bnc#1012628).
- perf top: Fix top.call-graph config option reading
  (bnc#1012628).
- KVM: lapic: stop advertising DIRECTED_EOI when in-kernel IOAPIC
  is in use (bnc#1012628).
- i2c: mv64xxx: Apply errata delay only in standard mode
  (bnc#1012628).
- cxgb4: Fix queue free path of ULD drivers (bnc#1012628).
- ACPICA: acpi: acpica: fix acpi operand cache leak in nseval.c
  (bnc#1012628).
- bcache: stop dc->writeback_rate_update properly (bnc#1012628).
- ACPICA: Fix memory leak on unusual memory leak (bnc#1012628).
- ACPICA: Events: add a return on failure from
  acpi_hw_register_read (bnc#1012628).
- bcache: fix cached_dev->count usage for bch_cache_set_error()
  (bnc#1012628).
- dt-bindings: add device tree binding for Allwinner H6 main CCU
  (bnc#1012628).
- remoteproc: imx_rproc: Fix an error handling path in
  'imx_rproc_probe()' (bnc#1012628).
- bcache: quit dc->writeback_thread when BCACHE_DEV_DETACHING
  is set (bnc#1012628).
- zorro: Set up z->dev.dma_mask for the DMA API (bnc#1012628).
- IB/mlx5: Set the default active rate and width to QDR and 4X
  (bnc#1012628).
- firmware: fix checking for return values for fw_add_devm_name()
  (bnc#1012628).
- cpufreq: cppc_cpufreq: Fix cppc_cpufreq_init() failure path
  (bnc#1012628).
- iommu/mediatek: Fix protect memory setting (bnc#1012628).
- drm/vmwgfx: Unpin the screen object backup buffer when not used
  (bnc#1012628).
- ext4: don't complain about incorrect features when probing
  (bnc#1012628).
- ima: clear IMA_HASH (bnc#1012628).
- arm: dts: socfpga: fix GIC PPI warning (bnc#1012628).
- virtio-net: Fix operstate for virtio when no VIRTIO_NET_F_STATUS
  (bnc#1012628).
- gfs2: Check for the end of metadata in punch_hole (bnc#1012628).
- watchdog: aspeed: Allow configuring for alternate boot
  (bnc#1012628).
- ima: Fallback to the builtin hash algorithm (bnc#1012628).
- ima: Fix Kconfig to select TPM 2.0 CRB interface (bnc#1012628).
- Update config files (TCG_CRB=y).
- hv_netvsc: Fix the return status in RX path (bnc#1012628).
- cxgb4: Setup FW queues before registering netdev (bnc#1012628).
- btrfs: fix null pointer deref when target device is missing
  (bnc#1012628).
- ath9k: fix crash in spectral scan (bnc#1012628).
- nvme-pci: disable APST for Samsung NVMe SSD 960 EVO + ASUS
  PRIME Z370-A (bnc#1012628).
- nvme_fc: fix abort race on teardown with lld reject
  (bnc#1012628).
- ath10k: Fix kernel panic while using worker
  (ath10k_sta_rc_update_wk) (bnc#1012628).
- net: qualcomm: rmnet: check for null ep to avoid null pointer
  dereference (bnc#1012628).
- net: hns3: fix for returning wrong value problem in
  hns3_get_rss_key_size (bnc#1012628).
- net: hns3: fix for returning wrong value problem in
  hns3_get_rss_indir_size (bnc#1012628).
- net: hns3: fix for the wrong shift problem in
  hns3_set_txbd_baseinfo (bnc#1012628).
- watchdog: davinci_wdt: fix error handling in davinci_wdt_probe()
  (bnc#1012628).
- net/mlx5: Protect from command bit overflow (bnc#1012628).
- i40e: hold the RTNL lock while changing interrupt schemes
  (bnc#1012628).
- selftests: Print the test we're running to /dev/kmsg
  (bnc#1012628).
- tools/thermal: tmon: fix for segfault (bnc#1012628).
- rsi: fix kernel panic observed on 64bit machine (bnc#1012628).
- powerpc/perf: Fix kernel address leak via sampling registers
  (bnc#1012628).
- powerpc/perf: Prevent kernel address leak to userspace via
  BHRB buffer (bnc#1012628).
- mt76x2: fix warning in ieee80211_get_key_rx_seq() (bnc#1012628).
- mt76x2: fix possible NULL pointer dereferencing in mt76x2_tx()
  (bnc#1012628).
- hwmon: (nct6775) Fix writing pwmX_mode (bnc#1012628).
- perf mmap: Fix accessing unmapped mmap in perf_mmap__read_done()
  (bnc#1012628).
- parisc/pci: Switch LBA PCI bus from Hard Fail to Soft Fail mode
  (bnc#1012628).
- net/mlx5e: Move all TX timeout logic to be under state lock
  (bnc#1012628).
- iwlwifi: mvm: take RCU lock before dereferencing (bnc#1012628).
- iwlwifi: mvm: check if mac80211_queue is valid in
  iwl_mvm_disable_txq (bnc#1012628).
- m68k: set dma and coherent masks for platform FEC ethernets
  (bnc#1012628).
- intel_th: Use correct method of finding hub (bnc#1012628).
- iommu/amd: Take into account that alloc_dev_data() may return
  NULL (bnc#1012628).
- ath10k: advertize beacon_int_min_gcd (bnc#1012628).
- ieee802154: ca8210: fix uninitialised data read (bnc#1012628).
- powerpc/mpic: Check if cpu_possible() in mpic_physmask()
  (bnc#1012628).
- ACPI: acpi_pad: Fix memory leak in power saving threads
  (bnc#1012628).
- drivers: macintosh: rack-meter: really fix bogus memsets
  (bnc#1012628).
- xen/acpi: off by one in read_acpi_id() (bnc#1012628).
- rxrpc: Don't treat call aborts as conn aborts (bnc#1012628).
- rxrpc: Fix Tx ring annotation after initial Tx failure
  (bnc#1012628).
- rxrpc: Fix resend event time calculation (bnc#1012628).
- btrfs: qgroup: Fix root item corruption when multiple same
  source snapshots are created with quota enabled (bnc#1012628).
- btrfs: fix lockdep splat in btrfs_alloc_subvolume_writers
  (bnc#1012628).
- Btrfs: fix copy_items() return value when logging an inode
  (bnc#1012628).
- btrfs: tests/qgroup: Fix wrong tree backref level (bnc#1012628).
- powerpc/64s: sreset panic if there is no debugger or crash
  dump handlers (bnc#1012628).
- bnxt_en: fix clear flags in ethtool reset handling
  (bnc#1012628).
- net: bgmac: Correctly annotate register space (bnc#1012628).
- net: bgmac: Fix endian access in bgmac_dma_tx_ring_free()
  (bnc#1012628).
- platform/x86: dell-smbios: Fix memory leaks in
  build_tokens_sysfs() (bnc#1012628).
- riscv/spinlock: Strengthen implementations with fences
  (bnc#1012628).
- sparc64: Make atomic_xchg() an inline function rather than a
  macro (bnc#1012628).
- dmaengine: rcar-dmac: Fix too early/late system suspend/resume
  callbacks (bnc#1012628).
- fscache: Fix hanging wait on page discarded by writeback
  (bnc#1012628).
- lan78xx: Connect phy early (bnc#1012628).
- KVM: VMX: raise internal error for exception during invalid
  protected mode state (bnc#1012628).
- x86/mm: Fix bogus warning during EFI bootup, use boot_cpu_has()
  instead of this_cpu_has() in build_cr3_noflush() (bnc#1012628).
- sched/rt: Fix rq->clock_update_flags < RQCF_ACT_SKIP warning
  (bnc#1012628).
- powerpc/64s/idle: Fix restore of AMOR on POWER9 after deep sleep
  (bnc#1012628).
- ocfs2/dlm: don't handle migrate lockres if already in shutdown
  (bnc#1012628).
- IB/rxe: Fix for oops in rxe_register_device on ppc64le arch
  (bnc#1012628).
- btrfs: Fix possible softlock on single core machines
  (bnc#1012628).
- Btrfs: fix NULL pointer dereference in log_dir_items
  (bnc#1012628).
- Btrfs: bail out on error during replay_dir_deletes
  (bnc#1012628).
- mm: thp: fix potential clearing to referenced flag in
  page_idle_clear_pte_refs_one() (bnc#1012628).
- mm: fix races between address_space dereference and free in
  page_evicatable (bnc#1012628).
- mm/ksm: fix interaction with THP (bnc#1012628).
- genirq/affinity: Don't return with empty affinity masks on error
  (bnc#1012628).
- ibmvnic: Zero used TX descriptor counter on reset (bnc#1012628).
- dp83640: Ensure against premature access to PHY registers
  after reset (bnc#1012628).
- perf clang: Add support for recent clang versions (bnc#1012628).
- perf tools: Fix perf builds with clang support (bnc#1012628).
- powerpc/fscr: Enable interrupts earlier before calling
  get_user() (bnc#1012628).
- cpufreq: CPPC: Initialize shared perf capabilities of CPUs
  (bnc#1012628).
- Force log to disk before reading the AGF during a fstrim
  (bnc#1012628).
- sr: get/drop reference to device in revalidate and check_events
  (bnc#1012628).
- z3fold: fix memory leak (bnc#1012628).
- swap: divide-by-zero when zero length swap file on ssd
  (bnc#1012628).
- kasan, slub: fix handling of kasan_slab_free hook (bnc#1012628).
- kasan: fix invalid-free test crashing the kernel (bnc#1012628).
- fs/proc/proc_sysctl.c: fix potential page fault while
  unregistering sysctl table (bnc#1012628).
- nvme: expand nvmf_check_if_ready checks (bnc#1012628).
- bnxt_en: Ignore src port field in decap filter nodes
  (bnc#1012628).
- x86/mm: Do not forbid _PAGE_RW before init for __ro_after_init
  (bnc#1012628).
- x86/pgtable: Don't set huge PUD/PMD on non-leaf entries
  (bnc#1012628).
- Btrfs: fix loss of prealloc extents past i_size after fsync
  log replay (bnc#1012628).
- Btrfs: clean up resources during umount after trans is aborted
  (bnc#1012628).
- nvme: don't send keep-alives to the discovery controller
  (bnc#1012628).
- firmware: dmi_scan: Fix UUID length safety check (bnc#1012628).
- sh: fix debug trap failure to process signals before return
  to user (bnc#1012628).
- ARM: dts: sun4i: Fix incorrect clocks for displays
  (bnc#1012628).
- x86/kvm: fix LAPIC timer drift when guest uses periodic mode
  (bnc#1012628).
- kvm: x86: IA32_ARCH_CAPABILITIES is always supported
  (bnc#1012628).
- KVM: x86: Update cpuid properly when CR4.OSXAVE or CR4.PKE is
  changed (bnc#1012628).
- KVM: s390: vsie: fix < 8k check for the itdba (bnc#1012628).
- KVM/VMX: Expose SSBD properly to guests (bnc#1012628).
- PM / core: Fix direct_complete handling for devices with no
  callbacks (bnc#1012628).
- kernel/sys.c: fix potential Spectre v1 issue (bnc#1012628).
- kasan: fix memory hotplug during boot (bnc#1012628).
- kasan: free allocated shadow memory on MEM_CANCEL_ONLINE
  (bnc#1012628).
- mm/kasan: don't vfree() nonexistent vm_area (bnc#1012628).
- ipc/shm: fix shmat() nil address after round-down when remapping
  (bnc#1012628).
- Revert "ipc/shm: Fix shmat mmap nil-page protection"
  (bnc#1012628).
- idr: fix invalid ptr dereference on item delete (bnc#1012628).
- bcma: fix buffer size caused crash in bcma_core_mips_print_irq()
  (bnc#1012628).
- sr: pass down correctly sized SCSI sense buffer (bnc#1012628).
- IB/umem: Use the correct mm during ib_umem_release
  (bnc#1012628).
- IB/hfi1: Use after free race condition in send context error
  path (bnc#1012628).
- powerpc/64s: Clear PCR on boot (bnc#1012628).
- arm64: export tishift functions to modules (bnc#1012628).
- arm64: lse: Add early clobbers to some input/output asm operands
  (bnc#1012628).
- drm/vmwgfx: Fix 32-bit VMW_PORT_HB_[IN|OUT] macros
  (bnc#1012628).
- xen-swiotlb: fix the check condition for
  xen_swiotlb_free_coherent (bnc#1012628).
- libata: blacklist Micron 500IT SSD with MU01 firmware
  (bnc#1012628).
- libata: Blacklist some Sandisk SSDs for NCQ (bnc#1012628).
- ahci: Add PCI ID for Cannon Lake PCH-LP AHCI (bnc#1012628).
- mmc: sdhci-iproc: add SDHCI_QUIRK2_HOST_OFF_CARD_ON for cygnus
  (bnc#1012628).
- mmc: sdhci-iproc: fix 32bit writes for TRANSFER_MODE register
  (bnc#1012628).
- mmc: sdhci-iproc: remove hard coded mmc cap 1.8v (bnc#1012628).
- mmc: block: propagate correct returned value in mmc_rpmb_ioctl
  (bnc#1012628).
- do d_instantiate/unlock_new_inode combinations safely
  (bnc#1012628).
- ALSA: timer: Fix pause event notification (bnc#1012628).
- Btrfs: fix error handling in btrfs_truncate() (bnc#1012628).
- aio: fix io_destroy(2) vs. lookup_ioctx() race (bnc#1012628).
- fs: don't scan the inode cache before SB_BORN is set
  (bnc#1012628).
- fix breakage caused by d_find_alias() semantics change
  (bnc#1012628).
- affs_lookup(): close a race with affs_remove_link()
  (bnc#1012628).
- KVM: Fix spelling mistake: "cop_unsuable" -> "cop_unusable"
  (bnc#1012628).
- MIPS: Fix ptrace(2) PTRACE_PEEKUSR and PTRACE_POKEUSR accesses
  to o32 FGRs (bnc#1012628).
- MIPS: ptrace: Expose FIR register through FP regset
  (bnc#1012628).
- MIPS: Fix build with DEBUG_ZBOOT and MACH_JZ4770 (bnc#1012628).
- MIPS: c-r4k: Fix data corruption related to cache coherence
  (bnc#1012628).
- MIPS: xilfpga: Actually include FDT in fitImage (bnc#1012628).
- MIPS: xilfpga: Stop generating useless dtb.o (bnc#1012628).
- commit e33cb3e
* Mon May 28 2018 mkubecek@suse.cz
- Update to 4.17-rc7
- Eliminated 1 patch
- Config changes:
  - reenable SSB_DRIVER_PCICORE and dependencies after revert of
    commit 882164a4a928
- commit c78299c
* Fri May 25 2018 jslaby@suse.cz
- Update config files.
- commit 39c7522
* Fri May 25 2018 jslaby@suse.cz
- Linux 4.16.12 (bnc#1012628).
- rtc: goldfish: Add missing MODULE_LICENSE (bnc#1012628).
- rtc: rp5c01: fix possible race condition (bnc#1012628).
- rtc: tx4939: avoid unintended sign extension on a 24 bit shift
  (bnc#1012628).
- rtc: m41t80: fix race conditions (bnc#1012628).
- rtc: rk808: fix possible race condition (bnc#1012628).
- rtc: hctosys: Ensure system time doesn't overflow time_t
  (bnc#1012628).
- rtc: snvs: Fix usage of snvs_rtc_enable (bnc#1012628).
- serial: altera: ensure port->regshift is honored consistently
  (bnc#1012628).
- serial: 8250: Don't service RX FIFO if interrupts are disabled
  (bnc#1012628).
- serial: arc_uart: Fix out-of-bounds access through DT alias
  (bnc#1012628).
- serial: fsl_lpuart: Fix out-of-bounds access through DT alias
  (bnc#1012628).
- serial: imx: Fix out-of-bounds access through serial port index
  (bnc#1012628).
- serial: mxs-auart: Fix out-of-bounds access through serial
  port index (bnc#1012628).
- serial: samsung: Fix out-of-bounds access through serial port
  index (bnc#1012628).
- serial: sh-sci: Fix out-of-bounds access through DT alias
  (bnc#1012628).
- serial: xuartps: Fix out-of-bounds access through DT alias
  (bnc#1012628).
- serial: mvebu-uart: fix tx lost characters (bnc#1012628).
- media: cx25821: prevent out-of-bounds read on array card
  (bnc#1012628).
- media: vivid: fix incorrect capabilities for radio
  (bnc#1012628).
- media: vb2: Fix videobuf2 to map correct area (bnc#1012628).
- media: i2c: adv748x: fix HDMI field heights (bnc#1012628).
- media: v4l: vsp1: Fix display stalls when requesting too many
  inputs (bnc#1012628).
- media: em28xx: Add Hauppauge SoloHD/DualHD bulk models
  (bnc#1012628).
- media: lgdt3306a: Fix a double kfree on i2c device remove
  (bnc#1012628).
- media: s3c-camif: fix out-of-bounds array access (bnc#1012628).
- media: cx23885: Set subdev host data to clk_freq pointer
  (bnc#1012628).
- media: cx23885: Override 888 ImpactVCBe crystal frequency
  (bnc#1012628).
- media: ov5645: add missing of_node_put() in error path
  (bnc#1012628).
- clk: meson: axg: add the fractional part of the fixed_pll
  (bnc#1012628).
- clk: meson: axg: fix the od shift of the sys_pll (bnc#1012628).
- clk: samsung: exynos3250: Fix PLL rates (bnc#1012628).
- clk: samsung: exynos5250: Fix PLL rates (bnc#1012628).
- clk: samsung: exynos5433: Fix PLL rates (bnc#1012628).
- clk: samsung: exynos5260: Fix PLL rates (bnc#1012628).
- clk: samsung: exynos7: Fix PLL rates (bnc#1012628).
- clk: samsung: s3c2410: Fix PLL rates (bnc#1012628).
- clk: rockchip: Prevent calculating mmc phase if clock rate is
  zero (bnc#1012628).
- clk: tegra: Fix pll_u rate configuration (bnc#1012628).
- clk: hisilicon: mark wdt_mux_p[] as const (bnc#1012628).
- clk: Don't show the incorrect clock phase (bnc#1012628).
- clk: rockchip: Fix wrong parent for SDMMC phase clock for rk3228
  (bnc#1012628).
- ASoC: samsung: i2s: Ensure the RCLK rate is properly determined
  (bnc#1012628).
- ASoC: topology: create TLV data for dapm widgets (bnc#1012628).
- ASoC: samsung: odroid: Fix 32000 sample rate handling
  (bnc#1012628).
- ASoC: rockchip: rk3288-hdmi-analog: Select needed codecs
  (bnc#1012628).
- scsi: lpfc: Fix frequency of Release WQE CQEs (bnc#1012628).
- scsi: lpfc: Fix IO failure during hba reset testing with nvme io
  (bnc#1012628).
- scsi: lpfc: Fix soft lockup in lpfc worker thread during LIP
  testing (bnc#1012628).
- scsi: lpfc: Fix nonrecovery of NVME controller after cable swap
  (bnc#1012628).
- scsi: lpfc: Fix issue_lip if link is disabled (bnc#1012628).
- scsi: mvsas: fix wrong endianness of sgpio api (bnc#1012628).
- scsi: core: Make SCSI Status CONDITION MET equivalent to GOOD
  (bnc#1012628).
- scsi: lpfc: Fix NVME Initiator FirstBurst (bnc#1012628).
- scsi: devinfo: add HP DISK-SUBSYSTEM device, for HP XP arrays
  (bnc#1012628).
- scsi: aacraid: Insure command thread is not recursively stopped
  (bnc#1012628).
- crypto: inside-secure - fix the invalidation step during
  cra_exit (bnc#1012628).
- crypto: sunxi-ss - Add MODULE_ALIAS to sun4i-ss (bnc#1012628).
- crypto: inside-secure - do not overwrite the threshold value
  (bnc#1012628).
- crypto: inside-secure - fix the extra cache computation
  (bnc#1012628).
- crypto: inside-secure - fix the cache_len computation
  (bnc#1012628).
- crypto: inside-secure - do not process request if no command
  was issued (bnc#1012628).
- crypto: ccp - don't disable interrupts while setting up debugfs
  (bnc#1012628).
- crypto: atmel-aes - fix the keys zeroing on errors
  (bnc#1012628).
- crypto: inside-secure - wait for the request to complete if
  in the backlog (bnc#1012628).
- crypto: inside-secure - move the digest to the request context
  (bnc#1012628).
- staging: lustre: lmv: correctly iput lmo_root (bnc#1012628).
- staging: ks7010: Use constants from ieee80211_eid instead of
  literal ints (bnc#1012628).
- staging: rtl8192u: return -ENOMEM on failed allocation of
  priv->oldaddr (bnc#1012628).
- staging: fsl-dpaa2/eth: Fix incorrect casts (bnc#1012628).
- staging: lustre: fix bug in osc_enter_cache_try (bnc#1012628).
- staging: fsl-dpaa2/eth: Fix incorrect kfree (bnc#1012628).
- staging: bcm2835-audio: Release resources on module_exit()
  (bnc#1012628).
- x86/kexec: Avoid double free_page() upon do_kexec_load()
  failure (bnc#1012628).
- hfsplus: stop workqueue when fill_super() failed (bnc#1012628).
- cfg80211: limit wiphy names to 128 bytes (bnc#1012628).
- loop: fix LOOP_GET_STATUS lock imbalance (bnc#1012628).
- loop: don't call into filesystem while holding lo_ctl_mutex
  (bnc#1012628).
- xhci: Show what USB release number the xHC supports from
  protocol capablity (bnc#1012628).
- Bluetooth: btusb: Add support for Intel Bluetooth device 22560
  [8087:0026] (bnc#1012628).
- Bluetooth: btusb: Add device ID for RTL8822BE (bnc#1012628).
- media: em28xx: USB bulk packet size fix (bnc#1012628).
- media: lgdt3306a: Fix module count mismatch on usb unplug
  (bnc#1012628).
- usb: gadget: composite: fix incorrect handling of OS desc
  requests (bnc#1012628).
- usb: gadget: udc: change comparison to bitshift when dealing
  with a mask (bnc#1012628).
- usbip: Correct maximum value of CONFIG_USBIP_VHCI_HC_PORTS
  (bnc#1012628).
- usb: gadget: ffs: Execute copy_to_user() with USER_DS set
  (bnc#1012628).
- usb: gadget: ffs: Let setup() return USB_GADGET_DELAYED_STATUS
  (bnc#1012628).
- usb: dwc2: host: Fix transaction errors in host mode
  (bnc#1012628).
- usb: dwc2: hcd: Fix host channel halt flow (bnc#1012628).
- usb: dwc2: Fix interval type issue (bnc#1012628).
- xhci: zero usb device slot_id member when disabling and freeing
  a xhci slot (bnc#1012628).
- usb: dwc3: Makefile: fix link error on randconfig (bnc#1012628).
- usb: dwc3: Update DWC_usb31 GTXFIFOSIZ reg fields (bnc#1012628).
- usb: dwc3: Add SoftReset PHY synchonization delay (bnc#1012628).
- ALSA: usb-audio: Add native DSD support for Luxman DA-06
  (bnc#1012628).
- Bluetooth: btusb: Add USB ID 7392:a611 for Edimax EW-7611ULB
  (bnc#1012628).
- scsi: zfcp: fix infinite iteration on ERP ready list
  (bnc#1012628).
- scsi: sg: allocate with __GFP_ZERO in sg_build_indirect()
  (bnc#1012628).
- s390: use expoline thunks in the BPF JIT (bnc#1012628).
- s390: extend expoline to BC instructions (bnc#1012628).
- s390: move spectre sysfs attribute code (bnc#1012628).
- s390/kernel: use expoline for indirect branches (bnc#1012628).
- s390/ftrace: use expoline for indirect branches (bnc#1012628).
- s390/lib: use expoline for indirect branches (bnc#1012628).
- s390/crc32-vx: use expoline for indirect branches (bnc#1012628).
- s390: move expoline assembler macros to a header (bnc#1012628).
- s390: correct module section names for expoline code revert
  (bnc#1012628).
- s390: correct nospec auto detection init order (bnc#1012628).
- s390: add assembler macros for CPU alternatives (bnc#1012628).
- s390: add sysfs attributes for spectre (bnc#1012628).
- s390: report spectre mitigation via syslog (bnc#1012628).
- s390: add automatic detection of the spectre defense
  (bnc#1012628).
- s390: move nobp parameter functions to nospec-branch.c
  (bnc#1012628).
- powerpc/64s: Add support for a store forwarding barrier at
  kernel entry/exit (bnc#1012628).
- powerpc: Move default security feature flags (bnc#1012628).
- powerpc/pseries: Fix clearing of security feature flags
  (bnc#1012628).
- powerpc/64s: Wire up cpu_show_spectre_v2() (bnc#1012628).
- powerpc/64s: Wire up cpu_show_spectre_v1() (bnc#1012628).
- powerpc/pseries: Use the security flags in
  pseries_setup_rfi_flush() (bnc#1012628).
- powerpc/powernv: Use the security flags in pnv_setup_rfi_flush()
  (bnc#1012628).
- powerpc/64s: Enhance the information in cpu_show_meltdown()
  (bnc#1012628).
- powerpc/64s: Move cpu_show_meltdown() (bnc#1012628).
- powerpc/powernv: Set or clear security feature flags
  (bnc#1012628).
- powerpc/pseries: Set or clear security feature flags
  (bnc#1012628).
- powerpc/pseries: Add new H_GET_CPU_CHARACTERISTICS flags
  (bnc#1012628).
- powerpc: Add security feature flags for Spectre/Meltdown
  (bnc#1012628).
- powerpc/rfi-flush: Always enable fallback flush on pseries
  (bnc#1012628).
- ext2: fix a block leak (bnc#1012628).
- sparc: vio: use put_device() instead of kfree() (bnc#1012628).
- qed: Fix LL2 race during connection terminate (bnc#1012628).
- qed: Fix possibility of list corruption during rmmod flows
  (bnc#1012628).
- qed: LL2 flush isles when connection is closed (bnc#1012628).
- net: ip6_gre: fix tunnel metadata device sharing (bnc#1012628).
- net: ip6_gre: Fix ip6erspan hlen calculation (bnc#1012628).
- net: ip6_gre: Split up ip6gre_changelink() (bnc#1012628).
- net: ip6_gre: Split up ip6gre_newlink() (bnc#1012628).
- net: ip6_gre: Split up ip6gre_tnl_change() (bnc#1012628).
- net: ip6_gre: Split up ip6gre_tnl_link_config() (bnc#1012628).
- net: ip6_gre: Fix headroom request in ip6erspan_tunnel_xmit()
  (bnc#1012628).
- net: ip6_gre: Request headroom in __gre6_xmit() (bnc#1012628).
- vmxnet3: use DMA memory barriers where required (bnc#1012628).
- vmxnet3: set the DMA mask before the first DMA map operation
  (bnc#1012628).
- cxgb4: fix offset in collecting TX rate limit info
  (bnc#1012628).
- 3c59x: convert to generic DMA API (bnc#1012628).
- net: dsa: bcm_sf2: Fix IPv6 rule half deletion (bnc#1012628).
- net: dsa: bcm_sf2: Fix IPv6 rules and chain ID (bnc#1012628).
- net: dsa: Do not register devlink for unused ports
  (bnc#1012628).
- net: dsa: bcm_sf2: Fix RX_CLS_LOC_ANY overwrite for last rule
  (bnc#1012628).
- cxgb4: Correct ntuple mask validation for hash filters
  (bnc#1012628).
- tuntap: fix use after free during release (bnc#1012628).
- tun: fix use after free for ptr_ring (bnc#1012628).
- tcp: purge write queue in tcp_connect_init() (bnc#1012628).
- sock_diag: fix use-after-free read in __sk_free (bnc#1012628).
- packet: in packet_snd start writing at link layer allocation
  (bnc#1012628).
- net: test tailroom before appending to linear skb (bnc#1012628).
- net/smc: check for missing nlattrs in SMC_PNETID messages
  (bnc#1012628).
- net: sched: red: avoid hashing NULL child (bnc#1012628).
- net/sched: fix refcnt leak in the error path of tcf_vlan_init()
  (bnc#1012628).
- net/mlx4_core: Fix error handling in mlx4_init_port_info
  (bnc#1012628).
- net: Fix a bug in removing queues from XPS map (bnc#1012628).
- net/mlx5: Fix build break when CONFIG_SMP=n (bnc#1012628).
- commit 9e125b1
* Thu May 24 2018 tiwai@suse.de
- Bluetooth: Apply QCA Rome patches for some ATH3012 models
  (bsc#1082504).
- commit e2f793c
* Wed May 23 2018 msuchanek@suse.de
- mkspec: only build docs for default variant kernel.
- commit 045f5ac
* Tue May 22 2018 jslaby@suse.cz
- Linux 4.16.11 (bnc#1012628).
- xhci: Fix USB3 NULL pointer dereference at logical disconnect
  (bnc#1012628).
- usbip: usbip_host: refine probe and disconnect debug msgs to
  be useful (bnc#1012628).
- usbip: usbip_host: delete device from busid_table after rebind
  (bnc#1012628).
- usbip: usbip_host: run rebind from exit when module is removed
  (bnc#1012628).
- usbip: usbip_host: fix NULL-ptr deref and use-after-free errors
  (bnc#1012628).
- usbip: usbip_host: fix bad unlock balance during stub_probe()
  (bnc#1012628).
- ALSA: usb: mixer: volume quirk for CM102-A+/102S+ (bnc#1012628).
- ALSA: hda/realtek - Clevo P950ER ALC1220 Fixup (bnc#1012628).
- ALSA: hda: Add Lenovo C50 All in one to the power_save blacklist
  (bnc#1012628).
- ALSA: control: fix a redundant-copy issue (bnc#1012628).
- spi: pxa2xx: Allow 64-bit DMA (bnc#1012628).
- spi: bcm-qspi: Avoid setting MSPI_CDRAM_PCS for spi-nor master
  (bnc#1012628).
- spi: bcm-qspi: Always read and set BSPI_MAST_N_BOOT_CTRL
  (bnc#1012628).
- KVM: vmx: update sec exec controls for UMIP iff emulating UMIP
  (bnc#1012628).
- KVM: arm/arm64: Properly protect VGIC locks from IRQs
  (bnc#1012628).
- KVM: arm/arm64: VGIC/ITS: Promote irq_lock() in update_affinity
  (bnc#1012628).
- KVM: arm/arm64: VGIC/ITS save/restore: protect kvm_read_guest()
  calls (bnc#1012628).
- KVM: arm/arm64: VGIC/ITS: protect kvm_read_guest() calls with
  SRCU lock (bnc#1012628).
- hwmon: (k10temp) Fix reading critical temperature register
  (bnc#1012628).
- hwmon: (k10temp) Use API function to access System Management
  Network (bnc#1012628).
- vfio: ccw: fix cleanup if cp_prefetch fails (bnc#1012628).
- tracing/x86/xen: Remove zero data size trace events
  trace_xen_mmu_flush_tlb{_all} (bnc#1012628).
- vsprintf: Replace memory barrier with static_key for
  random_ptr_key update (bnc#1012628).
- x86/amd_nb: Add support for Raven Ridge CPUs (bnc#1012628).
- tee: shm: fix use-after-free via temporarily dropped reference
  (bnc#1012628).
- netfilter: nf_tables: free set name in error path (bnc#1012628).
- netfilter: nf_tables: can't fail after linking rule into active
  rule list (bnc#1012628).
- netfilter: nf_tables: nf_tables_obj_lookup_byhandle() can be
  static (bnc#1012628).
- ARM64: dts: marvell: armada-cp110: Add clocks for the xmdio node
  (bnc#1012628).
- ARM64: dts: marvell: armada-cp110: Add mg_core_clk for ethernet
  node (bnc#1012628).
- i2c: designware: fix poll-after-enable regression (bnc#1012628).
- mtd: rawnand: marvell: Fix read logic for layouts with ->nchunks
  > 2 (bnc#1012628).
- powerpc/powernv: Fix NVRAM sleep in invalid context when
  crashing (bnc#1012628).
- drm: Match sysfs name in link removal to link creation
  (bnc#1012628).
- cpufreq: armada-37xx: driver relies on cpufreq-dt (bnc#1012628).
- lib/test_bitmap.c: fix bitmap optimisation tests to report
  errors correctly (bnc#1012628).
- radix tree: fix multi-order iteration race (bnc#1012628).
- mm: don't allow deferred pages with NEED_PER_CPU_KM
  (bnc#1012628).
- drm/i915/gen9: Add WaClearHIZ_WM_CHICKEN3 for bxt and glk
  (bnc#1012628).
- s390/qdio: fix access to uninitialized qdio_q fields
  (bnc#1012628).
- s390/cpum_sf: ensure sample frequency of perf event attributes
  is non-zero (bnc#1012628).
- s390/qdio: don't release memory in qdio_setup_irq()
  (bnc#1012628).
- s390: remove indirect branch from do_softirq_own_stack
  (bnc#1012628).
- bcache: return 0 from bch_debug_init() if CONFIG_DEBUG_FS=n
  (bnc#1012628).
- x86/pkeys: Override pkey when moving away from PROT_EXEC
  (bnc#1012628).
- x86/pkeys: Do not special case protection key 0 (bnc#1012628).
- efi: Avoid potential crashes, fix the 'struct
  efi_pci_io_protocol_32' definition for mixed mode (bnc#1012628).
- ARM: 8771/1: kprobes: Prohibit kprobes on do_undefinstr
  (bnc#1012628).
- x86/apic/x2apic: Initialize cluster ID properly (bnc#1012628).
- x86/mm: Drop TS_COMPAT on 64-bit exec() syscall (bnc#1012628).
- tick/broadcast: Use for_each_cpu() specially on UP kernels
  (bnc#1012628).
- ARM: 8769/1: kprobes: Fix to use get_kprobe_ctlblk after
  irq-disabed (bnc#1012628).
- ARM: 8770/1: kprobes: Prohibit probing on optimized_callback
  (bnc#1012628).
- ARM: 8772/1: kprobes: Prohibit kprobes on get_user functions
  (bnc#1012628).
- Btrfs: fix xattr loss after power failure (bnc#1012628).
- Btrfs: send, fix invalid access to commit roots due to
  concurrent snapshotting (bnc#1012628).
- btrfs: property: Set incompat flag if lzo/zstd compression is
  set (bnc#1012628).
- btrfs: fix crash when trying to resume balance without the
  resume flag (bnc#1012628).
- btrfs: Split btrfs_del_delalloc_inode into 2 functions
  (bnc#1012628).
- btrfs: Fix delalloc inodes invalidation during transaction abort
  (bnc#1012628).
- btrfs: fix reading stale metadata blocks after degraded raid1
  mounts (bnc#1012628).
- x86/nospec: Simplify alternative_msr_write() (bnc#1012628).
- x86/bugs: Concentrate bug detection into a separate function
  (bnc#1012628).
- x86/bugs: Concentrate bug reporting into a separate function
  (bnc#1012628).
- x86/bugs: Read SPEC_CTRL MSR during boot and re-use reserved
  bits (bnc#1012628).
- x86/bugs, KVM: Support the combination of guest and host IBRS
  (bnc#1012628).
- x86/bugs: Expose /sys/../spec_store_bypass (bnc#1012628).
- x86/cpufeatures: Add X86_FEATURE_RDS (bnc#1012628).
- x86/bugs: Provide boot parameters for the
  spec_store_bypass_disable mitigation (bnc#1012628).
- x86/bugs/intel: Set proper CPU features and setup RDS
  (bnc#1012628).
- x86/bugs: Whitelist allowed SPEC_CTRL MSR values (bnc#1012628).
- x86/bugs/AMD: Add support to disable RDS on Fam[15,16,17]h if
  requested (bnc#1012628).
- x86/KVM/VMX: Expose SPEC_CTRL Bit(2) to the guest (bnc#1012628).
- x86/speculation: Create spec-ctrl.h to avoid include hell
  (bnc#1012628).
- prctl: Add speculation control prctls (bnc#1012628).
- x86/process: Allow runtime control of Speculative Store Bypass
  (bnc#1012628).
- x86/speculation: Add prctl for Speculative Store Bypass
  mitigation (bnc#1012628).
- nospec: Allow getting/setting on non-current task (bnc#1012628).
- proc: Provide details on speculation flaw mitigations
  (bnc#1012628).
- seccomp: Enable speculation flaw mitigations (bnc#1012628).
- x86/bugs: Make boot modes __ro_after_init (bnc#1012628).
- prctl: Add force disable speculation (bnc#1012628).
- seccomp: Use PR_SPEC_FORCE_DISABLE (bnc#1012628).
- seccomp: Add filter flag to opt-out of SSB mitigation
  (bnc#1012628).
- seccomp: Move speculation migitation control to arch code
  (bnc#1012628).
- x86/speculation: Make "seccomp" the default mode for Speculative
  Store Bypass (bnc#1012628).
- x86/bugs: Rename _RDS to _SSBD (bnc#1012628).
- proc: Use underscores for SSBD in 'status' (bnc#1012628).
- Documentation/spec_ctrl: Do some minor cleanups (bnc#1012628).
- x86/bugs: Fix __ssb_select_mitigation() return type
  (bnc#1012628).
- x86/bugs: Make cpu_show_common() static (bnc#1012628).
- x86/bugs: Fix the parameters alignment and missing void
  (bnc#1012628).
- x86/cpu: Make alternative_msr_write work for 32-bit code
  (bnc#1012628).
- KVM: SVM: Move spec control call after restore of GS
  (bnc#1012628).
- x86/speculation: Use synthetic bits for IBRS/IBPB/STIBP
  (bnc#1012628).
- x86/cpufeatures: Disentangle MSR_SPEC_CTRL enumeration from IBRS
  (bnc#1012628).
- x86/cpufeatures: Disentangle SSBD enumeration (bnc#1012628).
- x86/cpufeatures: Add FEATURE_ZEN (bnc#1012628).
- x86/speculation: Handle HT correctly on AMD (bnc#1012628).
- x86/bugs, KVM: Extend speculation control for VIRT_SPEC_CTRL
  (bnc#1012628).
- x86/speculation: Add virtualized speculative store bypass
  disable support (bnc#1012628).
- x86/speculation: Rework speculative_store_bypass_update()
  (bnc#1012628).
- x86/bugs: Unify x86_spec_ctrl_{set_guest,restore_host}
  (bnc#1012628).
- x86/bugs: Expose x86_spec_ctrl_base directly (bnc#1012628).
- x86/bugs: Remove x86_spec_ctrl_set() (bnc#1012628).
- x86/bugs: Rework spec_ctrl base and mask logic (bnc#1012628).
- x86/speculation, KVM: Implement support for
  VIRT_SPEC_CTRL/LS_CFG (bnc#1012628).
- KVM: SVM: Implement VIRT_SPEC_CTRL support for SSBD
  (bnc#1012628).
- x86/bugs: Rename SSBD_NO to SSB_NO (bnc#1012628).
- bpf: Prevent memory disambiguation attack (bnc#1012628).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Refresh
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- commit f86282c
* Mon May 21 2018 mkubecek@suse.cz
- Makefile: disable PIE before testing asm goto (bsc#1092456).
- commit 67bdb0d
* Mon May 21 2018 mkubecek@suse.cz
- Update to 4.17-rc6
- commit 6912f6b
* Sun May 20 2018 jslaby@suse.cz
- Linux 4.16.10 (bnc#1012628).
- proc: do not access cmdline nor environ from file-backed areas
  (bnc#1012628).
- scsi: aacraid: Correct hba_send to include iu_type
  (bnc#1012628).
- net/smc: keep clcsock reference in smc_tcp_listen_work()
  (bnc#1012628).
- net: phy: sfp: fix the BR,min computation (bnc#1012628).
- net/mlx5: Fix mlx5_get_vector_affinity function (bnc#1012628).
- mlxsw: core: Fix an error handling path in
  'mlxsw_core_bus_device_register()' (bnc#1012628).
- ipv4: reset fnhe_mtu_locked after cache route flushed
  (bnc#1012628).
- hv_netvsc: Fix net device attach on older Windows hosts
  (bnc#1012628).
- tipc: fix one byte leak in tipc_sk_set_orig_addr()
  (bnc#1012628).
- tcp: restore autocorking (bnc#1012628).
- sctp: clear the new asoc's stream outcnt in sctp_stream_update
  (bnc#1012628).
- nfp: flower: set tunnel ttl value to net default (bnc#1012628).
- net: systemport: Correclty disambiguate driver instances
  (bnc#1012628).
- net/mlx5e: DCBNL fix min inline header size for dscp
  (bnc#1012628).
- mlxsw: spectrum_switchdev: Do not remove mrouter port from
  MDB's ports list (bnc#1012628).
- udp: fix SO_BINDTODEVICE (bnc#1012628).
- nsh: fix infinite loop (bnc#1012628).
- net/mlx5e: Allow offloading ipv4 header re-write for icmp
  (bnc#1012628).
- ipv6: fix uninit-value in ip6_multipath_l3_keys() (bnc#1012628).
- hv_netvsc: set master device (bnc#1012628).
- net/mlx5: Avoid cleaning flow steering table twice during
  error flow (bnc#1012628).
- net/mlx5e: TX, Use correct counter in dma_map error flow
  (bnc#1012628).
- net: sched: fix error path in tcf_proto_create() when modules
  are not configured (bnc#1012628).
- bonding: send learning packets for vlans on slave (bnc#1012628).
- bonding: do not allow rlb updates to invalid mac (bnc#1012628).
- tg3: Fix vunmap() BUG_ON() triggered from tg3_free_consistent()
  (bnc#1012628).
- tcp: ignore Fast Open on repair mode (bnc#1012628).
- tcp_bbr: fix to zero idle_restart only upon S/ACKed data
  (bnc#1012628).
- sctp: use the old asoc when making the cookie-ack chunk in
  dupcook_d (bnc#1012628).
- sctp: remove sctp_chunk_put from fail_mark err path in
  sctp_ulpevent_make_rcvmsg (bnc#1012628).
- sctp: handle two v4 addrs comparison in sctp_inet6_cmp_addr
  (bnc#1012628).
- sctp: fix the issue that the cookie-ack with auth can't get
  processed (bnc#1012628).
- sctp: delay the authentication for the duplicated cookie-echo
  chunk (bnc#1012628).
- rds: do not leak kernel memory to user land (bnc#1012628).
- r8169: fix powering up RTL8168h (bnc#1012628).
- qmi_wwan: do not steal interfaces from class drivers
  (bnc#1012628).
- openvswitch: Don't swap table in nlattr_set() after
  OVS_ATTR_NESTED is found (bnc#1012628).
- net/tls: Fix connection stall on partial tls record
  (bnc#1012628).
- net/tls: Don't recursively call push_record during
  tls_write_space callbacks (bnc#1012628).
- net: support compat 64-bit time in {s,g}etsockopt (bnc#1012628).
- net/smc: restrict non-blocking connect finish (bnc#1012628).
- net_sched: fq: take care of throttled flows before reuse
  (bnc#1012628).
- net sched actions: fix refcnt leak in skbmod (bnc#1012628).
- net/mlx5: E-Switch, Include VF RDMA stats in vport statistics
  (bnc#1012628).
- net/mlx5e: Err if asked to offload TC match on frag being first
  (bnc#1012628).
- net/mlx4_en: Verify coalescing parameters are in range
  (bnc#1012628).
- net/mlx4_en: Fix an error handling path in
  'mlx4_en_init_netdev()' (bnc#1012628).
- net: ethernet: ti: cpsw: fix packet leaking in dual_mac mode
  (bnc#1012628).
- net: ethernet: sun: niu set correct packet size in skb
  (bnc#1012628).
- llc: better deal with too small mtu (bnc#1012628).
- ipv4: fix memory leaks in udp_sendmsg, ping_v4_sendmsg
  (bnc#1012628).
- ipv4: fix fnhe usage by non-cached routes (bnc#1012628).
- dccp: fix tasklet usage (bnc#1012628).
- bridge: check iface upper dev when setting master via ioctl
  (bnc#1012628).
- 8139too: Use disable_irq_nosync() in rtl8139_poll_controller()
  (bnc#1012628).
- commit 68e48d7
* Thu May 17 2018 msuchanek@suse.de
- kernel-{binary,docs}.spec sort dependencies.
- commit d2ab971
* Thu May 17 2018 mgalbraith@suse.de
- Fix config/x86_64/debug, turn PREEMPT_NONE off, and PREEMPT_DEBUG on.
- commit 3ec7274
* Wed May 16 2018 jslaby@suse.cz
- Linux 4.16.9 (bnc#1012628).
- perf/x86: Fix possible Spectre-v1 indexing for
  x86_pmu::event_map() (bnc#1012628).
- perf/core: Fix possible Spectre-v1 indexing for ->aux_pages[]
  (bnc#1012628).
- perf/x86/msr: Fix possible Spectre-v1 indexing in the MSR driver
  (bnc#1012628).
- perf/x86/cstate: Fix possible Spectre-v1 indexing for pkg_msr
  (bnc#1012628).
- perf/x86: Fix possible Spectre-v1 indexing for hw_perf_event
  cache_* (bnc#1012628).
- tracing/uprobe_event: Fix strncpy corner case (bnc#1012628).
- sched/autogroup: Fix possible Spectre-v1 indexing for
  sched_prio_to_weight[] (bnc#1012628).
- sched/core: Fix possible Spectre-v1 indexing for
  sched_prio_to_weight[] (bnc#1012628).
- swiotlb: silent unwanted warning "buffer is full" (bnc#1012628).
- smb3: directory sync should not return an error (bnc#1012628).
- nvme: Fix sync controller reset return (bnc#1012628).
- nvme: add quirk to force medium priority for SQ creation
  (bnc#1012628).
- thermal: exynos: Propagate error value from tmu_read()
  (bnc#1012628).
- thermal: exynos: Reading temperature makes sense only when
  TMU is turned on (bnc#1012628).
- Bluetooth: btusb: Only check needs_reset_resume DMI table for
  QCA rome chipsets (bnc#1012628).
- Bluetooth: btusb: Add Dell XPS 13 9360 to
  btusb_needs_reset_resume_table (bnc#1012628).
- Revert "Bluetooth: btusb: Fix quirk for Atheros 1525/QCA6174"
  (bnc#1012628).
- arm: dts: imx[35]*: declare flexcan devices to be compatible
  to imx25's flexcan (bnc#1012628).
- cpufreq: schedutil: Avoid using invalid next_freq (bnc#1012628).
- PCI / PM: Check device_may_wakeup() in pci_enable_wake()
  (bnc#1012628).
- PCI / PM: Always check PME wakeup capability for runtime wakeup
  support (bnc#1012628).
- atm: zatm: Fix potential Spectre v1 (bnc#1012628).
- net: atm: Fix potential Spectre v1 (bnc#1012628).
- drm/atomic: Clean private obj old_state/new_state in
  drm_atomic_state_default_clear() (bnc#1012628).
- drm/atomic: Clean old_state/new_state in
  drm_atomic_state_default_clear() (bnc#1012628).
- drm/nouveau/ttm: don't dereference nvbo::cli, it can outlive
  client (bnc#1012628).
- drm/nouveau: Fix deadlock in nv50_mstm_register_connector()
  (bnc#1012628).
- drm/i915: Adjust eDP's logical vco in a reliable place
  (bnc#1012628).
- drm/i915: Fix drm:intel_enable_lvds ERROR message in kernel log
  (bnc#1012628).
- drm/ttm: Use GFP_TRANSHUGE_LIGHT for allocating huge pages
  (bnc#1012628).
- drm/vc4: Fix scaling of uni-planar formats (bnc#1012628).
- mtd: rawnand: marvell: fix command xtype in BCH write hook
  (bnc#1012628).
- mtd: rawnand: marvell: pass ms delay to wait_op (bnc#1012628).
- can: hi311x: Work around TX complete interrupt erratum
  (bnc#1012628).
- can: hi311x: Acquire SPI lock on ->do_get_berr_counter
  (bnc#1012628).
- can: kvaser_usb: Increase correct stats counter in
  kvaser_usb_rx_can_msg() (bnc#1012628).
- can: flexcan: fix endianess detection (bnc#1012628).
- ceph: fix rsize/wsize capping in ceph_direct_read_write()
  (bnc#1012628).
- mm, oom: fix concurrent munlock and oom reaper unmap, v3
  (bnc#1012628).
- mm: sections are not offlined during memory hotremove
  (bnc#1012628).
- z3fold: fix reclaim lock-ups (bnc#1012628).
- tracing: Fix regex_match_front() to not over compare the test
  string (bnc#1012628).
- dm integrity: use kvfree for kvmalloc'd memory (bnc#1012628).
- libata: Apply NOLPM quirk for SanDisk SD7UB3Q*G1001 SSDs
  (bnc#1012628).
- rfkill: gpio: fix memory leak in probe error path (bnc#1012628).
- gpio: fix error path in lineevent_create (bnc#1012628).
- gpio: fix aspeed_gpio unmask irq (bnc#1012628).
- gpioib: do not free unrequested descriptors (bnc#1012628).
- compat: fix 4-byte infoleak via uninitialized struct field
  (bnc#1012628).
- bdi: Fix oops in wb_workfn() (bnc#1012628).
- bdi: Fix use after free bug in debugfs_remove() (bnc#1012628).
- bdi: wake up concurrent wb_shutdown() callers (bnc#1012628).
- tcp: fix TCP_REPAIR_QUEUE bound checking (bnc#1012628).
- i2c: dev: prevent ZERO_SIZE_PTR deref in i2cdev_ioctl_rdwr()
  (bnc#1012628).
- perf: Remove superfluous allocation error check (bnc#1012628).
- memcg: fix per_node_info cleanup (bnc#1012628).
- bpf/tracing: fix a deadlock in perf_event_detach_bpf_prog
  (bnc#1012628).
- inetpeer: fix uninit-value in inet_getpeer (bnc#1012628).
- soreuseport: initialise timewait reuseport field (bnc#1012628).
- ipv4: fix uninit-value in ip_route_output_key_hash_rcu()
  (bnc#1012628).
- dccp: initialize ireq->ir_mark (bnc#1012628).
- net: fix uninit-value in __hw_addr_add_ex() (bnc#1012628).
- net: initialize skb->peeked when cloning (bnc#1012628).
- net: fix rtnh_ok() (bnc#1012628).
- netlink: fix uninit-value in netlink_sendmsg (bnc#1012628).
- crypto: af_alg - fix possible uninit-value in alg_bind()
  (bnc#1012628).
- rds: tcp: must use spin_lock_irq* and not spin_lock_bh with
  rds_tcp_conn_lock (bnc#1012628).
- kcm: Call strp_stop before strp_done in kcm_attach
  (bnc#1012628).
- clk: ti: fix flag space conflict with clkctrl clocks
  (bnc#1012628).
- netfilter: ebtables: don't attempt to allocate 0-sized compat
  array (bnc#1012628).
- ipvs: fix rtnl_lock lockups caused by start_sync_thread
  (bnc#1012628).
- commit 4f45b1e
* Wed May 16 2018 msuchanek@suse.de
- macros.kernel-source: Fix building non-x86 KMPs
- commit 8631d05
* Tue May 15 2018 jeffm@suse.com
- reiserfs: package in separate KMP (FATE#323394).
- commit d14f152
* Mon May 14 2018 msuchanek@suse.de
- macros.kernel-source: ignore errors when using make to print kernel release
  There is no way to handle the errors anyway and including the error into
  package version does not give good results.
- commit 282e9a6
* Mon May 14 2018 palcantara@suse.de
- cifs: smb2ops: Fix listxattr() when there are no EAs
  (bsc#1091442).
- commit c6f0d32
* Mon May 14 2018 mkubecek@suse.cz
- Update to 4.17-rc5
- commit 80e3a99
* Fri May 11 2018 msuchanek@suse.de
- Revert "kernel-binary: do not package extract-cert when not signing modules"
  This reverts commit 10a8bc496a553b8069d490a8ae7508bdb19f58d9.
- commit 1f7acca
* Wed May  9 2018 jslaby@suse.cz
- Linux 4.16.8 (bnc#1012628).
- ACPI / button: make module loadable when booted in non-ACPI mode
  (bnc#1012628).
- arm64: Add work around for Arm Cortex-A55 Erratum 1024718
  (bnc#1012628).
- ALSA: hda - Fix incorrect usage of IS_REACHABLE() (bnc#1012628).
- ALSA: pcm: Check PCM state at xfern compat ioctl (bnc#1012628).
- ALSA: seq: Fix races at MIDI encoding in
  snd_virmidi_output_trigger() (bnc#1012628).
- ALSA: dice: fix kernel NULL pointer dereference due to invalid
  calculation for array index (bnc#1012628).
- ALSA: aloop: Mark paused device as inactive (bnc#1012628).
- ALSA: aloop: Add missing cable lock to ctl API callbacks
  (bnc#1012628).
- errseq: Always report a writeback error once (bnc#1012628).
- tracepoint: Do not warn on ENOMEM (bnc#1012628).
- scsi: target: Fix fortify_panic kernel exception (bnc#1012628).
- Input: leds - fix out of bound access (bnc#1012628).
- Input: atmel_mxt_ts - add touchpad button mapping for Samsung
  Chromebook Pro (bnc#1012628).
- swiotlb: fix inversed DMA_ATTR_NO_WARN test (bnc#1012628).
- rtlwifi: cleanup 8723be ant_sel definition (bnc#1012628).
- xfs: prevent creating negative-sized file via INSERT_RANGE
  (bnc#1012628).
- tools: power/acpi, revert to LD = gcc (bnc#1012628).
- RDMA/cxgb4: release hw resources on device removal
  (bnc#1012628).
- RDMA/ucma: Allow resolving address w/o specifying source address
  (bnc#1012628).
- RDMA/mlx5: Fix multiple NULL-ptr deref errors in rereg_mr flow
  (bnc#1012628).
- RDMA/mlx4: Add missed RSS hash inner header flag (bnc#1012628).
- RDMA/mlx5: Protect from shift operand overflow (bnc#1012628).
- NET: usb: qmi_wwan: add support for ublox R410M PID 0x90b2
  (bnc#1012628).
- IB/mlx5: Use unlimited rate when static rate is not supported
  (bnc#1012628).
- infiniband: mlx5: fix build errors when INFINIBAND_USER_ACCESS=m
  (bnc#1012628).
- IB/hfi1: Fix handling of FECN marked multicast packet
  (bnc#1012628).
- IB/hfi1: Fix loss of BECN with AHG (bnc#1012628).
- IB/hfi1: Fix NULL pointer dereference when invalid num_vls is
  used (bnc#1012628).
- iw_cxgb4: Atomically flush per QP HW CQEs (bnc#1012628).
- btrfs: Take trans lock before access running trans in
  check_delayed_ref (bnc#1012628).
- drm/vc4: Make sure vc4_bo_{inc,dec}_usecnt() calls are balanced
  (bnc#1012628).
- drm/vmwgfx: Fix a buffer object leak (bnc#1012628).
- drm/bridge: vga-dac: Fix edid memory leak (bnc#1012628).
- test_firmware: fix setting old custom fw path back on exit,
  second try (bnc#1012628).
- xhci: Fix use-after-free in xhci_free_virt_device (bnc#1012628).
- USB: serial: visor: handle potential invalid device
  configuration (bnc#1012628).
- usb: dwc3: gadget: Fix list_del corruption in dwc3_ep_dequeue
  (bnc#1012628).
- USB: Accept bulk endpoints with 1024-byte maxpacket
  (bnc#1012628).
- USB: serial: option: reimplement interface masking
  (bnc#1012628).
- USB: serial: option: adding support for ublox R410M
  (bnc#1012628).
- usb: musb: host: fix potential NULL pointer dereference
  (bnc#1012628).
- usb: musb: trace: fix NULL pointer dereference in musb_g_tx()
  (bnc#1012628).
- platform/x86: asus-wireless: Fix NULL pointer dereference
  (bnc#1012628).
- platform/x86: Kconfig: Fix dell-laptop dependency chain
  (bnc#1012628).
- KVM: x86: remove APIC Timer periodic/oneshot spikes
  (bnc#1012628).
- x86/tsc: Always unregister clocksource_tsc_early (bnc#1012628).
- x86/tsc: Fix mark_tsc_unstable() (bnc#1012628).
- irqchip/qcom: Fix check for spurious interrupts (bnc#1012628).
- clocksource: Allow clocksource_mark_unstable() on unregistered
  clocksources (bnc#1012628).
- clocksource: Initialize cs->wd_list (bnc#1012628).
- clocksource: Consistent de-rate when marking unstable
  (bnc#1012628).
- tracing: Fix bad use of igrab in trace_uprobe.c (bnc#1012628).
- Delete patches.suse/tools-power-acpi-revert-to-LD-gcc.patch.
- Update config files.
- commit 9269cc1
* Mon May  7 2018 mkubecek@suse.cz
- Update to 4.17-rc4
- Eliminated 2 patches
- Update to 4.17-rc3
- Eliminated 2 patches
- commit a993a00
* Wed May  2 2018 jslaby@suse.cz
- Linux 4.16.7 (bnc#1012628).
- ext4: prevent right-shifting extents beyond EXT_MAX_BLOCKS
  (bnc#1012628).
- ext4: set h_journal if there is a failure starting a reserved
  handle (bnc#1012628).
- ext4: add MODULE_SOFTDEP to ensure crc32c is included in the
  initramfs (bnc#1012628).
- ext4: add validity checks for bitmap block numbers
  (bnc#1012628).
- ext4: fix bitmap position validation (bnc#1012628).
- random: set up the NUMA crng instances after the CRNG is fully
  initialized (bnc#1012628).
- random: fix possible sleeping allocation from irq context
  (bnc#1012628).
- random: rate limit unseeded randomness warnings (bnc#1012628).
- usbip: usbip_event: fix to not print kernel pointer address
  (bnc#1012628).
- usbip: usbip_host: fix to hold parent lock for device_attach()
  calls (bnc#1012628).
- usbip: vhci_hcd: Fix usb device and sockfd leaks (bnc#1012628).
- usbip: vhci_hcd: check rhport before using in vhci_hub_control()
  (bnc#1012628).
- Revert "xhci: plat: Register shutdown for xhci_plat"
  (bnc#1012628).
- xhci: Fix Kernel oops in xhci dbgtty (bnc#1012628).
- xhci: Fix USB ports for Dell Inspiron 5775 (bnc#1012628).
- USB: serial: simple: add libtransistor console (bnc#1012628).
- USB: serial: ftdi_sio: use jtag quirk for Arrow USB Blaster
  (bnc#1012628).
- USB: serial: cp210x: add ID for NI USB serial console
  (bnc#1012628).
- serial: mvebu-uart: Fix local flags handling on termios update
  (bnc#1012628).
- usb: typec: ucsi: Increase command completion timeout value
  (bnc#1012628).
- usb: core: Add quirk for HP v222w 16GB Mini (bnc#1012628).
- USB: Increment wakeup count on remote wakeup (bnc#1012628).
- virtio: add ability to iterate over vqs (bnc#1012628).
- virtio_console: don't tie bufs to a vq (bnc#1012628).
- virtio_console: free buffers after reset (bnc#1012628).
- virtio_console: drop custom control queue cleanup (bnc#1012628).
- virtio_console: move removal code (bnc#1012628).
- virtio_console: reset on out of memory (bnc#1012628).
- drm/virtio: fix vq wait_event condition (bnc#1012628).
- tty: Don't call panic() at tty_ldisc_init() (bnc#1012628).
- tty: n_gsm: Fix long delays with control frame timeouts in
  ADM mode (bnc#1012628).
- tty: n_gsm: Fix DLCI handling for ADM mode if debug & 2 is
  not set (bnc#1012628).
- tty: Avoid possible error pointer dereference at
  tty_ldisc_restore() (bnc#1012628).
- tty: Use __GFP_NOFAIL for tty_ldisc_get() (bnc#1012628).
- cifs: smbd: Avoid allocating iov on the stack (bnc#1012628).
- cifs: smbd: Don't use RDMA read/write when signing is used
  (bnc#1012628).
- ALSA: dice: fix OUI for TC group (bnc#1012628).
- ALSA: dice: fix error path to destroy initialized stream data
  (bnc#1012628).
- ALSA: hda - Skip jack and others for non-existing PCM streams
  (bnc#1012628).
- ALSA: opl3: Hardening for potential Spectre v1 (bnc#1012628).
- ALSA: asihpi: Hardening for potential Spectre v1 (bnc#1012628).
- ALSA: hdspm: Hardening for potential Spectre v1 (bnc#1012628).
- ALSA: rme9652: Hardening for potential Spectre v1 (bnc#1012628).
- ALSA: control: Hardening for potential Spectre v1 (bnc#1012628).
- ALSA: pcm: Return negative delays from SNDRV_PCM_IOCTL_DELAY
  (bnc#1012628).
- ALSA: core: Report audio_tstamp in snd_pcm_sync_ptr
  (bnc#1012628).
- ALSA: seq: oss: Fix unbalanced use lock for synth MIDI device
  (bnc#1012628).
- ALSA: seq: oss: Hardening for potential Spectre v1
  (bnc#1012628).
- ALSA: hda: Hardening for potential Spectre v1 (bnc#1012628).
- ALSA: hda/realtek - Add some fixes for ALC233 (bnc#1012628).
- ALSA: hda/realtek - Update ALC255 depop optimize (bnc#1012628).
- ALSA: hda/realtek - change the location for one of two front
  mics (bnc#1012628).
- mtd: spi-nor: cadence-quadspi: Fix page fault kernel panic
  (bnc#1012628).
- mtd: cfi: cmdset_0001: Do not allow read/write to suspend
  erase block (bnc#1012628).
- mtd: cfi: cmdset_0001: Workaround Micron Erase suspend bug
  (bnc#1012628).
- mtd: cfi: cmdset_0002: Do not allow read/write to suspend
  erase block (bnc#1012628).
- mtd: rawnand: tango: Fix struct clk memory leak (bnc#1012628).
- mtd: rawnand: marvell: fix the chip-select DT parsing logic
  (bnc#1012628).
- kobject: don't use WARN for registration failures (bnc#1012628).
- scsi: sd_zbc: Avoid that resetting a zone fails sporadically
  (bnc#1012628).
- scsi: sd: Defer spinning up drive while SANITIZE is in progress
  (bnc#1012628).
- blk-mq: start request gstate with gen 1 (bnc#1012628).
- bfq-iosched: ensure to clear bic/bfqq pointers when preparing
  request (bnc#1012628).
- block: do not use interruptible wait anywhere (bnc#1012628).
- vfio: ccw: process ssch with interrupts disabled (bnc#1012628).
- SMB311: Fix reconnect (bnc#1012628).
- ANDROID: binder: prevent transactions into own process
  (bnc#1012628).
- PCI: aardvark: Fix logic in advk_pcie_{rd,wr}_conf()
  (bnc#1012628).
- PCI: aardvark: Set PIO_ADDR_LS correctly in advk_pcie_rd_conf()
  (bnc#1012628).
- PCI: aardvark: Use ISR1 instead of ISR0 interrupt in legacy
  irq mode (bnc#1012628).
- PCI: aardvark: Fix PCIe Max Read Request Size setting
  (bnc#1012628).
- ARM: amba: Make driver_override output consistent with other
  buses (bnc#1012628).
- ARM: amba: Fix race condition with driver_override
  (bnc#1012628).
- ARM: amba: Don't read past the end of sysfs "driver_override"
  buffer (bnc#1012628).
- ARM: dts: Fix NAS4220B pin config (bnc#1012628).
- ARM: socfpga_defconfig: Remove QSPI Sector 4K size force
  (bnc#1012628).
- KVM: arm/arm64: Close VMID generation race (bnc#1012628).
- slimbus: Fix out-of-bounds access in slim_slicesize()
  (bnc#1012628).
- powerpc/mm: Flush cache on memory hot(un)plug (bnc#1012628).
- powerpc/mce: Fix a bug where mce loops on memory UE
  (bnc#1012628).
- powerpc/powernv/npu: Do a PID GPU TLB flush when invalidating
  a large address range (bnc#1012628).
- crypto: drbg - set freed buffers to NULL (bnc#1012628).
- ASoC: dmic: Fix clock parenting (bnc#1012628).
- ASoC: fsl_esai: Fix divisor calculation failure at lower ratio
  (bnc#1012628).
- libceph: un-backoff on tick when we have a authenticated session
  (bnc#1012628).
- libceph: reschedule a tick in finish_hunting() (bnc#1012628).
- libceph: validate con->state at the top of try_write()
  (bnc#1012628).
- PCI / PM: Do not clear state_saved in pci_pm_freeze() when
  smart suspend is set (bnc#1012628).
- virt: vbox: Move declarations of vboxguest private functions
  to private header (bnc#1012628).
- virt: vbox: Add vbg_req_free() helper function (bnc#1012628).
- virt: vbox: Use __get_free_pages instead of kmalloc for DMA32
  memory (bnc#1012628).
- fpga-manager: altera-ps-spi: preserve nCONFIG state
  (bnc#1012628).
- module: Fix display of wrong module .text address (bnc#1012628).
- earlycon: Use a pointer table to fix __earlycon_table stride
  (bnc#1012628).
- cpufreq: powernv: Fix hardlockup due to synchronous smp_call
  in timer interrupt (bnc#1012628).
- rtc: opal: Fix OPAL RTC driver OPAL_BUSY loops (bnc#1012628).
- drm/edid: Reset more of the display info (bnc#1012628).
- drm/amdgpu: set COMPUTE_PGM_RSRC1 for SGPR/VGPR clearing shaders
  (bnc#1012628).
- drm/i915/fbdev: Enable late fbdev initial configuration
  (bnc#1012628).
- drm/i915/audio: set minimum CD clock to twice the BCLK
  (bnc#1012628).
- drm/i915: Enable display WA#1183 from its correct spot
  (bnc#1012628).
- drm/amd/display: Fix deadlock when flushing irq (bnc#1012628).
- drm/amd/display: Don't read EDID in atomic_check (bnc#1012628).
- drm/amd/display: Disallow enabling CRTC without primary plane
  with FB (bnc#1012628).
- x86/ipc: Fix x32 version of shmid64_ds and msqid64_ds
  (bnc#1012628).
- x86/smpboot: Don't use mwait_play_dead() on AMD systems
  (bnc#1012628).
- x86/microcode/intel: Save microcode patch unconditionally
  (bnc#1012628).
- x86/microcode: Do not exit early from __reload_late()
  (bnc#1012628).
- tick/sched: Do not mess with an enqueued hrtimer (bnc#1012628).
- crypto: ccp - add check to get PSP master only when PSP is
  detected (bnc#1012628).
- arm/arm64: KVM: Add PSCI version selection API (bnc#1012628).
- sparc64: Fix mistake in oradax license text (bnc#1012628).
- commit 938738d
* Wed May  2 2018 msuchanek@suse.de
- kernel-binary: also default klp_symbols to 0 here.
- commit e35f14a
* Wed May  2 2018 msuchanek@suse.de
- klp_symbols: make --klp-symbols argument semantic sane
  It selects build of klp symbols and defaults to off
- commit 0e53042
* Wed May  2 2018 jslaby@suse.cz
- tools: power/acpi, revert to LD = gcc (build fix).
- Delete
  patches.suse/revert-tools-fix-cross-compile-var-clobbering.patch.
  Replace by the upstream commit.
- commit ad991e8
* Mon Apr 30 2018 jslaby@suse.cz
- Linux 4.16.6 (bnc#1012628).
- Revert "pinctrl: intel: Initialize GPIO properly when used
  through irqchip" (bnc#1012628).
- drm: bridge: dw-hdmi: Fix overflow workaround for Amlogic
  Meson GX SoCs (bnc#1012628).
- i40e: Fix attach VF to VM issue (bnc#1012628).
- tpm: cmd_ready command can be issued only after granting
  locality (bnc#1012628).
- tpm: tpm-interface: fix tpm_transmit/_cmd kdoc (bnc#1012628).
- tpm: add retry logic (bnc#1012628).
- bonding: do not set slave_dev npinfo before slave_enable_netpoll
  in bond_enslave (bnc#1012628).
- docs: ip-sysctl.txt: fix name of some ipv6 variables
  (bnc#1012628).
- ipv6: add RTA_TABLE and RTA_PREFSRC to rtm_ipv6_policy
  (bnc#1012628).
- ipv6: sr: fix NULL pointer dereference in seg6_do_srh_encap()-
  v4 pkts (bnc#1012628).
- KEYS: DNS: limit the length of option strings (bnc#1012628).
- l2tp: check sockaddr length in pppol2tp_connect() (bnc#1012628).
- llc: delete timers synchronously in llc_sk_free() (bnc#1012628).
- net: af_packet: fix race in PACKET_{R|T}X_RING (bnc#1012628).
- net: fix deadlock while clearing neighbor proxy table
  (bnc#1012628).
- net: mvpp2: Fix DMA address mask size (bnc#1012628).
- net: qmi_wwan: add Wistron Neweb D19Q1 (bnc#1012628).
- net/smc: fix shutdown in state SMC_LISTEN (bnc#1012628).
- net: stmmac: Disable ACS Feature for GMAC >= 4 (bnc#1012628).
- packet: fix bitfield update race (bnc#1012628).
- pppoe: check sockaddr length in pppoe_connect() (bnc#1012628).
- Revert "macsec: missing dev_put() on error in macsec_newlink()"
  (bnc#1012628).
- sctp: do not check port in sctp_inet6_cmp_addr (bnc#1012628).
- strparser: Do not call mod_delayed_work with a timeout of
  LONG_MAX (bnc#1012628).
- strparser: Fix incorrect strp->need_bytes value (bnc#1012628).
- tcp: clear tp->packets_out when purging write queue
  (bnc#1012628).
- tcp: don't read out-of-bounds opsize (bnc#1012628).
- tcp: md5: reject TCP_MD5SIG or TCP_MD5SIG_EXT on established
  sockets (bnc#1012628).
- team: avoid adding twice the same option to the event list
  (bnc#1012628).
- team: fix netconsole setup over team (bnc#1012628).
- tipc: add policy for TIPC_NLA_NET_ADDR (bnc#1012628).
- vlan: Fix reading memory beyond skb->tail in
  skb_vlan_tagged_multi (bnc#1012628).
- vmxnet3: fix incorrect dereference when rxvlan is disabled
  (bnc#1012628).
- amd-xgbe: Add pre/post auto-negotiation phy hooks (bnc#1012628).
- amd-xgbe: Improve KR auto-negotiation and training
  (bnc#1012628).
- amd-xgbe: Only use the SFP supported transceiver signals
  (bnc#1012628).
- net: sched: ife: signal not finding metaid (bnc#1012628).
- net: sched: ife: handle malformed tlv length (bnc#1012628).
- net: sched: ife: check on metadata length (bnc#1012628).
- l2tp: hold reference on tunnels in netlink dumps (bnc#1012628).
- l2tp: hold reference on tunnels printed in pppol2tp proc file
  (bnc#1012628).
- l2tp: hold reference on tunnels printed in l2tp/tunnels debugfs
  file (bnc#1012628).
- l2tp: fix {pppol2tp, l2tp_dfs}_seq_stop() in case of seq_file
  overflow (bnc#1012628).
- llc: hold llc_sap before release_sock() (bnc#1012628).
- llc: fix NULL pointer deref for SOCK_ZAPPED (bnc#1012628).
- s390/qeth: fix error handling in adapter command callbacks
  (bnc#1012628).
- s390/qeth: avoid control IO completion stalls (bnc#1012628).
- s390/qeth: handle failure on workqueue creation (bnc#1012628).
- net: ethernet: ti: cpsw: fix tx vlan priority mapping
  (bnc#1012628).
- net: validate attribute sizes in neigh_dump_table()
  (bnc#1012628).
- bnxt_en: Fix memory fault in bnxt_ethtool_init() (bnc#1012628).
- virtio-net: add missing virtqueue kick when flushing packets
  (bnc#1012628).
- VSOCK: make af_vsock.ko removable again (bnc#1012628).
- net: aquantia: Regression on reset with 1.x firmware
  (bnc#1012628).
- tun: fix vlan packet truncation (bnc#1012628).
- net: aquantia: oops when shutdown on already stopped device
  (bnc#1012628).
- virtio_net: split out ctrl buffer (bnc#1012628).
- virtio_net: fix adding vids on big-endian (bnc#1012628).
- Revert "mm/hmm: fix header file if/else/endif maze"
  (bnc#1012628).
- commoncap: Handle memory allocation failure (bnc#1012628).
- scsi: mptsas: Disable WRITE SAME (bnc#1012628).
- cdrom: information leak in cdrom_ioctl_media_changed()
  (bnc#1012628).
- fsnotify: Fix fsnotify_mark_connector race (bnc#1012628).
- m68k/mac: Don't remap SWIM MMIO region (bnc#1012628).
- block/swim: Check drive type (bnc#1012628).
- block/swim: Don't log an error message for an invalid ioctl
  (bnc#1012628).
- block/swim: Remove extra put_disk() call from error path
  (bnc#1012628).
- block/swim: Rename macros to avoid inconsistent inverted logic
  (bnc#1012628).
- block/swim: Select appropriate drive on device open
  (bnc#1012628).
- block/swim: Fix array bounds check (bnc#1012628).
- block/swim: Fix IO error at end of medium (bnc#1012628).
- tracing: Fix missing tab for hwlat_detector print format
  (bnc#1012628).
- hwmon: (k10temp) Add temperature offset for Ryzen 2700X
  (bnc#1012628).
- hwmon: (k10temp) Add support for AMD Ryzen w/ Vega graphics
  (bnc#1012628).
- s390/cio: update chpid descriptor after resource accessibility
  event (bnc#1012628).
- s390/dasd: fix IO error for newly defined devices (bnc#1012628).
- s390/uprobes: implement arch_uretprobe_is_alive() (bnc#1012628).
- s390/cpum_cf: rename IBM z13/z14 counter names (bnc#1012628).
- kprobes: Fix random address output of blacklist file
  (bnc#1012628).
- ACPI / video: Only default only_lcd to true on Win8-ready
  _desktops_ (bnc#1012628).
- commit 566acbc
* Mon Apr 30 2018 mkubecek@suse.cz
- Update to 4.17-rc3
- Eliminated 1 patch
- Config changes:
  - x86_64 and i386
  - SND_SST_ATOM_HIFI2_PLATFORM_ACPI=m
  - armv7hl
  - CONFIG_NFT_REDIR_IPV4=m (sync with other configs)
  - CONFIG_NFT_REDIR_IPV6=m (sync with other configs)
- commit 088acbb
* Sun Apr 29 2018 afaerber@suse.de
- config: armv7hl: Update to 4.17-rc2
- commit e76ffdc
* Sun Apr 29 2018 afaerber@suse.de
- config: armv6hl: Update to 4.17-rc2
- commit 7ac1254
* Sun Apr 29 2018 afaerber@suse.de
- config: arm64: Update to 4.17-rc2
- commit 8535e20
* Fri Apr 27 2018 msuchanek@suse.de
- kernel-binary: only install modules.fips on modular kernels.
- commit 2cb2bec
* Thu Apr 26 2018 jslaby@suse.cz
- Linux 4.16.5 (bnc#1012628).
- cifs: smbd: Check for iov length on sending the last iov
  (bnc#1012628).
- cifs: do not allow creating sockets except with SMB1 posix
  exensions (bnc#1012628).
- btrfs: fix unaligned access in readdir (bnc#1012628).
- btrfs: Fix race condition between delayed refs and blockgroup
  removal (bnc#1012628).
- x86/acpi: Prevent X2APIC id 0xffffffff from being accounted
  (bnc#1012628).
- clocksource/imx-tpm: Correct -ETIME return condition check
  (bnc#1012628).
- posix-cpu-timers: Ensure set_process_cpu_timer is always
  evaluated (bnc#1012628).
- x86/tsc: Prevent 32bit truncation in calc_hpet_ref()
  (bnc#1012628).
- drm/vc4: Fix memory leak during BO teardown (bnc#1012628).
- drm/i915/gvt: throw error on unhandled vfio ioctls
  (bnc#1012628).
- drm/i915/gvt: Add drm_format_mod update (bnc#1012628).
- drm/i915/bios: filter out invalid DDC pins from VBT child
  devices (bnc#1012628).
- drm/i915/audio: Fix audio detection issue on GLK (bnc#1012628).
- drm/i915: Do no use kfree() to free a kmem_cache_alloc()
  return value (bnc#1012628).
- drm/i915: Fix LSPCON TMDS output buffer enabling from low-power
  state (bnc#1012628).
- alarmtimer: Init nanosleep alarm timer on stack (bnc#1012628).
- mm,vmscan: Allow preallocating memory for register_shrinker()
  (bnc#1012628).
- netfilter: x_tables: cap allocations at 512 mbyte (bnc#1012628).
- netfilter: x_tables: add counters allocation wrapper
  (bnc#1012628).
- netfilter: compat: prepare xt_compat_init_offsets to return
  errors (bnc#1012628).
- netfilter: compat: reject huge allocation requests
  (bnc#1012628).
- netfilter: x_tables: limit allocation requests for blob rule
  heads (bnc#1012628).
- perf: Fix sample_max_stack maximum check (bnc#1012628).
- perf: Return proper values for user stack errors (bnc#1012628).
- RDMA/mlx5: Fix NULL dereference while accessing XRC_TGT QPs
  (bnc#1012628).
- Revert "KVM: X86: Fix SMRAM accessing even if VM is shutdown"
  (bnc#1012628).
- mac80211_hwsim: fix use-after-free bug in hwsim_exit_net
  (bnc#1012628).
- Refresh
  patches.suse/btrfs-fs-super.c-add-new-super-block-devices-super_block_d.patch.
- commit 16c5ff9
* Wed Apr 25 2018 tiwai@suse.de
- Revert "ath10k: send (re)assoc peer command when NSS changed"
  (bsc#1090458).
- commit 3f3a85c
* Tue Apr 24 2018 msuchanek@suse.de
- split-modules: use MAKE_ARGS
- commit d8fe174
* Tue Apr 24 2018 mcgrof@suse.com
- xfs: set format back to extents if xfs_bmap_extents_to_btree (bsc#1090717, CVE-2018-10323).
- xfs: set format back to extents if xfs_bmap_extents_to_btree
  (bsc#1090717, CVE-2018-10323).
- commit ddcd6f2
* Tue Apr 24 2018 msuchanek@suse.de
- kernel-binary: pass MAKE_ARGS to install script as well.
- commit ce62ae7
* Tue Apr 24 2018 mkubecek@suse.cz
- Update config files.
- commit becf16d
* Tue Apr 24 2018 msuchanek@suse.de
- kernel-binary: pass ARCH= to kernel build
  Recent kernel does not save CONFIG_64BIT so it has to be specified by
  arch.
- commit fb21b73
* Tue Apr 24 2018 tiwai@suse.de
- ALSA: usb-audio: Skip broken EU on Dell dock USB-audio
  (bsc#1090658).
- commit 5639170
* Tue Apr 24 2018 mkubecek@suse.cz
- config: fix i386 configs
  Since mainline commit f467c5640c29 ("kconfig: only write '# CONFIG_FOO is
  not set' for visible symbols"), make silentoldconfig (or make syncconfig as
  it is called now) doesn't add CONFIG_64BIT line into i386 configs if called
  with ARCH=i386.
  During the build, it's called without ARCH=i386 so that it requests this
  option to be entered manually and the build fails. Long term solution would
  probably be passing ARCH=%%{cpu_arch} to all make commands; for now, just
  add CONFIG_64BIT line to i386/pae to fix the build as is.
- commit d9a33ad
* Tue Apr 24 2018 jslaby@suse.cz
- Linux 4.16.4 (bnc#1012628).
- Bluetooth: hci_bcm: Add irq_polarity module option
  (bnc#1012628).
- cpufreq: CPPC: Use transition_delay_us depending
  transition_latency (bnc#1012628).
- cpufreq: armada-37xx: Fix clock leak (bnc#1012628).
- ubifs: Check ubifs_wbuf_sync() return code (bnc#1012628).
- ubi: fastmap: Don't flush fastmap work on detach (bnc#1012628).
- ubi: Fix error for write access (bnc#1012628).
- ubi: Reject MLC NAND (bnc#1012628).
- mm/ksm.c: fix inconsistent accounting of zero pages
  (bnc#1012628).
- mm/hmm: fix header file if/else/endif maze (bnc#1012628).
- mm/hmm: hmm_pfns_bad() was accessing wrong struct (bnc#1012628).
- mm: hwpoison: disable memory error handling on 1GB hugepage
  (bnc#1012628).
- task_struct: only use anon struct under randstruct plugin
  (bnc#1012628).
- fs/reiserfs/journal.c: add missing resierfs_warning() arg
  (bnc#1012628).
- ipc/shm: fix use-after-free of shm file via remap_file_pages()
  (bnc#1012628).
- mm, slab: reschedule cache_reap() on the same CPU (bnc#1012628).
- usb: musb: gadget: misplaced out of bounds check (bnc#1012628).
- phy: allwinner: sun4i-usb: poll vbus changes on A23/A33 when
  driving VBUS (bnc#1012628).
- usb: gadget: udc: core: update usb_ep_queue() documentation
  (bnc#1012628).
- ARM64: dts: meson: reduce odroid-c2 eMMC maximum rate
  (bnc#1012628).
- KVM: arm/arm64: vgic-its: Fix potential overrun in
  vgic_copy_lpi_list (bnc#1012628).
- ARM: EXYNOS: Fix coupled CPU idle freeze on Exynos4210
  (bnc#1012628).
- arm: dts: mt7623: fix USB initialization fails on bananapi-r2
  (bnc#1012628).
- ARM: dts: at91: at91sam9g25: fix mux-mask pinctrl property
  (bnc#1012628).
- ARM: dts: exynos: Fix IOMMU support for GScaler devices on
  Exynos5250 (bnc#1012628).
- ARM: dts: at91: sama5d4: fix pinctrl compatible string
  (bnc#1012628).
- spi: atmel: init FIFOs before spi enable (bnc#1012628).
- spi: Fix scatterlist elements size in spi_map_buf (bnc#1012628).
- spi: Fix unregistration of controller with fixed SPI bus number
  (bnc#1012628).
- media: rc: oops in ir_timer_keyup after device unplug
  (bnc#1012628).
- media: atomisp_fops.c: disable atomisp_compat_ioctl32
  (bnc#1012628).
- media: vivid: check if the cec_adapter is valid (bnc#1012628).
- media: vb2: core: Finish buffers at the end of the stream
  (bnc#1012628).
- media: vsp1: Fix BRx conditional path in WPF (bnc#1012628).
- x86/xen: Delay get_cpu_cap until stack canary is established
  (bnc#1012628).
- regmap: Fix reversed bounds check in regmap_raw_write()
  (bnc#1012628).
- ACPI / video: Add quirk to force acpi-video backlight on
  Samsung 670Z5E (bnc#1012628).
- ACPI / hotplug / PCI: Check presence of slot itself in
  get_slot_status() (bnc#1012628).
- acpi, nfit: rework NVDIMM leaf method detection (bnc#1012628).
- USB: gadget: f_midi: fixing a possible double-free in f_midi
  (bnc#1012628).
- USB:fix USB3 devices behind USB3 hubs not resuming at hibernate
  thaw (bnc#1012628).
- usb: dwc3: prevent setting PRTCAP to OTG from debugfs
  (bnc#1012628).
- usb: dwc3: pci: Properly cleanup resource (bnc#1012628).
- usb: dwc3: gadget: never call ->complete() from ->ep_queue()
  (bnc#1012628).
- cifs: fix memory leak in SMB2_open() (bnc#1012628).
- fix smb3-encryption breakage when CONFIG_DEBUG_SG=y
  (bnc#1012628).
- Tree connect for SMB3.1.1 must be signed for non-encrypted
  shares (bnc#1012628).
- cifs: smbd: avoid reconnect lockup (bnc#1012628).
- cifs: smbd: disconnect transport on RDMA errors (bnc#1012628).
- smb3: Fix root directory when server returns inode number of
  zero (bnc#1012628).
- HID: i2c-hid: fix size check and type usage (bnc#1012628).
- i2c: i801: Save register SMBSLVCMD value only once
  (bnc#1012628).
- i2c: i801: Restore configuration at shutdown (bnc#1012628).
- CIFS: refactor crypto shash/sdesc allocation&free (bnc#1012628).
- CIFS: add sha512 secmech (bnc#1012628).
- CIFS: implement v3.11 preauth integrity (bnc#1012628).
- CIFS: fix sha512 check in cifs_crypto_secmech_release
  (bnc#1012628).
- powerpc/64s: Fix pkey support in dt_cpu_ftrs, add CPU_FTR_PKEY
  bit (bnc#1012628).
- powerpc/powernv: Handle unknown OPAL errors in
  opal_nvram_write() (bnc#1012628).
- powerpc/eeh: Fix race with driver un/bind (bnc#1012628).
- powerpc/64s: Fix dt_cpu_ftrs to have restore_cpu clear unwanted
  LPCR bits (bnc#1012628).
- powerpc/64: Call H_REGISTER_PROC_TBL when running as a HPT
  guest on POWER9 (bnc#1012628).
- powerpc/64: Fix smp_wmb barrier definition use use lwsync
  consistently (bnc#1012628).
- powerpc/kprobes: Fix call trace due to incorrect preempt count
  (bnc#1012628).
- powerpc/kexec_file: Fix error code when trying to load kdump
  kernel (bnc#1012628).
- powerpc/powernv: define a standard delay for OPAL_BUSY type
  retry loops (bnc#1012628).
- powerpc/powernv: Fix OPAL NVRAM driver OPAL_BUSY loops
  (bnc#1012628).
- powerpc/mm/radix: Fix checkstops caused by invalid tlbiel
  (bnc#1012628).
- ceph: always update atime/mtime/ctime for new inode
  (bnc#1012628).
- HID: Fix hid_report_len usage (bnc#1012628).
- HID: core: Fix size as type u32 (bnc#1012628).
- soc: mediatek: fix the mistaken pointer accessed when subdomains
  are added (bnc#1012628).
- ASoC: ssm2602: Replace reg_default_raw with reg_default
  (bnc#1012628).
- ASoC: topology: Fix kcontrol name string handling (bnc#1012628).
- thunderbolt: Wait a bit longer for ICM to authenticate the
  active NVM (bnc#1012628).
- thunderbolt: Serialize PCIe tunnel creation with PCI rescan
  (bnc#1012628).
- thunderbolt: Resume control channel after hibernation image
  is created (bnc#1012628).
- thunderbolt: Handle connecting device in place of host properly
  (bnc#1012628).
- thunderbolt: Prevent crash when ICM firmware is not running
  (bnc#1012628).
- irqchip/gic: Take lock when updating irq type (bnc#1012628).
- random: use a tighter cap in credit_entropy_bits_safe()
  (bnc#1012628).
- extcon: intel-cht-wc: Set direction and drv flags for V5 boost
  GPIO (bnc#1012628).
- block: use 32-bit blk_status_t on Alpha (bnc#1012628).
- jbd2: if the journal is aborted then don't allow update of
  the log tail (bnc#1012628).
- ext4: shutdown should not prevent get_write_access
  (bnc#1012628).
- ext4: eliminate sleep from shutdown ioctl (bnc#1012628).
- ext4: pass -ESHUTDOWN code to jbd2 layer (bnc#1012628).
- ext4: don't update checksum of new initialized bitmaps
  (bnc#1012628).
- ext4: protect i_disksize update by i_data_sem in direct write
  path (bnc#1012628).
- ext4: fix offset overflow on 32-bit archs in ext4_iomap_begin()
  (bnc#1012628 bsc#1079747).
- ext4: limit xattr size to INT_MAX (bnc#1012628).
- ext4: fail ext4_iget for root directory if unallocated
  (bnc#1012628).
- ext4: always initialize the crc32c checksum driver
  (bnc#1012628).
- ext4: don't allow r/w mounts if metadata blocks overlap the
  superblock (bnc#1012628).
- ext4: move call to ext4_error() into ext4_xattr_check_block()
  (bnc#1012628).
- ext4: add bounds checking to ext4_xattr_find_entry()
  (bnc#1012628).
- ext4: add extra checks to ext4_xattr_block_get() (bnc#1012628).
- ext4: force revalidation of directory pointer after seekdir(2)
  (bnc#1012628).
- dm: backfill abnormal IO support to non-splitting IO submission
  (bnc#1012628).
- dm crypt: limit the number of allocated pages (bnc#1012628).
- RDMA/ucma: Don't allow setting RDMA_OPTION_IB_PATH without an
  RDMA device (bnc#1012628).
- RDMA/mlx5: Protect from NULL pointer derefence (bnc#1012628).
- RDMA/rxe: Fix an out-of-bounds read (bnc#1012628).
- RDMA/core: Avoid that ib_drain_qp() triggers an out-of-bounds
  stack access (bnc#1012628).
- xprtrdma: Fix latency regression on NUMA NFS/RDMA clients
  (bnc#1012628).
- xprtrdma: Fix corner cases when handling device removal
  (bnc#1012628).
- ALSA: pcm: Avoid potential races between OSS ioctls and
  read/write (bnc#1012628).
- ALSA: pcm: Return -EBUSY for OSS ioctls changing busy streams
  (bnc#1012628).
- ALSA: pcm: Fix mutex unbalance in OSS emulation ioctls
  (bnc#1012628).
- ALSA: pcm: Fix UAF at PCM release via PCM timer access
  (bnc#1012628).
- ALSA: pcm: Fix endless loop for XRUN recovery in OSS emulation
  (bnc#1012628).
- IB/srp: Fix srp_abort() (bnc#1012628).
- IB/srp: Fix completion vector assignment algorithm
  (bnc#1012628).
- IB/srpt: Fix an out-of-bounds stack access in
  srpt_zerolength_write() (bnc#1012628).
- drivers/infiniband/core/verbs.c: fix build with gcc-4.4.4
  (bnc#1012628).
- drivers/infiniband/ulp/srpt/ib_srpt.c: fix build with gcc-4.4.4
  (bnc#1012628).
- dm raid: fix nosync status (bnc#1012628).
- dmaengine: at_xdmac: fix rare residue corruption (bnc#1012628).
- cxl: Fix possible deadlock when processing page faults from
  cxllib (bnc#1012628).
- tpm: self test failure should not cause suspend to fail
  (bnc#1012628).
- libnvdimm, dimm: fix dpa reservation vs uninitialized label area
  (bnc#1012628).
- libnvdimm, namespace: use a safe lookup for dimm device name
  (bnc#1012628).
- vsprintf: Do not preprocess non-dereferenced pointers for
  bprintf (%%px and %%pK) (bnc#1012628).
- nfit, address-range-scrub: fix scrub in-progress reporting
  (bnc#1012628).
- nfit: skip region registration for incomplete control regions
  (bnc#1012628).
- ring-buffer: Check if memory is available before allocation
  (bnc#1012628).
- um: Compile with modern headers (bnc#1012628).
- um: Use POSIX ucontext_t instead of struct ucontext
  (bnc#1012628).
- iommu/vt-d: Fix a potential memory leak (bnc#1012628).
- mmc: core: Prevent bus reference leak in mmc_blk_init()
  (bnc#1012628).
- mmc: jz4740: Fix race condition in IRQ mask update
  (bnc#1012628).
- mmc: tmio: Fix error handling when issuing CMD23 (bnc#1012628).
- Revert "drm/amd/display: fix dereferencing possible ERR_PTR()"
  (bnc#1012628).
- drm/amd/display: HDMI has no sound after Panel power off/on
  (bnc#1012628).
- trace_uprobe: Use %%lx to display offset (bnc#1012628).
- PCI: Mark Broadcom HT1100 and HT2000 Root Port Extended Tags
  as broken (bnc#1012628).
- clk: mvebu: armada-38x: add support for missing clocks
  (bnc#1012628).
- clk: fix false-positive Wmaybe-uninitialized warning
  (bnc#1012628).
- clk: mediatek: fix PWM clock source by adding a fixed-factor
  clock (bnc#1012628).
- clk: bcm2835: De-assert/assert PLL reset signal when appropriate
  (bnc#1012628).
- clk: tegra: Mark HCLK, SCLK and EMC as critical (bnc#1012628).
- pwm: rcar: Fix a condition to prevent mismatch value setting
  to duty (bnc#1012628).
- pwm: mediatek: Fix up PWM4 and PWM5 malfunction on MT7623
  (bnc#1012628).
- pwm: mediatek: Improve precision in rate calculation
  (bnc#1012628).
- thermal: imx: Fix race condition in imx_thermal_probe()
  (bnc#1012628).
- dt-bindings: clock: mediatek: add binding for fixed-factor
  clock axisel_d4 (bnc#1012628).
- watchdog: f71808e_wdt: Fix WD_EN register read (bnc#1012628).
- drm/amdgpu: Add an ATPX quirk for hybrid laptop (bnc#1012628).
- drm/amdgpu: Fix always_valid bos multiple LRU insertions
  (bnc#1012628).
- drm/amdgpu/sdma: fix mask in emit_pipeline_sync (bnc#1012628).
- drm/amdgpu: Fix PCIe lane width calculation (bnc#1012628).
- drm/amdgpu/si: implement get/set pcie_lanes asic callback
  (bnc#1012628).
- drm/rockchip: Clear all interrupts before requesting the IRQ
  (bnc#1012628).
- drm/radeon: add PX quirk for Asus K73TK (bnc#1012628).
- drm/radeon: Fix PCIe lane width calculation (bnc#1012628).
- ALSA: line6: Use correct endpoint type for midi output
  (bnc#1012628).
- ALSA: rawmidi: Fix missing input substream checks in compat
  ioctls (bnc#1012628).
- ALSA: hda - New VIA controller suppor no-snoop path
  (bnc#1012628).
- ALSA: hda/realtek - set PINCFG_HEADSET_MIC to parse_flags
  (bnc#1012628).
- ALSA: hda/realtek - adjust the location of one mic
  (bnc#1012628).
- random: fix crng_ready() test (bnc#1012628).
- random: use a different mixing algorithm for
  add_device_randomness() (bnc#1012628).
- random: crng_reseed() should lock the crng instance that it
  is modifying (bnc#1012628).
- random: add new ioctl RNDRESEEDCRNG (bnc#1012628).
- HID: i2c-hid: Fix resume issue on Raydium touchscreen device
  (bnc#1012628).
- HID: input: fix battery level reporting on BT mice
  (bnc#1012628).
- HID: hidraw: Fix crash on HIDIOCGFEATURE with a destroyed device
  (bnc#1012628).
- HID: wacom: bluetooth: send exit report for recent Bluetooth
  devices (bnc#1012628).
- s390: add support for IBM z14 Model ZR1 (bnc#1012628).
- MIPS: uaccess: Add micromips clobbers to bzero invocation
  (bnc#1012628).
- MIPS: memset.S: EVA & fault support for small_memset
  (bnc#1012628).
- MIPS: memset.S: Fix return of __clear_user from Lpartial_fixup
  (bnc#1012628).
- MIPS: memset.S: Fix clobber of v1 in last_fixup (bnc#1012628).
- powerpc/eeh: Fix enabling bridge MMIO windows (bnc#1012628).
- powerpc/xive: Fix trying to "push" an already active pool VP
  (bnc#1012628).
- powerpc/lib: Fix off-by-one in alternate feature patching
  (bnc#1012628).
- udf: Fix leak of UTF-16 surrogates into encoded strings
  (bnc#1012628).
- fanotify: fix logic of events on child (bnc#1012628).
- mmc: sdhci-pci: Only do AMD tuning for HS200 (bnc#1012628).
- drm/i915: Fix hibernation with ACPI S0 target state
  (bnc#1012628).
- drm/i915: Correctly handle limited range YCbCr data on VLV/CHV
  (bnc#1012628).
- jffs2_kill_sb(): deal with failed allocations (bnc#1012628).
- hypfs_kill_super(): deal with failed allocations (bnc#1012628).
- orangefs_kill_sb(): deal with allocation failures (bnc#1012628).
- rpc_pipefs: fix double-dput() (bnc#1012628).
- Don't leak MNT_INTERNAL away from internal mounts (bnc#1012628).
- libnvdimm, dimm: handle EACCES failures from label reads
  (bnc#1012628).
- device-dax: allow MAP_SYNC to succeed (bnc#1012628).
- autofs: mount point create should honour passed in mode
  (bnc#1012628).
- mm/filemap.c: fix NULL pointer in page_cache_tree_insert()
  (bnc#1012628).
- drm/i915/gvt: init mmio by lri command in vgpu inhibit context
  (bnc#1012628).
- HID: i2c-hid: fix inverted return value from i2c_hid_command()
  (bnc#1012628).
- writeback: safer lock nesting (bnc#1012628).
- Delete
  patches.suse/ext4-llseek-do-not-crop-offset-on-32bit.patch.
- commit 2ebc2ec
* Tue Apr 24 2018 mkubecek@suse.cz
- Documentation: typec.rst: Use literal-block element with
  ascii art.
- commit 1aebada
* Mon Apr 23 2018 jeffm@suse.com
- README.BRANCH: Added Michal Kubecek as co-maintainer.
- commit 53ecad7
* Mon Apr 23 2018 mkubecek@suse.cz
- Update to 4.17-rc2
- Eliminated 2 patches
- Config changes:
  - s390x:
  - KEXEC_FILE=y
- commit 8aad964
* Fri Apr 20 2018 mkubecek@suse.cz
- Update to 4.17-rc1.
- Eliminated 55 patches (51 stable 4.16.x)
- ARM configs need updating.
- Config changes:
  - x86:
  - ACPI_TAD=m
  - s390:
  - EXPOLINE_FULL=y
  - VT=y
  - CONSOLE_TRANSLATIONS=y
  - VT_CONSOLE=y
  - VT_HW_CONSOLE_BINDING=n
  - DUMMY_CONSOLE_COLUMNS=80
  - DUMMY_CONSOLE_ROWS=25
  - SPEAKUP=n
  - Network:
  - NF_TABLES_INET=y
  - NF_TABLES_NETDEV=y
  - NF_TABLES_ARP=y
  - NF_TABLES_BRIDGE=y
  - NET_EMATCH_IPT=m
  - ICE=m
  - RSI_COEX=y
  - IEEE802154_MCR20A=m
  - INFINIBAND_EXP_LEGACY_VERBS_NEW_UAPI=n
  - Filesystems:
  - OVERLAY_FS_XINO_AUTO=n
  - PSTORE_DEFLATE_COMPRESS=m
  - PSTORE_LZ4HC_COMPRESS=m
  - PSTORE_842_COMPRESS=n
  - PSTORE_DEFLATE_COMPRESS_DEFAULT=deflate
  - Crypto:
  - CRYPTO_CFB=m
  - CRYPTO_SM4=m
  - CRYPTO_SPECK=m
  - CRYPTO_DEV_CHELSIO_TLS=m
  - Input:
  - JOYSTICK_PXRC=m
  - HID_ELAN=m
  - HID_GOOGLE_HAMMER=m
  - Sound:
  - SND_SOC_INTEL_CHT_BSW_NAU8824_MACH=m
  - SND_SOC_INTEL_KBL_DA7219_MAX98357A_MACH=m
  - SND_SOC_AK4458=n
  - SND_SOC_AK5558=n
  - SND_SOC_BD28623=n
  - SND_SOC_MAX9867=n
  - SND_SOC_PCM1789_I2C=n
  - SND_SOC_TDA7419=m
  - SND_SOC_MAX9759=n
  - USB:
  - TYPEC_MUX_PI3USB30532=m
  - USB_ROLES_INTEL_XHCI=m
  - GPIO:
  - GPIO_104_DIO_48E=m
  - GPIO_104_IDIO_16=m
  - GPIO_104_IDI_48=m
  - GPIO_GPIO_MM=m
  - GPIO_WINBOND=m
  - GPIO_WS16C48=m
  - Media:
  - CEC_PIN_ERROR_INJ=n
  - CXD2880_SPI_DRV=m
  - MTK_MMC=n
  - IIO:
  - 104_QUAD_8=m
  - CIO_DAC=n
  - AD5272=m
  - MCP4018=m
  - MLX90632=m
  - Other:
  - THERMAL_STATISTICS=y
  - EBC_C384_WDT=m
  - LEDS_MLXREG=m
  - COMMON_CLK_SI544=n
  - STX104=n
  - LV0104CS=n
  - Remote controlers:
  - IR_IMON_DECODER=m
  - IR_IMON_RAW=m
  - INTEL_TH_ACPI=m
  - Debugging:
  - DEBUG_RWSEMS=n
- commit 4e61ecf
* Fri Apr 20 2018 mkubecek@suse.cz
- config: enable TCP_MD5SIG (bsc#1090162)
- commit 1cfc938
* Fri Apr 20 2018 mkubecek@suse.cz
- x86/power/64: Fix page-table setup for temporary text mapping
  (https://patchwork.kernel.org/patch/10342491/).
- x86/ldt: Fix support_pte_mask filtering in map_ldt_struct()
  (https://patchwork.kernel.org/patch/10342491/).
- commit 3c56473
* Fri Apr 20 2018 msuchanek@suse.de
- HID: redragon: Fix modifier keys for Redragon Asura Keyboard
  (https://build.opensuse.org/request/show/597583).
  Update config files.
- commit e9bd8ea
* Thu Apr 19 2018 jslaby@suse.cz
- Linux 4.16.3 (bnc#1012628).
- cdc_ether: flag the Cinterion AHS8 modem by gemalto as WWAN
  (bnc#1012628).
- rds: MP-RDS may use an invalid c_path (bnc#1012628).
- slip: Check if rstate is initialized before uncompressing
  (bnc#1012628).
- vhost: fix vhost_vq_access_ok() log check (bnc#1012628).
- l2tp: fix races in tunnel creation (bnc#1012628).
- l2tp: fix race in duplicate tunnel detection (bnc#1012628).
- ip_gre: clear feature flags when incompatible o_flags are set
  (bnc#1012628).
- vhost: Fix vhost_copy_to_user() (bnc#1012628).
- lan78xx: Correctly indicate invalid OTP (bnc#1012628).
- sparc64: Properly range check DAX completion index
  (bnc#1012628).
- media: v4l2-compat-ioctl32: don't oops on overlay (bnc#1012628).
- media: v4l: vsp1: Fix header display list status check in
  continuous mode (bnc#1012628).
- ipmi: Fix some error cleanup issues (bnc#1012628).
- parisc: Fix out of array access in match_pci_device()
  (bnc#1012628).
- parisc: Fix HPMC handler by increasing size to multiple of 16
  bytes (bnc#1012628).
- iwlwifi: add a bunch of new 9000 PCI IDs (bnc#1012628).
- Drivers: hv: vmbus: do not mark HV_PCIE as perf_device
  (bnc#1012628).
- PCI: hv: Serialize the present and eject work items
  (bnc#1012628).
- PCI: hv: Fix 2 hang issues in hv_compose_msi_msg()
  (bnc#1012628).
- KVM: PPC: Book3S HV: trace_tlbie must not be called in realmode
  (bnc#1012628).
- perf intel-pt: Fix overlap detection to identify consecutive
  buffers correctly (bnc#1012628).
- perf intel-pt: Fix sync_switch (bnc#1012628).
- perf intel-pt: Fix error recovery from missing TIP packet
  (bnc#1012628).
- perf intel-pt: Fix timestamp following overflow (bnc#1012628).
- perf/core: Fix use-after-free in uprobe_perf_close()
  (bnc#1012628).
- radeon: hide pointless #warning when compile testing
  (bnc#1012628).
- x86/mce/AMD: Pass the bank number to smca_get_bank_type()
  (bnc#1012628).
- x86/mce/AMD, EDAC/mce_amd: Enumerate Reserved SMCA bank type
  (bnc#1012628).
- x86/mce/AMD: Get address from already initialized block
  (bnc#1012628).
- ath9k: Protect queue draining by rcu_read_lock() (bnc#1012628).
- x86/uapi: Fix asm/bootparam.h userspace compilation errors
  (bnc#1012628).
- x86/apic: Fix signedness bug in APIC ID validity checks
  (bnc#1012628).
- sunrpc: remove incorrect HMAC request initialization
  (bnc#1012628).
- f2fs: fix heap mode to reset it back (bnc#1012628).
- block: Change a rcu_read_{lock,unlock}_sched() pair into
  rcu_read_{lock,unlock}() (bnc#1012628).
- nvme: Skip checking heads without namespaces (bnc#1012628).
- lib: fix stall in __bitmap_parselist() (bnc#1012628).
- zboot: fix stack protector in compressed boot phase
  (bnc#1012628).
- blk-mq: Directly schedule q->timeout_work when aborting a
  request (bnc#1012628).
- blk-mq: order getting budget and driver tag (bnc#1012628).
- blk-mq: make sure that correct hctx->next_cpu is set
  (bnc#1012628).
- blk-mq: don't keep offline CPUs mapped to hctx 0 (bnc#1012628).
- ovl: Set d->last properly during lookup (bnc#1012628).
- ovl: fix lookup with middle layer opaque dir and absolute path
  redirects (bnc#1012628).
- ovl: set i_ino to the value of st_ino for NFS export
  (bnc#1012628).
- ovl: set lower layer st_dev only if setting lower st_ino
  (bnc#1012628).
- xen: xenbus_dev_frontend: Fix XS_TRANSACTION_END handling
  (bnc#1012628).
- hugetlbfs: fix bug in pgoff overflow checking (bnc#1012628).
- nfsd: fix incorrect umasks (bnc#1012628).
- scsi: scsi_dh: Don't look for NULL devices handlers by name
  (bnc#1012628).
- scsi: qla2xxx: Fix small memory leak in qla2x00_probe_one on
  probe failure (bnc#1012628).
- Revert "scsi: core: return BLK_STS_OK for DID_OK in
  __scsi_error_from_host_byte()" (bnc#1012628).
- apparmor: fix logging of the existence test for signals
  (bnc#1012628).
- apparmor: fix display of .ns_name for containers (bnc#1012628).
- apparmor: fix resource audit messages when auditing peer
  (bnc#1012628).
- block/loop: fix deadlock after loop_set_status (bnc#1012628).
- nfit: fix region registration vs block-data-window ranges
  (bnc#1012628).
- s390/qdio: don't retry EQBS after CCQ 96 (bnc#1012628).
- s390/qdio: don't merge ERROR output buffers (bnc#1012628).
- s390/ipl: ensure loadparm valid flag is set (bnc#1012628).
- s390/compat: fix setup_frame32 (bnc#1012628).
- get_user_pages_fast(): return -EFAULT on access_ok failure
  (bnc#1012628).
- mm/gup_benchmark: handle gup failures (bnc#1012628).
- getname_kernel() needs to make sure that ->name != ->iname in
  long case (bnc#1012628).
- Bluetooth: Fix connection if directed advertising and privacy
  is used (bnc#1012628).
- Bluetooth: hci_bcm: Treat Interrupt ACPI resources as always
  being active-low (bnc#1012628).
- rtl8187: Fix NULL pointer dereference in priv->conf_mutex
  (bnc#1012628).
- Refresh patches.suse/0001-AppArmor-basic-networking-rules.patch.
- commit 771261a
* Thu Apr 19 2018 tiwai@suse.de
- resource: fix integer overflow at reallocation (bsc#1086739).
- commit 4cf2593
* Thu Apr 19 2018 tiwai@suse.de
- Update tags of upstreamed patches
  Refresh
  patches.suse/Revert-drm-amd-display-disable-CRTCs-with-NULL-FB.patch
  patches.suse/media-v4l2-core-fix-size-of-devnode_nums-bitarray.patch
  patches.suse/swiotlb-Fix-unexpected-swiotlb_alloc_coherent-failur.patch
- commit e2aa76d
* Thu Apr 19 2018 msuchanek@suse.de
- objtool, perf: Fix GCC 8 -Wrestrict error (bsc#1084620).
- commit 0c6114f
* Wed Apr 18 2018 msuchanek@suse.de
- supported.conf: update from openSUSE-15.0
- commit 4ef3f17
* Mon Apr 16 2018 tiwai@suse.de
- Revert "drm/amd/display: disable CRTCs with NULL FB on their
  primary plane (V2)" (bsc#1089615, bsc#1088902).
- commit e881e16
* Mon Apr 16 2018 mbrugger@suse.com
- arm64: Update config files. (bsc#1089764)
  Increase NR_CPUS to 384
- commit 6f06d9e
* Thu Apr 12 2018 jslaby@suse.cz
- Linux 4.16.2 (bnc#1012628).
- nfp: use full 40 bits of the NSP buffer address (bnc#1012628).
- net_sched: fix a missing idr_remove() in u32_delete_key()
  (bnc#1012628).
- vti6: better validate user provided tunnel names (bnc#1012628).
- ip6_tunnel: better validate user provided tunnel names
  (bnc#1012628).
- ip6_gre: better validate user provided tunnel names
  (bnc#1012628).
- ipv6: sit: better validate user provided tunnel names
  (bnc#1012628).
- ip_tunnel: better validate user provided tunnel names
  (bnc#1012628).
- net: fool proof dev_valid_name() (bnc#1012628).
- vlan: also check phy_driver ts_info for vlan's real device
  (bnc#1012628).
- sky2: Increase D3 delay to sky2 stops working after suspend
  (bnc#1012628).
- sctp: sctp_sockaddr_af must check minimal addr length for
  AF_INET6 (bnc#1012628).
- sctp: do not leak kernel memory to user space (bnc#1012628).
- pptp: remove a buggy dst release in pptp_connect()
  (bnc#1012628).
- net/sched: fix NULL dereference in the error path of
  tcf_bpf_init() (bnc#1012628).
- net/ipv6: Increment OUTxxx counters after netfilter hook
  (bnc#1012628).
- net: dsa: Discard frames from unused ports (bnc#1012628).
- arp: fix arp_filter on l3slave devices (bnc#1012628).
- sparc64: Oracle DAX driver depends on SPARC64 (bnc#1012628).
- commit 8ea896b
* Wed Apr 11 2018 jslaby@suse.cz
- Update config files.
  s390x/vanilla fails to build without this.
- commit e8d83e8
* Tue Apr 10 2018 tiwai@suse.de
- swiotlb: Fix unexpected swiotlb_alloc_coherent() failures
  (bsc#1088658, bsc#1088902).
- commit 096b538
* Tue Apr 10 2018 msuchanek@suse.de
- rpm/package-descriptions: fix typo in kernel-azure
- Add azure kernel description.
- commit af0f13e
* Mon Apr  9 2018 tiwai@suse.de
- media: v4l2-core: fix size of devnode_nums[] bitarray
  (bsc#1088640).
- commit 6fcb3b5
* Mon Apr  9 2018 jslaby@suse.cz
- Linux 4.16.1 (bnc#1012628).
- signal: Correct the offset of si_pkey and si_lower in struct
  siginfo on m68k (bnc#1012628).
- Fix slab name "biovec-(1<<(21-12))" (bnc#1012628).
- vt: change SGR 21 to follow the standards (bnc#1012628).
- Input: i8042 - enable MUX on Sony VAIO VGN-CS series to fix
  touchpad (bnc#1012628).
- Input: i8042 - add Lenovo ThinkPad L460 to i8042 reset list
  (bnc#1012628).
- Input: ALPS - fix TrackStick detection on Thinkpad L570 and
  Latitude 7370 (bnc#1012628).
- Revert "base: arch_topology: fix section mismatch build
  warnings" (bnc#1012628).
- staging: comedi: ni_mio_common: ack ai fifo error interrupts
  (bnc#1012628).
- siox: fix possible buffer overflow in device_add_store
  (bnc#1012628).
- Btrfs: fix unexpected cow in run_delalloc_nocow (bnc#1012628).
- Bluetooth: hci_bcm: Add 6 new ACPI HIDs (bnc#1012628).
- crypto: x86/cast5-avx - fix ECB encryption when long sg follows
  short one (bnc#1012628).
- crypto: arm,arm64 - Fix random regeneration of S_shipped
  (bnc#1012628).
- crypto: ccp - return an actual key size from RSA max_size
  callback (bnc#1012628).
- crypto: caam - Fix null dereference at error path (bnc#1012628).
- crypto: ahash - Fix early termination in hash walk
  (bnc#1012628).
- crypto: talitos - fix IPsec cipher in length (bnc#1012628).
- crypto: testmgr - Fix incorrect values in PKCS#1 test vector
  (bnc#1012628).
- crypto: inside-secure - fix clock management (bnc#1012628).
- crypto: talitos - don't persistently map req_ctx->hw_context
  and req_ctx->buf (bnc#1012628).
- crypto: ccp - Fill the result buffer only on digest, finup,
  and final ops (bnc#1012628).
- crypto: lrw - Free rctx->ext with kzfree (bnc#1012628).
- parport_pc: Add support for WCH CH382L PCI-E single parallel
  port card (bnc#1012628).
- media: usbtv: prevent double free in error case (bnc#1012628).
- /dev/mem: Avoid overwriting "err" in read_mem() (bnc#1012628).
- mei: remove dev_err message on an unsupported ioctl
  (bnc#1012628).
- serial: 8250: Add Nuvoton NPCM UART (bnc#1012628).
- USB: serial: cp210x: add ELDAT Easywave RX09 id (bnc#1012628).
- USB: serial: ftdi_sio: add support for Harman
  FirmwareHubEmulator (bnc#1012628).
- USB: serial: ftdi_sio: add RT Systems VX-8 cable (bnc#1012628).
- bitmap: fix memset optimization on big-endian systems
  (bnc#1012628).
- commit 4bf9d1e
* Fri Apr  6 2018 agraf@suse.de
- armv6hl: Disable uacces with memcpy (boo#1080435)
- commit 2592f12
* Thu Apr  5 2018 rgoldwyn@suse.com
- apparmor: Check all profiles attached to the label (bsc#1085996).
- commit b249c9e
* Wed Apr  4 2018 jslaby@suse.cz
- Revert "tools: fix cross-compile var clobbering" (build fix).
- commit 590ff92
* Mon Apr  2 2018 jeffm@suse.com
- Update to 4.16-final.
- commit 1b10c5b
* Sat Mar 31 2018 jslaby@suse.cz
- Linux 4.15.15 (bnc#1012628).
- team: Fix double free in error path (bnc#1012628).
- skbuff: Fix not waking applications when errors are enqueued
  (bnc#1012628).
- qede: Fix qedr link update (bnc#1012628).
- net: systemport: Rewrite __bcm_sysport_tx_reclaim()
  (bnc#1012628).
- net: Only honor ifindex in IP_PKTINFO if non-0 (bnc#1012628).
- netlink: avoid a double skb free in genlmsg_mcast()
  (bnc#1012628).
- net/iucv: Free memory obtained by kzalloc (bnc#1012628).
- net: fec: Fix unbalanced PM runtime calls (bnc#1012628).
- net: ethernet: ti: cpsw: add check for in-band mode setting
  with RGMII PHY interface (bnc#1012628).
- commit 4904fc3
* Sat Mar 31 2018 jslaby@suse.cz
- net: ethernet: arc: Fix a potential memory leak if an optional
  regulator is deferred (bnc#1012628).
- l2tp: do not accept arbitrary sockets (bnc#1012628).
- ipv6: fix access to non-linear packet in
  ndisc_fill_redirect_hdr_option() (bnc#1012628).
- dccp: check sk for closed state in dccp_sendmsg() (bnc#1012628).
- dpaa_eth: remove duplicate increment of the tx_errors counter
  (bnc#1012628).
- dpaa_eth: increment the RX dropped counter when needed
  (bnc#1012628).
- dpaa_eth: remove duplicate initialization (bnc#1012628).
- dpaa_eth: fix error in dpaa_remove() (bnc#1012628).
- soc/fsl/qbman: fix issue in qman_delete_cgr_safe()
  (bnc#1012628).
- s390/qeth: on channel error, reject further cmd requests
  (bnc#1012628).
- s390/qeth: lock read device while queueing next buffer
  (bnc#1012628).
- s390/qeth: when thread completes, wake up all waiters
  (bnc#1012628).
- s390/qeth: free netdevice when removing a card (bnc#1012628).
- net: Fix hlist corruptions in inet_evict_bucket() (bnc#1012628).
- net: use skb_to_full_sk() in skb_update_prio() (bnc#1012628).
- ieee802154: 6lowpan: fix possible NULL deref in
  lowpan_device_event() (bnc#1012628).
- sch_netem: fix skb leak in netem_enqueue() (bnc#1012628).
- kcm: lock lower socket in kcm_attach (bnc#1012628).
- test_rhashtable: add test case for rhltable with duplicate
  objects (bnc#1012628).
- rhashtable: Fix rhlist duplicates insertion (bnc#1012628).
- ppp: avoid loop in xmit recursion detection code (bnc#1012628).
- net sched actions: return explicit error when tunnel_key mode
  is not specified (bnc#1012628).
- ipv6: Reflect MTU changes on PMTU of exceptions for MTU-less
  routes (bnc#1012628).
- net: phy: Tell caller result of phy_change() (bnc#1012628).
- mlxsw: spectrum_buffers: Set a minimum quota for CPU port
  traffic (bnc#1012628).
- ipv6: sr: fix scheduling in RCU when creating seg6 lwtunnel
  state (bnc#1012628).
- ipv6: sr: fix NULL pointer dereference when setting encap
  source address (bnc#1012628).
- ipv6: old_dport should be a __be16 in __ip6_datagram_connect()
  (bnc#1012628).
- net: ipv6: keep sk status consistent after datagram connect
  failure (bnc#1012628).
- macvlan: filter out unsupported feature flags (bnc#1012628).
- devlink: Remove redundant free on error path (bnc#1012628).
- net: phy: relax error checking when creating sysfs link
  netdev->phydev (bnc#1012628).
- sysfs: symlink: export sysfs_create_link_nowarn() (bnc#1012628).
- qed: Fix non TCP packets should be dropped on iWARP ll2
  connection (bnc#1012628).
- tcp: purge write queue upon aborting the connection
  (bnc#1012628).
- qed: Fix MPA unalign flow in case header is split across two
  packets (bnc#1012628).
- openvswitch: meter: fix the incorrect calculation of max delta_t
  (bnc#1012628).
- net: dsa: Fix dsa_is_user_port() test inversion (bnc#1012628).
- commit 0e7b541
* Thu Mar 29 2018 jslaby@suse.cz
- Linux 4.15.14 (bnc#1012628).
- MIPS: ralink: Remove ralink_halt() (bnc#1012628).
- MIPS: ralink: Fix booting on MT7621 (bnc#1012628).
- MIPS: lantiq: Fix Danube USB clock (bnc#1012628).
- MIPS: lantiq: Enable AHB Bus for USB (bnc#1012628).
- MIPS: lantiq: ase: Enable MFD_SYSCON (bnc#1012628).
- iio: chemical: ccs811: Corrected firmware boot/application
  mode transition (bnc#1012628).
- iio: st_pressure: st_accel: pass correct platform data to init
  (bnc#1012628).
- iio: adc: meson-saradc: unlock on error in meson_sar_adc_lock()
  (bnc#1012628).
- ALSA: usb-audio: Fix parsing descriptor of UAC2 processing unit
  (bnc#1012628).
- ALSA: aloop: Sync stale timer before release (bnc#1012628).
- ALSA: aloop: Fix access to not-yet-ready substream via cable
  (bnc#1012628).
- ALSA: hda - Force polling mode on CFL for fixing codec
  communication (bnc#1012628).
- ALSA: hda/realtek - Fix speaker no sound after system resume
  (bnc#1012628).
- ALSA: hda/realtek - Fix Dell headset Mic can't record
  (bnc#1012628).
- ALSA: hda/realtek - Always immediately update mute LED with
  pin VREF (bnc#1012628).
- mmc: core: Fix tracepoint print of blk_addr and blksz
  (bnc#1012628).
- mmc: core: Disable HPI for certain Micron (Numonyx) eMMC cards
  (bnc#1012628).
- mmc: block: fix updating ext_csd caches on ioctl call
  (bnc#1012628).
- mmc: dw_mmc: Fix the DTO/CTO timeout overflow calculation for
  32-bit systems (bnc#1012628).
- mmc: dw_mmc: exynos: fix the suspend/resume issue for exynos5433
  (bnc#1012628).
- mmc: dw_mmc: fix falling from idmac to PIO mode when
  dw_mci_reset occurs (bnc#1012628).
- PCI: Add function 1 DMA alias quirk for Highpoint RocketRAID
  644L (bnc#1012628).
- ahci: Add PCI-id for the Highpoint Rocketraid 644L card
  (bnc#1012628).
- lockdep: fix fs_reclaim warning (bnc#1012628).
- clk: bcm2835: Fix ana->maskX definitions (bnc#1012628).
- clk: bcm2835: Protect sections updating shared registers
  (bnc#1012628).
- clk: sunxi-ng: a31: Fix CLK_OUT_* clock ops (bnc#1012628).
- RDMA/mlx5: Fix crash while accessing garbage pointer and freed
  memory (bnc#1012628).
- Drivers: hv: vmbus: Fix ring buffer signaling (bnc#1012628).
- pinctrl: samsung: Validate alias coming from DT (bnc#1012628).
- Bluetooth: btusb: Remove Yoga 920 from the
  btusb_needs_reset_resume_table (bnc#1012628).
- Bluetooth: btusb: Add Dell OptiPlex 3060 to
  btusb_needs_reset_resume_table (bnc#1012628).
- libata: fix length validation of ATAPI-relayed SCSI commands
  (bnc#1012628).
- libata: remove WARN() for DMA or PIO command without data
  (bnc#1012628).
- libata: don't try to pass through NCQ commands to non-NCQ
  devices (bnc#1012628).
- libata: Apply NOLPM quirk to Crucial MX100 512GB SSDs
  (bnc#1012628).
- libata: disable LPM for Crucial BX100 SSD 500GB drive
  (bnc#1012628).
- libata: Enable queued TRIM for Samsung SSD 860 (bnc#1012628).
- libata: Apply NOLPM quirk to Crucial M500 480 and 960GB SSDs
  (bnc#1012628).
- libata: Make Crucial BX100 500GB LPM quirk apply to all firmware
  versions (bnc#1012628).
- libata: Modify quirks for MX100 to limit NCQ_TRIM quirk to
  MU01 version (bnc#1012628).
- sched, cgroup: Don't reject lower cpu.max on ancestors
  (bnc#1012628).
- cgroup: fix rule checking for threaded mode switching
  (bnc#1012628).
- nfsd: remove blocked locks on client teardown (bnc#1012628).
- media: tegra-cec: reset rx_buf_cnt when start bit detected
  (bnc#1012628).
- hugetlbfs: check for pgoff value overflow (bnc#1012628).
- h8300: remove extraneous __BIG_ENDIAN definition (bnc#1012628).
- mm/vmalloc: add interfaces to free unmapped page table
  (bnc#1012628).
- x86/mm: implement free pmd/pte page interfaces (bnc#1012628).
- mm/khugepaged.c: convert VM_BUG_ON() to collapse fail
  (bnc#1012628).
- mm/thp: do not wait for lock_page() in deferred_split_scan()
  (bnc#1012628).
- mm/shmem: do not wait for lock_page() in
  shmem_unused_huge_shrink() (bnc#1012628).
- Revert "mm: page_alloc: skip over regions of invalid pfns
  where possible" (bnc#1012628).
- drm/vmwgfx: Fix black screen and device errors when running
  without fbdev (bnc#1012628).
- drm/vmwgfx: Fix a destoy-while-held mutex problem (bnc#1012628).
- drm/radeon: Don't turn off DP sink when disconnected
  (bnc#1012628).
- drm/amd/display: We shouldn't set format_default on plane as
  atomic driver (bnc#1012628).
- drm/amd/display: Add one to EDID's audio channel count when
  passing to DC (bnc#1012628).
- drm: Reject getfb for multi-plane framebuffers (bnc#1012628).
- drm: udl: Properly check framebuffer mmap offsets (bnc#1012628).
- mm/vmscan: wake up flushers for legacy cgroups too
  (bnc#1012628).
- module: propagate error in modules_open() (bnc#1012628).
- acpi, numa: fix pxm to online numa node associations
  (bnc#1012628).
- ACPI / watchdog: Fix off-by-one error at resource assignment
  (bnc#1012628).
- libnvdimm, {btt, blk}: do integrity setup before add_disk()
  (bnc#1012628).
- brcmfmac: fix P2P_DEVICE ethernet address generation
  (bnc#1012628).
- rtlwifi: rtl8723be: Fix loss of signal (bnc#1012628).
- tracing: probeevent: Fix to support minus offset from symbol
  (bnc#1012628).
- mtdchar: fix usage of mtd_ooblayout_ecc() (bnc#1012628).
- mtd: nand: fsl_ifc: Fix nand waitfunc return value
  (bnc#1012628).
- mtd: nand: fsl_ifc: Fix eccstat array overflow for IFC ver >=
  2.0.0 (bnc#1012628).
- mtd: nand: fsl_ifc: Read ECCSTAT0 and ECCSTAT1 registers for
  IFC 2.0 (bnc#1012628).
- can: peak/pcie_fd: fix echo_skb is occupied! bug (bnc#1012628).
- can: peak/pcie_fd: remove useless code when interface starts
  (bnc#1012628).
- can: ifi: Repair the error handling (bnc#1012628).
- can: ifi: Check core revision upon probe (bnc#1012628).
- can: cc770: Fix stalls on rt-linux, remove redundant IRQ ack
  (bnc#1012628).
- can: cc770: Fix queue stall & dropped RTR reply (bnc#1012628).
- can: cc770: Fix use after free in cc770_tx_interrupt()
  (bnc#1012628).
- tty: vt: fix up tabstops properly (bnc#1012628).
- selftests/x86/ptrace_syscall: Fix for yet more glibc
  interference (bnc#1012628).
- x86/vsyscall/64: Use proper accessor to update P4D entry
  (bnc#1012628).
- x86/efi: Free efi_pgd with free_pages() (bnc#1012628).
- posix-timers: Protect posix clock array access against
  speculation (bnc#1012628).
- kvm/x86: fix icebp instruction handling (bnc#1012628).
- x86/build/64: Force the linker to use 2MB page size
  (bnc#1012628).
- x86/boot/64: Verify alignment of the LOAD segment (bnc#1012628).
- hwmon: (k10temp) Only apply temperature offset if result is
  positive (bnc#1012628).
- hwmon: (k10temp) Add temperature offset for Ryzen 1900X
  (bnc#1012628).
- perf/x86/intel/uncore: Fix Skylake UPI event format
  (bnc#1012628).
- perf stat: Fix CVS output format for non-supported counters
  (bnc#1012628).
- perf/core: Fix ctx_event_type in ctx_resched() (bnc#1012628).
- trace/bpf: remove helper bpf_perf_prog_read_value from
  tracepoint type programs (bnc#1012628).
- perf/x86/intel: Don't accidentally clear high bits in
  bdw_limit_period() (bnc#1012628).
- perf/x86/intel/uncore: Fix multi-domain PCI CHA enumeration
  bug on Skylake servers (bnc#1012628).
- iio: ABI: Fix name of timestamp sysfs file (bnc#1012628).
- iio: imu: st_lsm6dsx: fix endianness in
  st_lsm6dsx_read_oneshot() (bnc#1012628).
- iio: imu: st_lsm6dsx: introduce conf_lock mutex (bnc#1012628).
- staging: android: ion: Zero CMA allocated memory (bnc#1012628).
- kbuild: disable clang's default use of -fmerge-all-constants
  (bnc#1012628).
- bpf: skip unnecessary capability check (bnc#1012628).
- bpf, x64: increase number of passes (bnc#1012628).
- commit def7e44
* Wed Mar 28 2018 neilb@suse.com
- staging: ncpfs: memory corruption in ncp_read_kernel()
  (bsc#1086162, CVE-2018-8822).
- commit a967c04
* Tue Mar 27 2018 bp@suse.de
- x86/entry/64: Don't use IST entry for #BP stack (bsc#1087088).
- commit 67a9975
* Mon Mar 26 2018 tiwai@suse.de
- brcmsmac: allocate ucode with GFP_KERNEL (bsc#1085174).
- commit 580a38a
* Mon Mar 26 2018 jslaby@suse.cz
- Update vanilla config files.
- commit 9beaab6
* Mon Mar 26 2018 bpoirier@suse.com
- net: phy: mdio-bcm-unimac: fix potential NULL dereference in
  unimac_mdio_probe() (bsc#1084829 CVE-2018-8043).
- commit 7b5f96b
* Mon Mar 26 2018 jeffm@suse.com
- Update to 4.16-rc7.
- Eliminated 1 patch.
- commit 7a36f2f
* Sun Mar 25 2018 jslaby@suse.cz
- Linux 4.15.13 (bnc#1012628).
- RDMA/ucma: Don't allow join attempts for unsupported AF family
  (bnc#1012628).
- RDMA/ucma: Fix access to non-initialized CM_ID object
  (bnc#1012628).
- clk: migrate the count of orphaned clocks at init (bnc#1012628).
- RDMA/core: Do not use invalid destination in determining port
  reuse (bnc#1012628).
- serial: 8250_pci: Don't fail on multiport card class
  (bnc#1012628).
- RDMA/vmw_pvrdma: Fix usage of user response structures in ABI
  file (bnc#1012628).
- IB/mlx5: Fix out-of-bounds read in create_raw_packet_qp_rq
  (bnc#1012628).
- IB/mlx5: Fix integer overflows in mlx5_ib_create_srq
  (bnc#1012628).
- dmaengine: ti-dma-crossbar: Fix event mapping for
  TPCC_EVT_MUX_60_63 (bnc#1012628).
- hwrng: core - Clean up RNG list when last hwrng is unregistered
  (bnc#1012628).
- crypto: artpec6 - set correct iv size for gcm(aes)
  (bnc#1012628).
- clk: si5351: Rename internal plls to avoid name collisions
  (bnc#1012628).
- clk: axi-clkgen: Correctly handle nocount bit in recalc_rate()
  (bnc#1012628).
- clk: Don't touch hardware when reparenting during registration
  (bnc#1012628).
- clk: at91: pmc: Wait for clocks when resuming (bnc#1012628).
- nfsd4: permit layoutget of executable-only files (bnc#1012628).
- ARM: dts: aspeed-evb: Add unit name to memory node
  (bnc#1012628).
- RDMA/ocrdma: Fix permissions for OCRDMA_RESET_STATS
  (bnc#1012628).
- scsi: lpfc: Fix issues connecting with nvme initiator
  (bnc#1012628).
- scsi: lpfc: Fix SCSI LUN discovery when SCSI and NVME enabled
  (bnc#1012628).
- soc: qcom: smsm: fix child-node lookup (bnc#1012628).
- ip_gre: fix potential memory leak in erspan_rcv (bnc#1012628).
- ip_gre: fix error path when erspan_rcv failed (bnc#1012628).
- ip6_vti: adjust vti mtu according to mtu of lower device
  (bnc#1012628).
- iommu/vt-d: clean up pr_irq if request_threaded_irq fails
  (bnc#1012628).
- pinctrl: rockchip: enable clock when reading pin direction
  register (bnc#1012628).
- pinctrl: Really force states during suspend/resume
  (bnc#1012628).
- clk: use round rate to bail out early in set_rate (bnc#1012628).
- dt-bindings: display: panel: Fix compatible string for Toshiba
  LT089AC29000 (bnc#1012628).
- clk: check ops pointer on clock register (bnc#1012628).
- media: davinci: fix a debug printk (bnc#1012628).
- PCI: rcar: Handle rcar_pcie_parse_request_of_pci_ranges()
  failures (bnc#1012628).
- PCI: endpoint: Fix find_first_zero_bit() usage (bnc#1012628).
- PCI: designware-ep: Fix ->get_msi() to check MSI_EN bit
  (bnc#1012628).
- coresight: Fix disabling of CoreSight TPIU (bnc#1012628).
- pty: cancel pty slave port buf's work in tty_release
  (bnc#1012628).
- drm/omap: DMM: Check for DMM readiness after successful
  transaction commit (bnc#1012628).
- mmc: sdhci-xenon: wait 5ms after set 1.8V signal enable
  (bnc#1012628).
- omapdrm: panel: fix compatible vendor string for td028ttec1
  (bnc#1012628).
- vgacon: Set VGA struct resource types (bnc#1012628).
- PCI/ASPM: Calculate LTR_L1.2_THRESHOLD from device
  characteristics (bnc#1012628).
- bpf/cgroup: fix a verification error for a CGROUP_DEVICE type
  prog (bnc#1012628).
- iser-target: avoid reinitializing rdma contexts for isert
  commands (bnc#1012628).
- IB/umem: Fix use of npages/nmap fields (bnc#1012628).
- RDMA/cma: Use correct size when writing netlink stats
  (bnc#1012628).
- IB/ipoib: Avoid memory leak if the SA returns a different DGID
  (bnc#1012628).
- rtc: ac100: Fix multiple race conditions (bnc#1012628).
- media: s5p-mfc: Fix lock contention - request_firmware() once
  (bnc#1012628).
- sfp: fix non-detection of PHY (bnc#1012628).
- sfp: fix EEPROM reading in the case of non-SFF8472 SFPs
  (bnc#1012628).
- net: phy: meson-gxl: check phy_write return value (bnc#1012628).
- /dev/mem: Add bounce buffer for copy-out (bnc#1012628).
- mmc: block: fix logical error to avoid memory leak
  (bnc#1012628).
- mmc: avoid removing non-removable hosts during suspend
  (bnc#1012628).
- drm/tilcdc: ensure nonatomic iowrite64 is not used
  (bnc#1012628).
- dmaengine: zynqmp_dma: Fix race condition in the probe
  (bnc#1012628).
- platform/chrome: Use proper protocol transfer function
  (bnc#1012628).
- watchdog: Fix kref imbalance seen if handle_boot_enabled=0
  (bnc#1012628).
- watchdog: Fix potential kref imbalance when opening watchdog
  (bnc#1012628).
- cros_ec: fix nul-termination for firmware build info
  (bnc#1012628).
- serial: 8250_dw: Disable clock on error (bnc#1012628).
- tty: goldfish: Enable 'earlycon' only if built-in (bnc#1012628).
- qmi_wwan: set FLAG_SEND_ZLP to avoid network initiated
  disconnect (bnc#1012628).
- media: [RESEND] media: dvb-frontends: Add delay to Si2168
  restart (bnc#1012628).
- ath10k: handling qos at STA side based on AP WMM enable/disable
  (bnc#1012628).
- media: bt8xx: Fix err 'bt878_probe()' (bnc#1012628).
- rtlwifi: always initialize variables given to RT_TRACE()
  (bnc#1012628).
- rtlwifi: rtl_pci: Fix the bug when inactiveps is enabled
  (bnc#1012628).
- libbpf: prefer global symbols as bpf program name source
  (bnc#1012628).
- spi: sh-msiof: Avoid writing to registers from
  spi_master.setup() (bnc#1012628).
- tcp: allow TLP in ECN CWR (bnc#1012628).
- hv_netvsc: Fix the TX/RX buffer default sizes (bnc#1012628).
- hv_netvsc: Fix the receive buffer size limit (bnc#1012628).
- RDMA/iwpm: Fix uninitialized error code in iwpm_send_mapinfo()
  (bnc#1012628).
- IB/ipoib: Warn when one port fails to initialize (bnc#1012628).
- drm/msm: fix leak in failed get_pages (bnc#1012628).
- media: c8sectpfe: fix potential NULL pointer dereference in
  c8sectpfe_timer_interrupt (bnc#1012628).
- cpufreq: longhaul: Revert transition_delay_us to 200 ms
  (bnc#1012628).
- Bluetooth: btqcomsmd: Fix skb double free corruption
  (bnc#1012628).
- Bluetooth: hci_qca: Avoid setup failure on missing rampatch
  (bnc#1012628).
- drm/amdgpu: use polling mem to set SDMA3 wptr for VF
  (bnc#1012628).
- staging: android: ashmem: Fix possible deadlock in ashmem_ioctl
  (bnc#1012628).
- scsi: megaraid_sas: Do not use 32-bit atomic request descriptor
  for Ventura controllers (bnc#1012628).
- commit 950fc49
* Fri Mar 23 2018 agraf@suse.de
- armv7hl: Disable uacces with memcpy (boo#1080435)
- commit a3fb408
* Wed Mar 21 2018 jslaby@suse.cz
- Linux 4.15.12 (bnc#1012628).
- phy: phy-brcm-usb-init: Power down USB 3.0 PHY when XHCI
  disabled (bnc#1012628).
- phy: phy-brcm-usb-init: DRD mode can cause crash on startup
  (bnc#1012628).
- phy: phy-brcm-usb-init: Some Low Speed keyboards fail on 7271
  (bnc#1012628).
- phy: phy-brcm-usb: Fix two DT properties to match bindings doc
  (bnc#1012628).
- usb: gadget: udc: renesas_usb3: fix oops in
  renesas_usb3_remove() (bnc#1012628).
- usb: dwc3: of-simple: fix oops by unbalanced clk disable call
  (bnc#1012628).
- usb: dwc3: core: Power-off core/PHYs on system_suspend in host
  mode (bnc#1012628).
- usb: dwc3: Fix GDBGFIFOSPACE_TYPE values (bnc#1012628).
- USB: gadget: udc: Add missing platform_device_put() on error
  in bdc_pci_probe() (bnc#1012628).
- dt-bindings: usb: fix the STM32F7 DWC2 OTG HS core binding
  (bnc#1012628).
- usb: dwc2: fix STM32F7 USB OTG HS compatible (bnc#1012628).
- scsi: qla2xxx: Fix crashes in qla2x00_probe_one on probe failure
  (bnc#1012628).
- scsi: qla2xxx: Fix logo flag for qlt_free_session_done()
  (bnc#1012628).
- scsi: qla2xxx: Fix NULL pointer access for fcport structure
  (bnc#1012628).
- scsi: qla2xxx: Fix smatch warning in
  qla25xx_delete_{rsp|req}_que (bnc#1012628).
- btrfs: Fix memory barriers usage with device stats counters
  (bnc#1012628).
- btrfs: remove spurious WARN_ON(ref->count < 0) in
  find_parent_nodes (bnc#1012628).
- btrfs: Fix use-after-free when cleaning up fs_devs with a
  single stale device (bnc#1012628).
- btrfs: alloc_chunk: fix DUP stripe size handling (bnc#1012628).
- btrfs: add missing initialization in btrfs_check_shared
  (bnc#1012628).
- btrfs: Fix NULL pointer exception in find_bio_stripe
  (bnc#1012628).
- xfs: preserve i_rdev when recycling a reclaimable inode
  (bnc#1012628).
- nvme: fix subsystem multiple controllers support check
  (bnc#1012628).
- irqchip/gic-v3-its: Ensure nr_ites >= nr_lpis (bnc#1012628).
- RDMAVT: Fix synchronization around percpu_ref (bnc#1012628).
- fs/aio: Use RCU accessors for kioctx_table->table[]
  (bnc#1012628).
- fs/aio: Add explicit RCU grace period when freeing kioctx
  (bnc#1012628).
- lock_parent() needs to recheck if dentry got __dentry_kill'ed
  under it (bnc#1012628).
- KVM: arm/arm64: vgic: Don't populate multiple LRs with the
  same vintid (bnc#1012628).
- kvm: arm/arm64: vgic-v3: Tighten synchronization for guests
  using v2 on v3 (bnc#1012628).
- KVM: arm/arm64: Reset mapped IRQs on VM reset (bnc#1012628).
- KVM: arm/arm64: Reduce verbosity of KVM init log (bnc#1012628).
- fs: Teach path_connected to handle nfs filesystems with multiple
  roots (bnc#1012628).
- drm/amdgpu/dce: Don't turn off DP sink when disconnected
  (bnc#1012628).
- drm/radeon: fix prime teardown order (bnc#1012628).
- drm/amdgpu: fix prime teardown order (bnc#1012628).
- drm/nouveau/mmu: ALIGN_DOWN correct variable (bnc#1012628).
- drm/nouveau/bl: Fix oops on driver unbind (bnc#1012628).
- ALSA: seq: Clear client entry before deleting else at closing
  (bnc#1012628).
- ALSA: seq: Fix possible UAF in snd_seq_check_queue()
  (bnc#1012628).
- ALSA: hda - Revert power_save option default value
  (bnc#1012628).
- ALSA: pcm: Fix UAF in snd_pcm_oss_get_formats() (bnc#1012628).
- parisc: Handle case where flush_cache_range is called with no
  context (bnc#1012628).
- x86/mm: Fix vmalloc_fault to use pXd_large (bnc#1012628).
- KVM: x86: Fix device passthrough when SME is active
  (bnc#1012628).
- x86/speculation: Remove Skylake C2 from Speculation Control
  microcode blacklist (bnc#1012628).
- x86/speculation, objtool: Annotate indirect calls/jumps for
  objtool on 32-bit kernels (bnc#1012628).
- x86/vm86/32: Fix POPF emulation (bnc#1012628).
- selftests/x86/entry_from_vm86: Add test cases for POPF
  (bnc#1012628).
- selftests/x86/entry_from_vm86: Exit with 1 if we fail
  (bnc#1012628).
- x86/cpufeatures: Add Intel PCONFIG cpufeature (bnc#1012628).
- x86/cpufeatures: Add Intel Total Memory Encryption cpufeature
  (bnc#1012628).
- commit 9f942ce
* Mon Mar 19 2018 jslaby@suse.cz
- Update config files (4.15.11).
- commit a1db525
* Mon Mar 19 2018 jslaby@suse.cz
- Linux 4.15.11 (bnc#1012628).
- drm/i915/glk: Disable Guc and HuC on GLK (bnc#1012628).
- dmaengine: qcom_hidma: check pending interrupts (bnc#1012628).
- IB/mlx5: revisit -Wmaybe-uninitialized warning (bnc#1012628).
- ima: relax requiring a file signature for new files with zero
  length (bnc#1012628).
- locking/locktorture: Fix num reader/writer corner cases
  (bnc#1012628).
- rcutorture/configinit: Fix build directory error message
  (bnc#1012628).
- ipvlan: add L2 check for packets arriving via virtual devices
  (bnc#1012628).
- Fix misannotated out-of-line _copy_to_user() (bnc#1012628).
- mmc: mmc_test: Ensure command queue is disabled for testing
  (bnc#1012628).
- ASoC: nuc900: Fix a loop timeout test (bnc#1012628).
- crypto: caam/qi - use correct print specifier for size_t
  (bnc#1012628).
- mac80211: remove BUG() when interface type is invalid
  (bnc#1012628).
- mac80211_hwsim: enforce PS_MANUAL_POLL to be set after
  PS_ENABLED (bnc#1012628).
- agp/intel: Flush all chipset writes after updating the GGTT
  (bnc#1012628).
- arm64: dts: renesas: salvator-common: Add EthernetAVB PHY reset
  (bnc#1012628).
- powerpc/64: Don't trace irqs-off at interrupt return to
  soft-disabled context (bnc#1012628).
- powerpc/modules: Don't try to restore r2 after a sibling call
  (bnc#1012628).
- drm/amdkfd: Fix memory leaks in kfd topology (bnc#1012628).
- veth: set peer GSO values (bnc#1012628).
- net: sched: drop qdisc_reset from dev_graft_qdisc (bnc#1012628).
- virtio_net: Disable interrupts if napi_complete_done rescheduled
  napi (bnc#1012628).
- media: davinci: vpif_capture: add NULL check on devm_kzalloc
  return value (bnc#1012628).
- media: cpia2: Fix a couple off by one bugs (bnc#1012628).
- dm raid: fix raid set size revalidation (bnc#1012628).
- media: vsp1: Prevent suspending and resuming DRM pipelines
  (bnc#1012628).
- staging: fsl-dpaa2/eth: Fix access to FAS field (bnc#1012628).
- clk: renesas: r8a77970: Add LVDS clock (bnc#1012628).
- scsi: dh: add new rdac devices (bnc#1012628).
- scsi: devinfo: apply to HP XP the same flags as Hitachi VSP
  (bnc#1012628).
- scsi: core: scsi_get_device_flags_keyed(): Always return device
  flags (bnc#1012628).
- bnxt_en: Don't print "Link speed -1 no longer supported"
  messages (bnc#1012628).
- spi: sun6i: disable/unprepare clocks on remove (bnc#1012628).
- tools/usbip: fixes build with musl libc toolchain (bnc#1012628).
- ath10k: fix invalid STS_CAP_OFFSET_MASK (bnc#1012628).
- mwifiex: cfg80211: do not change virtual interface during scan
  processing (bnc#1012628).
- clk: qcom: msm8916: fix mnd_width for codec_digcodec
  (bnc#1012628).
- bnxt_en: Uninitialized variable in bnxt_tc_parse_actions()
  (bnc#1012628).
- drm/amdgpu: fix amdgpu_sync_resv v2 (bnc#1012628).
- drm/amdgpu:fix virtual dce bug (bnc#1012628).
- iwlwifi: mvm: avoid dumping assert log when device is stopped
  (bnc#1012628).
- perf annotate: Fix objdump comment parsing for Intel mov
  dissassembly (bnc#1012628).
- perf annotate: Fix unnecessary memory allocation for s390x
  (bnc#1012628).
- pinctrl: sh-pfc: r8a7795-es1: Fix MOD_SEL1 bit[25:24] to 0x3
  when using STP_ISEN_1_D (bnc#1012628).
- pinctrl: sh-pfc: r8a7791: Add can_clk function (bnc#1012628).
- drm/sun4i: Fix format mask in DE2 driver (bnc#1012628).
- pwm: stmpe: Fix wrong register offset for hwpwm=2 case
  (bnc#1012628).
- scsi: ses: don't ask for diagnostic pages repeatedly during
  probe (bnc#1012628).
- scsi: lpfc: Fix crash during driver unload with running nvme
  traffic (bnc#1012628).
- drm/amdgpu:fix random missing of FLR NOTIFY (bnc#1012628).
- KVM: X86: Restart the guest when insn_len is zero and SEV is
  enabled (bnc#1012628).
- cpufreq: Fix governor module removal race (bnc#1012628).
- ath10k: update tdls teardown state to target (bnc#1012628).
- iio: health: max30102: Add power enable parameter to get_temp
  function (bnc#1012628).
- iio: adc: ina2xx: Shift bus voltage register to mask flag bits
  (bnc#1012628).
- drm/etnaviv: make THERMAL selectable (bnc#1012628).
- power: supply: ab8500_charger: Bail out in case of error in
  'ab8500_charger_init_hw_registers()' (bnc#1012628).
- power: supply: ab8500_charger: Fix an error handling path
  (bnc#1012628).
- power: supply: sbs-message: double left shift bug in
  sbsm_select() (bnc#1012628).
- bpf: fix stack state printing in verifier log (bnc#1012628).
- leds: pm8058: Silence pointer to integer size warning
  (bnc#1012628).
- xfrm: Fix xfrm_replay_overflow_offload_esn (bnc#1012628).
- userns: Don't fail follow_automount based on s_user_ns
  (bnc#1012628).
- mtd: nand: ifc: update bufnum mask for ver >= 2.0.0
  (bnc#1012628).
- ARM: dts: omap3-n900: Fix the audio CODEC's reset pin
  (bnc#1012628).
- ARM: dts: am335x-pepper: Fix the audio CODEC's reset pin
  (bnc#1012628).
- net: thunderx: Set max queue count taking XDP_TX into account
  (bnc#1012628).
- mtd: nand: fix interpretation of NAND_CMD_NONE in
  nand_command[_lp]() (bnc#1012628).
- gpiolib: don't allow OPEN_DRAIN & OPEN_SOURCE flags
  simultaneously (bnc#1012628).
- net: xfrm: allow clearing socket xfrm policies (bnc#1012628).
- perf report: Fix -D output for user metadata events
  (bnc#1012628).
- rtc: brcmstb-waketimer: fix error handling in
  brcmstb_waketmr_probe() (bnc#1012628).
- net: ieee802154: adf7242: Fix bug if defined DEBUG
  (bnc#1012628).
- drm/vblank: Fix vblank timestamp debugs (bnc#1012628).
- test_firmware: fix setting old custom fw path back on exit
  (bnc#1012628).
- crypto: cavium - fix memory leak on info (bnc#1012628).
- crypto: keywrap - Add missing ULL suffixes for 64-bit constants
  (bnc#1012628).
- crypto: ecc - Fix NULL pointer deref. on no default_rng
  (bnc#1012628).
- crypto: chelsio - Fix an error code in chcr_hash_dma_map()
  (bnc#1012628).
- sched: Stop resched_cpu() from sending IPIs to offline CPUs
  (bnc#1012628).
- sched: Stop switched_to_rt() from sending IPIs to offline CPUs
  (bnc#1012628).
- dt-bindings: serial: Add common rs485 binding for RTS polarity
  (bnc#1012628).
- USB: ledtrig-usbport: fix of-node leak (bnc#1012628).
- typec: tcpm: fusb302: Resolve out of order messaging events
  (bnc#1012628).
- staging: rtl8822be: fix missing null check on dev_alloc_skb
  return (bnc#1012628).
- drm/amdgpu: fix get_max_engine_clock_in_mhz (bnc#1012628).
- ARM: dts: exynos: Correct Trats2 panel reset line (bnc#1012628).
- clk: meson: gxbb: fix wrong clock for SARADC/SANA (bnc#1012628).
- ARM: dts: koelsch: Move cec_clock to root node (bnc#1012628).
- iwlwifi: mvm: rs: don't override the rate history in the search
  cycle (bnc#1012628).
- HID: elo: clear BTN_LEFT mapping (bnc#1012628).
- KVM: PPC: Book3S HV: Fix typo in kvmppc_hv_get_dirty_log_radix()
  (bnc#1012628).
- video/hdmi: Allow "empty" HDMI infoframes (bnc#1012628).
- dma-buf/fence: Fix lock inversion within dma-fence-array
  (bnc#1012628).
- drm/edid: set ELD connector type in drm_edid_to_eld()
  (bnc#1012628).
- KVM: PPC: Book3S HV: Avoid shifts by negative amounts
  (bnc#1012628).
- HID: multitouch: Only look at non touch fields in first packet
  of a frame (bnc#1012628).
- spi: imx: Fix failure path leak on GPIO request error correctly
  (bnc#1012628).
- drm/panel: rpi-touchscreen: propagate errors in
  rpi_touchscreen_i2c_read() (bnc#1012628).
- gfs2: Fixes to "Implement iomap for block_map" (2)
  (bnc#1012628).
- gfs2: Clean up {lookup,fillup}_metapath (bnc#1012628).
- Revert "btrfs: use proper endianness accessors for super_copy"
  (bnc#1012628).
- dm mpath: fix passing integrity data (bnc#1012628).
- earlycon: add reg-offset to physical address before mapping
  (bnc#1012628).
- serial: core: mark port as initialized in autoconfig
  (bnc#1012628).
- serial: 8250_pci: Add Brainboxes UC-260 4 port serial device
  (bnc#1012628).
- usb: dwc3: Fix lock-up on ID change during system suspend/resume
  (bnc#1012628).
- usb: gadget: f_fs: Fix use-after-free in ffs_fs_kill_sb()
  (bnc#1012628).
- usb: usbmon: Read text within supplied buffer size
  (bnc#1012628).
- usb: quirks: add control message delay for 1b1c:1b20
  (bnc#1012628).
- usbip: vudc: fix null pointer dereference on udc->lock
  (bnc#1012628).
- USB: storage: Add JMicron bridge 152d:2567 to unusual_devs.h
  (bnc#1012628).
- scsi: sd_zbc: Fix potential memory leak (bnc#1012628).
- staging: android: ashmem: Fix lockdep issue during llseek
  (bnc#1012628).
- staging: comedi: fix comedi_nsamples_left (bnc#1012628).
- uas: fix comparison for error code (bnc#1012628).
- tty/serial: atmel: add new version check for usart
  (bnc#1012628).
- serial: sh-sci: prevent lockup on full TTY buffers
  (bnc#1012628).
- xhci: fix endpoint context tracer output (bnc#1012628).
- xhci: Fix front USB ports on ASUS PRIME B350M-A (bnc#1012628).
- usb: host: xhci-rcar: add support for r8a77965 (bnc#1012628).
- ASoC: rt5651: Fix regcache sync errors on resume (bnc#1012628).
- ASoC: wm_adsp: For TLV controls only register TLV get/set
  (bnc#1012628).
- ASoC: sgtl5000: Fix suspend/resume (bnc#1012628).
- ASoC: sun4i-i2s: Fix RX slot number of SUN8I (bnc#1012628).
- x86: Treat R_X86_64_PLT32 as R_X86_64_PC32 (bnc#1012628).
- commit 5c89418
* Mon Mar 19 2018 mkubecek@suse.cz
- Update
  patches.kernel.org/4.15.10-113-netfilter-ebtables-CONFIG_COMPAT-don-t-trust-.patch
  references (add CVE-2018-1068).
- Update
  patches.suse/netfilter-ebtables-fix-erroneous-reject-of-last-rule.patch
  references (add CVE-2018-1068).
- commit 3127e9f
* Mon Mar 19 2018 msuchanek@suse.de
- kernel-*.spec: remove remaining occurences of %%release from dependencies
  There is a mix of %%release and %%source_rel in manually added
  dependencies and the %%release dependencies tend to fail due to rebuild
  sync issues. So get rid of them.
- commit b4ec514
* Mon Mar 19 2018 jeffm@suse.com
- Update to 4.16-rc6.
- commit a98eb00
* Mon Mar 19 2018 jeffm@suse.com
- Refresh patches.suse/kernel-add-release-status-to-kernel-build.patch.
- commit cf5ff13
* Thu Mar 15 2018 jslaby@suse.cz
- Linux 4.15.10 (bnc#1012628).
- RDMA/ucma: Limit possible option size (bnc#1012628).
- RDMA/ucma: Check that user doesn't overflow QP state
  (bnc#1012628).
- RDMA/mlx5: Fix integer overflow while resizing CQ (bnc#1012628).
- IB/uverbs: Improve lockdep_check (bnc#1012628).
- mac80211_hwsim: don't use WQ_MEM_RECLAIM (bnc#1012628).
- net/smc: fix NULL pointer dereference on sock_create_kern()
  error path (bnc#1012628).
- regulator: stm32-vrefbuf: fix check on ready flag (bnc#1012628).
- drm/i915: Check for fused or unused pipes (bnc#1012628).
- drm/i915/audio: fix check for av_enc_map overflow (bnc#1012628).
- drm/i915: Fix rsvd2 mask when out-fence is returned
  (bnc#1012628).
- drm/i915: Clear the in-use marker on execbuf failure
  (bnc#1012628).
- drm/i915: Disable DC states around GMBUS on GLK (bnc#1012628).
- drm/i915: Update watermark state correctly in
  sanitize_watermarks (bnc#1012628).
- drm/i915: Try EDID bitbanging on HDMI after failed read
  (bnc#1012628).
- drm/i915/perf: fix perf stream opening lock (bnc#1012628).
- scsi: core: Avoid that ATA error handling can trigger a kernel
  hang or oops (bnc#1012628).
- scsi: qla2xxx: Fix NULL pointer crash due to active timer for
  ABTS (bnc#1012628).
- drm/i915: Always call to intel_display_set_init_power() in
  resume_early (bnc#1012628).
- workqueue: Allow retrieval of current task's work struct
  (bnc#1012628).
- drm: Allow determining if current task is output poll worker
  (bnc#1012628).
- drm/nouveau: Fix deadlock on runtime suspend (bnc#1012628).
- drm/radeon: Fix deadlock on runtime suspend (bnc#1012628).
- drm/amdgpu: Fix deadlock on runtime suspend (bnc#1012628).
- drm/nouveau: prefer XBGR2101010 for addfb ioctl (bnc#1012628).
- drm/amd/powerplay/smu7: allow mclk switching with no displays
  (bnc#1012628).
- drm/amd/powerplay/vega10: allow mclk switching with no displays
  (bnc#1012628).
- Revert "drm/radeon/pm: autoswitch power state when in balanced
  mode" (bnc#1012628).
- drm/amd/display: check for ipp before calling cursor operations
  (bnc#1012628).
- drm/radeon: insist on 32-bit DMA for Cedar on PPC64/PPC64LE
  (bnc#1012628).
- drm/amd/powerplay: fix power over limit on Fiji (bnc#1012628).
- drm/amd/display: Default HDMI6G support to true. Log VBIOS
  table error (bnc#1012628).
- drm/amdgpu: used cached pcie gen info for SI (v2) (bnc#1012628).
- drm/amdgpu: Notify sbios device ready before send request
  (bnc#1012628).
- drm/radeon: fix KV harvesting (bnc#1012628).
- drm/amdgpu: fix KV harvesting (bnc#1012628).
- drm/amdgpu:Correct max uvd handles (bnc#1012628).
- drm/amdgpu:Always save uvd vcpu_bo in VM Mode (bnc#1012628).
- ovl: redirect_dir=nofollow should not follow redirect for
  opaque lower (bnc#1012628).
- MIPS: BMIPS: Do not mask IPIs during suspend (bnc#1012628).
- MIPS: ath25: Check for kzalloc allocation failure (bnc#1012628).
- MIPS: OCTEON: irq: Check for null return on kzalloc allocation
  (bnc#1012628).
- PCI: dwc: Fix enumeration end when reaching root subordinate
  (bnc#1012628).
- Input: matrix_keypad - fix race when disabling interrupts
  (bnc#1012628).
- Revert "Input: synaptics - Lenovo Thinkpad T460p devices should
  use RMI" (bnc#1012628).
- bug: use %%pB in BUG and stack protector failure (bnc#1012628).
- lib/bug.c: exclude non-BUG/WARN exceptions from report_bug()
  (bnc#1012628).
- mm/memblock.c: hardcode the end_pfn being -1 (bnc#1012628).
- loop: Fix lost writes caused by missing flag (bnc#1012628).
- virtio_ring: fix num_free handling in error case (bnc#1012628).
- KVM: s390: fix memory overwrites when not using SCA entries
  (bnc#1012628).
- arm64: mm: fix thinko in non-global page table attribute check
  (bnc#1012628).
- IB/core: Fix missing RDMA cgroups release in case of failure
  to register device (bnc#1012628).
- Revert "nvme: create 'slaves' and 'holders' entries for hidden
  controllers" (bnc#1012628).
- kbuild: Handle builtin dtb file names containing hyphens
  (bnc#1012628).
- dm bufio: avoid false-positive Wmaybe-uninitialized warning
  (bnc#1012628).
- IB/mlx5: Fix incorrect size of klms in the memory region
  (bnc#1012628).
- bcache: fix crashes in duplicate cache device register
  (bnc#1012628).
- bcache: don't attach backing with duplicate UUID (bnc#1012628).
- x86/MCE: Save microcode revision in machine check records
  (bnc#1012628).
- x86/MCE: Serialize sysfs changes (bnc#1012628).
- perf tools: Fix trigger class trigger_on() (bnc#1012628).
- x86/spectre_v2: Don't check microcode versions when running
  under hypervisors (bnc#1012628).
- ALSA: hda/realtek - Add support headset mode for DELL WYSE
  (bnc#1012628).
- ALSA: hda/realtek - Add headset mode support for Dell laptop
  (bnc#1012628).
- ALSA: hda/realtek: Limit mic boost on T480 (bnc#1012628).
- ALSA: hda/realtek - Fix dock line-out volume on Dell Precision
  7520 (bnc#1012628).
- ALSA: hda/realtek - Make dock sound work on ThinkPad L570
  (bnc#1012628).
- ALSA: seq: Don't allow resizing pool in use (bnc#1012628).
- ALSA: seq: More protection for concurrent write and ioctl races
  (bnc#1012628).
- ALSA: hda - Fix a wrong FIXUP for alc289 on Dell machines
  (bnc#1012628).
- ALSA: hda: add dock and led support for HP EliteBook 820 G3
  (bnc#1012628).
- ALSA: hda: add dock and led support for HP ProBook 640 G2
  (bnc#1012628).
- scsi: qla2xxx: Fix NULL pointer crash due to probe failure
  (bnc#1012628).
- scsi: qla2xxx: Fix recursion while sending terminate exchange
  (bnc#1012628).
- dt-bindings: Document mti,mips-cpc binding (bnc#1012628).
- MIPS: CPC: Map registers using DT in
  mips_cpc_default_phys_base() (bnc#1012628).
- nospec: Kill array_index_nospec_mask_check() (bnc#1012628).
- nospec: Include <asm/barrier.h> dependency (bnc#1012628).
- x86/entry: Reduce the code footprint of the 'idtentry' macro
  (bnc#1012628).
- x86/entry/64: Use 'xorl' for faster register clearing
  (bnc#1012628).
- x86/mm: Remove stale comment about KMEMCHECK (bnc#1012628).
- x86/asm: Improve how GEN_*_SUFFIXED_RMWcc() specify clobbers
  (bnc#1012628).
- x86/IO-APIC: Avoid warning in 32-bit builds (bnc#1012628).
- x86/LDT: Avoid warning in 32-bit builds with older gcc
  (bnc#1012628).
- x86-64/realmode: Add instruction suffix (bnc#1012628).
- Revert "x86/retpoline: Simplify vmexit_fill_RSB()"
  (bnc#1012628).
- x86/speculation: Use IBRS if available before calling into
  firmware (bnc#1012628).
- x86/retpoline: Support retpoline builds with Clang
  (bnc#1012628).
- x86/speculation, objtool: Annotate indirect calls/jumps for
  objtool (bnc#1012628).
- x86/speculation: Move firmware_restrict_branch_speculation_*()
  from C to CPP (bnc#1012628).
- x86/paravirt, objtool: Annotate indirect calls (bnc#1012628).
- x86/boot, objtool: Annotate indirect jump in
  secondary_startup_64() (bnc#1012628).
- x86/mm/sme, objtool: Annotate indirect call in
  sme_encrypt_execute() (bnc#1012628).
- objtool: Use existing global variables for options
  (bnc#1012628).
- objtool: Add retpoline validation (bnc#1012628).
- objtool: Add module specific retpoline rules (bnc#1012628).
- objtool, retpolines: Integrate objtool with retpoline support
  more closely (bnc#1012628).
- objtool: Fix another switch table detection issue (bnc#1012628).
- objtool: Fix 32-bit build (bnc#1012628).
- x86/kprobes: Fix kernel crash when probing .entry_trampoline
  code (bnc#1012628).
- watchdog: hpwdt: SMBIOS check (bnc#1012628).
- watchdog: hpwdt: Check source of NMI (bnc#1012628).
- watchdog: hpwdt: fix unused variable warning (bnc#1012628).
- watchdog: hpwdt: Remove legacy NMI sourcing (bnc#1012628).
- netfilter: add back stackpointer size checks (bnc#1012628).
- netfilter: ipt_CLUSTERIP: fix a race condition of proc file
  creation (bnc#1012628).
- netfilter: xt_hashlimit: fix lock imbalance (bnc#1012628).
- netfilter: x_tables: fix missing timer initialization in xt_LED
  (bnc#1012628).
- netfilter: nat: cope with negative port range (bnc#1012628).
- netfilter: IDLETIMER: be syzkaller friendly (bnc#1012628).
- netfilter: bridge: ebt_among: add missing match size checks
  (bnc#1012628).
- netfilter: ipv6: fix use-after-free Write in
  nf_nat_ipv6_manip_pkt (bnc#1012628).
- netfilter: use skb_to_full_sk in ip6_route_me_harder
  (bnc#1012628).
- tpm_tis: Move ilb_base_addr to tpm_tis_data (bnc#1012628).
- tpm: Keep CLKRUN enabled throughout the duration of
  transmit_cmd() (bnc#1012628).
- tpm: delete the TPM_TIS_CLK_ENABLE flag (bnc#1012628).
- tpm: remove unused variables (bnc#1012628).
- tpm: only attempt to disable the LPC CLKRUN if is already
  enabled (bnc#1012628).
- x86/xen: Calculate __max_logical_packages on PV domains
  (bnc#1012628).
- scsi: qla2xxx: Fix system crash for Notify ack timeout handling
  (bnc#1012628).
- scsi: qla2xxx: Fix gpnid error processing (bnc#1012628).
- scsi: qla2xxx: Move session delete to driver work queue
  (bnc#1012628).
- scsi: qla2xxx: Skip IRQ affinity for Target QPairs
  (bnc#1012628).
- scsi: qla2xxx: Fix re-login for Nport Handle in use
  (bnc#1012628).
- scsi: qla2xxx: Retry switch command on time out (bnc#1012628).
- scsi: qla2xxx: Serialize GPNID for multiple RSCN (bnc#1012628).
- scsi: qla2xxx: Fix login state machine stuck at GPDB
  (bnc#1012628).
- scsi: qla2xxx: Fix NPIV host cleanup in target mode
  (bnc#1012628).
- scsi: qla2xxx: Relogin to target port on a cable swap
  (bnc#1012628).
- scsi: qla2xxx: Fix Relogin being triggered too fast
  (bnc#1012628).
- scsi: qla2xxx: Fix PRLI state check (bnc#1012628).
- scsi: qla2xxx: Fix abort command deadlock due to spinlock
  (bnc#1012628).
- scsi: qla2xxx: Replace fcport alloc with qla2x00_alloc_fcport
  (bnc#1012628).
- scsi: qla2xxx: Fix scan state field for fcport (bnc#1012628).
- scsi: qla2xxx: Clear loop id after delete (bnc#1012628).
- scsi: qla2xxx: Defer processing of GS IOCB calls (bnc#1012628).
- scsi: qla2xxx: Remove aborting ELS IOCB call issued as part
  of timeout (bnc#1012628).
- scsi: qla2xxx: Fix system crash in qlt_plogi_ack_unref
  (bnc#1012628).
- scsi: qla2xxx: Fix memory leak in dual/target mode
  (bnc#1012628).
- NFS: Fix an incorrect type in struct nfs_direct_req
  (bnc#1012628).
- pNFS: Prevent the layout header refcount going to zero in
  pnfs_roc() (bnc#1012628).
- NFS: Fix unstable write completion (bnc#1012628).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Refresh
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- Refresh
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- commit 5e4329c
* Thu Mar 15 2018 tiwai@suse.de
- Bluebooth: btusb: Fix quirk for Atheros 1525/QCA6174
  (bsc#1082504).
- commit 8413b00
* Thu Mar 15 2018 tiwai@suse.de
- Bluebooth: btusb: Fix quirk for Atheros 1525/QCA6174
  (bsc#1082504).
- commit e8a80ec
* Thu Mar 15 2018 mkubecek@suse.cz
- netfilter: ebtables: fix erroneous reject of last rule
  (bsc#1085107).
- netfilter: ebtables: CONFIG_COMPAT: don't trust userland offsets
  (bsc#1085107).
- commit bfb5701
* Wed Mar 14 2018 jeffm@suse.com
- config: sync i386/default
  Some options had been removed completely.
- commit 95f48d7
* Wed Mar 14 2018 jeffm@suse.com
- rpm/kernel-source.spec.in: Add check-module-license to Sources
  The package builds in the build service but the script won't make it
  into the SRPM if it's not in the Sources list.
- commit 031ed9e
* Wed Mar 14 2018 tiwai@suse.de
- brcmsmac: allocate ucode with GFP_KERNEL (bsc#1085174).
- commit 8e06b20
* Wed Mar 14 2018 tiwai@suse.de
- mac80211_hwsim: fix possible memory leak in hwsim_new_radio_nl()
  (CVE-2018-8087,bsc#1085053).
- commit cddf6d5
* Tue Mar 13 2018 msuchanek@suse.de
- mkspec: fix perl warning
- commit f15670f
* Mon Mar 12 2018 jeffm@suse.com
- Update to 4.16-rc5.
- Eliminated 1 patch.
- commit 0dfffad
* Mon Mar 12 2018 jslaby@suse.cz
- Linux 4.15.9 (bnc#1012628).
- bpf: fix mlock precharge on arraymaps (bnc#1012628).
- bpf: fix memory leak in lpm_trie map_free callback function
  (bnc#1012628).
- bpf: fix rcu lockdep warning for lpm_trie map_free callback
  (bnc#1012628).
- bpf, x64: implement retpoline for tail call (bnc#1012628).
- bpf, arm64: fix out of bounds access in tail call (bnc#1012628).
- bpf: add schedule points in percpu arrays management
  (bnc#1012628).
- bpf: allow xadd only on aligned memory (bnc#1012628).
- bpf, ppc64: fix out of bounds access in tail call (bnc#1012628).
- scsi: mpt3sas: fix oops in error handlers after shutdown/unload
  (bnc#1012628).
- scsi: mpt3sas: wait for and flush running commands on
  shutdown/unload (bnc#1012628).
- KVM: x86: fix backward migration with async_PF (bnc#1012628).
- Refresh
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- commit 23fae4b
* Sun Mar 11 2018 afaerber@suse.de
- config: armv7hl: Update to 4.16-rc4
- commit ad451a4
* Sun Mar 11 2018 afaerber@suse.de
- config: armv6hl: Update to 4.16-rc4
- commit 6c846e1
* Sat Mar 10 2018 tiwai@suse.de
- Refresh to upstream patch (bsc#1083694)
  patches.suse/Documentation-sphinx-Fix-Directive-import-error.patch
- commit 2d62679
* Sat Mar 10 2018 jeffm@suse.com
- kernel: add release status to kernel build (bsc#FATE#325281).
- commit c51605f
* Sat Mar 10 2018 jeffm@suse.com
- rpm: use %%_sourcedir prefix for release-projects
- rpm: set SUSE_KERNEL_RELEASED based on project name
  Set SUSE_KERNEL_RELEASED in the config only if the project name matches
  a list of projects that are part of official release channels.  This
  list of projects is maintained per-branch.
- commit a391a5b
* Fri Mar  9 2018 jeffm@suse.com
- config: added new 'kvmsmall' flavor
  This flavor is an unreleased internal configuration intended for kernel
  developers to use in simple virtual machines.  It contains only the
  device drivers necessary to use a KVM virtual machine *without* device
  passthrough enabled.  Common local and network file systems are enabled.
  All device mapper targets are enabled.  Only the network and graphics
  drivers for devices that qemu emulates are enabled.  Many subsystems
  enabled in the default kernel are entirely disabled.  This kernel is
  meant to be small and to build very quickly.  There will be no kABI
  stability and its configuration may be changed arbitrarily.
- commit 088f1da
* Fri Mar  9 2018 jeffm@suse.com
- config: convert kvmsmall to fragment config
- commit 7a5941a
* Fri Mar  9 2018 jeffm@suse.com
- config: disabled some more options for kvmsmall
  Disable CAN, BT, rare partition types, unused mouse protocols, UIO,
  STM, and others.
- commit 4707d44
* Fri Mar  9 2018 jeffm@suse.com
- config: added new 'kvmsmall' flavor
  This flavor is intended for kernel developers to use in simple virtual
  machines.  It contains only the device drivers necessary to use a
  KVM virtual machine *without* device passthrough enabled.  Common
  local and network file systems are enabled.  All device mapper targets
  are enabled.  Only the network and graphics drivers for devices that qemu
  emulates are enabled.  Many subsystems enabled in the default kernel
  are entirely disabled.  This kernel is meant to be small and to build
  very quickly.
- commit 3c99d1f
* Fri Mar  9 2018 jslaby@suse.cz
- Linux 4.15.8 (bnc#1012628).
- platform/x86: dell-laptop: fix kbd_get_state's request value
  (bnc#1012628).
- md: only allow remove_and_add_spares when no sync_thread running
  (bnc#1012628).
- powerpc/64s/radix: Boot-time NULL pointer protection using a
  guard-PID (bnc#1012628).
- ARM: dts: LogicPD Torpedo: Fix I2C1 pinmux (bnc#1012628).
- ARM: dts: LogicPD SOM-LV: Fix I2C1 pinmux (bnc#1012628).
- ACPI / bus: Parse tables as term_list for Dell XPS 9570 and
  Precision M5530 (bnc#1012628).
- KVM/x86: remove WARN_ON() for when vm_munmap() fails
  (bnc#1012628).
- KVM: x86: fix vcpu initialization with userspace lapic
  (bnc#1012628).
- KVM/VMX: Optimize vmx_vcpu_run() and svm_vcpu_run() by marking
  the RDMSR path as unlikely() (bnc#1012628).
- KVM: x86: move LAPIC initialization after VMCS creation
  (bnc#1012628).
- KVM/x86: Remove indirect MSR op calls from SPEC_CTRL
  (bnc#1012628).
- KVM: mmu: Fix overlap between public and private memslots
  (bnc#1012628).
- KVM: X86: Fix SMRAM accessing even if VM is shutdown
  (bnc#1012628).
- ARM: kvm: fix building with gcc-8 (bnc#1012628).
- ARM: mvebu: Fix broken PL310_ERRATA_753970 selects
  (bnc#1012628).
- ARM: dts: rockchip: Remove 1.8 GHz operation point from phycore
  som (bnc#1012628).
- ARM: orion: fix orion_ge00_switch_board_info initialization
  (bnc#1012628).
- x86/mm: Fix {pmd,pud}_{set,clear}_flags() (bnc#1012628).
- nospec: Allow index argument to have const-qualified type
  (bnc#1012628).
- KVM: s390: consider epoch index on TOD clock syncs
  (bnc#1012628).
- KVM: s390: consider epoch index on hotplugged CPUs
  (bnc#1012628).
- KVM: s390: provide only a single function for setting the tod
  (fix SCK) (bnc#1012628).
- KVM: s390: take care of clock-comparator sign control
  (bnc#1012628).
- EDAC, sb_edac: Fix out of bound writes during DIMM configuration
  on KNL (bnc#1012628).
- media: m88ds3103: don't call a non-initalized function
  (bnc#1012628).
- blk-mq: don't call io sched's .requeue_request when requeueing
  rq to ->dispatch (bnc#1012628).
- tcp: revert F-RTO extension to detect more spurious timeouts
  (bnc#1012628).
- tcp: revert F-RTO middle-box workaround (bnc#1012628).
- s390/qeth: fix IPA command submission race (bnc#1012628).
- s390/qeth: fix IP address lookup for L3 devices (bnc#1012628).
- Revert "s390/qeth: fix using of ref counter for rxip addresses"
  (bnc#1012628).
- s390/qeth: fix double-free on IP add/remove race (bnc#1012628).
- s390/qeth: fix IP removal on offline cards (bnc#1012628).
- s390/qeth: fix overestimated count of buffer elements
  (bnc#1012628).
- s390/qeth: fix SETIP command handling (bnc#1012628).
- s390/qeth: fix underestimated count of buffer elements
  (bnc#1012628).
- l2tp: fix tunnel lookup use-after-free race (bnc#1012628).
- l2tp: fix race in pppol2tp_release with session object destroy
  (bnc#1012628).
- l2tp: fix races with tunnel socket close (bnc#1012628).
- l2tp: don't use inet_shutdown on ppp session destroy
  (bnc#1012628).
- l2tp: don't use inet_shutdown on tunnel destroy (bnc#1012628).
- tcp: tracepoint: only call trace_tcp_send_reset with full socket
  (bnc#1012628).
- net: phy: Restore phy_resume() locking assumption (bnc#1012628).
- net/mlx5: Fix error handling when adding flow rules
  (bnc#1012628).
- cxgb4: fix trailing zero in CIM LA dump (bnc#1012628).
- virtio-net: disable NAPI only when enabled during XDP set
  (bnc#1012628).
- tuntap: disable preemption during XDP processing (bnc#1012628).
- tuntap: correctly add the missing XDP flush (bnc#1012628).
- tcp: purge write queue upon RST (bnc#1012628).
- netlink: put module reference if dump start fails (bnc#1012628).
- mlxsw: spectrum_router: Do not unconditionally clear route
  offload indication (bnc#1012628).
- cls_u32: fix use after free in u32_destroy_key() (bnc#1012628).
- amd-xgbe: Restore PCI interrupt enablement setting on resume
  (bnc#1012628).
- tls: Use correct sk->sk_prot for IPV6 (bnc#1012628).
- net/mlx5e: Verify inline header size do not exceed SKB linear
  size (bnc#1012628).
- bridge: Fix VLAN reference count problem (bnc#1012628).
- sctp: fix dst refcnt leak in sctp_v6_get_dst() (bnc#1012628).
- net: ipv4: Set addr_type in hash_keys for forwarded case
  (bnc#1012628).
- mlxsw: spectrum_router: Fix error path in mlxsw_sp_vr_create
  (bnc#1012628).
- sctp: do not pr_err for the duplicated node in transport rhlist
  (bnc#1012628).
- net/sched: cls_u32: fix cls_u32 on filter replace (bnc#1012628).
- net_sched: gen_estimator: fix broken estimators based on percpu
  stats (bnc#1012628).
- net/mlx5e: Fix loopback self test when GRO is off (bnc#1012628).
- doc: Change the min default value of tcp_wmem/tcp_rmem
  (bnc#1012628).
- tcp_bbr: better deal with suboptimal GSO (bnc#1012628).
- rxrpc: Fix send in rxrpc_send_data_packet() (bnc#1012628).
- tcp: Honor the eor bit in tcp_mtu_probe (bnc#1012628).
- net: phy: fix phy_start to consider PHY_IGNORE_INTERRUPT
  (bnc#1012628).
- net/mlx5e: Specify numa node when allocating drop rq
  (bnc#1012628).
- mlxsw: spectrum_switchdev: Check success of FDB add operation
  (bnc#1012628).
- sctp: fix dst refcnt leak in sctp_v4_get_dst (bnc#1012628).
- net/mlx5e: Fix TCP checksum in LRO buffers (bnc#1012628).
- udplite: fix partial checksum initialization (bnc#1012628).
- sctp: verify size of a new chunk in _sctp_make_chunk()
  (bnc#1012628).
- ppp: prevent unregistered channels from connecting to PPP units
  (bnc#1012628).
- net: sched: report if filter is too large to dump (bnc#1012628).
- netlink: ensure to loop over all netns in
  genlmsg_multicast_allns() (bnc#1012628).
- net: ipv4: don't allow setting net.ipv4.route.min_pmtu below 68
  (bnc#1012628).
- net: fix race on decreasing number of TX queues (bnc#1012628).
- net: ethernet: ti: cpsw: fix net watchdog timeout (bnc#1012628).
- net: amd-xgbe: fix comparison to bitshift when dealing with
  a mask (bnc#1012628).
- ipv6 sit: work around bogus gcc-8 -Wrestrict warning
  (bnc#1012628).
- hdlc_ppp: carrier detect ok, don't turn off negotiation
  (bnc#1012628).
- fib_semantics: Don't match route with mismatching tclassid
  (bnc#1012628).
- bridge: check brport attr show in brport_show (bnc#1012628).
- x86/cpu_entry_area: Sync cpu_entry_area to initial_page_table
  (bnc#1012628).
- x86/platform/intel-mid: Handle Intel Edison reboot correctly
  (bnc#1012628).
- x86/xen: Zero MSR_IA32_SPEC_CTRL before suspend (bnc#1012628).
- direct-io: Fix sleep in atomic due to sync AIO (bnc#1012628).
- dax: fix vma_is_fsdax() helper (bnc#1012628).
- cpufreq: s3c24xx: Fix broken s3c_cpufreq_init() (bnc#1012628).
- vfio: disable filesystem-dax page pinning (bnc#1012628).
- block: pass inclusive 'lend' parameter to
  truncate_inode_pages_range (bnc#1012628).
- block: kyber: fix domain token leak during requeue
  (bnc#1012628).
- block: fix the count of PGPGOUT for WRITE_SAME (bnc#1012628).
- btrfs: use proper endianness accessors for super_copy
  (bnc#1012628).
- parisc: Hide virtual kernel memory layout (bnc#1012628).
- parisc: Fix ordering of cache and TLB flushes (bnc#1012628).
- parisc: Reduce irq overhead when run in qemu (bnc#1012628).
- parisc: Use cr16 interval timers unconditionally on qemu
  (bnc#1012628).
- timers: Forward timer base before migrating timers
  (bnc#1012628).
- mmc: dw_mmc: Fix out-of-bounds access for slot's caps
  (bnc#1012628).
- mmc: dw_mmc: Factor out dw_mci_init_slot_caps (bnc#1012628).
- mmc: dw_mmc: Avoid accessing registers in runtime suspended
  state (bnc#1012628).
- mmc: dw_mmc-k3: Fix out-of-bounds access through DT alias
  (bnc#1012628).
- mmc: sdhci-pci: Fix S0i3 for Intel BYT-based controllers
  (bnc#1012628).
- ALSA: hda - Fix pincfg at resume on Lenovo T470 dock
  (bnc#1012628).
- ALSA: hda: Add a power_save blacklist (bnc#1012628).
- ALSA: x86: Fix missing spinlock and mutex initializations
  (bnc#1012628).
- ALSA: control: Fix memory corruption risk in snd_ctl_elem_read
  (bnc#1012628).
- ALSA: usb-audio: Add a quirck for B&W PX headphones
  (bnc#1012628).
- tpm_tis: fix potential buffer overruns caused by bit glitches
  on the bus (bnc#1012628).
- tpm_i2c_nuvoton: fix potential buffer overruns caused by bit
  glitches on the bus (bnc#1012628).
- tpm_i2c_infineon: fix potential buffer overruns caused by bit
  glitches on the bus (bnc#1012628).
- tpm: fix potential buffer overruns caused by bit glitches on
  the bus (bnc#1012628).
- tpm: st33zp24: fix potential buffer overruns caused by bit
  glitches on the bus (bnc#1012628).
- ixgbe: fix crash in build_skb Rx code path (bnc#1012628).
- Bluetooth: btusb: Use DMI matching for QCA reset_resume quirking
  (bnc#1012628).
- powerpc/pseries: Enable RAS hotplug events later (bnc#1012628).
- platform/x86: dell-laptop: Allocate buffer on heap rather than
  globally (bnc#1012628).
- ipmi_si: Fix error handling of platform device (bnc#1012628).
- hrtimer: Ensure POSIX compliance (relative CLOCK_REALTIME
  hrtimers) (bnc#1012628).
- vsprintf: avoid misleading "(null)" for %%px (bnc#1012628).
- commit 67f0889
* Thu Mar  8 2018 msuchanek@suse.de
- mkspec: do not build dtbs for architectures with no kernel.
- commit 8394abf
* Thu Mar  8 2018 jeffm@suse.com
- kconfig: move SUSE options from init/Kconfig to init/Kconfig.suse
- commit b7f69ff
* Wed Mar  7 2018 afaerber@suse.de
- config: arm64: Update to 4.16-rc4
- commit 0bb9ed4
* Wed Mar  7 2018 tiwai@suse.de
- rpm/kernel-binary.spec.in: Check module licenses (bsc#1083215,bsc#1083527)
- commit e41de0c
* Wed Mar  7 2018 tiwai@suse.de
- x86/kvm/vmx: do not use vm-exit instruction length for fast
  MMIO when running nested (bsc#1081431).
- commit 4e5b14d
* Tue Mar  6 2018 jslaby@suse.cz
- Update config files.
  Enable module signing (bnc#1082905):
  * CONFIG_MODULE_SIG=y
  * # CONFIG_MODULE_SIG_FORCE is not set
  * # CONFIG_MODULE_SIG_ALL is not set
  * # CONFIG_MODULE_SIG_SHA1 is not set
  * # CONFIG_MODULE_SIG_SHA224 is not set
  * CONFIG_MODULE_SIG_SHA256=y
  * # CONFIG_MODULE_SIG_SHA384 is not set
  * # CONFIG_MODULE_SIG_SHA512 is not set
  * CONFIG_MODULE_SIG_HASH="sha256"
  * CONFIG_MODULE_SIG_KEY="certs/signing_key.pem"
  * CONFIG_SECONDARY_TRUSTED_KEYRING=y
  * CONFIG_SYSTEM_BLACKLIST_KEYRING=y
  * CONFIG_SYSTEM_BLACKLIST_HASH_LIST=""
  This commit synchronizes these options with SLE15.
  We do not add patches for loading keys from the shim layer (as in
  SLE15) for the time being. They were rejected multiple times in
  upstream and we do not want to forward-port them infinitely. This only
  means that loading KMPs with none/invalid signatures generates this:
  <module_name>: loading out-of-tree module taints kernel.
  <module_name>: module verification failed: signature and/or required key missing - tainting kernel
  But the modules load fine after that as we have MODULE_SIG_FORCE set
  to 'n'.
  Tested in qemu+OVMF and bare metal and everything looks fine.
- commit 12abbef
* Mon Mar  5 2018 msuchanek@suse.de
- rpm: provide %%name%%-srchash = <kernel-source commit hash> (FATE#325312).
  - Also use for kernel-obs-build dependency.
- commit b6fccdf
* Mon Mar  5 2018 jeffm@suse.com
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Refresh
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- Refresh
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- commit 1ba5305
* Mon Mar  5 2018 jeffm@suse.com
- Update to 4.16-rc4.
- IBRS patches need review.
- commit 061459a
* Sun Mar  4 2018 msuchanek@suse.de
- arch-symbols: use bash as interpreter since the script uses bashism.
- commit 4cdfb23
* Fri Mar  2 2018 msuchanek@suse.de
- kernel-binary: do not BuildIgnore m4.
  It is actually needed for regenerating zconf when it is not up-to-date
  due to merge.
- commit 967b28b
* Fri Mar  2 2018 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: add build requirement for flex
  In addition to bison, we also need flex for "make oldconfig".
- commit 83d831c
* Fri Mar  2 2018 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: remove m4 from BuildIgnore list
  As bison depends on m4, we cannot set !BuildIgnore for it any more.
- commit d7695e1
* Fri Mar  2 2018 tiwai@suse.de
- Documentation/sphinx: Fix Directive import error (bsc#1083694).
- commit 7f94eb1
* Wed Feb 28 2018 msuchanek@suse.de
- bs-upload-kernel: do not set %%opensuse_bs
  Since SLE15 it is not set in the distribution project so do not set it
  for kernel projects either.
- commit d696aa0
* Wed Feb 28 2018 jslaby@suse.cz
- Linux 4.15.7 (bnc#1012628).
- microblaze: fix endian handling (bnc#1012628).
- drm/i915/breadcrumbs: Ignore unsubmitted signalers
  (bnc#1012628).
- arm64: __show_regs: Only resolve kernel symbols when running
  at EL1 (bnc#1012628).
- drm/amdgpu: add new device to use atpx quirk (bnc#1012628).
- drm/amdgpu: Avoid leaking PM domain on driver unbind (v2)
  (bnc#1012628).
- drm/amdgpu: add atpx quirk handling (v2) (bnc#1012628).
- drm/amdgpu: only check mmBIF_IOV_FUNC_IDENTIFIER on tonga/fiji
  (bnc#1012628).
- drm/amdgpu: Add dpm quirk for Jet PRO (v2) (bnc#1012628).
- drm/amdgpu: fix VA hole handling on Vega10 v3 (bnc#1012628).
- drm/amdgpu: disable MMHUB power gating on raven (bnc#1012628).
- drm: Handle unexpected holes in color-eviction (bnc#1012628).
- drm/atomic: Fix memleak on ERESTARTSYS during non-blocking
  commits (bnc#1012628).
- drm/cirrus: Load lut in crtc_commit (bnc#1012628).
- usb: renesas_usbhs: missed the "running" flag in usb_dmac with
  rx path (bnc#1012628).
- usb: gadget: f_fs: Use config_ep_by_speed() (bnc#1012628).
- usb: gadget: f_fs: Process all descriptors during bind
  (bnc#1012628).
- Revert "usb: musb: host: don't start next rx urb if current
  one failed" (bnc#1012628).
- usb: ldusb: add PIDs for new CASSY devices supported by this
  driver (bnc#1012628).
- usb: phy: mxs: Fix NULL pointer dereference on i.MX23/28
  (bnc#1012628).
- usb: dwc3: ep0: Reset TRB counter for ep0 IN (bnc#1012628).
- usb: dwc3: gadget: Set maxpacket size for ep0 IN (bnc#1012628).
- usb: host: ehci: use correct device pointer for dma ops
  (bnc#1012628).
- drm/edid: Add 6 bpc quirk for CPT panel in Asus UX303LA
  (bnc#1012628).
- Add delay-init quirk for Corsair K70 RGB keyboards
  (bnc#1012628).
- arm64: cpufeature: Fix CTR_EL0 field definitions (bnc#1012628).
- arm64: Disable unhandled signal log messages by default
  (bnc#1012628).
- arm64: Remove unimplemented syscall log message (bnc#1012628).
- usb: ohci: Proper handling of ed_rm_list to handle race
  condition between usb_kill_urb() and finish_unlinks()
  (bnc#1012628).
- ohci-hcd: Fix race condition caused by ohci_urb_enqueue()
  and io_watchdog_func() (bnc#1012628).
- net: thunderbolt: Run disconnect flow asynchronously when
  logout is received (bnc#1012628).
- net: thunderbolt: Tear down connection properly on suspend
  (bnc#1012628).
- PCI/cxgb4: Extend T3 PCI quirk to T4+ devices (bnc#1012628).
- irqchip/mips-gic: Avoid spuriously handling masked interrupts
  (bnc#1012628).
- irqchip/gic-v3: Use wmb() instead of smb_wmb() in
  gic_raise_softirq() (bnc#1012628).
- uapi/if_ether.h: move __UAPI_DEF_ETHHDR libc define
  (bnc#1012628).
- mm: don't defer struct page initialization for Xen pv guests
  (bnc#1012628).
- mm, swap, frontswap: fix THP swap if frontswap enabled
  (bnc#1012628).
- x86/oprofile: Fix bogus GCC-8 warning in nmi_setup()
  (bnc#1012628).
- x86/apic/vector: Handle vector release on CPU unplug correctly
  (bnc#1012628).
- Kbuild: always define endianess in kconfig.h (bnc#1012628).
- iio: adis_lib: Initialize trigger before requesting interrupt
  (bnc#1012628).
- iio: buffer: check if a buffer has been set up when poll is
  called (bnc#1012628).
- iio: srf08: fix link error "devm_iio_triggered_buffer_setup"
  undefined (bnc#1012628).
- iio: adc: stm32: fix stm32h7_adc_enable error handling
  (bnc#1012628).
- RDMA/uverbs: Sanitize user entered port numbers prior to access
  it (bnc#1012628).
- RDMA/uverbs: Fix circular locking dependency (bnc#1012628).
- RDMA/uverbs: Fix bad unlock balance in ib_uverbs_close_xrcd
  (bnc#1012628).
- RDMA/uverbs: Protect from command mask overflow (bnc#1012628).
- RDMA/uverbs: Protect from races between lookup and destroy of
  uobjects (bnc#1012628).
- genirq/matrix: Handle CPU offlining proper (bnc#1012628).
- extcon: int3496: process id-pin first so that we start with
  the right status (bnc#1012628).
- PKCS#7: fix certificate blacklisting (bnc#1012628).
- PKCS#7: fix certificate chain verification (bnc#1012628).
- X.509: fix NULL dereference when restricting key with
  unsupported_sig (bnc#1012628).
- X.509: fix BUG_ON() when hash algorithm is unsupported
  (bnc#1012628).
- i2c: bcm2835: Set up the rising/falling edge delays
  (bnc#1012628).
- i2c: designware: must wait for enable (bnc#1012628).
- cfg80211: fix cfg80211_beacon_dup (bnc#1012628).
- MIPS: Drop spurious __unused in struct compat_flock
  (bnc#1012628).
- scsi: ibmvfc: fix misdefined reserved field in
  ibmvfc_fcp_rsp_info (bnc#1012628).
- xtensa: fix high memory/reserved memory collision (bnc#1012628).
- MIPS: boot: Define __ASSEMBLY__ for its.S build (bnc#1012628).
- kconfig.h: Include compiler types to avoid missed struct
  attributes (bnc#1012628).
- arm64: mm: don't write garbage into TTBR1_EL1 register
  (bnc#1012628).
- netfilter: drop outermost socket lock in getsockopt()
  (bnc#1012628).
- commit 48cfb35
* Wed Feb 28 2018 jeffm@suse.com
- kernel: add product-identifying information to kernel build (FATE#325281).
- commit 450b8db
* Tue Feb 27 2018 msuchanek@suse.de
- Revert "rpm/kernel-binary.spec.in: Also require m4 for build."
  This reverts commit 0d7b4b3f948c2efb67b7d1b95b5e1dcae225991c.
- commit f5686d2
* Tue Feb 27 2018 tiwai@suse.de
- kernel-binary: do not package extract-cert when not signing modules
  (boo#1080250).
- commit 10a8bc4
* Tue Feb 27 2018 jeffm@suse.com
- Update to 4.16-rc3.
- Eliminated 2 patches.
- commit a1d0a5c
* Tue Feb 27 2018 jeffm@suse.com
- Update to 4.16-rc2.
- Eliminated 1 patch.
- Config changes:
  - i386:
  - X86_MINIMUM_CPU_FAMILY (set automatically by oldconfig).
- commit 70f217f
* Tue Feb 27 2018 jeffm@suse.com
- Update to 4.16-rc1.
- Eliminated 624 patches (mostly 4.15.x).
- ARM configs need updating.
- Config changes:
  - General:
  - CC_STACKPROTECTOR_REGULAR=y
  - x86:
  - ACPI_SPCR_TABLE=y
  - ACER_WIRELESS=m
  - GPD_POCKET_FAN=m
  - INTEL_CHTDC_TI_PWRBTN=m
  - MELLANOX_PLATFORM=y
  - MLXREG_HOTPLUG=m
  - JAILHOUSE_GUEST=y
  - i386:
  - MLX_PLATFORM=m
  - DEFERRED_STRUCT_PAGE_INIT=y
  - powerpc:
  - PPC_MEM_KEYS=y
  - OCXL=m
  - PPC_IRQ_SOFT_MASK_DEBUG=n
  - s390:
  - KERNEL_NOBP=y
  - EXPOLINE=y
  - EXPOLINE_FULL=y
  - PCI:
  - PCIE_CADENCE_HOST=y
  - PCIE_CADENCE_EP=y
  - Network:
  - NF_FLOW_TABLE=m
  - NF_FLOW_TABLE_IPV4=m
  - NF_FLOW_TABLE_IPV6=m
  - IP6_NF_MATCH_SRH=m
  - BT_HCIBTUSB_AUTOSUSPEND=y
  - NET_VENDOR_CORTINA=y
  - GEMINI_ETHERNET=m
  - NET_VENDOR_SOCIONEXT=y
  - NETDEVSIM=n
  - NFT_FLOW_OFFLOAD=m
  - NF_FLOW_TABLE_INET=m
  - Block:
  - BLK_DEV_NULL_BLK_FAULT_INJECTION=n
  - SATA_MOBILE_LPM_POLICY=0
  - DM_UNSTRIPED=m
  - MMC_SDHCI_F_SDH30=n
  - Misc:
  - MISC_RTSX_PCI=m
  - MISC_RTSX_USB=m
  - HW_RANDOM_TPM=y (from m)
  - I2C_GPIO_FAULT_INJECTOR=n
  - PINCTRL_AXP209=m
  - GPIO_WINBOND=m
  - GPIO_PCIE_IDIO_24=m
  - SENSORS_W83773G=m
  - MFD_CROS_EC_CHARDEV=n
  - RAVE_SP_CORE=n
  CAVIUM_PTP=m
  - Graphics:
  - DRM_PANEL_ILITEK_IL9322=n
  - TINYDRM_ILI9225=n
  - TINYDRM_ST7735R=n
  - Sound:
  - SND_SOC_INTEL_SST_TOPLEVEL=y
  - SND_SST_ATOM_HIFI2_PLATFORM_PCI=m
  - SND_SOC_INTEL_BYT_MAX98090_MACH=m
  - SND_SOC_INTEL_BYT_RT5640_MACH=m
  - SND_SOC_MAX98373=n
  - SND_SOC_PCM186X_I2C=n
  - SND_SOC_PCM186X_SPI=n
  - SND_SOC_TAS6424=n
  - SND_SOC_TLV320AIC32X4_I2C=n
  - SND_SOC_TLV320AIC32X4_SPI=n
  - SND_SOC_TSCS42XX=n
  - SOUNDWIRE=y
  - SOUNDWIRE_INTEL=m
  - Input:
  - HID_JABRA=n
  - USB:
  - USB_XHCI_DBGCAP=n
  - LEDS:
  - LEDS_LM3692X=n
  - LEDS_TRIGGER_NETDEV=m
  - LEDS_LP8860=n
  - RTC:
  - RTC_DRV_CROS_EC=n
  - VIRT:
  - VBOXGUEST=m
  - VIRTIO_MENU=y
  - KVM_AMD_SEV=y
  - Filesystems:
  - CIFS_SMB_DIRECT=n (still experimental)
  - Other:
  - UNISYSSPAR=n
  - XILINX_VCU=n
  - IIO_BUFFER_HW_CONSUMER=n
  - SD_ADC_MODULATOR=n
  - OF_FPGA_REGION=n
  - SIOX=n
  - SLIMBUS=n
  - BPF_KPROBE_OVERRIDE=n
  - FPGA_BRIDGE=n
  - Sensors:
  - ST_UVIS25=n
  - ZOPT2201=n
  - Media:
  - MT76x2E=m
  - LIRC=y
  - DVB_MMAP=n (still experimental)
  - DVB_ULE_DEBUG=n
  - Testing:
  - FAIL_FUNCTION=n
  - RUNTIME_TESTING_MENU=y
  - FIND_BIT_BENCHMARK=n
  - Crypto:
  - CHELSIO_IPSEC_INLINE=n
  - CRYPTO_DEV_SP_PSP=y
- commit 955d7ce
* Sun Feb 25 2018 jslaby@suse.cz
- bpf: cpumap: use GFP_KERNEL instead of GFP_ATOMIC in
  __cpu_map_entry_alloc() (git-fixes).
- commit b050949
* Sun Feb 25 2018 jslaby@suse.cz
- ptr_ring: prevent integer overflow when calculating size
  (git-fixes).
- commit f95a8d4
* Sun Feb 25 2018 jslaby@suse.cz
- Linux 4.15.6 (bnc#1012628).
- vmalloc: fix __GFP_HIGHMEM usage for vmalloc_32 on 32b systems
  (bnc#1012628).
- mei: me: add cannon point device ids for 4th device
  (bnc#1012628).
- mei: me: add cannon point device ids (bnc#1012628).
- crypto: s5p-sss - Fix kernel Oops in AES-ECB mode (bnc#1012628).
- usbip: keep usbip_device sockfd state in sync with tcp_socket
  (bnc#1012628).
- xhci: fix xhci debugfs errors in xhci_stop (bnc#1012628).
- xhci: xhci debugfs device nodes weren't removed after device
  plugged out (bnc#1012628).
- xhci: Fix xhci debugfs devices node disappearance after
  hibernation (bnc#1012628).
- xhci: Fix NULL pointer in xhci debugfs (bnc#1012628).
- staging: iio: ad5933: switch buffer mode to software
  (bnc#1012628).
- staging: iio: adc: ad7192: fix external frequency setting
  (bnc#1012628).
- staging: fsl-mc: fix build testing on x86 (bnc#1012628).
- binder: replace "%%p" with "%%pK" (bnc#1012628).
- binder: check for binder_thread allocation failure in
  binder_poll() (bnc#1012628).
- staging: android: ashmem: Fix a race condition in pin ioctls
  (bnc#1012628).
- ANDROID: binder: synchronize_rcu() when using POLLFREE
  (bnc#1012628).
- ANDROID: binder: remove WARN() for redundant txn error
  (bnc#1012628).
- dn_getsockoptdecnet: move nf_{get/set}sockopt outside sock lock
  (bnc#1012628).
- arm64: dts: add #cooling-cells to CPU nodes (bnc#1012628).
- ARM: 8743/1: bL_switcher: add MODULE_LICENSE tag (bnc#1012628).
- video: fbdev/mmp: add MODULE_LICENSE (bnc#1012628).
- ASoC: ux500: add MODULE_LICENSE tag (bnc#1012628).
- soc: qcom: rmtfs_mem: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- net_sched: gen_estimator: fix lockdep splat (bnc#1012628).
- net: avoid skb_warn_bad_offload on IS_ERR (bnc#1012628).
- rds: tcp: atomically purge entries from rds_tcp_conn_list
  during netns delete (bnc#1012628).
- rds: tcp: correctly sequence cleanup on netns deletion
  (bnc#1012628).
- netfilter: xt_RATEEST: acquire xt_rateest_mutex for hash insert
  (bnc#1012628).
- netfilter: xt_cgroup: initialize info->priv in
  cgroup_mt_check_v1() (bnc#1012628).
- netfilter: on sockopt() acquire sock lock only in the required
  scope (bnc#1012628).
- netfilter: ipt_CLUSTERIP: fix out-of-bounds accesses in
  clusterip_tg_check() (bnc#1012628).
- netfilter: x_tables: avoid out-of-bounds reads in
  xt_request_find_{match|target} (bnc#1012628).
- netfilter: x_tables: fix int overflow in xt_alloc_table_info()
  (bnc#1012628).
- kcov: detect double association with a single task
  (bnc#1012628).
- KVM: x86: fix escape of guest dr6 to the host (bnc#1012628).
- blk_rq_map_user_iov: fix error override (bnc#1012628).
- staging: android: ion: Switch from WARN to pr_warn
  (bnc#1012628).
- staging: android: ion: Add __GFP_NOWARN for system contig heap
  (bnc#1012628).
- crypto: x86/twofish-3way - Fix %%rbp usage (bnc#1012628).
- media: pvrusb2: properly check endpoint types (bnc#1012628).
- selinux: skip bounded transition processing if the policy
  isn't loaded (bnc#1012628).
- selinux: ensure the context is NUL terminated in
  security_context_to_sid_core() (bnc#1012628).
- ptr_ring: try vmalloc() when kmalloc() fails (bnc#1012628).
- ptr_ring: fail early if queue occupies more than
  KMALLOC_MAX_SIZE (bnc#1012628).
- tun: fix tun_napi_alloc_frags() frag allocator (bnc#1012628).
- commit 71fd692
* Thu Feb 22 2018 jslaby@suse.cz
- powerpc/pseries: Add empty update_numa_cpu_lookup_table()
  for NUMA=n (git-fixes).
- commit 4a82466
* Thu Feb 22 2018 jslaby@suse.cz
- Linux 4.15.5 (bnc#1012628).
- scsi: smartpqi: allow static build ("built-in") (bnc#1012628).
- IB/umad: Fix use of unprotected device pointer (bnc#1012628).
- IB/qib: Fix comparison error with qperf compare/swap test
  (bnc#1012628).
- IB/mlx4: Fix incorrectly releasing steerable UD QPs when have
  only ETH ports (bnc#1012628).
- IB/core: Fix two kernel warnings triggered by rxe registration
  (bnc#1012628).
- IB/core: Fix ib_wc structure size to remain in 64 bytes boundary
  (bnc#1012628).
- IB/core: Avoid a potential OOPs for an unused optional parameter
  (bnc#1012628).
- selftests: seccomp: fix compile error seccomp_bpf (bnc#1012628).
- kselftest: fix OOM in memory compaction test (bnc#1012628).
- RDMA/rxe: Fix a race condition related to the QP error state
  (bnc#1012628).
- RDMA/rxe: Fix a race condition in rxe_requester() (bnc#1012628).
- RDMA/rxe: Fix rxe_qp_cleanup() (bnc#1012628).
- cpufreq: powernv: Dont assume distinct pstate values for
  nominal and pmin (bnc#1012628).
- swiotlb: suppress warning when __GFP_NOWARN is set
  (bnc#1012628).
- PM / devfreq: Propagate error from devfreq_add_device()
  (bnc#1012628).
- mwifiex: resolve reset vs. remove()/shutdown() deadlocks
  (bnc#1012628).
- ocfs2: try a blocking lock before return AOP_TRUNCATED_PAGE
  (bnc#1012628).
- trace_uprobe: Display correct offset in uprobe_events
  (bnc#1012628).
- powerpc/radix: Remove trace_tlbie call from radix__flush_tlb_all
  (bnc#1012628).
- powerpc/kernel: Block interrupts when updating TIDR
  (bnc#1012628).
- powerpc/vas: Don't set uses_vas for kernel windows
  (bnc#1012628).
- powerpc/numa: Invalidate numa_cpu_lookup_table on cpu remove
  (bnc#1012628).
- powerpc/mm: Flush radix process translations when setting MMU
  type (bnc#1012628).
- powerpc/xive: Use hw CPU ids when configuring the CPU queues
  (bnc#1012628).
- dma-buf: fix reservation_object_wait_timeout_rcu once more v2
  (bnc#1012628).
- s390: fix handling of -1 in set{,fs}[gu]id16 syscalls
  (bnc#1012628).
- arm64: dts: msm8916: Correct ipc references for smsm
  (bnc#1012628).
- ARM: lpc3250: fix uda1380 gpio numbers (bnc#1012628).
- ARM: dts: STi: Add gpio polarity for "hdmi,hpd-gpio" property
  (bnc#1012628).
- ARM: dts: nomadik: add interrupt-parent for clcd (bnc#1012628).
- arm: dts: mt7623: fix card detection issue on bananapi-r2
  (bnc#1012628).
- arm: spear600: Add missing interrupt-parent of rtc
  (bnc#1012628).
- arm: spear13xx: Fix dmas cells (bnc#1012628).
- arm: spear13xx: Fix spics gpio controller's warning
  (bnc#1012628).
- x86/gpu: add CFL to early quirks (bnc#1012628).
- x86/kexec: Make kexec (mostly) work in 5-level paging mode
  (bnc#1012628).
- x86/xen: init %%gs very early to avoid page faults with stack
  protector (bnc#1012628).
- x86: PM: Make APM idle driver initialize polling state
  (bnc#1012628).
- mm, memory_hotplug: fix memmap initialization (bnc#1012628).
- x86/entry/64: Clear extra registers beyond syscall arguments,
  to reduce speculation attack surface (bnc#1012628).
- x86/entry/64/compat: Clear registers for compat syscalls,
  to reduce speculation attack surface (bnc#1012628).
- compiler-gcc.h: Introduce __optimize function attribute
  (bnc#1012628).
- compiler-gcc.h: __nostackprotector needs gcc-4.4 and up
  (bnc#1012628).
- crypto: sun4i_ss_prng - fix return value of
  sun4i_ss_prng_generate (bnc#1012628).
- crypto: sun4i_ss_prng - convert lock to _bh in
  sun4i_ss_prng_generate (bnc#1012628).
- powerpc/mm/radix: Split linear mapping on hot-unplug
  (bnc#1012628).
- x86/mm/pti: Fix PTI comment in entry_SYSCALL_64() (bnc#1012628).
- x86/speculation: Update Speculation Control microcode blacklist
  (bnc#1012628).
- x86/speculation: Correct Speculation Control microcode blacklist
  again (bnc#1012628).
- Revert "x86/speculation: Simplify
  indirect_branch_prediction_barrier()" (bnc#1012628).
- KVM/x86: Reduce retpoline performance impact in
  slot_handle_level_range(), by always inlining iterator helper
  methods (bnc#1012628).
- X86/nVMX: Properly set spec_ctrl and pred_cmd before merging
  MSRs (bnc#1012628).
- KVM/nVMX: Set the CPU_BASED_USE_MSR_BITMAPS if we have a valid
  L02 MSR bitmap (bnc#1012628).
- x86/speculation: Clean up various Spectre related details
  (bnc#1012628).
- PM / runtime: Update links_count also if !CONFIG_SRCU
  (bnc#1012628).
- PM: cpuidle: Fix cpuidle_poll_state_init() prototype
  (bnc#1012628).
- platform/x86: wmi: fix off-by-one write in wmi_dev_probe()
  (bnc#1012628).
- x86/entry/64: Clear registers for exceptions/interrupts,
  to reduce speculation attack surface (bnc#1012628).
- x86/entry/64: Merge SAVE_C_REGS and SAVE_EXTRA_REGS, remove
  unused extensions (bnc#1012628).
- x86/entry/64: Merge the POP_C_REGS and POP_EXTRA_REGS macros
  into a single POP_REGS macro (bnc#1012628).
- x86/entry/64: Interleave XOR register clearing with PUSH
  instructions (bnc#1012628).
- x86/entry/64: Introduce the PUSH_AND_CLEAN_REGS macro
  (bnc#1012628).
- x86/entry/64: Use PUSH_AND_CLEAN_REGS in more cases
  (bnc#1012628).
- x86/entry/64: Get rid of the ALLOC_PT_GPREGS_ON_STACK and
  SAVE_AND_CLEAR_REGS macros (bnc#1012628).
- x86/entry/64: Indent PUSH_AND_CLEAR_REGS and POP_REGS properly
  (bnc#1012628).
- x86/entry/64: Fix paranoid_entry() frame pointer warning
  (bnc#1012628).
- x86/entry/64: Remove the unused 'icebp' macro (bnc#1012628).
- selftests/x86: Fix vDSO selftest segfault for vsyscall=none
  (bnc#1012628).
- selftests/x86: Clean up and document sscanf() usage
  (bnc#1012628).
- selftests/x86/pkeys: Remove unused functions (bnc#1012628).
- selftests/x86: Fix build bug caused by the 5lvl test which
  has been moved to the VM directory (bnc#1012628).
- selftests/x86: Do not rely on "int $0x80" in test_mremap_vdso.c
  (bnc#1012628).
- gfs2: Fixes to "Implement iomap for block_map" (bnc#1012628).
- selftests/x86: Do not rely on "int $0x80" in
  single_step_syscall.c (bnc#1012628).
- selftests/x86: Disable tests requiring 32-bit support on pure
  64-bit systems (bnc#1012628).
- objtool: Fix segfault in ignore_unreachable_insn()
  (bnc#1012628).
- x86/debug, objtool: Annotate WARN()-related UD2 as reachable
  (bnc#1012628).
- x86/debug: Use UD2 for WARN() (bnc#1012628).
- x86/speculation: Fix up array_index_nospec_mask() asm constraint
  (bnc#1012628).
- nospec: Move array_index_nospec() parameter checking into
  separate macro (bnc#1012628).
- x86/speculation: Add <asm/msr-index.h> dependency (bnc#1012628).
- x86/mm: Rename flush_tlb_single() and flush_tlb_one() to
  __flush_tlb_one_[user|kernel]() (bnc#1012628).
- selftests/x86/mpx: Fix incorrect bounds with old _sigfault
  (bnc#1012628).
- x86/cpu: Rename cpu_data.x86_mask to cpu_data.x86_stepping
  (bnc#1012628).
- x86/spectre: Fix an error message (bnc#1012628).
- x86/cpu: Change type of x86_cache_size variable to unsigned int
  (bnc#1012628).
- x86/entry/64: Fix CR3 restore in paranoid_exit() (bnc#1012628).
- drm/ttm: Don't add swapped BOs to swap-LRU list (bnc#1012628).
- drm/ttm: Fix 'buf' pointer update in ttm_bo_vm_access_kmap()
  (v2) (bnc#1012628).
- drm/qxl: unref cursor bo when finished with it (bnc#1012628).
- drm/qxl: reapply cursor after resetting primary (bnc#1012628).
- drm/amd/powerplay: Fix smu_table_entry.handle type
  (bnc#1012628).
- drm/ast: Load lut in crtc_commit (bnc#1012628).
- drm: Check for lessee in DROP_MASTER ioctl (bnc#1012628).
- arm64: Add missing Falkor part number for branch predictor
  hardening (bnc#1012628).
- drm/radeon: Add dpm quirk for Jet PRO (v2) (bnc#1012628).
- drm/radeon: adjust tested variable (bnc#1012628).
- x86/smpboot: Fix uncore_pci_remove() indexing bug when
  hot-removing a physical CPU (bnc#1012628).
- rtc-opal: Fix handling of firmware error codes, prevent busy
  loops (bnc#1012628).
- mbcache: initialize entry->e_referenced in
  mb_cache_entry_create() (bnc#1012628).
- mmc: sdhci: Implement an SDHCI-specific bounce buffer
  (bnc#1012628).
- mmc: bcm2835: Don't overwrite max frequency unconditionally
  (bnc#1012628).
- Revert "mmc: meson-gx: include tx phase in the tuning process"
  (bnc#1012628).
- mlx5: fix mlx5_get_vector_affinity to start from completion
  vector 0 (bnc#1012628).
- Revert "apple-gmux: lock iGP IO to protect from vgaarb changes"
  (bnc#1012628).
- jbd2: fix sphinx kernel-doc build warnings (bnc#1012628).
- ext4: fix a race in the ext4 shutdown path (bnc#1012628).
- ext4: save error to disk in __ext4_grp_locked_error()
  (bnc#1012628).
- ext4: correct documentation for grpid mount option
  (bnc#1012628).
- mm: hide a #warning for COMPILE_TEST (bnc#1012628).
- mm: Fix memory size alignment in devm_memremap_pages_release()
  (bnc#1012628).
- MIPS: Fix typo BIG_ENDIAN to CPU_BIG_ENDIAN (bnc#1012628).
- MIPS: CPS: Fix MIPS_ISA_LEVEL_RAW fallout (bnc#1012628).
- MIPS: Fix incorrect mem=X@Y handling (bnc#1012628).
- PCI: Disable MSI for HiSilicon Hip06/Hip07 only in Root Port
  mode (bnc#1012628).
- PCI: iproc: Fix NULL pointer dereference for BCMA (bnc#1012628).
- PCI: pciehp: Assume NoCompl+ for Thunderbolt ports
  (bnc#1012628).
- PCI: keystone: Fix interrupt-controller-node lookup
  (bnc#1012628).
- video: fbdev: atmel_lcdfb: fix display-timings lookup
  (bnc#1012628).
- console/dummy: leave .con_font_get set to NULL (bnc#1012628).
- rbd: whitelist RBD_FEATURE_OPERATIONS feature bit (bnc#1012628).
- xen: Fix {set,clear}_foreign_p2m_mapping on autotranslating
  guests (bnc#1012628).
- xenbus: track caller request id (bnc#1012628).
- seq_file: fix incomplete reset on read from zero offset
  (bnc#1012628).
- tracing: Fix parsing of globs with a wildcard at the beginning
  (bnc#1012628).
- mpls, nospec: Sanitize array index in mpls_label_ok()
  (bnc#1012628).
- rtlwifi: rtl8821ae: Fix connection lost problem correctly
  (bnc#1012628).
- arm64: proc: Set PTE_NG for table entries to avoid traversing
  them twice (bnc#1012628).
- xprtrdma: Fix calculation of ri_max_send_sges (bnc#1012628).
- xprtrdma: Fix BUG after a device removal (bnc#1012628).
- blk-wbt: account flush requests correctly (bnc#1012628).
- target/iscsi: avoid NULL dereference in CHAP auth error path
  (bnc#1012628).
- iscsi-target: make sure to wake up sleeping login worker
  (bnc#1012628).
- dm: correctly handle chained bios in dec_pending()
  (bnc#1012628).
- Btrfs: fix deadlock in run_delalloc_nocow (bnc#1012628).
- Btrfs: fix crash due to not cleaning up tree log block's dirty
  bits (bnc#1012628).
- Btrfs: fix extent state leak from tree log (bnc#1012628).
- Btrfs: fix use-after-free on root->orphan_block_rsv
  (bnc#1012628).
- Btrfs: fix unexpected -EEXIST when creating new inode
  (bnc#1012628).
- 9p/trans_virtio: discard zero-length reply (bnc#1012628).
- mtd: nand: vf610: set correct ooblayout (bnc#1012628).
- ALSA: hda - Fix headset mic detection problem for two Dell
  machines (bnc#1012628).
- ALSA: usb-audio: Fix UAC2 get_ctl request with a RANGE attribute
  (bnc#1012628).
- ALSA: hda/realtek - Add headset mode support for Dell laptop
  (bnc#1012628).
- ALSA: hda/realtek - Enable Thinkpad Dock device for ALC298
  platform (bnc#1012628).
- ALSA: hda/realtek: PCI quirk for Fujitsu U7x7 (bnc#1012628).
- ALSA: usb-audio: add implicit fb quirk for Behringer UFX1204
  (bnc#1012628).
- ALSA: usb: add more device quirks for USB DSD devices
  (bnc#1012628).
- ALSA: seq: Fix racy pool initializations (bnc#1012628).
- mvpp2: fix multicast address filter (bnc#1012628).
- usb: Move USB_UHCI_BIG_ENDIAN_* out of USB_SUPPORT
  (bnc#1012628).
- x86/mm, mm/hwpoison: Don't unconditionally unmap kernel 1:1
  pages (bnc#1012628).
- ARM: dts: exynos: fix RTC interrupt for exynos5410
  (bnc#1012628).
- ARM: pxa/tosa-bt: add MODULE_LICENSE tag (bnc#1012628).
- arm64: dts: msm8916: Add missing #phy-cells (bnc#1012628).
- ARM: dts: s5pv210: add interrupt-parent for ohci (bnc#1012628).
- arm: dts: mt7623: Update ethsys binding (bnc#1012628).
- arm: dts: mt2701: Add reset-cells (bnc#1012628).
- ARM: dts: Delete bogus reference to the charlcd (bnc#1012628).
- media: r820t: fix r820t_write_reg for KASAN (bnc#1012628).
- mmc: sdhci-of-esdhc: fix eMMC couldn't work after kexec
  (bnc#1012628).
- mmc: sdhci-of-esdhc: fix the mmc error after sleep on ls1046ardb
  (bnc#1012628).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Refresh
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- Refresh
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- commit 078aac5
* Thu Feb 22 2018 lpechacek@suse.com
- rpm/kernel-spec-macros: Try harder to detect Build Service environment (bsc#1078788)
- commit a5f1a4a
* Wed Feb 21 2018 msuchanek@suse.de
- kernel-binary undefine unique_debug_names
  Some tools do not understand names like
  usr/lib/debug/boot/vmlinux-4.12.14-11.10-default-4.12.14-11.10.ppc64le.debug
- commit 2b90c1e
* Tue Feb 20 2018 jeffm@suse.com
- config: enable IMA and EVM
- commit 8c97198
* Sun Feb 18 2018 afaerber@suse.de
- config: arm64: Enable MAX77620 for Nvidia Jetson TX1 (boo#1081473)
- commit 5cbffaf
* Sat Feb 17 2018 jslaby@suse.cz
- Linux 4.15.4 (bnc#1012628).
- watchdog: indydog: Add dependency on SGI_HAS_INDYDOG
  (bnc#1012628).
- cifs: Fix missing put_xid in cifs_file_strict_mmap
  (bnc#1012628).
- cifs: Fix autonegotiate security settings mismatch
  (bnc#1012628).
- CIFS: zero sensitive data when freeing (bnc#1012628).
- cpufreq: mediatek: add mediatek related projects into blacklist
  (bnc#1012628).
- dmaengine: dmatest: fix container_of member in dmatest_callback
  (bnc#1012628).
- ssb: Do not disable PCI host on non-Mips (bnc#1012628).
- watchdog: gpio_wdt: set WDOG_HW_RUNNING in gpio_wdt_stop
  (bnc#1012628).
- Revert "drm/i915: mark all device info struct with __initconst"
  (bnc#1012628).
- sched/rt: Use container_of() to get root domain in
  rto_push_irq_work_func() (bnc#1012628).
- sched/rt: Up the root domain ref count when passing it around
  via IPIs (bnc#1012628).
- media: dvb-usb-v2: lmedm04: Improve logic checking of warm start
  (bnc#1012628).
- media: dvb-usb-v2: lmedm04: move ts2020 attach to
  dm04_lme2510_tuner (bnc#1012628).
- media: hdpvr: Fix an error handling path in hdpvr_probe()
  (bnc#1012628).
- arm64: cpu_errata: Add Kryo to Falkor 1003 errata (bnc#1012628).
- arm64: kpti: Make use of nG dependent on
  arm64_kernel_unmapped_at_el0() (bnc#1012628).
- arm64: mm: Permit transitioning from Global to Non-Global
  without BBM (bnc#1012628).
- arm64: kpti: Add ->enable callback to remap swapper using nG
  mappings (bnc#1012628).
- arm64: Force KPTI to be disabled on Cavium ThunderX
  (bnc#1012628).
- arm64: entry: Reword comment about post_ttbr_update_workaround
  (bnc#1012628).
- arm64: idmap: Use "awx" flags for .idmap.text .pushsection
  directives (bnc#1012628).
- arm64: barrier: Add CSDB macros to control data-value prediction
  (bnc#1012628).
- arm64: Implement array_index_mask_nospec() (bnc#1012628).
- arm64: Make USER_DS an inclusive limit (bnc#1012628).
- arm64: Use pointer masking to limit uaccess speculation
  (bnc#1012628).
- arm64: entry: Ensure branch through syscall table is bounded
  under speculation (bnc#1012628).
- arm64: uaccess: Prevent speculative use of the current
  addr_limit (bnc#1012628).
- arm64: uaccess: Don't bother eliding access_ok checks in __{get,
  put}_user (bnc#1012628).
- arm64: uaccess: Mask __user pointers for __arch_{clear,
  copy_*}_user (bnc#1012628).
- arm64: futex: Mask __user pointers prior to dereference
  (bnc#1012628).
- arm64: cpufeature: __this_cpu_has_cap() shouldn't stop early
  (bnc#1012628).
- arm64: entry: Apply BP hardening for high-priority synchronous
  exceptions (bnc#1012628).
- arm64: entry: Apply BP hardening for suspicious interrupts
  from EL0 (bnc#1012628).
- arm64: KVM: Increment PC after handling an SMC trap
  (bnc#1012628).
- arm/arm64: KVM: Consolidate the PSCI include files
  (bnc#1012628).
- arm/arm64: KVM: Add PSCI_VERSION helper (bnc#1012628).
- arm/arm64: KVM: Add smccc accessors to PSCI code (bnc#1012628).
- arm/arm64: KVM: Implement PSCI 1.0 support (bnc#1012628).
- arm/arm64: KVM: Advertise SMCCC v1.1 (bnc#1012628).
- arm/arm64: KVM: Turn kvm_psci_version into a static inline
  (bnc#1012628).
- arm64: KVM: Report SMCCC_ARCH_WORKAROUND_1 BP hardening support
  (bnc#1012628).
- arm64: KVM: Add SMCCC_ARCH_WORKAROUND_1 fast handling
  (bnc#1012628).
- firmware/psci: Expose PSCI conduit (bnc#1012628).
- firmware/psci: Expose SMCCC version through psci_ops
  (bnc#1012628).
- arm/arm64: smccc: Make function identifiers an unsigned quantity
  (bnc#1012628).
- arm/arm64: smccc: Implement SMCCC v1.1 inline primitive
  (bnc#1012628).
- arm64: Add ARM_SMCCC_ARCH_WORKAROUND_1 BP hardening support
  (bnc#1012628).
- arm64: Kill PSCI_GET_VERSION as a variant-2 workaround
  (bnc#1012628).
- mtd: cfi: convert inline functions to macros (bnc#1012628).
- mtd: nand: brcmnand: Disable prefetch by default (bnc#1012628).
- mtd: nand: Fix nand_do_read_oob() return value (bnc#1012628).
- mtd: nand: sunxi: Fix ECC strength choice (bnc#1012628).
- ubi: Fix race condition between ubi volume creation and udev
  (bnc#1012628).
- ubi: fastmap: Erase outdated anchor PEBs during attach
  (bnc#1012628).
- ubi: block: Fix locking for idr_alloc/idr_remove (bnc#1012628).
- ubifs: free the encrypted symlink target (bnc#1012628).
- nfs/pnfs: fix nfs_direct_req ref leak when i/o falls back to
  the mds (bnc#1012628).
- nfs41: do not return ENOMEM on LAYOUTUNAVAILABLE (bnc#1012628).
- NFS: Add a cond_resched() to nfs_commit_release_pages()
  (bnc#1012628).
- NFS: Fix nfsstat breakage due to LOOKUPP (bnc#1012628).
- NFS: commit direct writes even if they fail partially
  (bnc#1012628).
- NFS: reject request for id_legacy key without auxdata
  (bnc#1012628).
- NFS: Fix a race between mmap() and O_DIRECT (bnc#1012628).
- nfsd: Detect unhashed stids in nfsd4_verify_open_stid()
  (bnc#1012628).
- kernfs: fix regression in kernfs_fop_write caused by wrong type
  (bnc#1012628).
- ahci: Annotate PCI ids for mobile Intel chipsets as such
  (bnc#1012628).
- ahci: Add PCI ids for Intel Bay Trail, Cherry Trail and Apollo
  Lake AHCI (bnc#1012628).
- ahci: Add Intel Cannon Lake PCH-H PCI ID (bnc#1012628).
- crypto: hash - introduce crypto_hash_alg_has_setkey()
  (bnc#1012628).
- crypto: cryptd - pass through absence of ->setkey()
  (bnc#1012628).
- crypto: mcryptd - pass through absence of ->setkey()
  (bnc#1012628).
- crypto: poly1305 - remove ->setkey() method (bnc#1012628).
- crypto: hash - annotate algorithms taking optional key
  (bnc#1012628).
- crypto: hash - prevent using keyed hashes without setting key
  (bnc#1012628).
- media: v4l2-ioctl.c: use check_fmt for enum/g/s/try_fmt
  (bnc#1012628).
- media: v4l2-ioctl.c: don't copy back the result for -ENOTTY
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: add missing VIDIOC_PREPARE_BUF
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: fix the indentation (bnc#1012628).
- media: v4l2-compat-ioctl32.c: move 'helper' functions to
  __get/put_v4l2_format32 (bnc#1012628).
- media: v4l2-compat-ioctl32.c: avoid sizeof(type) (bnc#1012628).
- media: v4l2-compat-ioctl32.c: copy m.userptr in put_v4l2_plane32
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: fix ctrl_is_pointer (bnc#1012628).
- media: v4l2-compat-ioctl32.c: copy clip list in
  put_v4l2_window32 (bnc#1012628).
- media: v4l2-compat-ioctl32.c: drop pr_info for unknown buffer
  type (bnc#1012628).
- media: v4l2-compat-ioctl32.c: don't copy back the result for
  certain errors (bnc#1012628).
- media: v4l2-compat-ioctl32.c: refactor compat ioctl32 logic
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: make ctrl_is_pointer work for
  subdevs (bnc#1012628).
- crypto: caam - fix endless loop when DECO acquire fails
  (bnc#1012628).
- crypto: sha512-mb - initialize pending lengths correctly
  (bnc#1012628).
- crypto: talitos - fix Kernel Oops on hashing an empty file
  (bnc#1012628).
- arm: KVM: Fix SMCCC handling of unimplemented SMC/HVC calls
  (bnc#1012628).
- KVM: nVMX: Fix races when sending nested PI while dest
  enters/leaves L2 (bnc#1012628).
- KVM: nVMX: Fix bug of injecting L2 exception into L1
  (bnc#1012628).
- KVM: PPC: Book3S HV: Make sure we don't re-enter guest without
  XIVE loaded (bnc#1012628).
- KVM: PPC: Book3S HV: Drop locks before reading guest memory
  (bnc#1012628).
- KVM: arm/arm64: Handle CPU_PM_ENTER_FAILED (bnc#1012628).
- KVM: PPC: Book3S PR: Fix broken select due to misspelling
  (bnc#1012628).
- ASoC: acpi: fix machine driver selection based on quirk
  (bnc#1012628).
- ASoC: rockchip: i2s: fix playback after runtime resume
  (bnc#1012628).
- ASoC: skl: Fix kernel warning due to zero NHTL entry
  (bnc#1012628).
- ASoC: compress: Correct handling of copy callback (bnc#1012628).
- watchdog: imx2_wdt: restore previous timeout after
  suspend+resume (bnc#1012628).
- afs: Add missing afs_put_cell() (bnc#1012628).
- afs: Need to clear responded flag in addr cursor (bnc#1012628).
- afs: Fix missing cursor clearance (bnc#1012628).
- afs: Fix server list handling (bnc#1012628).
- btrfs: Handle btrfs_set_extent_delalloc failure in fixup worker
  (bnc#1012628).
- Btrfs: raid56: iterate raid56 internal bio with
  bio_for_each_segment_all (bnc#1012628).
- kasan: don't emit builtin calls when sanitization is off
  (bnc#1012628).
- kasan: rework Kconfig settings (bnc#1012628).
- media: dvb_frontend: be sure to init dvb_frontend_handle_ioctl()
  return code (bnc#1012628).
- media: dvb-frontends: fix i2c access helpers for KASAN
  (bnc#1012628).
- media: dt-bindings/media/cec-gpio.txt: mention the CEC/HPD
  max voltages (bnc#1012628).
- media: ts2020: avoid integer overflows on 32 bit machines
  (bnc#1012628).
- media: vivid: fix module load error when enabling fb and
  no_error_inj=1 (bnc#1012628).
- media: cxusb, dib0700: ignore XC2028_I2C_FLUSH (bnc#1012628).
- fs/proc/kcore.c: use probe_kernel_read() instead of memcpy()
  (bnc#1012628).
- kernel/async.c: revert "async: simplify lowest_in_progress()"
  (bnc#1012628).
- kernel/relay.c: revert "kernel/relay.c: fix potential memory
  leak" (bnc#1012628).
- pipe: actually allow root to exceed the pipe buffer limits
  (bnc#1012628).
- pipe: fix off-by-one error when checking buffer limits
  (bnc#1012628).
- HID: quirks: Fix keyboard + touchpad on Toshiba Click Mini
  not working (bnc#1012628).
- Bluetooth: btsdio: Do not bind to non-removable BCM43341
  (bnc#1012628).
- Revert "Bluetooth: btusb: fix QCA Rome suspend/resume"
  (bnc#1012628).
- Bluetooth: btusb: Restore QCA Rome suspend/resume fix with a
  "rewritten" version (bnc#1012628).
- ipmi: use dynamic memory for DMI driver override (bnc#1012628).
- signal/openrisc: Fix do_unaligned_access to send the proper
  signal (bnc#1012628).
- signal/sh: Ensure si_signo is initialized in do_divide_error
  (bnc#1012628).
- alpha: fix crash if pthread_create races with signal delivery
  (bnc#1012628).
- alpha: osf_sys.c: fix put_tv32 regression (bnc#1012628).
- alpha: Fix mixed up args in EXC macro in futex operations
  (bnc#1012628).
- alpha: fix reboot on Avanti platform (bnc#1012628).
- alpha: fix formating of stack content (bnc#1012628).
- xtensa: fix futex_atomic_cmpxchg_inatomic (bnc#1012628).
- EDAC, octeon: Fix an uninitialized variable warning
  (bnc#1012628).
- genirq: Make legacy autoprobing work again (bnc#1012628).
- pinctrl: intel: Initialize GPIO properly when used through
  irqchip (bnc#1012628).
- pinctrl: mcp23s08: fix irq setup order (bnc#1012628).
- pinctrl: sx150x: Unregister the pinctrl on release
  (bnc#1012628).
- pinctrl: sx150x: Register pinctrl before adding the gpiochip
  (bnc#1012628).
- pinctrl: sx150x: Add a static gpio/pinctrl pin range mapping
  (bnc#1012628).
- pktcdvd: Fix pkt_setup_dev() error path (bnc#1012628).
- pktcdvd: Fix a recently introduced NULL pointer dereference
  (bnc#1012628).
- blk-mq: quiesce queue before freeing queue (bnc#1012628).
- clocksource/drivers/stm32: Fix kernel panic with multiple timers
  (bnc#1012628).
- lib/ubsan.c: s/missaligned/misaligned/ (bnc#1012628).
- lib/ubsan: add type mismatch handler for new GCC/Clang
  (bnc#1012628).
- objtool: Fix switch-table detection (bnc#1012628).
- arm64: dts: marvell: add Ethernet aliases (bnc#1012628).
- drm/i915: Avoid PPS HW/SW state mismatch due to rounding
  (bnc#1012628).
- ACPI: sbshc: remove raw pointer from printk() message
  (bnc#1012628).
- acpi, nfit: fix register dimm error handling (bnc#1012628).
- ovl: force r/o mount when index dir creation fails
  (bnc#1012628).
- ovl: fix failure to fsync lower dir (bnc#1012628).
- ovl: take mnt_want_write() for work/index dir setup
  (bnc#1012628).
- ovl: take mnt_want_write() for removing impure xattr
  (bnc#1012628).
- ovl: hash directory inodes for fsnotify (bnc#1012628).
- mn10300/misalignment: Use SIGSEGV SEGV_MAPERR to report a
  failed user copy (bnc#1012628).
- devpts: fix error handling in devpts_mntget() (bnc#1012628).
- ftrace: Remove incorrect setting of glob search field
  (bnc#1012628).
- scsi: core: Ensure that the SCSI error handler gets woken up
  (bnc#1012628).
- scsi: lpfc: Fix crash after bad bar setup on driver attachment
  (bnc#1012628).
- scsi: cxlflash: Reset command ioasc (bnc#1012628).
- rcu: Export init_rcu_head() and destroy_rcu_head() to GPL
  modules (bnc#1012628).
- media: dvb_frontend: fix return error code (git-fixes).
- mtd: ubi: wl: Fix error return code in ubi_wl_init()
  (git-fixes).
- Update config files.
- Linux 4.15.4 (bnc#1012628).
- watchdog: indydog: Add dependency on SGI_HAS_INDYDOG
  (bnc#1012628).
- cifs: Fix missing put_xid in cifs_file_strict_mmap
  (bnc#1012628).
- cifs: Fix autonegotiate security settings mismatch
  (bnc#1012628).
- CIFS: zero sensitive data when freeing (bnc#1012628).
- cpufreq: mediatek: add mediatek related projects into blacklist
  (bnc#1012628).
- dmaengine: dmatest: fix container_of member in dmatest_callback
  (bnc#1012628).
- ssb: Do not disable PCI host on non-Mips (bnc#1012628).
- watchdog: gpio_wdt: set WDOG_HW_RUNNING in gpio_wdt_stop
  (bnc#1012628).
- Revert "drm/i915: mark all device info struct with __initconst"
  (bnc#1012628).
- sched/rt: Use container_of() to get root domain in
  rto_push_irq_work_func() (bnc#1012628).
- sched/rt: Up the root domain ref count when passing it around
  via IPIs (bnc#1012628).
- media: dvb-usb-v2: lmedm04: Improve logic checking of warm start
  (bnc#1012628).
- media: dvb-usb-v2: lmedm04: move ts2020 attach to
  dm04_lme2510_tuner (bnc#1012628).
- media: hdpvr: Fix an error handling path in hdpvr_probe()
  (bnc#1012628).
- arm64: cpu_errata: Add Kryo to Falkor 1003 errata (bnc#1012628).
- arm64: kpti: Make use of nG dependent on
  arm64_kernel_unmapped_at_el0() (bnc#1012628).
- arm64: mm: Permit transitioning from Global to Non-Global
  without BBM (bnc#1012628).
- arm64: kpti: Add ->enable callback to remap swapper using nG
  mappings (bnc#1012628).
- arm64: Force KPTI to be disabled on Cavium ThunderX
  (bnc#1012628).
- arm64: entry: Reword comment about post_ttbr_update_workaround
  (bnc#1012628).
- arm64: idmap: Use "awx" flags for .idmap.text .pushsection
  directives (bnc#1012628).
- arm64: barrier: Add CSDB macros to control data-value prediction
  (bnc#1012628).
- arm64: Implement array_index_mask_nospec() (bnc#1012628).
- arm64: Make USER_DS an inclusive limit (bnc#1012628).
- arm64: Use pointer masking to limit uaccess speculation
  (bnc#1012628).
- arm64: entry: Ensure branch through syscall table is bounded
  under speculation (bnc#1012628).
- arm64: uaccess: Prevent speculative use of the current
  addr_limit (bnc#1012628).
- arm64: uaccess: Don't bother eliding access_ok checks in __{get,
  put}_user (bnc#1012628).
- arm64: uaccess: Mask __user pointers for __arch_{clear,
  copy_*}_user (bnc#1012628).
- arm64: futex: Mask __user pointers prior to dereference
  (bnc#1012628).
- arm64: cpufeature: __this_cpu_has_cap() shouldn't stop early
  (bnc#1012628).
- arm64: entry: Apply BP hardening for high-priority synchronous
  exceptions (bnc#1012628).
- arm64: entry: Apply BP hardening for suspicious interrupts
  from EL0 (bnc#1012628).
- arm64: KVM: Increment PC after handling an SMC trap
  (bnc#1012628).
- arm/arm64: KVM: Consolidate the PSCI include files
  (bnc#1012628).
- arm/arm64: KVM: Add PSCI_VERSION helper (bnc#1012628).
- arm/arm64: KVM: Add smccc accessors to PSCI code (bnc#1012628).
- arm/arm64: KVM: Implement PSCI 1.0 support (bnc#1012628).
- arm/arm64: KVM: Advertise SMCCC v1.1 (bnc#1012628).
- arm/arm64: KVM: Turn kvm_psci_version into a static inline
  (bnc#1012628).
- arm64: KVM: Report SMCCC_ARCH_WORKAROUND_1 BP hardening support
  (bnc#1012628).
- arm64: KVM: Add SMCCC_ARCH_WORKAROUND_1 fast handling
  (bnc#1012628).
- firmware/psci: Expose PSCI conduit (bnc#1012628).
- firmware/psci: Expose SMCCC version through psci_ops
  (bnc#1012628).
- arm/arm64: smccc: Make function identifiers an unsigned quantity
  (bnc#1012628).
- arm/arm64: smccc: Implement SMCCC v1.1 inline primitive
  (bnc#1012628).
- arm64: Add ARM_SMCCC_ARCH_WORKAROUND_1 BP hardening support
  (bnc#1012628).
- arm64: Kill PSCI_GET_VERSION as a variant-2 workaround
  (bnc#1012628).
- mtd: cfi: convert inline functions to macros (bnc#1012628).
- mtd: nand: brcmnand: Disable prefetch by default (bnc#1012628).
- mtd: nand: Fix nand_do_read_oob() return value (bnc#1012628).
- mtd: nand: sunxi: Fix ECC strength choice (bnc#1012628).
- ubi: Fix race condition between ubi volume creation and udev
  (bnc#1012628).
- ubi: fastmap: Erase outdated anchor PEBs during attach
  (bnc#1012628).
- ubi: block: Fix locking for idr_alloc/idr_remove (bnc#1012628).
- ubifs: free the encrypted symlink target (bnc#1012628).
- nfs/pnfs: fix nfs_direct_req ref leak when i/o falls back to
  the mds (bnc#1012628).
- nfs41: do not return ENOMEM on LAYOUTUNAVAILABLE (bnc#1012628).
- NFS: Add a cond_resched() to nfs_commit_release_pages()
  (bnc#1012628).
- NFS: Fix nfsstat breakage due to LOOKUPP (bnc#1012628).
- NFS: commit direct writes even if they fail partially
  (bnc#1012628).
- NFS: reject request for id_legacy key without auxdata
  (bnc#1012628).
- NFS: Fix a race between mmap() and O_DIRECT (bnc#1012628).
- nfsd: Detect unhashed stids in nfsd4_verify_open_stid()
  (bnc#1012628).
- kernfs: fix regression in kernfs_fop_write caused by wrong type
  (bnc#1012628).
- ahci: Annotate PCI ids for mobile Intel chipsets as such
  (bnc#1012628).
- ahci: Add PCI ids for Intel Bay Trail, Cherry Trail and Apollo
  Lake AHCI (bnc#1012628).
- ahci: Add Intel Cannon Lake PCH-H PCI ID (bnc#1012628).
- crypto: hash - introduce crypto_hash_alg_has_setkey()
  (bnc#1012628).
- crypto: cryptd - pass through absence of ->setkey()
  (bnc#1012628).
- crypto: mcryptd - pass through absence of ->setkey()
  (bnc#1012628).
- crypto: poly1305 - remove ->setkey() method (bnc#1012628).
- crypto: hash - annotate algorithms taking optional key
  (bnc#1012628).
- crypto: hash - prevent using keyed hashes without setting key
  (bnc#1012628).
- media: v4l2-ioctl.c: use check_fmt for enum/g/s/try_fmt
  (bnc#1012628).
- media: v4l2-ioctl.c: don't copy back the result for -ENOTTY
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: add missing VIDIOC_PREPARE_BUF
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: fix the indentation (bnc#1012628).
- media: v4l2-compat-ioctl32.c: move 'helper' functions to
  __get/put_v4l2_format32 (bnc#1012628).
- media: v4l2-compat-ioctl32.c: avoid sizeof(type) (bnc#1012628).
- media: v4l2-compat-ioctl32.c: copy m.userptr in put_v4l2_plane32
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: fix ctrl_is_pointer (bnc#1012628).
- media: v4l2-compat-ioctl32.c: copy clip list in
  put_v4l2_window32 (bnc#1012628).
- media: v4l2-compat-ioctl32.c: drop pr_info for unknown buffer
  type (bnc#1012628).
- media: v4l2-compat-ioctl32.c: don't copy back the result for
  certain errors (bnc#1012628).
- media: v4l2-compat-ioctl32.c: refactor compat ioctl32 logic
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: make ctrl_is_pointer work for
  subdevs (bnc#1012628).
- crypto: caam - fix endless loop when DECO acquire fails
  (bnc#1012628).
- crypto: sha512-mb - initialize pending lengths correctly
  (bnc#1012628).
- crypto: talitos - fix Kernel Oops on hashing an empty file
  (bnc#1012628).
- arm: KVM: Fix SMCCC handling of unimplemented SMC/HVC calls
  (bnc#1012628).
- KVM: nVMX: Fix races when sending nested PI while dest
  enters/leaves L2 (bnc#1012628).
- KVM: nVMX: Fix bug of injecting L2 exception into L1
  (bnc#1012628).
- KVM: PPC: Book3S HV: Make sure we don't re-enter guest without
  XIVE loaded (bnc#1012628).
- KVM: PPC: Book3S HV: Drop locks before reading guest memory
  (bnc#1012628).
- KVM: arm/arm64: Handle CPU_PM_ENTER_FAILED (bnc#1012628).
- KVM: PPC: Book3S PR: Fix broken select due to misspelling
  (bnc#1012628).
- ASoC: acpi: fix machine driver selection based on quirk
  (bnc#1012628).
- ASoC: rockchip: i2s: fix playback after runtime resume
  (bnc#1012628).
- ASoC: skl: Fix kernel warning due to zero NHTL entry
  (bnc#1012628).
- ASoC: compress: Correct handling of copy callback (bnc#1012628).
- watchdog: imx2_wdt: restore previous timeout after
  suspend+resume (bnc#1012628).
- afs: Add missing afs_put_cell() (bnc#1012628).
- afs: Need to clear responded flag in addr cursor (bnc#1012628).
- afs: Fix missing cursor clearance (bnc#1012628).
- afs: Fix server list handling (bnc#1012628).
- btrfs: Handle btrfs_set_extent_delalloc failure in fixup worker
  (bnc#1012628).
- Btrfs: raid56: iterate raid56 internal bio with
  bio_for_each_segment_all (bnc#1012628).
- kasan: don't emit builtin calls when sanitization is off
  (bnc#1012628).
- kasan: rework Kconfig settings (bnc#1012628).
- media: dvb_frontend: be sure to init dvb_frontend_handle_ioctl()
  return code (bnc#1012628).
- media: dvb-frontends: fix i2c access helpers for KASAN
  (bnc#1012628).
- media: dt-bindings/media/cec-gpio.txt: mention the CEC/HPD
  max voltages (bnc#1012628).
- media: ts2020: avoid integer overflows on 32 bit machines
  (bnc#1012628).
- media: vivid: fix module load error when enabling fb and
  no_error_inj=1 (bnc#1012628).
- media: cxusb, dib0700: ignore XC2028_I2C_FLUSH (bnc#1012628).
- fs/proc/kcore.c: use probe_kernel_read() instead of memcpy()
  (bnc#1012628).
- kernel/async.c: revert "async: simplify lowest_in_progress()"
  (bnc#1012628).
- kernel/relay.c: revert "kernel/relay.c: fix potential memory
  leak" (bnc#1012628).
- pipe: actually allow root to exceed the pipe buffer limits
  (bnc#1012628).
- pipe: fix off-by-one error when checking buffer limits
  (bnc#1012628).
- HID: quirks: Fix keyboard + touchpad on Toshiba Click Mini
  not working (bnc#1012628).
- Bluetooth: btsdio: Do not bind to non-removable BCM43341
  (bnc#1012628).
- Revert "Bluetooth: btusb: fix QCA Rome suspend/resume"
  (bnc#1012628).
- Bluetooth: btusb: Restore QCA Rome suspend/resume fix with a
  "rewritten" version (bnc#1012628).
- ipmi: use dynamic memory for DMI driver override (bnc#1012628).
- signal/openrisc: Fix do_unaligned_access to send the proper
  signal (bnc#1012628).
- signal/sh: Ensure si_signo is initialized in do_divide_error
  (bnc#1012628).
- alpha: fix crash if pthread_create races with signal delivery
  (bnc#1012628).
- alpha: osf_sys.c: fix put_tv32 regression (bnc#1012628).
- alpha: Fix mixed up args in EXC macro in futex operations
  (bnc#1012628).
- alpha: fix reboot on Avanti platform (bnc#1012628).
- alpha: fix formating of stack content (bnc#1012628).
- xtensa: fix futex_atomic_cmpxchg_inatomic (bnc#1012628).
- EDAC, octeon: Fix an uninitialized variable warning
  (bnc#1012628).
- genirq: Make legacy autoprobing work again (bnc#1012628).
- pinctrl: intel: Initialize GPIO properly when used through
  irqchip (bnc#1012628).
- pinctrl: mcp23s08: fix irq setup order (bnc#1012628).
- pinctrl: sx150x: Unregister the pinctrl on release
  (bnc#1012628).
- pinctrl: sx150x: Register pinctrl before adding the gpiochip
  (bnc#1012628).
- pinctrl: sx150x: Add a static gpio/pinctrl pin range mapping
  (bnc#1012628).
- pktcdvd: Fix pkt_setup_dev() error path (bnc#1012628).
- pktcdvd: Fix a recently introduced NULL pointer dereference
  (bnc#1012628).
- blk-mq: quiesce queue before freeing queue (bnc#1012628).
- clocksource/drivers/stm32: Fix kernel panic with multiple timers
  (bnc#1012628).
- lib/ubsan.c: s/missaligned/misaligned/ (bnc#1012628).
- lib/ubsan: add type mismatch handler for new GCC/Clang
  (bnc#1012628).
- objtool: Fix switch-table detection (bnc#1012628).
- arm64: dts: marvell: add Ethernet aliases (bnc#1012628).
- drm/i915: Avoid PPS HW/SW state mismatch due to rounding
  (bnc#1012628).
- ACPI: sbshc: remove raw pointer from printk() message
  (bnc#1012628).
- acpi, nfit: fix register dimm error handling (bnc#1012628).
- ovl: force r/o mount when index dir creation fails
  (bnc#1012628).
- ovl: fix failure to fsync lower dir (bnc#1012628).
- ovl: take mnt_want_write() for work/index dir setup
  (bnc#1012628).
- ovl: take mnt_want_write() for removing impure xattr
  (bnc#1012628).
- ovl: hash directory inodes for fsnotify (bnc#1012628).
- mn10300/misalignment: Use SIGSEGV SEGV_MAPERR to report a
  failed user copy (bnc#1012628).
- devpts: fix error handling in devpts_mntget() (bnc#1012628).
- ftrace: Remove incorrect setting of glob search field
  (bnc#1012628).
- scsi: core: Ensure that the SCSI error handler gets woken up
  (bnc#1012628).
- scsi: lpfc: Fix crash after bad bar setup on driver attachment
  (bnc#1012628).
- scsi: cxlflash: Reset command ioasc (bnc#1012628).
- rcu: Export init_rcu_head() and destroy_rcu_head() to GPL
  modules (bnc#1012628).
- Update config files.
- commit 4d42c34
* Thu Feb 15 2018 jmoreira@suse.de
- Add kernel livepatch-devel package
  Resolving non-exported static symbols in kernel livepatches cannot
  be done implicitly. For such, the relocations of these symbols must
  follow a specially crafted format in the respective elf file. Willing
  to make the task of converting the elf into the right format, a tool
  named klp-convert was proposed. Through a file that maps all kernel
  symbols into their respective kernel object, this tool infers which
  non-exported symbol is relative to a livepatch relocation and
  automatically formats the final elf file.
  Add support to the generation of a map file right after the kernel
  compilation.
  Add the package kernel-<flavour>-livepatch-devel that brings
  the map file.
- commit 0b1b4d3
* Tue Feb 13 2018 jslaby@suse.cz
- Linux 4.15.3 (bnc#1012628).
- crypto: tcrypt - fix S/G table for test_aead_speed()
  (bnc#1012628).
- gpio: uniphier: fix mismatch between license text and
  MODULE_LICENSE (bnc#1012628).
- media: tegra-cec: add missing MODULE_DESCRIPTION/AUTHOR/LICENSE
  (bnc#1012628).
- media: soc_camera: soc_scale_crop: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- media: mtk-vcodec: add missing MODULE_LICENSE/DESCRIPTION
  (bnc#1012628).
- net: sched: fix use-after-free in tcf_block_put_ext
  (bnc#1012628).
- net_sched: get rid of rcu_barrier() in tcf_block_put_ext()
  (bnc#1012628).
- soreuseport: fix mem leak in reuseport_add_sock() (bnc#1012628).
- ipv6: Fix SO_REUSEPORT UDP socket with implicit sk_ipv6only
  (bnc#1012628).
- cls_u32: add missing RCU annotation (bnc#1012628).
- tcp_bbr: fix pacing_gain to always be unity when using lt_bw
  (bnc#1012628).
- rocker: fix possible null pointer dereference in
  rocker_router_fib_event_work (bnc#1012628).
- net: ipv6: send unsolicited NA after DAD (bnc#1012628).
- Revert "defer call to mem_cgroup_sk_alloc()" (bnc#1012628).
- ipv6: change route cache aging logic (bnc#1012628).
- ipv6: addrconf: break critical section in addrconf_verify_rtnl()
  (bnc#1012628).
- vhost_net: stop device during reset owner (bnc#1012628).
- tcp: release sk_frag.page in tcp_disconnect (bnc#1012628).
- r8169: fix RTL8168EP take too long to complete driver
  initialization (bnc#1012628).
- qmi_wwan: Add support for Quectel EP06 (bnc#1012628).
- qlcnic: fix deadlock bug (bnc#1012628).
- net: igmp: add a missing rcu locking section (bnc#1012628).
- ip6mr: fix stale iterator (bnc#1012628).
- commit e7bb737
* Tue Feb 13 2018 jslaby@suse.cz
- ext4: llseek, do not crop offset on 32bit (bsc#1079747).
- commit c6ab9c6
* Sun Feb 11 2018 afaerber@suse.de
- config: arm64: Enable Hi6421 PMU (bsc#1080449)
- commit 77a784c
* Fri Feb  9 2018 jslaby@suse.cz
- Update i386 config files.
  Switch from almost unusable UNWINDER_GUESS to UNWINDER_FRAME_POINTER
  (which enables FRAME_POINTERs). It will slow down the kernel a bit,
  but improves the stack traces by the order of magnitude. Sad is that
  we have no ORCs on i386...
- commit 1d39996
* Fri Feb  9 2018 jslaby@suse.cz
- Update config files.
  Sync vanilla configs to 4.15.
- commit 85c7881
* Thu Feb  8 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Also require m4 for build.
- commit 0d7b4b3
* Thu Feb  8 2018 jslaby@suse.cz
- Linux 4.15.2 (bnc#1012628).
- KVM: x86: Make indirect calls in emulator speculation safe
  (bnc#1012628).
- KVM: VMX: Make indirect call speculation safe (bnc#1012628).
- x86/alternative: Print unadorned pointers (bnc#1012628).
- auxdisplay: img-ascii-lcd: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- iio: adc/accel: Fix up module licenses (bnc#1012628).
- pinctrl: pxa: pxa2xx: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- ASoC: pcm512x: add missing MODULE_DESCRIPTION/AUTHOR/LICENSE
  (bnc#1012628).
- KVM: nVMX: Eliminate vmcs02 pool (bnc#1012628).
- KVM: VMX: introduce alloc_loaded_vmcs (bnc#1012628).
- objtool: Improve retpoline alternative handling (bnc#1012628).
- objtool: Add support for alternatives at the end of a section
  (bnc#1012628).
- objtool: Warn on stripped section symbol (bnc#1012628).
- x86/mm: Fix overlap of i386 CPU_ENTRY_AREA with FIX_BTMAP
  (bnc#1012628).
- x86/entry/64: Remove the SYSCALL64 fast path (bnc#1012628).
- x86/entry/64: Push extra regs right away (bnc#1012628).
- x86/asm: Move 'status' from thread_struct to thread_info
  (bnc#1012628).
- x86/spectre: Fix spelling mistake: "vunerable"-> "vulnerable"
  (bnc#1012628).
- x86/paravirt: Remove 'noreplace-paravirt' cmdline option
  (bnc#1012628).
- KVM: VMX: make MSR bitmaps per-VCPU (bnc#1012628).
- x86/kvm: Update spectre-v1 mitigation (bnc#1012628).
- x86/retpoline: Avoid retpolines for built-in __init functions
  (bnc#1012628).
- x86/speculation: Fix typo IBRS_ATT, which should be IBRS_ALL
  (bnc#1012628).
- KVM/x86: Update the reverse_cpuid list to include CPUID_7_EDX
  (bnc#1012628).
- KVM/x86: Add IBPB support (bnc#1012628).
- KVM/VMX: Emulate MSR_IA32_ARCH_CAPABILITIES (bnc#1012628).
- KVM/VMX: Allow direct access to MSR_IA32_SPEC_CTRL
  (bnc#1012628).
- KVM/SVM: Allow direct access to MSR_IA32_SPEC_CTRL
  (bnc#1012628).
- serial: core: mark port as initialized after successful IRQ
  change (bnc#1012628).
- fpga: region: release of_parse_phandle nodes after use
  (bnc#1012628).
- commit 54903ae
* Wed Feb  7 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: install ksym-provides tool (bsc#1077692).
- commit 679f5c5
* Wed Feb  7 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: require bison for build.
  linux-next tends to have outdated generated files so it needs bison to
  regenerate them.
- commit 4ad1ede
* Wed Feb  7 2018 msuchanek@suse.de
- Add ksym-provides tool (bsc#1077692).
- commit 9cd1e1e
* Mon Feb  5 2018 jslaby@suse.cz
- x86/pti: Mark constant arrays as __initconst (bsc#1068032
  CVE-2017-5753).
- x86/cpuid: Fix up "virtual" IBRS/IBPB/STIBP feature bits on
  Intel (bsc#1068032 CVE-2017-5753).
- commit 7d4f257
* Mon Feb  5 2018 jslaby@suse.cz
- x86/speculation: Add basic IBRS support infrastructure
  (bsc#1068032 CVE-2017-5753).
- x86/pti: Do not enable PTI on CPUs which are not vulnerable
  to Meltdown (bsc#1068032 CVE-2017-5753).
- x86/cpufeature: Blacklist SPEC_CTRL/PRED_CMD on early Spectre
  v2 microcodes (bsc#1068032 CVE-2017-5753).
- x86/nospec: Fix header guards names (bsc#1068032 CVE-2017-5753).
- x86/bugs: Drop one "mitigation" from dmesg (bsc#1068032
  CVE-2017-5753).
- x86/cpu/bugs: Make retpoline module warning conditional
  (bsc#1068032 CVE-2017-5753).
- x86/cpufeatures: Clean up Spectre v2 related CPUID flags
  (bsc#1068032 CVE-2017-5753).
- x86/retpoline: Simplify vmexit_fill_RSB() (bsc#1068032
  CVE-2017-5753).
- x86/speculation: Simplify indirect_branch_prediction_barrier()
  (bsc#1068032 CVE-2017-5753).
- module/retpoline: Warn about missing retpoline in module
  (bsc#1068032 CVE-2017-5753).
- x86/spectre: Check CONFIG_RETPOLINE in command line parser
  (bsc#1068032 CVE-2017-5753).
- x86/speculation: Use Indirect Branch Prediction Barrier in
  context switch (bsc#1068032 CVE-2017-5753).
- Refresh
  patches.suse/0001-x86-cpufeatures-Add-CPUID_7_EDX-CPUID-leaf.patch.
- Refresh
  patches.suse/0002-x86-cpufeatures-Add-Intel-feature-bits-for-Speculati.patch.
- Refresh
  patches.suse/0003-x86-cpufeatures-Add-AMD-feature-bits-for-Speculation.patch.
- Refresh
  patches.suse/0004-x86-msr-Add-definitions-for-new-speculation-control-.patch.
- Refresh
  patches.suse/0007-x86-speculation-Add-basic-IBPB-Indirect-Branch-Predi.patch.
- Refresh patches.suse/supported-flag.
- Delete
  patches.suse/0005-x86-pti-Do-not-enable-PTI-on-processors-which-are-no.patch.
- Delete
  patches.suse/0006-x86-cpufeature-Blacklist-SPEC_CTRL-on-early-Spectre-.patch.
- Delete patches.suse/0008-x86-kvm-Add-IBPB-support.patch.
- Delete
  patches.suse/0009-x86-speculation-Use-Indirect-Branch-Prediction-Barri.patch.
- Delete
  patches.suse/0010-x86-mm-Only-flush-indirect-branches-when-switching-i.patch.
- Delete
  patches.suse/0011-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Delete
  patches.suse/0017-x86-ibrs-Add-new-helper-macros-to-save-restore-MSR_I-fix.patch.
- Delete
  patches.suse/0017-x86-ibrs-Add-new-helper-macros-to-save-restore-MSR_I.patch.
- Delete
  patches.suse/0018-x86-vmx-Direct-access-to-MSR_IA32_SPEC_CTRL.patch.
  Update to the patches from 4.16-rc1 and the updated IBRS patches from
  the dwmw's repo.
- commit cd20d46
* Mon Feb  5 2018 jslaby@suse.cz
- Documentation: Document array_index_nospec (bsc#1068032
  CVE-2017-5715).
- array_index_nospec: Sanitize speculative array de-references
  (bsc#1068032 CVE-2017-5715).
- x86: Implement array_index_mask_nospec (bsc#1068032
  CVE-2017-5715).
- x86: Introduce barrier_nospec (bsc#1068032 CVE-2017-5715).
- x86: Introduce __uaccess_begin_nospec() and uaccess_try_nospec
  (bsc#1068032 CVE-2017-5715).
- x86/usercopy: Replace open coded stac/clac with
  __uaccess_{begin, end} (bsc#1068032 CVE-2017-5715).
- x86/syscall: Sanitize syscall table de-references under
  speculation (bsc#1068032 CVE-2017-5715).
- nl80211: Sanitize array index in parse_txq_params (bsc#1068032
  CVE-2017-5715).
- x86/spectre: Report get_user mitigation for spectre_v1
  (bsc#1068032 CVE-2017-5715).
- Delete patches.suse/0001-Documentation-document-array_ptr.patch.
- Delete
  patches.suse/0002-asm-nospec-array_ptr-sanitize-speculative-array-de-r.patch.
- Delete patches.suse/0003-x86-implement-array_ptr_mask.patch.
- Delete
  patches.suse/0004-x86-introduce-__uaccess_begin_nospec-and-ifence.patch.
- Delete
  patches.suse/0007-x86-narrow-out-of-bounds-syscalls-to-sys_read-under-.patch.
- Delete
  patches.suse/0009-kvm-x86-update-spectre-v1-mitigation.patch.
- Delete
  patches.suse/0010-nl80211-sanitize-array-index-in-parse_txq_params.patch.
  Replace by the patches from 4.16-rc1.
- commit 8343cab
* Mon Feb  5 2018 jslaby@suse.cz
- scsi: aacraid: remove redundant setting of variable c
  (git-fixes).
- commit 143e25c
* Sun Feb  4 2018 jslaby@suse.cz
- Linux 4.15.1 (bnc#1012628).
- x86/efi: Clarify that reset attack mitigation needs appropriate
  userspace (bnc#1012628).
- Input: synaptics-rmi4 - do not delete interrupt memory too early
  (bnc#1012628).
- Input: synaptics-rmi4 - unmask F03 interrupts when port is
  opened (bnc#1012628).
- test_firmware: fix missing unlock on error in
  config_num_requests_store() (bnc#1012628).
- iio: chemical: ccs811: Fix output of IIO_CONCENTRATION channels
  (bnc#1012628).
- iio: adc: stm32: fix scan of multiple channels with DMA
  (bnc#1012628).
- spi: imx: do not access registers while clocks disabled
  (bnc#1012628).
- serial: imx: Only wakeup via RTSDEN bit if the system has
  RTS/CTS (bnc#1012628).
- serial: 8250_dw: Revert "Improve clock rate setting"
  (bnc#1012628).
- serial: 8250_uniphier: fix error return code in
  uniphier_uart_probe() (bnc#1012628).
- serial: 8250_of: fix return code when probe function fails to
  get reset (bnc#1012628).
- mei: me: allow runtime pm for platform with D0i3 (bnc#1012628).
- android: binder: use VM_ALLOC to get vm area (bnc#1012628).
- ANDROID: binder: remove waitqueue when thread exits
  (bnc#1012628).
- usb/gadget: Fix "high bandwidth" check in
  usb_gadget_ep_match_desc() (bnc#1012628).
- usb: uas: unconditionally bring back host after reset
  (bnc#1012628).
- usb: f_fs: Prevent gadget unbind if it is already unbound
  (bnc#1012628).
- USB: serial: simple: add Motorola Tetra driver (bnc#1012628).
- usbip: list: don't list devices attached to vhci_hcd
  (bnc#1012628).
- usbip: prevent bind loops on devices attached to vhci_hcd
  (bnc#1012628).
- USB: serial: io_edgeport: fix possible sleep-in-atomic
  (bnc#1012628).
- CDC-ACM: apply quirk for card reader (bnc#1012628).
- USB: cdc-acm: Do not log urb submission errors on disconnect
  (bnc#1012628).
- USB: serial: pl2303: new device id for Chilitag (bnc#1012628).
- usb: option: Add support for FS040U modem (bnc#1012628).
- tty: fix data race between tty_init_dev and flush of buf
  (bnc#1012628).
- staging: ccree: fix fips event irq handling build (bnc#1012628).
- staging: ccree: NULLify backup_info when unused (bnc#1012628).
- staging: lustre: separate a connection destroy from free struct
  kib_conn (bnc#1012628).
- scsi: storvsc: missing error code in storvsc_probe()
  (bnc#1012628).
- scsi: aacraid: Fix hang in kdump (bnc#1012628).
- scsi: aacraid: Fix udev inquiry race condition (bnc#1012628).
- ima/policy: fix parsing of fsuuid (bnc#1012628).
- igb: Free IRQs when device is hotplugged (bnc#1012628).
- mtd: nand: denali_pci: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- gpio: ath79: add missing MODULE_DESCRIPTION/LICENSE
  (bnc#1012628).
- gpio: iop: add missing MODULE_DESCRIPTION/AUTHOR/LICENSE
  (bnc#1012628).
- power: reset: zx-reboot: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- HID: wacom: Fix reporting of touch toggle
  (WACOM_HID_WD_MUTE_DEVICE) events (bnc#1012628).
- HID: wacom: EKR: ensure devres groups at higher indexes are
  released (bnc#1012628).
- crypto: af_alg - whitelist mask and type (bnc#1012628).
- crypto: sha3-generic - fixes for alignment and big endian
  operation (bnc#1012628).
- crypto: inside-secure - avoid unmapping DMA memory that was
  not mapped (bnc#1012628).
- crypto: inside-secure - fix hash when length is a multiple of
  a block (bnc#1012628).
- crypto: aesni - Fix out-of-bounds access of the AAD buffer in
  generic-gcm-aesni (bnc#1012628).
- crypto: aesni - Fix out-of-bounds access of the data buffer
  in generic-gcm-aesni (bnc#1012628).
- crypto: aesni - add wrapper for generic gcm(aes) (bnc#1012628).
- crypto: aesni - fix typo in generic_gcmaes_decrypt
  (bnc#1012628).
- crypto: aesni - handle zero length dst buffer (bnc#1012628).
- crypto: ecdh - fix typo in KPP dependency of CRYPTO_ECDH
  (bnc#1012628).
- ALSA: hda - Reduce the suspend time consumption for ALC256
  (bnc#1012628).
- gpio: Fix kernel stack leak to userspace (bnc#1012628).
- gpio: stmpe: i2c transfer are forbiden in atomic context
  (bnc#1012628).
- tools/gpio: Fix build error with musl libc (bnc#1012628).
- Bluetooth: hci_serdev: Init hci_uart proto_lock to avoid oops
  (bnc#1012628).
- Linux 4.15.1 (bnc#1012628).
- x86/efi: Clarify that reset attack mitigation needs appropriate
  userspace (bnc#1012628).
- Input: synaptics-rmi4 - do not delete interrupt memory too early
  (bnc#1012628).
- Input: synaptics-rmi4 - unmask F03 interrupts when port is
  opened (bnc#1012628).
- test_firmware: fix missing unlock on error in
  config_num_requests_store() (bnc#1012628).
- iio: chemical: ccs811: Fix output of IIO_CONCENTRATION channels
  (bnc#1012628).
- iio: adc: stm32: fix scan of multiple channels with DMA
  (bnc#1012628).
- spi: imx: do not access registers while clocks disabled
  (bnc#1012628).
- serial: imx: Only wakeup via RTSDEN bit if the system has
  RTS/CTS (bnc#1012628).
- serial: 8250_dw: Revert "Improve clock rate setting"
  (bnc#1012628).
- serial: 8250_uniphier: fix error return code in
  uniphier_uart_probe() (bnc#1012628).
- serial: 8250_of: fix return code when probe function fails to
  get reset (bnc#1012628).
- mei: me: allow runtime pm for platform with D0i3 (bnc#1012628).
- android: binder: use VM_ALLOC to get vm area (bnc#1012628).
- ANDROID: binder: remove waitqueue when thread exits
  (bnc#1012628).
- usb/gadget: Fix "high bandwidth" check in
  usb_gadget_ep_match_desc() (bnc#1012628).
- usb: uas: unconditionally bring back host after reset
  (bnc#1012628).
- usb: f_fs: Prevent gadget unbind if it is already unbound
  (bnc#1012628).
- USB: serial: simple: add Motorola Tetra driver (bnc#1012628).
- usbip: list: don't list devices attached to vhci_hcd
  (bnc#1012628).
- usbip: prevent bind loops on devices attached to vhci_hcd
  (bnc#1012628).
- USB: serial: io_edgeport: fix possible sleep-in-atomic
  (bnc#1012628).
- CDC-ACM: apply quirk for card reader (bnc#1012628).
- USB: cdc-acm: Do not log urb submission errors on disconnect
  (bnc#1012628).
- USB: serial: pl2303: new device id for Chilitag (bnc#1012628).
- usb: option: Add support for FS040U modem (bnc#1012628).
- tty: fix data race between tty_init_dev and flush of buf
  (bnc#1012628).
- staging: ccree: fix fips event irq handling build (bnc#1012628).
- staging: ccree: NULLify backup_info when unused (bnc#1012628).
- staging: lustre: separate a connection destroy from free struct
  kib_conn (bnc#1012628).
- scsi: storvsc: missing error code in storvsc_probe()
  (bnc#1012628).
- scsi: aacraid: Fix hang in kdump (bnc#1012628).
- scsi: aacraid: Fix udev inquiry race condition (bnc#1012628).
- ima/policy: fix parsing of fsuuid (bnc#1012628).
- igb: Free IRQs when device is hotplugged (bnc#1012628).
- mtd: nand: denali_pci: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- gpio: ath79: add missing MODULE_DESCRIPTION/LICENSE
  (bnc#1012628).
- gpio: iop: add missing MODULE_DESCRIPTION/AUTHOR/LICENSE
  (bnc#1012628).
- power: reset: zx-reboot: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- HID: wacom: Fix reporting of touch toggle
  (WACOM_HID_WD_MUTE_DEVICE) events (bnc#1012628).
- HID: wacom: EKR: ensure devres groups at higher indexes are
  released (bnc#1012628).
- crypto: af_alg - whitelist mask and type (bnc#1012628).
- crypto: sha3-generic - fixes for alignment and big endian
  operation (bnc#1012628).
- crypto: inside-secure - avoid unmapping DMA memory that was
  not mapped (bnc#1012628).
- crypto: inside-secure - fix hash when length is a multiple of
  a block (bnc#1012628).
- crypto: aesni - Fix out-of-bounds access of the AAD buffer in
  generic-gcm-aesni (bnc#1012628).
- crypto: aesni - Fix out-of-bounds access of the data buffer
  in generic-gcm-aesni (bnc#1012628).
- crypto: aesni - add wrapper for generic gcm(aes) (bnc#1012628).
- crypto: aesni - fix typo in generic_gcmaes_decrypt
  (bnc#1012628).
- crypto: aesni - handle zero length dst buffer (bnc#1012628).
- crypto: ecdh - fix typo in KPP dependency of CRYPTO_ECDH
  (bnc#1012628).
- ALSA: hda - Reduce the suspend time consumption for ALC256
  (bnc#1012628).
- gpio: Fix kernel stack leak to userspace (bnc#1012628).
- gpio: stmpe: i2c transfer are forbiden in atomic context
  (bnc#1012628).
- tools/gpio: Fix build error with musl libc (bnc#1012628).
- Bluetooth: hci_serdev: Init hci_uart proto_lock to avoid oops
  (bnc#1012628).
- commit 671bf29
* Thu Feb  1 2018 matwey.kornilov@gmail.com
- config: arm64: Enable RockChip 8xx
  We need RockChip RK-808 support to run openSUSE on Rock64 board (RK3328).
  Currently, even voltage regulator is missed.
- commit a348749
* Wed Jan 31 2018 jslaby@suse.cz
- Update to 4.15-final.
- Eliminated 5 patches.
- Config changes:
  - Security:
  - GENERIC_CPU_VULNERABILITIES=y
- commit 978c9b0
* Tue Jan 30 2018 mkubecek@suse.cz
- Update
  patches.kernel.org/4.14.14-036-RDS-Heap-OOB-write-in-rds_message_alloc_sgs.patch
  upstream references (add CVE-2018-5332 bsc#1075621).
- commit 510de01
* Tue Jan 30 2018 mkubecek@suse.cz
- Update
  patches.kernel.org/4.14.14-037-RDS-null-pointer-dereference-in-rds_atomic_fr.patch
  upstream references (add CVE-2018-5333 bsc#1075617).
- commit e6cf845
* Mon Jan 29 2018 jeffm@suse.com
- Update to 4.15-final.
- Eliminated 5 patches.
- commit 36830f7
* Mon Jan 29 2018 jeffm@suse.com
- btrfs: fix btrfs_evict_inode to handle abnormal inodes correctly (bsc#1078019).
- commit d3f1d2c
* Mon Jan 29 2018 jslaby@suse.cz
- Revert "module: Add retpoline tag to VERMAGIC" (fix loading
  of KMPs).
- commit 9a6fca5
* Fri Jan 26 2018 yousaf.kaukab@suse.com
- config: arm64: enable UNMAP_KERNEL_AT_EL0 and HARDEN_BRANCH_PREDICTOR
- commit c41900c
* Fri Jan 26 2018 yousaf.kaukab@suse.com
- arm64: Turn on KPTI only on CPUs that need it (bsc#1068032).
- arm64: Branch predictor hardening for Cavium ThunderX2
  (bsc#1068032).
- arm64: Run enable method for errata work arounds on late CPUs
  (bsc#1068032).
- arm64: Move BP hardening to check_and_switch_context
  (bsc#1068032).
- arm: KVM: Invalidate icache on guest exit for Cortex-A15
  (bsc#1068032).
- arm: Invalidate icache on prefetch abort outside of user
  mapping on Cortex-A15 (bsc#1068032).
- arm: Add icache invalidation on switch_mm for Cortex-A15
  (bsc#1068032).
- arm: KVM: Invalidate BTB on guest exit (bsc#1068032).
- arm: Invalidate BTB on prefetch abort outside of user mapping
  on Cortex A8, A9, A12 and A17 (bsc#1068032).
- arm: Add BTB invalidation on switch_mm for Cortex-A9, A12 and
  A17 (bsc#1068032).
- arm64: cputype: Add MIDR values for Cavium ThunderX2 CPUs
  (bsc#1068032).
- arm64: Implement branch predictor hardening for Falkor
  (bsc#1068032).
- arm64: Implement branch predictor hardening for affected
  Cortex-A CPUs (bsc#1068032).
- arm64: cputype: Add missing MIDR values for Cortex-A72 and
  Cortex-A75 (bsc#1068032).
- arm64: KVM: Make PSCI_VERSION a fast path (bsc#1068032).
- arm64: KVM: Use per-CPU vector when BP hardening is enabled
  (bsc#1068032).
- arm64: Add skeleton to harden the branch predictor against
  aliasing attacks (bsc#1068032).
- arm64: Move post_ttbr_update_workaround to C code (bsc#1068032).
- drivers/firmware: Expose psci_get_version through psci_ops
  structure (bsc#1068032).
- arm64: Take into account ID_AA64PFR0_EL1.CSV3 (bsc#1068032).
- arm64: Kconfig: Reword UNMAP_KERNEL_AT_EL0 kconfig entry
  (bsc#1068032).
- arm64: use RET instruction for exiting the trampoline
  (bsc#1068032).
- arm64: capabilities: Handle duplicate entries for a capability
  (bsc#1068032).
- arm64: cpufeature: Pass capability structure to ->enable
  callback (bsc#1068032).
- arm64: kpti: Fix the interaction between ASID switching and
  software PAN (bsc#1068032).
- arm64: kaslr: Put kernel vectors address in separate data page
  (bsc#1068032).
- arm64: mm: Introduce TTBR_ASID_MASK for getting at the ASID
  in the TTBR (bsc#1068032).
- perf: arm_spe: Fail device probe when
  arm64_kernel_unmapped_at_el0() (bsc#1068032).
- arm64: Kconfig: Add CONFIG_UNMAP_KERNEL_AT_EL0 (bsc#1068032).
- arm64: entry: Add fake CPU feature for unmapping the kernel
  at EL0 (bsc#1068032).
- arm64: tls: Avoid unconditional zeroing of tpidrro_el0 for
  native tasks (bsc#1068032).
- arm64: erratum: Work around Falkor erratum #E1003 in trampoline
  code (bsc#1068032).
- arm64: entry: Hook up entry trampoline to exception vectors
  (bsc#1068032).
- arm64: entry: Explicitly pass exception level to kernel_ventry
  macro (bsc#1068032).
- arm64: mm: Map entry trampoline into trampoline and kernel
  page tables (bsc#1068032).
- arm64: entry: Add exception trampoline page for exceptions
  from EL0 (bsc#1068032).
- arm64: mm: Invalidate both kernel and user ASIDs when performing
  TLBI (bsc#1068032).
- arm64: mm: Add arm64_kernel_unmapped_at_el0 helper
  (bsc#1068032).
- arm64: mm: Allocate ASIDs in pairs (bsc#1068032).
- arm64: mm: Fix and re-enable ARM64_SW_TTBR0_PAN (bsc#1068032).
- arm64: mm: Rename post_ttbr0_update_workaround (bsc#1068032).
- arm64: mm: Remove pre_ttbr0_update_workaround for Falkor
  erratum #E1003 (bsc#1068032).
- arm64: mm: Move ASID from TTBR0 to TTBR1 (bsc#1068032).
- arm64: mm: Temporarily disable ARM64_SW_TTBR0_PAN (bsc#1068032).
- arm64: mm: Use non-global mappings for kernel space
  (bsc#1068032).
- commit cdf2ded
* Fri Jan 26 2018 yousaf.kaukab@suse.com
- config: arm64: enable rk3399 missing drivers
  These drivers are required for Rockchip RK3399 Sapphire board
- commit 94b8551
* Fri Jan 26 2018 jslaby@suse.cz
- Refresh
  patches.suse/netfilter-nfnetlink_cthelper-Add-missing-permission-.patch.
- Refresh
  patches.suse/netfilter-xt_osf-Add-missing-permission-checks.patch.
- Refresh patches.suse/scsi-libfc-fix-ELS-request-handling.patch.
  Update upstream status.
- commit 12e5c10
* Fri Jan 26 2018 jslaby@suse.cz
- x86/ibrs: Add new helper macros to save/restore
  MSR_IA32_SPEC_CTRL fix (bsc#1068032 CVE-2017-5753).
- commit 13295d4
* Thu Jan 25 2018 jslaby@suse.cz
- Delete patches.suse/orc-fix-retpolines-segfaults.patch.
  No longer needed.
- commit 9e84548
* Thu Jan 25 2018 jslaby@suse.cz
- x86/cpufeatures: Add Intel feature bits for Speculation Control
  (bsc#1068032 CVE-2017-5715).
- x86/cpufeatures: Add AMD feature bits for Speculation Control
  (bsc#1068032 CVE-2017-5715).
- x86/pti: Do not enable PTI on processors which are not
  vulnerable to Meltdown (bsc#1068032 CVE-2017-5715).
- x86/cpufeature: Blacklist SPEC_CTRL on early Spectre v2
  microcodes (bsc#1068032 CVE-2017-5715).
- x86/speculation: Add basic IBPB (Indirect Branch Prediction
  Barrier) support (bsc#1068032 CVE-2017-5715).
- x86/kvm: Add IBPB support (bsc#1068032 CVE-2017-5715).
- x86/speculation: Use Indirect Branch Prediction Barrier in
  context switch (bsc#1068032 CVE-2017-5715).
- x86/mm: Only flush indirect branches when switching into non
  dumpable process (bsc#1068032 CVE-2017-5715).
- x86/speculation: Add basic IBRS support infrastructure
  (bsc#1068032 CVE-2017-5715).
- x86/speculation: Add inlines to control Indirect Branch
  Speculation (bsc#1068032 CVE-2017-5715).
- x86: Simplify spectre_v2 command line parsing (bsc#1068032
  CVE-2017-5715).
- x86/idle: Control Indirect Branch Speculation in idle
  (bsc#1068032 CVE-2017-5715).
- x86/enter: Create macros to restrict/unrestrict Indirect Branch
  Speculation (bsc#1068032 CVE-2017-5715).
- x86/enter: Use IBRS on syscall and interrupts (bsc#1068032
  CVE-2017-5715).
- x86/ibrs: Add new helper macros to save/restore
  MSR_IA32_SPEC_CTRL (bsc#1068032 CVE-2017-5715).
- x86/vmx: Direct access to MSR_IA32_SPEC_CTRL (bsc#1068032
  CVE-2017-5715).
- Delete
  patches.suse/0002-x86-cpufeatures-Add-AMD-feature-bits-for-Prediction-.patch.
- Delete
  patches.suse/0004-x86-feature-Report-presence-of-IBPB-and-IBRS-control.patch.
- Delete
  patches.suse/0005-x86-enter-MACROS-to-set-clear-IBRS-and-set-IBPB.patch.
- Delete
  patches.suse/0006-x86-Add-macro-that-does-not-save-rax-rcx-rdx-on-stac.patch.
- Delete
  patches.suse/0007-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- Delete
  patches.suse/0008-x86-spec_ctrl-save-IBRS-MSR-value-in-paranoid_entry.patch.
- Delete
  patches.suse/0009-x86-idle-Disable-IBRS-entering-idle-and-enable-it-on.patch.
- Delete
  patches.suse/0010-x86-idle-Disable-IBRS-when-offlining-cpu-and-re-enab.patch.
- Delete
  patches.suse/0011-x86-mm-Set-IBPB-upon-context-switch.patch.
- Delete
  patches.suse/0012-x86-mm-Only-set-IBPB-when-the-new-thread-cannot-ptra.patch.
- Delete
  patches.suse/0013-x86-entry-Stuff-RSB-for-entry-to-kernel-for-non-SMEP.patch.
- Delete
  patches.suse/0014-x86-syscall-Clear-unused-extra-registers-on-syscall-.patch.
- Delete
  patches.suse/0015-x86-syscall-Clear-unused-extra-registers-on-32-bit-c.patch.
- Delete
  patches.suse/0016-x86-kvm-add-MSR_IA32_SPEC_CTRL-and-MSR_IA32_PRED_CMD.patch.
- Delete
  patches.suse/0017-x86-kvm-Set-IBPB-when-switching-VM.patch.
- Delete
  patches.suse/0018-x86-kvm-Toggle-IBRS-on-VM-entry-and-exit.patch.
- Delete
  patches.suse/0021-x86-spec_ctrl-Add-sysctl-knobs-to-enable-disable-SPE.patch.
- Delete
  patches.suse/0022-x86-spec_ctrl-Add-lock-to-serialize-changes-to-ibrs-.patch.
- Delete
  patches.suse/0023-x86-Move-IBRS-IBPB-feature-detection-to-scattered.c.patch.
- Delete
  patches.suse/0024-x86-microcode-Recheck-IBRS-and-IBPB-feature-on-micro.patch.
- Delete
  patches.suse/0025-x86-cpu-AMD-Add-speculative-control-support-for-AMD.patch.
- Delete
  patches.suse/0028-x86-svm-Set-IBPB-when-running-a-different-VCPU.patch.
- Delete
  patches.suse/0029-kvm-svm-add-MSR_IA32_SPEC_CTRL-and-MSR_IA32_PRED_CMD.patch.
- Delete patches.suse/0030-Use-the-ibrs_inuse-variable.patch.
- Delete
  patches.suse/0031-Reverting-the-commit-e5247c4f209530-to-replace.patch.
- Delete
  patches.suse/0032-kvm-vmx-add-MSR_IA32_SPEC_CTRL-and-MSR_IA32_PRED_CMD.patch.
- Delete
  patches.suse/0033-KVM-x86-add-SPEC_CTRL-to-MSR-and-CPUID-lists.patch.
- Delete
  patches.suse/0034-Remove-the-code-that-uses-MSR-save-restore-list.patch.
- Delete patches.suse/0035-Use-the-ibpb_inuse-variable.patch.
- Delete
  patches.suse/0037-Set-IBPB-when-running-a-different-VCPU.patch.
  Update spectre_v1 to the upstream patches.
- commit 67b0a37
* Thu Jan 25 2018 jslaby@suse.cz
- Revert "futex: Prevent overflow by strengthen input validation"
  (4.14.15-fix).
- commit 5b3d0ce
* Thu Jan 25 2018 jslaby@suse.cz
- x86/cpufeature: Move processor tracing out of scattered features
  (bsc#1068032 CVE-2017-5753).
- Refresh
  patches.suse/0001-x86-cpufeatures-Add-CPUID_7_EDX-CPUID-leaf.patch.
- Refresh
  patches.suse/0007-x86-speculation-Add-basic-IBPB-Indirect-Branch-Predi.patch.
- commit 8d8b718
* Wed Jan 24 2018 jslaby@suse.cz
- x86/retpoline: Add LFENCE to the retpoline/RSB filling RSB
  macros (bsc#1068032 CVE-2017-5753).
- commit 8dc7c71
* Wed Jan 24 2018 jslaby@suse.cz
- x86/vmx: Direct access to MSR_IA32_SPEC_CTRL (bsc#1068032
  CVE-2017-5753).
- x86/ibrs: Add new helper macros to save/restore
  MSR_IA32_SPEC_CTRL (bsc#1068032 CVE-2017-5753).
- x86/enter: Use IBRS on syscall and interrupts (bsc#1068032
  CVE-2017-5753).
- x86/enter: Create macros to restrict/unrestrict Indirect Branch
  Speculation (bsc#1068032 CVE-2017-5753).
- x86/idle: Control Indirect Branch Speculation in idle
  (bsc#1068032 CVE-2017-5753).
- x86: Simplify spectre_v2 command line parsing (bsc#1068032
  CVE-2017-5753).
- x86/speculation: Add inlines to control Indirect Branch
  Speculation (bsc#1068032 CVE-2017-5753).
- x86/speculation: Add basic IBRS support infrastructure
  (bsc#1068032 CVE-2017-5753).
- x86/mm: Only flush indirect branches when switching into non
  dumpable process (bsc#1068032 CVE-2017-5753).
- x86/speculation: Use Indirect Branch Prediction Barrier in
  context switch (bsc#1068032 CVE-2017-5753).
- x86/kvm: Add IBPB support (bsc#1068032 CVE-2017-5753).
- x86/speculation: Add basic IBPB (Indirect Branch Prediction
  Barrier) support (bsc#1068032 CVE-2017-5753).
- x86/cpufeature: Blacklist SPEC_CTRL on early Spectre v2
  microcodes (bsc#1068032 CVE-2017-5753).
- x86/pti: Do not enable PTI on processors which are not
  vulnerable to Meltdown (bsc#1068032 CVE-2017-5753).
- x86/msr: Add definitions for new speculation control MSRs
  (bsc#1068032 CVE-2017-5753).
- x86/cpufeatures: Add AMD feature bits for Speculation Control
  (bsc#1068032 CVE-2017-5753).
- x86/cpufeatures: Add Intel feature bits for Speculation Control
  (bsc#1068032 CVE-2017-5753).
- x86/cpufeatures: Add CPUID_7_EDX CPUID leaf (bsc#1068032
  CVE-2017-5753).
- x86/retpoline: Optimize inline assembler for vmexit_fill_RSB
  (bsc#1068032 CVE-2017-5753).
- x86/retpoline: Fill RSB on context switch for affected CPUs
  (bsc#1068032 CVE-2017-5753).
- commit e36ab4f
* Wed Jan 24 2018 jslaby@suse.cz
- Documentation: document array_ptr (bsc#1068032 CVE-2017-5715).
- asm/nospec, array_ptr: sanitize speculative array de-references
  (bsc#1068032 CVE-2017-5715).
- x86: implement array_ptr_mask() (bsc#1068032 CVE-2017-5715).
- x86: introduce __uaccess_begin_nospec and ifence (bsc#1068032
  CVE-2017-5715).
- x86, __get_user: use __uaccess_begin_nospec (bsc#1068032
  CVE-2017-5715).
- x86, get_user: use pointer masking to limit speculation
  (bsc#1068032 CVE-2017-5715).
- x86: narrow out of bounds syscalls to sys_read under speculation
  (bsc#1068032 CVE-2017-5715).
- vfs, fdtable: prevent bounds-check bypass via speculative
  execution (bsc#1068032 CVE-2017-5715).
- kvm, x86: update spectre-v1 mitigation (bsc#1068032
  CVE-2017-5715).
- nl80211: sanitize array index in parse_txq_params (bsc#1068032
  CVE-2017-5715).
- Delete
  patches.suse/0003-locking-barriers-introduce-new-observable-speculatio.patch.
- Delete
  patches.suse/0004-bpf-prevent-speculative-execution-in-eBPF-interprete.patch.
- Delete
  patches.suse/0005-x86-bpf-jit-prevent-speculative-execution-when-JIT-i.patch.
- Delete
  patches.suse/0006-uvcvideo-prevent-speculative-execution.patch.
- Delete
  patches.suse/0007-carl9170-prevent-speculative-execution.patch.
- Delete
  patches.suse/0008-p54-prevent-speculative-execution.patch.
- Delete
  patches.suse/0009-qla2xxx-prevent-speculative-execution.patch.
- Delete
  patches.suse/0010-cw1200-prevent-speculative-execution.patch.
- Delete
  patches.suse/0011-Thermal-int340x-prevent-speculative-execution.patch.
- Delete
  patches.suse/0012-ipv4-prevent-speculative-execution.patch.
- Delete
  patches.suse/0013-ipv6-prevent-speculative-execution.patch.
- Delete patches.suse/0014-fs-prevent-speculative-execution.patch.
- Delete
  patches.suse/0015-net-mpls-prevent-speculative-execution.patch.
- Delete
  patches.suse/0016-udf-prevent-speculative-execution.patch.
- Delete
  patches.suse/0017-userns-prevent-speculative-execution.patch.
  Replace by the potential upstream solution.
- commit 804f8a1
* Wed Jan 24 2018 jslaby@suse.cz
- Documentation: document array_ptr (bsc#1068032 CVE-2017-5715).
- asm/nospec, array_ptr: sanitize speculative array de-references
  (bsc#1068032 CVE-2017-5715).
- x86: implement array_ptr_mask() (bsc#1068032 CVE-2017-5715).
- x86: introduce __uaccess_begin_nospec and ifence (bsc#1068032
  CVE-2017-5715).
- x86, __get_user: use __uaccess_begin_nospec (bsc#1068032
  CVE-2017-5715).
- x86, get_user: use pointer masking to limit speculation
  (bsc#1068032 CVE-2017-5715).
- x86: narrow out of bounds syscalls to sys_read under speculation
  (bsc#1068032 CVE-2017-5715).
- vfs, fdtable: prevent bounds-check bypass via speculative
  execution (bsc#1068032 CVE-2017-5715).
- kvm, x86: update spectre-v1 mitigation (bsc#1068032
  CVE-2017-5715).
- nl80211: sanitize array index in parse_txq_params (bsc#1068032
  CVE-2017-5715).
- Delete
  patches.suse/0003-locking-barriers-introduce-new-observable-speculatio.patch.
- Delete
  patches.suse/0005-x86-bpf-jit-prevent-speculative-execution-when-JIT-i.patch.
- Delete
  patches.suse/0006-uvcvideo-prevent-speculative-execution.patch.
- Delete
  patches.suse/0007-carl9170-prevent-speculative-execution.patch.
- Delete
  patches.suse/0008-p54-prevent-speculative-execution.patch.
- Delete
  patches.suse/0009-qla2xxx-prevent-speculative-execution.patch.
- Delete
  patches.suse/0010-cw1200-prevent-speculative-execution.patch.
- Delete
  patches.suse/0011-Thermal-int340x-prevent-speculative-execution.patch.
- Delete
  patches.suse/0012-ipv4-prevent-speculative-execution.patch.
- Delete
  patches.suse/0013-ipv6-prevent-speculative-execution.patch.
- Delete patches.suse/0014-fs-prevent-speculative-execution.patch.
- Delete
  patches.suse/0015-net-mpls-prevent-speculative-execution.patch.
- Delete
  patches.suse/0016-udf-prevent-speculative-execution.patch.
- Delete
  patches.suse/0017-userns-prevent-speculative-execution.patch.
  Replace intel's shit by the potential upstream solution for spectre_v1.
- commit 6fdb1df
* Tue Jan 23 2018 jslaby@suse.cz
- Linux 4.14.15 (bnc#1012628).
- tools/objtool/Makefile: don't assume sync-check.sh is executable
  (bnc#1012628).
- objtool: Fix seg fault with clang-compiled objects
  (bnc#1012628).
- objtool: Fix Clang enum conversion warning (bnc#1012628).
- objtool: Fix seg fault caused by missing parameter
  (bnc#1012628).
- powerpc/pseries: Add H_GET_CPU_CHARACTERISTICS flags & wrapper
  (bnc#1012628).
- powerpc/64: Add macros for annotating the destination of
  rfid/hrfid (bnc#1012628).
- powerpc/64s: Simple RFI macro conversions (bnc#1012628).
- powerpc/64: Convert the syscall exit path to use
  RFI_TO_USER/KERNEL (bnc#1012628).
- powerpc/64: Convert fast_exception_return to use
  RFI_TO_USER/KERNEL (bnc#1012628).
- powerpc/64s: Convert slb_miss_common to use RFI_TO_USER/KERNEL
  (bnc#1012628).
- powerpc/64s: Add support for RFI flush of L1-D cache
  (bnc#1012628).
- powerpc/64s: Support disabling RFI flush with no_rfi_flush
  and nopti (bnc#1012628).
- powerpc/pseries: Query hypervisor for RFI flush settings
  (bnc#1012628).
- powerpc/powernv: Check device-tree for RFI flush settings
  (bnc#1012628).
- futex: Avoid violating the 10th rule of futex (bnc#1012628).
- futex: Prevent overflow by strengthen input validation
  (bnc#1012628).
- ALSA: pcm: Remove yet superfluous WARN_ON() (bnc#1012628).
- ALSA: hda - Apply headphone noise quirk for another Dell XPS
  13 variant (bnc#1012628).
- ALSA: hda - Apply the existing quirk to iMac 14,1 (bnc#1012628).
- IB/hfi1: Prevent a NULL dereference (bnc#1012628).
- RDMA/mlx5: Fix out-of-bound access while querying AH
  (bnc#1012628).
- timers: Unconditionally check deferrable base (bnc#1012628).
- af_key: fix buffer overread in verify_address_len()
  (bnc#1012628).
- af_key: fix buffer overread in parse_exthdrs() (bnc#1012628).
- iser-target: Fix possible use-after-free in connection
  establishment error (bnc#1012628).
- delayacct: Account blkio completion on the correct task
  (bnc#1012628).
- objtool: Fix seg fault with gold linker (bnc#1012628).
- mmc: sdhci-esdhc-imx: Fix i.MX53 eSDHCv3 clock (bnc#1012628).
- x86/kasan: Panic if there is not enough memory to boot
  (bnc#1012628).
- objtool: Improve error message for bad file argument
  (bnc#1012628).
- x86/cpufeature: Move processor tracing out of scattered features
  (bnc#1012628).
- x86/intel_rdt/cqm: Prevent use after free (bnc#1012628).
- x86/mm/pkeys: Fix fill_sig_info_pkey (bnc#1012628).
- x86/idt: Mark IDT tables __initconst (bnc#1012628).
- x86/tsc: Future-proof native_calibrate_tsc() (bnc#1012628).
- x86/tsc: Fix erroneous TSC rate on Skylake Xeon (bnc#1012628).
- pipe: avoid round_pipe_size() nr_pages overflow on 32-bit
  (bnc#1012628).
- x86/apic/vector: Fix off by one in error path (bnc#1012628).
- x86/mm: Clean up register saving in the __enc_copy() assembly
  code (bnc#1012628).
- x86/mm: Use a struct to reduce parameters for SME PGD mapping
  (bnc#1012628).
- x86/mm: Centralize PMD flags in sme_encrypt_kernel()
  (bnc#1012628).
- x86/mm: Prepare sme_encrypt_kernel() for PAGE aligned encryption
  (bnc#1012628).
- ARM: OMAP3: hwmod_data: add missing module_offs for MMC3
  (bnc#1012628).
- x86/mm: Encrypt the initrd earlier for BSP microcode update
  (bnc#1012628).
- Input: ALPS - fix multi-touch decoding on SS4 plus touchpads
  (bnc#1012628).
- Input: synaptics-rmi4 - prevent UAF reported by KASAN
  (bnc#1012628).
- Input: 88pm860x-ts - fix child-node lookup (bnc#1012628).
- Input: twl6040-vibra - fix child-node lookup (bnc#1012628).
- Input: twl4030-vibra - fix sibling-node lookup (bnc#1012628).
- tracing: Fix converting enum's from the map in
  trace_event_eval_update() (bnc#1012628).
- phy: work around 'phys' references to usb-nop-xceiv devices
  (bnc#1012628).
- ARM64: dts: marvell: armada-cp110: Fix clock resources for
  various node (bnc#1012628).
- ARM: sunxi_defconfig: Enable CMA (bnc#1012628).
- ARM: dts: kirkwood: fix pin-muxing of MPP7 on OpenBlocks A7
  (bnc#1012628).
- can: peak: fix potential bug in packet fragmentation
  (bnc#1012628).
- can: af_can: can_rcv(): replace WARN_ONCE by pr_warn_once
  (bnc#1012628).
- can: af_can: canfd_rcv(): replace WARN_ONCE by pr_warn_once
  (bnc#1012628).
- i2c: core-smbus: prevent stack corruption on read I2C_BLOCK_DATA
  (bnc#1012628).
- scripts/gdb/linux/tasks.py: fix get_thread_info (bnc#1012628).
- proc: fix coredump vs read /proc/*/stat race (bnc#1012628).
- libata: apply MAX_SEC_1024 to all LITEON EP1 series devices
  (bnc#1012628).
- scsi: libsas: Disable asynchronous aborts for SATA devices
  (bnc#1012628).
- workqueue: avoid hard lockups in show_workqueue_state()
  (bnc#1012628).
- drm/vmwgfx: fix memory corruption with legacy/sou connectors
  (bnc#1012628).
- dm btree: fix serious bug in btree_split_beneath()
  (bnc#1012628).
- dm thin metadata: THIN_MAX_CONCURRENT_LOCKS should be 6
  (bnc#1012628).
- dm integrity: don't store cipher request on the stack
  (bnc#1012628).
- dm crypt: fix crash by adding missing check for auth key size
  (bnc#1012628).
- dm crypt: wipe kernel key copy after IV initialization
  (bnc#1012628).
- dm crypt: fix error return code in crypt_ctr() (bnc#1012628).
- x86: Use __nostackprotect for sme_encrypt_kernel (bnc#1012628).
- alpha/PCI: Fix noname IRQ level detection (bnc#1012628).
- MIPS: CM: Drop WARN_ON(vp != 0) (bnc#1012628).
- KVM: arm/arm64: Check pagesize when allocating a hugepage at
  Stage 2 (bnc#1012628).
- arm64: KVM: Fix SMCCC handling of unimplemented SMC/HVC calls
  (bnc#1012628).
- x86/mce: Make machine check speculation protected (bnc#1012628).
- retpoline: Introduce start/end markers of indirect thunk
  (bnc#1012628).
- kprobes/x86: Blacklist indirect thunk functions for kprobes
  (bnc#1012628).
- kprobes/x86: Disable optimizing on the function jumps to
  indirect thunk (bnc#1012628).
- x86/pti: Document fix wrong index (bnc#1012628).
- x86/retpoline: Optimize inline assembler for vmexit_fill_RSB
  (bnc#1012628).
- x86/mm: Rework wbinvd, hlt operation in stop_this_cpu()
  (bnc#1012628).
- mm, page_vma_mapped: Drop faulty pointer arithmetics in
  check_pte() (bnc#1012628).
- net: mvpp2: do not disable GMAC padding (bnc#1012628).
- MIPS: AR7: ensure the port type's FCR value is used
  (bnc#1012628).
- Refresh
  patches.kernel.org/4.14.10-003-objtool-Move-kernel-headers-code-sync-check-t.patch.
- Refresh
  patches.suse/0001-x86-cpufeatures-Add-Intel-feature-bits-for-Speculati.patch.
- Refresh
  patches.suse/0002-x86-cpufeatures-Add-AMD-feature-bits-for-Prediction-.patch.
- commit fe1d712
* Mon Jan 22 2018 msuchanek@suse.de
- rpm/mkspec-dtb: Remove COPYING file (bsc#1076905).
  It conflicts between different versions of dtb package.
- commit 0e5fcf9
* Sun Jan 21 2018 jslaby@suse.cz
- x86/cpufeatures: Add Intel feature bits for Speculation Control
  (bsc#1068032 CVE-2017-5715).
- x86/cpufeatures: Add AMD feature bits for Prediction Command
  (bsc#1068032 CVE-2017-5715).
- x86/msr: Add definitions for new speculation control MSRs
  (bsc#1068032 CVE-2017-5715).
- module: Add retpoline tag to VERMAGIC (bsc#1068032
  CVE-2017-5715).
- x86/retpoline: Add LFENCE to the retpoline/RSB filling RSB
  macros (bsc#1068032 CVE-2017-5715).
- x86/retpoline: Fill RSB on context switch for affected CPUs
  (bsc#1068032 CVE-2017-5715).
- Refresh
  patches.suse/0005-x86-enter-MACROS-to-set-clear-IBRS-and-set-IBPB.patch.
- Refresh
  patches.suse/0008-x86-spec_ctrl-save-IBRS-MSR-value-in-paranoid_entry.patch.
- Refresh
  patches.suse/0009-x86-idle-Disable-IBRS-entering-idle-and-enable-it-on.patch.
- Refresh
  patches.suse/0010-x86-idle-Disable-IBRS-when-offlining-cpu-and-re-enab.patch.
- Refresh
  patches.suse/0011-x86-mm-Set-IBPB-upon-context-switch.patch.
- Refresh
  patches.suse/0012-x86-mm-Only-set-IBPB-when-the-new-thread-cannot-ptra.patch.
- Refresh
  patches.suse/0017-x86-kvm-Set-IBPB-when-switching-VM.patch.
- Refresh
  patches.suse/0018-x86-kvm-Toggle-IBRS-on-VM-entry-and-exit.patch.
- Refresh
  patches.suse/0021-x86-spec_ctrl-Add-sysctl-knobs-to-enable-disable-SPE.patch.
- Refresh
  patches.suse/0023-x86-Move-IBRS-IBPB-feature-detection-to-scattered.c.patch.
- Refresh
  patches.suse/0028-x86-svm-Set-IBPB-when-running-a-different-VCPU.patch.
- Refresh
  patches.suse/0029-kvm-svm-add-MSR_IA32_SPEC_CTRL-and-MSR_IA32_PRED_CMD.patch.
- Refresh patches.suse/0030-Use-the-ibrs_inuse-variable.patch.
- Refresh
  patches.suse/0032-kvm-vmx-add-MSR_IA32_SPEC_CTRL-and-MSR_IA32_PRED_CMD.patch.
- Refresh
  patches.suse/0034-Remove-the-code-that-uses-MSR-save-restore-list.patch.
- Refresh patches.suse/0035-Use-the-ibpb_inuse-variable.patch.
- Refresh
  patches.suse/0037-Set-IBPB-when-running-a-different-VCPU.patch.
- Delete
  patches.suse/0001-x86-feature-Enable-the-x86-feature-to-control-Specul.patch.
- Delete
  patches.suse/0002-x86-cpufeature-Add-X86_FEATURE_IA32_ARCH_CAPS-and-X8.patch.
- Delete
  patches.suse/0003-x86-Add-STIBP-feature-enumeration.patch.
- commit 5790c9a
* Thu Jan 18 2018 jslaby@suse.cz
- Update config files (bsc#1068032 CVE-2017-5715).
  Enable RETPOLINE -- the compiler is capable of them already.
- commit 5d5345e
* Wed Jan 17 2018 rjschwei@suse.com
- kernel-obs-build.spec.in: enable xfs module
  This allows the public cloud team to build images with XFS
  as root filesystem
- commit 95a2d6f
* Wed Jan 17 2018 msuchanek@suse.de
- macros.kernel-source: pass -f properly in module subpackage (boo#1076393).
- commit 66bd9b8
* Wed Jan 17 2018 jslaby@suse.cz
- Linux 4.14.14 (bnc#1012628).
- Delete
  patches.kernel.org/4.14.14-053-Revert-Revert-xfrm-Fix-stack-out-of-bounds-re.patch.
- commit eef6178
* Tue Jan 16 2018 tiwai@suse.de
- ALSA: seq: Make ioctls race-free (CVE-2018-1000004,bsc#1076017).
- commit 2134862
* Tue Jan 16 2018 jslaby@suse.cz
- ORC: fix retpolines segfaults (bnc#1068032 CVE-2017-5715).
- commit 470cac2
* Tue Jan 16 2018 jslaby@suse.cz
- dm bufio: fix shrinker scans when (nr_to_scan < retain_target)
  (bnc#1012628).
- KVM: Fix stack-out-of-bounds read in write_mmio (bnc#1012628).
- can: vxcan: improve handling of missing peer name attribute
  (bnc#1012628).
- can: gs_usb: fix return value of the "set_bittiming" callback
  (bnc#1012628).
- IB/srpt: Disable RDMA access by the initiator (bnc#1012628).
- IB/srpt: Fix ACL lookup during login (bnc#1012628).
- MIPS: Validate PR_SET_FP_MODE prctl(2) requests against the
  ABI of the task (bnc#1012628).
- MIPS: Factor out NT_PRFPREG regset access helpers (bnc#1012628).
- MIPS: Guard against any partial write attempt with
  PTRACE_SETREGSET (bnc#1012628).
- MIPS: Consistently handle buffer counter with PTRACE_SETREGSET
  (bnc#1012628).
- MIPS: Fix an FCSR access API regression with NT_PRFPREG and MSA
  (bnc#1012628).
- MIPS: Also verify sizeof `elf_fpreg_t' with PTRACE_SETREGSET
  (bnc#1012628).
- MIPS: Disallow outsized PTRACE_SETREGSET NT_PRFPREG regset
  accesses (bnc#1012628).
- cgroup: fix css_task_iter crash on CSS_TASK_ITER_PROC
  (bnc#1012628).
- kvm: vmx: Scrub hardware GPRs at VM-exit (bnc#1012628
  bnc#1068032 CVE-2017-5715).
- platform/x86: wmi: Call acpi_wmi_init() later (bnc#1012628).
- iw_cxgb4: only call the cq comp_handler when the cq is armed
  (bnc#1012628).
- iw_cxgb4: atomically flush the qp (bnc#1012628).
- iw_cxgb4: only clear the ARMED bit if a notification is needed
  (bnc#1012628).
- iw_cxgb4: reflect the original WR opcode in drain cqes
  (bnc#1012628).
- iw_cxgb4: when flushing, complete all wrs in a chain
  (bnc#1012628).
- x86/acpi: Handle SCI interrupts above legacy space gracefully
  (bnc#1012628).
- ALSA: pcm: Remove incorrect snd_BUG_ON() usages (bnc#1012628).
- ALSA: pcm: Workaround for weird PulseAudio behavior on rewind
  error (bnc#1012628).
- ALSA: pcm: Add missing error checks in OSS emulation plugin
  builder (bnc#1012628).
- ALSA: pcm: Abort properly at pending signal in OSS read/write
  loops (bnc#1012628).
- ALSA: pcm: Allow aborting mutex lock at OSS read/write loops
  (bnc#1012628).
- ALSA: aloop: Release cable upon open error path (bnc#1012628).
- ALSA: aloop: Fix inconsistent format due to incomplete rule
  (bnc#1012628).
- ALSA: aloop: Fix racy hw constraints adjustment (bnc#1012628).
- x86/acpi: Reduce code duplication in mp_override_legacy_irq()
  (bnc#1012628).
- 8021q: fix a memory leak for VLAN 0 device (bnc#1012628).
- ip6_tunnel: disable dst caching if tunnel is dual-stack
  (bnc#1012628).
- net: core: fix module type in sock_diag_bind (bnc#1012628).
- phylink: ensure we report link down when LOS asserted
  (bnc#1012628).
- RDS: Heap OOB write in rds_message_alloc_sgs() (bnc#1012628).
- RDS: null pointer dereference in rds_atomic_free_op
  (bnc#1012628).
- net: fec: restore dev_id in the cases of probe error
  (bnc#1012628).
- net: fec: defer probe if regulator is not ready (bnc#1012628).
- net: fec: free/restore resource in related probe error pathes
  (bnc#1012628).
- sctp: do not retransmit upon FragNeeded if PMTU discovery is
  disabled (bnc#1012628).
- sctp: fix the handling of ICMP Frag Needed for too small MTUs
  (bnc#1012628).
- sh_eth: fix TSU resource handling (bnc#1012628).
- net: stmmac: enable EEE in MII, GMII or RGMII only
  (bnc#1012628).
- sh_eth: fix SH7757 GEther initialization (bnc#1012628).
- ipv6: fix possible mem leaks in ipv6_make_skb() (bnc#1012628).
- ethtool: do not print warning for applications using legacy API
  (bnc#1012628).
- mlxsw: spectrum_router: Fix NULL pointer deref (bnc#1012628).
- net/sched: Fix update of lastuse in act modules implementing
  stats_update (bnc#1012628).
- ipv6: sr: fix TLVs not being copied using setsockopt
  (bnc#1012628).
- mlxsw: spectrum: Relax sanity checks during enslavement
  (bnc#1012628).
- sfp: fix sfp-bus oops when removing socket/upstream
  (bnc#1012628).
- Revert "Revert "xfrm: Fix stack-out-of-bounds read in
  xfrm_state_find."" (bnc#1012628).
- membarrier: Disable preemption when calling
  smp_call_function_many() (bnc#1012628).
- crypto: algapi - fix NULL dereference in crypto_remove_spawns()
  (bnc#1012628).
- mmc: renesas_sdhi: Add MODULE_LICENSE (bnc#1012628).
- rbd: reacquire lock should update lock owner client id
  (bnc#1012628).
- rbd: set max_segments to USHRT_MAX (bnc#1012628).
- iwlwifi: pcie: fix DMA memory mapping / unmapping (bnc#1012628).
- x86/microcode/intel: Extend BDW late-loading with a revision
  check (bnc#1012628).
- KVM: x86: Add memory barrier on vmcs field lookup (bnc#1012628).
- KVM: PPC: Book3S PR: Fix WIMG handling under pHyp (bnc#1012628).
- KVM: PPC: Book3S HV: Drop prepare_done from struct
  kvm_resize_hpt (bnc#1012628).
- KVM: PPC: Book3S HV: Fix use after free in case of multiple
  resize requests (bnc#1012628).
- KVM: PPC: Book3S HV: Always flush TLB in
  kvmppc_alloc_reset_hpt() (bnc#1012628).
- drm/vmwgfx: Don't cache framebuffer maps (bnc#1012628).
- drm/vmwgfx: Potential off by one in vmw_view_add()
  (bnc#1012628).
- drm/i915/gvt: Clear the shadow page table entry after post-sync
  (bnc#1012628).
- drm/i915: Whitelist SLICE_COMMON_ECO_CHICKEN1 on Geminilake
  (bnc#1012628).
- drm/i915: Move init_clock_gating() back to where it was
  (bnc#1012628).
- drm/i915: Fix init_clock_gating for resume (bnc#1012628).
- bpf: arsh is not supported in 32 bit alu thus reject it
  (bnc#1012628).
- USB: serial: cp210x: add IDs for LifeScan OneTouch Verio IQ
  (bnc#1012628).
- USB: serial: cp210x: add new device ID ELV ALC 8xxx
  (bnc#1012628).
- usb: misc: usb3503: make sure reset is low for at least 100us
  (bnc#1012628).
- USB: fix usbmon BUG trigger (bnc#1012628).
- USB: UDC core: fix double-free in usb_add_gadget_udc_release
  (bnc#1012628).
- usbip: remove kernel addresses from usb device and urb debug
  msgs (bnc#1012628).
- usbip: fix vudc_rx: harden CMD_SUBMIT path to handle malicious
  input (bnc#1012628).
- usbip: vudc_tx: fix v_send_ret_submit() vulnerability to null
  xfer buffer (bnc#1012628).
- staging: android: ashmem: fix a race condition in
  ASHMEM_SET_SIZE ioctl (bnc#1012628).
- Bluetooth: Prevent stack info leak from the EFS element
  (bnc#1012628).
- uas: ignore UAS for Norelsys NS1068(X) chips (bnc#1012628).
- mux: core: fix double get_device() (bnc#1012628).
- kdump: write correct address of mem_section into vmcoreinfo
  (bnc#1012628).
- apparmor: fix ptrace label match when matching stacked labels
  (bnc#1012628).
- e1000e: Fix e1000_check_for_copper_link_ich8lan return value
  (bnc#1012628).
- x86/pti: Unbreak EFI old_memmap (bnc#1012628).
- x86/Documentation: Add PTI description (bnc#1012628).
- x86/cpufeatures: Add X86_BUG_SPECTRE_V[12] (bnc#1012628).
- sysfs/cpu: Add vulnerability folder (bnc#1012628).
- x86/cpu: Implement CPU vulnerabilites sysfs functions
  (bnc#1012628).
- x86/tboot: Unbreak tboot with PTI enabled (bnc#1012628).
- x86/mm/pti: Remove dead logic in pti_user_pagetable_walk*()
  (bnc#1012628).
- sysfs/cpu: Fix typos in vulnerability documentation
  (bnc#1012628).
- x86/alternatives: Fix optimize_nops() checking (bnc#1012628).
- x86/pti: Make unpoison of pgd for trusted boot work for real
  (bnc#1012628).
- objtool: Detect jumps to retpoline thunks (bnc#1012628).
- objtool: Allow alternatives to be ignored (bnc#1012628).
- x86/retpoline: Add initial retpoline support (bnc#1012628
  bnc#1068032 CVE-2017-5715).
- x86/spectre: Add boot time option to select Spectre v2
  mitigation (bnc#1012628).
- x86/retpoline/crypto: Convert crypto assembler indirect jumps
  (bnc#1012628).
- x86/retpoline/entry: Convert entry assembler indirect jumps
  (bnc#1012628).
- x86/retpoline/ftrace: Convert ftrace assembler indirect jumps
  (bnc#1012628).
- x86/retpoline/hyperv: Convert assembler indirect jumps
  (bnc#1012628).
- x86/retpoline/xen: Convert Xen hypercall indirect jumps
  (bnc#1012628).
- x86/retpoline/checksum32: Convert assembler indirect jumps
  (bnc#1012628).
- x86/retpoline/irq32: Convert assembler indirect jumps
  (bnc#1012628).
- x86/retpoline: Fill return stack buffer on vmexit (bnc#1012628
  bnc#1068032 CVE-2017-5715).
- selftests/x86: Add test_vsyscall (bnc#1012628).
- x86/pti: Fix !PCID and sanitize defines (bnc#1012628).
- security/Kconfig: Correct the Documentation reference for PTI
  (bnc#1012628).
- x86,perf: Disable intel_bts when PTI (bnc#1012628).
- x86/retpoline: Remove compile time warning (bnc#1012628).
- Update config files.
- Refresh
  patches.suse/0007-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- Refresh
  patches.suse/0016-x86-kvm-add-MSR_IA32_SPEC_CTRL-and-MSR_IA32_PRED_CMD.patch.
- Refresh
  patches.suse/0029-kvm-svm-add-MSR_IA32_SPEC_CTRL-and-MSR_IA32_PRED_CMD.patch.
- Refresh
  patches.suse/0031-Reverting-the-commit-e5247c4f209530-to-replace.patch.
- Refresh
  patches.suse/0032-kvm-vmx-add-MSR_IA32_SPEC_CTRL-and-MSR_IA32_PRED_CMD.patch.
- Delete patches.suse/0019-x86-kvm-Pad-RSB-on-VM-transition.patch.
- Delete
  patches.suse/0020-x86-kvm-clear-registers-on-VM-exit.patch.
- Delete
  patches.suse/0026-Revert-x86-kvm-Pad-RSB-on-VM-transition.patch.
- Delete patches.suse/0027-x86-kvm-Pad-RSB-on-VM-transition.patch.
- Delete
  patches.suse/0036-Clear-the-host-registers-after-setbe.patch.
- commit edd3e75
* Mon Jan 15 2018 jeffm@suse.com
- Update to 4.15-rc8.
- Eliminated 3 patches.
- Config changes:
  - Security:
  - BPF_JIT_ALWAYS_ON=y
  - RETPOLINE=n (depends on gcc with -mindirect-branch=thunk-extern)
- commit 05e4405
* Fri Jan 12 2018 jslaby@suse.cz
- bpf, array: fix overflow in max_entries and undefined behavior
  in index_mask (bsc#1068032 CVE-2017-5753).
- commit 3283516
* Fri Jan 12 2018 jslaby@suse.cz
- Refresh
  patches.suse/bpf-prevent-out-of-bounds-speculation.patch.
- Delete
  patches.suse/0004-bpf-prevent-speculative-execution-in-eBPF-interprete.patch.
  Update the upstream status of the former.
  And removed the latter as it has been just replaced by the proper
  upstream solution.
- commit 20ac09f
* Fri Jan 12 2018 jslaby@suse.cz
- bpf: prevent out-of-bounds speculation (bsc#1068032
  CVE-2017-5753).
- commit 0eca303
* Thu Jan 11 2018 matwey.kornilov@gmail.com
- config: arm64: Enable Aardvark PCIe controller
  Aardvark PCIe controller is a part of Marvel Armada 3700 SoC.
  This option is required to support PCIe for JeOS-espressobin.
- commit b0bb655
* Thu Jan 11 2018 tiwai@suse.de
- drm/nouveau/disp/gf119: add missing drive vfunc ptr
  (bsc#1075613).
- commit 80f2eaf
* Thu Jan 11 2018 lpechacek@suse.com
- rpm/kernel-binary.spec.in: more specific kGraft Provides: (fate#323682)
  Follow openSUSE packaging practices described at
  https://en.opensuse.org/openSUSE:Package_dependencies#Renaming_a_package.
- commit 050081b
* Thu Jan 11 2018 mkubecek@suse.cz
- Update
  patches.kernel.org/4.14.9-161-bpf-fix-branch-pruning-logic.patch
  references (add CVE-2017-17862 CVE-2017-17864 bsc#1073928).
- Update
  patches.kernel.org/4.14.9-166-bpf-verifier-fix-bounds-calculation-on-BPF_RSH.patch
  references (add CVE-2017-17853 bsc#1073928).
- Update
  patches.kernel.org/4.14.9-167-bpf-fix-incorrect-sign-extension-in-check_alu_.patch
  references (add CVE-2017-16995 bsc#1073928).
- Update
  patches.kernel.org/4.14.9-168-bpf-fix-incorrect-tracking-of-register-size-tr.patch
  references (add CVE-2017-16996 bsc#1073928).
- Update
  patches.kernel.org/4.14.9-169-bpf-fix-32-bit-ALU-op-verification.patch
  references (add CVE-2017-17852 bsc#1073928).
- Update
  patches.kernel.org/4.14.9-170-bpf-fix-missing-error-return-in-check_stack_bo.patch
  references (add CVE-2017-17857 bsc#1073928).
- Update
  patches.kernel.org/4.14.9-171-bpf-force-strict-alignment-checks-for-stack-po.patch
  references (add CVE-2017-17856 bsc#1073928).
- Update
  patches.kernel.org/4.14.9-172-bpf-don-t-prune-branches-when-a-scalar-is-repl.patch
  references (add CVE-2017-17855 bsc#1073928).
- Update
  patches.kernel.org/4.14.9-173-bpf-fix-integer-overflows.patch
  references (add CVE-2017-17854 bsc#1073928).
- Update
  patches.kernel.org/4.14.9-174-selftests-bpf-add-tests-for-recent-bugfixes.patch
  references (add bsc#1073928).
- commit 4a4cd97
* Thu Jan 11 2018 mkubecek@suse.cz
- Fix mainline reference:
  patches.kernel.org/4.14.9-170-bpf-fix-missing-error-return-in-check_stack_bo.patch.
- commit 98662d2
* Thu Jan 11 2018 mkubecek@suse.cz
- Update
  patches.kernel.org/4.14.11-084-net-Fix-double-free-and-memory-corruption-in-.patch
  references (add CVE-2017-15129 bsc#1074839).
- commit 7acebb3
* Wed Jan 10 2018 jslaby@suse.cz
- x86/cpu/AMD: Make LFENCE a serializing instruction (bsc#1068032
  CVE-2017-5754).
- x86/cpu/AMD: Use LFENCE_RDTSC in preference to MFENCE_RDTSC
  (bsc#1068032 CVE-2017-5754).
- Delete
  patches.suse/0001-x86-cpu-AMD-Make-the-LFENCE-instruction-serialized.patch.
- Delete
  patches.suse/0002-x86-cpu-AMD-Remove-now-unused-definition-of-MFENCE_R.patch.
  Use the variants from upstream (tip tree).
- commit 33b16eb
* Wed Jan 10 2018 jslaby@suse.cz
- Linux 4.14.13 (bnc#1012628).
- x86/mm: Set MODULES_END to 0xffffffffff000000 (bnc#1012628).
- x86/mm: Map cpu_entry_area at the same place on 4/5 level
  (bnc#1012628).
- x86/kaslr: Fix the vaddr_end mess (bnc#1012628).
- x86/events/intel/ds: Use the proper cache flush method for
  mapping ds buffers (bnc#1012628).
- x86/tlb: Drop the _GPL from the cpu_tlbstate export
  (bnc#1012628).
- x86/alternatives: Add missing '\n' at end of ALTERNATIVE inline
  asm (bnc#1012628).
- x86/pti: Rename BUG_CPU_INSECURE to BUG_CPU_MELTDOWN
  (bnc#1012628).
- kernel/acct.c: fix the acct->needcheck check in
  check_free_space() (bnc#1012628).
- mm/mprotect: add a cond_resched() inside change_pmd_range()
  (bnc#1012628).
- mm/sparse.c: wrong allocation for mem_section (bnc#1012628).
- userfaultfd: clear the vma->vm_userfaultfd_ctx if
  UFFD_EVENT_FORK fails (bnc#1012628).
- btrfs: fix refcount_t usage when deleting btrfs_delayed_nodes
  (bnc#1012628).
- efi/capsule-loader: Reinstate virtual capsule mapping
  (bnc#1012628).
- crypto: n2 - cure use after free (bnc#1012628).
- crypto: chacha20poly1305 - validate the digest size
  (bnc#1012628).
- crypto: pcrypt - fix freeing pcrypt instances (bnc#1012628).
- crypto: chelsio - select CRYPTO_GF128MUL (bnc#1012628).
- drm/i915: Disable DC states around GMBUS on GLK (bnc#1012628).
- drm/i915: Apply Display WA #1183 on skl, kbl, and cfl
  (bnc#1012628).
- sunxi-rsb: Include OF based modalias in device uevent
  (bnc#1012628).
- fscache: Fix the default for fscache_maybe_release_page()
  (bnc#1012628).
- x86 / CPU: Avoid unnecessary IPIs in arch_freq_get_on_cpu()
  (bnc#1012628).
- x86 / CPU: Always show current CPU frequency in /proc/cpuinfo
  (bnc#1012628).
- kernel/signal.c: protect the traced SIGNAL_UNKILLABLE tasks
  from SIGKILL (bnc#1012628).
- kernel/signal.c: protect the SIGNAL_UNKILLABLE tasks from
  !sig_kernel_only() signals (bnc#1012628).
- kernel/signal.c: remove the no longer needed SIGNAL_UNKILLABLE
  check in complete_signal() (bnc#1012628).
- iommu/arm-smmu-v3: Don't free page table ops twice
  (bnc#1012628).
- iommu/arm-smmu-v3: Cope with duplicated Stream IDs
  (bnc#1012628).
- ARC: uaccess: dont use "l" gcc inline asm constraint modifier
  (bnc#1012628).
- powerpc/mm: Fix SEGV on mapped region to return SEGV_ACCERR
  (bnc#1012628).
- Input: elantech - add new icbody type 15 (bnc#1012628).
- apparmor: fix regression in mount mediation when feature set
  is pinned (bnc#1012628).
- parisc: Fix alignment of pa_tlb_lock in assembly on 32-bit
  SMP kernel (bnc#1012628).
- parisc: qemu idle sleep support (bnc#1012628).
- mtd: nand: pxa3xx: Fix READOOB implementation (bnc#1012628).
- KVM: s390: fix cmma migration for multiple memory slots
  (bnc#1012628).
- KVM: s390: prevent buffer overrun on memory hotplug during
  migration (bnc#1012628).
- commit bd444a0
* Tue Jan  9 2018 jslaby@suse.cz
- Refresh
  patches.suse/0007-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- Refresh
  patches.suse/0013-x86-entry-Stuff-RSB-for-entry-to-kernel-for-non-SMEP.patch.
- Refresh
  patches.suse/0015-x86-syscall-Clear-unused-extra-registers-on-32-bit-c.patch.
  Fix double fault in 32bit binaries (bnc#1074869, bnc#1074918,
  bnc#1074920, bnc#1074921, bnc#1075018, bnc#1075034)
- commit f4b3cf0
* Mon Jan  8 2018 msuchanek@suse.de
- kernel-obs-build.spec.in: add --no-hostonly-cmdline to dracut invocation (boo#1062303).
  call dracut with --no-hostonly-cmdline to avoid the random rootfs UUID
  being added into the initrd's /etc/cmdline.d/95root-dev.conf
- commit da5186f
* Mon Jan  8 2018 jeffm@suse.com
- Update to 4.15-rc7.
- Eliminated 1 patch.
- commit b07c570
* Sat Jan  6 2018 jslaby@suse.cz
- rpm/constraints.in: lower kernel-syzkaller's mem requirements
  OBS now reports that it needs only around 2G, so lower the limit to
  8G, so that more compliant workers can be used.
- commit a73399a
* Fri Jan  5 2018 jslaby@suse.cz
- Linux 4.14.12 (bnc#1012628).
- exec: Weaken dumpability for secureexec (bnc#1012628).
- capabilities: fix buffer overread on very short xattr
  (bnc#1012628).
- x86/cpu, x86/pti: Do not enable PTI on AMD processors
  (bnc#1012628).
- x86/pti: Make sure the user/kernel PTEs match (bnc#1012628).
- x86/dumpstack: Fix partial register dumps (bnc#1012628).
- x86/dumpstack: Print registers for first stack frame
  (bnc#1012628).
- x86/pti: Switch to kernel CR3 at early in entry_SYSCALL_compat()
  (bnc#1012628).
- x86/process: Define cpu_tss_rw in same section as declaration
  (bnc#1012628).
- Revert "xfrm: Fix stack-out-of-bounds read in
  xfrm_state_find." (bnc#1012628).
- rtc: m41t80: m41t80_sqw_set_rate should return 0 on success
  (bnc#1012628).
- rtc: m41t80: fix m41t80_sqw_round_rate return value
  (bnc#1012628).
- rtc: m41t80: avoid i2c read in m41t80_sqw_recalc_rate
  (bnc#1012628).
- rtc: m41t80: avoid i2c read in m41t80_sqw_is_prepared
  (bnc#1012628).
- rtc: m41t80: remove unneeded checks from m41t80_sqw_set_rate
  (bnc#1012628).
- Refresh
  patches.suse/0002-x86-stacktrace-make-clear-the-success-paths.patch.
- Refresh
  patches.suse/0007-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- Refresh
  patches.suse/0013-x86-entry-Stuff-RSB-for-entry-to-kernel-for-non-SMEP.patch.
- Refresh
  patches.suse/0015-x86-syscall-Clear-unused-extra-registers-on-32-bit-c.patch.
- commit 3cf399e
* Thu Jan  4 2018 jslaby@suse.cz
- Refresh
  patches.suse/0027-x86-kvm-Pad-RSB-on-VM-transition.patch.
- Refresh
  patches.suse/0031-Reverting-the-commit-e5247c4f209530-to-replace.patch.
  Fix i386 build.
- commit c36893f
* Wed Jan  3 2018 jslaby@suse.cz
- Set IBPB when running a different VCPU (bnc#1068032
  CVE-2017-5715).
- Clear the host registers after setbe (bnc#1068032
  CVE-2017-5715).
- Use the ibpb_inuse variable (bnc#1068032 CVE-2017-5715).
- Remove the code that uses MSR save/restore list (bnc#1068032
  CVE-2017-5715).
- KVM: x86: add SPEC_CTRL to MSR and CPUID lists (bnc#1068032
  CVE-2017-5715).
- kvm: vmx: add MSR_IA32_SPEC_CTRL and MSR_IA32_PRED_CMD
  (bnc#1068032 CVE-2017-5715).
- Reverting the commit e5247c4f209530 to replace (bnc#1068032
  CVE-2017-5715).
- Use the "ibrs_inuse" variable (bnc#1068032 CVE-2017-5715).
- kvm: svm: add MSR_IA32_SPEC_CTRL and MSR_IA32_PRED_CMD
  (bnc#1068032 CVE-2017-5715).
- x86/svm: Set IBPB when running a different VCPU (bnc#1068032
  CVE-2017-5715).
- x86/kvm: Pad RSB on VM transition (bnc#1068032 CVE-2017-5715).
- Revert x86/kvm: Pad RSB on VM transition (bnc#1068032
  CVE-2017-5715).
- x86/cpu/AMD: Add speculative control support for AMD
  (bnc#1068032 CVE-2017-5715).
- x86/microcode: Recheck IBRS and IBPB feature on microcode reload
  (bnc#1068032 CVE-2017-5715).
- x86: Move IBRS/IBPB feature detection to scattered.c
  (bnc#1068032 CVE-2017-5715).
- x86/spec_ctrl: Add lock to serialize changes to ibrs and ibpb
  control (bnc#1068032 CVE-2017-5715).
- x86/spec_ctrl: Add sysctl knobs to enable/disable SPEC_CTRL
  feature (bnc#1068032 CVE-2017-5715).
- x86/kvm: clear registers on VM exit (bnc#1068032 CVE-2017-5715).
- x86/kvm: Pad RSB on VM transition (bnc#1068032 CVE-2017-5715).
- x86/kvm: Toggle IBRS on VM entry and exit (bnc#1068032
  CVE-2017-5715).
- x86/kvm: Set IBPB when switching VM (bnc#1068032 CVE-2017-5715).
- x86/kvm: add MSR_IA32_SPEC_CTRL and MSR_IA32_PRED_CMD to kvm
  (bnc#1068032 CVE-2017-5715).
- x86/syscall: Clear unused extra registers on 32-bit compatible
  syscall entrance (bnc#1068032 CVE-2017-5715).
- x86/syscall: Clear unused extra registers on syscall entrance
  (bnc#1068032 CVE-2017-5715).
- x86/entry: Stuff RSB for entry to kernel for non-SMEP platform
  (bnc#1068032 CVE-2017-5715).
- x86/mm: Only set IBPB when the new thread cannot ptrace current
  thread (bnc#1068032 CVE-2017-5715).
- x86/mm: Set IBPB upon context switch (bnc#1068032
  CVE-2017-5715).
- x86/idle: Disable IBRS when offlining cpu and re-enable on
  wakeup (bnc#1068032 CVE-2017-5715).
- x86/idle: Disable IBRS entering idle and enable it on wakeup
  (bnc#1068032 CVE-2017-5715).
- x86/spec_ctrl: save IBRS MSR value in paranoid_entry
  (bnc#1068032 CVE-2017-5715).
- x86/enter: Use IBRS on syscall and interrupts (bnc#1068032
  CVE-2017-5715).
- x86: Add macro that does not save rax, rcx, rdx on stack to
  disable IBRS (bnc#1068032 CVE-2017-5715).
- x86/enter: MACROS to set/clear IBRS and set IBPB (bnc#1068032
  CVE-2017-5715).
- x86/feature: Report presence of IBPB and IBRS control
  (bnc#1068032 CVE-2017-5715).
- x86: Add STIBP feature enumeration (bnc#1068032 CVE-2017-5715).
- x86/cpufeature: Add X86_FEATURE_IA32_ARCH_CAPS and
  X86_FEATURE_IBRS_ATT (bnc#1068032 CVE-2017-5715).
- x86/feature: Enable the x86 feature to control Speculation
  (bnc#1068032 CVE-2017-5715).
- commit 816f713
* Wed Jan  3 2018 jslaby@suse.cz
- userns: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- udf: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- net: mpls: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- fs: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- ipv6: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- ipv4: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- Thermal/int340x: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- cw1200: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- qla2xxx: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- p54: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- carl9170: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- uvcvideo: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- x86, bpf, jit: prevent speculative execution when JIT is enabled
  (bnc#1068032 CVE-2017-5753).
- bpf: prevent speculative execution in eBPF interpreter
  (bnc#1068032 CVE-2017-5753).
- locking/barriers: introduce new observable speculation barrier
  (bnc#1068032 CVE-2017-5753).
- x86/cpu/AMD: Remove now unused definition of MFENCE_RDTSC
  feature (bnc#1068032 CVE-2017-5753).
- x86/cpu/AMD: Make the LFENCE instruction serialized (bnc#1068032
  CVE-2017-5753).
- commit cf46932
* Wed Jan  3 2018 jslaby@suse.cz
- Linux 4.14.11 (bnc#1012628).
- tracing: Remove extra zeroing out of the ring buffer page
  (bnc#1012628).
- tracing: Fix possible double free on failure of allocating
  trace buffer (bnc#1012628).
- tracing: Fix crash when it fails to alloc ring buffer
  (bnc#1012628).
- x86/cpufeatures: Add X86_BUG_CPU_INSECURE (bnc#1012628).
- x86/mm/pti: Disable global pages if PAGE_TABLE_ISOLATION=y
  (bnc#1012628).
- x86/mm/pti: Prepare the x86/entry assembly code for entry/exit
  CR3 switching (bnc#1012628).
- x86/mm/pti: Add infrastructure for page table isolation
  (bnc#1012628).
- x86/pti: Add the pti= cmdline option and documentation
  (bnc#1012628).
- x86/mm/pti: Add mapping helper functions (bnc#1012628).
- x86/mm/pti: Allow NX poison to be set in p4d/pgd (bnc#1012628).
- x86/mm/pti: Allocate a separate user PGD (bnc#1012628).
- x86/mm/pti: Populate user PGD (bnc#1012628).
- x86/mm/pti: Add functions to clone kernel PMDs (bnc#1012628).
- x86/mm/pti: Force entry through trampoline when PTI active
  (bnc#1012628).
- x86/mm/pti: Share cpu_entry_area with user space page tables
  (bnc#1012628).
- x86/entry: Align entry text section to PMD boundary
  (bnc#1012628).
- x86/mm/pti: Share entry text PMD (bnc#1012628).
- x86/mm/pti: Map ESPFIX into user space (bnc#1012628).
- x86/cpu_entry_area: Add debugstore entries to cpu_entry_area
  (bnc#1012628).
- x86/events/intel/ds: Map debug buffers in cpu_entry_area
  (bnc#1012628).
- x86/mm/64: Make a full PGD-entry size hole in the memory map
  (bnc#1012628).
- x86/pti: Put the LDT in its own PGD if PTI is on (bnc#1012628).
- x86/pti: Map the vsyscall page if needed (bnc#1012628).
- x86/mm: Allow flushing for future ASID switches (bnc#1012628).
- x86/mm: Abstract switching CR3 (bnc#1012628).
- x86/mm: Use/Fix PCID to optimize user/kernel switches
  (bnc#1012628).
- x86/mm: Optimize RESTORE_CR3 (bnc#1012628).
- x86/mm: Use INVPCID for __native_flush_tlb_single()
  (bnc#1012628).
- x86/mm: Clarify the whole ASID/kernel PCID/user PCID naming
  (bnc#1012628).
- x86/dumpstack: Indicate in Oops whether PTI is configured and
  enabled (bnc#1012628).
- x86/mm/pti: Add Kconfig (bnc#1012628).
- x86/mm/dump_pagetables: Add page table directory to the debugfs
  VFS hierarchy (bnc#1012628).
- x86/mm/dump_pagetables: Check user space page table for WX pages
  (bnc#1012628).
- x86/mm/dump_pagetables: Allow dumping current pagetables
  (bnc#1012628).
- x86/ldt: Make the LDT mapping RO (bnc#1012628).
- ring-buffer: Mask out the info bits when returning buffer page
  length (bnc#1012628).
- ring-buffer: Do no reuse reader page if still in use
  (bnc#1012628).
- iw_cxgb4: Only validate the MSN for successful completions
  (bnc#1012628).
- ASoC: codecs: msm8916-wcd: Fix supported formats (bnc#1012628).
- ASoC: wm_adsp: Fix validation of firmware and coeff lengths
  (bnc#1012628).
- ASoC: da7218: fix fix child-node lookup (bnc#1012628).
- ASoC: fsl_ssi: AC'97 ops need regmap, clock and cleaning up
  on failure (bnc#1012628).
- ASoC: twl4030: fix child-node lookup (bnc#1012628).
- ASoC: tlv320aic31xx: Fix GPIO1 register definition
  (bnc#1012628).
- gpio: fix "gpio-line-names" property retrieval (bnc#1012628).
- IB/hfi: Only read capability registers if the capability exists
  (bnc#1012628).
- IB/mlx5: Serialize access to the VMA list (bnc#1012628).
- IB/uverbs: Fix command checking as part of
  ib_uverbs_ex_modify_qp() (bnc#1012628).
- IB/core: Verify that QP is security enabled in create and
  destroy (bnc#1012628).
- ALSA: hda: Drop useless WARN_ON() (bnc#1012628).
- ALSA: hda - Add MIC_NO_PRESENCE fixup for 2 HP machines
  (bnc#1012628).
- ALSA: hda - change the location for one mic on a Lenovo machine
  (bnc#1012628).
- ALSA: hda - fix headset mic detection issue on a Dell machine
  (bnc#1012628).
- ALSA: hda - Fix missing COEF init for ALC225/295/299
  (bnc#1012628).
- cpufreq: schedutil: Use idle_calls counter of the remote CPU
  (bnc#1012628).
- block: fix blk_rq_append_bio (bnc#1012628).
- block: don't let passthrough IO go into .make_request_fn()
  (bnc#1012628).
- kbuild: add '-fno-stack-check' to kernel build options
  (bnc#1012628).
- ipv4: igmp: guard against silly MTU values (bnc#1012628).
- ipv6: mcast: better catch silly mtu values (bnc#1012628).
- net: fec: unmap the xmit buffer that are not transferred by DMA
  (bnc#1012628).
- net: igmp: Use correct source address on IGMPv3 reports
  (bnc#1012628).
- net: qmi_wwan: add Sierra EM7565 1199:9091 (bnc#1012628).
- net: reevalulate autoflowlabel setting after sysctl setting
  (bnc#1012628).
- ptr_ring: add barriers (bnc#1012628).
- RDS: Check cmsg_len before dereferencing CMSG_DATA
  (bnc#1012628).
- tcp_bbr: record "full bw reached" decision in new
  full_bw_reached bit (bnc#1012628).
- tcp md5sig: Use skb's saddr when replying to an incoming segment
  (bnc#1012628).
- tg3: Fix rx hang on MTU change with 5717/5719 (bnc#1012628).
- tcp_bbr: reset full pipe detection on loss recovery undo
  (bnc#1012628).
- tcp_bbr: reset long-term bandwidth sampling on loss recovery
  undo (bnc#1012628).
- s390/qeth: apply takeover changes when mode is toggled
  (bnc#1012628).
- s390/qeth: don't apply takeover changes to RXIP (bnc#1012628).
- s390/qeth: lock IP table while applying takeover changes
  (bnc#1012628).
- s390/qeth: update takeover IPs after configuration change
  (bnc#1012628).
- net: ipv4: fix for a race condition in raw_sendmsg
  (bnc#1012628).
- net: mvmdio: disable/unprepare clocks in EPROBE_DEFER case
  (bnc#1012628).
- sctp: Replace use of sockets_allocated with specified macro
  (bnc#1012628).
- adding missing rcu_read_unlock in ipxip6_rcv (bnc#1012628).
- ip6_gre: fix device features for ioctl setup (bnc#1012628).
- ipv4: Fix use-after-free when flushing FIB tables (bnc#1012628).
- net: bridge: fix early call to br_stp_change_bridge_id and
  plug newlink leaks (bnc#1012628).
- net: Fix double free and memory corruption in get_net_ns_by_id()
  (bnc#1012628).
- net: phy: micrel: ksz9031: reconfigure autoneg after phy
  autoneg workaround (bnc#1012628).
- sock: free skb in skb_complete_tx_timestamp on error
  (bnc#1012628).
- tcp: invalidate rate samples during SACK reneging (bnc#1012628).
- net/mlx5: Fix rate limit packet pacing naming and struct
  (bnc#1012628).
- net/mlx5e: Fix possible deadlock of VXLAN lock (bnc#1012628).
- net/mlx5e: Fix features check of IPv6 traffic (bnc#1012628).
- net/mlx5e: Add refcount to VXLAN structure (bnc#1012628).
- net/mlx5e: Prevent possible races in VXLAN control flow
  (bnc#1012628).
- net/mlx5: Fix error flow in CREATE_QP command (bnc#1012628).
- openvswitch: Fix pop_vlan action for double tagged frames
  (bnc#1012628).
- sfc: pass valid pointers from efx_enqueue_unwind (bnc#1012628).
- net: dsa: bcm_sf2: Clear IDDQ_GLOBAL_PWR bit for PHY
  (bnc#1012628).
- s390/qeth: fix error handling in checksum cmd callback
  (bnc#1012628).
- sctp: make sure stream nums can match optlen in
  sctp_setsockopt_reset_streams (bnc#1012628).
- tipc: fix hanging poll() for stream sockets (bnc#1012628).
- mlxsw: spectrum: Disable MAC learning for ovs port
  (bnc#1012628).
- tcp: fix potential underestimation on rcv_rtt (bnc#1012628).
- net: phy: marvell: Limit 88m1101 autoneg errata to 88E1145 as
  well (bnc#1012628).
- ipv6: Honor specified parameters in fibmatch lookup
  (bnc#1012628).
- tcp: refresh tcp_mstamp from timers callbacks (bnc#1012628).
- net/mlx5: FPGA, return -EINVAL if size is zero (bnc#1012628).
- vxlan: restore dev->mtu setting based on lower device
  (bnc#1012628).
- net: sched: fix static key imbalance in case of
  ingress/clsact_init error (bnc#1012628).
- bnxt_en: Fix sources of spurious netpoll warnings (bnc#1012628).
- phylink: ensure the PHY interface mode is appropriately set
  (bnc#1012628).
- phylink: ensure AN is enabled (bnc#1012628).
- ipv4: fib: Fix metrics match when deleting a route
  (bnc#1012628).
- ipv6: set all.accept_dad to 0 by default (bnc#1012628).
- Revert "mlx5: move affinity hints assignments to generic code"
  (bnc#1012628).
- skbuff: orphan frags before zerocopy clone (bnc#1012628).
- skbuff: skb_copy_ubufs must release uarg even without user frags
  (bnc#1012628).
- skbuff: in skb_copy_ubufs unclone before releasing zerocopy
  (bnc#1012628).
- sparc64: repair calling incorrect hweight function from stubs
  (bnc#1012628).
- usbip: fix usbip bind writing random string after command in
  match_busid (bnc#1012628).
- usbip: prevent leaking socket pointer address in messages
  (bnc#1012628).
- usbip: stub: stop printing kernel pointer addresses in messages
  (bnc#1012628).
- usbip: vhci: stop printing kernel pointer addresses in messages
  (bnc#1012628).
- USB: chipidea: msm: fix ulpi-node lookup (bnc#1012628).
- USB: serial: ftdi_sio: add id for Airbus DS P8GR (bnc#1012628).
- USB: serial: qcserial: add Sierra Wireless EM7565 (bnc#1012628).
- USB: serial: option: add support for Telit ME910 PID 0x1101
  (bnc#1012628).
- USB: serial: option: adding support for YUGA CLM920-NC5
  (bnc#1012628).
- usb: Add device quirk for Logitech HD Pro Webcam C925e
  (bnc#1012628).
- usb: add RESET_RESUME for ELSA MicroLink 56K (bnc#1012628).
- USB: Fix off by one in type-specific length check of BOS SSP
  capability (bnc#1012628).
- usb: xhci: Add XHCI_TRUST_TX_LENGTH for Renesas uPD720201
  (bnc#1012628).
- timers: Use deferrable base independent of base::nohz_active
  (bnc#1012628).
- timers: Invoke timer_start_debug() where it makes sense
  (bnc#1012628).
- timers: Reinitialize per cpu bases on hotplug (bnc#1012628).
- binder: fix proc->files use-after-free (bnc#1012628).
- phy: tegra: fix device-tree node lookups (bnc#1012628).
- drivers: base: cacheinfo: fix cache type for non-architected
  system cache (bnc#1012628).
- staging: android: ion: Fix dma direction for
  dma_sync_sg_for_cpu/device (bnc#1012628).
- nohz: Prevent a timer interrupt storm in
  tick_nohz_stop_sched_tick() (bnc#1012628).
- x86/smpboot: Remove stale TLB flush invocations (bnc#1012628).
- x86/mm: Remove preempt_disable/enable() from
  __native_flush_tlb() (bnc#1012628).
- x86-32: Fix kexec with stack canary (CONFIG_CC_STACKPROTECTOR)
  (bnc#1012628).
- x86/espfix/64: Fix espfix double-fault handling on 5-level
  systems (bnc#1012628).
- x86/ldt: Plug memory leak in error path (bnc#1012628).
- x86/ldt: Make LDT pgtable free conditional (bnc#1012628).
- n_tty: fix EXTPROC vs ICANON interaction with TIOCINQ (aka
  FIONREAD) (bnc#1012628).
- tty: fix tty_ldisc_receive_buf() documentation (bnc#1012628).
- Update config files.
- commit 58fec0f
* Wed Jan  3 2018 jeffm@suse.com
- config: x86, PAGE_TABLE_ISOLATION=y (bsc#1068032).
- commit 4343d87
* Tue Jan  2 2018 jslaby@suse.cz
- userns: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- udf: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- net: mpls: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- fs: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- ipv6: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- ipv4: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- Thermal/int340x: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- cw1200: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- qla2xxx: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- p54: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- carl9170: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- uvcvideo: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- x86, bpf, jit: prevent speculative execution when JIT is enabled
  (bnc#1068032 CVE-2017-5753).
- bpf: prevent speculative execution in eBPF interpreter
  (bnc#1068032 CVE-2017-5753).
- locking/barriers: introduce new observable speculation barrier
  (bnc#1068032 CVE-2017-5753).
- x86/cpu/AMD: Remove now unused definition of MFENCE_RDTSC
  feature (bnc#1068032 CVE-2017-5753).
- x86/cpu/AMD: Make the LFENCE instruction serialized (bnc#1068032
  CVE-2017-5753).
- commit ee4aa62
* Tue Jan  2 2018 jeffm@suse.com
- Update to 4.15-rc6.
- Config changes:
  - x86: PAGE_TABLE_ISOLATION=n (default, performance)
- commit cd70bd8
* Mon Jan  1 2018 jslaby@suse.cz
- Update config files.
- i386: NR_CPUS 128->64
  - 7bbcbd3d1cd (x86/Kconfig: Limit NR_CPUS on 32-bit to a sane
    amount)
- commit 69201cf
* Fri Dec 29 2017 jslaby@suse.cz
- Linux 4.14.10 (bnc#1012628).
- Revert "ipmi_si: fix memory leak on new_smi" (bnc#1012628).
- net: mvneta: eliminate wrong call to handle rx descriptor error
  (bnc#1012628).
- net: mvneta: use proper rxq_number in loop on rx queues
  (bnc#1012628).
- net: mvneta: clear interface link status on port disable
  (bnc#1012628).
- libnvdimm, pfn: fix start_pad handling for aligned namespaces
  (bnc#1012628).
- libnvdimm, btt: Fix an incompatibility in the log layout
  (bnc#1012628).
- libnvdimm, dax: fix 1GB-aligned namespaces vs physical
  misalignment (bnc#1012628).
- drm/sun4i: Fix error path handling (bnc#1012628).
- drm/i915: Flush pending GTT writes before unbinding
  (bnc#1012628).
- powerpc/perf: Dereference BHRB entries safely (bnc#1012628).
- clk: sunxi: sun9i-mmc: Implement reset callback for reset
  controls (bnc#1012628).
- kvm: x86: fix RSM when PCID is non-zero (bnc#1012628).
- KVM: X86: Fix load RFLAGS w/o the fixed bit (bnc#1012628).
- KVM: MMU: Fix infinite loop when there is no available mmu page
  (bnc#1012628).
- KVM: PPC: Book3S HV: Fix pending_pri value in
  kvmppc_xive_get_icp() (bnc#1012628).
- KVM: PPC: Book3S: fix XIVE migration of pending interrupts
  (bnc#1012628).
- KVM: arm/arm64: Fix HYP unmapping going off limits
  (bnc#1012628).
- arm64: kvm: Prevent restoring stale PMSCR_EL1 for vcpu
  (bnc#1012628).
- pinctrl: cherryview: Mask all interrupts on Intel_Strago based
  systems (bnc#1012628).
- spi: a3700: Fix clk prescaling for coefficient over 15
  (bnc#1012628).
- spi: xilinx: Detect stall with Unknown commands (bnc#1012628).
- Revert "parisc: Re-enable interrupts early" (bnc#1012628).
- parisc: Hide Diva-built-in serial aux and graphics card
  (bnc#1012628).
- parisc: Fix indenting in puts() (bnc#1012628).
- parisc: Align os_hpmc_size on word boundary (bnc#1012628).
- block-throttle: avoid double charge (bnc#1012628).
- block: unalign call_single_data in struct request (bnc#1012628).
- PCI / PM: Force devices to D0 in pci_pm_thaw_noirq()
  (bnc#1012628).
- ALSA: usb-audio: Fix the missing ctl name suffix at parsing SU
  (bnc#1012628).
- ALSA: usb-audio: Add native DSD support for Esoteric D-05X
  (bnc#1012628).
- ALSA: hda - Add vendor id for Cannonlake HDMI codec
  (bnc#1012628).
- ALSA: hda/realtek - Fix Dell AIO LineOut issue (bnc#1012628).
- ALSA: rawmidi: Avoid racy info ioctl via ctl device
  (bnc#1012628).
- mfd: twl6040: Fix child-node lookup (bnc#1012628).
- mfd: twl4030-audio: Fix sibling-node lookup (bnc#1012628).
- mfd: cros ec: spi: Don't send first message too soon
  (bnc#1012628).
- crypto: af_alg - fix race accessing cipher request
  (bnc#1012628).
- crypto: af_alg - wait for data at beginning of recvmsg
  (bnc#1012628).
- crypto: mcryptd - protect the per-CPU queue with a lock
  (bnc#1012628).
- crypto: skcipher - set walk.iv for zero-length inputs
  (bnc#1012628).
- acpi, nfit: fix health event notification (bnc#1012628).
- ACPI: APEI / ERST: Fix missing error handling in erst_reader()
  (bnc#1012628).
- x86/cpu_entry_area: Prevent wraparound in
  setup_cpu_entry_area_ptes() on 32bit (bnc#1012628).
- init: Invoke init_espfix_bsp() from mm_init() (bnc#1012628).
- x86/cpu_entry_area: Move it out of the fixmap (bnc#1012628).
- x86/cpu_entry_area: Move it to a separate unit (bnc#1012628).
- x86/mm: Create asm/invpcid.h (bnc#1012628).
- x86/mm: Put MMU to hardware ASID translation in one place
  (bnc#1012628).
- x86/mm: Remove hard-coded ASID limit checks (bnc#1012628).
- x86/mm: Move the CR3 construction functions to tlbflush.h
  (bnc#1012628).
- x86/mm: Add comments to clarify which TLB-flush functions are
  supposed to flush what (bnc#1012628).
- x86/mm: Remove superfluous barriers (bnc#1012628).
- x86/mm: Use __flush_tlb_one() for kernel memory (bnc#1012628).
- x86/microcode: Dont abuse the TLB-flush interface (bnc#1012628).
- x86/uv: Use the right TLB-flush API (bnc#1012628).
- x86/entry: Rename SYSENTER_stack to CPU_ENTRY_AREA_entry_stack
  (bnc#1012628).
- x86/doc: Remove obvious weirdnesses from the x86 MM layout
  documentation (bnc#1012628).
- x86/mm/64: Improve the memory map documentation (bnc#1012628).
- x86/ldt: Prevent LDT inheritance on exec (bnc#1012628).
- x86/ldt: Rework locking (bnc#1012628).
- arch, mm: Allow arch_dup_mmap() to fail (bnc#1012628).
- x86/vsyscall/64: Warn and fail vsyscall emulation in NATIVE mode
  (bnc#1012628).
- x86/vsyscall/64: Explicitly set _PAGE_USER in the pagetable
  hierarchy (bnc#1012628).
- x86/mm/dump_pagetables: Make the address hints correct and
  readable (bnc#1012628).
- x86/mm/dump_pagetables: Check PAGE_PRESENT for real
  (bnc#1012628).
- x86/Kconfig: Limit NR_CPUS on 32-bit to a sane amount
  (bnc#1012628).
- x86/insn-eval: Add utility functions to get segment selector
  (bnc#1012628).
- x86/decoder: Fix and update the opcodes map (bnc#1012628).
- objtool: Fix 64-bit build on 32-bit host (bnc#1012628).
- tools/headers: Sync objtool UAPI header (bnc#1012628).
- objtool: Fix cross-build (bnc#1012628).
- objtool: Move kernel headers/code sync check to a script
  (bnc#1012628).
- objtool: Move synced files to their original relative locations
  (bnc#1012628).
- Revert "ipv6: grab rt->rt6i_ref before allocating pcpu rt"
  (bnc#1012628).
- commit a9b9f85
* Mon Dec 25 2017 jslaby@suse.cz
- Linux 4.14.9 (bnc#1012628).
- x86/asm: Remove unnecessary \n\t in front of CC_SET() from
  asm templates (bnc#1012628).
- ACPI / APEI: adjust a local variable type in
  ghes_ioremap_pfn_irq() (bnc#1012628).
- x86/fpu/debug: Remove unused 'x86_fpu_state' and
  'x86_fpu_deactivate_state' tracepoints (bnc#1012628).
- bitops: Add clear/set_bit32() to linux/bitops.h (bnc#1012628).
- x86/cpuid: Add generic table for CPUID dependencies
  (bnc#1012628).
- x86/fpu: Parse clearcpuid= as early XSAVE argument
  (bnc#1012628).
- x86/fpu: Make XSAVE check the base CPUID features before
  enabling (bnc#1012628).
- x86/fpu: Remove the explicit clearing of XSAVE dependent
  features (bnc#1012628).
- x86/platform/UV: Convert timers to use timer_setup()
  (bnc#1012628).
- x86/cpuid: Prevent out of bound access in do_clear_cpu_cap()
  (bnc#1012628).
- mm/sparsemem: Allocate mem_section at runtime for
  CONFIG_SPARSEMEM_EXTREME=y (bnc#1012628).
- x86/kasan: Use the same shadow offset for 4- and 5-level paging
  (bnc#1012628).
- x86/xen: Provide pre-built page tables only for CONFIG_XEN_PV=y
  and CONFIG_XEN_PVH=y (bnc#1012628).
- x86/xen: Drop 5-level paging support code from the XEN_PV code
  (bnc#1012628).
- ACPI / APEI: remove the unused dead-code for SEA/NMI
  notification type (bnc#1012628).
- x86/asm: Don't use the confusing '.ifeq' directive
  (bnc#1012628).
- x86/build: Beautify build log of syscall headers (bnc#1012628).
- x86/mm/64: Rename the register_page_bootmem_memmap() 'size'
  parameter to 'nr_pages' (bnc#1012628).
- x86/cpufeatures: Enable new SSE/AVX/AVX512 CPU features
  (bnc#1012628).
- x86/mm: Relocate page fault error codes to traps.h
  (bnc#1012628).
- x86/boot: Relocate definition of the initial state of CR0
  (bnc#1012628).
- ptrace,x86: Make user_64bit_mode() available to 32-bit builds
  (bnc#1012628).
- x86/entry/64: Remove the restore_c_regs_and_iret label
  (bnc#1012628).
- x86/entry/64: Split the IRET-to-user and IRET-to-kernel paths
  (bnc#1012628).
- x86/entry/64: Move SWAPGS into the common IRET-to-usermode path
  (bnc#1012628).
- x86/entry/64: Simplify reg restore code in the standard IRET
  paths (bnc#1012628).
- x86/entry/64: Shrink paranoid_exit_restore and make labels local
  (bnc#1012628).
- x86/entry/64: Use pop instead of movq in
  syscall_return_via_sysret (bnc#1012628).
- x86/entry/64: Merge the fast and slow SYSRET paths
  (bnc#1012628).
- x86/entry/64: Use POP instead of MOV to restore regs on NMI
  return (bnc#1012628).
- x86/entry/64: Remove the RESTORE_..._REGS infrastructure
  (bnc#1012628).
- xen, x86/entry/64: Add xen NMI trap entry (bnc#1012628).
- x86/entry/64: De-Xen-ify our NMI code (bnc#1012628).
- x86/entry/32: Pull the MSR_IA32_SYSENTER_CS update code out
  of native_load_sp0() (bnc#1012628).
- x86/entry/64: Pass SP0 directly to load_sp0() (bnc#1012628).
- x86/entry: Add task_top_of_stack() to find the top of a task's
  stack (bnc#1012628).
- x86/xen/64, x86/entry/64: Clean up SP code in
  cpu_initialize_context() (bnc#1012628).
- x86/entry/64: Stop initializing TSS.sp0 at boot (bnc#1012628).
- x86/entry/64: Remove all remaining direct thread_struct::sp0
  reads (bnc#1012628).
- x86/entry/32: Fix cpu_current_top_of_stack initialization at
  boot (bnc#1012628).
- x86/entry/64: Remove thread_struct::sp0 (bnc#1012628).
- x86/traps: Use a new on_thread_stack() helper to clean up an
  assertion (bnc#1012628).
- x86/entry/64: Shorten TEST instructions (bnc#1012628).
- x86/cpuid: Replace set/clear_bit32() (bnc#1012628).
- bitops: Revert cbe96375025e ("bitops: Add clear/set_bit32()
  to linux/bitops.h") (bnc#1012628).
- x86/mm: Define _PAGE_TABLE using _KERNPG_TABLE (bnc#1012628).
- x86/cpufeatures: Re-tabulate the X86_FEATURE definitions
  (bnc#1012628).
- x86/cpufeatures: Fix various details in the feature definitions
  (bnc#1012628).
- selftests/x86/ldt_gdt: Add infrastructure to test
  set_thread_area() (bnc#1012628).
- selftests/x86/ldt_gdt: Run most existing LDT test cases against
  the GDT as well (bnc#1012628).
- ACPI / APEI: Replace ioremap_page_range() with fixmap
  (bnc#1012628).
- x86/virt, x86/platform: Merge 'struct x86_hyper' into 'struct
  x86_platform' and 'struct x86_init' (bnc#1012628).
- x86/virt: Add enum for hypervisors to replace x86_hyper
  (bnc#1012628).
- drivers/misc/intel/pti: Rename the header file to free up the
  namespace (bnc#1012628).
- x86/cpufeature: Add User-Mode Instruction Prevention definitions
  (bnc#1012628).
- x86: Make X86_BUG_FXSAVE_LEAK detectable in CPUID on AMD
  (bnc#1012628).
- perf/x86: Enable free running PEBS for REGS_USER/INTR
  (bnc#1012628).
- bpf: fix build issues on um due to mising bpf_perf_event.h
  (bnc#1012628).
- locking/barriers: Add implicit smp_read_barrier_depends()
  to READ_ONCE() (bnc#1012628).
- locking/barriers: Convert users of lockless_dereference()
  to READ_ONCE() (bnc#1012628).
- x86/mm/kasan: Don't use vmemmap_populate() to initialize shadow
  (bnc#1012628).
- x86/entry/64/paravirt: Use paravirt-safe macro to access eflags
  (bnc#1012628).
- x86/unwinder/orc: Dont bail on stack overflow (bnc#1012628).
- x86/unwinder: Handle stack overflows more gracefully
  (bnc#1012628).
- x86/irq: Remove an old outdated comment about context tracking
  races (bnc#1012628).
- x86/irq/64: Print the offending IP in the stack overflow warning
  (bnc#1012628).
- x86/entry/64: Allocate and enable the SYSENTER stack
  (bnc#1012628).
- x86/dumpstack: Add get_stack_info() support for the SYSENTER
  stack (bnc#1012628).
- x86/entry/gdt: Put per-CPU GDT remaps in ascending order
  (bnc#1012628).
- x86/mm/fixmap: Generalize the GDT fixmap mechanism, introduce
  struct cpu_entry_area (bnc#1012628).
- x86/kasan/64: Teach KASAN about the cpu_entry_area
  (bnc#1012628).
- x86/entry: Fix assumptions that the HW TSS is at the beginning
  of cpu_tss (bnc#1012628).
- x86/dumpstack: Handle stack overflow on all stacks
  (bnc#1012628).
- x86/entry: Move SYSENTER_stack to the beginning of struct
  tss_struct (bnc#1012628).
- x86/entry: Remap the TSS into the CPU entry area (bnc#1012628).
- x86/entry/64: Separate cpu_current_top_of_stack from TSS.sp0
  (bnc#1012628).
- x86/espfix/64: Stop assuming that pt_regs is on the entry stack
  (bnc#1012628).
- x86/entry/64: Use a per-CPU trampoline stack for IDT entries
  (bnc#1012628).
- x86/entry/64: Return to userspace from the trampoline stack
  (bnc#1012628).
- x86/entry/64: Create a per-CPU SYSCALL entry trampoline
  (bnc#1012628).
- x86/entry/64: Move the IST stacks into struct cpu_entry_area
  (bnc#1012628).
- x86/entry/64: Remove the SYSENTER stack canary (bnc#1012628).
- x86/entry: Clean up the SYSENTER_stack code (bnc#1012628).
- x86/entry/64: Make cpu_entry_area.tss read-only (bnc#1012628).
- x86/paravirt: Dont patch flush_tlb_single (bnc#1012628).
- x86/paravirt: Provide a way to check for hypervisors
  (bnc#1012628).
- x86/cpufeatures: Make CPU bugs sticky (bnc#1012628).
- optee: fix invalid of_node_put() in optee_driver_init()
  (bnc#1012628).
- backlight: pwm_bl: Fix overflow condition (bnc#1012628).
- drm: Add retries for lspcon mode detection (bnc#1012628).
- clk: sunxi-ng: nm: Check if requested rate is supported by
  fractional clock (bnc#1012628).
- clk: sunxi-ng: sun5i: Fix bit offset of audio PLL post-divider
  (bnc#1012628).
- crypto: crypto4xx - increase context and scatter ring buffer
  elements (bnc#1012628).
- crypto: lrw - Fix an error handling path in 'create()'
  (bnc#1012628).
- rtc: pl031: make interrupt optional (bnc#1012628).
- kvm, mm: account kvm related kmem slabs to kmemcg (bnc#1012628).
- net: phy: at803x: Change error to EINVAL for invalid MAC
  (bnc#1012628).
- PCI: Avoid bus reset if bridge itself is broken (bnc#1012628).
- scsi: cxgb4i: fix Tx skb leak (bnc#1012628).
- scsi: mpt3sas: Fix IO error occurs on pulling out a drive from
  RAID1 volume created on two SATA drive (bnc#1012628).
- PCI: Create SR-IOV virtfn/physfn links before attaching driver
  (bnc#1012628).
- PM / OPP: Move error message to debug level (bnc#1012628).
- igb: check memory allocation failure (bnc#1012628).
- i40e: use the safe hash table iterator when deleting mac filters
  (bnc#1012628).
- iio: st_sensors: add register mask for status register
  (bnc#1012628).
- ixgbe: fix use of uninitialized padding (bnc#1012628).
- IB/rxe: check for allocation failure on elem (bnc#1012628).
- block,bfq: Disable writeback throttling (bnc#1012628).
- md: always set THREAD_WAKEUP and wake up wqueue if thread
  existed (bnc#1012628).
- ip_gre: check packet length and mtu correctly in erspan tx
  (bnc#1012628).
- ipv6: grab rt->rt6i_ref before allocating pcpu rt (bnc#1012628).
- leds: pca955x: Don't invert requested value in
  pca955x_gpio_set_value() (bnc#1012628).
- Bluetooth: hci_uart_set_flow_control: Fix NULL deref when
  using serdev (bnc#1012628).
- Bluetooth: hci_bcm: Fix setting of irq trigger type
  (bnc#1012628).
- i40e/i40evf: spread CPU affinity hints across online CPUs only
  (bnc#1012628).
- PCI/AER: Report non-fatal errors only to the affected endpoint
  (bnc#1012628).
- tracing: Exclude 'generic fields' from histograms (bnc#1012628).
- ASoC: codecs: msm8916-wcd-analog: fix micbias level
  (bnc#1012628).
- ASoC: img-parallel-out: Add pm_runtime_get/put to set_fmt
  callback (bnc#1012628).
- powerpc/xmon: Avoid tripping SMP hardlockup watchdog
  (bnc#1012628).
- powerpc/watchdog: Do not trigger SMP crash from
  touch_nmi_watchdog (bnc#1012628).
- sctp: silence warns on sctp_stream_init allocations
  (bnc#1012628).
- ASoC: codecs: msm8916-wcd-analog: fix module autoload
  (bnc#1012628).
- fm10k: fix mis-ordered parameters in declaration for
  .ndo_set_vf_bw (bnc#1012628).
- scsi: lpfc: Fix secure firmware updates (bnc#1012628).
- scsi: lpfc: PLOGI failures during NPIV testing (bnc#1012628).
- scsi: lpfc: Fix warning messages when NVME_TARGET_FC not defined
  (bnc#1012628).
- i40e: fix client notify of VF reset (bnc#1012628).
- vfio/pci: Virtualize Maximum Payload Size (bnc#1012628).
- ARM: exynos_defconfig: Enable UAS support for Odroid HC1 board
  (bnc#1012628).
- fm10k: ensure we process SM mbx when processing VF mbx
  (bnc#1012628).
- ibmvnic: Set state UP (bnc#1012628).
- net: ipv6: send NS for DAD when link operationally up
  (bnc#1012628).
- RDMA/hns: Avoid NULL pointer exception (bnc#1012628).
- staging: greybus: light: Release memory obtained by kasprintf
  (bnc#1012628).
- clk: sunxi-ng: sun6i: Rename HDMI DDC clock to avoid name
  collision (bnc#1012628).
- tcp: fix under-evaluated ssthresh in TCP Vegas (bnc#1012628).
- rtc: set the alarm to the next expiring timer (bnc#1012628).
- cpuidle: fix broadcast control when broadcast can not be entered
  (bnc#1012628).
- drm/vc4: Avoid using vrefresh==0 mode in DSI htotal math
  (bnc#1012628).
- IB/opa_vnic: Properly clear Mac Table Digest (bnc#1012628).
- IB/opa_vnic: Properly return the total MACs in UC MAC list
  (bnc#1012628).
- thermal/drivers/hisi: Fix missing interrupt enablement
  (bnc#1012628).
- thermal/drivers/hisi: Fix kernel panic on alarm interrupt
  (bnc#1012628).
- thermal/drivers/hisi: Simplify the temperature/step computation
  (bnc#1012628).
- thermal/drivers/hisi: Fix multiple alarm interrupts firing
  (bnc#1012628).
- platform/x86: asus-wireless: send an EV_SYN/SYN_REPORT between
  state changes (bnc#1012628).
- mm/sparsemem: Fix ARM64 boot crash when
  CONFIG_SPARSEMEM_EXTREME=y (bnc#1012628).
- bpf: fix branch pruning logic (bnc#1012628).
- bpf: fix corruption on concurrent perf_event_output calls
  (bnc#1012628).
- bpf, s390x: do not reload skb pointers in non-skb context
  (bnc#1012628).
- bpf, ppc64: do not reload skb pointers in non-skb context
  (bnc#1012628).
- bpf, sparc: fix usage of wrong reg for load_skb_regs after call
  (bnc#1012628).
- bpf/verifier: fix bounds calculation on BPF_RSH (bnc#1012628).
- bpf: fix incorrect sign extension in check_alu_op()
  (bnc#1012628).
- bpf: fix incorrect tracking of register size truncation
  (bnc#1012628).
- bpf: fix 32-bit ALU op verification (bnc#1012628).
- bpf: fix missing error return in check_stack_boundary()
  (bnc#1012628).
- bpf: force strict alignment checks for stack pointers
  (bnc#1012628).
- bpf: don't prune branches when a scalar is replaced with a
  pointer (bnc#1012628).
- bpf: fix integer overflows (bnc#1012628).
- selftests/bpf: add tests for recent bugfixes (bnc#1012628).
- linux/compiler.h: Split into compiler.h and compiler_types.h
  (bnc#1012628).
- Refresh patches.suse/dm-mpath-accept-failed-paths.
- Refresh patches.suse/suse-hv-guest-os-id.patch.
- commit 9423ca2
* Mon Dec 25 2017 jeffm@suse.com
- config: disable BUG_ON_DATA_CORRUPTION
  On its face this option makes sense but it brings along with it
  DEBUG_LIST, which is very expensive and obvious on benchmarks.
- commit 7bfff34
* Mon Dec 25 2017 jeffm@suse.com
- config: refresh i386/default
  Commit 4735d41aeeb added a disabled CONFIG_SPI_INTEL_SPI_PLATFORM option
  that doesn't exist on i386/default (at least in 4.15-rc5).
- commit 84167ae
* Sun Dec 24 2017 jeffm@suse.com
- Update to 4.15-rc5.
- Config changes:
  - i386: NR_CPUS 128->64
  - 7bbcbd3d1cd (x86/Kconfig: Limit NR_CPUS on 32-bit to a sane amount)
- commit 9e8deb3
* Thu Dec 21 2017 msuchanek@suse.de
- kernel-obs-build: use pae and lpae kernels where available
  (bsc#1073579).
- commit 1ac1946
* Thu Dec 21 2017 tiwai@suse.de
- Disable CONFIG_SPI_INTEL_SPI_PCI as well (bsc#1073836)
- commit ddb33b2
* Thu Dec 21 2017 tiwai@suse.de
- Disable CONFIG_SPI_INTEL_SPI_PLATFORM for BIOS breakge on Lenovo laptops
  (bsc#1073836)
- commit 4735d41
* Wed Dec 20 2017 jslaby@suse.cz
- Linux 4.14.8 (bnc#1012628).
- mfd: fsl-imx25: Clean up irq settings during removal
  (bnc#1012628).
- crypto: algif_aead - fix reference counting of null skcipher
  (bnc#1012628).
- crypto: rsa - fix buffer overread when stripping leading zeroes
  (bnc#1012628).
- crypto: hmac - require that the underlying hash algorithm is
  unkeyed (bnc#1012628).
- crypto: salsa20 - fix blkcipher_walk API usage (bnc#1012628).
- crypto: af_alg - fix NULL pointer dereference in (bnc#1012628).
- cifs: fix NULL deref in SMB2_read (bnc#1012628).
- string.h: workaround for increased stack usage (bnc#1012628).
- autofs: fix careless error in recent commit (bnc#1012628).
- kernel: make groups_sort calling a responsibility group_info
  allocators (bnc#1012628).
- mm, oom_reaper: fix memory corruption (bnc#1012628).
- tracing: Allocate mask_str buffer dynamically (bnc#1012628).
- USB: uas and storage: Add US_FL_BROKEN_FUA for another JMicron
  JMS567 ID (bnc#1012628).
- USB: core: prevent malicious bNumInterfaces overflow
  (bnc#1012628).
- ovl: Pass ovl_get_nlink() parameters in right order
  (bnc#1012628).
- ovl: update ctx->pos on impure dir iteration (bnc#1012628).
- usbip: fix stub_rx: get_pipe() to validate endpoint number
  (bnc#1012628).
- usbip: fix stub_rx: harden CMD_SUBMIT path to handle malicious
  input (bnc#1012628).
- usbip: prevent vhci_hcd driver from leaking a socket pointer
  address (bnc#1012628).
- usbip: fix stub_send_ret_submit() vulnerability to null
  transfer_buffer (bnc#1012628).
- mmc: core: apply NO_CMD23 quirk to some specific cards
  (bnc#1012628).
- ceph: drop negative child dentries before try pruning inode's
  alias (bnc#1012628).
- usb: xhci: fix TDS for MTK xHCI1.1 (bnc#1012628).
- xhci: Don't add a virt_dev to the devs array before it's fully
  allocated (bnc#1012628).
- IB/core: Bound check alternate path port number (bnc#1012628).
- IB/core: Don't enforce PKey security on SMI MADs (bnc#1012628).
- nfs: don't wait on commit in nfs_commit_inode() if there were
  no commit requests (bnc#1012628).
- arm64: mm: Fix pte_mkclean, pte_mkdirty semantics (bnc#1012628).
- arm64: Initialise high_memory global variable earlier
  (bnc#1012628).
- arm64: fix CONFIG_DEBUG_WX address reporting (bnc#1012628).
- scsi: core: Fix a scsi_show_rq() NULL pointer dereference
  (bnc#1012628).
- scsi: libsas: fix length error in sas_smp_handler()
  (bnc#1012628).
- sched/rt: Do not pull from current CPU if only one CPU to pull
  (bnc#1012628).
- dm: fix various targets to dm_register_target after module
  __init resources created (bnc#1012628).
- SUNRPC: Fix a race in the receive code path (bnc#1012628).
- iw_cxgb4: only insert drain cqes if wq is flushed (bnc#1012628).
- x86/boot/compressed/64: Detect and handle 5-level paging at
  boot-time (bnc#1012628).
- x86/boot/compressed/64: Print error if 5-level paging is not
  supported (bnc#1012628).
- eeprom: at24: change nvmem stride to 1 (bnc#1012628).
- posix-timer: Properly check sigevent->sigev_notify
  (bnc#1012628).
- dmaengine: dmatest: move callback wait queue to thread context
  (bnc#1012628).
- Revert "exec: avoid RLIMIT_STACK races with prlimit()"
  (bnc#1012628).
- ext4: support fast symlinks from ext3 file systems
  (bnc#1012628).
- ext4: fix fdatasync(2) after fallocate(2) operation
  (bnc#1012628).
- ext4: add missing error check in __ext4_new_inode()
  (bnc#1012628).
- ext4: fix crash when a directory's i_size is too small
  (bnc#1012628).
- IB/mlx4: Fix RSS's QPC attributes assignments (bnc#1012628).
- HID: cp2112: fix broken gpio_direction_input callback
  (bnc#1012628).
- sfc: don't warn on successful change of MAC (bnc#1012628).
- fbdev: controlfb: Add missing modes to fix out of bounds access
  (bnc#1012628).
- video: udlfb: Fix read EDID timeout (bnc#1012628).
- video: fbdev: au1200fb: Release some resources if a memory
  allocation fails (bnc#1012628).
- video: fbdev: au1200fb: Return an error code if a memory
  allocation fails (bnc#1012628).
- rtc: pcf8563: fix output clock rate (bnc#1012628).
- scsi: aacraid: use timespec64 instead of timeval (bnc#1012628).
- drm/amdgpu: bypass lru touch for KIQ ring submission
  (bnc#1012628).
- PM / s2idle: Clear the events_check_enabled flag (bnc#1012628).
- ASoC: Intel: Skylake: Fix uuid_module memory leak in failure
  case (bnc#1012628).
- dmaengine: ti-dma-crossbar: Correct am335x/am43xx mux value type
  (bnc#1012628).
- mlxsw: spectrum: Fix error return code in mlxsw_sp_port_create()
  (bnc#1012628).
- PCI/PME: Handle invalid data when reading Root Status
  (bnc#1012628).
- powerpc/powernv/cpufreq: Fix the frequency read by /proc/cpuinfo
  (bnc#1012628).
- PCI: Do not allocate more buses than available in parent
  (bnc#1012628).
- iommu/mediatek: Fix driver name (bnc#1012628).
- thunderbolt: tb: fix use after free in tb_activate_pcie_devices
  (bnc#1012628).
- netfilter: ipvs: Fix inappropriate output of procfs
  (bnc#1012628).
- powerpc/opal: Fix EBUSY bug in acquiring tokens (bnc#1012628).
- powerpc/ipic: Fix status get and status clear (bnc#1012628).
- powerpc/pseries/vio: Dispose of virq mapping on vdevice
  unregister (bnc#1012628).
- platform/x86: intel_punit_ipc: Fix resource ioremap warning
  (bnc#1012628).
- target/iscsi: Detect conn_cmd_list corruption early
  (bnc#1012628).
- target/iscsi: Fix a race condition in
  iscsit_add_reject_from_cmd() (bnc#1012628).
- iscsi-target: fix memory leak in lio_target_tiqn_addtpg()
  (bnc#1012628).
- target:fix condition return in core_pr_dump_initiator_port()
  (bnc#1012628).
- target/file: Do not return error for UNMAP if length is zero
  (bnc#1012628).
- badblocks: fix wrong return value in badblocks_set if badblocks
  are disabled (bnc#1012628).
- iommu/amd: Limit the IOVA page range to the specified addresses
  (bnc#1012628).
- xfs: truncate pagecache before writeback in xfs_setattr_size()
  (bnc#1012628).
- arm-ccn: perf: Prevent module unload while PMU is in use
  (bnc#1012628).
- crypto: tcrypt - fix buffer lengths in test_aead_speed()
  (bnc#1012628).
- mm: Handle 0 flags in _calc_vm_trans() macro (bnc#1012628).
- net: hns3: fix for getting advertised_caps in
  hns3_get_link_ksettings (bnc#1012628).
- net: hns3: Fix a misuse to devm_free_irq (bnc#1012628).
- staging: rtl8188eu: Revert part of "staging: rtl8188eu: fix
  comments with lines over 80 characters" (bnc#1012628).
- clk: mediatek: add the option for determining PLL source clock
  (bnc#1012628).
- clk: imx: imx7d: Fix parent clock for OCRAM_CLK (bnc#1012628).
- clk: imx6: refine hdmi_isfr's parent to make HDMI work on
  i.MX6 SoCs w/o VPU (bnc#1012628).
- media: camss-vfe: always initialize reg at vfe_set_xbar_cfg()
  (bnc#1012628).
- clk: hi6220: mark clock cs_atb_syspll as critical (bnc#1012628).
- blk-mq-sched: dispatch from scheduler IFF progress is made in
  - >dispatch (bnc#1012628).
- clk: tegra: Use readl_relaxed_poll_timeout_atomic() in
  tegra210_clock_init() (bnc#1012628).
- clk: tegra: Fix cclk_lp divisor register (bnc#1012628).
- ppp: Destroy the mutex when cleanup (bnc#1012628).
- ASoC: rsnd: rsnd_ssi_run_mods() needs to care ssi_parent_mod
  (bnc#1012628).
- thermal/drivers/step_wise: Fix temperature regulation
  misbehavior (bnc#1012628).
- misc: pci_endpoint_test: Fix failure path return values in probe
  (bnc#1012628).
- misc: pci_endpoint_test: Avoid triggering a BUG() (bnc#1012628).
- scsi: scsi_debug: write_same: fix error report (bnc#1012628).
- GFS2: Take inode off order_write list when setting jdata flag
  (bnc#1012628).
- media: usbtv: fix brightness and contrast controls
  (bnc#1012628).
- rpmsg: glink: Initialize the "intent_req_comp" completion
  variable (bnc#1012628).
- bcache: explicitly destroy mutex while exiting (bnc#1012628).
- bcache: fix wrong cache_misses statistics (bnc#1012628).
- Ib/hfi1: Return actual operational VLs in port info query
  (bnc#1012628).
- Bluetooth: hci_ldisc: Fix another race when closing the tty
  (bnc#1012628).
- arm64: prevent regressions in compressed kernel image size
  when upgrading to binutils 2.27 (bnc#1012628).
- btrfs: fix false EIO for missing device (bnc#1012628).
- btrfs: Explicitly handle btrfs_update_root failure
  (bnc#1012628).
- btrfs: undo writable superblocke when sprouting fails
  (bnc#1012628).
- btrfs: avoid null pointer dereference on fs_info when calling
  btrfs_crit (bnc#1012628).
- btrfs: tests: Fix a memory leak in error handling path in
  'run_test()' (bnc#1012628).
- qtnfmac: modify full Tx queue error reporting (bnc#1012628).
- mtd: spi-nor: stm32-quadspi: Fix uninitialized error return code
  (bnc#1012628).
- ARM64: dts: meson-gxbb-odroidc2: fix usb1 power supply
  (bnc#1012628).
- Bluetooth: btusb: Add new NFA344A entry (bnc#1012628).
- samples/bpf: adjust rlimit RLIMIT_MEMLOCK for xdp1
  (bnc#1012628).
- liquidio: fix kernel panic in VF driver (bnc#1012628).
- platform/x86: hp_accel: Add quirk for HP ProBook 440 G4
  (bnc#1012628).
- nvme: use kref_get_unless_zero in nvme_find_get_ns
  (bnc#1012628).
- l2tp: cleanup l2tp_tunnel_delete calls (bnc#1012628).
- xfs: fix log block underflow during recovery cycle verification
  (bnc#1012628).
- xfs: return a distinct error code value for IGET_INCORE cache
  misses (bnc#1012628).
- xfs: fix incorrect extent state in
  xfs_bmap_add_extent_unwritten_real (bnc#1012628).
- net: dsa: lan9303: Do not disable switch fabric port 0 at .probe
  (bnc#1012628).
- net: hns3: fix a bug in hclge_uninit_client_instance
  (bnc#1012628).
- net: hns3: add nic_client check when initialize roce base
  information (bnc#1012628).
- net: hns3: fix the bug of hns3_set_txbd_baseinfo (bnc#1012628).
- RDMA/cxgb4: Declare stag as __be32 (bnc#1012628).
- PCI: Detach driver before procfs & sysfs teardown on device
  remove (bnc#1012628).
- scsi: hisi_sas: fix the risk of freeing slot twice
  (bnc#1012628).
- scsi: hpsa: cleanup sas_phy structures in sysfs when unloading
  (bnc#1012628).
- scsi: hpsa: destroy sas transport properties before scsi_host
  (bnc#1012628).
- mfd: mxs-lradc: Fix error handling in mxs_lradc_probe()
  (bnc#1012628).
- net: hns3: fix the TX/RX ring.queue_index in hns3_ring_get_cfg
  (bnc#1012628).
- net: hns3: fix the bug when map buffer fail (bnc#1012628).
- net: hns3: fix a bug when alloc new buffer (bnc#1012628).
- serdev: ttyport: enforce tty-driver open() requirement
  (bnc#1012628).
- powerpc/perf/hv-24x7: Fix incorrect comparison in memord
  (bnc#1012628).
- powerpc/xmon: Check before calling xive functions (bnc#1012628).
- soc: mediatek: pwrap: fix compiler errors (bnc#1012628).
- ipv4: ipv4_default_advmss() should use route mtu (bnc#1012628).
- KVM: nVMX: Fix EPT switching advertising (bnc#1012628).
- tty fix oops when rmmod 8250 (bnc#1012628).
- dev/dax: fix uninitialized variable build warning (bnc#1012628).
- pinctrl: adi2: Fix Kconfig build problem (bnc#1012628).
- raid5: Set R5_Expanded on parity devices as well as data
  (bnc#1012628).
- IB/core: Fix use workqueue without WQ_MEM_RECLAIM (bnc#1012628).
- IB/core: Fix calculation of maximum RoCE MTU (bnc#1012628).
- vt6655: Fix a possible sleep-in-atomic bug in vt6655_suspend
  (bnc#1012628).
- IB/hfi1: Mask out A bit from psn trace (bnc#1012628).
- rtl8188eu: Fix a possible sleep-in-atomic bug in
  rtw_createbss_cmd (bnc#1012628).
- rtl8188eu: Fix a possible sleep-in-atomic bug in
  rtw_disassoc_cmd (bnc#1012628).
- nullb: fix error return code in null_init() (bnc#1012628).
- scsi: sd: change manage_start_stop to bool in sysfs interface
  (bnc#1012628).
- scsi: sd: change allow_restart to bool in sysfs interface
  (bnc#1012628).
- scsi: bfa: integer overflow in debugfs (bnc#1012628).
- raid5-ppl: check recovery_offset when performing ppl recovery
  (bnc#1012628).
- md-cluster: fix wrong condition check in raid1_write_request
  (bnc#1012628).
- xprtrdma: Don't defer fencing an async RPC's chunks
  (bnc#1012628).
- udf: Avoid overflow when session starts at large offset
  (bnc#1012628).
- macvlan: Only deliver one copy of the frame to the macvlan
  interface (bnc#1012628).
- IB/core: Fix endianness annotation in rdma_is_multicast_addr()
  (bnc#1012628).
- RDMA/cma: Avoid triggering undefined behavior (bnc#1012628).
- IB/ipoib: Grab rtnl lock on heavy flush when calling
  ndo_open/stop (bnc#1012628).
- icmp: don't fail on fragment reassembly time exceeded
  (bnc#1012628).
- lightnvm: pblk: prevent gc kicks when gc is not operational
  (bnc#1012628).
- lightnvm: pblk: fix changing GC group list for a line
  (bnc#1012628).
- lightnvm: pblk: use right flag for GC allocation (bnc#1012628).
- lightnvm: pblk: initialize debug stat counter (bnc#1012628).
- lightnvm: pblk: fix min size for page mempool (bnc#1012628).
- lightnvm: pblk: protect line bitmap while submitting meta io
  (bnc#1012628).
- ath9k: fix tx99 potential info leak (bnc#1012628).
- ath10k: fix core PCI suspend when WoWLAN is supported but
  disabled (bnc#1012628).
- ath10k: fix build errors with !CONFIG_PM (bnc#1012628).
- usb: musb: da8xx: fix babble condition handling (bnc#1012628).
- commit 674981b
* Tue Dec 19 2017 jeffm@suse.com
- Update to 4.15-rc4.
- Eliminated 1 patch.
- Config changes:
  - ARM:
  - QCOM_FALKOR_ERRATUM_E1041=y
  - Overlayfs:
  - OVERLAY_FS_REDIRECT_ALWAYS_FOLLOW=y (preserves existing behavior)
- commit ff8819c
* Mon Dec 18 2017 jslaby@suse.cz
- Linux 4.14.7 (bnc#1012628).
- net: qmi_wwan: add Quectel BG96 2c7c:0296 (bnc#1012628).
- net: thunderx: Fix TCP/UDP checksum offload for IPv6 pkts
  (bnc#1012628).
- net: thunderx: Fix TCP/UDP checksum offload for IPv4 pkts
  (bnc#1012628).
- net: realtek: r8169: implement set_link_ksettings()
  (bnc#1012628).
- s390/qeth: fix early exit from error path (bnc#1012628).
- tipc: fix memory leak in tipc_accept_from_sock() (bnc#1012628).
- vhost: fix skb leak in handle_rx() (bnc#1012628).
- rds: Fix NULL pointer dereference in __rds_rdma_map
  (bnc#1012628).
- sit: update frag_off info (bnc#1012628).
- tcp: add tcp_v4_fill_cb()/tcp_v4_restore_cb() (bnc#1012628).
- packet: fix crash in fanout_demux_rollover() (bnc#1012628).
- net/packet: fix a race in packet_bind() and packet_notifier()
  (bnc#1012628).
- tcp: remove buggy call to tcp_v6_restore_cb() (bnc#1012628).
- usbnet: fix alignment for frames with no ethernet header
  (bnc#1012628).
- net: remove hlist_nulls_add_tail_rcu() (bnc#1012628).
- stmmac: reset last TSO segment size after device open
  (bnc#1012628).
- tcp/dccp: block bh before arming time_wait timer (bnc#1012628).
- s390/qeth: build max size GSO skbs on L2 devices (bnc#1012628).
- s390/qeth: fix thinko in IPv4 multicast address tracking
  (bnc#1012628).
- s390/qeth: fix GSO throughput regression (bnc#1012628).
- tcp: use IPCB instead of TCP_SKB_CB in inet_exact_dif_match()
  (bnc#1012628).
- tipc: call tipc_rcv() only if bearer is up in tipc_udp_recv()
  (bnc#1012628).
- tcp: use current time in tcp_rcv_space_adjust() (bnc#1012628).
- net: sched: cbq: create block for q->link.block (bnc#1012628).
- tap: free skb if flags error (bnc#1012628).
- tcp: when scheduling TLP, time of RTO should account for
  current ACK (bnc#1012628).
- tun: free skb in early errors (bnc#1012628).
- net: ipv6: Fixup device for anycast routes during copy
  (bnc#1012628).
- tun: fix rcu_read_lock imbalance in tun_build_skb (bnc#1012628).
- net: accept UFO datagrams from tuntap and packet (bnc#1012628).
- net: openvswitch: datapath: fix data type in queue_gso_packets
  (bnc#1012628).
- cls_bpf: don't decrement net's refcount when offload fails
  (bnc#1012628).
- sctp: use right member as the param of list_for_each_entry
  (bnc#1012628).
- ipmi: Stop timers before cleaning up the module (bnc#1012628).
- usb: gadget: ffs: Forbid usb_ep_alloc_request from sleeping
  (bnc#1012628).
- fcntl: don't cap l_start and l_end values for F_GETLK64 in
  compat syscall (bnc#1012628).
- fix kcm_clone() (bnc#1012628).
- KVM: arm/arm64: vgic-its: Preserve the revious read from the
  pending table (bnc#1012628).
- kbuild: do not call cc-option before KBUILD_CFLAGS
  initialization (bnc#1012628).
- powerpc/powernv/idle: Round up latency and residency values
  (bnc#1012628).
- ipvlan: fix ipv6 outbound device (bnc#1012628).
- ide: ide-atapi: fix compile error with defining macro DEBUG
  (bnc#1012628).
- blk-mq: Avoid that request queue removal can trigger list
  corruption (bnc#1012628).
- nvmet-rdma: update queue list during ib_device removal
  (bnc#1012628).
- audit: Allow auditd to set pid to 0 to end auditing
  (bnc#1012628).
- audit: ensure that 'audit=1' actually enables audit for PID 1
  (bnc#1012628).
- dm raid: fix panic when attempting to force a raid to sync
  (bnc#1012628).
- md: free unused memory after bitmap resize (bnc#1012628).
- RDMA/cxgb4: Annotate r2 and stag as __be32 (bnc#1012628).
- x86/intel_rdt: Fix potential deadlock during resctrl unmount
  (bnc#1012628).
- Refresh patches.suse/supported-flag.
- commit 0598608
* Fri Dec 15 2017 jslaby@suse.cz
- x86/stacktrace: make clear the success paths (bnc#1058115).
- Refresh
  patches.suse/0003-x86-stacktrace-remove-STACKTRACE_DUMP_ONCE-from-__sa.patch.
- Refresh
  patches.suse/0004-x86-stacktrace-do-not-fail-for-ORC-with-regs-on-stac.patch.
- Delete
  patches.suse/0002-x86-stacktrace-remove-unwind_state-error.patch.
  Fix livepatch to succeed also for kthreads and idle tasks.
- commit 580e12c
* Thu Dec 14 2017 jslaby@suse.cz
- Linux 4.14.6 (bnc#1012628).
- usb: gadget: udc: renesas_usb3: fix number of the pipes
  (bnc#1012628).
- usb: gadget: core: Fix ->udc_set_speed() speed handling
  (bnc#1012628).
- serdev: ttyport: add missing receive_buf sanity checks
  (bnc#1012628).
- serdev: ttyport: fix NULL-deref on hangup (bnc#1012628).
- serdev: ttyport: fix tty locking in close (bnc#1012628).
- usb: f_fs: Force Reserved1=1 in OS_DESC_EXT_COMPAT
  (bnc#1012628).
- can: mcba_usb: fix device disconnect bug (bnc#1012628).
- can: peak/pci: fix potential bug when probe() fails
  (bnc#1012628).
- can: flexcan: fix VF610 state transition issue (bnc#1012628).
- can: ti_hecc: Fix napi poll return value for repoll
  (bnc#1012628).
- can: kvaser_usb: free buf in error paths (bnc#1012628).
- can: kvaser_usb: Fix comparison bug in
  kvaser_usb_read_bulk_callback() (bnc#1012628).
- can: kvaser_usb: ratelimit errors if incomplete messages are
  received (bnc#1012628).
- can: kvaser_usb: cancel urb on -EPIPE and -EPROTO (bnc#1012628).
- can: mcba_usb: cancel urb on -EPROTO (bnc#1012628).
- can: ems_usb: cancel urb on -EPIPE and -EPROTO (bnc#1012628).
- can: esd_usb2: cancel urb on -EPIPE and -EPROTO (bnc#1012628).
- can: usb_8dev: cancel urb on -EPIPE and -EPROTO (bnc#1012628).
- can: peak/pcie_fd: fix potential bug in restarting tx queue
  (bnc#1012628).
- virtio: release virtio index when fail to device_register
  (bnc#1012628).
- iio: stm32: fix adc/trigger link error (bnc#1012628).
- iio: health: max30102: Temperature should be in milli Celsius
  (bnc#1012628).
- iio: adc: cpcap: fix incorrect validation (bnc#1012628).
- iio: adc: meson-saradc: fix the bit_idx of the adc_en clock
  (bnc#1012628).
- iio: adc: meson-saradc: initialize the bandgap correctly on
  older SoCs (bnc#1012628).
- iio: adc: meson-saradc: Meson8 and Meson8b do not have REG11
  and REG13 (bnc#1012628).
- pinctrl: armada-37xx: Fix direction_output() callback behavior
  (bnc#1012628).
- Drivers: hv: vmbus: Fix a rescind issue (bnc#1012628).
- hv: kvp: Avoid reading past allocated blocks from KVP file
  (bnc#1012628).
- firmware: cleanup FIRMWARE_IN_KERNEL message (bnc#1012628).
- firmware: vpd: Destroy vpd sections in remove function
  (bnc#1012628).
- firmware: vpd: Tie firmware kobject to device lifetime
  (bnc#1012628).
- firmware: vpd: Fix platform driver and device
  registration/unregistration (bnc#1012628).
- isa: Prevent NULL dereference in isa_bus driver callbacks
  (bnc#1012628).
- scsi: dma-mapping: always provide dma_get_cache_alignment
  (bnc#1012628).
- scsi: use dma_get_cache_alignment() as minimum DMA alignment
  (bnc#1012628).
- scsi: libsas: align sata_device's rps_resp on a cacheline
  (bnc#1012628).
- efi: Move some sysfs files to be read-only by root
  (bnc#1012628).
- efi/esrt: Use memunmap() instead of kfree() to free the
  remapping (bnc#1012628).
- ASN.1: fix out-of-bounds read when parsing indefinite length
  item (bnc#1012628).
- ASN.1: check for error from ASN1_OP_END__ACT actions
  (bnc#1012628).
- KEYS: add missing permission check for request_key() destination
  (bnc#1012628).
- KEYS: reject NULL restriction string when type is specified
  (bnc#1012628).
- X.509: reject invalid BIT STRING for subjectPublicKey
  (bnc#1012628).
- X.509: fix comparisons of ->pkey_algo (bnc#1012628).
- x86/idt: Load idt early in start_secondary (bnc#1012628).
- x86/PCI: Make broadcom_postcore_init() check acpi_disabled
  (bnc#1012628).
- KVM: x86: fix APIC page invalidation (bnc#1012628).
- btrfs: fix missing error return in btrfs_drop_snapshot
  (bnc#1012628).
- btrfs: handle errors while updating refcounts in
  update_ref_for_cow (bnc#1012628).
- ALSA: hda/realtek - New codec support for ALC257 (bnc#1012628).
- ALSA: pcm: prevent UAF in snd_pcm_info (bnc#1012628).
- ALSA: seq: Remove spurious WARN_ON() at timer check
  (bnc#1012628).
- ALSA: usb-audio: Fix out-of-bound error (bnc#1012628).
- ALSA: usb-audio: Add check return value for usb_string()
  (bnc#1012628).
- iommu/vt-d: Fix scatterlist offset handling (bnc#1012628).
- smp/hotplug: Move step CPUHP_AP_SMPCFD_DYING to the correct
  place (bnc#1012628).
- s390: always save and restore all registers on context switch
  (bnc#1012628).
- s390/mm: fix off-by-one bug in 5-level page table handling
  (bnc#1012628).
- s390: fix compat system call table (bnc#1012628).
- KVM: s390: Fix skey emulation permission check (bnc#1012628).
- Revert "powerpc: Do not call ppc_md.panic in fadump panic
  notifier" (bnc#1012628).
- powerpc/64s: Initialize ISAv3 MMU registers before setting
  partition table (bnc#1012628).
- iwlwifi: mvm: mark MIC stripped MPDUs (bnc#1012628).
- iwlwifi: mvm: don't use transmit queue hang detection when it
  is not possible (bnc#1012628).
- iwlwifi: mvm: flush queue before deleting ROC (bnc#1012628).
- iwlwifi: add new cards for 9260 and 22000 series (bnc#1012628).
- iwlwifi: mvm: fix packet injection (bnc#1012628).
- iwlwifi: mvm: enable RX offloading with TKIP and WEP
  (bnc#1012628).
- brcmfmac: change driver unbind order of the sdio function
  devices (bnc#1012628).
- kdb: Fix handling of kallsyms_symbol_next() return value
  (bnc#1012628).
- md/r5cache: move mddev_lock() out of r5c_journal_mode_set()
  (bnc#1012628).
- drm/exynos: gem: Drop NONCONTIG flag for buffers allocated
  without IOMMU (bnc#1012628).
- drm/i915: Fix vblank timestamp/frame counter jumps on gen2
  (bnc#1012628).
- media: dvb: i2c transfers over usb cannot be done from stack
  (bnc#1012628).
- media: rc: sir_ir: detect presence of port (bnc#1012628).
- media: rc: partial revert of "media: rc: per-protocol repeat
  period" (bnc#1012628).
- arm64: KVM: fix VTTBR_BADDR_MASK BUG_ON off-by-one
  (bnc#1012628).
- arm: KVM: Fix VTTBR_BADDR_MASK BUG_ON off-by-one (bnc#1012628).
- KVM: VMX: remove I/O port 0x80 bypass on Intel hosts
  (bnc#1012628).
- KVM: arm/arm64: Fix broken GICH_ELRSR big endian conversion
  (bnc#1012628).
- KVM: arm/arm64: vgic-irqfd: Fix MSI entry allocation
  (bnc#1012628).
- KVM: arm/arm64: vgic: Preserve the revious read from the
  pending table (bnc#1012628).
- KVM: arm/arm64: vgic-its: Check result of allocation before use
  (bnc#1012628).
- arm64: fpsimd: Prevent registers leaking from dead tasks
  (bnc#1012628).
- arm64: SW PAN: Point saved ttbr0 at the zero page when switching
  to init_mm (bnc#1012628).
- arm64: SW PAN: Update saved ttbr0 value on enter_lazy_tlb
  (bnc#1012628).
- Revert "ARM: dts: imx53: add srtc node" (bnc#1012628).
- bus: arm-cci: Fix use of smp_processor_id() in preemptible
  context (bnc#1012628).
- bus: arm-ccn: Check memory allocation failure (bnc#1012628).
- bus: arm-ccn: Fix use of smp_processor_id() in preemptible
  context (bnc#1012628).
- bus: arm-ccn: fix module unloading Error: Removing state 147
  which has instances left (bnc#1012628).
- IB/core: Avoid unnecessary return value check (bnc#1012628).
- IB/core: Only enforce security for InfiniBand (bnc#1012628).
- crypto: talitos - fix AEAD test failures (bnc#1012628).
- crypto: talitos - fix memory corruption on SEC2 (bnc#1012628).
- crypto: talitos - fix setkey to check key weakness
  (bnc#1012628).
- crypto: talitos - fix AEAD for sha224 on non sha224 capable
  chips (bnc#1012628).
- crypto: talitos - fix use of sg_link_tbl_len (bnc#1012628).
- crypto: talitos - fix ctr-aes-talitos (bnc#1012628).
- ARM: BUG if jumping to usermode address in kernel mode
  (bnc#1012628).
- ARM: avoid faulting on qemu (bnc#1012628).
- irqchip/qcom: Fix u32 comparison with value less than zero
  (bnc#1012628).
- net/smc: use sk_rcvbuf as start for rmb creation (bnc#1012628).
- kbuild: pkg: use --transform option to prefix paths in tar
  (bnc#1012628).
- coccinelle: fix parallel build with CHECK=scripts/coccicheck
  (bnc#1012628).
- powerpc/perf: Fix pmu_count to count only nest imc pmus
  (bnc#1012628).
- apparmor: fix leak of null profile name if profile allocation
  fails (bnc#1012628).
- x86/mpx/selftests: Fix up weird arrays (bnc#1012628).
- mac80211_hwsim: Fix memory leak in hwsim_new_radio_nl()
  (bnc#1012628).
- gre6: use log_ecn_error module parameter in ip6_tnl_rcv()
  (bnc#1012628).
- route: also update fnhe_genid when updating a route cache
  (bnc#1012628).
- route: update fnhe_expires for redirect when the fnhe exists
  (bnc#1012628).
- rsi: fix memory leak on buf and usb_reg_buf (bnc#1012628).
- drivers/rapidio/devices/rio_mport_cdev.c: fix resource leak
  in error handling path in 'rio_dma_transfer()' (bnc#1012628).
- pipe: match pipe_max_size data type with procfs (bnc#1012628).
- lib/genalloc.c: make the avail variable an atomic_long_t
  (bnc#1012628).
- dynamic-debug-howto: fix optional/omitted ending line number
  to be LARGE instead of 0 (bnc#1012628).
- NFS: Fix a typo in nfs_rename() (bnc#1012628).
- sunrpc: Fix rpc_task_begin trace point (bnc#1012628).
- nfp: inherit the max_mtu from the PF netdev (bnc#1012628).
- nfp: fix flower offload metadata flag usage (bnc#1012628).
- xfs: fix forgotten rcu read unlock when skipping inode reclaim
  (bnc#1012628).
- dt-bindings: usb: fix reg-property port-number range
  (bnc#1012628).
- block: wake up all tasks blocked in get_request() (bnc#1012628).
- sparc64/mm: set fields in deferred pages (bnc#1012628).
- zsmalloc: calling zs_map_object() from irq is a bug
  (bnc#1012628).
- slub: fix sysfs duplicate filename creation when slub_debug=O
  (bnc#1012628).
- sctp: do not free asoc when it is already dead in sctp_sendmsg
  (bnc#1012628).
- sctp: use the right sk after waking up from wait_buf sleep
  (bnc#1012628).
- fcntl: don't leak fd reference when fixup_compat_flock fails
  (bnc#1012628).
- geneve: fix fill_info when link down (bnc#1012628).
- bpf: fix lockdep splat (bnc#1012628).
- clk: stm32h7: fix test of clock config (bnc#1012628).
- clk: sunxi-ng: a83t: Fix i2c buses bits (bnc#1012628).
- clk: qcom: common: fix legacy board-clock registration
  (bnc#1012628).
- clk: uniphier: fix DAPLL2 clock rate of Pro5 (bnc#1012628).
- clk: hi3660: fix incorrect uart3 clock freqency (bnc#1012628).
- mailbox: mailbox-test: don't rely on rx_buffer content to
  signal data ready (bnc#1012628).
- kbuild: rpm-pkg: fix jobserver unavailable warning
  (bnc#1012628).
- atm: horizon: Fix irq release error (bnc#1012628).
- jump_label: Invoke jump_label_test() via early_initcall()
  (bnc#1012628).
- tls: Use kzalloc for aead_request allocation (bnc#1012628).
- xfrm: Copy policy family in clone_policy (bnc#1012628).
- f2fs: fix to clear FI_NO_PREALLOC (bnc#1012628).
- bnxt_re: changing the ip address shouldn't affect new
  connections (bnc#1012628).
- IB/mlx4: Increase maximal message size under UD QP
  (bnc#1012628).
- IB/mlx5: Assign send CQ and recv CQ of UMR QP (bnc#1012628).
- afs: Fix total-length calculation for multiple-page send
  (bnc#1012628).
- afs: Connect up the CB.ProbeUuid (bnc#1012628).
- commit 45f120a
* Wed Dec 13 2017 msuchanek@suse.de
- s390/sclp: disable FORTIFY_SOURCE for early sclp code (-).
- commit 62412b6
* Tue Dec 12 2017 bp@suse.de
- x86/microcode/AMD: Add support for fam17h microcode loading
  (bsc#1068032).
- commit c1a1611
* Tue Dec 12 2017 mkubecek@suse.cz
- netfilter: xt_osf: Add missing permission checks (CVE-2017-17450
  bsc#1071695).
- commit a1ac243
* Tue Dec 12 2017 mkubecek@suse.cz
- netlink: Add netns check on taps (CVE-2017-17449 bsc#1071694).
- commit 9e5e383
* Tue Dec 12 2017 mkubecek@suse.cz
- netfilter: nfnetlink_cthelper: Add missing permission checks
  (CVE-2017-17448 bsc#1071693).
- commit a208c29
* Tue Dec 12 2017 mkubecek@suse.cz
- dccp: CVE-2017-8824: use-after-free in DCCP code (CVE-2017-8824
  bsc#1070771).
- commit bd1657a
* Mon Dec 11 2017 jslaby@suse.cz
- Linux 4.14.5 (bnc#1012628).
- Update config files.
- locking/refcounts: Do not force refcount_t usage as GPL-only
  export (bnc#1012628).
- usb: host: fix incorrect updating of offset (bnc#1012628).
- USB: usbfs: Filter flags passed in from user space
  (bnc#1012628).
- USB: core: Add type-specific length check of BOS descriptors
  (bnc#1012628).
- usb: xhci: fix panic in xhci_free_virt_devices_depth_first
  (bnc#1012628).
- xhci: Don't show incorrect WARN message about events for empty
  rings (bnc#1012628).
- USB: ulpi: fix bus-node lookup (bnc#1012628).
- usb: hub: Cycle HUB power when initialization fails
  (bnc#1012628).
- staging: ccree: fix leak of import() after init() (bnc#1012628).
- dma-buf/sw_sync: force signal all unsignaled fences on dying
  timeline (bnc#1012628).
- powerpc/kprobes: Disable preemption before invoking probe
  handler for optprobes (bnc#1012628).
- powerpc/jprobes: Disable preemption when triggered through
  ftrace (bnc#1012628).
- locking/refcounts, x86/asm: Enable CONFIG_ARCH_HAS_REFCOUNT
  (bnc#1012628).
- iio: multiplexer: add NULL check on devm_kzalloc() and
  devm_kmemdup() return values (bnc#1012628).
- iio: adc: ti-ads1015: add 10%% to conversion wait time
  (bnc#1012628).
- mm, x86/mm: Fix performance regression in get_user_pages_fast()
  (bnc#1012628).
- perf tools: Fix leaking rec_argv in error cases (bnc#1012628).
- tools include: Do not use poison with C++ (bnc#1012628).
- s390/ptrace: fix guarded storage regset handling (bnc#1012628).
- locking/refcounts, x86/asm: Use unique .text section for
  refcount exceptions (bnc#1012628).
- kprobes/x86: Disable preemption in ftrace-based jprobes
  (bnc#1012628).
- perf test attr: Fix python error on empty result (bnc#1012628).
- perf test attr: Fix ignored test case result (bnc#1012628).
- staging: fsl-mc/dpio: Fix incorrect comparison (bnc#1012628).
- serial: imx: Update cached mctrl value when changing RTS
  (bnc#1012628).
- usbip: tools: Install all headers needed for libusbip
  development (bnc#1012628).
- serial: sh-sci: suppress warning for ports without dma channels
  (bnc#1012628).
- sysrq : fix Show Regs call trace on ARM (bnc#1012628).
- usb: xhci: Return error when host is dead in xhci_disable_slot()
  (bnc#1012628).
- ARM: cpuidle: Correct driver unregistration if init fails
  (bnc#1012628).
- staging: rtl8822be: Keep array subscript no lower than zero
  (bnc#1012628).
- staging: fsl-dpaa2/eth: Account for Rx FD buffers on error path
  (bnc#1012628).
- usb: mtu3: fix error return code in ssusb_gadget_init()
  (bnc#1012628).
- EDAC, sb_edac: Fix missing break in switch (bnc#1012628).
- dt-bindings: timer: renesas, cmt: Fix SoC-specific compatible
  values (bnc#1012628).
- clocksource/drivers/arm_arch_timer: Validate CNTFRQ after
  enabling frame (bnc#1012628).
- x86/entry: Use SYSCALL_DEFINE() macros for sys_modify_ldt()
  (bnc#1012628).
- kprobes: Use synchronize_rcu_tasks() for optprobe with
  CONFIG_PREEMPT=y (bnc#1012628).
- serial: 8250: Preserve DLD[7:4] for PORT_XR17V35X (bnc#1012628).
- x86/intel_rdt: Fix potential deadlock during resctrl mount
  (bnc#1012628).
- x86/intel_rdt: Initialize bitmask of shareable resource if
  CDP enabled (bnc#1012628).
- PCI: dra7xx: Create functional dependency between PCIe and PHY
  (bnc#1012628).
- usb: phy: tahvo: fix error handling in tahvo_usb_probe()
  (bnc#1012628).
- perf/core: Fix __perf_read_group_add() locking (bnc#1012628).
- hwmon: (pmbus/core) Prevent unintentional setting of page to
  0xFF (bnc#1012628).
- mmc: sdhci-msm: fix issue with power irq (bnc#1012628).
- mmc: tmio: check mmc_regulator_get_supply return value
  (bnc#1012628).
- spi: spi-axi: fix potential use-after-free after deregistration
  (bnc#1012628).
- spi: sh-msiof: Fix DMA transfer size check (bnc#1012628).
- staging: rtl8188eu: avoid a null dereference on pmlmepriv
  (bnc#1012628).
- staging: rtl8822be: fix wrong dma unmap len (bnc#1012628).
- serial: 8250_fintek: Fix rs485 disablement on invalid ioctl()
  (bnc#1012628).
- m68k: fix ColdFire node shift size calculation (bnc#1012628).
- staging: greybus: loopback: Fix iteration count on async path
  (bnc#1012628).
- selftests/x86/ldt_gdt: Robustify against set_thread_area()
  and LAR oddities (bnc#1012628).
- selftests/x86/ldt_get: Add a few additional tests for limits
  (bnc#1012628).
- s390/pci: do not require AIS facility (bnc#1012628).
- PM / Domains: Fix genpd to deal with drivers returning 1 from
  - >prepare() (bnc#1012628).
- s390: vfio-ccw: Do not attempt to free no-op, test and tic cda
  (bnc#1012628).
- ima: fix hash algorithm initialization (bnc#1012628).
- MIPS: Add custom serial.h with BASE_BAUD override for generic
  kernel (bnc#1012628).
- serial: 8250_early: Only set divisor if valid clk & baud
  (bnc#1012628).
- USB: serial: usb_debug: add new USB device id (bnc#1012628).
- USB: serial: option: add Quectel BG96 id (bnc#1012628).
- ANDROID: binder: fix transaction leak (bnc#1012628).
- serial: 8250_pci: Add Amazon PCI serial device ID (bnc#1012628).
- usb: quirks: Add no-lpm quirk for KY-688 USB 3.1 Type-C Hub
  (bnc#1012628).
- uas: Always apply US_FL_NO_ATA_1X quirk to Seagate devices
  (bnc#1012628).
- usbip: Fix USB device hang due to wrong enabling of
  scatter-gather (bnc#1012628).
- usbip: fix usbip attach to find a port that matches the
  requested speed (bnc#1012628).
- s390/runtime instrumentation: simplify task exit handling
  (bnc#1012628).
- drm/amdgpu: Use unsigned ring indices in amdgpu_queue_mgr_map
  (bnc#1012628).
- drm/fsl-dcu: enable IRQ before drm_atomic_helper_resume()
  (bnc#1012628).
- drm/fsl-dcu: avoid disabling pixel clock twice on suspend
  (bnc#1012628).
- commit c4edabf
* Mon Dec 11 2017 jeffm@suse.com
- Update to 4.15-rc3.
- Eliminated 1 patch.
- commit 383d72f
* Sat Dec  9 2017 afaerber@suse.de
- config: armv7hl: Enable SUN4I_A10_CCU for Allwinner A20 (boo#1072032)
- commit 170d177
* Fri Dec  8 2017 msuchanek@suse.de
- Add undefine _unique_build_ids (bsc#964063)
- commit 47e91a1
* Tue Dec  5 2017 jslaby@suse.cz
- Linux 4.14.4 (bnc#1012628).
- platform/x86: hp-wmi: Fix tablet mode detection for convertibles
  (bnc#1012628).
- mm, memory_hotplug: do not back off draining pcp free pages
  from kworker context (bnc#1012628).
- mm, oom_reaper: gather each vma to prevent leaking TLB entry
  (bnc#1012628).
- mm, thp: Do not make page table dirty unconditionally in
  touch_p[mu]d() (bnc#1012628).
- mm/cma: fix alloc_contig_range ret code/potential leak
  (bnc#1012628).
- mm: fix device-dax pud write-faults triggered by
  get_user_pages() (bnc#1012628).
- mm, hugetlbfs: introduce ->split() to vm_operations_struct
  (bnc#1012628).
- device-dax: implement ->split() to catch invalid munmap attempts
  (bnc#1012628).
- mm: introduce get_user_pages_longterm (bnc#1012628).
- mm: fail get_vaddr_frames() for filesystem-dax mappings
  (bnc#1012628).
- v4l2: disable filesystem-dax mapping support (bnc#1012628).
- IB/core: disable memory registration of filesystem-dax vmas
  (bnc#1012628).
- exec: avoid RLIMIT_STACK races with prlimit() (bnc#1012628).
- mm/madvise.c: fix madvise() infinite loop under special
  circumstances (bnc#1012628).
- mm: migrate: fix an incorrect call of prep_transhuge_page()
  (bnc#1012628).
- mm, memcg: fix mem_cgroup_swapout() for THPs (bnc#1012628).
- fs/fat/inode.c: fix sb_rdonly() change (bnc#1012628).
- autofs: revert "autofs: take more care to not update last_used
  on path walk" (bnc#1012628).
- autofs: revert "autofs: fix AT_NO_AUTOMOUNT not being honored"
  (bnc#1012628).
- mm/hugetlb: fix NULL-pointer dereference on 5-level paging
  machine (bnc#1012628).
- btrfs: clear space cache inode generation always (bnc#1012628).
- nfsd: Fix stateid races between OPEN and CLOSE (bnc#1012628).
- nfsd: Fix another OPEN stateid race (bnc#1012628).
- nfsd: fix panic in posix_unblock_lock called from
  nfs4_laundromat (bnc#1012628).
- crypto: algif_aead - skip SGL entries with NULL page
  (bnc#1012628).
- crypto: af_alg - remove locking in async callback (bnc#1012628).
- crypto: skcipher - Fix skcipher_walk_aead_common (bnc#1012628).
- lockd: lost rollback of set_grace_period() in lockd_down_net()
  (bnc#1012628).
- s390: revert ELF_ET_DYN_BASE base changes (bnc#1012628).
- drm: omapdrm: Fix DPI on platforms using the DSI VDDS
  (bnc#1012628).
- omapdrm: hdmi4: Correct the SoC revision matching (bnc#1012628).
- arm64: module-plts: factor out PLT generation code for ftrace
  (bnc#1012628).
- arm64: ftrace: emit ftrace-mod.o contents through code
  (bnc#1012628).
- powerpc/powernv: Fix kexec crashes caused by tlbie tracing
  (bnc#1012628).
- powerpc/kexec: Fix kexec/kdump in P9 guest kernels
  (bnc#1012628).
- KVM: x86: pvclock: Handle first-time write to pvclock-page
  contains random junk (bnc#1012628).
- KVM: x86: Exit to user-mode on #UD intercept when emulator
  requires (bnc#1012628).
- KVM: x86: inject exceptions produced by x86_decode_insn
  (bnc#1012628).
- KVM: lapic: Split out x2apic ldr calculation (bnc#1012628).
- KVM: lapic: Fixup LDR on load in x2apic (bnc#1012628).
- mmc: block: Fix missing blk_put_request() (bnc#1012628).
- mmc: block: Check return value of blk_get_request()
  (bnc#1012628).
- mmc: core: Do not leave the block driver in a suspended state
  (bnc#1012628).
- mmc: block: Ensure that debugfs files are removed (bnc#1012628).
- mmc: core: prepend 0x to pre_eol_info entry in sysfs
  (bnc#1012628).
- mmc: core: prepend 0x to OCR entry in sysfs (bnc#1012628).
- ACPI / EC: Fix regression related to PM ops support in ECDT
  device (bnc#1012628).
- eeprom: at24: fix reading from 24MAC402/24MAC602 (bnc#1012628).
- eeprom: at24: correctly set the size for at24mac402
  (bnc#1012628).
- eeprom: at24: check at24_read/write arguments (bnc#1012628).
- i2c: i801: Fix Failed to allocate irq -2147483648 error
  (bnc#1012628).
- cxl: Check if vphb exists before iterating over AFU devices
  (bnc#1012628).
- bcache: Fix building error on MIPS (bnc#1012628).
- bcache: only permit to recovery read error when cache device
  is clean (bnc#1012628).
- bcache: recover data from backing when data is clean
  (bnc#1012628).
- hwmon: (jc42) optionally try to disable the SMBUS timeout
  (bnc#1012628).
- nvme-pci: add quirk for delay before CHK RDY for WDC SN200
  (bnc#1012628).
- Revert "drm/radeon: dont switch vt on suspend" (bnc#1012628).
- drm/amdgpu: potential uninitialized variable in
  amdgpu_vce_ring_parse_cs() (bnc#1012628).
- drm/amdgpu: Potential uninitialized variable in
  amdgpu_vm_update_directories() (bnc#1012628).
- drm/amdgpu: correct reference clock value on vega10
  (bnc#1012628).
- drm/amdgpu: fix error handling in amdgpu_bo_do_create
  (bnc#1012628).
- drm/amdgpu: Properly allocate VM invalidate eng v2
  (bnc#1012628).
- drm/amdgpu: Remove check which is not valid for certain VBIOS
  (bnc#1012628).
- drm/ttm: fix ttm_bo_cleanup_refs_or_queue once more
  (bnc#1012628).
- dma-buf: make reservation_object_copy_fences rcu save
  (bnc#1012628).
- drm/amdgpu: reserve root PD while releasing it (bnc#1012628).
- drm/ttm: Always and only destroy bo->ttm_resv in
  ttm_bo_release_list (bnc#1012628).
- drm/vblank: Fix flip event vblank count (bnc#1012628).
- drm/vblank: Tune drm_crtc_accurate_vblank_count() WARN down
  to a debug (bnc#1012628).
- drm/tilcdc: Precalculate total frametime in
  tilcdc_crtc_set_mode() (bnc#1012628).
- drm/radeon: fix atombios on big endian (bnc#1012628).
- drm/panel: simple: Add missing panel_simple_unprepare() calls
  (bnc#1012628).
- drm/hisilicon: Ensure LDI regs are properly configured
  (bnc#1012628).
- drm/ttm: once more fix ttm_buffer_object_transfer (bnc#1012628).
- drm/amd/pp: fix typecast error in powerplay (bnc#1012628).
- drm/fb_helper: Disable all crtc's when initial setup fails
  (bnc#1012628).
- drm/fsl-dcu: Don't set connector DPMS property (bnc#1012628).
- drm/edid: Don't send non-zero YQ in AVI infoframe for HDMI
  1.x sinks (bnc#1012628).
- drm/amdgpu: move UVD/VCE and VCN structure out from union
  (bnc#1012628).
- drm/amdgpu: Set adev->vcn.irq.num_types for VCN (bnc#1012628).
- include/linux/compiler-clang.h: handle randomizable anonymous
  structs (bnc#1012628).
- IB/core: Do not warn on lid conversions for OPA (bnc#1012628).
- IB/hfi1: Do not warn on lid conversions for OPA (bnc#1012628).
- e1000e: fix the use of magic numbers for buffer overrun issue
  (bnc#1012628).
- md: forbid a RAID5 from having both a bitmap and a journal
  (bnc#1012628).
- drm/i915: Fix false-positive assert_rpm_wakelock_held in
  i915_pmic_bus_access_notifier v2 (bnc#1012628).
- drm/i915: Re-register PMIC bus access notifier on runtime resume
  (bnc#1012628).
- drm/i915/fbdev: Serialise early hotplug events with async
  fbdev config (bnc#1012628).
- drm/i915/gvt: Correct ADDR_4K/2M/1G_MASK definition
  (bnc#1012628).
- drm/i915: Don't try indexed reads to alternate slave addresses
  (bnc#1012628).
- drm/i915: Prevent zero length "index" write (bnc#1012628).
- Revert "x86/entry/64: Add missing irqflags tracing to
  native_load_gs_index()" (bnc#1012628).
- commit b29439c
* Tue Dec  5 2017 jslaby@suse.cz
- x86/stacktrace: do now unwind after user regs (bnc#1058115).
- x86/stacktrace: remove unwind_state->error (bnc#1058115).
- x86/stacktrace: remove STACKTRACE_DUMP_ONCE from
  __save_stack_trace_reliable (bnc#1058115).
- x86/stacktrace: do not fail for ORC with regs on stack
  (bnc#1058115).
  More make-ORC-reliable patches.
- commit a6a5b05
* Mon Dec  4 2017 jeffm@suse.com
- Update to 4.15-rc2.
- Eliminated 2 patches.
- commit 68549b6
* Thu Nov 30 2017 jslaby@suse.cz
- Linux 4.14.3 (bnc#1012628).
- s390: fix transactional execution control register handling
  (bnc#1012628).
- s390/noexec: execute kexec datamover without DAT (bnc#1012628).
- s390/runtime instrumention: fix possible memory corruption
  (bnc#1012628).
- s390/guarded storage: fix possible memory corruption
  (bnc#1012628).
- s390/disassembler: add missing end marker for e7 table
  (bnc#1012628).
- s390/disassembler: increase show_code buffer size (bnc#1012628).
- ACPI / PM: Fix acpi_pm_notifier_lock vs flush_workqueue()
  deadlock (bnc#1012628).
- ACPI / EC: Fix regression related to triggering source of EC
  event handling (bnc#1012628).
- cpufreq: schedutil: Reset cached_raw_freq when not in sync
  with next_freq (bnc#1012628).
- serdev: fix registration of second slave (bnc#1012628).
- sched: Make resched_cpu() unconditional (bnc#1012628).
- lib/mpi: call cond_resched() from mpi_powm() loop (bnc#1012628).
- x86/boot: Fix boot failure when SMP MP-table is based at 0
  (bnc#1012628).
- x86/decoder: Add new TEST instruction pattern (bnc#1012628).
- x86/entry/64: Fix entry_SYSCALL_64_after_hwframe() IRQ tracing
  (bnc#1012628).
- x86/entry/64: Add missing irqflags tracing to
  native_load_gs_index() (bnc#1012628).
- perf/x86/intel: Hide TSX events when RTM is not supported
  (bnc#1012628).
- arm64: Implement arch-specific pte_access_permitted()
  (bnc#1012628).
- ARM: 8722/1: mm: make STRICT_KERNEL_RWX effective for LPAE
  (bnc#1012628).
- ARM: 8721/1: mm: dump: check hardware RO bit for LPAE
  (bnc#1012628).
- uapi: fix linux/tls.h userspace compilation error (bnc#1012628).
- uapi: fix linux/rxrpc.h userspace compilation errors
  (bnc#1012628).
- MIPS: cmpxchg64() and HAVE_VIRT_CPU_ACCOUNTING_GEN don't work
  for 32-bit SMP (bnc#1012628).
- MIPS: ralink: Fix MT7628 pinmux (bnc#1012628).
- MIPS: ralink: Fix typo in mt7628 pinmux function (bnc#1012628).
- net: mvneta: fix handling of the Tx descriptor counter
  (bnc#1012628).
- nbd: wait uninterruptible for the dead timeout (bnc#1012628).
- nbd: don't start req until after the dead connection logic
  (bnc#1012628).
- PM / OPP: Add missing of_node_put(np) (bnc#1012628).
- PCI/ASPM: Account for downstream device's Port
  Common_Mode_Restore_Time (bnc#1012628).
- PCI/ASPM: Use correct capability pointer to program
  LTR_L1.2_THRESHOLD (bnc#1012628).
- PCI: hv: Use effective affinity mask (bnc#1012628).
- PCI: Set Cavium ACS capability quirk flags to assert RR/CR/SV/UF
  (bnc#1012628).
- PCI: Apply Cavium ThunderX ACS quirk to more Root Ports
  (bnc#1012628).
- ALSA: hda: Add Raven PCI ID (bnc#1012628).
- dm integrity: allow unaligned bv_offset (bnc#1012628).
- dm cache: fix race condition in the writeback mode overwrite_bio
  optimisation (bnc#1012628).
- dm crypt: allow unaligned bv_offset (bnc#1012628).
- dm zoned: ignore last smaller runt zone (bnc#1012628).
- dm mpath: remove annoying message of 'blk_get_request()
  returned -11' (bnc#1012628).
- dm bufio: fix integer overflow when limiting maximum cache size
  (bnc#1012628).
- ovl: Put upperdentry if ovl_check_origin() fails (bnc#1012628).
- dm: allocate struct mapped_device with kvzalloc (bnc#1012628).
- sched/rt: Simplify the IPI based RT balancing logic
  (bnc#1012628).
- MIPS: pci: Remove KERN_WARN instance inside the mt7620 driver
  (bnc#1012628).
- dm: fix race between dm_get_from_kobject() and __dm_destroy()
  (bnc#1012628).
- dm: discard support requires all targets in a table support
  discards (bnc#1012628).
- MIPS: Fix odd fp register warnings with MIPS64r2 (bnc#1012628).
- MIPS: Fix MIPS64 FP save/restore on 32-bit kernels
  (bnc#1012628).
- MIPS: dts: remove bogus bcm96358nb4ser.dtb from dtb-y entry
  (bnc#1012628).
- MIPS: Fix an n32 core file generation regset support regression
  (bnc#1012628).
- MIPS: BCM47XX: Fix LED inversion for WRT54GSv1 (bnc#1012628).
- MIPS: math-emu: Fix final emulation phase for certain
  instructions (bnc#1012628).
- rt2x00usb: mark device removed when get ENOENT usb error
  (bnc#1012628).
- mm/z3fold.c: use kref to prevent page free/compact race
  (bnc#1012628).
- autofs: don't fail mount for transient error (bnc#1012628).
- nilfs2: fix race condition that causes file system corruption
  (bnc#1012628).
- fscrypt: lock mutex before checking for bounce page pool
  (bnc#1012628).
- eCryptfs: use after free in ecryptfs_release_messaging()
  (bnc#1012628).
- libceph: don't WARN() if user tries to add invalid key
  (bnc#1012628).
- bcache: check ca->alloc_thread initialized before wake up it
  (bnc#1012628).
- fs: guard_bio_eod() needs to consider partitions (bnc#1012628).
- fanotify: fix fsnotify_prepare_user_wait() failure
  (bnc#1012628).
- isofs: fix timestamps beyond 2027 (bnc#1012628).
- btrfs: change how we decide to commit transactions during
  flushing (bnc#1012628).
- f2fs: expose some sectors to user in inline data or dentry case
  (bnc#1012628).
- NFS: Fix typo in nomigration mount option (bnc#1012628).
- NFS: Revert "NFS: Move the flock open mode check into
  nfs_flock()" (bnc#1012628).
- nfs: Fix ugly referral attributes (bnc#1012628).
- NFS: Avoid RCU usage in tracepoints (bnc#1012628).
- NFS: revalidate "." etc correctly on "open" (bnc#1012628).
- nfsd: deal with revoked delegations appropriately (bnc#1012628).
- rtlwifi: rtl8192ee: Fix memory leak when loading firmware
  (bnc#1012628).
- rtlwifi: fix uninitialized rtlhal->last_suspend_sec time
  (bnc#1012628).
- iwlwifi: fix firmware names for 9000 and A000 series hw
  (bnc#1012628).
- md: fix deadlock error in recent patch (bnc#1012628).
- md: don't check MD_SB_CHANGE_CLEAN in md_allow_write
  (bnc#1012628).
- Bluetooth: btqcomsmd: Add support for BD address setup
  (bnc#1012628).
- md/bitmap: revert a patch (bnc#1012628 bsc#1062597).
- fsnotify: clean up fsnotify_prepare/finish_user_wait()
  (bnc#1012628).
- fsnotify: pin both inode and vfsmount mark (bnc#1012628).
- fsnotify: fix pinning group in fsnotify_prepare_user_wait()
  (bnc#1012628).
- ata: fixes kernel crash while tracing ata_eh_link_autopsy event
  (bnc#1012628).
- ext4: fix interaction between i_size, fallocate, and delalloc
  after a crash (bnc#1012628).
- ext4: prevent data corruption with inline data + DAX
  (bnc#1012628).
- ext4: prevent data corruption with journaling + DAX
  (bnc#1012628).
- ALSA: pcm: update tstamp only if audio_tstamp changed
  (bnc#1012628).
- ALSA: usb-audio: Add sanity checks to FE parser (bnc#1012628).
- ALSA: usb-audio: Fix potential out-of-bound access at parsing SU
  (bnc#1012628).
- ALSA: usb-audio: Add sanity checks in v2 clock parsers
  (bnc#1012628).
- ALSA: timer: Remove kernel warning at compat ioctl error paths
  (bnc#1012628).
- ALSA: hda/realtek - Fix ALC275 no sound issue (bnc#1012628).
- ALSA: hda: Fix too short HDMI/DP chmap reporting (bnc#1012628).
- ALSA: hda - Fix yet remaining issue with vmaster 0dB
  initialization (bnc#1012628).
- ALSA: hda/realtek - Fix ALC700 family no sound issue
  (bnc#1012628).
- ASoC: sun8i-codec: Invert Master / Slave condition
  (bnc#1012628).
- ASoC: sun8i-codec: Fix left and right channels inversion
  (bnc#1012628).
- ASoC: sun8i-codec: Set the BCLK divider (bnc#1012628).
- mfd: lpc_ich: Avoton/Rangeley uses SPI_BYT method (bnc#1012628).
- fix a page leak in vhost_scsi_iov_to_sgl() error recovery
  (bnc#1012628).
- 9p: Fix missing commas in mount options (bnc#1012628).
- fs/9p: Compare qid.path in v9fs_test_inode (bnc#1012628).
- net/9p: Switch to wait_event_killable() (bnc#1012628).
- scsi: qla2xxx: Suppress a kernel complaint in
  qla_init_base_qpair() (bnc#1012628).
- scsi: sd_zbc: Fix sd_zbc_read_zoned_characteristics()
  (bnc#1012628).
- scsi: lpfc: fix pci hot plug crash in timer management routines
  (bnc#1012628).
- scsi: lpfc: fix pci hot plug crash in list_add call
  (bnc#1012628).
- scsi: lpfc: Fix crash receiving ELS while detaching driver
  (bnc#1012628).
- scsi: lpfc: Fix FCP hba_wqidx assignment (bnc#1012628).
- scsi: lpfc: Fix oops if nvmet_fc_register_targetport fails
  (bnc#1012628).
- iscsi-target: Make TASK_REASSIGN use proper se_cmd->cmd_kref
  (bnc#1012628).
- iscsi-target: Fix non-immediate TMR reference leak
  (bnc#1012628).
- target: fix null pointer regression in core_tmr_drain_tmr_list
  (bnc#1012628).
- target: fix buffer offset in core_scsi3_pri_read_full_status
  (bnc#1012628).
- target: Fix QUEUE_FULL + SCSI task attribute handling
  (bnc#1012628).
- target: Fix caw_sem leak in transport_generic_request_failure
  (bnc#1012628).
- target: Fix quiese during transport_write_pending_qf endless
  loop (bnc#1012628).
- target: Avoid early CMD_T_PRE_EXECUTE failures during ABORT_TASK
  (bnc#1012628).
- mtd: Avoid probe failures when mtd->dbg.dfs_dir is invalid
  (bnc#1012628).
- mtd: nand: Export nand_reset() symbol (bnc#1012628).
- mtd: nand: atmel: Actually use the PM ops (bnc#1012628).
- mtd: nand: omap2: Fix subpage write (bnc#1012628).
- mtd: nand: Fix writing mtdoops to nand flash (bnc#1012628).
- mtd: nand: mtk: fix infinite ECC decode IRQ issue (bnc#1012628).
- mailbox: bcm-flexrm-mailbox: Fix FlexRM ring flush sequence
  (bnc#1012628).
- p54: don't unregister leds when they are not initialized
  (bnc#1012628).
- block: Fix a race between blk_cleanup_queue() and timeout
  handling (bnc#1012628).
- raid1: prevent freeze_array/wait_all_barriers deadlock
  (bnc#1012628).
- genirq: Track whether the trigger type has been set
  (bnc#1012628).
- irqchip/gic-v3: Fix ppi-partitions lookup (bnc#1012628).
- lockd: double unregister of inetaddr notifiers (bnc#1012628).
- KVM: PPC: Book3S HV: Don't call real-mode XICS hypercall
  handlers if not enabled (bnc#1012628).
- KVM: nVMX: set IDTR and GDTR limits when loading L1 host state
  (bnc#1012628).
- KVM: SVM: obey guest PAT (bnc#1012628).
- kvm: vmx: Reinstate support for CPUs without virtual NMI
  (bnc#1012628).
- dax: fix PMD faults on zero-length files (bnc#1012628).
- dax: fix general protection fault in dax_alloc_inode
  (bnc#1012628).
- SUNRPC: Fix tracepoint storage issues with svc_recv and
  svc_rqst_status (bnc#1012628).
- clk: ti: dra7-atl-clock: fix child-node lookups (bnc#1012628).
- libnvdimm, dimm: clear 'locked' status on successful DIMM enable
  (bnc#1012628).
- libnvdimm, pfn: make 'resource' attribute only readable by root
  (bnc#1012628).
- libnvdimm, namespace: fix label initialization to use valid
  seq numbers (bnc#1012628).
- libnvdimm, region : make 'resource' attribute only readable
  by root (bnc#1012628).
- libnvdimm, namespace: make 'resource' attribute only readable
  by root (bnc#1012628).
- svcrdma: Preserve CB send buffer across retransmits
  (bnc#1012628).
- IB/srpt: Do not accept invalid initiator port names
  (bnc#1012628).
- IB/cm: Fix memory corruption in handling CM request
  (bnc#1012628).
- IB/hfi1: Fix incorrect available receive user context count
  (bnc#1012628).
- IB/srp: Avoid that a cable pull can trigger a kernel crash
  (bnc#1012628).
- IB/core: Avoid crash on pkey enforcement failed in received MADs
  (bnc#1012628).
- IB/core: Only maintain real QPs in the security lists
  (bnc#1012628).
- NFC: fix device-allocation error return (bnc#1012628).
- spi-nor: intel-spi: Fix broken software sequencing codes
  (bnc#1012628).
- i40e: Use smp_rmb rather than read_barrier_depends
  (bnc#1012628).
- igb: Use smp_rmb rather than read_barrier_depends (bnc#1012628).
- igbvf: Use smp_rmb rather than read_barrier_depends
  (bnc#1012628).
- ixgbevf: Use smp_rmb rather than read_barrier_depends
  (bnc#1012628).
- i40evf: Use smp_rmb rather than read_barrier_depends
  (bnc#1012628).
- fm10k: Use smp_rmb rather than read_barrier_depends
  (bnc#1012628).
- ixgbe: Fix skb list corruption on Power systems (bnc#1012628).
- parisc: Fix validity check of pointer size argument in new
  CAS implementation (bnc#1012628).
- powerpc: Fix boot on BOOK3S_32 with CONFIG_STRICT_KERNEL_RWX
  (bnc#1012628).
- powerpc/mm/radix: Fix crashes on Power9 DD1 with radix MMU
  and STRICT_RWX (bnc#1012628).
- powerpc/perf/imc: Use cpu_to_node() not
  topology_physical_package_id() (bnc#1012628).
- powerpc/signal: Properly handle return value from
  uprobe_deny_signal() (bnc#1012628).
- powerpc/64s: Fix masking of SRR1 bits on instruction fault
  (bnc#1012628).
- powerpc/64s/radix: Fix 128TB-512TB virtual address boundary
  case allocation (bnc#1012628).
- powerpc/64s/hash: Fix 512T hint detection to use >= 128T
  (bnc#1012628).
- powerpc/64s/hash: Fix 128TB-512TB virtual address boundary
  case allocation (bnc#1012628).
- powerpc/64s/hash: Fix fork() with 512TB process address space
  (bnc#1012628).
- powerpc/64s/hash: Allow MAP_FIXED allocations to cross 128TB
  boundary (bnc#1012628).
- media: Don't do DMA on stack for firmware upload in the AS102
  driver (bnc#1012628).
- media: rc: check for integer overflow (bnc#1012628).
- media: rc: nec decoder should not send both repeat and keycode
  (bnc#1012628).
- media: v4l2-ctrl: Fix flags field on Control events
  (bnc#1012628).
- media: venus: fix wrong size on dma_free (bnc#1012628).
- media: venus: venc: fix bytesused v4l2_plane field
  (bnc#1012628).
- media: venus: reimplement decoder stop command (bnc#1012628).
- ARM64: dts: meson-gxl: Add alternate ARM Trusted Firmware
  reserved memory zone (bnc#1012628).
- iwlwifi: fix wrong struct for a000 device (bnc#1012628).
- iwlwifi: add a new a000 device (bnc#1012628).
- iwlwifi: pcie: sort IDs for the 9000 series for easier
  comparisons (bnc#1012628).
- iwlwifi: add new cards for a000 series (bnc#1012628).
- iwlwifi: add new cards for 8265 series (bnc#1012628).
- iwlwifi: add new cards for 8260 series (bnc#1012628).
- iwlwifi: fix PCI IDs and configuration mapping for 9000 series
  (bnc#1012628).
- e1000e: Fix error path in link detection (bnc#1012628).
- e1000e: Fix return value test (bnc#1012628).
- e1000e: Separate signaling for link check/link up (bnc#1012628).
- e1000e: Avoid receiver overrun interrupt bursts (bnc#1012628).
- e1000e: fix buffer overrun while the I219 is processing DMA
  transactions (bnc#1012628).
- Refresh patches.suse/dm-mpath-accept-failed-paths.
- Delete
  patches.suse/0002-md-bitmap-copy-correct-data-for-bitmap-super.patch.
- commit a731a45
* Thu Nov 30 2017 jslaby@suse.cz
- Refresh
  patches.suse/apparmor-fix-oops-in-audit_signal_cb-hook.patch.
  Update upstream status.
- commit 00f319b
* Thu Nov 30 2017 jslaby@suse.cz
- mmc: sdhci: Avoid swiotlb buffer being full (bnc#1068877).
- Delete
  patches.suse/revert-mmc-Delete-bounce-buffer-handling.patch.
- mmc: sdhci: Avoid swiotlb buffer being full (bnc#1068877).
- commit acb1236
* Wed Nov 29 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: fix incorrectly moved comment
  While moving # END COMMON DEPS moved following comment with it.
- commit 858b7e7
* Tue Nov 28 2017 afaerber@suse.de
- config: armv7hl: Update to 4.15-rc1
- commit b4c7f19
* Tue Nov 28 2017 afaerber@suse.de
- config: armv6hl: Update to 4.15-rc1
- commit edcdf48
* Tue Nov 28 2017 afaerber@suse.de
- config: arm64: Update to 4.15-rc1
- commit 3278861
* Mon Nov 27 2017 jeffm@suse.com
- Update to 4.15-rc1.
- Eliminated 74 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - CPU_ISOLATION=y
  - GUP_BENCHMARK=n
  - x86:
  - X86_INTEL_UMIP=y
  - PINCTRL_CEDARFORK=m
  - INTEL_SOC_PMIC_CHTDC_TI=m
  - INTEL_WMI_THUNDERBOLT=m
  - DELL_SMBIOS_WMI=m
  - DELL_SMBIOS_SMM=m
  - CHT_DC_TI_PMIC_OPREGION=y
  - RPMSG_CHAR=m
  - i386:
  - IR_SPI=m
  - IR_GPIO_CIR=m
  - IR_GPIO_TX=m
  - IR_PWM_TX=m
  - powerpc:
  - PPC_RADIX_MMU_DEFAULT=y (default)
  - MEM_SOFT_DIRTY=n (needs arch expert review)
  - PINCTRL=n
  - PPC_FAST_ENDIAN_SWITCH=n (default)
  - s390:
  - GCC_PLUGINS=n
  - MEM_SOFT_DIRTY=(needs arch expert review)
  - PINCTRL=n
  - FORTIFY_SOURCE=y
  - s390/zfcpdump:
  - BPF_STREAM_PARSER=n
  - MTD=n
  - Network:
  - NET_SCH_CBS=m
  - VSOCKETS_DIAG=m
  - DP83822_PHY=m
  - RENESAS_PHY=m
  - THUNDERBOLT_NET=m
  - Input:
  - TOUCHSCREEN_EXC3000=m
  - TOUCHSCREEN_HIDEEP=m
  - TOUCHSCREEN_S6SY761=m
  - DRM_I2C_ADV7511_CEC=y
  - Misc:
  - IPMI_PROC_INTERFACE=y
  - GPIO_MAX3191X=m
  - MANAGER_SBS=m
  - W1_SLAVE_DS28E17=m
  - SENSORS_MAX6621=m
  - SENSORS_MAX31785=m
  - CEC_GPIO=m
  - TYPEC_TPS6598X=m
  - RPMSG_VIRTIO=m
  - IIO_CROS_EC_ACCEL_LEGACY=m
  - RFD77402=m
  - NTB_SWITCHTEC=m
  - MMC_SDHCI_OMAP=m
  - Filesystems:
  - XFS_ONLINE_SCRUB=n (still experimental)
  - BTRFS_FS_REF_VERIFY=n
  - CRAMFS_BLOCKDEV=y
  - CRAMFS_MTD=y
  - INTEGRITY_TRUSTED_KEYRING=y
  - Crypto:
  - CRYPTO_SM3=m
  - SIGNED_PE_FILE_VERIFICATION=y
  - SYSTEM_TRUSTED_KEYS (empty)
  - SYSTEM_EXTRA_CERTIFICATE=n
  - SECONDARY_TRUSTED_KEYRING=n
  - LEDS:
  - LEDS_APU=m
  - LEDS_TRIGGER_ACTIVITY=m
  - RTC:
  - RTC_DRV_PCF85363=m
  - Xen:
  - XEN_PVCALLS_FRONTEND=n
  - Graphics:
  - DRM_AMD_DC=y
  - DRM_AMD_DC_PRE_VEGA=y
  - DRM_AMD_DC_FBC=y ?
  - DRM_AMD_DC_DCN1_0=y
  - DEBUG_KERNEL_DC=n
  - NOUVEAU_DEBUG_MMU=n
  - Storage:
  - NVME_MULTIPATH=y
  - IB:
  - MLX4_CORE_GEN2=y
  - Sound:
  - SND_SOC_INTEL_SST_TOPLEVEL=m
  - SND_SOC_INTEL_BAYTRAIL=m
  - Testing:
  - KCOV_ENABLE_COMPARISONS=y (syzkaller)
  - BOOTPARAM_LOCKDEP_CROSSRELEASE_FULLSTACK=n
  - PREEMPTIRQ_EVENTS=y
  - TEST_FIND_BIT=n
  - PKCS7_TEST_KEY=n
  - CHASH_SELFTEST=n
  - CHASH_STATS=n
- commit bc47c49
* Sun Nov 26 2017 afaerber@suse.de
- config: armv6hl: Enable 8250 irq sharing for RPi Zero W (boo#1069828)
- commit 01942c4
* Sat Nov 25 2017 mwilck@suse.com
- scsi: libfc: fix ELS request handling (bsc#1069801).
- commit 75312a6
* Sat Nov 25 2017 afaerber@suse.de
- config: armv6hl: Enable brcmfmac for RPi Zero W (boo#1069830)
- commit 56423d9
* Sat Nov 25 2017 afaerber@suse.de
- config: armv6hl: Enable 8250 serial console for RPi Zero W (boo#1069828)
- commit 3a3001a
* Fri Nov 24 2017 bp@suse.de
- dvb_frontend: don't use-after-free the frontend struct
  (bsc#1067087 CVE-2017-16648).
- media: dvb-core: always call invoke_release() in fe_free()
  (bsc#1067087).
- commit 2a04ad0
* Fri Nov 24 2017 tiwai@suse.de
- rpm/kernel-binary.spec.in: Correct supplements for recent SLE products (bsc#1067494)
- commit 8f05b9f
* Fri Nov 24 2017 jbeulich@suse.com
- supported:conf: Remove stale Xen driver entries.
- commit c46464b
* Fri Nov 24 2017 jslaby@suse.cz
- ipmi_si: fix memory leak on new_smi (git-fixes).
- commit 4ca3b35
* Fri Nov 24 2017 jslaby@suse.cz
- Linux 4.14.2 (bnc#1012628).
- af_netlink: ensure that NLMSG_DONE never fails in dumps
  (bnc#1012628).
- vxlan: fix the issue that neigh proxy blocks all icmpv6 packets
  (bnc#1012628).
- net: cdc_ncm: GetNtbFormat endian fix (bnc#1012628).
- fealnx: Fix building error on MIPS (bnc#1012628).
- net/sctp: Always set scope_id in sctp_inet6_skb_msgname
  (bnc#1012628).
- ima: do not update security.ima if appraisal status is not
  INTEGRITY_PASS (bnc#1012628).
- serial: omap: Fix EFR write on RTS deassertion (bnc#1012628).
- serial: 8250_fintek: Fix finding base_port with activated
  SuperIO (bnc#1012628).
- tpm-dev-common: Reject too short writes (bnc#1012628).
- rcu: Fix up pending cbs check in rcu_prepare_for_idle
  (bnc#1012628).
- mm/pagewalk.c: report holes in hugetlb ranges (bnc#1012628).
- ocfs2: fix cluster hang after a node dies (bnc#1012628).
- ocfs2: should wait dio before inode lock in ocfs2_setattr()
  (bnc#1012628).
- ipmi: fix unsigned long underflow (bnc#1012628).
- mm/page_alloc.c: broken deferred calculation (bnc#1012628).
- mm/page_ext.c: check if page_ext is not prepared (bnc#1012628).
- coda: fix 'kernel memory exposure attempt' in fsync
  (bnc#1012628).
- ipmi: Prefer ACPI system interfaces over SMBIOS ones
  (bnc#1012628).
- commit 295c90a
* Thu Nov 23 2017 jslaby@suse.cz
- apparmor: fix oops in audit_signal_cb hook (bnc#1069562).
- Refresh patches.suse/0001-AppArmor-basic-networking-rules.patch.
- commit d091ad8
* Thu Nov 23 2017 jslaby@suse.cz
- bio: ensure __bio_clone_fast copies bi_partno (bnc#1069605).
- commit 59c6ade
* Tue Nov 21 2017 jslaby@suse.cz
- Update config files.
  After renaming the UNWINDER config options, vanilla has the old names
  and they need to be in configs. For example, x86_64 default config
  has CONFIG_UNWINDER_ORC=y, vanilla has CONFIG_ORC_UNWINDER=y.
- commit d0dab46
* Tue Nov 21 2017 jslaby@suse.cz
- objtool: Print top level commands on incorrect usage
  (bnc#1058115).
- commit 6603336
* Tue Nov 21 2017 jslaby@suse.cz
- x86/unwind: Make CONFIG_UNWINDER_ORC=y the default in kconfig
  for 64-bit (bnc#1058115).
- Update config files.
- x86/unwind: Rename unwinder config options to
  'CONFIG_UNWINDER_*' (bnc#1058115).
- Refresh patches.suse/0001-orc-mark-it-as-reliable.patch.
- Update config files.
- x86/unwinder: Make CONFIG_UNWINDER_ORC=y the default in the
  64-bit defconfig (bnc#1058115).
- commit c81ce89
* Tue Nov 21 2017 jslaby@suse.cz
- x86/stacktrace: Avoid recording save_stack_trace() wrappers
  (bnc#1058115).
- commit fa72e96
* Tue Nov 21 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-objtool-Don-t-report-end-of-section-error-after-an-e.patch.
- Refresh
  patches.suse/0002-x86-head-Remove-confusing-comment.patch.
- Refresh
  patches.suse/0003-x86-head-Remove-unused-bad_address-code.patch.
- Refresh
  patches.suse/0004-x86-head-Fix-head-ELF-function-annotations.patch.
- Refresh
  patches.suse/0005-x86-boot-Annotate-verify_cpu-as-a-callable-function.patch.
- Refresh
  patches.suse/0006-x86-xen-Fix-xen-head-ELF-annotations.patch.
- Refresh
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-head-Add-unwind-hint-annotations.patch.
  Update upstream status.
- commit f655f80
* Tue Nov 21 2017 jslaby@suse.cz
- move all patches to patches.suse/
- commit 6fafae6
* Tue Nov 21 2017 jslaby@suse.cz
- Linux 4.14.1 (bnc#1012628).
- EDAC, sb_edac: Don't create a second memory controller if HA1
  is not present (bnc#1012628).
- dmaengine: dmatest: warn user when dma test times out
  (bnc#1012628).
- crypto: dh - Fix double free of ctx->p (bnc#1012628).
- crypto: dh - Don't permit 'p' to be 0 (bnc#1012628).
- crypto: dh - Don't permit 'key' or 'g' size longer than 'p'
  (bnc#1012628).
- crypto: brcm - Explicity ACK mailbox message (bnc#1012628).
- USB: early: Use new USB product ID and strings for DbC device
  (bnc#1012628).
- USB: usbfs: compute urb->actual_length for isochronous
  (bnc#1012628).
- USB: Add delay-init quirk for Corsair K70 LUX keyboards
  (bnc#1012628).
- usb: gadget: f_fs: Fix use-after-free in ffs_free_inst
  (bnc#1012628).
- USB: serial: metro-usb: stop I/O after failed open
  (bnc#1012628).
- USB: serial: Change DbC debug device binding ID (bnc#1012628).
- USB: serial: qcserial: add pid/vid for Sierra Wireless EM7355
  fw update (bnc#1012628).
- USB: serial: garmin_gps: fix I/O after failed probe and remove
  (bnc#1012628).
- USB: serial: garmin_gps: fix memory leak on probe errors
  (bnc#1012628).
- selftests/x86/protection_keys: Fix syscall NR redefinition
  warnings (bnc#1012628).
- x86/MCE/AMD: Always give panic severity for UC errors in kernel
  context (bnc#1012628).
- platform/x86: peaq-wmi: Add DMI check before binding to the
  WMI interface (bnc#1012628 bsc#1059807).
- platform/x86: peaq_wmi: Fix missing terminating entry for
  peaq_dmi_table (bnc#1012628).
- HID: cp2112: add HIDRAW dependency (bnc#1012628).
- HID: wacom: generic: Recognize WACOM_HID_WD_PEN as a type of
  pen collection (bnc#1012628).
- rpmsg: glink: Add missing MODULE_LICENSE (bnc#1012628).
- staging: wilc1000: Fix bssid buffer offset in Txq (bnc#1012628).
- staging: sm750fb: Fix parameter mistake in poke32 (bnc#1012628).
- staging: ccree: fix 64 bit scatter/gather DMA ops (bnc#1012628).
- staging: greybus: spilib: fix use-after-free after
  deregistration (bnc#1012628).
- staging: vboxvideo: Fix reporting invalid
  suggested-offset-properties (bnc#1012628).
- staging: rtl8188eu: Revert 4 commits breaking ARP (bnc#1012628).
- spi: fix use-after-free at controller deregistration
  (bnc#1012628).
- sparc32: Add cmpxchg64() (bnc#1012628).
- sparc64: mmu_context: Add missing include files (bnc#1012628).
- sparc64: Fix page table walk for PUD hugepages (bnc#1012628).
- commit b1ba0c0
* Tue Nov 21 2017 jslaby@suse.cz
- drm/bridge: analogix dp: Fix runtime PM state in get_modes()
  callback (bnc#1069146).
- commit 8354c2c
* Tue Nov 21 2017 jslaby@suse.cz
- Linux 4.14.1 (bnc#1012628).
- EDAC, sb_edac: Don't create a second memory controller if HA1
  is not present (bnc#1012628).
- dmaengine: dmatest: warn user when dma test times out
  (bnc#1012628).
- crypto: dh - Fix double free of ctx->p (bnc#1012628).
- crypto: dh - Don't permit 'p' to be 0 (bnc#1012628).
- crypto: dh - Don't permit 'key' or 'g' size longer than 'p'
  (bnc#1012628).
- crypto: brcm - Explicity ACK mailbox message (bnc#1012628).
- USB: early: Use new USB product ID and strings for DbC device
  (bnc#1012628).
- USB: usbfs: compute urb->actual_length for isochronous
  (bnc#1012628).
- USB: Add delay-init quirk for Corsair K70 LUX keyboards
  (bnc#1012628).
- usb: gadget: f_fs: Fix use-after-free in ffs_free_inst
  (bnc#1012628).
- USB: serial: metro-usb: stop I/O after failed open
  (bnc#1012628).
- USB: serial: Change DbC debug device binding ID (bnc#1012628).
- USB: serial: qcserial: add pid/vid for Sierra Wireless EM7355
  fw update (bnc#1012628).
- USB: serial: garmin_gps: fix I/O after failed probe and remove
  (bnc#1012628).
- USB: serial: garmin_gps: fix memory leak on probe errors
  (bnc#1012628).
- selftests/x86/protection_keys: Fix syscall NR redefinition
  warnings (bnc#1012628).
- x86/MCE/AMD: Always give panic severity for UC errors in kernel
  context (bnc#1012628).
- platform/x86: peaq_wmi: Fix missing terminating entry for
  peaq_dmi_table (bnc#1012628).
- HID: cp2112: add HIDRAW dependency (bnc#1012628).
- HID: wacom: generic: Recognize WACOM_HID_WD_PEN as a type of
  pen collection (bnc#1012628).
- rpmsg: glink: Add missing MODULE_LICENSE (bnc#1012628).
- staging: wilc1000: Fix bssid buffer offset in Txq (bnc#1012628).
- staging: sm750fb: Fix parameter mistake in poke32 (bnc#1012628).
- staging: ccree: fix 64 bit scatter/gather DMA ops (bnc#1012628).
- staging: greybus: spilib: fix use-after-free after
  deregistration (bnc#1012628).
- staging: vboxvideo: Fix reporting invalid
  suggested-offset-properties (bnc#1012628).
- staging: rtl8188eu: Revert 4 commits breaking ARP (bnc#1012628).
- spi: fix use-after-free at controller deregistration
  (bnc#1012628).
- sparc32: Add cmpxchg64() (bnc#1012628).
- sparc64: mmu_context: Add missing include files (bnc#1012628).
- sparc64: Fix page table walk for PUD hugepages (bnc#1012628).
- commit 5bbb894
* Mon Nov 20 2017 jslaby@suse.cz
- iwlwifi: mvm: support version 7 of the SCAN_REQ_UMAC FW command
  (bnc#1068838).
- commit 1d02750
* Mon Nov 20 2017 jslaby@suse.cz
- Revert "mmc: Delete bounce buffer handling" (bnc#1068877).
- commit ad8c19c
* Wed Nov 15 2017 rgoldwyn@suse.com
- apparmor: Fix quieting of audit messages for network mediation
  (FATE#300516, boo#1065536).
- apparmor: update apparmor-basic-networking-rules for 4.11-rc1
  (FATE#300516, boo#1065536).
- AppArmor: basic networking rules (FATE#300516, boo#1065536).
- commit fca1de8
* Wed Nov 15 2017 rgoldwyn@suse.com
- VFS: Handle lazytime in do_mount() (boo#1068256).
- commit 0f12060
* Mon Nov 13 2017 jeffm@suse.com
- Update to 4.14-final.
- commit c152297
* Thu Nov  9 2017 lpechacek@suse.com
- rpm/kernel-binary.spec.in: rename kGraft to KLP (fate#323682)
- commit 0ed191d
* Wed Nov  8 2017 tiwai@suse.de
- media: dib0700: fix invalid dvb_detach argument (CVE-2017-16646
  bsc#1067105).
- commit c6cd519
* Wed Nov  8 2017 tiwai@suse.de
- Input: ims-psu - check if CDC union descriptor is sane
  (CVE-2017-16645 bsc#1067132).
- commit 0cfe4b6
* Wed Nov  8 2017 tiwai@suse.de
- net: usb: asix: fill null-ptr-deref in asix_suspend
  (CVE-2017-16647 bsc#1067102).
- commit a088160
* Wed Nov  8 2017 jslaby@suse.cz
- Linux 4.13.12 (bnc#1012628).
- irqchip/irq-mvebu-gicp: Add missing spin_lock init
  (bnc#1012628).
- x86/mcelog: Get rid of RCU remnants (bnc#1012628).
- perf/cgroup: Fix perf cgroup hierarchy support (bnc#1012628).
- futex: Fix more put_pi_state() vs. exit_pi_state_list() races
  (bnc#1012628).
- powerpc/kprobes: Dereference function pointers only if the
  address does not belong to kernel text (bnc#1012628).
- x86: CPU: Fix up "cpu MHz" in /proc/cpuinfo (bnc#1012628).
- Revert "x86: do not use cpufreq_quick_get() for /proc/cpuinfo
  "cpu MHz"" (bnc#1012628).
- MIPS: SMP: Fix deadlock & online race (bnc#1012628).
- MIPS: microMIPS: Fix incorrect mask in insn_table_MM
  (bnc#1012628).
- MIPS: smp-cmp: Use right include for task_struct (bnc#1012628).
- MIPS: bpf: Fix a typo in build_one_insn() (bnc#1012628).
- Revert "powerpc64/elfv1: Only dereference function descriptor
  for non-text symbols" (bnc#1012628).
- drm/i915/edp: read edp display control registers unconditionally
  (bnc#1012628).
- drm/i915: Do not rely on wm preservation for ILK watermarks
  (bnc#1012628).
- mm, swap: fix race between swap count continuation operations
  (bnc#1012628).
- fs/hugetlbfs/inode.c: fix hwpoison reserve accounting
  (bnc#1012628).
- ocfs2: fstrim: Fix start offset of first cluster group during
  fstrim (bnc#1012628).
- userfaultfd: hugetlbfs: prevent UFFDIO_COPY to fill beyond
  the end of i_size (bnc#1012628).
- drm/amdgpu: allow harvesting check for Polaris VCE
  (bnc#1012628).
- drm/amdgpu: return -ENOENT from uvd 6.0 early init for
  harvesting (bnc#1012628).
- ARM: 8715/1: add a private asm/unaligned.h (bnc#1012628).
- ARM: dts: mvebu: pl310-cache disable double-linefill
  (bnc#1012628).
- arm/arm64: kvm: Disable branch profiling in HYP code
  (bnc#1012628).
- arm/arm64: KVM: set right LR register value for 32 bit guest
  when inject abort (bnc#1012628).
- KVM: arm64: its: Fix missing dynamic allocation check in
  scan_its_table (bnc#1012628).
- arm64: ensure __dump_instr() checks addr_limit (bnc#1012628).
- virtio_blk: Fix an SG_IO regression (bnc#1012628).
- ASoC: adau17x1: Workaround for noise bug in ADC (bnc#1012628).
- KEYS: fix out-of-bounds read during ASN.1 parsing (bnc#1012628).
- KEYS: trusted: fix writing past end of buffer in trusted_read()
  (bnc#1012628).
- KEYS: return full count in keyring_read() if buffer is too small
  (bnc#1012628).
- cifs: check MaxPathNameComponentLength != 0 before using it
  (bnc#1012628).
- ALSA: seq: Fix nested rwsem annotation for lockdep splat
  (bnc#1012628).
- ALSA: timer: Add missing mutex lock for compat ioctls
  (bnc#1012628).
- commit 19cf938
* Mon Nov  6 2017 jeffm@suse.com
- Update to 4.14-rc8.
- commit 0fbdeee
* Mon Nov  6 2017 tiwai@suse.de
- media: imon: Fix null-ptr-deref in imon_probe (CVE-2017-16537
  bsc#1066573).
- [media] cx231xx-cards: fix NULL-deref on missing association
  descriptor (CVE-2017-16536 bsc#1066606).
- media: imon: Fix null-ptr-deref in imon_probe (CVE-2017-16537
  bsc#1066573).
- [media] cx231xx-cards: fix NULL-deref on missing association
  descriptor (CVE-2017-16536 bsc#1066606).
- commit 0cd38c2
* Mon Nov  6 2017 jkosina@suse.cz
- rpm/kernel-binary.spec.in: add explicit dependency of kernel-*-devel on
  libelf-devel.
  Otherwise warning that got turned into error by upstream 3dd40cb3 ("objtool:
  Upgrade libelf-devel warning to error...") would trigger and cause any
  packages being built against kernel-*-devel (such as KMPs, crash) not to have
  the libelf dependency included, and fail to build.
- rpm/kernel-binary.spec.in: add explicit dependency of kernel-*-devel on
  libelf-devel. Otherwise warning that got turned into error by e683952999
  ("objtool: Upgrade libelf-devel warning to error...") would trigger and
  cause any packages being built against kernel-*-devel (such as KMPs,
  crash) not to have the libelf dependency included, and fail to build.
- commit f6c0f80
* Sat Nov  4 2017 mcgrof@suse.com
- mac80211: don't compare TKIP TX MIC key in reinstall prevention
  (bsc#1066472).
- commit a2a7106
* Sat Nov  4 2017 mcgrof@suse.com
- mac80211: use constant time comparison with keys (bsc#1066471).
- commit e2a3d57
* Thu Nov  2 2017 jslaby@suse.cz
- Linux 4.13.11 (bnc#1012628).
- powerpc/xive: Fix the size of the cpumask used in
  xive_find_target_in_mask() (bnc#1012628).
- regulator: fan53555: fix I2C device ids (bnc#1012628).
- ipsec: Fix aborted xfrm policy dump crash (bnc#1012628).
- cfg80211: fix connect/disconnect edge cases (bnc#1012628).
- can: kvaser_usb: Ignore CMD_FLUSH_QUEUE_REPLY messages
  (bnc#1012628).
- can: kvaser_usb: Correct return value in printout (bnc#1012628).
- can: sun4i: fix loopback mode (bnc#1012628).
- drm/i915/perf: fix perf enable/disable ioctls with 32bits
  userspace (bnc#1012628).
- drm/amd/powerplay: fix uninitialized variable (bnc#1012628).
- x86/cpu/AMD: Apply the Erratum 688 fix when the BIOS doesn't
  (bnc#1012628).
- scsi: sg: Re-fix off by one in sg_fill_request_table()
  (bnc#1012628).
- scsi: qla2xxx: Initialize Work element before requesting IRQs
  (bnc#1012628).
- scsi: aacraid: Fix controller initialization failure
  (bnc#1012628).
- scsi: zfcp: fix erp_action use-before-initialize in REC action
  trace (bnc#1012628).
- assoc_array: Fix a buggy node-splitting case (bnc#1012628).
- SMB3: Validate negotiate request must always be signed
  (bnc#1012628).
- Fix encryption labels and lengths for SMB3.1.1 (bnc#1012628).
- Input: gtco - fix potential out-of-bound access (bnc#1012628).
- Input: elan_i2c - add ELAN0611 to the ACPI table (bnc#1012628).
- CIFS: Fix NULL pointer deref on SMB2_tcon() failure
  (bnc#1012628).
- cifs: Select all required crypto modules (bnc#1012628).
- xen: fix booting ballooned down hvm guest (bnc#1012628).
- xen/gntdev: avoid out of bounds access in case of partial
  gntdev_mmap() (bnc#1012628).
- fuse: fix READDIRPLUS skipping an entry (bnc#1012628).
- ovl: do not cleanup unsupported index entries (bnc#1012628).
- ovl: handle ENOENT on index lookup (bnc#1012628).
- ovl: fix EIO from lookup of non-indexed upper (bnc#1012628).
- ovl: add NULL check in ovl_alloc_inode (bnc#1012628).
- spi: armada-3700: Fix failing commands with quad-SPI
  (bnc#1012628).
- spi: bcm-qspi: Fix use after free in bcm_qspi_probe() in error
  path (bnc#1012628).
- spi: a3700: Return correct value on timeout detection
  (bnc#1012628).
- spi: uapi: spidev: add missing ioctl header (bnc#1012628).
- nbd: handle interrupted sendmsg with a sndtimeo set
  (bnc#1012628).
- s390/kvm: fix detection of guest machine checks (bnc#1012628).
- KVM: PPC: Book3S: Protect kvmppc_gpa_to_ua() with SRCU
  (bnc#1012628).
- KVM: PPC: Book3S HV: POWER9 more doorbell fixes (bnc#1012628).
- KVM: PPC: Fix oops when checking KVM_CAP_PPC_HTM (bnc#1012628).
- Fix tracing sample code warning (bnc#1012628).
- ceph: unlock dangling spinlock in try_flush_caps()
  (bnc#1012628).
- ALSA: hda - fix headset mic problem for Dell machines with
  alc236 (bnc#1012628).
- ALSA: hda/realtek - Add support for ALC236/ALC3204
  (bnc#1012628).
- nvme-fc: fix iowait hang (bnc#1012628).
- workqueue: replace pool->manager_arb mutex with a flag
  (bnc#1012628).
- commit 5a48675
* Mon Oct 30 2017 neilb@suse.com
- REVERT:  md/bitmap: copy correct data for bitmap super
  (bsc#1062597).
- commit 9382440
* Mon Oct 30 2017 jslaby@suse.cz
- x86/unwind: Show function name+offset in ORC error messages
  (bnc#1058115).
- x86/entry: Fix idtentry unwind hint (bnc#1058115).
- objtool: Fix memory leak in decode_instructions() (bnc#1058115).
- x86/unwind: Disable unwinder warnings on 32-bit (bnc#1058115).
- x86/unwind: Align stack pointer in unwinder dump (bnc#1058115).
- x86/unwind: Use MSB for frame pointer encoding on 32-bit
  (bnc#1058115).
- x86/unwind: Fix dereference of untrusted pointer (bnc#1058115).
- x86/kvm: Move kvm_fastop_exception to .fixup section
  (bnc#1058115).
- objtool: Upgrade libelf-devel warning to error for
  CONFIG_ORC_UNWINDER (bnc#1058115).
- kprobes/x86: Set up frame pointer in kprobe trampoline
  (bnc#1058115).
- objtool: Support unoptimized frame pointer setup (bnc#1058115).
- objtool: Skip unreachable warnings for GCC 4.4 and older
  (bnc#1058115).
- commit dd8c5e5
* Mon Oct 30 2017 jeffm@suse.com
- Update to 4.14-rc7.
- commit dbf3e9b
* Sun Oct 29 2017 jslaby@suse.cz
- x86/unwind: Show function name+offset in ORC error messages
  (bnc#1058115).
- x86/entry: Fix idtentry unwind hint (bnc#1058115).
- commit 951f578
* Fri Oct 27 2017 jslaby@suse.cz
- Linux 4.13.10 final
- commit db36cf8
* Fri Oct 27 2017 jslaby@suse.cz
- scripts/stableids: revert unwanted change
- commit d6206ec
* Fri Oct 27 2017 jslaby@suse.cz
- futex: futex_wake_op, fix sign_extend32 sign bits (bnc#1064590).
- commit a6d946f
* Thu Oct 26 2017 neilb@suse.com
- VFS: expedite unmount (bsc#1024412).
- commit 10c4365
* Wed Oct 25 2017 jslaby@suse.cz
- Linux 4.13.10 (bnc#1012628).
- staging: bcm2835-audio: Fix memory corruption (bnc#1012628).
- USB: devio: Revert "USB: devio: Don't corrupt user memory"
  (bnc#1012628).
- USB: core: fix out-of-bounds access bug in
  usb_get_bos_descriptor() (bnc#1012628).
- USB: serial: metro-usb: add MS7820 device id (bnc#1012628).
- usb: cdc_acm: Add quirk for Elatec TWN3 (bnc#1012628).
- usb: quirks: add quirk for WORLDE MINI MIDI keyboard
  (bnc#1012628).
- usb: hub: Allow reset retry for USB2 devices on connect bounce
  (bnc#1012628).
- ALSA: usb-audio: Add native DSD support for Pro-Ject Pre Box
  S2 Digital (bnc#1012628).
- can: gs_usb: fix busy loop if no more TX context is available
  (bnc#1012628).
- scsi: qla2xxx: Fix uninitialized work element (bnc#1012628).
- nbd: don't set the device size until we're connected
  (bnc#1012628).
- s390/cputime: fix guest/irq/softirq times after CPU hotplug
  (bnc#1012628).
- parisc: Fix double-word compare and exchange in LWS code on
  32-bit kernels (bnc#1012628).
- parisc: Fix detection of nonsynchronous cr16 cycle counters
  (bnc#1012628).
- iio: dummy: events: Add missing break (bnc#1012628).
- usb: musb: sunxi: Explicitly release USB PHY on exit
  (bnc#1012628).
- USB: musb: fix session-bit runtime-PM quirk (bnc#1012628).
- USB: musb: fix late external abort on suspend (bnc#1012628).
- usb: musb: musb_cppi41: Fix the address of teardown and autoreq
  registers (bnc#1012628).
- usb: musb: musb_cppi41: Fix cppi41_set_dma_mode() for DA8xx
  (bnc#1012628).
- usb: musb: musb_cppi41: Configure the number of channels for
  DA8xx (bnc#1012628).
- usb: musb: Check for host-mode using is_host_active() on reset
  interrupt (bnc#1012628).
- xhci: Identify USB 3.1 capable hosts by their port protocol
  capability (bnc#1012628).
- xhci: Cleanup current_cmd in xhci_cleanup_command_queue()
  (bnc#1012628).
- usb: xhci: Reset halted endpoint if trb is noop (bnc#1012628).
- usb: xhci: Handle error condition in xhci_stop_device()
  (bnc#1012628).
- can: esd_usb2: Fix can_dlc value for received RTR, frames
  (bnc#1012628).
- can: af_can: can_pernet_init(): add missing error handling
  for kzalloc returning NULL (bnc#1012628).
- can: flexcan: fix state transition regression (bnc#1012628).
- can: flexcan: rename legacy error state quirk (bnc#1012628).
- can: flexcan: implement error passive state quirk (bnc#1012628).
- can: flexcan: fix i.MX6 state transition issue (bnc#1012628).
- can: flexcan: fix i.MX28 state transition issue (bnc#1012628).
- can: flexcan: fix p1010 state transition issue (bnc#1012628).
- KEYS: encrypted: fix dereference of NULL user_key_payload
  (bnc#1012628).
- mmc: sdhci-pci: Fix default d3_retune for Intel host controllers
  (bnc#1012628).
- drm/i915: Use bdw_ddi_translations_fdi for Broadwell
  (bnc#1012628).
- drm/nouveau/kms/nv50: fix oops during DP IRQ handling on
  non-MST boards (bnc#1012628).
- drm/nouveau/bsp/g92: disable by default (bnc#1012628).
- drm/nouveau/mmu: flush tlbs before deleting page tables
  (bnc#1012628).
- media: s5p-cec: add NACK detection support (bnc#1012628).
- media: cec: Respond to unregistered initiators, when applicable
  (bnc#1012628).
- media: dvb: i2c transfers over usb cannot be done from stack
  (bnc#1012628).
- tracing/samples: Fix creation and deletion of simple_thread_fn
  creation (bnc#1012628).
- ALSA: seq: Enable 'use' locking in all configurations
  (bnc#1012628).
- ALSA: hda: Remove superfluous '-' added by printk conversion
  (bnc#1012628).
- i2c: ismt: Separate I2C block read from SMBus block read
  (bnc#1012628).
- i2c: piix4: Fix SMBus port selection for AMD Family 17h chips
  (bnc#1012628).
- Revert "tools/power turbostat: stop migrating, unless '-m'"
  (bnc#1012628).
- Input: stmfts - fix setting ABS_MT_POSITION_* maximum size
  (bnc#1012628).
- brcmfmac: Add check for short event packets (bnc#1012628).
- brcmsmac: make some local variables 'static const' to reduce
  stack size (bnc#1012628).
- ARM: dts: sun6i: Fix endpoint IDs in second display pipeline
  (bnc#1012628).
- bus: mbus: fix window size calculation for 4GB windows
  (bnc#1012628).
- clockevents/drivers/cs5535: Improve resilience to spurious
  interrupts (bnc#1012628).
- rtlwifi: rtl8821ae: Fix connection lost problem (bnc#1012628).
- x86/microcode/intel: Disable late loading on model 79
  (bnc#1012628).
- lib/digsig: fix dereference of NULL user_key_payload
  (bnc#1012628).
- fscrypt: fix dereference of NULL user_key_payload (bnc#1012628).
- ecryptfs: fix dereference of NULL user_key_payload
  (bnc#1012628).
- KEYS: Fix race between updating and finding a negative key
  (bnc#1012628).
- FS-Cache: fix dereference of NULL user_key_payload
  (bnc#1012628).
- KEYS: don't let add_key() update an uninstantiated key
  (bnc#1012628).
- pkcs7: Prevent NULL pointer dereference, since sinfo is not
  always set (bnc#1012628).
- arm64: dts: rockchip: correct vqmmc voltage for rk3399 platforms
  (bnc#1012628).
- ALSA: hda - Fix incorrect TLV callback check introduced during
  set_fs() removal (bnc#1012628).
- iomap_dio_rw: Allocate AIO completion queue before submitting
  dio (bnc#1012628).
- xfs: don't unconditionally clear the reflink flag on zero-block
  files (bnc#1012628).
- xfs: evict CoW fork extents when performing finsert/fcollapse
  (bnc#1012628).
- fs/xfs: Use %%pS printk format for direct addresses
  (bnc#1012628).
- xfs: report zeroed or not correctly in xfs_zero_range()
  (bnc#1012628).
- xfs: update i_size after unwritten conversion in dio completion
  (bnc#1012628).
- xfs: perag initialization should only touch m_ag_max_usable
  for AG 0 (bnc#1012628).
- xfs: Capture state of the right inode in xfs_iflush_done
  (bnc#1012628).
- xfs: always swap the cow forks when swapping extents
  (bnc#1012628).
- xfs: handle racy AIO in xfs_reflink_end_cow (bnc#1012628).
- xfs: Don't log uninitialised fields in inode structures
  (bnc#1012628).
- xfs: move more RT specific code under CONFIG_XFS_RT
  (bnc#1012628).
- xfs: don't change inode mode if ACL update fails (bnc#1012628).
- xfs: reinit btree pointer on attr tree inactivation walk
  (bnc#1012628).
- xfs: handle error if xfs_btree_get_bufs fails (bnc#1012628
  bsc#1059863).
- xfs: cancel dirty pages on invalidation (bnc#1012628).
- xfs: trim writepage mapping to within eof (bnc#1012628).
- xfs: move two more RT specific functions into CONFIG_XFS_RT
  (bnc#1012628).
- scripts/stableids:
- commit e760ea6
* Mon Oct 23 2017 jeffm@suse.com
- Update to 4.14-rc6.
- Eliminated 2 patches.
- commit 8b364ca
* Mon Oct 23 2017 jslaby@suse.cz
- futex: do not fail on invalid op (bnc#1064590).
- commit e7d7106
* Sun Oct 22 2017 jslaby@suse.cz
- Linux 4.13.9 (bnc#1012628).
- vmbus: more host signalling avoidance (bnc#1012628).
- vmbus: eliminate duplicate cached index (bnc#1012628).
- vmbus: refactor hv_signal_on_read (bnc#1012628).
- vmbus: simplify hv_ringbuffer_read (bnc#1012628).
- Drivers: hv: vmbus: Fix bugs in rescind handling (bnc#1012628).
- Drivers: hv: vmbus: Fix rescind handling issues (bnc#1012628).
- HID: hid-elecom: extend to fix descriptor for HUGE trackball
  (bnc#1012628).
- mm: page_vma_mapped: ensure pmd is loaded with READ_ONCE
  outside of lock (bnc#1012628).
- perf pmu: Unbreak perf record for arm/arm64 with events with
  explicit PMU (bnc#1012628).
- x86/apic: Silence "FW_BUG TSC_DEADLINE disabled due to Errata"
  on hypervisors (bnc#1012628).
- x86/apic: Silence "FW_BUG TSC_DEADLINE disabled due to Errata"
  on CPUs without the feature (bnc#1012628).
- commit abdc07c
* Wed Oct 18 2017 mcgrof@suse.com
- mac80211: accept key reinstall without changing anything (CVE-2017-13080 bsc#1063667).
- commit 19d19fc
* Wed Oct 18 2017 tiwai@suse.de
- ALSA: hda: Abort capability probe at invalid register read
  (bsc#1064017).
- commit d1f5e26
* Wed Oct 18 2017 jslaby@suse.cz
- Linux 4.13.8 (bnc#1012628).
- USB: dummy-hcd: Fix deadlock caused by disconnect detection
  (bnc#1012628).
- MIPS: math-emu: Remove pr_err() calls from fpu_emu()
  (bnc#1012628).
- MIPS: bpf: Fix uninitialised target compiler error
  (bnc#1012628).
- mei: always use domain runtime pm callbacks (bnc#1012628).
- dmaengine: edma: Align the memcpy acnt array size with the
  transfer (bnc#1012628).
- dmaengine: ti-dma-crossbar: Fix possible race condition with
  dma_inuse (bnc#1012628).
- NFS: Fix uninitialized rpc_wait_queue (bnc#1012628).
- nfs/filelayout: fix oops when freeing filelayout segment
  (bnc#1012628).
- HID: usbhid: fix out-of-bounds bug (bnc#1012628).
- crypto: skcipher - Fix crash on zero-length input (bnc#1012628).
- crypto: shash - Fix zero-length shash ahash digest crash
  (bnc#1012628).
- KVM: MMU: always terminate page walks at level 1 (bnc#1012628).
- KVM: nVMX: fix guest CR4 loading when emulating L2 to L1 exit
  (bnc#1012628).
- usb: renesas_usbhs: Fix DMAC sequence for receiving zero-length
  packet (bnc#1012628).
- pinctrl/amd: Fix build dependency on pinmux code (bnc#1012628).
- iommu/amd: Finish TLB flush in amd_iommu_unmap() (bnc#1012628).
- device property: Track owner device of device property
  (bnc#1012628).
- Revert "vmalloc: back off when the current task is killed"
  (bnc#1012628).
- fs/mpage.c: fix mpage_writepage() for pages with buffers
  (bnc#1012628).
- ALSA: usb-audio: Kill stray URB at exiting (bnc#1012628).
- ALSA: seq: Fix copy_from_user() call inside lock (bnc#1012628).
- ALSA: caiaq: Fix stray URB at probe error path (bnc#1012628).
- ALSA: line6: Fix NULL dereference at podhd_disconnect()
  (bnc#1012628).
- ALSA: line6: Fix missing initialization before error path
  (bnc#1012628).
- ALSA: line6: Fix leftover URB at error-path during probe
  (bnc#1012628).
- drm/atomic: Unref duplicated drm_atomic_state in
  drm_atomic_helper_resume() (bnc#1012628).
- drm/i915/edp: Get the Panel Power Off timestamp after panel
  is off (bnc#1012628).
- drm/i915: Read timings from the correct transcoder in
  intel_crtc_mode_get() (bnc#1012628).
- drm/i915/bios: parse DDI ports also for CHV for HDMI DDC pin
  and DP AUX channel (bnc#1012628).
- drm/i915: Use crtc_state_is_legacy_gamma in intel_color_check
  (bnc#1012628).
- usb: gadget: configfs: Fix memory leak of interface directory
  data (bnc#1012628).
- usb: gadget: composite: Fix use-after-free in
  usb_composite_overwrite_options (bnc#1012628).
- PCI: aardvark: Move to struct pci_host_bridge IRQ mapping
  functions (bnc#1012628).
- Revert "PCI: tegra: Do not allocate MSI target memory"
  (bnc#1012628).
- direct-io: Prevent NULL pointer access in submit_page_section
  (bnc#1012628).
- fix unbalanced page refcounting in bio_map_user_iov
  (bnc#1012628).
- more bio_map_user_iov() leak fixes (bnc#1012628).
- bio_copy_user_iov(): don't ignore ->iov_offset (bnc#1012628).
- perf script: Add missing separator for "-F ip,brstack" (and
  brstackoff) (bnc#1012628).
- genirq/cpuhotplug: Enforce affinity setting on startup of
  managed irqs (bnc#1012628).
- genirq/cpuhotplug: Add sanity check for effective affinity mask
  (bnc#1012628).
- USB: serial: ftdi_sio: add id for Cypress WICED dev board
  (bnc#1012628).
- USB: serial: cp210x: fix partnum regression (bnc#1012628).
- USB: serial: cp210x: add support for ELV TFD500 (bnc#1012628).
- USB: serial: option: add support for TP-Link LTE module
  (bnc#1012628).
- USB: serial: qcserial: add Dell DW5818, DW5819 (bnc#1012628).
- USB: serial: console: fix use-after-free on disconnect
  (bnc#1012628).
- USB: serial: console: fix use-after-free after failed setup
  (bnc#1012628).
- RAS/CEC: Use the right length for "cec_disable" (bnc#1012628).
- x86/microcode: Do the family check first (bnc#1012628).
- x86/alternatives: Fix alt_max_short macro to really be a max()
  (bnc#1012628).
- KVM: nVMX: update last_nonleaf_level when initializing nested
  EPT (bnc#1012628).
- commit 569e26e
* Wed Oct 18 2017 mcgrof@suse.com
- xfs: handle error if xfs_btree_get_bufs fails (bsc#1059863).
- commit a1a185d
* Mon Oct 16 2017 jeffm@suse.com
- Update to 4.14-rc5.
- commit 39eecab
* Mon Oct 16 2017 jslaby@suse.cz
- futex: Remove duplicated code and fix undefined behaviour
  (bnc#1005915).
- commit b17692d
* Sun Oct 15 2017 jslaby@suse.cz
- Linux 4.13.7 (bnc#1012628).
- commit 031d6da
* Fri Oct 13 2017 msuchanek@suse.de
- Revert "rpm/constraints.in: Lower default disk space requirement from 25G to 24G"
  This reverts commit 406abda1467c038842febffe264faae1fa2e3c1d.
  ok, did not wait long enough to see the failure.
- commit ed99981
* Fri Oct 13 2017 msuchanek@suse.de
- rpm/constraints.in: Lower default disk space requirement from 25G to 24G
  25G is rejected by the build service on ARM.
- commit 406abda
* Fri Oct 13 2017 jslaby@suse.cz
- waitid(): Add missing access_ok() checks (bnc#1062473
  CVE-2017-5123).
- commit a8d2202
* Thu Oct 12 2017 jslaby@suse.cz
- Linux 4.13.6 (bnc#1012628).
- imx-media-of: avoid uninitialized variable warning
  (bnc#1012628).
- usb: dwc3: ep0: fix DMA starvation by assigning req->trb on ep0
  (bnc#1012628).
- mlxsw: spectrum: Fix EEPROM access in case of SFP/SFP+
  (bnc#1012628).
- net: bonding: Fix transmit load balancing in balance-alb mode
  if specified by sysfs (bnc#1012628).
- openvswitch: Fix an error handling path in
  'ovs_nla_init_match_and_action()' (bnc#1012628).
- mlxsw: spectrum: Prevent mirred-related crash on removal
  (bnc#1012628).
- net: bonding: fix tlb_dynamic_lb default value (bnc#1012628).
- net_sched: gen_estimator: fix scaling error in bytes/packets
  samples (bnc#1012628).
- net: sched: fix use-after-free in tcf_action_destroy and
  tcf_del_walker (bnc#1012628).
- sctp: potential read out of bounds in
  sctp_ulpevent_type_enabled() (bnc#1012628).
- tcp: update skb->skb_mstamp more carefully (bnc#1012628).
- bpf/verifier: reject BPF_ALU64|BPF_END (bnc#1012628).
- tcp: fix data delivery rate (bnc#1012628).
- udpv6: Fix the checksum computation when HW checksum does not
  apply (bnc#1012628).
- ip6_gre: skb_push ipv6hdr before packing the header in
  ip6gre_header (bnc#1012628).
- net: phy: Fix mask value write on gmii2rgmii converter speed
  register (bnc#1012628).
- ip6_tunnel: do not allow loading ip6_tunnel if ipv6 is disabled
  in cmdline (bnc#1012628).
- net/sched: cls_matchall: fix crash when used with classful qdisc
  (bnc#1012628).
- bpf: do not disable/enable BH in bpf_map_free_id()
  (bnc#1012628).
- tcp: fastopen: fix on syn-data transmit failure (bnc#1012628).
- net: emac: Fix napi poll list corruption (bnc#1012628).
- net: ipv6: fix regression of no RTM_DELADDR sent after DAD
  failure (bnc#1012628).
- packet: hold bind lock when rebinding to fanout hook
  (bnc#1012628).
- bpf: one perf event close won't free bpf program attached by
  another perf event (bnc#1012628).
- net: change skb->mac_header when Generic XDP calls adjust_head
  (bnc#1012628).
- isdn/i4l: fetch the ppp_write buffer in one shot (bnc#1012628).
- net_sched: always reset qdisc backlog in qdisc_reset()
  (bnc#1012628).
- net: stmmac: Cocci spatch "of_table" (bnc#1012628).
- net: qcom/emac: specify the correct size when mapping a DMA
  buffer (bnc#1012628).
- vti: fix use after free in vti_tunnel_xmit/vti6_tnl_xmit
  (bnc#1012628).
- l2tp: fix race condition in l2tp_tunnel_delete (bnc#1012628).
- tun: bail out from tun_get_user() if the skb is empty
  (bnc#1012628).
- net: dsa: mv88e6xxx: Allow dsa and cpu ports in multiple vlans
  (bnc#1012628).
- net: dsa: Fix network device registration order (bnc#1012628).
- packet: in packet_do_bind, test fanout with bind_lock held
  (bnc#1012628).
- packet: only test po->has_vnet_hdr once in packet_snd
  (bnc#1012628).
- net: dsa: mv88e6xxx: lock mutex when freeing IRQs (bnc#1012628).
- net: Set sk_prot_creator when cloning sockets to the right proto
  (bnc#1012628).
- net/mlx5e: IPoIB, Fix access to invalid memory address
  (bnc#1012628).
- netlink: do not proceed if dump's start() errs (bnc#1012628).
- ip6_gre: ip6gre_tap device should keep dst (bnc#1012628).
- ip6_tunnel: update mtu properly for ARPHRD_ETHER tunnel device
  in tx path (bnc#1012628).
- IPv4: early demux can return an error code (bnc#1012628).
- tipc: use only positive error codes in messages (bnc#1012628).
- l2tp: fix l2tp_eth module loading (bnc#1012628).
- socket, bpf: fix possible use after free (bnc#1012628).
- net: rtnetlink: fix info leak in RTM_GETSTATS call
  (bnc#1012628).
- bpf: fix bpf_tail_call() x64 JIT (bnc#1012628).
- usb: gadget: core: fix ->udc_set_speed() logic (bnc#1012628).
- USB: gadgetfs: Fix crash caused by inadequate synchronization
  (bnc#1012628).
- USB: gadgetfs: fix copy_to_user while holding spinlock
  (bnc#1012628).
- usb: gadget: udc: atmel: set vbus irqflags explicitly
  (bnc#1012628).
- usb: gadget: udc: renesas_usb3: fix for no-data control transfer
  (bnc#1012628).
- usb: gadget: udc: renesas_usb3: fix Pn_RAMMAP.Pn_MPKT value
  (bnc#1012628).
- usb: gadget: udc: renesas_usb3: Fix return value of
  usb3_write_pipe() (bnc#1012628).
- usb-storage: unusual_devs entry to fix write-access regression
  for Seagate external drives (bnc#1012628).
- usb-storage: fix bogus hardware error messages for ATA pass-thru
  devices (bnc#1012628).
- usb: renesas_usbhs: fix the BCLR setting condition for non-DCP
  pipe (bnc#1012628).
- usb: renesas_usbhs: fix usbhsf_fifo_clear() for RX direction
  (bnc#1012628).
- ALSA: usb-audio: Check out-of-bounds access by corrupted buffer
  descriptor (bnc#1012628).
- usb: pci-quirks.c: Corrected timeout values used in handshake
  (bnc#1012628).
- USB: cdc-wdm: ignore -EPIPE from GetEncapsulatedResponse
  (bnc#1012628).
- USB: dummy-hcd: fix connection failures (wrong speed)
  (bnc#1012628).
- USB: dummy-hcd: fix infinite-loop resubmission bug
  (bnc#1012628).
- USB: dummy-hcd: Fix erroneous synchronization change
  (bnc#1012628).
- USB: devio: Prevent integer overflow in proc_do_submiturb()
  (bnc#1012628).
- USB: devio: Don't corrupt user memory (bnc#1012628).
- USB: g_mass_storage: Fix deadlock when driver is unbound
  (bnc#1012628).
- USB: uas: fix bug in handling of alternate settings
  (bnc#1012628).
- USB: core: harden cdc_parse_cdc_header (bnc#1012628).
- usb: Increase quirk delay for USB devices (bnc#1012628).
- USB: fix out-of-bounds in usb_set_configuration (bnc#1012628).
- usb: xhci: Free the right ring in xhci_add_endpoint()
  (bnc#1012628).
- xhci: fix finding correct bus_state structure for USB 3.1 hosts
  (bnc#1012628).
- xhci: fix wrong endpoint ESIT value shown in tracing
  (bnc#1012628).
- usb: host: xhci-plat: allow sysdev to inherit from ACPI
  (bnc#1012628).
- xhci: Fix sleeping with spin_lock_irq() held in ASmedia 1042A
  workaround (bnc#1012628).
- xhci: set missing SuperSpeedPlus Link Protocol bit in roothub
  descriptor (bnc#1012628).
- Revert "xhci: Limit USB2 port wake support for AMD Promontory
  hosts" (bnc#1012628).
- iio: adc: twl4030: Fix an error handling path in
  'twl4030_madc_probe()' (bnc#1012628).
- iio: adc: twl4030: Disable the vusb3v1 rugulator in the error
  handling path of 'twl4030_madc_probe()' (bnc#1012628).
- iio: ad_sigma_delta: Implement a dedicated reset function
  (bnc#1012628).
- staging: iio: ad7192: Fix - use the dedicated reset function
  avoiding dma from stack (bnc#1012628).
- iio: core: Return error for failed read_reg (bnc#1012628).
- IIO: BME280: Updates to Humidity readings need ctrl_reg
  write! (bnc#1012628).
- iio: trigger: stm32-timer: preset shouldn't be buffered
  (bnc#1012628).
- iio: trigger: stm32-timer: fix a corner case to write preset
  (bnc#1012628).
- iio: ad7793: Fix the serial interface reset (bnc#1012628).
- iio: adc: stm32: fix bad error check on max_channels
  (bnc#1012628).
- iio: adc: mcp320x: Fix readout of negative voltages
  (bnc#1012628).
- iio: adc: mcp320x: Fix oops on module unload (bnc#1012628).
- uwb: properly check kthread_run return value (bnc#1012628).
- uwb: ensure that endpoint is interrupt (bnc#1012628).
- staging: vchiq_2835_arm: Fix NULL ptr dereference in
  free_pagelist (bnc#1012628).
- ksm: fix unlocked iteration over vmas in cmp_and_merge_page()
  (bnc#1012628).
- mm, hugetlb, soft_offline: save compound page order before
  page migration (bnc#1012628).
- mm, oom_reaper: skip mm structs with mmu notifiers
  (bnc#1012628).
- mm: fix RODATA_TEST failure "rodata_test: test data was not
  read only" (bnc#1012628).
- mm: avoid marking swap cached page as lazyfree (bnc#1012628).
- mm: fix data corruption caused by lazyfree page (bnc#1012628).
- userfaultfd: non-cooperative: fix fork use after free
  (bnc#1012628).
- lib/ratelimit.c: use deferred printk() version (bnc#1012628).
- lsm: fix smack_inode_removexattr and xattr_getsecurity memleak
  (bnc#1012628).
- ALSA: compress: Remove unused variable (bnc#1012628).
- Revert "ALSA: echoaudio: purge contradictions between dimension
  matrix members and total number of members" (bnc#1012628).
- ALSA: usx2y: Suppress kernel warning at page allocation failures
  (bnc#1012628).
- powerpc/powernv: Increase memory block size to 1GB on radix
  (bnc#1012628).
- powerpc: Fix action argument for cpufeatures-based TLB flush
  (bnc#1012628).
- powerpc/64s: Use emergency stack for kernel TM Bad Thing
  program checks (bnc#1012628).
- powerpc/tm: Fix illegal TM state in signal handler
  (bnc#1012628).
- percpu: make this_cpu_generic_read() atomic w.r.t. interrupts
  (bnc#1012628).
- intel_th: pci: Add Lewisburg PCH support (bnc#1012628).
- driver core: platform: Don't read past the end of
  "driver_override" buffer (bnc#1012628).
- cgroup: Reinit cgroup_taskset structure before
  cgroup_migrate_execute() returns (bnc#1012628).
- Drivers: hv: fcopy: restore correct transfer length
  (bnc#1012628).
- vmbus: don't acquire the mutex in
  vmbus_hvsock_device_unregister() (bnc#1012628).
- stm class: Fix a use-after-free (bnc#1012628).
- auxdisplay: charlcd: properly restore atomic counter on error
  path (bnc#1012628).
- ftrace: Fix kmemleak in unregister_ftrace_graph (bnc#1012628).
- ovl: fix error value printed in ovl_lookup_index()
  (bnc#1012628).
- ovl: fix dput() of ERR_PTR in ovl_cleanup_index() (bnc#1012628).
- ovl: fix dentry leak in ovl_indexdir_cleanup() (bnc#1012628).
- ovl: fix missing unlock_rename() in ovl_do_copy_up()
  (bnc#1012628).
- ovl: fix regression caused by exclusive upper/work dir
  protection (bnc#1012628).
- arm64: dt marvell: Fix AP806 system controller size
  (bnc#1012628).
- HID: rmi: Make sure the HID device is opened on resume
  (bnc#1012628).
- HID: i2c-hid: allocate hid buffers for real worst case
  (bnc#1012628).
- HID: wacom: leds: Don't try to control the EKR's read-only LEDs
  (bnc#1012628).
- HID: wacom: Properly report negative values from Intuos Pro
  2 Bluetooth (bnc#1012628).
- HID: wacom: Correct coordinate system of touchring and pen twist
  (bnc#1012628).
- HID: wacom: generic: Send MSC_SERIAL and ABS_MISC when leaving
  prox (bnc#1012628).
- HID: wacom: generic: Clear ABS_MISC when tool leaves proximity
  (bnc#1012628).
- HID: wacom: Always increment hdev refcount within
  wacom_get_hdev_data (bnc#1012628).
- HID: wacom: bits shifted too much for 9th and 10th buttons
  (bnc#1012628).
- btrfs: avoid overflow when sector_t is 32 bit (bnc#1012628).
- Btrfs: fix overlap of fs_info::flags values (bnc#1012628).
- rocker: fix rocker_tlv_put_* functions for KASAN (bnc#1012628).
- netlink: fix nla_put_{u8,u16,u32} for KASAN (bnc#1012628).
- dm crypt: reject sector_size feature if device length is not
  aligned to it (bnc#1012628).
- dm ioctl: fix alignment of event number in the device list
  (bnc#1012628).
- dm crypt: fix memory leak in crypt_ctr_cipher_old()
  (bnc#1012628).
- KVM: PPC: Book3S: Fix server always zero from
  kvmppc_xive_get_xive() (bnc#1012628).
- kvm/x86: Avoid async PF preempting the kernel incorrectly
  (bnc#1012628).
- iwlwifi: mvm: use IWL_HCMD_NOCOPY for MCAST_FILTER_CMD
  (bnc#1012628).
- scsi: sd: Implement blacklist option for WRITE SAME w/ UNMAP
  (bnc#1012628).
- scsi: sd: Do not override max_sectors_kb sysfs setting
  (bnc#1012628).
- brcmfmac: add length check in brcmf_cfg80211_escan_handler()
  (bnc#1012628).
- brcmfmac: setup passive scan if requested by user-space
  (bnc#1012628).
- drm/i915: always update ELD connector type after get modes
  (bnc#1012628).
- drm/i915/bios: ignore HDMI on port A (bnc#1012628).
- bsg-lib: fix use-after-free under memory-pressure (bnc#1012628).
- nvme-pci: Use PCI bus address for data/queues in CMB
  (bnc#1012628).
- mmc: core: add driver strength selection when selecting hs400es
  (bnc#1012628).
- nl80211: Define policy for packet pattern attributes
  (bnc#1012628).
- clk: samsung: exynos4: Enable VPLL and EPLL clocks for
  suspend/resume cycle (bnc#1012628).
- udp: perform source validation for mcast early demux
  (bnc#1012628).
- udp: fix bcast packet reception (bnc#1012628).
- base: arch_topology: fix section mismatch build warnings
  (bnc#1012628).
- commit 5a88d59
* Wed Oct 11 2017 tiwai@suse.de
- ALSA: seq: Fix use-after-free at creating a port
  (CVE-2017-15265, bsc#1062520).
- commit fe07a5d
* Mon Oct  9 2017 mbrugger@suse.com
- arm64: Ensure fpsimd support is ready before userspace is active
  (bsc#1061188).
- arm64: Ensure the instruction emulation is ready for userspace
  (bsc#1061188).
- commit d9ee625
* Mon Oct  9 2017 jeffm@suse.com
- Update to 4.14-rc4.
- commit 879f297
* Fri Oct  6 2017 mwilck@suse.com
- watchdog: Revert "iTCO_wdt: all versions count down twice"
  (bsc#1061556).
- commit c6bc876
* Fri Oct  6 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: add the kernel-binary dependencies to
  kernel-binary-base (bsc#1060333).
- commit 955681c
* Fri Oct  6 2017 pmladek@suse.com
- Delete
  patches.suse/ftrace-x86-xen-use-kernel-identity-mapping-only-when.patch.
  The change is not longer needed with PVOPS Xen (bsc#873195).
- commit 8366b6a
* Thu Oct  5 2017 jeffm@suse.com
- Delete patches.rpmify/cloneconfig.diff.
- commit 437d08e
* Thu Oct  5 2017 jeffm@suse.com
- Only use patches.suse for patches.
  This eliminates patches.arch, patches.drivers, and patches.fixes, and moves
  the patches contained in them to patches.suse.
  Also update feedback for Patch-mainline tags.
- commit 343996e
* Thu Oct  5 2017 jslaby@suse.cz
- Linux 4.13.5 (bnc#1012628).
- cifs: check rsp for NULL before dereferencing in SMB2_open
  (bnc#1012628).
- cifs: release cifs root_cred after exit_cifs (bnc#1012628).
- cifs: release auth_key.response for reconnect (bnc#1012628).
- nvme-pci: fix host memory buffer allocation fallback
  (bnc#1012628).
- nvme-pci: use appropriate initial chunk size for HMB allocation
  (bnc#1012628).
- nvme-pci: propagate (some) errors from host memory buffer setup
  (bnc#1012628).
- dax: remove the pmem_dax_ops->flush abstraction (bnc#1012628).
- dm integrity: do not check integrity for failed read operations
  (bnc#1012628).
- mmc: block: Fix incorrectly initialized requests (bnc#1012628).
- fs/proc: Report eip/esp in /prod/PID/stat for coredumping
  (bnc#1012628).
- scsi: scsi_transport_fc: fix NULL pointer dereference in
  fc_bsg_job_timeout (bnc#1012628).
- SMB3: Add support for multidialect negotiate (SMB2.1 and later)
  (bnc#1012628).
- mac80211: fix VLAN handling with TXQs (bnc#1012628).
- mac80211_hwsim: Use proper TX power (bnc#1012628).
- mac80211: flush hw_roc_start work before cancelling the ROC
  (bnc#1012628).
- mac80211: fix deadlock in driver-managed RX BA session start
  (bnc#1012628).
- genirq: Make sparse_irq_lock protect what it should protect
  (bnc#1012628).
- genirq/msi: Fix populating multiple interrupts (bnc#1012628).
- genirq: Fix cpumask check in __irq_startup_managed()
  (bnc#1012628).
- KVM: PPC: Book3S HV: Hold kvm->lock around call to
  kvmppc_update_lpcr (bnc#1012628).
- KVM: PPC: Book3S HV: Fix bug causing host SLB to be restored
  incorrectly (bnc#1012628).
- KVM: PPC: Book3S HV: Don't access XIVE PIPR register using
  byte accesses (bnc#1012628).
- tracing: Fix trace_pipe behavior for instance traces
  (bnc#1012628).
- tracing: Erase irqsoff trace with empty write (bnc#1012628).
- tracing: Remove RCU work arounds from stack tracer
  (bnc#1012628).
- md/raid5: fix a race condition in stripe batch (bnc#1012628).
- md/raid5: preserve STRIPE_ON_UNPLUG_LIST in
  break_stripe_batch_list (bnc#1012628).
- scsi: scsi_transport_iscsi: fix the issue that iscsi_if_rx
  doesn't parse nlmsg properly (bnc#1012628).
- scsi: aacraid: Fix 2T+ drives on SmartIOC-2000 (bnc#1012628).
- scsi: aacraid: Add a small delay after IOP reset (bnc#1012628).
- drm/exynos: Fix locking in the suspend/resume paths
  (bnc#1012628).
- drm/i915/gvt: Fix incorrect PCI BARs reporting (bnc#1012628).
- Revert "drm/i915/bxt: Disable device ready before shutdown
  command" (bnc#1012628).
- drm/radeon: disable hard reset in hibernate for APUs
  (bnc#1012628).
- crypto: drbg - fix freeing of resources (bnc#1012628).
- crypto: talitos - Don't provide setkey for non hmac hashing algs
  (bnc#1012628).
- crypto: talitos - fix sha224 (bnc#1012628).
- crypto: talitos - fix hashing (bnc#1012628).
- security/keys: properly zero out sensitive key material in
  big_key (bnc#1012628).
- security/keys: rewrite all of big_key crypto (bnc#1012628).
- KEYS: fix writing past end of user-supplied buffer in
  keyring_read() (bnc#1012628).
- KEYS: prevent creating a different user's keyrings
  (bnc#1012628).
- KEYS: prevent KEYCTL_READ on negative key (bnc#1012628).
- libnvdimm, namespace: fix btt claim class crash (bnc#1012628).
- powerpc/eeh: Create PHB PEs after EEH is initialized
  (bnc#1012628).
- powerpc/pseries: Fix parent_dn reference leak in add_dt_node()
  (bnc#1012628).
- powerpc/tm: Flush TM only if CPU has TM feature (bnc#1012628).
- MIPS: Fix perf event init (bnc#1012628).
- s390/perf: fix bug when creating per-thread event (bnc#1012628).
- s390/mm: make pmdp_invalidate() do invalidation only
  (bnc#1012628).
- s390/mm: fix write access check in gup_huge_pmd() (bnc#1012628).
- PM: core: Fix device_pm_check_callbacks() (bnc#1012628).
- Revert "IB/ipoib: Update broadcast object if PKey value was
  changed in index 0" (bnc#1012628).
- Fix SMB3.1.1 guest authentication to Samba (bnc#1012628).
- SMB3: Fix endian warning (bnc#1012628).
- SMB3: Warn user if trying to sign connection that authenticated
  as guest (bnc#1012628).
- SMB: Validate negotiate (to protect against downgrade) even
  if signing off (bnc#1012628).
- SMB3: handle new statx fields (bnc#1012628).
- SMB3: Don't ignore O_SYNC/O_DSYNC and O_DIRECT flags
  (bnc#1012628).
- vfs: Return -ENXIO for negative SEEK_HOLE / SEEK_DATA offsets
  (bnc#1012628).
- libceph: don't allow bidirectional swap of pg-upmap-items
  (bnc#1012628).
- brd: fix overflow in __brd_direct_access (bnc#1012628).
- gfs2: Fix debugfs glocks dump (bnc#1012628).
- bsg-lib: don't free job in bsg_prepare_job (bnc#1012628).
- iw_cxgb4: drop listen destroy replies if no ep found
  (bnc#1012628).
- iw_cxgb4: remove the stid on listen create failure
  (bnc#1012628).
- iw_cxgb4: put ep reference in pass_accept_req() (bnc#1012628).
- rcu: Allow for page faults in NMI handlers (bnc#1012628).
- mmc: sdhci-pci: Fix voltage switch for some Intel host
  controllers (bnc#1012628).
- extable: Consolidate *kernel_text_address() functions
  (bnc#1012628).
- extable: Enable RCU if it is not watching in
  kernel_text_address() (bnc#1012628).
- selftests/seccomp: Support glibc 2.26 siginfo_t.h (bnc#1012628).
- seccomp: fix the usage of get/put_seccomp_filter() in
  seccomp_get_filter() (bnc#1012628).
- arm64: Make sure SPsel is always set (bnc#1012628).
- arm64: mm: Use READ_ONCE when dereferencing pointer to pte table
  (bnc#1012628).
- arm64: fault: Route pte translation faults via
  do_translation_fault (bnc#1012628).
- KVM: VMX: extract __pi_post_block (bnc#1012628).
- KVM: VMX: avoid double list add with VT-d posted interrupts
  (bnc#1012628).
- KVM: VMX: simplify and fix vmx_vcpu_pi_load (bnc#1012628).
- KVM: nVMX: fix HOST_CR3/HOST_CR4 cache (bnc#1012628).
- kvm/x86: Handle async PF in RCU read-side critical sections
  (bnc#1012628).
- KVM: VMX: Do not BUG() on out-of-bounds guest IRQ (bnc#1012628).
- kvm: nVMX: Don't allow L2 to access the hardware CR8
  (bnc#1012628).
- xfs: validate bdev support for DAX inode flag (bnc#1012628).
- fix infoleak in waitid(2) (bnc#1012628).
- sched/sysctl: Check user input value of sysctl_sched_time_avg
  (bnc#1012628).
- irq/generic-chip: Don't replace domain's name (bnc#1012628).
- mtd: Fix partition alignment check on multi-erasesize devices
  (bnc#1012628).
- mtd: nand: atmel: fix buffer overflow in atmel_pmecc_user
  (bnc#1012628).
- etnaviv: fix submit error path (bnc#1012628).
- etnaviv: fix gem object list corruption (bnc#1012628).
- futex: Fix pi_state->owner serialization (bnc#1012628).
- md: fix a race condition for flush request handling
  (bnc#1012628).
- md: separate request handling (bnc#1012628).
- PCI: Fix race condition with driver_override (bnc#1012628).
- btrfs: fix NULL pointer dereference from free_reloc_roots()
  (bnc#1012628).
- btrfs: clear ordered flag on cleaning up ordered extents
  (bnc#1012628).
- btrfs: finish ordered extent cleaning if no progress is found
  (bnc#1012628).
- btrfs: propagate error to btrfs_cmp_data_prepare caller
  (bnc#1012628).
- btrfs: prevent to set invalid default subvolid (bnc#1012628).
- PM / OPP: Call notifier without holding opp_table->lock
  (bnc#1012628).
- x86/mm: Fix fault error path using unsafe vma pointer
  (bnc#1012628).
- x86/fpu: Don't let userspace set bogus xcomp_bv (bnc#1012628).
- KVM: VMX: do not change SN bit in vmx_update_pi_irte()
  (bnc#1012628).
- KVM: VMX: remove WARN_ON_ONCE in
  kvm_vcpu_trigger_posted_interrupt (bnc#1012628).
- KVM: VMX: use cmpxchg64 (bnc#1012628).
- video: fbdev: aty: do not leak uninitialized padding in clk
  to userspace (bnc#1012628).
- Update config files.
- commit 3fd9659
* Thu Oct  5 2017 tiwai@suse.de
- Refresh QXL fixes: they've been upstreamed
  patches.drivers/qxl-fix-pinning.patch
  patches.drivers/qxl-fix-primary-surface-handling.patch
- commit 7034d64
* Thu Oct  5 2017 tiwai@suse.de
- platform/x86: peaq-wmi: Add DMI check before binding to the
  WMI interface (bsc#1059807).
- commit a6a03ea
* Wed Oct  4 2017 jeffm@suse.com
- Delete patches.suse/suse-hv-storvsc-sg_tablesize.patch.
  Per Olaf Hering, this is no longer needed.
- commit 83b19a6
* Wed Oct  4 2017 jslaby@suse.cz
- orc: mark it as reliable (bnc#1058115).
- Update config files.
- commit 3cbbf06
* Wed Oct  4 2017 jslaby@suse.cz
- x86/asm: Use register variable to get stack pointer value
  (bnc#1058115).
- commit a5d4692
* Wed Oct  4 2017 jslaby@suse.cz
- x86/asm: Fix inline asm call constraints for GCC 4.4
  (bnc#1058115).
- commit 034c016
* Wed Oct  4 2017 hare@suse.de
- Delete patches.fixes/sd_liberal_28_sense_invalid.diff.
- Delete patches.suse/dm-emulate-blkrrpart-ioctl.
- Delete patches.suse/scsi-netlink-ml.
- commit b8f0083
* Wed Oct  4 2017 agraf@suse.de
- Delete patches.arch/arm-OMAP-Fix-missing-usb.h-include.patch.
  (no longer needed)
- Delete patches.arch/arm-arndale-usb.patch. (no longer needed)
- Delete
  patches.arch/arm64-0006-arm64-Select-reboot-driver-for-X-Gene-platform.patch.
  (not needed, our config already includes the driver)
- Delete patches.arch/ppc64le-build-vmlinux.patch. (no longer needed)
- commit 2b9d327
* Tue Oct  3 2017 jeffm@suse.com
- Disable patches.suse/binutils2_26.patch for testing.
  The issue addressed by this patch should be handled via upstream
  commit 6d92bc9d483 (x86/build: Build compressed x86 kernels as PIE).
- commit f27997b
* Tue Oct  3 2017 neilb@suse.com
- Delete
  patches.fixes/0001-Revert-SUNRPC-xs_sock_mark_closed-does-not-need-to-t.patch.
  Not needed, bug was fixed some other way since that patch
  was created.
- commit d55ee70
* Tue Oct  3 2017 mgorman@suse.de
- Delete patches.suse/connector-read-mostly.
- commit 8ae100a
* Tue Oct  3 2017 jeffm@suse.com
- series.conf: remove commented out lines for removed patches
- commit 7ea9bcc
* Tue Oct  3 2017 jeffm@suse.com
- Delete patches.arch/arm-refresh-mach-types.diff.
  It was marked for refresh in 12/2016 and hasn't been updated.
- commit 8e357d7
* Mon Oct  2 2017 jeffm@suse.com
- Remove s390 message catalog patches.
- Delete patches.arch/kmsg-fix-parameter-limitations.
- Delete patches.arch/s390-message-catalog.diff.
- commit 865e88d
* Mon Oct  2 2017 jeffm@suse.com
- Refresh patches.suse/dm-mpath-accept-failed-paths.
- commit 04a0a7a
* Mon Oct  2 2017 jeffm@suse.com
- Moved powerpc-Blacklist-GCC-5.4-6.1-and-6.2.patch to patches.rpmify.
  It's a compiler blacklist addition and should be applied to vanilla too.
- commit e34eae8
* Mon Oct  2 2017 jeffm@suse.com
- Update to 4.14-rc3.
- Eliminated 2 patches.
- Config changes:
  - Crypto:
  - Crypto changes brought by Kconfig changes:
  - CONFIG_CRYPTO_GHASH=y (Kconfig dependency change)
  - CONFIG_CRYPTO_GCM=y (Kconfig dependency change)
  - armv7hl:
  - DRM_SUN4I_HDMI_CEC=y
  - CONFIG_CEC_PIN=y (dependency)
  - s390x/zfcpdump:
  - Crypto changes brought by Kconfig changes, consistent with other configs:
  - CRYPTO_MANAGER_DISABLE_TESTS=n
  - CRYPTO_DRBG_HASH=y
  - CRYPTO_DRBG_CTR=y
  - Lots of dependencies
- commit 37f329b
* Mon Oct  2 2017 jslaby@suse.cz
- platform/x86: fujitsu-laptop: Don't oops when FUJ02E3 is not
  presnt (bnc#1058814).
- commit 80338f6
* Mon Oct  2 2017 jslaby@suse.cz
- ORC crypto patches: Update upstream status.
- commit 01974c6
* Mon Oct  2 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-objtool-Don-t-report-end-of-section-error-after-an-e.patch.
- Refresh
  patches.suse/0002-x86-head-Remove-confusing-comment.patch.
- Refresh
  patches.suse/0003-x86-head-Remove-unused-bad_address-code.patch.
- Refresh
  patches.suse/0004-x86-head-Fix-head-ELF-function-annotations.patch.
- Refresh
  patches.suse/0005-x86-boot-Annotate-verify_cpu-as-a-callable-function.patch.
- Refresh
  patches.suse/0006-x86-xen-Fix-xen-head-ELF-annotations.patch.
- Refresh
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-head-Add-unwind-hint-annotations.patch.
- Delete
  patches.suse/0002-dwarf-do-not-throw-away-unwind-info.patch.
  Update upstream status and drop the dwarf remainder.
- commit c3e0cbe
* Thu Sep 28 2017 jeffm@suse.com
- Update to 4.14-rc2.
- Eliminated 21 patches.
- commit b61ed0c
* Wed Sep 27 2017 jslaby@suse.cz
- Linux 4.13.4 (bnc#1012628).
- orangefs: Don't clear SGID when inheriting ACLs (bnc#1012628).
- <linux/uaccess.h>: Fix copy_in_user() declaration (bnc#1012628).
- IB/hfi1: Revert egress pkey check enforcement (bnc#1012628).
- IB/{qib, hfi1}: Avoid flow control testing for RDMA write
  operation (bnc#1012628).
- IB/mlx5: Fix cached MR allocation flow (bnc#1012628).
- srcu: Provide ordering for CPU not involved in grace period
  (bnc#1012628).
- smp/hotplug: Handle removal correctly in cpuhp_store_callbacks()
  (bnc#1012628).
- Input: xpad - validate USB endpoint type during probe
  (bnc#1012628).
- drm/amdgpu: read reg in each iterator of psp_wait_for loop
  (bnc#1012628).
- tty: improve tty_insert_flip_char() fast path (bnc#1012628).
- tty: improve tty_insert_flip_char() slow path (bnc#1012628).
- tty: fix __tty_insert_flip_char regression (bnc#1012628).
- pinctrl: samsung: Fix invalid register offset used for
  Exynos5433 external interrupts (bnc#1012628).
- pinctrl: samsung: Fix NULL pointer exception on external
  interrupts on S3C24xx (bnc#1012628).
- pinctrl/amd: save pin registers over suspend/resume
  (bnc#1012628).
- Input: i8042 - add Gigabyte P57 to the keyboard reset table
  (bnc#1012628).
- MIPS: math-emu: <MAX|MAXA|MIN|MINA>.<D|S>: Fix quiet NaN
  propagation (bnc#1012628).
- MIPS: math-emu: <MAX|MAXA|MIN|MINA>.<D|S>: Fix cases of both
  inputs zero (bnc#1012628).
- MIPS: math-emu: <MAX|MIN>.<D|S>: Fix cases of both inputs
  negative (bnc#1012628).
- MIPS: math-emu: <MAXA|MINA>.<D|S>: Fix cases of input values
  with opposite signs (bnc#1012628).
- MIPS: math-emu: <MAXA|MINA>.<D|S>: Fix cases of both infinite
  inputs (bnc#1012628).
- MIPS: math-emu: MINA.<D|S>: Fix some cases of infinity and
  zero inputs (bnc#1012628).
- MIPS: math-emu: <MADDF|MSUBF>.<D|S>: Fix NaN propagation
  (bnc#1012628).
- MIPS: math-emu: <MADDF|MSUBF>.<D|S>: Fix some cases of infinite
  inputs (bnc#1012628).
- MIPS: math-emu: <MADDF|MSUBF>.<D|S>: Fix some cases of zero
  inputs (bnc#1012628).
- MIPS: math-emu: <MADDF|MSUBF>.<D|S>: Clean up "maddf_flags"
  enumeration (bnc#1012628).
- MIPS: math-emu: <MADDF|MSUBF>.S: Fix accuracy (32-bit case)
  (bnc#1012628).
- MIPS: math-emu: <MADDF|MSUBF>.D: Fix accuracy (64-bit case)
  (bnc#1012628).
- docs: disable KASLR when debugging kernel (bnc#1012628).
- crypto: ccp - Fix XTS-AES-128 support on v5 CCPs (bnc#1012628).
- crypto: scompress - don't sleep with preemption disabled
  (bnc#1012628).
- crypto: caam/qi - fix typo in authenc alg driver name
  (bnc#1012628).
- crypto: caam/qi - properly set IV after {en,de}crypt
  (bnc#1012628).
- crypto: AF_ALG - remove SGL terminator indicator when chaining
  (bnc#1012628).
- regulator: cpcap: Fix standby mode (bnc#1012628).
- wcn36xx: Introduce mutual exclusion of fw configuration
  (bnc#1012628).
- ext4: in ext4_seek_{hole,data}, return -ENXIO for negative
  offsets (bnc#1012628).
- ext4: fix incorrect quotaoff if the quota feature is enabled
  (bnc#1012628).
- ext4: fix quota inconsistency during orphan cleanup for
  read-only mounts (bnc#1012628).
- cxl: Fix driver use count (bnc#1012628).
- powerpc/powernv/npu: Move tlb flush before launching ATSD
  (bnc#1012628).
- powerpc/pseries: Don't attempt to acquire drc during memory
  hot add for assigned lmbs (bnc#1012628).
- powerpc: Fix DAR reporting when alignment handler faults
  (bnc#1012628).
- block: Relax a check in blk_start_queue() (bnc#1012628).
- block: directly insert blk-mq request from
  blk_insert_cloned_request() (bnc#1012628).
- md/bitmap: copy correct data for bitmap super (bnc#1012628).
- md/bitmap: disable bitmap_resize for file-backed bitmaps
  (bnc#1012628).
- skd: Avoid that module unloading triggers a use-after-free
  (bnc#1012628).
- skd: Submit requests to firmware before triggering the doorbell
  (bnc#1012628).
- scsi: zfcp: fix queuecommand for scsi_eh commands when DIX
  enabled (bnc#1012628).
- scsi: zfcp: add handling for FCP_RESID_OVER to the fcp ingress
  path (bnc#1012628).
- scsi: zfcp: fix capping of unsuccessful GPN_FT SAN response
  trace records (bnc#1012628).
- scsi: zfcp: fix passing fsf_req to SCSI trace on TMF to
  correlate with HBA (bnc#1012628).
- scsi: zfcp: fix missing trace records for early returns in
  TMF eh handlers (bnc#1012628).
- scsi: zfcp: fix payload with full FCP_RSP IU in SCSI trace
  records (bnc#1012628).
- scsi: zfcp: trace HBA FSF response by default on dismiss or
  timedout late response (bnc#1012628).
- scsi: zfcp: trace high part of "new" 64 bit SCSI LUN
  (bnc#1012628).
- scsi: qedi: off by one in qedi_get_cmd_from_tid() (bnc#1012628).
- scsi: aacraid: Fix command send race condition (bnc#1012628).
- scsi: megaraid_sas: mismatch of allocated MFI frame size and
  length exposed in MFI MPT pass through command (bnc#1012628).
- scsi: megaraid_sas: set minimum value of resetwaittime to be
  1 secs (bnc#1012628).
- scsi: megaraid_sas: Check valid aen class range to avoid kernel
  panic (bnc#1012628).
- scsi: megaraid_sas: Return pended IOCTLs with cmd_status
  MFI_STAT_WRONG_STATE in case adapter is dead (bnc#1012628).
- scsi: storvsc: fix memory leak on ring buffer busy
  (bnc#1012628).
- scsi: sg: factor out sg_fill_request_table() (bnc#1012628).
- scsi: sg: fixup infoleak when using SG_GET_REQUEST_TABLE
  (bnc#1012628).
- scsi: qla2xxx: Update fw_started flags at qpair creation
  (bnc#1012628).
- scsi: qla2xxx: Correction to vha->vref_count timeout
  (bnc#1012628).
- scsi: qla2xxx: Fix target multiqueue configuration
  (bnc#1012628).
- scsi: qla2xxx: Use BIT_6 to acquire FAWWPN from switch
  (bnc#1012628).
- scsi: qla2xxx: Use fabric name for Get Port Speed command
  (bnc#1012628).
- mailbox: bcm-flexrm-mailbox: Fix mask used in
  CMPL_START_ADDR_VALUE() (bnc#1012628).
- ftrace: Fix debug preempt config name in
  stack_tracer_{en,dis}able (bnc#1012628).
- ftrace: Fix selftest goto location on error (bnc#1012628).
- ftrace: Fix memleak when unregistering dynamic ops when tracing
  disabled (bnc#1012628).
- tracing: Add barrier to trace_printk() buffer nesting
  modification (bnc#1012628).
- tracing: Fix clear of RECORDED_TGID flag when disabling trace
  event (bnc#1012628).
- tracing: Apply trace_clock changes to instance max buffer
  (bnc#1012628).
- ARC: Re-enable MMU upon Machine Check exception (bnc#1012628).
- PCI: shpchp: Enable bridge bus mastering if MSI is enabled
  (bnc#1012628).
- PCI: pciehp: Report power fault only once until we clear it
  (bnc#1012628).
- net/netfilter/nf_conntrack_core: Fix net_conntrack_lock()
  (bnc#1012628).
- s390/mm: fix local TLB flushing vs. detach of an mm address
  space (bnc#1012628).
- s390/mm: fix race on mm->context.flush_mm (bnc#1012628).
- media: v4l2-compat-ioctl32: Fix timespec conversion
  (bnc#1012628).
- media: Revert "[media] lirc_dev: remove superfluous
  get/put_device() calls" (bnc#1012628).
- media: venus: fix copy/paste error in return_buf_error
  (bnc#1012628).
- media: uvcvideo: Prevent heap overflow when accessing mapped
  controls (bnc#1012628).
- media: adv7180: add missing adv7180cp, adv7180st i2c device IDs
  (bnc#1012628).
- PM / devfreq: Fix memory leak when fail to register device
  (bnc#1012628).
- ALSA: seq: Cancel pending autoload work at unbinding device
  (bnc#1012628).
- bcache: initialize dirty stripes in flash_dev_run()
  (bnc#1012628).
- bcache: Fix leak of bdev reference (bnc#1012628).
- bcache: do not subtract sectors_to_gc for bypassed IO
  (bnc#1012628).
- bcache: correct cache_dirty_target in __update_writeback_rate()
  (bnc#1012628).
- bcache: Correct return value for sysfs attach errors
  (bnc#1012628).
- bcache: fix sequential large write IO bypass (bnc#1012628).
- bcache: fix for gc and write-back race (bnc#1012628).
- bcache: fix bch_hprint crash and improve output (bnc#1012628).
- sched/cpuset/pm: Fix cpuset vs. suspend-resume bugs
  (bnc#1012628).
- iwlwifi: add workaround to disable wide channels in 5GHz
  (bnc#1012628).
- commit c028f76
* Wed Sep 27 2017 jslaby@suse.cz
- usb: quirks: add delay init quirk for Corsair Strafe RGB
  keyboard (bnc#1012628).
- USB: serial: option: add support for D-Link DWM-157 C1
  (bnc#1012628).
- usb: Add device quirk for Logitech HD Pro Webcam C920-C
  (bnc#1012628).
- usb:xhci:Fix regression when ATI chipsets detected
  (bnc#1012628).
- USB: musb: fix external abort on suspend (bnc#1012628).
- ANDROID: binder: add padding to binder_fd_array_object
  (bnc#1012628).
- ANDROID: binder: add hwbinder,vndbinder to BINDER_DEVICES
  (bnc#1012628).
- USB: core: Avoid race of async_completed() w/ usbdev_release()
  (bnc#1012628).
- staging/rts5208: fix incorrect shift to extract upper nybble
  (bnc#1012628).
- staging: ccree: save ciphertext for CTS IV (bnc#1012628).
- staging: fsl-dpaa2/eth: fix off-by-one FD ctrl bitmaks
  (bnc#1012628).
- iio: adc: ti-ads1015: fix incorrect data rate setting update
  (bnc#1012628).
- iio: adc: ti-ads1015: fix scale information for ADS1115
  (bnc#1012628).
- iio: adc: ti-ads1015: enable conversion when CONFIG_PM is not
  set (bnc#1012628).
- iio: adc: ti-ads1015: avoid getting stale result after runtime
  resume (bnc#1012628).
- iio: adc: ti-ads1015: don't return invalid value from buffer
  setup callbacks (bnc#1012628).
- iio: adc: ti-ads1015: add adequate wait time to get correct
  conversion (bnc#1012628).
- driver core: bus: Fix a potential double free (bnc#1012628).
- HID: wacom: Do not completely map WACOM_HID_WD_TOUCHRINGSTATUS
  usage (bnc#1012628).
- binder: free memory on error (bnc#1012628).
- crypto: caam/qi - fix compilation with
  CONFIG_DEBUG_FORCE_WEAK_PER_CPU=y (bnc#1012628).
- crypto: caam/qi - fix compilation with DEBUG enabled
  (bnc#1012628).
- thunderbolt: Fix reset response_type (bnc#1012628).
- fpga: altera-hps2fpga: fix multiple init of l3_remap_lock
  (bnc#1012628).
- intel_th: pci: Add Cannon Lake PCH-H support (bnc#1012628).
- intel_th: pci: Add Cannon Lake PCH-LP support (bnc#1012628).
- ath10k: fix memory leak in rx ring buffer allocation
  (bnc#1012628).
- drm/vgem: Pin our pages for dmabuf exports (bnc#1012628).
- drm/ttm: Fix accounting error when fail to get pages for pool
  (bnc#1012628).
- drm/dp/mst: Handle errors from
  drm_atomic_get_private_obj_state() correctly (bnc#1012628).
- rtlwifi: rtl_pci_probe: Fix fail path of _rtl_pci_find_adapter
  (bnc#1012628).
- Bluetooth: Add support of 13d3:3494 RTL8723BE device
  (bnc#1012628).
- iwlwifi: pci: add new PCI ID for 7265D (bnc#1012628).
- dlm: avoid double-free on error path in
  dlm_device_{register,unregister} (bnc#1012628).
- mwifiex: correct channel stat buffer overflows (bnc#1012628).
- MCB: add support for SC31 to mcb-lpc (bnc#1012628).
- s390/mm: avoid empty zero pages for KVM guests to avoid postcopy
  hangs (bnc#1012628).
- drm/nouveau/pci/msi: disable MSI on big-endian platforms by
  default (bnc#1012628).
- drm/nouveau: Fix error handling in nv50_disp_atomic_commit
  (bnc#1012628).
- workqueue: Fix flag collision (bnc#1012628).
- ahci: don't use MSI for devices with the silly Intel NVMe
  remapping scheme (bnc#1012628).
- cs5536: add support for IDE controller variant (bnc#1012628).
- scsi: sg: protect against races between mmap() and
  SG_SET_RESERVED_SIZE (bnc#1012628).
- scsi: sg: recheck MMAP_IO request length with lock held
  (bnc#1012628).
- of/device: Prevent buffer overflow in of_device_modalias()
  (bnc#1012628).
- rtlwifi: Fix memory leak when firmware request fails
  (bnc#1012628).
- rtlwifi: Fix fallback firmware loading (bnc#1012628).
- Linux 4.13.1 (bnc#1012628).
- mtd: nand: make Samsung SLC NAND usable again (bnc#1012628).
- mtd: nand: hynix: add support for 20nm NAND chips (bnc#1012628).
- mtd: nand: mxc: Fix mxc_v1 ooblayout (bnc#1012628).
- mtd: nand: qcom: fix read failure without complete bootchain
  (bnc#1012628).
- mtd: nand: qcom: fix config error for BCH (bnc#1012628).
- nvme-fabrics: generate spec-compliant UUID NQNs (bnc#1012628).
- btrfs: resume qgroup rescan on rw remount (bnc#1012628).
- rtlwifi: btcoexist: Fix breakage of ant_sel for rtl8723be
  (bnc#1012628).
- rtlwifi: btcoexist: Fix antenna selection code (bnc#1012628).
- radix-tree: must check __radix_tree_preload() return value
  (bnc#1012628).
- brcmfmac: feature check for multi-scheduled scan fails on
  bcm4345 devices (bnc#1012628).
- kselftests: timers: leap-a-day: Change default arguments to
  help test runs (bnc#1012628).
- selftests: timers: Fix run_destructive_tests target to handle
  skipped tests (bnc#1012628).
- selftests/x86/fsgsbase: Test selectors 1, 2, and 3
  (bnc#1012628).
- mm: kvfree the swap cluster info if the swap file is
  unsatisfactory (bnc#1012628).
- mm/swapfile.c: fix swapon frontswap_map memory leak on error
  (bnc#1012628).
- mm/sparse.c: fix typo in online_mem_sections (bnc#1012628).
- mm/memory.c: fix mem_cgroup_oom_disable() call missing
  (bnc#1012628).
- KVM: SVM: Limit PFERR_NESTED_GUEST_PAGE error_code check to
  L1 guest (bnc#1012628).
- Revert "firmware: add sanity check on shutdown/suspend"
  (bnc#1012628).
- rt2800: fix TX_PIN_CFG setting for non MT7620 chips (bnc#1012628
  bnc#1055826).
- Bluetooth: Properly check L2CAP config option output buffer
  length (bnc#1012628).
- ARM64: dts: marvell: armada-37xx: Fix GIC maintenance interrupt
  (bnc#1012628).
- ARM: 8692/1: mm: abort uaccess retries upon fatal signal
  (bnc#1012628).
- NFS: Fix 2 use after free issues in the I/O code (bnc#1012628).
- NFS: Sync the correct byte range during synchronous writes
  (bnc#1012628).
- NFSv4: Fix up mirror allocation (bnc#1012628).
- xfs: XFS_IS_REALTIME_INODE() should be false if no rt device
  present (bnc#1012628).
- Linux 4.13.2 (bnc#1012628).
- Revert "net: use lib/percpu_counter API for fragmentation mem
  accounting" (bnc#1012628).
- Revert "net: fix percpu memory leaks" (bnc#1012628).
- gianfar: Fix Tx flow control deactivation (bnc#1012628).
- vhost_net: correctly check tx avail during rx busy polling
  (bnc#1012628).
- ip6_gre: update mtu properly in ip6gre_err (bnc#1012628).
- udp: drop head states only when all skb references are gone
  (bnc#1012628).
- ipv6: fix memory leak with multiple tables during netns
  destruction (bnc#1012628).
- ipv6: fix typo in fib6_net_exit() (bnc#1012628).
- sctp: fix missing wake ups in some situations (bnc#1012628).
- tcp: fix a request socket leak (bnc#1012628).
- ip_tunnel: fix setting ttl and tos value in collect_md mode
  (bnc#1012628).
- f2fs: let fill_super handle roll-forward errors (bnc#1012628).
- f2fs: check hot_data for roll-forward recovery (bnc#1012628).
- thunderbolt: Remove superfluous check (bnc#1012628).
- thunderbolt: Make key root-only accessible (bnc#1012628).
- thunderbolt: Allow clearing the key (bnc#1012628).
- x86/fsgsbase/64: Fully initialize FS and GS state in
  start_thread_common (bnc#1012628).
- x86/fsgsbase/64: Report FSBASE and GSBASE correctly in core
  dumps (bnc#1012628).
- x86/switch_to/64: Rewrite FS/GS switching yet again to fix
  AMD CPUs (bnc#1012628).
- x86/mm, mm/hwpoison: Clear PRESENT bit for kernel 1:1 mappings
  of poison pages (bnc#1012628).
- ovl: fix false positive ESTALE on lookup (bnc#1012628).
- fuse: allow server to run in different pid_ns (bnc#1012628).
- idr: remove WARN_ON_ONCE() when trying to replace negative ID
  (bnc#1012628).
- libnvdimm, btt: check memory allocation failure (bnc#1012628).
- libnvdimm: fix integer overflow static analysis warning
  (bnc#1012628).
- xfs: write unmount record for ro mounts (bnc#1012628).
- xfs: toggle readonly state around xfs_log_mount_finish
  (bnc#1012628).
- xfs: Add infrastructure needed for error propagation during
  buffer IO failure (bnc#1012628).
- xfs: Properly retry failed inode items in case of error during
  buffer writeback (bnc#1012628).
- xfs: fix recovery failure when log record header wraps log end
  (bnc#1012628).
- xfs: always verify the log tail during recovery (bnc#1012628).
- xfs: fix log recovery corruption error due to tail overwrite
  (bnc#1012628).
- xfs: handle -EFSCORRUPTED during head/tail verification
  (bnc#1012628).
- xfs: stop searching for free slots in an inode chunk when
  there are none (bnc#1012628).
- xfs: evict all inodes involved with log redo item (bnc#1012628).
- xfs: check for race with xfs_reclaim_inode() in
  xfs_ifree_cluster() (bnc#1012628).
- xfs: open-code xfs_buf_item_dirty() (bnc#1012628).
- xfs: remove unnecessary dirty bli format check for ordered bufs
  (bnc#1012628).
- xfs: ordered buffer log items are never formatted (bnc#1012628).
- xfs: refactor buffer logging into buffer dirtying helper
  (bnc#1012628).
- xfs: don't log dirty ranges for ordered buffers (bnc#1012628).
- xfs: skip bmbt block ino validation during owner change
  (bnc#1012628).
- xfs: move bmbt owner change to last step of extent swap
  (bnc#1012628).
- xfs: disallow marking previously dirty buffers as ordered
  (bnc#1012628).
- xfs: relog dirty buffers during swapext bmbt owner change
  (bnc#1012628).
- xfs: disable per-inode DAX flag (bnc#1012628).
- xfs: fix incorrect log_flushed on fsync (bnc#1012628).
- xfs: don't set v3 xflags for v2 inodes (bnc#1012628).
- xfs: open code end_buffer_async_write in
  xfs_finish_page_writeback (bnc#1012628).
- xfs: use kmem_free to free return value of kmem_zalloc
  (bnc#1012628).
- md/raid1/10: reset bio allocated from mempool (bnc#1012628).
- md/raid5: release/flush io in raid5_do_work() (bnc#1012628).
- xfs: fix compiler warnings (bnc#1012628).
- Linux 4.13.3 (bnc#1012628).
- Delete patches.kernel.org/patch-4.13.1.
- Delete patches.kernel.org/patch-4.13.1-2.
- Delete patches.kernel.org/patch-4.13.2-3.
  Replace stable all-in-one patches by expanded patches.
- commit 8e0ee21
* Mon Sep 25 2017 jslaby@suse.cz
- x86/asm: Fix inline asm call constraints for Clang
  (bnc#1058115).
- objtool: Handle another GCC stack pointer adjustment bug
  (bnc#1058115).
- x86/asm: Fix inline asm call constraints for Clang
  (bnc#1058115).
- objtool: Handle another GCC stack pointer adjustment bug
  (bnc#1058115).
- commit 8e680d0
* Mon Sep 25 2017 jslaby@suse.cz
- scripts/stableids: generate one file per commit
- commit c82ad0e
* Mon Sep 25 2017 mkubecek@suse.cz
- 8139too: revisit napi_complete_done() usage (bsc#1042208).
- commit 99343bb
* Sun Sep 24 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: only rewrite modules.dep if non-zero in size
  (bsc#1056979).
- commit 75691fd
* Fri Sep 22 2017 jslaby@suse.cz
- crypto: x86/blowfish - Fix RBP usage (bnc#1058115).
- crypto: x86/camellia - Fix RBP usage (bnc#1058115).
- crypto: x86/cast5 - Fix RBP usage (bnc#1058115).
- crypto: x86/cast6 - Fix RBP usage (bnc#1058115).
- crypto: x86/des3_ede - Fix RBP usage (bnc#1058115).
- crypto: x86/sha1-avx2 - Fix RBP usage (bnc#1058115).
- crypto: x86/sha1-ssse3 - Fix RBP usage (bnc#1058115).
- crypto: x86/sha256-avx - Fix RBP usage (bnc#1058115).
- crypto: x86/sha256-avx2 - Fix RBP usage (bnc#1058115).
- crypto: x86/sha256-ssse3 - Fix RBP usage (bnc#1058115).
- crypto: sha512-avx2 - Fix RBP usage (bnc#1058115).
- crypto: x86/twofish - Fix RBP usage (bnc#1058115).
  Update upstream status.
- commit e890e3e
* Thu Sep 21 2017 jeffm@suse.com
- drm/tegra: trace: Fix path to include (build fix).
- commit aecd9be
* Wed Sep 20 2017 afaerber@suse.de
- config: armv7hl: Update to 4.14-rc1
- commit 9d284f8
* Wed Sep 20 2017 afaerber@suse.de
- config: armv6hl: Update to 4.14-rc1
- commit 0c2764f
* Wed Sep 20 2017 afaerber@suse.de
- config: arm64: Update to 4.14-rc1
- commit d6909a3
* Wed Sep 20 2017 jeffm@suse.com
- Revert "KVM: Don't accept obviously wrong gsi values via
  KVM_IRQFD" (build fix).
- commit f436aa0
* Wed Sep 20 2017 mcgrof@suse.com
- nl80211: check for the required netlink attributes presence
  (bsc#1058410 CVE-2017-12153).
- commit 8afa5c8
* Wed Sep 20 2017 mcgrof@suse.com
- nl80211: check for the required netlink attributes presence
  (bsc#1058410 CVE-2017-12153).
- commit 6d93561
* Wed Sep 20 2017 tiwai@suse.de
- qxl: fix pinning (bsc#1057241,bsc#1057123).
- qxl: fix primary surface handling (bsc#1057241,bsc#1057123).
- commit b3d7f33
* Wed Sep 20 2017 jslaby@suse.cz
- Linux 4.13.3 (bnc#1012628).
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- commit 76ecbd3
* Wed Sep 20 2017 lduncan@suse.com
- Fix incorrect backport of compatibility patch (bsc#1053501)
  This fixes commit fe56e414dcf9, which incorrectly placed
  the back-ported macros in libc-compat.h in the wrong place.
  It is important for __UAPI_DEF_IOVEC to be defined
  correctly with and without GLIBC being defined.
- commit 102e6e3
* Tue Sep 19 2017 jslaby@suse.cz
- objtool: Fix object file corruption (bnc#1058115).
- objtool: Do not retrieve data from empty sections (bnc#1058115).
- objtool: Fix memory leak in elf_create_rela_section()
  (bnc#1058115).
- objtool: Fix object file corruption (bnc#1058115).
- objtool: Do not retrieve data from empty sections (bnc#1058115).
- objtool: Fix memory leak in elf_create_rela_section()
  (bnc#1058115).
- commit 5a29d69
* Tue Sep 19 2017 jslaby@suse.cz
- x86/crypto: Fix RBP usage in twofish-avx-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in sha512-avx2-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha256-ssse3-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha256-avx2-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha256-avx-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha1_ssse3_asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha1_avx2_x86_64_asm.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in des3_ede-asm_64.S (bnc#1058115).
- x86/crypto: Fix RBP usage in cast6-avx-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in cast5-avx-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in camellia-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in blowfish-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in twofish-avx-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in sha512-avx2-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha256-ssse3-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha256-avx2-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha256-avx-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha1_ssse3_asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha1_avx2_x86_64_asm.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in des3_ede-asm_64.S (bnc#1058115).
- x86/crypto: Fix RBP usage in cast6-avx-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in cast5-avx-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in camellia-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in blowfish-x86_64-asm_64.S
  (bnc#1058115).
- commit 38f3021
* Tue Sep 19 2017 jeffm@suse.com
- Update to 4.14-rc1.
- Eliminated 17 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - HMM_MIRROR=n
  - DEVICE_PRIVATE=n
  - DEVICE_PUBLIC=n
  - SQUASHFS_ZSTD=y
  - ZRAM_WRITEBACK=y
  - x86:
  - INTEL_RDT=y (renamed option)
  - XEN_PVCALLS_BACKEND=y
  - X86_5LEVEL=n (will only boot on systems that support it)
  - AMD_MEM_ENCRYPT=y
  - AMD_MEM_ENCRYPT_ACTIVE_BY_DEFAULT=n
  - ppc:
  - PPC_MEMTRACE=y
  - PPC_VAS=y
  - s390:
  - CMA_DEBUG=n
  - CMA_DEBUGFS=n
  - CMA_AREAS=7 (default)
  - DMA_CMA=n
  - VMCP_CMA_SIZE=4 (default)
  - Netfilter:
  - NFT_FIB_NETDEV
  - Hyperv:
  - HYPERV_VSOCKETS
  - Network:
  - NET_NSH
  - BPF_STREAM_PARSER=y (build fix)
  - BNXT_FLOWER_OFFLOAD=y
  - HINIC
  - MLX5_MPFS=y
  - MLX5_ESWITCH=y
  - RMNET=n
  - ROCKCHIP_PHY
  - WIL6210_DEBUGFS=n
  - ATH10K_USB
  - Bluetooth:
  - BT_LEGACY_IOCTL=y (default)
  - SPI:
  - SPI_INTEL_SPI_PCI
  - Misc:
  - INPUT_PWM_VIBRA=m
  - SERIO_GPIO_PS2=m
  - PINCTRL_DENVERTON
  - PINCTRL_LEWISBURG
  - W1_SLAVE_DS2805
  - BATTERY_BQ27XXX_HDQ=m
  - BATTERY_MAX1721X
  - SENSORS_IBM_CFFPS
  - SENSORS_TPS53679
  - CLOCK_THERMAL=y
  - DEVFREQ_THERMAL=y
  - MFD_BD9571MWV=n
  - INTEL_SOC_PMIC_CHTWC=y
  - MFD_TPS68470=n
  - IR_GPIO_TX=n
  - IR_PWM_TX=n
  - DVB_DDBRIDGE
  - DVB_DDBRIDGE_MSIENABLE=n
  - TINYDRM_REPAPER=n
  - TINYDRM_ST7586=n
  - SND_SOC_CS43130=n
  - SND_SOC_WM8524=n
  - MMC_SPI
  - LEDS_AS3645A=n
  - LEDS_PCA955X_GPIO=y
  - INFINIBAND_EXP_USER_ACCESS=y [?]
  - CONFIG_ALTERA_MSGDMA
  - R8822BE
  - PI433=n
  - CLK_HSDK=n
  - EXTCON_USBC_CROS_EC
  - DLN2_ADC=m
  - LTC2471=n
  - CCS811=n
  - RESET_HSDK_V1=n
  - FPGA_MGR_ALTERA_CVP=m
  - FPGA_MGR_ALTERA_PS_SPI=m
  - CRYPTO_DEV_SP_CCP=y
  - I2C_CHT_WC=m
  - RESET_ATTACK_MITIGATION=y
- commit 08ca987
* Tue Sep 19 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-objtool-Don-t-report-end-of-section-error-after-an-e.patch.
- Refresh
  patches.suse/0002-x86-head-Remove-confusing-comment.patch.
- Refresh
  patches.suse/0003-x86-head-Remove-unused-bad_address-code.patch.
- Refresh
  patches.suse/0004-x86-head-Fix-head-ELF-function-annotations.patch.
- Refresh
  patches.suse/0005-x86-boot-Annotate-verify_cpu-as-a-callable-function.patch.
- Refresh
  patches.suse/0006-x86-xen-Fix-xen-head-ELF-annotations.patch.
- Refresh
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-head-Add-unwind-hint-annotations.patch.
- Delete
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations-fix.patch.
  Update to the submitted v2.
- commit 27de3c0
* Sun Sep 17 2017 jdelvare@suse.de
- drm/amdgpu: revert tile table update for oland (boo#1027378,
  boo#1039806, bko#194761).
- Delete
  patches.fixes/drm-amdgpu-revert-update-tile-table-for-oland-hainan.patch.
- commit 51745cf
* Thu Sep 14 2017 jslaby@suse.cz
- Linux 4.13.2 (bnc#1012628 bsc#1055826).
- Delete
  patches.drivers/rt2800-fix-TX_PIN_CFG-setting-for-non-MT7620-chips.
- Delete
  patches.fixes/Bluetooth-validate-output-buffer-length-for-config-r.patch.
- commit 96d9efa
* Wed Sep 13 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix a thinko for xmlto buildreq condition
- commit 0ef59d3
* Wed Sep 13 2017 jslaby@suse.cz
- Bluetooth: validate output buffer length for config requests
  and responses (bnc#1057389 CVE-2017-1000251).
- commit c0b7e1f
* Tue Sep 12 2017 jslaby@suse.cz
- fix annotations of xen-head.S (bnc#1058115).
- commit d4c88a5
* Tue Sep 12 2017 msuchanek@suse.de
- rpm/kernel-docs.spec.in: make unpack scripts executable
- commit 1ba3766
* Tue Sep 12 2017 jslaby@suse.cz
- x86/head: Add unwind hint annotations (bnc#1058115).
- x86/xen: Add unwind hint annotations (bnc#1058115).
- x86/xen: Fix xen head ELF annotations (bnc#1058115).
- x86/boot: Annotate verify_cpu() as a callable function
  (bnc#1058115).
- x86/head: Fix head ELF function annotations (bnc#1058115).
- x86/head: Remove unused 'bad_address' code (bnc#1058115).
- x86/head: Remove confusing comment (bnc#1058115).
- objtool: Don't report end of section error after an empty
  unwind hint (bnc#1058115).
- commit 53af152
* Tue Sep 12 2017 jslaby@suse.cz
- objtool: Assume unannotated UD2 instructions are dead ends
  (bnc#1058115).
- objtool: Fix gcov check for older versions of GCC (bnc#1058115).
- objtool: Fix objtool fallthrough detection with function padding
  (bnc#1058115).
- objtool: Fix validate_branch() return codes (bnc#1058115).
- objtool: Handle GCC stack pointer adjustment bug (bnc#1058115).
- x86/asm: Add ASM_UNREACHABLE (bnc#1058115).
- x86/asm: Fix UNWIND_HINT_REGS macro for older binutils
  (bnc#1058115).
- x86/asm: Make objtool unreachable macros independent from GCC
  version (bnc#1058115).
- objtool: Skip unreachable warnings for 'alt' instructions
  (bnc#1058115).
- objtool: Track DRAP separately from callee-saved registers
  (bnc#1058115).
- Refresh patches.suse/0001-x86-unwind-Add-the-ORC-unwinder.patch.
  Take all ORC upstream patches. This will go to stable & SLE15 too.
- commit 831ca01
* Mon Sep 11 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- Refresh patches.suse/0001-x86-unwind-Add-the-ORC-unwinder.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
- Refresh
  patches.suse/0002-x86-kconfig-Make-it-easier-to-switch-to-the-new-ORC-.patch.
- Refresh
  patches.suse/0003-x86-dumpstack-Fix-occasionally-missing-registers.patch.
- Refresh
  patches.suse/0003-x86-kconfig-Consolidate-unwinders-into-multiple-choi.patch.
- Refresh
  patches.suse/0004-x86-dumpstack-Fix-interrupt-and-exception-stack-boun.patch.
- Refresh
  patches.suse/0005-objtool-Add-ORC-unwind-table-generation.patch.
- Refresh
  patches.suse/0006-objtool-x86-Add-facility-for-asm-code-to-provide-unw.patch.
- Refresh
  patches.suse/0007-x86-entry-64-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-asm-Add-unwind-hint-annotations-to-sync_core.patch.
- Delete
  patches.suse/0001-linkage-new-macros-for-assembler-symbols.patch.
- Delete
  patches.suse/0003-DWARF-EH-frame-based-stack-unwinding.patch.
- Delete patches.suse/stack-unwind-disable-kasan.patch.
  Update upstream status of ORC and drop already-disabled DWARF unwinder.
- commit 2e9b944
* Mon Sep 11 2017 jslaby@suse.cz
- rpm/constraints.in: build ARM on at least 2 cpus
- commit b7edeaf
* Mon Sep 11 2017 jslaby@suse.cz
- rpm/constraints.in: increase memory for kernel-syzkaller
  And see if it helps. If so, push it to packaging...
- commit 7193e65
* Sun Sep 10 2017 afaerber@suse.de
- config: arm64: Enable legacy instruction emulation (boo#1029158)
  Needed for execution of older e.g. ARMv6 code.
- commit a4e05e8
* Sun Sep 10 2017 afaerber@suse.de
- config: arm64: Enable ACPI_DOCK for consistency
- commit cec354f
* Sun Sep 10 2017 afaerber@suse.de
- config: arm64: Enable some network options
- Marvell Armada 7K/8K Ethernet driver
- Microchip ENC28J60 and related SPI Ethernet drivers
- Micrel KS8851 SPI Ethernet driver
- MMIO MDIO mux driver
- commit cf926f4
* Sun Sep 10 2017 jslaby@suse.cz
- rpm/constraints.in: set physical memory
  Not memory.
- rpm/constraints.in: increase memory for kernel-syzkaller
  And see if it helps. If so, push it to packaging...
- commit 0d725b5
* Sun Sep 10 2017 jslaby@suse.cz
- Linux 4.13.1 (bnc#1012628).
- commit 8740849
* Fri Sep  8 2017 jslaby@suse.cz
- rpm/kernel-binary.spec.in: package ftrace-mod.o on arm64
  It is needed for building modules since 4.13:
  CC [M]  /suse/jslaby/a/aaa.o
  Building modules, stage 2.
  MODPOST 1 modules
  CC      /suse/jslaby/a/aaa.mod.o
  LD [M]  /suse/jslaby/a/aaa.ko
  ld: cannot find ./arch/arm64/kernel/ftrace-mod.o: No such file or directory
  ...
- commit 07da115
* Thu Sep  7 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Expand kernel tree directly from sources (bsc#1057199)
- commit a61b4d9
* Thu Sep  7 2017 jslaby@suse.cz
- Linux 4.12.11 (bnc#1012628).
- commit bf7fb08
* Wed Sep  6 2017 mcgrof@suse.com
- supported.conf: add test_syctl to new kselftests-kmp package FATE#323821
  As per FATE#323821 we will require new FATE requests per each
  new selftest driver. We don't want to support these module on
  production runs but we do want to support them for QA / testing
  uses. The compromise is to package them into its own package,
  this will be the kselftests-kmp package.
  Selftests can also be used as proof of concept vehicle for issues
  by customers or ourselves.
  Vanilla kernels do not get test_sysctl given that driver was
  using built-in defaults, this also means we cannot run sefltests
  on config/s390x/zfcpdump which does not enable modules.
  Likeweise, since we had to *change* the kernel for test_syctl, it
  it also means we can't test test_syctl with vanilla kernels. It
  should be possible with other selftests drivers if they are
  present in vanilla kernels though.
- commit ae8069f
* Wed Sep  6 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Re-add xmlto buildreq conditionally for SLE15 & co
- commit 259b49e
* Wed Sep  6 2017 mchandras@suse.de
- rpm/group-source-files.pl: Add arch/*/tools/* files to the devel package
  Commit b71c9ffb1405 ("powerpc: Add arch/powerpc/tools directory")
  introduced in v4.12-rc1 release, moved the scripts into the tools
  directory. However, this location is not considered for the kernel devel
  package and the following error occurs when building a kmp for powerpc
  make[2]: /usr/src/linux-4.12.9-1/arch/powerpc/tools/gcc-check-mprofile-kernel.sh: Command not found
- commit 5f1ff53
* Tue Sep  5 2017 jeffm@suse.com
- Update to 4.13-final.
- commit 3fdcb17
* Thu Aug 31 2017 tiwai@suse.de
- rt2800: fix TX_PIN_CFG setting for non MT7620 chips
  (bsc#1055826).
- commit 8116757
* Thu Aug 31 2017 jeffm@suse.com
- Update to 4.13-rc7.
- Eliminate 2 patches.
- commit dd00417
* Thu Aug 31 2017 jthumshirn@suse.de
- scsi: qla2xxx: Fix an integer overflow in sysfs code
  (bsc#1056588, CVE-2017-14051).
- commit 4fafb75
* Thu Aug 31 2017 jthumshirn@suse.de
- scsi: qla2xxx: Fix an integer overflow in sysfs code
  (bsc#1056588, CVE-2017-14051).
- commit aacb454
* Wed Aug 30 2017 jslaby@suse.cz
- Linux 4.12.10 (bnc#1012628 bnc#1014351 bnc#1048935 bsc#1020657
  bsc#1050582).
- Delete
  patches.drivers/ALSA-hda-Add-stereo-mic-quirk-for-Lenovo-G50-70-17aa.
- Delete
  patches.fixes/Bluetooth-hidp-fix-possible-might-sleep-error-in-hid.patch.
- Delete
  patches.fixes/Input-ALPS-Fix-Alps-Touchpad-two-finger-scroll-does-.
- Delete
  patches.fixes/netfilter-expect-fix-crash-when-putting-uninited-exp.patch.
- commit 030062c
* Tue Aug 29 2017 tiwai@suse.de
- Refresh patches.suse/iwlwifi-expose-default-fallback-ucode-api.
  The latest firmware matches for iwl7xxx/3168 series, so dropped the changes.
- commit 1447668
* Tue Aug 29 2017 tiwai@suse.de
- Update config files: enable CONFIG_SPI_PXA2XX for MacBook (bsc#1055817)
- commit 3ce18e9
* Mon Aug 28 2017 tiwai@suse.de
- rpm/kernel-binary.spec.in: Update drm-kmp obsolete for SLE12-SP3/Leap-42.3
- commit 77ccbd0
* Mon Aug 28 2017 tiwai@suse.de
- Refresh patch tags of patches.fixes/Input-ALPS-Fix-Alps-Touchpad-two-finger-scroll-does-
- commit 0b3ef4c
* Mon Aug 28 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Disable PDF build again
  ... due to the breakage with the recent TeXLive 2017.
  Also add the missing dependency on texlive-varwidth.
- commit 9f682b5
* Fri Aug 25 2017 jslaby@suse.cz
- Linux 4.12.9 (bnc#1012628 bsc#1052580 bnc#1049599).
- Delete
  patches.drivers/ALSA-usb-audio-Apply-sample-rate-quirk-to-Sennheiser.
- Delete patches.fixes/debug-fix-WARN_ON_ONCE-for-modules.patch.
- Update config files.
- commit f2ab6ba
* Wed Aug 23 2017 tiwai@suse.de
- ALSA: hda - Add stereo mic quirk for Lenovo G50-70 (17aa:3978)
  (bsc#1020657).
- commit 3f6a0b2
* Wed Aug 23 2017 tiwai@suse.de
- ALSA: hda - Add stereo mic quirk for Lenovo G50-70 (17aa:3978)
  (bsc#1020657).
- commit d300598
* Wed Aug 23 2017 jslaby@suse.cz
- Bluetooth: hidp: fix possible might sleep error in
  hidp_session_thread (bnc#1014351).
- commit fa3a4f0
* Tue Aug 22 2017 tiwai@suse.de
- ALSA: ice1712: Add support for STAudio ADCIII (bsc#1048934).
- commit 99a99ef
* Tue Aug 22 2017 tiwai@suse.de
- ALSA: ice1712: Add support for STAudio ADCIII (bsc#1048934).
- commit 53a20a8
* Tue Aug 22 2017 tiwai@suse.de
- ALSA: hda - Implement mic-mute LED mode enum (bsc#1055013).
- commit a3c362f
* Tue Aug 22 2017 tiwai@suse.de
- ALSA: hda - Implement mic-mute LED mode enum (bsc#1055013).
- commit b870486
* Mon Aug 21 2017 jeffm@suse.com
- Update to 4.13-rc6.
- commit ee50b89
* Fri Aug 18 2017 msuchanek@suse.de
- Do not ship firmware (bsc#1054239).
  Pull firmware from kernel-firmware instead.
- commit 0b0b5c9
* Thu Aug 17 2017 jeffm@suse.com
- supported.conf: clear mistaken external support flag for cifs.ko (bsc#1053802).
- commit 75e287e
* Thu Aug 17 2017 jeffm@suse.com
- supported.conf: mark reiserfs unsupported (FATE#323394).
  ReiserFS is not supported in SLE15.  ReiserFS file systems must be
  transferred or converted before installing.
- commit 8a547c5
* Thu Aug 17 2017 jeffm@suse.com
- Update to 4.13-rc5.
- commit c3fb699
* Thu Aug 17 2017 jslaby@suse.cz
- Linux 4.12.8 (bnc#1012628).
- commit 4d7933a
* Wed Aug 16 2017 msuchanek@suse.de
- s390: export symbols for crash-kmp (bsc#1053915).
- commit 7dd9b75
* Tue Aug 15 2017 hare@suse.de
- Delete patches.fixes/scsi-dh-queuedata-accessors.
- commit ee998ab
* Tue Aug 15 2017 hare@suse.de
- Delete patches.suse/dm-mpath-detach-existing-hardware-handler.
- commit a8291cd
* Tue Aug 15 2017 hare@suse.de
- Delete patches.suse/no-partition-scan (FATE#323406)
- commit e1cccca
* Tue Aug 15 2017 tiwai@suse.de
- ALSA: usb-audio: Apply sample rate quirk to Sennheiser headset
  (bsc#1052580).
- commit a8251af
* Sun Aug 13 2017 jslaby@suse.cz
- Linux 4.12.7 (bnc#1012628).
- commit 7dae241
* Sun Aug 13 2017 jslaby@suse.cz
- Refresh
  patches.fixes/netfilter-expect-fix-crash-when-putting-uninited-exp.patch.
  Update upstream status.
- commit cdb9f49
* Sat Aug 12 2017 jslaby@suse.cz
- Linux 4.12.6 (CVE-2017-7542 CVE-2017-8831 bnc#1012628
  bsc#1037994 bsc#1049882).
- Delete
  patches.fixes/ipv6-avoid-overflow-of-offset-in-ip6_find_1stfragopt.patch.
- Delete
  patches.fixes/media-saa7164-fix-double-fetch-PCIe-access-condition.
- commit 29b7412
* Sat Aug 12 2017 lduncan@suse.com
- uapi: add a compatibility layer between linux/uio.h and glibc
  (bsc#1053501).
- commit fe56e41
* Thu Aug 10 2017 msuchanek@suse.de
- Refresh vanilla config.
- commit ae18928
* Thu Aug 10 2017 msuchanek@suse.de
- rpm/modules.fips include module list from dracut
- commit f70bab5
* Wed Aug  9 2017 ohering@suse.de
- Delete stale patches.fixes/scsi-ibmvscsi-module_alias.patch.
- Delete stale patches.suse/suse-ppc64-branding.
- commit 1c8934b
* Wed Aug  9 2017 tiwai@suse.de
- [media] saa7164: fix double fetch PCIe access condition
  (CVE-2017-8831 bsc#1037994).
- commit 4d38c27
* Tue Aug  8 2017 jeffm@suse.com
- Update to 4.13-rc4.
- commit 94b098f
* Mon Aug  7 2017 jslaby@suse.cz
- Linux 4.12.5 (bnc#1012628 bsc#1049483 bsc#1049599).
- Delete patches.fixes/dentry-name-snapshots.patch.
- Delete
  patches.suse/0001-md-remove-idx-from-struct-resync_pages.patch.
- commit e6109ef
* Wed Aug  2 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix package list and enable building PDFs
  Finally it works!  Added some missing pieces (ImageMagick, some texlive
  subpkgs) in addition to use explicitly python3-Sphinx stuff.
- commit c117a0c
* Tue Aug  1 2017 agraf@suse.de
- Clean up upstreamed patches list. Annotate the remaining ones
  with their current status.
- Delete patches.arch/arm-exynos-dwmmc-modalias.patch.
- Delete
  patches.arch/arm64-Relocate-screen_info.lfb_base-on-PCI-BAR-alloc.patch.
- commit 3f654d5
* Mon Jul 31 2017 jeffm@suse.com
- Update to 4.13-rc3.
- commit 4ef483a
* Fri Jul 28 2017 jslaby@suse.cz
- Update config files.
  Fix vanillas after the orc update.
- commit 2a27bf2
* Fri Jul 28 2017 jslaby@suse.cz
- Linux 4.12.4 (bnc#1012628).
- commit f2e2c0a
* Thu Jul 27 2017 mkubecek@suse.cz
- ipv6: avoid overflow of offset in ip6_find_1stfragopt
  (CVE-2017-7542 bsc#1049882).
- commit 00c5961
* Thu Jul 27 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-md-remove-idx-from-struct-resync_pages.patch.
- commit b11fd5b
* Thu Jul 27 2017 jslaby@suse.cz
- objtool: Fix sibling call detection logic (bnc#1018348).
- x86/kconfig: Make it easier to switch to the new ORC unwinder
  (bnc#1018348).
- x86/kconfig: Consolidate unwinders into multiple choice
  selection (bnc#1018348).
- Refresh
- Refresh patches.suse/0001-x86-unwind-Add-the-ORC-unwinder.patch.
- Refresh
  patches.suse/0002-dwarf-do-not-throw-away-unwind-info.patch.
- Refresh
  patches.suse/0002-objtool-x86-Add-several-functions-and-files-to-the-o.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
- Refresh
  patches.suse/0002-x86-kconfig-Make-it-easier-to-switch-to-the-new-ORC-.patch.
- Refresh
  patches.suse/0003-objtool-Implement-stack-validation-2.0.patch.
- Refresh
  patches.suse/0003-x86-kconfig-Consolidate-unwinders-into-multiple-choi.patch.
- Refresh
  patches.suse/0007-x86-entry-64-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-asm-Add-unwind-hint-annotations-to-sync_core.patch.
- Update config files.
  Update to version from -tip. ORC is in -tip completely. So make sure
  we use the upstream version.
- x86/kconfig: Make it easier to switch to the new ORC unwinder
  (bnc#1018348).
- x86/kconfig: Consolidate unwinders into multiple choice
  selection (bnc#1018348).
- Update config files.
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- Refresh
  patches.suse/0002-dwarf-do-not-throw-away-unwind-info.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
  Update to version from -tip. ORC is in -tip completely. So make sure
  we use the upstream version.
- commit 34dd0f5
* Wed Jul 26 2017 mcgrof@suse.com
- Refresh
  patches.suse/0001-mm-kmemleak-slightly-reduce-the-size-of-some-structu.patch.
- Refresh
  patches.suse/0002-mm-kmemleak-factor-object-reference-updating-out-of-.patch.
- Refresh
  patches.suse/0003-mm-kmemleak-treat-vm_struct-as-alternative-reference.patch.
- commit f7ebe40
* Wed Jul 26 2017 mcgrof@suse.com
- Refresh
  patches.suse/0001-mm-kmemleak-slightly-reduce-the-size-of-some-structu.patch.
- Refresh
  patches.suse/0002-mm-kmemleak-factor-object-reference-updating-out-of-.patch.
- Refresh
  patches.suse/0003-mm-kmemleak-treat-vm_struct-as-alternative-reference.patch.
- commit eb41516
* Wed Jul 26 2017 jeffm@suse.com
- Update to 4.13-rc2.
- Eliminated 1 patch.
- Config changes:
  - DRM_VBOXVIDEO=m
- commit b545b87
* Wed Jul 26 2017 tiwai@suse.de
- Input: ALPS - Fix Alps Touchpad two finger scroll does not
  work on right side (bsc#1050582).
- commit 474729b
* Sun Jul 23 2017 stefan.bruens@rwth-aachen.de
- config: arm64: Enable RTC and SPI on Allwinner A64/H5
  A64 and H5 share the RTC and SPI functional blocks with older SoCs,
  enable the corresponding drivers.
- commit b5bf58a
* Fri Jul 21 2017 colyli@suse.de
- md: remove 'idx' from 'struct resync_pages' (bsc#1049599).
- commit 515f14e
* Fri Jul 21 2017 jslaby@suse.cz
- Linux 4.12.3 (CVE-2017-7541 bnc#1012628 bsc#1049645).
- Refresh patches.suse/pstore-backend-autoaction.
- Delete
  patches.fixes/brcmfmac-fix-possible-buffer-overflow-in-brcmf_cfg80.
- commit 409edbf
* Thu Jul 20 2017 jack@suse.cz
- dentry name snapshots (bsc#1049483).
- commit 76ea0ca
* Thu Jul 20 2017 jslaby@suse.cz
- debug: fix WARN_ON_ONCE() for modules (bnc#1049599).
- commit b1e9bab
* Thu Jul 20 2017 tiwai@suse.de
- brcmfmac: fix possible buffer overflow in
  brcmf_cfg80211_mgmt_tx() (CVE-2017-7541,bsc#1049645).
- commit 823a643
* Wed Jul 19 2017 mmarek@suse.cz
- rpm/kernel-binary.spec.in: find-debuginfo.sh should not touch build-id
  This needs rpm-4.14+ (bsc#964063).
- commit f622d60
* Tue Jul 18 2017 afaerber@suse.de
- config: armv7hl: Update to v4.13-rc1
- commit 1d72b01
* Tue Jul 18 2017 afaerber@suse.de
- config: armv6hl: Update to v4.13-rc1
- commit 5ede81f
* Tue Jul 18 2017 afaerber@suse.de
- config: arm64: Update to v4.13-rc1
- commit 7d005f8
* Tue Jul 18 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
- Refresh
  patches.suse/0003-x86-dumpstack-fix-occasionally-missing-registers.patch.
- Refresh
  patches.suse/0004-x86-dumpstack-fix-interrupt-and-exception-stack-boun.patch.
- Refresh
  patches.suse/0005-objtool-add-ORC-unwind-table-generation.patch.
- Refresh
  patches.suse/0006-objtool-x86-add-facility-for-asm-code-to-provide-unw.patch.
- Refresh
  patches.suse/0007-x86-entry-64-add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-asm-add-unwind-hint-annotations-to-sync_core.patch.
  Update upstream information.
- commit 8db850a
* Tue Jul 18 2017 tiwai@suse.de
- Delete patches.fixes/drm-i915-Fix-S4-resume-breakage.
  The workaround wasn't merged to upstream, and it seems becoming
  superfluous with the recent i915 driver, so let's drop this one.
- commit f6f228c
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Drop unnecessary xmlto for 4.13+
- commit e47dc84
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Correct kernel-docs package summary/description
- commit 697b763
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: refresh dependencies for PDF build (bsc#1048129)
  But it still doesn't work with Tex Live 2017, thus disabled yet.
  Also add texlive-anyfontsize for HTML math handling.
- commit ead44a1
* Tue Jul 18 2017 jslaby@suse.cz
- Delete patches.rpmify/drm-i915-disable-KASAN-for-handlers.patch.
  It was never accepted, is under discussion. But we disabled
  CONFIG_DRM_I915_WERROR in commit 5fc7b327348b, so we are safe anyway.
- commit 09fc05f
* Tue Jul 18 2017 jslaby@suse.cz
- Delete patches.rpmify/get_builtin_firmware-gcc-7.patch.
  This was never accepted. Instead this seems to be fixed in gcc.
- commit c486b10
* Mon Jul 17 2017 jeffm@suse.com
- Updated to 4.13-rc1.
- Eliminated 13 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - SLAB_MERGE_DEFAULT=y (current behavior)
  - REFCOUNT_FULL=n (current behavior)
  - PERCPU_STATS=n (default)
  - FORTIFY_SOURCE=n (needs performance analysis)
  - WARN_ALL_UNSEEDED_RANDOM=n
  - TRACE_EVAL_MAP_FILE=n
  - TEST_SYSCTL=n
  - TEST_KMOD=n
  - Storage:
  - DM_ZONED=m
  - IB:
  - Options for MLX5:
  - MLX5_FPGA
  - MLX5_EN_IPSEC=y
  - MLXFW=m
  - SECURITY_INFINIBAND=y
  - Network:
  - Options for NFP:
  - NFP_APP_FLOWER=y
  - CORTINA_PHY=n (intended for embedded apps)
  - ATH10K_SDIO=m
  - QTNFMAC_PEARL_PCIE=m
  - DRM:
  - DRM_I915_SW_FENCE_CHECK_DAG=n
  - Sound:
  - SND_SOC_INTEL_BYT_CHT_ES8316_MACH=m
  - SND_SOC_INTEL_KBL_RT5663_MAX98927_MACH=m
  - SND_SOC_INTEL_KBL_RT5663_RT5514_MAX98927_MACH=m
  - SND_SOC_ZX_AUD96P22=n
  - HID:
  - HID_ITE=n
  - HID_RETRODE=m
  - USB:
  - TYPEC_UCSI=m
  - UCSI_ACPI=m
  - Misc:
  - RTC_NVMEM=y
  - RTC_DRV_DS3232_HWMON=y
  - WMI_BMOF=m
  - PEAQ_WMI=m
  - INTEL_INT0002_VGPIO=m
  - CROS_EC_LPC_MEC=y
  - EXTCON_INTEL_CHT_WC=m
  - NTB_IDT=m
  - MULTIPLEXER=m
  - KEYBOARD_DLINK_DIR685=n
  - TOUCHSCREEN_STMFTS=n
  - I2C_DESIGNWARE_SLAVE=n
  - SPI_SLAVE=n
  - PINCTRL_MCP23S08=n
  - PINCTRL_CANNONLAKE=m
  - GPIO_XRA1403=n
  - BATTERY_BQ27XXX_DT_UPDATES_NVM=n
  - CHARGER_LTC3651=n
  - SENSORS_IR35221=n
  - WATCHDOG_HANDLE_BOOT_ENABLED=y (default)
  - File Systems:
  - OVERLAY_FS_INDEX=n (mounting on an older kernel read-write will cause unexpected results)
  - CIFS_DEBUG_DUMP_KEYS=n
  - Crypto:
  - CRC4=m
  - X86:
  - INTEL_SOC_PMIC_CHTWC=m
  - CHT_WC_PMIC_OPREGION=y
  - ppc64/ppc64le:
  - CONFIG_IRQ_TIME_ACCOUNTING=n
  - CONFIG_LD_HEAD_STUB_CATCH=n
  - ZONE_DEVICE=y
  - ppc64le:
  - STRICT_KERNEL_RWX=y
  - s390x:
  - CRYPTO_PAES_S390=m
- commit d418532
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.drivers/ppc64-adb.
  This hardware was discontinued in 2006 and the patch was never accepted
  upstream.
- commit 995698b
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.arch/ppc-prom-nodisplay.patch.
  We no longer support 32-bit ppc and this hardware only existed with a
  32-bit CPU.
- commit d94ed1e
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.arch/ppc-pegasos-console-autodetection.patch.
  We no longer support 32-bit ppc and this hardware only existed with a
  32-bit CPU.
- commit b42ddc6
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.suse/ppc-powerbook-usb-fn-key-default.patch.
  We no longer support 32-bit ppc and there were no 64-bit powerbooks.
- commit 9e9a512
* Mon Jul 17 2017 jeffm@suse.com
- Disable patches.suse/pstore-backend-autoaction.
  It needs updating and there now exists a mount option instead of a module
  parameter.
- commit 87a5ab7
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.fixes/block-copy-bi_vcnt-in-_bio_clone_fast.
  This was obsoleted by 764f612c6c3c ("blk-merge: don't compute
  bi_phys_segments from bi_vcnt for cloned bio").
- commit f0c2642
* Mon Jul 17 2017 jslaby@suse.cz
- netfilter: expect: fix crash when putting uninited expectation
  (bnc#1048935).
- netfilter: expect: fix crash when putting uninited expectation
  (bnc#1048935).
- Delete
  patches.fixes/netfilter-nf_ct_expect-fix-expect-removal.patch.
  Replace by upstream fix (from a subsys repo).
- commit cc9efac
* Mon Jul 17 2017 jslaby@suse.cz
- netfilter: nf_ct_expect: fix expect removal (bnc#1048935).
- commit 28fe876
* Mon Jul 17 2017 mmarek@suse.cz
- Drop multiversion(kernel) from the KMP template (fate#323189)
- commit 71504d8
* Tue Jul 11 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix and cleanup for 4.13 doc build (bsc#1048129)
  The whole DocBook stuff has been deleted.  The PDF build still non-working
  thus the sub-packaging disabled so far.
- commit 8e7de10
* Mon Jun 19 2017 mcgrof@suse.com
- mm: kmemleak: treat vm_struct as alternative reference to vmalloc'ed objects (bsc#1027456).
- mm: kmemleak: factor object reference updating out of scan_block() (bsc#1027456).
- mm: kmemleak: slightly reduce the size of some structures on 64-bit architectures (bsc#1027456).
- commit 880dbd7
* Fri Jun  2 2017 afaerber@suse.de
- rpm/dtb.spec.in.in: Fix new include path
  Commit 89de3db69113d58cdab14d2c777de6080eac49dc ("rpm/dtb.spec.in.in:
  Update include path for dt-bindings") introduced an additional include
  path for 4.12. The commit message had it correct, but the spec file
  template lacked a path component, breaking the aarch64 build while
  succeeding on armv7hl. Fix that.
- commit c8d853a
* Wed May 31 2017 afaerber@suse.de
- rpm/dtb.spec.in.in: Update include path for dt-bindings
  Kernels before 4.12 had arch/{arm,arm64}/boot/dts/include/ directories
  with a symlink to include/dt-bindings/.
  In 4.12 those include/ directories were dropped.
  Therefore use include/ directly.
  Additionally some cross-architecture .dtsi reuse was introduced, which
  requires scripts/dtc/include-prefixes/ that didn't exist on older kernels.
- commit 466f108
* Fri Jan  6 2017 afaerber@suse.de
- rpm: Add arm64 dtb-zte subpackage
  4.9 added arch/arm64/boot/dts/zte/.
- commit 073d831
* Fri Jan  6 2017 afaerber@suse.de
- rpm: Add arm64 dtb-allwinner subpackage
  4.10 added arch/arm64/boot/dts/allwinner/.
- commit dfeb94a
* Tue Dec 20 2016 xxxxxmichl@googlemail.com
- added De0-Nanos-SoC board support (and others based on Altera SOC).
- commit 9278339
* Tue Apr 26 2016 mmarek@suse.cz
- Drop sysctl files for dropped archs, add ppc64le and arm (bsc#1178838).
- commit 87cd715
* Tue Mar 31 2009 jeffm@suse.de
- doc/README.KSYMS: Add to repo.
- commit 04ec451
